word_awl ={"abandon",
"abandoned",
"abandoning",
"abandonment",
"abandons",
"abstract",
"abstraction",
"abstractions",
"abstractly",
"abstracts",
"academy",
"academia",
"academic",
"academically",
"academics",
"academies",
"access",
"accessed",
"accesses",
"accessibility",
"accessible",
"accessing",
"inaccessible",
"accommodate",
"accommodated",
"accommodates",
"accommodating",
"accommodation",
"accompany",
"accompanied",
"accompanies",
"accompaniment",
"accompanying",
"unaccompanied",
"accumulate",
"accumulated",
"accumulating",
"accumulation",
"accumulates",
"accurate",
"accuracy",
"accurately",
"inaccuracy",
"inaccuracies",
"inaccurate",
"achieve",
"achievable",
"achieved",
"achievement",
"achievements",
"achieves",
"achieving",
"acknowledge",
"acknowledged",
"acknowledges",
"acknowledging",
"acknowledgement",
"acknowledgements",
"acquire",
"acquired",
"acquires",
"acquiring",
"acquisition",
"acquisitions",
"adapt",
"adaptability",
"adaptable",
"adaptation",
"adaptations",
"adapted",
"adapting",
"adaptive",
"adapts",
"adequate",
"adequacy",
"adequately",
"inadequacies",
"inadequacy",
"inadequate",
"inadequately",
"adjacent",
"adjust",
"adjusted",
"adjusting",
"adjustment",
"adjustments",
"adjusts",
"readjust",
"readjusted",
"readjusting",
"readjustment",
"readjustments",
"readjusts",
"administrate",
"administrates",
"administration",
"administrations",
"administrative",
"administratively",
"administrator",
"administrators",
"adult",
"adulthood",
"adults",
"advocate",
"advocacy",
"advocated",
"advocates",
"advocating",
"affect",
"affected",
"affecting",
"affective",
"affects",
"unaffected",
"aggregate",
"aggregated",
"aggregates",
"aggregating",
"aggregation",
"aid",
"aided",
"aiding",
"aids",
"unaided",
"albeit",
"allocate",
"allocated",
"allocates",
"allocating",
"allocation",
"allocations",
"alter",
"alterable",
"alteration",
"alterations",
"altered",
"altering",
"alternate",
"alternating",
"alters",
"unalterable",
"unaltered",
"alternative",
"alternatively",
"alternatives",
"ambiguous",
"ambiguities",
"ambiguity",
"unambiguous",
"unambiguously",
"amend",
"amended",
"amending",
"amendment",
"amendments",
"amends",
"analogy",
"analogies",
"analogous",
"analyse",
"analysed",
"analyser",
"analysers",
"analyses",
"analysing",
"analysis",
"analyst",
"analysts",
"analytic",
"analytical",
"analytically",
"analyze",
"analyzed",
"analyzes",
"analyzing",
"annual",
"annually",
"anticipate",
"anticipated",
"anticipates",
"anticipating",
"anticipation",
"unanticipated",
"apparent",
"apparently",
"append",
"appendix",
"appended",
"appends",
"appending",
"appendices",
"appendixes",
"appreciate",
"appreciable",
"appreciably",
"appreciated",
"appreciates",
"appreciating",
"appreciation",
"unappreciated",
"approach",
"approachable",
"approached",
"approaches",
"approaching",
"unapproachable",
"appropriate",
"appropriately",
"appropriateness",
"inappropriate",
"inappropriately",
"approximate",
"approximated",
"approximately",
"approximates",
"approximating",
"approximation",
"approximations",
"arbitrary",
"arbitrariness",
"arbitrarily",
"area",
"areas",
"aspect",
"aspects",
"assemble",
"assembled",
"assembles",
"assemblies",
"assembling",
"assembly",
"assess",
"assessable",
"assessed",
"assesses",
"assessing",
"assessment",
"assessments",
"reassess",
"reassessed",
"reassessing",
"reassessment",
"assign",
"assigned",
"assigning",
"assignment",
"assignments",
"assigns",
"reassign",
"reassigned",
"reassigning",
"reassigns",
"unassigned",
"assist",
"assistance",
"assistant",
"assistants",
"assisted",
"assisting",
"assists",
"unassisted",
"assume",
"assumed",
"assumes",
"assuming",
"assumption",
"assumptions",
"assure",
"assurance",
"assurances",
"assured",
"assuredly",
"assures",
"assuring",
"attach",
"attached",
"attaches",
"attaching",
"attachment",
"attachments",
"unattached",
"attain",
"attainable",
"attained",
"attaining",
"attainment",
"attainments",
"attains",
"unattainable",
"attitude",
"attitudes",
"attribute",
"attributable",
"attributed",
"attributes",
"attributing",
"attribution",
"author",
"authored",
"authoring",
"authors",
"authorship",
"authority",
"authoritative",
"authorities",
"automate",
"automatic",
"automated",
"automates",
"automating",
"automatically",
"automation",
"available",
"availability",
"unavailable",
"aware",
"awareness",
"unaware",
"behalf",
"benefit",
"beneficial",
"beneficiary",
"beneficiaries",
"benefited",
"benefiting",
"benefits",
"bias",
"biased",
"biases",
"biasing",
"unbiased",
"bond",
"bonded",
"bonding",
"bonds",
"brief",
"brevity",
"briefed",
"briefing",
"briefly",
"briefs",
"bulk",
"bulky",
"capable",
"capabilities",
"capability",
"incapable",
"capacity",
"capacities",
"incapacitate",
"incapacitated",
"category",
"categories",
"categorisation",
"categorise",
"categorised",
"categorises",
"categorising",
"categorization",
"categorized",
"categorizes",
"categorizing",
"cease",
"ceased",
"ceaseless",
"ceases",
"ceasing",
"challenge",
"challenged",
"challenger",
"challengers",
"challenges",
"challenging",
"channel",
"channelled",
"channelling",
"channels",
"chapter",
"chapters",
"chart",
"charted",
"charting",
"charts",
"uncharted",
"chemical",
"chemically",
"chemicals",
"circumstance",
"circumstances",
"cite",
"citation",
"citations",
"cited",
"citing",
"cites",
"civil",
"clarify",
"clarification",
"clarified",
"clarifies",
"clarifying",
"clarity",
"classic",
"classical",
"classics",
"clause",
"clauses",
"code",
"coded",
"codes",
"coding",
"coherent",
"coherence",
"coherently",
"incoherent",
"incoherently",
"coincide",
"coincided",
"coincides",
"coinciding",
"coincidence",
"coincidences",
"coincident",
"coincidental",
"collapse",
"collapsed",
"collapses",
"collapsible",
"collapsing",
"colleague",
"colleagues",
"commence",
"commenced",
"commences",
"commencement",
"commencing",
"recommences",
"recommenced",
"recommencing",
"comment",
"commentaries",
"commentary",
"commentator",
"commentators",
"commented",
"commenting",
"comments",
"commission",
"commissioned",
"commissioner",
"commissioners",
"commissioning",
"commissions",
"commit",
"commitment",
"commitments",
"commits",
"committed",
"committing",
"commodity",
"commodities",
"communicate",
"communicable",
"communicated",
"communicates",
"communicating",
"communication",
"communications",
"communicative",
"uncommunicative",
"community",
"communities",
"compatible",
"compatibility",
"incompatibility",
"incompatible",
"compensate",
"compensated",
"compensates",
"compensating",
"compensation",
"compensations",
"compensatory",
"compile",
"compilation",
"compilations",
"compiled",
"compiles",
"compiling",
"complement",
"complementary",
"complemented",
"complementing",
"complements",
"complex",
"complexities",
"complexity",
"component",
"components",
"compound",
"compounded",
"compounding",
"compounds",
"comprehensive",
"comprehensively",
"comprise",
"comprised",
"comprises",
"comprising",
"compute",
"computation",
"computational",
"computations",
"computable",
"computer",
"computed",
"computerised",
"computers",
"computing",
"conceive",
"conceivable",
"conceivably",
"conceived",
"conceives",
"conceiving",
"inconceivable",
"inconceivably",
"concentrate",
"concentrated",
"concentrates",
"concentrating",
"concentration",
"concept",
"conception",
"concepts",
"conceptual",
"conceptualisation",
"conceptualise",
"conceptualised",
"conceptualises",
"conceptualising",
"conceptually",
"conclude",
"concluded",
"concludes",
"concluding",
"conclusion",
"conclusions",
"conclusive",
"conclusively",
"inconclusive",
"inconclusively",
"concurrent",
"concurrently",
"conduct",
"conducted",
"conducting",
"conducts",
"confer",
"conference",
"conferences",
"conferred",
"conferring",
"confers",
"confine",
"confined",
"confines",
"confining",
"unconfined",
"confirm",
"confirmation",
"confirmed",
"confirming",
"confirms",
"conflict",
"conflicted",
"conflicting",
"conflicts",
"conform",
"conformable",
"conformance",
"conformation",
"conformed",
"conforming",
"conformist",
"conformists",
"conformity",
"conforms",
"nonconformist",
"nonconformists",
"nonconformity",
"non-conformist",
"non-conformists",
"non-conformity",
"consent",
"consensus",
"consented",
"consenting",
"consents",
"consequent",
"consequence",
"consequences",
"consequently",
"considerable",
"considerably",
"consist",
"consisted",
"consistency",
"consistent",
"consistently",
"consisting",
"consists",
"inconsistencies",
"inconsistency",
"inconsistent",
"constant",
"constancy",
"constantly",
"constants",
"inconstancy",
"inconstantly",
"constitute",
"constituencies",
"constituency",
"constituent",
"constituents",
"constituted",
"constitutes",
"constituting",
"constitution",
"constitutions",
"constitutional",
"constitutionally",
"constitutive",
"unconstitutional",
"constrain",
"constrained",
"constraining",
"constrains",
"constraint",
"constraints",
"unconstrained",
"construct",
"constructed",
"constructing",
"construction",
"constructions",
"constructive",
"constructs",
"reconstruct",
"reconstructed",
"reconstructing",
"reconstruction",
"reconstructs",
"consult",
"consultancy",
"consultant",
"consultants",
"consultation",
"consultations",
"consultative",
"consulted",
"consults",
"consulting",
"consume",
"consumed",
"consumer",
"consumers",
"consumes",
"consuming",
"consumption",
"contact",
"contactable",
"contacted",
"contacting",
"contacts",
"contemporary",
"contemporaries",
"context",
"contexts",
"contextual",
"contextualise",
"contextualised",
"contextualising",
"contextualize",
"contextualized",
"contextualizing",
"contract",
"contracted",
"contracting",
"contractor",
"contractors",
"contracts",
"contradict",
"contradicted",
"contradicting",
"contradiction",
"contradictions",
"contradictory",
"contradicts",
"contrary",
"contrarily",
"contrast",
"contrasted",
"contrasting",
"contrastive",
"contrasts",
"contribute",
"contributed",
"contributes",
"contributing",
"contribution",
"contributions",
"contributor",
"contributors",
"controversy",
"controversies",
"controversial",
"controversially",
"uncontroversial",
"convene",
"convention",
"convenes",
"convened",
"convening",
"conventional",
"conventionally",
"conventions",
"unconventional",
"converse",
"conversely",
"convert",
"conversion",
"conversions",
"converted",
"convertible",
"converting",
"converts",
"convince",
"convinced",
"convinces",
"convincing",
"convincingly",
"unconvinced",
"cooperate",
"cooperated",
"cooperates",
"cooperating",
"cooperation",
"cooperative",
"cooperatively",
"co-operate",
"co-operated",
"co-operates",
"co-operation",
"co-operative",
"co-operatively",
"coordinate",
"coordinated",
"coordinates",
"coordinating",
"coordination",
"coordinator",
"coordinators",
"co-ordinate",
"co-ordinated",
"co-ordinates",
"co-ordinating",
"co-ordination",
"co-ordinator",
"co-ordinators",
"core",
"cores",
"coring",
"cored",
"corporate",
"corporates",
"corporation",
"corporations",
"correspond",
"corresponded",
"correspondence",
"corresponding",
"correspondingly",
"corresponds",
"couple",
"coupled",
"coupling",
"couples",
"create",
"created",
"creates",
"creating",
"creation",
"creations",
"creative",
"creatively",
"creativity",
"creator",
"creators",
"recreate",
"recreated",
"recreates",
"recreating",
"credit",
"credited",
"crediting",
"creditor",
"creditors",
"credits",
"criteria",
"criterion",
"crucial",
"crucially",
"culture",
"cultural",
"culturally",
"cultured",
"cultures",
"uncultured",
"currency",
"currencies",
"cycle",
"cycled",
"cycles",
"cyclic",
"cyclical",
"cycling",
"data",
"debate",
"debatable",
"debated",
"debates",
"debating",
"decade",
"decades",
"decline",
"declined",
"declines",
"declining",
"deduce",
"deduced",
"deduces",
"deducing",
"deduction",
"deductions",
"define",
"definable",
"defined",
"defines",
"defining",
"definition",
"definitions",
"redefine",
"redefined",
"redefines",
"redefining",
"undefined",
"definite",
"definitely",
"definitive",
"indefinite",
"indefinitely",
"demonstrate",
"demonstrable",
"demonstrably",
"demonstrated",
"demonstrates",
"demonstrating",
"demonstration",
"demonstrations",
"demonstrative",
"demonstratively",
"demonstrator",
"demonstrators",
"denote",
"denotation",
"denotations",
"denoted",
"denotes",
"denoting",
"deny",
"deniable",
"denial",
"denials",
"denied",
"denies",
"denying",
"undeniable",
"depress",
"depressed",
"depresses",
"depressing",
"depression",
"derive",
"derivation",
"derivations",
"derivative",
"derivatives",
"derived",
"derives",
"deriving",
"design",
"designed",
"designer",
"designers",
"designing",
"designs",
"despite",
"detect",
"detectable",
"detected",
"detecting",
"detection",
"detective",
"detectives",
"detector",
"detectors",
"detects",
"deviate",
"deviated",
"deviates",
"deviating",
"deviation",
"deviations",
"device",
"devices",
"devote",
"devoted",
"devotedly",
"devotes",
"devoting",
"devotion",
"devotions",
"differentiate",
"differentiated",
"differentiates",
"differentiating",
"differentiation",
"dimension",
"dimensional",
"dimensions",
"multidimensional",
"diminish",
"diminished",
"diminishes",
"diminishing",
"diminution",
"undiminished",
"discrete",
"discretely",
"discretion",
"discretionary",
"indiscretion",
"discriminate",
"discriminated",
"discriminates",
"discriminating",
"discrimination",
"displace",
"displaced",
"displacement",
"displaces",
"displacing",
"display",
"displayed",
"displaying",
"displays",
"dispose",
"disposable",
"disposal",
"disposed",
"disposes",
"disposing",
"distinct",
"distinction",
"distinctions",
"distinctive",
"distinctively",
"distinctly",
"indistinct",
"indistinctly",
"distort",
"distorted",
"distorting",
"distortion",
"distortions",
"distorts",
"distribute",
"distributed",
"distributing",
"distribution",
"distributional",
"distributions",
"distributive",
"distributor",
"distributors",
"redistribute",
"redistributed",
"redistributes",
"redistributing",
"redistribution",
"diverse",
"diversely",
"diversification",
"diversified",
"diversifies",
"diversify",
"diversifying",
"diversity",
"document",
"documentation",
"documented",
"documenting",
"documents",
"domain",
"domains",
"domestic",
"domestically",
"domesticate",
"domesticated",
"domesticating",
"domestics",
"dominate",
"dominance",
"dominant",
"dominated",
"dominates",
"dominating",
"domination",
"draft",
"drafted",
"drafting",
"drafts",
"redraft",
"redrafted",
"redrafting",
"redrafts",
"drama",
"dramas",
"dramatic",
"dramatically",
"dramatise",
"dramatised",
"dramatising",
"dramatises",
"dramatisation",
"dramatisations",
"dramatist",
"dramatists",
"dramatization",
"dramatizations",
"dramatize",
"dramatized",
"dramatizes",
"dramatizing",
"duration",
"dynamic",
"dynamically",
"dynamics",
"economy",
"economic",
"economical",
"economically",
"economics",
"economies",
"economist",
"economists",
"uneconomical",
"edit",
"edited",
"editing",
"edition",
"editions",
"editor",
"editorial",
"editorials",
"editors",
"edits",
"element",
"elements",
"eliminate",
"eliminated",
"eliminates",
"eliminating",
"elimination",
"emerge",
"emerged",
"emergence",
"emergent",
"emerges",
"emerging",
"emphasis",
"emphasise",
"emphasised",
"emphasising",
"emphasize",
"emphasized",
"emphasizes",
"emphasizing",
"emphatic",
"emphatically",
"empirical",
"empirically",
"empiricism",
"enable",
"enabled",
"enables",
"enabling",
"encounter",
"encountered",
"encountering",
"encounters",
"energy",
"energetic",
"energetically",
"energies",
"enforce",
"enforced",
"enforcement",
"enforces",
"enforcing",
"enhance",
"enhanced",
"enhancement",
"enhances",
"enhancing",
"enormous",
"enormity",
"enormously",
"ensure",
"ensured",
"ensures",
"ensuring",
"entity",
"entities",
"environment",
"environmental",
"environmentalist",
"environmentalists",
"environmentally",
"environments",
"equate",
"equated",
"equates",
"equating",
"equation",
"equations",
"equip",
"equipment",
"equipped",
"equipping",
"equips",
"equivalent",
"equivalence",
"erode",
"eroded",
"erodes",
"eroding",
"erosion",
"error",
"erroneous",
"erroneously",
"errors",
"establish",
"disestablish",
"disestablished",
"disestablishes",
"disestablishing",
"disestablishment",
"established",
"establishes",
"establishing",
"establishment",
"establishments",
"estate",
"estates",
"estimate",
"estimated",
"estimates",
"estimating",
"estimation",
"estimations",
"over-estimate",
"overestimate",
"overestimated",
"overestimates",
"overestimating",
"underestimate",
"underestimated",
"underestimates",
"underestimating",
"ethic",
"ethical",
"ethically",
"ethics",
"unethical",
"ethnic",
"ethnicity",
"evaluate",
"evaluated",
"evaluates",
"evaluating",
"evaluation",
"evaluations",
"evaluative",
"re-evaluate",
"re-evaluated",
"re-evaluates",
"re-evaluating",
"re-evaluation",
"eventual",
"eventuality",
"eventually",
"evident",
"evidenced",
"evidence",
"evidential",
"evidently",
"evolve",
"evolution",
"evolved",
"evolving",
"evolves",
"evolutionary",
"evolutionist",
"evolutionists",
"exceed",
"exceeded",
"exceeding",
"exceeds",
"exclude",
"excluded",
"excludes",
"excluding",
"exclusion",
"exclusionary",
"exclusions",
"exclusive",
"exclusively",
"exhibit",
"exhibited",
"exhibiting",
"exhibition",
"exhibitions",
"exhibits",
"expand",
"expanded",
"expanding",
"expands",
"expansion",
"expansionism",
"expansive",
"expert",
"expertise",
"expertly",
"experts",
"explicit",
"explicitly",
"exploit",
"exploitation",
"exploited",
"exploiting",
"exploits",
"export",
"exported",
"exporter",
"exporters",
"exporting",
"exports",
"expose",
"exposed",
"exposes",
"exposing",
"exposure",
"exposures",
"external",
"externalisation",
"externalise",
"externalised",
"externalises",
"externalising",
"externalization",
"externalize",
"externalized",
"externalizes",
"externalizing",
"externally",
"extract",
"extracted",
"extracting",
"extraction",
"extracts",
"facilitate",
"facilitated",
"facilitates",
"facilities",
"facilitating",
"facilitation",
"facilitator",
"facilitators",
"facility",
"factor",
"factored",
"factoring",
"factors",
"feature",
"featured",
"features",
"featuring",
"federal",
"federation",
"federations",
"fee",
"fees",
"file",
"filed",
"files",
"filing",
"final",
"finalise",
"finalised",
"finalises",
"finalising",
"finalize",
"finalized",
"finalizes",
"finalizing",
"finality",
"finally",
"finals",
"finance",
"financed",
"finances",
"financial",
"financially",
"financier",
"financiers",
"financing",
"finite",
"infinite",
"infinitely",
"flexible",
"flexibility",
"inflexible",
"inflexibility",
"fluctuate",
"fluctuated",
"fluctuates",
"fluctuating",
"fluctuation",
"fluctuations",
"focus",
"focused",
"focuses",
"focusing",
"refocus",
"refocused",
"refocuses",
"refocusing",
"format",
"formatted",
"formatting",
"formats",
"formula",
"formulae",
"formulas",
"formulate",
"formulated",
"formulating",
"formulation",
"formulations",
"reformulate",
"reformulated",
"reformulating",
"reformulation",
"reformulations",
"forthcoming",
"foundation",
"foundations",
"founded",
"founder",
"founders",
"founding",
"unfounded",
"framework",
"frameworks",
"function",
"functional",
"functionally",
"functioned",
"functioning",
"functions",
"fund",
"funded",
"funding",
"funds",
"fundamental",
"fundamentally",
"furthermore",
"gender",
"genders",
"generate",
"generated",
"generates",
"generating",
"generation",
"generations",
"globe",
"global",
"globally",
"globalisation",
"globalization",
"goal",
"goals",
"grade",
"graded",
"grades",
"grading",
"grant",
"granted",
"granting",
"grants",
"guarantee",
"guaranteed",
"guaranteeing",
"guarantees",
"guideline",
"guidelines",
"hence",
"hierarchy",
"hierarchical",
"hierarchies",
"highlight",
"highlighted",
"highlighting",
"highlights",
"hypothesis",
"hypotheses",
"hypothesise",
"hypothesised",
"hypothesises",
"hypothesising",
"hypothesize",
"hypothesized",
"hypothesizes",
"hypothesizing",
"hypothetical",
"hypothetically",
"identical",
"identically",
"identify",
"identifiable",
"identification",
"identified",
"identifies",
"identifying",
"identities",
"identity",
"unidentifiable",
"ideology",
"ideological",
"ideologically",
"ideologies",
"ignorant",
"ignorance",
"ignore",
"ignored",
"ignores",
"ignoring",
"illustrate",
"illustrated",
"illustrates",
"illustrating",
"illustration",
"illustrations",
"illustrative",
"image",
"imagery",
"images",
"immigrate",
"immigrant",
"immigrants",
"immigrated",
"immigrates",
"immigrating",
"immigration",
"impact",
"impacted",
"impacting",
"impacts",
"implement",
"implementation",
"implemented",
"implementing",
"implements",
"implicate",
"implicated",
"implicates",
"implicating",
"implication",
"implications",
"implicit",
"implicitly",
"imply",
"implied",
"implies",
"implying",
"impose",
"imposed",
"imposes",
"imposing",
"imposition",
"incentive",
"incentives",
"incidence",
"incident",
"incidentally",
"incidents",
"incline",
"inclination",
"inclinations",
"inclined",
"inclines",
"inclining",
"income",
"incomes",
"incorporate",
"incorporated",
"incorporates",
"incorporating",
"incorporation",
"index",
"indexed",
"indexes",
"indexing",
"indicate",
"indicated",
"indicates",
"indicating",
"indication",
"indications",
"indicative",
"indicator",
"indicators",
"individual",
"individualised",
"individuality",
"individualism",
"individualist",
"individualists",
"individualistic",
"individually",
"individuals",
"induce",
"induced",
"induces",
"inducing",
"induction",
"inevitable",
"inevitability",
"inevitably",
"infer",
"inference",
"inferences",
"inferred",
"inferring",
"infers",
"infrastructure",
"infrastructures",
"inherent",
"inherently",
"inhibit",
"inhibited",
"inhibiting",
"inhibition",
"inhibitions",
"inhibits",
"initial",
"initially",
"initiate",
"initiated",
"initiates",
"initiating",
"initiation",
"initiations",
"initiative",
"initiatives",
"initiator",
"initiators",
"injure",
"injured",
"injures",
"injuries",
"injuring",
"injury",
"uninjured",
"innovate",
"innovation",
"innovated",
"innovates",
"innovating",
"innovations",
"innovative",
"innovator",
"innovators",
"input",
"inputs",
"insert",
"inserted",
"inserting",
"insertion",
"inserts",
"insight",
"insightful",
"insights",
"inspect",
"inspected",
"inspecting",
"inspection",
"inspections",
"inspector",
"inspectors",
"inspects",
"instance",
"instances",
"institute",
"instituted",
"institutes",
"instituting",
"institution",
"institutional",
"institutionalise",
"institutionalised",
"institutionalises",
"institutionalising",
"institutionalized",
"institutionalizes",
"institutionalizing",
"institutionally",
"institutions",
"instruct",
"instruction",
"instructed",
"instructing",
"instructions",
"instructive",
"instructor",
"instructors",
"instructs",
"integral",
"integrate",
"integrated",
"integrates",
"integrating",
"integration",
"integrity",
"intelligence",
"intelligent",
"intelligently",
"unintelligent",
"intense",
"intensely",
"intensification",
"intensified",
"intensifies",
"intensify",
"intensifying",
"intensity",
"intensive",
"intensively",
"interact",
"interacted",
"interacting",
"interaction",
"interactions",
"interactive",
"interactively",
"interacts",
"intermediate",
"internal",
"internalise",
"internalised",
"internalises",
"internalising",
"internalize",
"internalized",
"internalizes",
"internalizing",
"internally",
"interpret",
"interpretation",
"interpretations",
"interpretative",
"interpreted",
"interpreting",
"interpretive",
"interprets",
"misinterpret",
"misinterpretation",
"misinterpretations",
"misinterpreted",
"misinterpreting",
"misinterprets",
"reinterpret",
"reinterpreted",
"reinterprets",
"reinterpreting",
"reinterpretation",
"reinterpretations",
"interval",
"intervals",
"intervene",
"intervened",
"intervenes",
"intervening",
"intervention",
"interventions",
"intrinsic",
"intrinsically",
"invest",
"invested",
"investing",
"investment",
"investments",
"investor",
"investors",
"invests",
"reinvest",
"reinvested",
"reinvesting",
"reinvestment",
"reinvests",
"investigate",
"investigated",
"investigates",
"investigating",
"investigation",
"investigations",
"investigative",
"investigator",
"investigators",
"invoke",
"invoked",
"invokes",
"invoking",
"involve",
"involved",
"involvement",
"involves",
"involving",
"uninvolved",
"isolate",
"isolated",
"isolates",
"isolating",
"isolation",
"isolationism",
"issue",
"issued",
"issues",
"issuing",
"item",
"itemisation",
"itemise",
"itemised",
"itemises",
"itemising",
"items",
"job",
"jobs",
"journal",
"journals",
"justify",
"justifiable",
"justifiably",
"justification",
"justifications",
"justified",
"justifies",
"justifying",
"unjustified",
"label",
"labeled",
"labeling",
"labelled",
"labelling",
"labels",
"labour",
"labor",
"labored",
"labors",
"laboured",
"labouring",
"labours",
"layer",
"layered",
"layering",
"layers",
"lecture",
"lectured",
"lecturer",
"lecturers",
"lectures",
"lecturing",
"legal",
"illegal",
"illegality",
"illegally",
"legality",
"legally",
"legislate",
"legislated",
"legislates",
"legislating",
"legislation",
"legislative",
"legislator",
"legislators",
"legislature",
"levy",
"levies",
"liberal",
"liberalise",
"liberalism",
"liberalisation",
"liberalised",
"liberalises",
"liberalising",
"liberalization",
"liberalize",
"liberalized",
"liberalizes",
"liberalizing",
"liberate",
"liberated",
"liberates",
"liberation",
"liberating",
"liberator",
"liberators",
"liberally",
"liberals",
"licence",
"licences",
"license",
"licensed",
"licensing",
"licenses",
"unlicensed",
"likewise",
"link",
"linkage",
"linkages",
"linked",
"linking",
"links",
"locate",
"located",
"locating",
"location",
"locations",
"relocate",
"relocated",
"relocates",
"relocating",
"relocation",
"logic",
"illogical",
"illogically",
"logical",
"logically",
"logician",
"logicians",
"maintain",
"maintained",
"maintaining",
"maintains",
"maintenance",
"major",
"majorities",
"majority",
"manipulate",
"manipulated",
"manipulates",
"manipulating",
"manipulation",
"manipulations",
"manipulative",
"manual",
"manually",
"manuals",
"margin",
"marginal",
"marginally",
"margins",
"mature",
"immature",
"immaturity",
"maturation",
"matured",
"matures",
"maturing",
"maturity",
"maximise",
"max",
"maximised",
"maximises",
"maximising",
"maximisation",
"maximize",
"maximized",
"maximizes",
"maximizing",
"maximization",
"maximum",
"mechanism",
"mechanisms",
"media",
"mediate",
"mediated",
"mediates",
"mediating",
"mediation",
"medical",
"medically",
"medium",
"mental",
"mentality",
"mentally",
"method",
"methodical",
"methodological",
"methodologies",
"methodology",
"methods",
"migrate",
"migrant",
"migrants",
"migrated",
"migrates",
"migrating",
"migration",
"migrations",
"migratory",
"military",
"minimal",
"minimalises",
"minimalist",
"minimalists",
"minimalistic",
"minimally",
"minimise",
"minimised",
"minimises",
"minimising",
"minimize",
"minimized",
"minimizes",
"minimizing",
"minimum",
"ministry",
"ministerial",
"ministries",
"minor",
"minorities",
"minority",
"minors",
"mode",
"modes",
"modify",
"modification",
"modifications",
"modified",
"modifies",
"modifying",
"unmodified",
"monitor",
"monitored",
"monitoring",
"monitors",
"unmonitored",
"motive",
"motivate",
"motivated",
"motivates",
"motivating",
"motivation",
"motivations",
"motives",
"unmotivated",
"mutual",
"mutually",
"negate",
"negative",
"negated",
"negates",
"negating",
"negatively",
"negatives",
"network",
"networked",
"networking",
"networks",
"neutral",
"neutralisation",
"neutralise",
"neutralised",
"neutralises",
"neutralising",
"neutrality",
"neutralization",
"neutralize",
"neutralized",
"neutralizes",
"neutralizing",
"nevertheless",
"nonetheless",
"norm",
"norms",
"normal",
"abnormal",
"abnormally",
"normalisation",
"normalise",
"normalised",
"normalises",
"normalising",
"normalization",
"normalize",
"normalized",
"normalizes",
"normalizing",
"normality",
"normally",
"notion",
"notions",
"notwithstanding",
"nuclear",
"objective",
"objectively",
"objectivity",
"obtain",
"obtainable",
"obtained",
"obtaining",
"obtains",
"unobtainable",
"obvious",
"obviously",
"occupy",
"occupancy",
"occupant",
"occupants",
"occupation",
"occupational",
"occupations",
"occupied",
"occupier",
"occupiers",
"occupies",
"occupying",
"occur",
"occurred",
"occurrence",
"occurrences",
"occurring",
"occurs",
"reoccur",
"reoccurred",
"reoccurring",
"reoccurs",
"odd",
"odds",
"offset",
"offsets",
"offsetting",
"ongoing",
"option",
"optional",
"options",
"orient",
"orientate",
"orientated",
"orientates",
"orientation",
"orientating",
"oriented",
"orienting",
"orients",
"reorient",
"reorientation",
"outcome",
"outcomes",
"output",
"outputs",
"overall",
"overlap",
"overlapped",
"overlapping",
"overlaps",
"overseas",
"panel",
"panelled",
"panelling",
"panels",
"paradigm",
"paradigms",
"paragraph",
"paragraphing",
"paragraphs",
"parallel",
"paralleled",
"parallelled",
"parallelling",
"parallels",
"unparalleled",
"parameter",
"parameters",
"participate",
"participant",
"participants",
"participated",
"participates",
"participating",
"participation",
"participatory",
"partner",
"partners",
"partnership",
"partnerships",
"passive",
"passively",
"passivity",
"perceive",
"perceived",
"perceives",
"perceiving",
"perception",
"perceptions",
"percent",
"percentage",
"percentages",
"period",
"periodic",
"periodical",
"periodically",
"periodicals",
"periods",
"persist",
"persisted",
"persistence",
"persistent",
"persistently",
"persisting",
"persists",
"perspective",
"perspectives",
"phase",
"phased",
"phases",
"phasing",
"phenomenon",
"phenomena",
"phenomenal",
"philosophy",
"philosopher",
"philosophers",
"philosophical",
"philosophically",
"philosophies",
"philosophise",
"philosophised",
"philosophises",
"philosophising",
"philosophize",
"philosophized",
"philosophizes",
"philosophizing",
"physical",
"physically",
"plus",
"pluses",
"policy",
"policies",
"portion",
"portions",
"pose",
"posed",
"poses",
"posing",
"positive",
"positively",
"potential",
"potentially",
"practitioner",
"practitioners",
"precede",
"preceded",
"precedence",
"precedent",
"precedes",
"preceding",
"unprecedented",
"precise",
"imprecise",
"precisely",
"precision",
"predict",
"predictability",
"predictable",
"predictably",
"predicted",
"predicting",
"prediction",
"predictions",
"predicts",
"unpredictability",
"unpredictable",
"predominant",
"predominance",
"predominantly",
"predominate",
"predominated",
"predominates",
"predominating",
"preliminary",
"preliminaries",
"presume",
"presumably",
"presumed",
"presumes",
"presuming",
"presumption",
"presumptions",
"previous",
"previously",
"primary",
"primarily",
"prime",
"primacy",
"principal",
"principally",
"principle",
"principled",
"principles",
"unprincipled",
"prior",
"priority",
"priorities",
"prioritisation",
"prioritise",
"prioritised",
"prioritises",
"prioritising",
"prioritization",
"prioritize",
"prioritized",
"prioritizes",
"prioritizing",
"proceed",
"procedural",
"procedure",
"procedures",
"proceeded",
"proceeding",
"proceedings",
"proceeds",
"process",
"processed",
"processes",
"processing",
"professional",
"professionally",
"professionals",
"professionalism",
"prohibit",
"prohibited",
"prohibiting",
"prohibition",
"prohibitions",
"prohibitive",
"prohibits",
"project",
"projected",
"projecting",
"projection",
"projections",
"projects",
"promote",
"promoted",
"promoter",
"promoters",
"promotes",
"promoting",
"promotion",
"promotions",
"proportion",
"disproportion",
"disproportionate",
"disproportionately",
"proportional",
"proportionally",
"proportionate",
"proportionately",
"proportions",
"prospect",
"prospective",
"prospects",
"protocol",
"protocols",
"psychology",
"psychological",
"psychologically",
"psychologist",
"psychologists",
"publication",
"publications",
"publish",
"published",
"publisher",
"publishers",
"publishes",
"publishing",
"unpublished",
"purchase",
"purchased",
"purchaser",
"purchasers",
"purchases",
"purchasing",
"pursue",
"pursued",
"pursues",
"pursuing",
"pursuit",
"pursuits",
"qualitative",
"qualitatively",
"quote",
"quotation",
"quotations",
"quoted",
"quotes",
"quoting",
"radical",
"radically",
"radicals",
"random",
"randomly",
"randomness",
"range",
"ranged",
"ranges",
"ranging",
"ratio",
"ratios",
"rational",
"irrational",
"rationalisation",
"rationalisations",
"rationalise",
"rationalised",
"rationalises",
"rationalising",
"rationalism",
"rationality",
"rationalization",
"rationalizations",
"rationalize",
"rationalized",
"rationalizes",
"rationally",
"react",
"reacted",
"reacts",
"reacting",
"reaction",
"reactionaries",
"reactionary",
"reactions",
"reactive",
"reactivate",
"reactivation",
"reactor",
"reactors",
"recover",
"recoverable",
"recovered",
"recovering",
"recovers",
"recovery",
"refine",
"refined",
"refinement",
"refinements",
"refines",
"refining",
"regime",
"regimes",
"region",
"regional",
"regionally",
"regions",
"register",
"registered",
"registering",
"registers",
"registration",
"regulate",
"deregulated",
"deregulates",
"deregulating",
"deregulation",
"regulated",
"regulates",
"regulating",
"regulation",
"regulations",
"regulator",
"regulators",
"regulatory",
"unregulated",
"reinforce",
"reinforced",
"reinforcement",
"reinforcements",
"reinforces",
"reinforcing",
"reject",
"rejected",
"rejecting",
"rejection",
"rejects",
"rejections",
"relax",
"relaxation",
"relaxed",
"relaxes",
"relaxing",
"release",
"released",
"releases",
"releasing",
"relevant",
"irrelevance",
"irrelevant",
"relevance",
"reluctance",
"reluctant",
"reluctantly",
"rely",
"reliability",
"reliable",
"reliably",
"reliance",
"reliant",
"relied",
"relies",
"relying",
"unreliable",
"remove",
"removable",
"removal",
"removals",
"removed",
"removes",
"removing",
"require",
"required",
"requirement",
"requirements",
"requires",
"requiring",
"research",
"researched",
"researcher",
"researchers",
"researches",
"researching",
"reside",
"resided",
"residence",
"resident",
"residential",
"residents",
"resides",
"residing",
"resolve",
"resolution",
"resolved",
"resolves",
"resolving",
"unresolved",
"resource",
"resourced",
"resourceful",
"resources",
"resourcing",
"under-resourced",
"respond",
"responded",
"respondent",
"respondents",
"responding",
"responds",
"response",
"responses",
"responsive",
"responsiveness",
"unresponsive",
"restore",
"restoration",
"restored",
"restores",
"restoring",
"restrain",
"restrained",
"restraining",
"restrains",
"restraint",
"restraints",
"unrestrained",
"restrict",
"restricted",
"restricting",
"restriction",
"restrictions",
"restrictive",
"restrictively",
"restricts",
"unrestricted",
"retain",
"retained",
"retaining",
"retainer",
"retainers",
"retains",
"retention",
"retentive",
"reveal",
"revealed",
"revealing",
"reveals",
"revelation",
"revelations",
"revenue",
"revenues",
"reverse",
"reversal",
"reversed",
"reverses",
"reversible",
"reversing",
"reversals",
"irreversible",
"revise",
"revised",
"revises",
"revising",
"revision",
"revisions",
"revolution",
"revolutionary",
"revolutionaries",
"revolutionise",
"revolutionised",
"revolutionises",
"revolutionising",
"revolutionist",
"revolutionists",
"revolutionize",
"revolutionized",
"revolutionizes",
"revolutionizing",
"revolutions",
"rigid",
"rigidities",
"rigidity",
"rigidly",
"role",
"roles",
"route",
"routed",
"routes",
"routing",
"scenario",
"scenarios",
"schedule",
"reschedule",
"rescheduled",
"reschedules",
"rescheduling",
"scheduled",
"schedules",
"scheduling",
"unscheduled",
"scheme",
"schematic",
"schematically",
"schemed",
"schemes",
"scheming",
"scope",
"section",
"sectioned",
"sectioning",
"sections",
"sector",
"sectors",
"secure",
"insecure",
"insecurities",
"insecurity",
"secured",
"securely",
"secures",
"securing",
"securities",
"security",
"seek",
"seeking",
"seeks",
"sought",
"select",
"selected",
"selecting",
"selection",
"selections",
"selective",
"selectively",
"selector",
"selectors",
"selects",
"sequence",
"sequenced",
"sequences",
"sequencing",
"sequential",
"sequentially",
"series",
"sex",
"sexes",
"sexism",
"sexual",
"sexuality",
"sexually",
"shift",
"shifted",
"shifting",
"shifts",
"significant",
"insignificant",
"insignificantly",
"significance",
"significantly",
"signified",
"signifies",
"signify",
"signifying",
"similar",
"dissimilar",
"similarities",
"similarity",
"similarly",
"simulate",
"simulated",
"simulates",
"simulating",
"simulation",
"site",
"sites",
"so-called",
"sole",
"solely",
"somewhat",
"source",
"sourced",
"sources",
"sourcing",
"specific",
"specifically",
"specification",
"specifications",
"specificity",
"specifics",
"specify",
"specifiable",
"specified",
"specifies",
"specifying",
"unspecified",
"sphere",
"spheres",
"spherical",
"spherically",
"stable",
"instability",
"stabilisation",
"stabilise",
"stabilised",
"stabilises",
"stabilising",
"stabilization",
"stabilize",
"stabilized",
"stabilizes",
"stabilizing",
"stability",
"unstable",
"statistic",
"statistician",
"statisticians",
"statistical",
"statistically",
"statistics",
"status",
"straightforward",
"strategy",
"strategic",
"strategies",
"strategically",
"strategist",
"strategists",
"stress",
"stressed",
"stresses",
"stressful",
"stressing",
"unstressed",
"structure",
"restructure",
"restructured",
"restructures",
"restructuring",
"structural",
"structurally",
"structured",
"structures",
"structuring",
"unstructured",
"style",
"styled",
"styles",
"styling",
"stylish",
"stylise",
"stylised",
"stylises",
"stylising",
"stylize",
"stylized",
"stylizes",
"stylizing",
"submit",
"submission",
"submissions",
"submits",
"submitted",
"submitting",
"subordinate",
"subordinates",
"subordination",
"subsequent",
"subsequently",
"subsidy",
"subsidiary",
"subsidies",
"subsidise",
"subsidised",
"subsidises",
"subsidising",
"subsidize",
"subsidized",
"subsidizes",
"subsidizing",
"substitute",
"substituted",
"substitutes",
"substituting",
"substitution",
"successor",
"succession",
"successions",
"successive",
"successively",
"successors",
"sufficient",
"sufficiency",
"insufficient",
"insufficiently",
"sufficiently",
"sum",
"summation",
"summed",
"summing",
"sums",
"summary",
"summaries",
"summarise",
"summarised",
"summarises",
"summarising",
"summarize",
"summarized",
"summarizes",
"summarizing",
"supplement",
"supplementary",
"supplemented",
"supplementing",
"supplements",
"survey",
"surveyed",
"surveying",
"surveys",
"survive",
"survival",
"survived",
"survives",
"surviving",
"survivor",
"survivors",
"suspend",
"suspended",
"suspending",
"suspends",
"suspension",
"sustain",
"sustainable",
"sustainability",
"sustained",
"sustaining",
"sustains",
"sustenance",
"unsustainable",
"symbol",
"symbolic",
"symbolically",
"symbolise",
"symbolises",
"symbolised",
"symbolising",
"symbolism",
"symbolize",
"symbolized",
"symbolizes",
"symbolizing",
"symbols",
"tape",
"taped",
"tapes",
"taping",
"target",
"targeted",
"targeting",
"targets",
"task",
"tasks",
"team",
"teamed",
"teaming",
"teams",
"technical",
"technically",
"technique",
"techniques",
"technology",
"technological",
"technologically",
"temporary",
"temporarily",
"tense",
"tension",
"tensely",
"tenser",
"tensest",
"tensions",
"terminate",
"terminal",
"terminals",
"terminated",
"terminates",
"terminating",
"termination",
"terminations",
"text",
"texts",
"textual",
"theme",
"themes",
"thematic",
"thematically",
"theory",
"theoretical",
"theoretically",
"theories",
"theorist",
"theorists",
"thereby",
"thesis",
"theses",
"topic",
"topical",
"topics",
"trace",
"traceable",
"traced",
"traces",
"tracing",
"tradition",
"non-traditional",
"traditional",
"traditionalist",
"traditionally",
"traditions",
"transfer",
"transferable",
"transference",
"transferred",
"transferring",
"transfers",
"transform",
"transformation",
"transformations",
"transformed",
"transforming",
"transforms",
"transit",
"transited",
"transiting",
"transition",
"transitional",
"transitions",
"transitory",
"transits",
"transmit",
"transmission",
"transmissions",
"transmitted",
"transmitting",
"transmits",
"transport",
"transportation",
"transported",
"transporter",
"transporters",
"transporting",
"transports",
"trend",
"trends",
"trigger",
"triggered",
"triggering",
"triggers",
"ultimate",
"ultimately",
"undergo",
"undergoes",
"undergoing",
"undergone",
"underwent",
"underlie",
"underlay",
"underlies",
"underlying",
"undertake",
"undertaken",
"undertakes",
"undertaking",
"undertook",
"uniform",
"uniformity",
"uniformly",
"unify",
"unification",
"unified",
"unifies",
"unifying",
"unique",
"uniquely",
"uniqueness",
"utilise",
"utilisation",
"utilised",
"utilises",
"utilising",
"utility",
"utilities",
"utilization",
"utilize",
"utilized",
"utilizes",
"utilizing",
"valid",
"invalidate",
"invalidity",
"validate",
"validated",
"validating",
"validation",
"validity",
"validly",
"vary",
"invariable",
"invariably",
"variability",
"variable",
"variables",
"variably",
"variance",
"variant",
"variants",
"variation",
"variations",
"varied",
"varies",
"varying",
"vehicle",
"vehicles",
"version",
"versions",
"via",
"violate",
"violated",
"violates",
"violating",
"violation",
"violations",
"virtual",
"virtually",
"visible",
"visibility",
"visibly",
"invisible",
"invisibility",
"vision",
"visions",
"visual",
"visualise",
"visualised",
"visualising",
"visualisation",
"visualize",
"visualized",
"visualizing",
"visualization",
"visually",
"volume",
"volumes",
"vol",
"voluntary",
"voluntarily",
"volunteer",
"volunteering",
"volunteered",
"volunteers",
"welfare",
"whereas",
"whereby",
"widespread",
"affectively",
"appropriacy",
"inappropriacy",
"unassessed",
"communicatively",
"componentry",
"conformability",
"uncontextualised",
"uncontextualized",
"indiscrete",
"exclusionist",
"externality",
"focussed",
"focussing",
"refocussed",
"refocusses",
"refocussing",
"funder",
"funders",
"intenseness",
"intension",
"liberations",
"maturational",
"minimalisation",
"minimalise",
"minimalised",
"minimalising",
"minimalization",
"minimalize",
"minimalized",
"minimalizes",
"minimalizing",
"deregister",
"deregistered",
"deregistering",
"deregisters",
"deregistration",
"unresourceful",
"unrestrictive",
"summarisation",
"summarisations",
"summarization",
"summarizations",
"utiliser",
"utilisers"}

is_word_awl = lambda w : w in word_awl

def submit(port, host='127.0.0.1',  db=0):
	import redis
	r = redis.Redis(host=host, port=port, db=db)
	for w in word_awl: 
		r.sadd("dict:awl", w )
		r.hset('dict:word_level', w, 'awl')
	print(">> finished loading awl")

if __name__ == '__main__':
	submit(6311)
