mwe_pv = {
"a case of",
"a class of",
"a component of",
"a derivative of",
"a family of",
"a form of",
"a fragment of",
"a high percentage of",
"a kind of",
"a member of",
"a part of",
"a percentage of",
"a piece of",
"a portion of",
"a product of",
"a quantitative of",
"a section of",
"a segment of",
"a series of",
"a set of",
"a small percentage of",
"a sort of",
"a type of",
"a variant of",
"a variety of",
"absent from",
"acorn-shaped",
"adjacent to",
"akin to",
"almond-shaped",
"already",
"always",
"amount of",
"amounts of",
"an element of",
"an equivalent of",
"an example of",
"an ingredient of",
"analogous to",
"annual",
"annually",
"appear in",
"appeared in",
"appears in",
"apple-shaped",
"apple-sized",
"approach",
"approached",
"approaches",
"approaching",
"approximate",
"approximately",
"are",
"arise from",
"arise out of",
"arose from",
"arose out of",
"arranged",
"arrow-shaped",
"as illustrated by",
"as opposed to",
"at first",
"at last",
"at once",
"average",
"awl-shaped",
"bag-shaped",
"ball-shaped",
"bar-shaped",
"barrel-shaped",
"basket-shaped",
"be",
"bean-shaped",
"bear-sized",
"became",
"become",
"becomes",
"becoming",
"been",
"being",
"bell-shaped",
"belong to",
"belonging to",
"belongs to",
"belt-shaped",
"boat-shaped",
"boot-shaped",
"bottle-shaped",
"bowl-shaped",
"box-shaped",
"branch into",
"branched into",
"branches into",
"brick-shaped",
"brightly-colored",
"buff-colored",
"bulb-shaped",
"butterfly-shaped",
"button-shaped",
"came from",
"categories",
"categorized",
"categorizing",
"category",
"cause",
"caused",
"causes",
"change into",
"changed into",
"changes into",
"characteristic of",
"characteristics of",
"characterized by",
"cherry-sized",
"chestnut-colored",
"chocolate-colored",
"cigar-shaped",
"cinnamon-colored",
"classification",
"classifications",
"claw-shaped",
"club-shaped",
"coated with",
"come from",
"comes from",
"comparable to",
"component",
"components",
"composed of",
"comprise",
"comprised of",
"cone-shaped",
"conflict",
"conflicted",
"conflicting",
"conflicts",
"considered as",
"consist of",
"consistent of",
"consisting of",
"consists of",
"constancy",
"constant",
"constitute",
"constituted",
"constitutes",
"constituting",
"constitution",
"contain",
"contained",
"contained in",
"contained with",
"containing",
"contains",
"continual",
"continually",
"continuous",
"continuously",
"contradictory",
"converted to",
"cookie-sized",
"correspond to",
"corresponded to",
"corresponding to",
"corresponds to",
"counterpart of",
"cover",
"coverage",
"coverages",
"covered",
"covered with",
"covering",
"covers",
"cowl-shaped",
"cream-colored",
"creamy-colored",
"crescent-shaped",
"cross-shaped",
"crow-sized",
"cube-shaped",
"cucumber-shaped",
"current",
"daily",
"dark-colored",
"derive from",
"derived from",
"derives from",
"deriving from",
"develop",
"develop from",
"developed",
"developed from",
"developing",
"developing from",
"develops",
"deviod of",
"differ from",
"differed from",
"different from",
"differing from",
"differs from",
"dimension",
"disc-shaped",
"dish-shaped",
"disk-shaped",
"dissimilar",
"distinct from",
"distinguished from",
"distributed",
"divided into",
"dog-sized",
"dome-shaped",
"doughnut-shaped",
"drum-shaped",
"due to",
"dun-colored",
"duration",
"dusky-colored",
"ear-shaped",
"early",
"eel-shaped",
"egg-shaped",
"embedded in",
"embodied",
"embodies",
"embody",
"embodying",
"encompass",
"encompassed",
"encompasses",
"encompassing",
"equal to",
"equidistant",
"equipped with",
"equivalent to",
"eternal",
"ever",
"evolve into",
"evolved into",
"evolves into",
"excluded from",
"exemplified by",
"exist in",
"existed in",
"exists in",
"extend",
"extended",
"extending",
"extends",
"face",
"faced",
"faces",
"facing",
"fall into",
"falling into",
"family",
"fan-shaped",
"fawn-colored",
"feature of",
"features of",
"fell into",
"ferret-sized",
"fiddle-shaped",
"fifth",
"fig-shaped",
"filled with",
"final",
"finally",
"first class",
"first of all",
"flame-colored",
"flesh-colored",
"follow",
"followed",
"following",
"follows",
"foot-shaped",
"football-shaped",
"form",
"formation",
"formed",
"formed by",
"former",
"forms",
"found in",
"fourth",
"free of",
"frequency",
"frequent",
"funnel-shaped",
"future",
"garnet-colored",
"gave away to",
"gave rise to",
"give away to",
"give rise to",
"gives away to",
"gives rise to",
"goblet-shaped",
"gold-colored",
"gradual",
"gradually",
"grape-sized",
"grew",
"group",
"groups",
"grow",
"growing",
"grows",
"guitar-shaped",
"h-shaped",
"hammer-shaped",
"hardly",
"harp-shaped",
"heart-shaped",
"helmet-shaped",
"henceforth",
"henceforward",
"hitherto",
"honey-colored",
"hook-shaped",
"horn-shaped",
"hourglass-shaped",
"human-sized",
"identical",
"identical with",
"ill-formed",
"immediate",
"immediately",
"in shades of",
"in shape",
"in the end",
"in the form of",
"in the shape of",
"include",
"included",
"includes",
"including",
"indistinguishable from",
"inserted into",
"interpreted as",
"is",
"keel-shaped",
"kidney-shaped",
"king-sized",
"kiwi-sized",
"l-shaped",
"lack",
"lacks",
"lain",
"lance-shaped",
"lancet-shaped",
"last",
"lasted",
"lasting",
"lasts",
"late",
"later",
"lay",
"lead-colored",
"lie",
"life-sized",
"light-colored",
"like",
"lilac-colored",
"lip-shaped",
"liver-colored",
"located",
"look",
"look like",
"looked like",
"looks like",
"lying",
"lyre-shaped",
"made from",
"made up of",
"maintain",
"maintained",
"maintains",
"man-sized",
"match",
"matched",
"matches",
"matching",
"measure",
"measured",
"measures",
"measuring",
"medium-sized",
"member",
"members",
"membership",
"metal-colored",
"metallic-colored",
"moderate-sized",
"monthly",
"mouse-colored",
"mouse-sized",
"multi-colored",
"needle-shaped",
"neutral-colored",
"never",
"next",
"no longer",
"no more",
"not any longer",
"not any more",
"number of",
"numbers of",
"nutmeg-shaped",
"occur as",
"occurred as",
"occurring as",
"occurs as",
"often",
"olive-colored",
"olive-sized",
"once",
"opposite",
"orange-colored",
"orange-sized",
"originate from",
"originated from",
"originates from",
"originating from",
"oval-shaped",
"oven-shaped",
"paddle-shaped",
"pale-colored",
"palm-shaped",
"parallel to",
"parallel with",
"part of",
"partitioned into",
"parts of",
"past",
"pastel-colored",
"peach-colored",
"peachy-colored",
"pear-shaped",
"percent",
"permanent",
"pig-sized",
"pillar-shaped",
"pint-sized",
"pinwheel-shaped",
"pitcher-shaped",
"placed",
"pocket-sized",
"polar",
"portion",
"positioned at",
"possess",
"possessed",
"possesses",
"possession",
"post-communist",
"post-free",
"post-haste",
"post-hole_digger",
"post-horse",
"post-impressionist",
"post-it",
"post-maturity",
"post-menopause",
"post-mortem",
"post-mortem_examinatio",
"post-obit_bond",
"post-office_box",
"post-office_box_number",
"post-paid",
"post-rotational_nystag",
"postgraduate",
"postpone",
"postwar",
"pouch-shaped",
"pre-christian",
"pre-columbian",
"pre-eclampsia",
"pre-eminently",
"pre-empt",
"pre-emption",
"pre-emptive",
"pre-emptive_strike",
"pre-emptor",
"pre-existent",
"pre-existing",
"pre-jurassic",
"pre-raphaelite",
"pre-socratic",
"precede",
"preface",
"prerequisite",
"present",
"previous",
"process of",
"produce",
"produced",
"produced by",
"produced from",
"produces",
"proportion of",
"proportional to",
"prototype of",
"provided with",
"pumpkin-shaped",
"queen-sized",
"rabbit-sized",
"range from",
"ranged from",
"ranges from",
"ranging from",
"rate of",
"re-formed",
"regarded as",
"regular",
"regularity",
"regularly",
"render",
"rendered",
"rendering",
"renders",
"represent",
"representative",
"representative as",
"represented",
"represented by",
"representing",
"represents",
"resemblance",
"resemble",
"reside",
"resided",
"resides",
"result from",
"result in",
"resulted from",
"resulted in",
"results from",
"results in",
"ribbon-shaped",
"ring-shaped",
"rod-shaped",
"rose-colored",
"rosy-colored",
"rust-colored",
"s-shaped",
"saddle-shaped",
"sat",
"saucer-shaped",
"sausage-shaped",
"second rate",
"seldom",
"self-colored",
"separated",
"shape",
"share",
"shared",
"shares",
"sharing",
"shield-shaped",
"shift",
"shifts",
"shrew-sized",
"sickle-shaped",
"silver-colored",
"similar to",
"simultaneous",
"simultaneously",
"sit",
"sits",
"sitting",
"situate",
"situated",
"situates",
"situating",
"sixth",
"slipper-shaped",
"solid-colored",
"sometimes",
"soon",
"spade-shaped",
"sparrow-sized",
"spatula-shaped",
"spearhead-shaped",
"spider-shaped",
"spindle-shaped",
"spoon-shaped",
"square-shaped",
"squirrel-sized",
"stand",
"standing",
"stands",
"star-shaped",
"stirrup-shaped",
"stood",
"straw-colored",
"subdivided into",
"subunit",
"sudden",
"suddenly",
"surround",
"surrounded by",
"switch",
"switched",
"switches",
"sword-shaped",
"synonymous with",
"system",
"systematic",
"t-shaped",
"tadpole-shaped",
"tail-shaped",
"tassel-shaped",
"tawny-colored",
"temporal",
"the feature of",
"the features of",
"the finding of",
"the reason why",
"the remaining",
"the result of",
"the same as",
"there",
"therefore",
"thereupon",
"thimble-shaped",
"third",
"thought of as",
"timely",
"to the exclusion of",
"tongue-shaped",
"trait of",
"traits of",
"transform into",
"transformed into",
"transforming into",
"transforms into",
"tree-shaped",
"trumpet-shaped",
"tube-shaped",
"turkey-sized",
"turn into",
"turned into",
"turnip-shaped",
"turns into",
"twice",
"two-part",
"u-shaped",
"umbrella-shaped",
"unit",
"united",
"units",
"unlike",
"urgency",
"urgent",
"urn-shaped",
"v-shaped",
"varied from",
"varies from",
"varieties",
"variety",
"vary from",
"varying from",
"vase-shaped",
"violet-colored",
"volume of",
"volumes of",
"w-shaped",
"was",
"watermelon-shaped",
"wedge-shaped",
"weekly",
"weigh",
"weighed",
"weighs",
"well-formed",
"were",
"wine-colored",
"wing-shaped",
"with frequency",
"wolf-sized",
"worm-shaped",
"y-shaped",
"yearly",
"yet",
"yield",
"yielded",
"yields",
}

if __name__ == '__main__':
	import redis
	r = redis.Redis(host='dev.werror.com', port=4328)
	for w in mwe_pv: 
		r.sadd("__dic:mwe_pv", w )
	print(">> finished loading mwe_pv")