word_gsl2 = {
"abroad",
"absence",
"absences",
"absent",
"absolute",
"absolutely",
"accident",
"accidents",
"accidental",
"accidentally",
"accuse",
"accusing",
"accuses",
"accused",
"accustom",
"accustoms",
"accustoming",
"accustomed",
"ache",
"aching",
"aches",
"ached",
"admire",
"admiring",
"admires",
"admired",
"admirable",
"admiration",
"advertise",
"advertising",
"advertises",
"advertiser",
"advertised",
"advertisement",
"advertisements",
"advice",
"advising",
"advises",
"advisers",
"adviser",
"advised",
"advise",
"advisory",
"aeroplane",
"aeroplanes",
"afford",
"afforded",
"affording",
"affords",
"affordable",
"afraid",
"afternoon",
"afternoons",
"agriculture",
"agricultural",
"ahead",
"aim",
"aims",
"aiming",
"aimed",
"aimless",
"aimlessness",
"airplane",
"airplanes",
"alike",
"alive",
"aloud",
"altogether",
"ambition",
"ambitions",
"ambitious",
"ambitiously",
"amuse",
"amusing",
"amuses",
"amused",
"amusement",
"amusements",
"anger",
"angers",
"angering",
"angered",
"angry",
"angrily",
"angrier",
"angriest",
"angle",
"angles",
"angling",
"angled",
"annoy",
"annoys",
"annoying",
"annoyed",
"annoyance",
"anxiety",
"anxieties",
"anxious",
"anxiously",
"apart",
"apologize",
"apologizes",
"apologized",
"apologise",
"apologising",
"apologises",
"apologised",
"apology",
"apologies",
"apologetic",
"applaud",
"applauds",
"applauding",
"applauded",
"applause",
"apple",
"apples",
"approve",
"approving",
"approves",
"approved",
"approval",
"disapprove",
"disapproving",
"disapproves",
"disapproved",
"disapproval",
"arch",
"arching",
"arches",
"arched",
"argue",
"arguing",
"argues",
"argued",
"arguable",
"argument",
"arguments",
"arrange",
"arranged",
"arranging",
"arranges",
"arrangement",
"arrangements",
"arrest",
"arrests",
"arresting",
"arrested",
"arrow",
"arrows",
"artificial",
"artificially",
"ash",
"ashes",
"ashamed",
"ashamedly",
"aside",
"asleep",
"astonish",
"astonishing",
"astonishes",
"astonished",
"astonishment",
"attend",
"attends",
"attending",
"attended",
"attendant",
"attendance",
"attendances",
"attention",
"attract",
"attracts",
"attracting",
"attracted",
"attractive",
"attraction",
"attractions",
"attractively",
"attractiveness",
"audience",
"audiences",
"aunt",
"aunts",
"autumn",
"avenue",
"avenues",
"avoid",
"avoids",
"avoiding",
"avoided",
"avoidance",
"avoidable",
"unavoidable",
"awake",
"awaken",
"awoken",
"awkward",
"awkwardly",
"axe",
"axing",
"axes",
"axed",
"ax",
"baby",
"babies",
"bag",
"bags",
"bagging",
"bagged",
"baggage",
"bake",
"baking",
"bakes",
"bakers",
"baker",
"baked",
"balance",
"balancing",
"balances",
"balanced",
"unbalanced",
"band",
"banded",
"banding",
"bands",
"barber",
"barbers",
"bare",
"baring",
"bares",
"bared",
"barely",
"bargain",
"bargains",
"bargaining",
"bargained",
"barrel",
"barrels",
"basin",
"basins",
"basket",
"baskets",
"bath",
"baths",
"bathe",
"bathing",
"bathes",
"bathed",
"bay",
"bays",
"beak",
"beaks",
"beaked",
"beam",
"beams",
"beamed",
"beaming",
"bean",
"beans",
"beard",
"beards",
"bearded",
"beast",
"beasts",
"beat",
"beats",
"beating",
"beaten",
"beg",
"begs",
"begging",
"begged",
"beggars",
"beggar",
"behave",
"behaves",
"behaved",
"behaving",
"behaviour",
"behaviours",
"behaviors",
"behavioural",
"behavior",
"behavioral",
"bell",
"bells",
"belt",
"belts",
"belting",
"belted",
"bend",
"bent",
"bends",
"bending",
"berry",
"berries",
"bicycle",
"bicycling",
"bicycles",
"bicycled",
"billion",
"billions",
"bind",
"binds",
"binding",
"binders",
"binder",
"birth",
"births",
"birthdays",
"birthday",
"bit",
"bits",
"bite",
"bites",
"biting",
"bitten",
"bitter",
"bitterness",
"bitterly",
"bitterest",
"bitterer",
"blade",
"blades",
"blame",
"blaming",
"blames",
"blamed",
"blameless",
"bless",
"blessed",
"blesses",
"blessing",
"blessings",
"blind",
"blinds",
"blindly",
"blinding",
"blinded",
"blindness",
"block",
"blocks",
"blocking",
"blocked",
"boast",
"boasts",
"boasting",
"boasted",
"boastful",
"boil",
"boils",
"boiling",
"boilers",
"boiler",
"boiled",
"bold",
"boldness",
"boldly",
"boldest",
"bolder",
"bone",
"boning",
"bones",
"boned",
"border",
"borders",
"bordering",
"bordered",
"borrow",
"borrows",
"borrowing",
"borrowed",
"bottle",
"bottling",
"bottles",
"bottled",
"bottom",
"bottoms",
"bound",
"bounds",
"bounding",
"bounded",
"boundless",
"boundary",
"boundaries",
"bow",
"bows",
"bowing",
"bowed",
"bowl",
"bowls",
"bowling",
"bowled",
"brain",
"brains",
"brass",
"brave",
"braving",
"braves",
"bravely",
"braved",
"bravery",
"breakfast",
"breakfasts",
"breakfasting",
"breakfasted",
"breath",
"breaths",
"breathlessly",
"breathless",
"breathe",
"breathing",
"breathes",
"breathed",
"bribe",
"bribing",
"bribes",
"bribed",
"bribery",
"brick",
"bricks",
"broadcast",
"broadcasting",
"broadcasts",
"brown",
"browns",
"browning",
"browned",
"brush",
"brushing",
"brushes",
"brushed",
"bucket",
"buckets",
"bunch",
"bunches",
"bundle",
"bundling",
"bundles",
"bundled",
"burst",
"bursts",
"bursting",
"bury",
"burying",
"buries",
"buried",
"burial",
"burials",
"bus",
"buses",
"bussed",
"bush",
"bushes",
"bushy",
"busy",
"busily",
"busiest",
"busier",
"butter",
"butters",
"buttering",
"buttered",
"button",
"buttons",
"buttoning",
"buttoned",
"unbuttoned",
"cage",
"caging",
"cages",
"caged",
"cake",
"cakes",
"calculate",
"calculator",
"calculating",
"calculates",
"calculated",
"calculation",
"calculations",
"calm",
"calms",
"calmly",
"calming",
"calmed",
"calmness",
"camera",
"cameras",
"camp",
"camped",
"camping",
"camps",
"canal",
"canals",
"cap",
"caps",
"capping",
"capped",
"cape",
"capes",
"caped",
"card",
"cards",
"carriage",
"carriages",
"cart",
"carts",
"carting",
"carted",
"cat",
"cats",
"cattle",
"caution",
"cautions",
"cautioning",
"cautioned",
"cautious",
"cautiously",
"cave",
"caving",
"caves",
"caved",
"cent",
"cents",
"centimetre",
"centimetres",
"century",
"centuries",
"ceremony",
"ceremonies",
"ceremonial",
"chain",
"chains",
"chaining",
"chained",
"chair",
"chairs",
"chairman",
"chalk",
"chalks",
"charm",
"charms",
"charming",
"charmed",
"cheap",
"cheapness",
"cheaply",
"cheapest",
"cheaper",
"cheat",
"cheats",
"cheating",
"cheated",
"check",
"checks",
"checking",
"checked",
"cheer",
"cheery",
"cheers",
"cheering",
"cheerful",
"cheered",
"cheese",
"cheeses",
"cheque",
"cheques",
"chest",
"chests",
"chicken",
"chickens",
"chimney",
"chimneys",
"christmas",
"christmases",
"civilise",
"civilizing",
"civilizes",
"civilized",
"civilize",
"civilising",
"civilises",
"civilised",
"civilisation",
"civilisations",
"clay",
"clays",
"clean",
"cleaned",
"cleaner",
"cleaners",
"cleanest",
"cleaning",
"cleanly",
"cleans",
"cleanness",
"clerk",
"clerks",
"clever",
"cleverness",
"cleverly",
"cleverest",
"cleverer",
"cliff",
"cliffs",
"climb",
"climbs",
"climbing",
"climbers",
"climber",
"climbed",
"clock",
"clocks",
"cloth",
"cloths",
"clothing",
"clothes",
"club",
"clubbed",
"clubbing",
"clubs",
"coarse",
"coarsest",
"coarser",
"coarseness",
"coarsely",
"coat",
"coats",
"coffee",
"coffees",
"collar",
"collars",
"collect",
"collects",
"collecting",
"collected",
"collective",
"collectively",
"collector",
"collectors",
"collection",
"collections",
"comb",
"combs",
"combing",
"combed",
"combine",
"combining",
"combines",
"combined",
"combination",
"combinations",
"comfort",
"uncomfortable",
"discomfort",
"comforts",
"comforting",
"comforted",
"comfortably",
"comfortable",
"commerce",
"commercial",
"commercially",
"companion",
"companions",
"companionship",
"compare",
"comparable",
"compared",
"compares",
"comparative",
"comparison",
"comparisons",
"comparing",
"comparatively",
"compete",
"competing",
"competes",
"competed",
"competition",
"competitions",
"complain",
"complaints",
"complaint",
"complains",
"complaining",
"complained",
"complicate",
"complicated",
"complicates",
"complicating",
"complication",
"complications",
"compose",
"composing",
"composes",
"composer",
"composed",
"composite",
"composition",
"confess",
"confessing",
"confesses",
"confessed",
"confession",
"confessions",
"confidence",
"confidences",
"confident",
"confidently",
"confuse",
"confusing",
"confuses",
"confused",
"confusion",
"congratulate",
"congratulating",
"congratulates",
"congratulated",
"congratulations",
"connect",
"connected",
"connecting",
"connects",
"connection",
"connections",
"conquer",
"conquers",
"conquerors",
"conqueror",
"conquering",
"conquered",
"conquest",
"conquests",
"conscience",
"consciences",
"conscious",
"consciousness",
"unconscious",
"unconsciously",
"consciously",
"convenience",
"conveniences",
"convenient",
"conveniently",
"conversation",
"conversations",
"cook",
"cooks",
"cooking",
"cookers",
"cooker",
"cooked",
"cool",
"cools",
"coolness",
"coolly",
"cooling",
"coolest",
"cooler",
"cooled",
"copper",
"copy",
"copying",
"copies",
"copied",
"cork",
"corks",
"corking",
"corked",
"corner",
"corners",
"cornered",
"cornering",
"correct",
"corrects",
"correctly",
"correcting",
"corrected",
"correctness",
"correction",
"corrections",
"incorrect",
"incorrectly",
"cottage",
"cottages",
"cough",
"coughs",
"coughing",
"coughed",
"courage",
"courageous",
"cousin",
"cousins",
"cow",
"cows",
"coward",
"cowards",
"cowardly",
"cowardice",
"crack",
"cracks",
"cracking",
"cracked",
"crash",
"crashing",
"crashes",
"crashed",
"cream",
"creams",
"creaming",
"creamed",
"creature",
"creatures",
"creep",
"crept",
"creeps",
"creeping",
"crime",
"crimes",
"criminal",
"criminally",
"critic",
"critics",
"critically",
"critical",
"crop",
"crops",
"cropping",
"cropped",
"cruel",
"cruelly",
"cruelness",
"cruelty",
"cruelties",
"crush",
"crushing",
"crushes",
"crushed",
"cultivate",
"cultivating",
"cultivates",
"cultivated",
"cultivation",
"cup",
"cups",
"cupboards",
"cupboard",
"cure",
"curing",
"cures",
"cured",
"curable",
"incurable",
"curious",
"curiously",
"curiosity",
"curl",
"curls",
"curling",
"curled",
"curly",
"curse",
"cursing",
"curses",
"cursed",
"curtain",
"curtains",
"curve",
"curving",
"curves",
"curved",
"cushion",
"cushions",
"cushioned",
"cushioning",
"custom",
"customs",
"customary",
"customer",
"customers",
"damage",
"damaging",
"damages",
"damaged",
"undamaged",
"damp",
"dampness",
"dampest",
"damper",
"dance",
"danced",
"dancer",
"dancers",
"dances",
"dancing",
"dare",
"dared",
"dares",
"daring",
"deaf",
"deafness",
"deafest",
"deafer",
"debt",
"debts",
"decay",
"decays",
"decaying",
"decayed",
"deceive",
"deceiving",
"deceives",
"deceived",
"deception",
"decrease",
"decreasing",
"decreases",
"decreased",
"deed",
"deeds",
"deer",
"defend",
"defence",
"defends",
"defending",
"defenders",
"defender",
"defended",
"delay",
"delays",
"delaying",
"delayed",
"delicate",
"delicately",
"delicacy",
"delicacies",
"delight",
"delights",
"delighting",
"delightfully",
"delightful",
"delighted",
"deliver",
"delivered",
"deliveries",
"delivering",
"delivers",
"undelivered",
"delivery",
"descend",
"descends",
"descending",
"descended",
"deserve",
"deserving",
"deserves",
"deservedly",
"deserved",
"desk",
"desks",
"despair",
"despairs",
"despairingly",
"despairing",
"despaired",
"devil",
"devils",
"diamond",
"diamonds",
"dictionary",
"dictionaries",
"dig",
"dug",
"digs",
"digging",
"dinner",
"dinners",
"dining",
"dines",
"dined",
"dine",
"dip",
"dips",
"dipping",
"dipped",
"dirt",
"dirty",
"disappoint",
"disappoints",
"disappointing",
"disappointed",
"disappointment",
"disappointments",
"discipline",
"disciplining",
"disciplines",
"disciplined",
"disciplinary",
"discuss",
"discussing",
"discusses",
"discussed",
"discussion",
"discussions",
"disease",
"diseases",
"diseased",
"disgust",
"disgusts",
"disgusting",
"disgusted",
"dish",
"dishes",
"dismiss",
"dismissing",
"dismisses",
"dismissed",
"dismissive",
"dismissively",
"disturb",
"disturbs",
"disturbing",
"disturbed",
"disturbance",
"disturbances",
"ditch",
"ditching",
"ditches",
"ditched",
"dive",
"diving",
"dives",
"dived",
"dove",
"diver",
"divers",
"donkey",
"donkeys",
"dot",
"dots",
"double",
"doubled",
"doubles",
"doubling",
"dozen",
"dozens",
"drag",
"drags",
"dragging",
"dragged",
"drawer",
"drawers",
"drown",
"drowns",
"drowning",
"drowned",
"drum",
"drums",
"drumming",
"drummed",
"duck",
"ducks",
"ducking",
"ducked",
"dull",
"dullness",
"dullest",
"duller",
"during",
"dust",
"dusts",
"dusting",
"dusted",
"duster",
"dusters",
"eager",
"eagerness",
"eagerly",
"earn",
"earns",
"earning",
"earned",
"earnings",
"earnest",
"earnestly",
"ease",
"easing",
"eases",
"eased",
"unease",
"uneasy",
"edge",
"edged",
"edges",
"edging",
"educate",
"educating",
"educates",
"educated",
"educator",
"educators",
"uneducated",
"education",
"educational",
"elastic",
"elastics",
"elasticity",
"elder",
"elderly",
"electric",
"electricity",
"electricians",
"electrician",
"electrical",
"electrically",
"elephant",
"elephants",
"empty",
"emptying",
"empties",
"emptied",
"enclose",
"enclosing",
"encloses",
"enclosed",
"enclosure",
"encourage",
"encouragingly",
"encouraging",
"encourages",
"encouraged",
"encouragement",
"engine",
"engines",
"engineer",
"engineering",
"engineers",
"entertain",
"entertains",
"entertaining",
"entertained",
"entertainment",
"entire",
"entirely",
"envelope",
"envelopes",
"envy",
"envying",
"envies",
"envied",
"envious",
"especial",
"especially",
"essence",
"essences",
"essential",
"essentials",
"essentially",
"evil",
"eviler",
"evilest",
"evilly",
"evilness",
"evils",
"exact",
"exactly",
"examining",
"examines",
"examined",
"examine",
"examiner",
"examiners",
"examination",
"examinations",
"excellent",
"excellence",
"excess",
"excessive",
"excessively",
"excite",
"exciting",
"excites",
"excitedly",
"excited",
"excitement",
"excuse",
"excusing",
"excuses",
"excused",
"explode",
"exploding",
"explodes",
"exploded",
"explosion",
"explosions",
"explosive",
"explore",
"exploring",
"exploration",
"explores",
"explored",
"exploratory",
"explorer",
"explorers",
"explorations",
"extra",
"extras",
"extraordinary",
"extraordinarily",
"extreme",
"extremely",
"fade",
"fading",
"fades",
"faded",
"faint",
"faints",
"faintly",
"fainting",
"fainter",
"fainted",
"faintness",
"false",
"falsely",
"falsehood",
"fan",
"fans",
"fanning",
"fanned",
"fancy",
"fancied",
"fancier",
"fancies",
"fanciest",
"fancily",
"fanciness",
"fancying",
"fashion",
"fashionable",
"fashioned",
"fashioning",
"fashions",
"fasten",
"fastened",
"fastener",
"fasteners",
"fastening",
"fastens",
"fat",
"fats",
"fatten",
"fatty",
"fate",
"fates",
"fault",
"faulty",
"faults",
"feast",
"feasts",
"feasting",
"feasted",
"feather",
"feathers",
"feathering",
"feathered",
"female",
"females",
"fence",
"fencing",
"fences",
"fenced",
"fever",
"feverish",
"fevers",
"fierce",
"fiercest",
"fiercer",
"fierceness",
"fiercely",
"film",
"films",
"filming",
"filmed",
"finger",
"fingers",
"firm",
"firms",
"firmness",
"firmly",
"firmest",
"flag",
"flags",
"flame",
"flames",
"flaming",
"flash",
"flashing",
"flashes",
"flashed",
"flat",
"flats",
"flatten",
"flattening",
"flavour",
"flavours",
"flavouring",
"flavoured",
"flavor",
"flavors",
"flavoring",
"flavored",
"flesh",
"float",
"floats",
"floating",
"floated",
"flood",
"floods",
"flooding",
"flooded",
"flour",
"fold",
"folds",
"folding",
"folded",
"fond",
"fondness",
"fondly",
"fondest",
"fonder",
"fool",
"fools",
"foolishness",
"foolishly",
"foolish",
"fooling",
"fooled",
"foot",
"feet",
"football",
"footballs",
"forbid",
"forbids",
"forbidding",
"forbidden",
"forgive",
"forgiving",
"forgives",
"forgiven",
"forgave",
"fork",
"forks",
"formal",
"formally",
"formality",
"forward",
"forwards",
"frame",
"framing",
"frames",
"framed",
"freeze",
"frozen",
"freezing",
"freezes",
"frequent",
"frequents",
"frequently",
"frequenting",
"frequented",
"frequency",
"infrequent",
"infrequently",
"fright",
"frights",
"frightful",
"frightens",
"frightening",
"frightened",
"frighten",
"fruit",
"fruits",
"fry",
"frying",
"fries",
"fried",
"fun",
"funny",
"funniest",
"funnier",
"funeral",
"funerals",
"fur",
"furs",
"gallon",
"gallons",
"gap",
"gaps",
"garage",
"garages",
"gay",
"gayness",
"gayest",
"gayer",
"gaily",
"gaiety",
"generous",
"generously",
"generosity",
"glory",
"glories",
"glorious",
"goat",
"goats",
"govern",
"govt",
"governs",
"governor",
"governing",
"governed",
"government",
"governments",
"governmental",
"grace",
"gracing",
"graces",
"gracefully",
"graceful",
"graced",
"gradual",
"gradually",
"grain",
"grains",
"gram",
"grams",
"grammar",
"grammars",
"grand",
"grandsons",
"grandson",
"grandparents",
"grandparent",
"grandpa",
"grandmother",
"grandma",
"grandfather",
"granddaughters",
"granddaughter",
"grandchildren",
"grandchild",
"grass",
"grasses",
"grassy",
"grateful",
"gratefully",
"grave",
"graves",
"grease",
"greasing",
"greases",
"greased",
"greasy",
"greed",
"greedy",
"greedily",
"greet",
"greetings",
"greets",
"greeting",
"greeted",
"grey",
"grind",
"grinds",
"grinding",
"guard",
"guarded",
"guarding",
"guards",
"guess",
"guessing",
"guesses",
"guessed",
"guest",
"guests",
"guide",
"guiding",
"guides",
"guided",
"guilty",
"guiltily",
"guilt",
"guiltless",
"gun",
"guns",
"gunner",
"habit",
"habits",
"habitual",
"habitually",
"hair",
"hairy",
"hairs",
"hall",
"halls",
"hammer",
"hammers",
"hammering",
"hammered",
"handkerchief",
"handkerchiefs",
"handle",
"handled",
"handles",
"handling",
"harbor",
"harbours",
"harbour",
"harbors",
"harm",
"harms",
"harmless",
"harming",
"harmful",
"harmed",
"harvest",
"harvests",
"harvesting",
"harvester",
"harvested",
"haste",
"hastily",
"hastens",
"hastening",
"hastened",
"hasten",
"hat",
"hats",
"hate",
"hatred",
"hating",
"hates",
"hated",
"hay",
"heal",
"heals",
"healing",
"healed",
"health",
"healthier",
"healthiest",
"healthily",
"healthy",
"heap",
"heaps",
"heaping",
"heaped",
"hesitate",
"hesitating",
"hesitates",
"hesitated",
"hesitation",
"hesitations",
"hide",
"hid",
"hidden",
"hides",
"hiding",
"hinder",
"hinders",
"hindering",
"hindered",
"hire",
"hiring",
"hires",
"hired",
"hit",
"hitting",
"hitter",
"hits",
"hole",
"holes",
"holiday",
"holidays",
"hollow",
"hollows",
"hollowing",
"hollowed",
"holy",
"holiness",
"holiest",
"holier",
"honest",
"honesty",
"honestly",
"dishonest",
"hook",
"hooks",
"hooking",
"hooked",
"horizon",
"horizons",
"hospital",
"hospitals",
"host",
"hosts",
"hosting",
"hosted",
"hotel",
"hotels",
"hullo",
"hello",
"hey",
"hi",
"humble",
"humbly",
"humbling",
"humbles",
"humbled",
"hunger",
"hungry",
"hungrily",
"hungers",
"hungering",
"hunt",
"hunts",
"hunting",
"hunters",
"hunter",
"hunted",
"hurrah",
"hurry",
"hurrying",
"hurries",
"hurriedly",
"hurried",
"hurt",
"hurts",
"hurting",
"hurtful",
"hut",
"huts",
"ice",
"icy",
"iced",
"ideal",
"ideals",
"ideally",
"idle",
"idling",
"idles",
"idled",
"idly",
"imagine",
"imagining",
"imagines",
"imagined",
"imagination",
"imaginations",
"imaginative",
"imaginary",
"imitate",
"imitating",
"imitates",
"imitated",
"imitation",
"imitations",
"immediate",
"immediacy",
"immediately",
"immense",
"immensely",
"improve",
"improving",
"improves",
"improved",
"improvement",
"improvements",
"inform",
"informs",
"informing",
"informed",
"information",
"informal",
"informally",
"ink",
"inks",
"inky",
"inn",
"inns",
"inquire",
"inquiry",
"inquiring",
"inquiries",
"inquires",
"inquired",
"enquire",
"enquiry",
"enquiring",
"insect",
"insects",
"inside",
"insider",
"insiders",
"instant",
"instantly",
"instrument",
"instruments",
"instrumental",
"insult",
"insults",
"insulting",
"insulted",
"insure",
"insuring",
"insures",
"insured",
"insurance",
"intend",
"intended",
"intending",
"intends",
"intent",
"intently",
"intention",
"intentions",
"intentional",
"intentionally",
"interfere",
"interfering",
"interferes",
"interfered",
"interference",
"international",
"internationally",
"interrupt",
"interrupts",
"interrupting",
"interrupted",
"invent",
"invents",
"inventors",
"inventor",
"inventing",
"invented",
"invention",
"inventions",
"invite",
"inviting",
"invites",
"invited",
"invitation",
"invitations",
"inward",
"inwardly",
"island",
"islands",
"jaw",
"jaws",
"jealous",
"jealously",
"jealousy",
"jewel",
"jewels",
"jewellers",
"jeweller",
"jewellery",
"joke",
"jokes",
"joked",
"joking",
"journey",
"journeys",
"journeying",
"journeyed",
"juice",
"juices",
"juicy",
"jump",
"jumps",
"jumping",
"jumped",
"key",
"keys",
"kick",
"kicks",
"kicking",
"kicked",
"kilogram",
"kilograms",
"kilometre",
"kilometres",
"kiss",
"kissing",
"kisses",
"kissed",
"kitchen",
"kitchens",
"knee",
"knees",
"kneel",
"kneels",
"kneeling",
"knife",
"knives",
"knock",
"knocks",
"knocking",
"knocked",
"knot",
"knotting",
"knotted",
"knots",
"ladder",
"ladders",
"lamp",
"lamps",
"lazy",
"laziness",
"lazily",
"laziest",
"lazier",
"leaf",
"leafy",
"lean",
"leans",
"leaning",
"leaned",
"leather",
"leathers",
"leg",
"legs",
"lend",
"lent",
"lends",
"lending",
"lesson",
"lessons",
"liberty",
"liberties",
"lid",
"lids",
"limb",
"limbs",
"liquid",
"liquids",
"list",
"unlisted",
"lists",
"listed",
"listing",
"litre",
"litres",
"load",
"unloads",
"unloading",
"unloaded",
"loads",
"loading",
"loaded",
"loaf",
"loaves",
"loan",
"loans",
"lock",
"unlocks",
"unlocking",
"unlocked",
"unlock",
"locks",
"locking",
"locked",
"lodging",
"lodgings",
"log",
"logs",
"lone",
"lonely",
"loneliness",
"loose",
"loosely",
"loosen",
"lot",
"lots",
"loud",
"loudness",
"loudly",
"loudest",
"louder",
"loyal",
"loyalty",
"loyally",
"luck",
"lucky",
"luckily",
"luckiest",
"luckier",
"unlucky",
"unluckily",
"lump",
"lumps",
"lunch",
"lunches",
"lung",
"lungs",
"mad",
"madness",
"madly",
"maddest",
"madder",
"madman",
"mail",
"mails",
"mailing",
"mailed",
"male",
"males",
"manage",
"managing",
"manages",
"managers",
"manager",
"managed",
"management",
"map",
"maps",
"mat",
"mats",
"match",
"matching",
"matches",
"matched",
"meal",
"meals",
"meantime",
"meanwhile",
"meat",
"meats",
"mechanic",
"mechanics",
"mechanical",
"mechanically",
"medicine",
"medicines",
"medic",
"melt",
"melts",
"melting",
"melted",
"mend",
"mends",
"mending",
"mended",
"merchant",
"merchants",
"mercy",
"merciful",
"mercies",
"merry",
"merriness",
"merriest",
"merrier",
"merrily",
"message",
"messages",
"messenger",
"messengers",
"metre",
"metres",
"mild",
"mildness",
"mildly",
"mildest",
"milder",
"mill",
"mills",
"milling",
"miller",
"milled",
"milligram",
"milligrams",
"millilitre",
"millilitres",
"millimetre",
"millimetres",
"mineral",
"minerals",
"miserable",
"miserably",
"mistake",
"mistaking",
"mistakes",
"mistakenly",
"mistaken",
"unmistakably",
"unmistakable",
"mix",
"mixtures",
"mixture",
"mixing",
"mixes",
"mixed",
"model",
"models",
"modelling",
"modelled",
"modeling",
"modeled",
"moderate",
"moderately",
"moderation",
"modest",
"modesty",
"modestly",
"monkey",
"monkeys",
"motion",
"motions",
"motioning",
"motioned",
"motionless",
"mouse",
"mice",
"mud",
"muddy",
"multiply",
"multiplying",
"multiplies",
"multiplied",
"multiple",
"multiplication",
"murder",
"murders",
"murdering",
"murderers",
"murderer",
"murdered",
"mystery",
"mysteriously",
"mysterious",
"mysteries",
"nail",
"nails",
"nailing",
"nailed",
"narrow",
"narrowed",
"narrower",
"narrowest",
"narrowing",
"narrowly",
"narrowness",
"narrows",
"neat",
"neatness",
"neatly",
"neatest",
"neater",
"neck",
"necks",
"needle",
"needling",
"needles",
"needled",
"neglect",
"neglects",
"neglecting",
"neglected",
"nephew",
"nephews",
"nest",
"nests",
"nesting",
"nested",
"net",
"nets",
"nice",
"nicest",
"nicer",
"niceness",
"nicely",
"niece",
"nieces",
"noise",
"noisy",
"noisily",
"noises",
"nonsense",
"nonsensical",
"noon",
"nose",
"noses",
"noun",
"nouns",
"nuisance",
"nuisances",
"nurse",
"nursing",
"nurses",
"nursed",
"nut",
"nuts",
"oar",
"oars",
"obey",
"obeys",
"obeying",
"obeyed",
"obedience",
"obediently",
"obedient",
"disobey",
"disobeyed",
"disobeying",
"ocean",
"oceans",
"offend",
"offenses",
"offense",
"offends",
"offending",
"offended",
"offensive",
"offensively",
"inoffensive",
"inoffensively",
"omit",
"omitting",
"omitted",
"omits",
"omission",
"omissions",
"onwards",
"onward",
"oppose",
"opposing",
"opposes",
"opposed",
"opposite",
"opposites",
"orange",
"oranges",
"organ",
"organs",
"origin",
"origins",
"originates",
"originated",
"original",
"originally",
"originality",
"ornament",
"ornaments",
"ornamental",
"outline",
"outlined",
"outlines",
"outlining",
"overcome",
"overcoming",
"overcomes",
"overcame",
"pack",
"packs",
"packing",
"packed",
"package",
"packages",
"pad",
"pads",
"padding",
"padded",
"pain",
"pains",
"painful",
"painfully",
"pair",
"pairs",
"pairing",
"paired",
"pale",
"paling",
"pales",
"paled",
"paleness",
"pan",
"pans",
"parcel",
"parcels",
"parcelled",
"pardon",
"pardons",
"pardoning",
"pardoned",
"unpardonable",
"parent",
"parents",
"parental",
"parentage",
"park",
"parks",
"parking",
"parked",
"permanent",
"permanently",
"passage",
"passages",
"passenger",
"passengers",
"paste",
"pasting",
"pastes",
"pasted",
"path",
"paths",
"patient",
"patiently",
"patience",
"patriotic",
"pattern",
"patterns",
"patterned",
"pause",
"pausing",
"pauses",
"paused",
"paw",
"paws",
"pearl",
"pearls",
"peculiar",
"peculiarly",
"peculiarity",
"peculiarities",
"pen",
"pens",
"pencil",
"pencils",
"penny",
"pennies",
"perfect",
"perfected",
"perfecting",
"perfectly",
"perfects",
"perfection",
"perform",
"performs",
"performing",
"performers",
"performed",
"performance",
"performances",
"persuade",
"persuasion",
"persuades",
"persuaded",
"persuading",
"persuasive",
"persuasively",
"pet",
"pets",
"photograph",
"photography",
"photographs",
"photographing",
"photographers",
"photographer",
"photographed",
"pick",
"picks",
"picking",
"pickers",
"picker",
"picked",
"pig",
"pigs",
"pigeon",
"pigeons",
"pile",
"piling",
"piles",
"piled",
"pin",
"pins",
"pinned",
"pinning",
"pinch",
"pinching",
"pinches",
"pinched",
"pink",
"pinkness",
"pinkest",
"pinker",
"pint",
"pints",
"pipe",
"pipes",
"pity",
"pitying",
"pities",
"pitied",
"plane",
"planes",
"plaster",
"plasters",
"plastering",
"plastered",
"plate",
"plates",
"plenty",
"plentiful",
"plough",
"ploughs",
"ploughing",
"ploughed",
"plural",
"plurals",
"pocket",
"pockets",
"poem",
"poetry",
"poetic",
"poet",
"poems",
"poison",
"poisons",
"poisonous",
"poisoning",
"poisoned",
"police",
"policing",
"policewomen",
"polices",
"policemen",
"policeman",
"policed",
"polish",
"polishing",
"polishes",
"polished",
"polite",
"politest",
"politer",
"politeness",
"pool",
"pools",
"pooling",
"postpone",
"postponing",
"postpones",
"postponed",
"pot",
"potting",
"potted",
"pots",
"pour",
"pours",
"pouring",
"poured",
"powder",
"powders",
"powdery",
"practical",
"practically",
"practise",
"practises",
"practised",
"practising",
"practice",
"practices",
"praise",
"praising",
"praises",
"praised",
"pray",
"prays",
"praying",
"prayers",
"prayer",
"prayed",
"preach",
"preaching",
"preaches",
"preachers",
"preacher",
"preached",
"precious",
"prefer",
"prefers",
"preferring",
"preferred",
"preferable",
"preference",
"preferences",
"preferential",
"prejudice",
"prejudices",
"prejudiced",
"unprejudiced",
"preserve",
"preserved",
"preserves",
"preserving",
"preservation",
"pretend",
"pretends",
"pretending",
"pretended",
"pretence",
"pride",
"prides",
"priest",
"priests",
"print",
"printed",
"printers",
"printing",
"prints",
"reprint",
"reprints",
"reprinting",
"reprinted",
"prison",
"prisons",
"prisoners",
"prisoner",
"imprison",
"prize",
"prized",
"prizes",
"probable",
"probably",
"probability",
"probabilities",
"improbable",
"procession",
"processions",
"profession",
"professions",
"programme",
"program",
"programed",
"programing",
"programmed",
"programmes",
"programming",
"programs",
"prompt",
"prompts",
"promptly",
"prompting",
"prompted",
"pronounce",
"pronouncing",
"pronounces",
"pronounced",
"proud",
"proudly",
"proudest",
"prouder",
"pump",
"pumps",
"pumping",
"pumped",
"punctual",
"punctually",
"punctuality",
"punish",
"punishing",
"punishes",
"punished",
"punishment",
"punishments",
"pupil",
"pupils",
"pure",
"purest",
"purer",
"pureness",
"purely",
"impure",
"impurity",
"purple",
"purplish",
"push",
"pushing",
"pushes",
"pushed",
"puzzle",
"puzzling",
"puzzles",
"puzzled",
"qualify",
"qualifying",
"qualifies",
"qualified",
"qualification",
"qualifications",
"quarrel",
"quarrels",
"quarrelling",
"quarrelled",
"quarreling",
"quarreled",
"quart",
"quarts",
"quick",
"quickness",
"quickly",
"quickest",
"quicker",
"quiet",
"quieter",
"quietest",
"quietly",
"quietness",
"rabbit",
"rabbits",
"radio",
"radios",
"radioed",
"rail",
"railways",
"railway",
"rails",
"railroads",
"railroad",
"rain",
"rains",
"raining",
"rained",
"raindrops",
"raindrop",
"rake",
"raking",
"rakes",
"raked",
"rapid",
"rapidly",
"rapidity",
"rare",
"rarest",
"rarer",
"rareness",
"rarely",
"rat",
"rats",
"raw",
"rawness",
"rawest",
"rawer",
"ray",
"rays",
"razor",
"razors",
"recommend",
"recommends",
"recommending",
"recommended",
"recommendation",
"recommendations",
"refer",
"refers",
"referring",
"referred",
"reflect",
"reflects",
"reflecting",
"reflected",
"reflective",
"reflection",
"reflections",
"refresh",
"refreshes",
"refreshing",
"refreshed",
"refreshment",
"regular",
"irregular",
"regularly",
"irregularly",
"regret",
"regretting",
"regretful",
"regretted",
"regrets",
"rejoice",
"rejoicing",
"rejoices",
"rejoiced",
"relieve",
"relieving",
"relieves",
"relieved",
"relief",
"remedy",
"remedying",
"remedies",
"remedied",
"remind",
"reminds",
"reminding",
"reminded",
"reminder",
"rent",
"renting",
"rented",
"rents",
"repair",
"repairs",
"repairing",
"repaired",
"repeat",
"repeated",
"repeatedly",
"repeating",
"repeats",
"replace",
"replacing",
"replaces",
"replaced",
"replacement",
"replacements",
"replaceable",
"irreplaceable",
"reproduce",
"reproduces",
"reproducing",
"reproduced",
"reproduction",
"reproductions",
"reputation",
"reputations",
"request",
"requests",
"requesting",
"requested",
"rescue",
"rescuing",
"rescues",
"rescued",
"resign",
"resigns",
"resigning",
"resigned",
"resignation",
"resignations",
"resist",
"resists",
"resisting",
"resisted",
"resistible",
"resistance",
"responsible",
"irresponsible",
"responsibility",
"responsibilities",
"restaurant",
"restaurants",
"retire",
"retiring",
"retires",
"retired",
"retirement",
"revenge",
"revenges",
"review",
"reviews",
"reviewing",
"reviewed",
"reward",
"rewards",
"rewarding",
"rewarded",
"ribbon",
"ribbons",
"rice",
"rid",
"rids",
"ridding",
"ripe",
"ripest",
"riper",
"ripeness",
"risk",
"risks",
"risking",
"risked",
"risky",
"rival",
"rivals",
"rivalry",
"rivalries",
"rivalling",
"rivalled",
"roar",
"roars",
"roaring",
"roared",
"roast",
"roasts",
"roasting",
"roasted",
"rob",
"robs",
"robbing",
"robber",
"robbed",
"robbers",
"rod",
"rods",
"roof",
"roofs",
"root",
"roots",
"rooted",
"rope",
"ropes",
"rot",
"rotting",
"rotted",
"rots",
"rotten",
"row",
"rows",
"rowing",
"rowed",
"rub",
"rubs",
"rubbing",
"rubbed",
"rubber",
"rubbers",
"rubbish",
"rude",
"rudest",
"ruder",
"rudeness",
"rudely",
"rug",
"rugs",
"ruin",
"ruined",
"ruining",
"ruins",
"rush",
"rushed",
"rushes",
"rushing",
"rust",
"rusty",
"rusts",
"rusting",
"rusted",
"sacred",
"sacredness",
"sacrifice",
"sacrificing",
"sacrifices",
"sacrificed",
"sacrificial",
"sad",
"sadness",
"sadly",
"saddest",
"sadder",
"sadden",
"saddle",
"saddling",
"saddles",
"saddled",
"sake",
"sakes",
"salary",
"salaries",
"sample",
"sampling",
"samples",
"sampled",
"sand",
"sandy",
"sands",
"satisfy",
"satisfying",
"satisfies",
"satisfied",
"satisfactory",
"satisfaction",
"dissatisfaction",
"dissatisfying",
"dissatisfy",
"dissatisfies",
"dissatisfied",
"sauce",
"sauces",
"saucer",
"saucers",
"saws",
"sawing",
"sawed",
"scale",
"scales",
"scatter",
"scatters",
"scattering",
"scattered",
"scent",
"scents",
"scenting",
"scented",
"scissors",
"scold",
"scolds",
"scolding",
"scolded",
"scorn",
"scorns",
"scorning",
"scorned",
"scornful",
"scornfully",
"scrape",
"scraping",
"scrapes",
"scraped",
"scratch",
"scratching",
"scratches",
"scratched",
"screen",
"screens",
"screening",
"screened",
"screw",
"screws",
"screwing",
"screwed",
"search",
"searching",
"searches",
"searched",
"seed",
"seeds",
"seeding",
"seeded",
"seedling",
"seize",
"seized",
"seizes",
"seizing",
"seldom",
"self",
"selfishness",
"selfishly",
"selfish",
"selves",
"sentence",
"sentences",
"severe",
"severity",
"severest",
"severer",
"severeness",
"severely",
"sew",
"sews",
"sewn",
"sewing",
"sewed",
"shade",
"shadings",
"shading",
"shades",
"shaded",
"shallow",
"shallowness",
"shallowest",
"shallower",
"shame",
"shaming",
"shames",
"shameful",
"shamefully",
"shamed",
"sharp",
"sharpness",
"sharply",
"sharpest",
"sharper",
"sharpens",
"sharpening",
"sharpened",
"sharpen",
"shave",
"shaved",
"shaving",
"shaves",
"sheep",
"sheet",
"sheets",
"shelf",
"shelves",
"shell",
"shells",
"shelling",
"shelled",
"shelter",
"shelters",
"sheltering",
"sheltered",
"shield",
"shields",
"shielding",
"shielded",
"shilling",
"shillings",
"shirt",
"shirts",
"shock",
"shocks",
"shocking",
"shocked",
"shoe",
"shoeing",
"shoes",
"shop",
"shops",
"shopping",
"shoppers",
"shopper",
"shopped",
"shout",
"shouted",
"shouting",
"shouts",
"shower",
"showers",
"showering",
"showered",
"shut",
"shutting",
"shuts",
"sick",
"sickness",
"sickly",
"sickest",
"sicker",
"signal",
"signals",
"signalling",
"signalled",
"silk",
"silks",
"sincere",
"sincerely",
"sincerity",
"sink",
"sunk",
"sinks",
"sinking",
"sank",
"skill",
"skilled",
"skills",
"skilfully",
"skin",
"skins",
"skinning",
"skinned",
"skirt",
"skirts",
"slave",
"slaves",
"slavery",
"slide",
"sliding",
"slides",
"slid",
"slight",
"slighted",
"slighter",
"slightest",
"slighting",
"slightly",
"slights",
"slow",
"slowed",
"slower",
"slowest",
"slowing",
"slowly",
"slows",
"slip",
"slips",
"slipping",
"slipped",
"slope",
"sloping",
"slopes",
"sloped",
"smell",
"smelt",
"smells",
"smelling",
"smelled",
"smoke",
"smoking",
"smokes",
"smokers",
"smokeless",
"smoked",
"smooth",
"smooths",
"smoothly",
"smoothing",
"smoothed",
"snake",
"snakes",
"soap",
"soaps",
"sock",
"socks",
"soil",
"soiled",
"soiling",
"soils",
"solemn",
"solemnly",
"solid",
"solidify",
"solidly",
"solids",
"solve",
"solving",
"solves",
"solved",
"solution",
"solutions",
"sore",
"sores",
"sorry",
"sorriness",
"sorriest",
"sorrier",
"soup",
"soups",
"sour",
"sours",
"sourly",
"souring",
"soured",
"sow",
"sows",
"sowing",
"sowed",
"spade",
"spades",
"spare",
"sparing",
"spares",
"spared",
"spell",
"spelt",
"spells",
"spelling",
"spelled",
"spill",
"spills",
"spilling",
"spilled",
"spin",
"spun",
"spins",
"spinning",
"spit",
"spits",
"spitting",
"spat",
"splendid",
"splendidly",
"split",
"splitting",
"splits",
"spoil",
"spoils",
"spoiling",
"spoiled",
"spoon",
"spoons",
"spoonful",
"sport",
"sporting",
"sports",
"staff",
"staffs",
"stain",
"stains",
"staining",
"stained",
"stairs",
"upstairs",
"downstairs",
"stamp",
"stamps",
"stamping",
"stamped",
"steady",
"unsteady",
"unsteadily",
"steadying",
"steadily",
"steadies",
"steadied",
"steal",
"stole",
"stolen",
"steals",
"stealing",
"steam",
"steams",
"steaming",
"steamed",
"steep",
"steepness",
"steepest",
"steeper",
"steer",
"steers",
"steering",
"steered",
"stem",
"stems",
"stemmed",
"stick",
"sticking",
"sticks",
"stuck",
"stiff",
"stiffness",
"stiffest",
"stiffer",
"stiffens",
"stiffening",
"stiffened",
"stiffen",
"sting",
"stung",
"stings",
"stinging",
"stir",
"stirs",
"stirring",
"stirred",
"stocking",
"stockings",
"stomach",
"stomachs",
"storm",
"stormed",
"storming",
"storms",
"stove",
"stoves",
"straight",
"straightened",
"straightening",
"straightens",
"straighter",
"straightest",
"strap",
"straps",
"strapping",
"strapped",
"straw",
"straws",
"stretch",
"stretched",
"stretches",
"stretching",
"strict",
"strictness",
"strictly",
"strictest",
"stricter",
"string",
"strings",
"stringing",
"stringed",
"strip",
"strips",
"stripped",
"stripping",
"stripe",
"stripes",
"striped",
"striping",
"stuff",
"stuffs",
"stuffing",
"stuffed",
"stupid",
"stupidity",
"stupidly",
"stupidest",
"stupider",
"suck",
"sucks",
"sucking",
"sucked",
"sudden",
"suddenly",
"suddenness",
"sugar",
"sugars",
"sugary",
"suit",
"suits",
"suiting",
"suited",
"suitability",
"suitable",
"unsuitable",
"supper",
"suppers",
"suspect",
"suspects",
"suspecting",
"suspected",
"unsuspecting",
"suspicion",
"suspicions",
"suspicious",
"suspiciously",
"swallow",
"swallows",
"swallowing",
"swallowed",
"swear",
"sworn",
"swore",
"swears",
"swearing",
"sweat",
"sweats",
"sweating",
"sweep",
"swept",
"sweeps",
"sweeping",
"swell",
"swollen",
"swells",
"swelling",
"swelled",
"swim",
"swum",
"swims",
"swimming",
"swam",
"swing",
"swung",
"swings",
"swinging",
"sympathy",
"sympathies",
"sympathetic",
"sympathetically",
"tail",
"tails",
"tailor",
"tailors",
"tailoring",
"tailored",
"tall",
"tallest",
"taller",
"tame",
"taming",
"tames",
"tamed",
"tap",
"taps",
"tapping",
"tapped",
"taste",
"tasted",
"tastes",
"tasting",
"taxi",
"taxis",
"tea",
"teas",
"telegraph",
"telegraphs",
"telegraphing",
"telegraphed",
"telephone",
"telephoning",
"telephones",
"telephoned",
"phones",
"phoning",
"phoned",
"phone",
"temper",
"tempers",
"temperature",
"temperatures",
"tempt",
"tempts",
"tempting",
"tempted",
"tend",
"tends",
"tended",
"tendency",
"tendencies",
"tender",
"tenderness",
"tenderly",
"tent",
"tents",
"terrible",
"terribly",
"thank",
"thanks",
"thanking",
"thankfully",
"thankful",
"thanked",
"theatre",
"theatres",
"theatrical",
"thick",
"thickness",
"thickly",
"thickest",
"thicker",
"thief",
"thieves",
"thin",
"thins",
"thinning",
"thinnest",
"thinness",
"thinner",
"thinned",
"thinly",
"thirst",
"thirsts",
"thorn",
"thorns",
"thorough",
"thoroughness",
"thoroughly",
"thread",
"threads",
"threading",
"threaded",
"threat",
"threats",
"threatens",
"threatening",
"threatened",
"threaten",
"throat",
"throats",
"thumb",
"thumbs",
"thunder",
"thunders",
"thundering",
"thundered",
"ticket",
"tickets",
"tide",
"tides",
"tidal",
"tidy",
"tidying",
"tidies",
"tidied",
"tie",
"untied",
"untie",
"tying",
"ties",
"tied",
"tight",
"tightness",
"tightest",
"tighter",
"tightly",
"tightens",
"tightening",
"tightened",
"tighten",
"tin",
"tins",
"tip",
"tips",
"tipping",
"tipped",
"tire",
"tiring",
"tires",
"tired",
"title",
"titled",
"titles",
"tobacco",
"tobaccos",
"toe",
"toes",
"tomorrow",
"tongue",
"tongues",
"tonight",
"tool",
"tools",
"tooth",
"teeth",
"toothless",
"tough",
"toughness",
"toughest",
"tougher",
"tour",
"tours",
"touring",
"toured",
"tourist",
"tourists",
"towel",
"towels",
"tower",
"towers",
"towering",
"toy",
"toys",
"track",
"tracks",
"tracking",
"tracked",
"translate",
"translating",
"translates",
"translated",
"translation",
"translations",
"trap",
"traps",
"trapping",
"trapped",
"tray",
"trays",
"treasure",
"treasuring",
"treasures",
"treasured",
"treasury",
"treasurer",
"treat",
"treats",
"treating",
"treated",
"treatment",
"treatments",
"tremble",
"trembling",
"trembles",
"trembled",
"tribe",
"tribes",
"trick",
"trickster",
"tricks",
"tricking",
"tricked",
"trip",
"trips",
"tripping",
"tripped",
"trunk",
"trunks",
"tube",
"tubes",
"tune",
"tuning",
"tunes",
"tuned",
"twist",
"twists",
"twisting",
"twisted",
"typical",
"typically",
"ugly",
"ugliness",
"ugliest",
"uglier",
"umbrella",
"umbrellas",
"uncle",
"uncles",
"universe",
"universal",
"upper",
"upright",
"upset",
"upsetting",
"upsets",
"upwards",
"upward",
"urge",
"urging",
"urges",
"urged",
"vain",
"vainly",
"vainest",
"vainer",
"veil",
"veils",
"veiling",
"veiled",
"verb",
"verbs",
"verse",
"verses",
"violent",
"violently",
"violence",
"nonviolent",
"vowel",
"vowels",
"voyage",
"voyaging",
"voyages",
"voyaged",
"waist",
"waists",
"wake",
"woke",
"waking",
"wakes",
"waken",
"woken",
"wander",
"wanders",
"wandering",
"wandered",
"warm",
"warms",
"warmly",
"warming",
"warmed",
"warmth",
"warn",
"warned",
"warning",
"warns",
"wash",
"washed",
"washes",
"washing",
"waste",
"wasted",
"wastes",
"wasting",
"wasteful",
"wastefully",
"wax",
"waxing",
"waxes",
"waxed",
"weak",
"weakly",
"weakness",
"weaken",
"weapon",
"weapons",
"weather",
"weathers",
"weathering",
"weathered",
"weave",
"wove",
"weaving",
"weaves",
"weaved",
"weed",
"weeds",
"weeding",
"weeded",
"weigh",
"weights",
"weight",
"weighs",
"weighing",
"weighed",
"wet",
"wetting",
"wets",
"wheat",
"wheel",
"wheels",
"wheeler",
"wheeled",
"whip",
"whips",
"whipping",
"whipped",
"whisper",
"whispers",
"whispering",
"whispered",
"whistle",
"whistling",
"whistles",
"whistled",
"wicked",
"wickedness",
"wickedest",
"wickeder",
"wickedly",
"widow",
"widows",
"widower",
"widowed",
"wine",
"wining",
"wines",
"wined",
"wing",
"wings",
"winging",
"winged",
"wipe",
"wiping",
"wipes",
"wiped",
"wiper",
"wipers",
"wire",
"wiring",
"wires",
"wired",
"witness",
"witnessing",
"witnesses",
"witnessed",
"wool",
"wools",
"woollen",
"woolly",
"worm",
"worms",
"worming",
"wormed",
"worry",
"worrying",
"worries",
"worried",
"worse",
"worst",
"worsen",
"worship",
"worshipping",
"worships",
"worshipped",
"wrap",
"wrapping",
"wraps",
"wrapper",
"wrappers",
"wrapped",
"wreck",
"wrecked",
"wrecking",
"wrecks",
"wrist",
"wrists",
"yard",
"yards",
"yellow",
"yellowish",
"zero",
"zeros",
"advisors",
"aunty",
"broadcasted",
"bussing",
"cappings",
"cruellest",
"crueller",
"kneeled",
"orangish",
"ridded",
"shoed",
"skilful",
"misspelt",
"sweated",
"wheats",
}

is_word_gsl2 = lambda w : w in word_gsl2

def submit(port, host='127.0.0.1',  db=0):
	import redis
	r = redis.Redis(host=host, port=port, db=db)
	for w in word_gsl2: 
		r.sadd("dict:gsl2", w )
		r.hset('dict:word_level', w, 'gsl2')
	print(">> finished loading gsl2")

if __name__ == '__main__':
	submit(6311)