word_pos = {
"'d":	{"MD","VBD"},
"'em":	{"PRP"},
"'hood":	{"NN"},
"'ll":	{"MD"},
"'m":	{"VBP"},
"'re":	{"VBP"},
"'s":	{"POS","VBZ","PRP"},
"'un":	{"PRP"},
"'ve":	{"VBP"},
"AIDS-related":	{"JJ"},
"ASEAN":	{"JJ"},
"AV":	{"NN"},
"Abyssinian":	{"NNP","JJ"},
"Acropolis":	{"NNS"},
"Adm":	{"NNP","NN"},
"Adriatic":	{"JJ"},
"Aegean":	{"JJ"},
"Afghan":	{"JJ","NNP"},
"African":	{"JJ","NNP"},
"African-American":	{"JJ","NNP"},
"Afrikaner":	{"JJ","NNP"},
"Afro":	{"JJ","NNP"},
"Afro-American":	{"JJ","NN"},
"Afro-Americans":	{"NNS"},
"Afro-Asian":	{"NNP","JJ"},
"Afro-Cuban":	{"JJ"},
"Alabamian":	{"JJ","NNP"},
"Alaouite":	{"JJ"},
"Alaskan":	{"JJ","NNP"},
"Albanian":	{"NNP","JJ"},
"Albanians":	{"NNPS","NNS"},
"Alexandrine":	{"NNP","JJ"},
"Algerian":	{"JJ","NNP"},
"Allied":	{"JJ"},
"Allons":	{"FW"},
"Alors":	{"FW"},
"Alsatian":	{"NNP","JJ"},
"Amazonian":	{"JJ"},
"American":	{"JJ","NNP"},
"Americanise":	{"VB","VBP"},
"Americanised":	{"VBD","VBN","JJ"},
"Americanises":	{"VBZ"},
"Americanising":	{"VBG"},
"Americanize":	{"VB","VBP"},
"Americanized":	{"VBD","VBN","JJ"},
"Americanizes":	{"VBZ"},
"Americanizing":	{"VBG"},
"Amish":	{"NNP","JJ"},
"Andean":	{"JJ","NNP"},
"Anglian":	{"JJ","NNP"},
"Anglican":	{"NNP","JJ"},
"Anglo-French":	{"JJ","NNP"},
"Anglo-Irish":	{"JJ","NNP"},
"Anglo-Saxon":	{"NNP","JJ"},
"Anglo-Saxons":	{"NNS"},
"Angolan":	{"JJ","NNP"},
"Antarctic":	{"NNP","JJ"},
"Antiguan":	{"NNP","JJ"},
"Apache":	{"NNP","NNPS"},
"Apollonian":	{"JJ"},
"Appalachian":	{"JJ"},
"Arab":	{"JJ","NNP"},
"Arabian":	{"NNP","JJ"},
"Arabic":	{"NNP","JJ"},
"Arcadian":	{"NNP","JJ"},
"Arctic":	{"NNP","JJ"},
"Argentine":	{"JJ","NNP"},
"Argentinian":	{"JJ","NNP"},
"Aristotelian":	{"JJ","NNP"},
"Arles":	{"NNS"},
"Armenian":	{"NNP","JJ"},
"Arthurian":	{"JJ"},
"Ashoka":	{"NN"},
"Asian":	{"JJ","NNP"},
"Asiatic":	{"JJ","NNP"},
"Assyrian":	{"NNP","JJ"},
"Athenian":	{"NNP","JJ"},
"Atlantic":	{"NNP","JJ"},
"Au":	{"NN"},
"Augustan":	{"JJ"},
"Aussie":	{"NNP","JJ"},
"Australasian":	{"NNP","JJ"},
"Australian":	{"JJ","NNP"},
"Austrian":	{"JJ","NNP"},
"Austro-Hungarian":	{"JJ"},
"Azerbaijani":	{"NNP","JJ","NNPS"},
"Aztec":	{"JJ","NNP"},
"B-cell":	{"NN"},
"B-cells":	{"NNS"},
"B-movie":	{"NN"},
"B-movies":	{"NNS"},
"Babbittry":	{"NN"},
"Babylonian":	{"NNP","JJ"},
"Bahamian":	{"JJ","NNP"},
"Balinese":	{"NNP","JJ"},
"Balkan":	{"JJ"},
"Balkanise":	{"VB","VBP"},
"Balkanization":	{"NN"},
"Balkanize":	{"VB","VBP"},
"Balkanized":	{"JJ","VBD","VBN"},
"Balkanizes":	{"VBZ"},
"Balkanizing":	{"VBG"},
"Baltic":	{"JJ"},
"Bangladeshi":	{"NNP","JJ"},
"Bantu":	{"NNP","JJ"},
"Baptist":	{"NNP","JJ"},
"Barbados":	{"NNS"},
"Basque":	{"NNP","JJ"},
"Bauhaus":	{"NNP","JJ"},
"Bavarian":	{"JJ","NNP"},
"Beaujolais":	{"NNP","NNPS"},
"Bedouins":	{"NNS"},
"Belarusian":	{"NNP","JJ"},
"Belgian":	{"JJ","NNP"},
"Belorussian":	{"NNP","JJ"},
"Benedictine":	{"NNP","JJ"},
"Benelux":	{"JJ"},
"Bengali":	{"JJ","NNP"},
"Berber":	{"NNP","JJ"},
"Berkeley":	{"NNP","NN"},
"Boheme":	{"NNP","FW"},
"Bohemian":	{"JJ","NNP"},
"Bolivian":	{"NNP","JJ"},
"Bologna":	{"NNP","NN"},
"Bolshevistic":	{"JJ"},
"Bosnian":	{"NNP","JJ"},
"Bostonian":	{"NNP","JJ"},
"Braille":	{"NNP","VB","VBP"},
"Brailled":	{"VBD","VBN"},
"Brasil":	{"JJ"},
"Brazilian":	{"JJ","NNP"},
"Brechtian":	{"JJ"},
"Britannic":	{"JJ"},
"British":	{"JJ","NNPS"},
"Britten":	{"NNP","NN"},
"Buddhism":	{"NN"},
"Buddhist":	{"NNP","JJ"},
"Bulgarian":	{"JJ","NNP"},
"Burgundian":	{"JJ"},
"Burmese":	{"JJ","NNP","NNPS"},
"Burundian":	{"JJ","NNP"},
"Byronic":	{"JJ"},
"Byzantine":	{"JJ","NNP"},
"CD":	{"NN"},
"CD-ROMs":	{"NNS"},
"CDs":	{"NNS"},
"COD":	{"NN"},
"CR":	{"NN"},
"CRs":	{"NNS"},
"Ca":	{"MD"},
"Caesarean":	{"NNP","JJ"},
"Cairns":	{"NNS"},
"Cajun":	{"JJ","NNP"},
"Californian":	{"NNP","JJ"},
"Callas":	{"NNS"},
"Calvinist":	{"NNP","JJ"},
"Calvinistic":	{"JJ"},
"Cambodian":	{"JJ","NNP"},
"Cambrian":	{"JJ","NNP"},
"Canadian":	{"JJ","NNP"},
"Cannes":	{"NNS"},
"Cantonese":	{"NNP","JJ","NNPS"},
"Capitoline":	{"NNP","JJ"},
"Caribbean":	{"NNP","JJ"},
"Carmelite":	{"JJ","NNP"},
"Caroline":	{"NNP","JJ"},
"Carolingian":	{"JJ"},
"Carolinian":	{"NNP","JJ"},
"Cartesian":	{"JJ"},
"Carthaginian":	{"NNP","JJ"},
"Caspian":	{"JJ"},
"Catholic":	{"NNP","JJ"},
"Cats":	{"NNS"},
"Caucasian":	{"JJ","NNP"},
"Celsius":	{"JJ","NNP"},
"Celtic":	{"JJ","NNP"},
"Centigrade":	{"JJ","NNP"},
"Chantilly":	{"NNP","JJ"},
"Chavez":	{"NNP","NN"},
"Chechen":	{"NNP","JJ"},
"Chekhovian":	{"JJ"},
"Chekovian":	{"JJ"},
"Cherokees":	{"NNS"},
"Chilean":	{"NNP","JJ"},
"Chinese":	{"JJ","NNP","NNPS"},
"Chinooks":	{"NNS"},
"Chippendale":	{"JJ"},
"Chrissake":	{"UH"},
"Christ":	{"NNP","UH"},
"Christian":	{"NNP","JJ"},
"Christlike":	{"JJ"},
"Churchillian":	{"JJ"},
"Ciceronian":	{"JJ"},
"Cinderella":	{"NNP","JJ"},
"Cleveland":	{"NNP","NN"},
"Colleagues":	{"NNS"},
"Colombian":	{"NNP","JJ"},
"Confucian":	{"NNP","JJ"},
"Congolese":	{"NNP","JJ"},
"Congregational":	{"JJ"},
"Copernican":	{"JJ"},
"Corinthian":	{"JJ","NNP"},
"Cornish":	{"JJ","NNP","NNPS"},
"Corsican":	{"NNP","JJ"},
"Cossack":	{"NNP","JJ"},
"Cretaceous":	{"JJ"},
"Cretan":	{"NNP","JJ"},
"Crimean":	{"JJ","NNP"},
"Croatian":	{"NNP","JJ"},
"Cromwellian":	{"JJ"},
"Cuban":	{"JJ","NNP"},
"Cubist":	{"NNP","JJ"},
"Cyclopean":	{"JJ"},
"Cyclopses":	{"NNS"},
"Cypriot":	{"NNP","JJ"},
"Czech":	{"NNP","JJ"},
"Czechoslovak":	{"JJ","NNP"},
"DT":	{"NN"},
"Dalglish":	{"NNP","JJ"},
"Damascene":	{"NNP","JJ"},
"Danish":	{"NNP","JJ"},
"Danubian":	{"JJ"},
"Darwinian":	{"JJ"},
"Democratic":	{"JJ"},
"Dickensian":	{"JJ"},
"Dionysian":	{"JJ"},
"Dominican":	{"NNP","JJ"},
"Doors":	{"NNS"},
"Dorchester":	{"NNP","NN"},
"Dorian":	{"NNP","JJ"},
"Doric":	{"JJ"},
"Dresden":	{"NNP","JJ"},
"Druids":	{"NNS"},
"Dulles":	{"NNP","NNS"},
"Dutch":	{"JJ","NNP","NNPS"},
"ECGs":	{"NNS"},
"East":	{"NNP","JJ","RB"},
"Ecuadorian":	{"JJ","NNP"},
"Eddard":	{"NN"},
"Edwardian":	{"JJ"},
"Egyptian":	{"JJ","NNP"},
"Einsteinian":	{"JJ"},
"Elizabethan":	{"NNP","JJ"},
"English":	{"NNP","NNPS","JJ"},
"English-speaking":	{"JJ"},
"Eocene":	{"NNP","JJ"},
"Episcopalian":	{"JJ","NNP"},
"Ericsson":	{"NNP","NN"},
"Eritrean":	{"JJ","NNP"},
"Eros":	{"NNS"},
"Eskimo":	{"NNP","NNPS"},
"Esthonian":	{"NNP","JJ"},
"Estonian":	{"JJ","NNP"},
"Ethiopia":	{"NNP","JJ"},
"Ethiopian":	{"JJ","NNP"},
"Etonian":	{"NNP","JJ"},
"Eucharistic":	{"JJ"},
"Euclidean":	{"JJ"},
"Euclidian":	{"JJ"},
"Eurasian":	{"JJ","NNP"},
"Eurocentric":	{"JJ"},
"European":	{"JJ","NNP"},
"Fabian":	{"NNP","JJ"},
"Faeroese":	{"JJ","NNP","NNPS"},
"Fahrenheit":	{"NNP","JJ"},
"Faulknerian":	{"JJ"},
"Faustian":	{"JJ"},
"Fijian":	{"JJ","NNP"},
"Filipino":	{"JJ","NNP"},
"Finnish":	{"NNP","JJ"},
"Flemish":	{"NNP","JJ"},
"Florentine":	{"NNP","JJ"},
"Floridian":	{"NNP","JJ"},
"Formica":	{"NN"},
"Formosan":	{"JJ"},
"Franciscan":	{"JJ","NNP"},
"Francophobe":	{"NNP","JJ"},
"Francophone":	{"JJ","NNP"},
"French":	{"JJ","NNP","NNPS"},
"French-fry":	{"JJ"},
"French-speaking":	{"JJ"},
"Frenchification":	{"NN"},
"Frenchified":	{"VBD","VBN"},
"Frenchifies":	{"VBZ"},
"Frenchify":	{"VB","VBP"},
"Frenchifying":	{"VBG"},
"Freudian":	{"NN","JJ"},
"Frisian":	{"JJ","NNP"},
"Furies":	{"NNS"},
"Gabonese":	{"JJ","NNP","NNPS"},
"Gaelic":	{"NNP","JJ"},
"Galilean":	{"JJ","NNP"},
"Gallic":	{"JJ"},
"Gambian":	{"JJ","NNP"},
"Gangetic":	{"JJ"},
"Gaussian":	{"JJ"},
"Geminean":	{"JJ","NNP"},
"Gentile":	{"JJ","NNP"},
"Georgian":	{"JJ","NNP"},
"German":	{"JJ","NNP"},
"German-speaking":	{"JJ"},
"Germanic":	{"JJ"},
"Geronimo":	{"NNP","UH"},
"Ghanaian":	{"NNP","JJ"},
"Gibraltarian":	{"JJ","NNP"},
"Glaswegian":	{"JJ","NNP"},
"God":	{"NNP","UH"},
"God-fearing":	{"JJ"},
"God-forsaken":	{"JJ"},
"God-given":	{"JJ"},
"Godspeed":	{"NNP","UH"},
"Gordian":	{"JJ"},
"Gothic":	{"JJ","NNP"},
"Grace":	{"NNP","NN"},
"Grand":	{"JJ"},
"Grecian":	{"JJ","NNP"},
"Greek":	{"NNP","JJ"},
"Gregorian":	{"JJ"},
"Grenadian":	{"JJ"},
"Guatemalan":	{"JJ","NNP"},
"Guinean":	{"JJ","NNP"},
"Guyanese":	{"JJ","NNP"},
"HDTV":	{"NN"},
"HDTVs":	{"NNS"},
"HMOs":	{"NNS"},
"HQ":	{"NN"},
"Habsburg":	{"NNP","JJ"},
"Haitian":	{"JJ","NNP"},
"Hamiltonian":	{"NNP","JJ"},
"Hanoverian":	{"NNP","JJ"},
"Hapsburg":	{"NNP","JJ"},
"Hasidic":	{"JJ"},
"Hawaiian":	{"JJ","NNP"},
"Hebraic":	{"JJ"},
"Hebrew":	{"NNP","JJ"},
"Hebridean":	{"JJ"},
"Hellenic":	{"NNP","JJ"},
"Hellenistic":	{"JJ"},
"Hereby":	{"RB"},
"Herr":	{"NNP","FW"},
"High-Church":	{"JJ"},
"High-Churchman":	{"NN"},
"High-Churchmen":	{"NNS"},
"Himalayan":	{"JJ"},
"Hindi":	{"JJ","NNP"},
"Hindoo":	{"NNP","JJ"},
"Hindu":	{"NNP","JJ"},
"Hindustani":	{"JJ","NNP"},
"Hispanic":	{"JJ","NNP"},
"Homeric":	{"JJ"},
"Honduran":	{"JJ","NNP"},
"Hopi":	{"NNP","NNPS","JJ"},
"Hottentot":	{"NNP","JJ","NNPS"},
"House":	{"NN"},
"Hungarian":	{"NNP","JJ"},
"Hz":	{"NN"},
"I":	{"PRP","NN","SYM"},
"ID":	{"NN","VB","VBP"},
"IDed":	{"VBD","VBN"},
"IDing":	{"VBG"},
"IDs":	{"NNS","VBZ"},
"IMO":	{"RB"},
"IOU":	{"NN"},
"IOUs":	{"NNS"},
"IQ":	{"NN"},
"IQs":	{"NNS"},
"ISP":	{"NN"},
"ISPs":	{"NNS"},
"IUD":	{"NN"},
"IUDs":	{"NNS"},
"Iberian":	{"JJ","NNP"},
"Icelandic":	{"JJ","NNP"},
"Idahoan":	{"NNP","JJ"},
"Implements":	{"NNS"},
"Implores":	{"VBZ"},
"Impressionist":	{"NN","JJ"},
"Inca":	{"NNP","NNPS"},
"Incan":	{"JJ"},
"Incorporated":	{"JJ"},
"Ind":	{"JJ","NNP"},
"Indian":	{"NNP","JJ"},
"Indic":	{"JJ"},
"Indo-European":	{"JJ"},
"Indochinese":	{"JJ","NNP","NNPS"},
"Indonesian":	{"NNP","JJ"},
"Indy":	{"NNP","FW"},
"Instagram":	{"NNP","VB","VBP"},
"Instagrammed":	{"VBD","VBN"},
"Instagramming":	{"VBG"},
"Instagrams":	{"VBZ"},
"International":	{"NNP","JJ"},
"Inuit":	{"NNP","JJ","NNPS"},
"Ionic":	{"JJ"},
"Iowan":	{"NNP","JJ"},
"Iranian":	{"JJ","NNP"},
"Iraqi":	{"NNP","JJ"},
"Irish":	{"JJ","NNP","NNPS"},
"Iroquoian":	{"JJ"},
"Islamic":	{"JJ"},
"Islamisation":	{"NN"},
"Islamise":	{"VB","VBP"},
"Islamised":	{"VBD","VBN"},
"Islamises":	{"VBZ"},
"Islamising":	{"VBG"},
"Islamization":	{"NN"},
"Islamize":	{"VB","VBP"},
"Islamized":	{"VBD","VBN"},
"Islamizes":	{"VBZ"},
"Islamizing":	{"VBG"},
"Israeli":	{"JJ","NNP"},
"Israelite":	{"NNP","JJ"},
"Italian":	{"JJ","NNP"},
"Italianate":	{"JJ"},
"JFK":	{"NN"},
"Jacksonian":	{"NNP","JJ"},
"Jacobean":	{"JJ"},
"Jacobinism":	{"NN"},
"Jacobite":	{"NNP","JJ"},
"Jamaican":	{"NNP","JJ"},
"Jamesian":	{"JJ"},
"Janus-faced":	{"JJ"},
"Jap":	{"NNP","JJ"},
"Japanese":	{"JJ","NNP","NNPS"},
"Javanese":	{"NNP","JJ"},
"Jeffersonian":	{"JJ","NNP"},
"Jesuitic":	{"JJ"},
"Jesuitical":	{"JJ"},
"Jesus":	{"NNP","UH"},
"Jewish":	{"JJ"},
"Joes":	{"NNS"},
"Joliet":	{"NN"},
"Joneses":	{"NNS"},
"Jordanian":	{"NNP","JJ"},
"Jovian":	{"JJ"},
"Judaic":	{"JJ"},
"Julian":	{"NNP","JJ"},
"Jungian":	{"NNP","JJ"},
"Junior":	{"JJ"},
"Junoesque":	{"JJ"},
"Jurassic":	{"NNP","JJ"},
"Jutish":	{"JJ","NNP"},
"KC":	{"NN"},
"KC-135s":	{"NNS"},
"KCs":	{"NNS"},
"KLM-controlled":	{"JJ"},
"KO":	{"NN","VB","VBP"},
"KO'd":	{"VBD","VBN"},
"KO's":	{"NNS","VBZ"},
"Kansan":	{"NNP","JJ"},
"Kantian":	{"JJ","NNP"},
"Kashmiri":	{"JJ","NNP"},
"Kee-reist":	{"UH"},
"Keeeerist":	{"UH"},
"Keep":	{"VB"},
"Keepers":	{"NNS"},
"Keeps":	{"VBZ"},
"Keerist":	{"UH"},
"Kelvin":	{"NNP","JJ"},
"Kennedyesque":	{"JJ"},
"Kentuckian":	{"NNP","JJ"},
"Kenyan":	{"NNP","JJ"},
"Kerkorian-owned":	{"JJ"},
"Kern":	{"NNP","NN"},
"Keynesian":	{"JJ","NNP"},
"Keynotes":	{"NNS"},
"Kibbutzniks":	{"NNS"},
"Kindertotenlieder":	{"FW"},
"Kingdom-based":	{"JJ"},
"Kisha":	{"FW"},
"Kissing":	{"VBG"},
"Klaus":	{"NNS"},
"Kleenex":	{"NNP","NNPS"},
"Kneeling":	{"VBG"},
"Know-nothings":	{"NNS"},
"Knowing":	{"VBG"},
"Knowledgeable":	{"JJ"},
"Known":	{"VBN"},
"Knox-like":	{"JJ"},
"Knut":	{"NN"},
"Kofanes":	{"NNS"},
"Kohi":	{"FW"},
"Kohnstamm-negative":	{"JJ"},
"Kong-dollar":	{"NN"},
"Koranic":	{"JJ"},
"Korean":	{"JJ","NNP"},
"Korobytsins":	{"NNS"},
"Krauts":	{"NNS"},
"Krishnaists":	{"NNS"},
"Krist":	{"UH"},
"Kristallstrukturen":	{"FW"},
"Kurdish":	{"NNP","JJ"},
"Kuwaiti":	{"NNP","JJ"},
"Ky.-based":	{"JJ"},
"L-shaped":	{"JJ"},
"LBO-related":	{"JJ"},
"LCD":	{"NN"},
"LCDs":	{"NNS"},
"LF":	{"NN"},
"LP":	{"NN"},
"LPs":	{"NNS"},
"LSO":	{"NN"},
"LV":	{"NN"},
"LYONs":	{"NNS"},
"La-la-landers":	{"NNS"},
"Laboring":	{"VBG"},
"Lackluster":	{"JJ"},
"Lady":	{"NNP","NN"},
"Lags":	{"VBZ"},
"Lamarckian":	{"JJ","NN"},
"Lamarckism":	{"NN"},
"Land-based":	{"JJ"},
"Landers":	{"NNS"},
"Landowners":	{"NNS"},
"Lanes":	{"NNS"},
"Lanvin-owned":	{"JJ"},
"Lao":	{"NNP","JJ","NNPS"},
"Laodicean":	{"JJ","NNP"},
"Laotian":	{"JJ","NNP"},
"Laotians":	{"NNS"},
"Lappish":	{"NNP","JJ"},
"Laptops":	{"NNS"},
"Large-deposit":	{"JJ"},
"Large-package":	{"JJ"},
"Large-screen":	{"JJ"},
"Largely":	{"RB"},
"Lars":	{"NNS"},
"Lasers":	{"NNS"},
"Lately":	{"RB"},
"Latest-quarter":	{"JJ"},
"Latin":	{"NNP","JJ","NNPS"},
"Latin-American":	{"JJ","NNP"},
"Latinise":	{"VB","VBP"},
"Latinised":	{"VBD","VBN"},
"Latinises":	{"VBZ"},
"Latinising":	{"VBG"},
"Latinism":	{"NN"},
"Latinist":	{"NN"},
"Latinize":	{"VB","VBP"},
"Latinized":	{"VBD","VBN"},
"Latinizes":	{"VBZ"},
"Latinizing":	{"VBG"},
"Latino":	{"NNP","JJ"},
"Latino-American":	{"NNP","JJ"},
"Latinos":	{"NNPS","NNS","NNP","JJ","RB"},
"Latvian":	{"JJ","NNP"},
"Laudably":	{"RB"},
"Laundered":	{"VBN"},
"Lawful":	{"JJ"},
"Lazybones":	{"NNS"},
"Leads":	{"VBZ"},
"Leaguers":	{"NNS"},
"Leaping":	{"VBG"},
"Least-cost":	{"JJ"},
"Leave":	{"VB"},
"Leaving":	{"VBG"},
"Lebanese":	{"JJ","NNP","NNPS"},
"Lebanese-controlled":	{"JJ"},
"Lee-based":	{"JJ"},
"Leeches":	{"NNS"},
"Leeds":	{"NNS"},
"Leery":	{"JJ"},
"Lees":	{"NNS"},
"Left-stream":	{"JJ"},
"Leftovers":	{"NNS"},
"Legislators":	{"NNS"},
"Legislatures":	{"NNS"},
"Legs":	{"NNS"},
"Leisurely":	{"RB"},
"Lemme":	{"VB"},
"Lend":	{"VB"},
"Lengthening":	{"VBG"},
"Lenten":	{"JJ"},
"Less-than-truckload":	{"JJ"},
"Lessening":	{"VBG"},
"Letting":	{"VBG"},
"Levantine":	{"JJ","NNP"},
"Levitical":	{"JJ"},
"Lexington-based":	{"JJ"},
"Liaisons":	{"NNS"},
"Libera":	{"FW"},
"Liberal":	{"NNP","JJ"},
"Liberals":	{"NNS"},
"Liberian":	{"NNP","JJ"},
"Libertines":	{"NNS"},
"Libran":	{"NN","JJ"},
"Librarians":	{"NNS"},
"Libyan":	{"NNP","JJ"},
"Liechtensteiner":	{"JJ","NNP"},
"Life-preservers":	{"NNS"},
"Likening":	{"VBG"},
"Likewise":	{"RB"},
"Lilliputian":	{"JJ"},
"Limiting":	{"VBG"},
"Line-item":	{"JJ"},
"Linger":	{"VB"},
"Linguists":	{"NNS"},
"Linking":	{"VBG"},
"Lips":	{"NNS"},
"Listeners":	{"NNS"},
"Listening":	{"NN","VBG"},
"Literally":	{"RB"},
"Lithuanian":	{"JJ"},
"Litigants":	{"NNS"},
"Live-In":	{"NN"},
"Lived":	{"VBD","VBN"},
"Liverpudlian":	{"NNP","JJ"},
"Lobbyists":	{"NNS"},
"Locally":	{"RB"},
"Located":	{"VBN"},
"Lockian":	{"JJ"},
"Locking":	{"VBG"},
"Loftier":	{"JJR"},
"Logically":	{"RB"},
"Lollipops":	{"NNS"},
"London-bred":	{"JJ"},
"Long-debated":	{"JJ"},
"Long-haul":	{"JJ"},
"Long-lived":	{"JJ"},
"Lookit":	{"VB"},
"Looks":	{"NNS"},
"Looky":	{"VB"},
"Looming":	{"VBG"},
"Loopholes":	{"NNS"},
"Losers":	{"NNS"},
"Lots":	{"NNS"},
"Loudspeakers":	{"NNS"},
"Louis-based":	{"JJ"},
"Louisianian":	{"NNP","JJ"},
"Lovie":	{"UH"},
"Lovingly":	{"RB"},
"Low-flying":	{"JJ"},
"Low-interest-rate":	{"JJ"},
"Low-paying":	{"JJ"},
"Lower":	{"JJR"},
"Lower-than-expected":	{"JJ"},
"Loyalist":	{"NNP","JJ"},
"Lubberlanders":	{"NNS"},
"Lucullan":	{"JJ"},
"Luigi":	{"NNS"},
"Lumped":	{"VBN"},
"Lutheran":	{"NNP","JJ"},
"Luxembourg-based":	{"JJ"},
"Luxembourg-registered":	{"JJ"},
"Lyme-disease":	{"JJ"},
"Lynch-led":	{"JJ"},
"Lyons":	{"NNS"},
"M-m-m":	{"UH"},
"M.D.-speak":	{"JJ"},
"M.D.s":	{"NNS"},
"M.I.T.-trained":	{"JJ"},
"MAHT":	{"NN"},
"MATLAB":	{"NN"},
"MBAs":	{"NNS"},
"MC":	{"NN"},
"MD":	{"NN"},
"MD-80-series":	{"NN"},
"MD-80s":	{"NNS"},
"MD-90s":	{"NNS"},
"MDs":	{"NNS"},
"MF":	{"NN"},
"MFA":	{"NN"},
"MHz":	{"NNS"},
"MIA":	{"NN"},
"MIAs":	{"NNS"},
"MIPS-based":	{"JJ"},
"MLitt":	{"NN"},
"MP":	{"NN"},
"MPs":	{"NNS"},
"MRI-type":	{"JJ"},
"MSX-run":	{"JJ"},
"MSc":	{"NN"},
"MVP":	{"NN"},
"MVPs":	{"NNS"},
"Mace":	{"NNP","NN"},
"Macedonian":	{"JJ","NNP"},
"Mach":	{"NN"},
"Machiavellian":	{"JJ"},
"Machine-tool":	{"JJ"},
"Machine-vision":	{"JJ"},
"Macrobians":	{"NNS"},
"Macrophages":	{"NNS"},
"Madagascan":	{"JJ","NNP"},
"Mademoiselles":	{"NNS"},
"Madrid-based":	{"JJ"},
"Mae-backed":	{"JJ"},
"Mafia-tainted":	{"JJ"},
"Magian":	{"NNP","JJ"},
"Magnolias":	{"NNS"},
"Magyar":	{"JJ","NNP"},
"Mail-Order":	{"JJ"},
"Mailings":	{"NNS"},
"Mainly":	{"RB"},
"Maintain":	{"VB"},
"Makes":	{"VBZ"},
"Malawian":	{"JJ","NNP"},
"Malay":	{"NNP","JJ"},
"Malay-based":	{"JJ"},
"Malaysian":	{"NNP","JJ"},
"Malaysian-based":	{"JJ"},
"Maldivian":	{"NNP","JJ"},
"Malian":	{"JJ","NNP"},
"Maltese":	{"NNP","JJ","NNPS"},
"Malthusian":	{"JJ","NNP"},
"Mammograms":	{"NNS"},
"Manchu":	{"NNP","JJ"},
"Mancunian":	{"JJ","NN"},
"Mancunians":	{"NNS"},
"Manhattan-based":	{"JJ"},
"Manichaean":	{"JJ","NN"},
"Manichaeanism":	{"NN"},
"Manila-based":	{"JJ"},
"Manitoba-based":	{"JJ"},
"Manners":	{"NNS"},
"Manufactured":	{"VBD","VBN"},
"Manx":	{"NNP","JJ"},
"Maoist":	{"JJ"},
"Maoist-style":	{"JJ"},
"Maori":	{"NNP","JJ"},
"Marian":	{"NNP","JJ"},
"Marinas":	{"NNS"},
"Market-based":	{"JJ"},
"Market-if-touched":	{"JJ"},
"Marketed":	{"VBN"},
"Maronite":	{"JJ"},
"Marques":	{"NNS"},
"Marruecos":	{"FW"},
"Marseille":	{"FW"},
"Marseilles":	{"NNS"},
"Martian":	{"NNP","JJ"},
"Martin-type":	{"JJ"},
"Marxist":	{"JJ","NNP"},
"Marxist-Leninist":	{"JJ","NNP"},
"Marxist-dominated":	{"JJ"},
"Masonic":	{"JJ"},
"Masons":	{"NNS"},
"Massachuset":	{"NNP","NNPS"},
"Massachusett":	{"NNP","NNPS"},
"MasterCards":	{"NNS"},
"Matchbook-sized":	{"JJ"},
"Matsushita-made":	{"JJ"},
"Matsushita-owned":	{"JJ"},
"Mauritanian":	{"JJ","NNP"},
"Mauritian":	{"JJ","NNP"},
"Mauve-colored":	{"JJ"},
"Maya":	{"NNP","NNPS","JJ"},
"Mayan":	{"JJ","NNP"},
"Mayhap":	{"RB"},
"Mayors":	{"NNS"},
"McCarthy-era":	{"JJ"},
"McFeely":	{"RB"},
"Mead":	{"NNP","NN"},
"Meager":	{"JJ"},
"Meaningful":	{"JJ"},
"Meanings":	{"NNS"},
"Meanwhile":	{"RB"},
"Meanwile":	{"RB"},
"Measured":	{"VBN"},
"Measures":	{"NNS"},
"Meatheads":	{"NNS"},
"Medicaid-covered":	{"JJ"},
"Medicaid-paid":	{"JJ"},
"Medical-instrument":	{"JJ"},
"Medical-supply":	{"JJ"},
"Medicare-approved":	{"JJ"},
"Medicare-catastrophic-care":	{"JJ"},
"Medicare-eligible":	{"JJ"},
"Mediterranean":	{"NNP","JJ"},
"Mediterranean-inspired":	{"JJ"},
"Mediumistic":	{"JJ"},
"Meetings":	{"NNS"},
"Mega-hits":	{"NNS"},
"Meinung":	{"FW"},
"Melanesian":	{"NNP","JJ"},
"Melbourne-based":	{"JJ"},
"Melodious":	{"JJ"},
"Melodramatic":	{"JJ"},
"Melted":	{"VBN"},
"Mementoes":	{"NNS"},
"Memoirs":	{"NNS"},
"Memorials":	{"NNS"},
"Mendelian":	{"JJ"},
"Mennonite":	{"JJ","NNP"},
"Mercantilists":	{"NNS"},
"Merited":	{"JJ"},
"Merits":	{"NNS"},
"Messengers":	{"NNS"},
"Methodist":	{"NNP","JJ"},
"Metrically":	{"RB"},
"Meurons":	{"NNS"},
"Mexican":	{"JJ","NNP"},
"Mexican-food":	{"JJ"},
"Mexico-based":	{"JJ"},
"Mexico-watchers":	{"NNS"},
"MiG-29s":	{"NNS"},
"Miami-based":	{"JJ"},
"Mice":	{"NNS"},
"Micelles":	{"NNS"},
"Mich.-based":	{"JJ"},
"Michigan-based":	{"JJ"},
"Micronesian":	{"NNP","JJ"},
"Microorganisms":	{"NNS"},
"Microphones":	{"NNS"},
"Microscopes":	{"NNS"},
"Microscopically":	{"RB"},
"Microwaves":	{"NNS"},
"Mid-sized":	{"JJ"},
"Midas":	{"NNS"},
"Middle-Eastern":	{"JJ"},
"Middle-aged":	{"JJ"},
"Mideastern":	{"JJ"},
"Midwestern":	{"JJ"},
"Midwesterners":	{"NNS"},
"Migs":	{"NNS"},
"Milan-based":	{"JJ"},
"Milanese":	{"JJ","NNP"},
"Mildred":	{"VBD","VBN"},
"Million-dollar":	{"JJ"},
"Millions":	{"NNS"},
"Milquetoasts":	{"NNS"},
"Miltonic":	{"JJ"},
"Milwaukee-based":	{"JJ"},
"Minister":	{"NN"},
"Minn.-based":	{"JJ"},
"Minneapolis-based":	{"JJ"},
"Minuses":	{"NNS"},
"Miraculously":	{"RB"},
"Mired":	{"JJ","VBN","VBD"},
"Miscellaneous":	{"JJ"},
"Misconceptions":	{"NNS"},
"Misdemeanors":	{"NNS"},
"Miserables":	{"FW"},
"Missions":	{"NNS"},
"Mississippians":	{"NNS"},
"Mixtec":	{"JJ"},
"Mmm":	{"UH"},
"Mmmm":	{"UH"},
"Mo.-based":	{"JJ"},
"Mobs":	{"NNS"},
"Models":	{"NNS"},
"Moderating":	{"VBG"},
"Modern":	{"JJ"},
"Modest":	{"JJ"},
"Modestly":	{"RB"},
"Modifications":	{"NNS"},
"Mohammedan":	{"JJ","NN"},
"Mohican":	{"NNP","JJ"},
"Moines-based":	{"JJ"},
"Moldovan":	{"JJ","NNP"},
"Mollusks":	{"NNS"},
"Momentarily":	{"RB"},
"Mon":	{"NN"},
"Monarque":	{"FW"},
"Monday-morning":	{"JJ"},
"Monetary":	{"JJ"},
"Money-making":	{"JJ"},
"Moneyed":	{"JJ"},
"Mongol":	{"JJ","NNP"},
"Mongolian":	{"NNP","JJ"},
"Mongoloid":	{"NNP","JJ"},
"Mono-unsaturated":	{"JJ"},
"Monsieur":	{"NN"},
"Montanan":	{"NNP","JJ"},
"Monterrey-based":	{"JJ"},
"Months":	{"NNS"},
"Montreal-Toronto":	{"JJ"},
"Montreal-based":	{"JJ"},
"Montserratian":	{"JJ","NNP"},
"Moon-faced":	{"JJ"},
"Moorish":	{"JJ"},
"Morals":	{"NNS"},
"More-detailed":	{"JJR"},
"Morever":	{"RB"},
"Mormon":	{"NNP","JJ"},
"Moroccan":	{"NNP","JJ"},
"Morover":	{"JJR"},
"Morphophonemic":	{"JJ"},
"Mortals":	{"NNS"},
"Mortars":	{"NNS"},
"Mosaic":	{"JJ"},
"Moscow-Shannon":	{"JJ"},
"Moscow-allied":	{"JJ"},
"Moscow-based":	{"JJ"},
"Moslem":	{"NNP","JJ"},
"Most-Favored":	{"JJS"},
"Most-Remarkable":	{"JJS"},
"Most-recommended":	{"JJ"},
"Motion-picture":	{"JJ"},
"Motorcycles":	{"NNS"},
"Motorists":	{"NNS"},
"Motorized":	{"VBD","VBN"},
"Movements":	{"NNS"},
"Moves":	{"NNS"},
"Mozambiquean":	{"NNP","JJ"},
"Mrads":	{"NNS"},
"Msec.":	{"NNS"},
"Mt":	{"NN"},
"Muenster":	{"NN"},
"Muffling":	{"VBG"},
"Muhammadan":	{"JJ","NNP"},
"Muhammedan":	{"JJ","NNP"},
"Multi-employer":	{"JJ"},
"Multiplexers":	{"NNS"},
"Muni":	{"JJ"},
"Munich-based":	{"JJ"},
"Murderers":	{"NNS"},
"Muscovite":	{"NNP","JJ"},
"Museums":	{"NNS"},
"Muslim":	{"NNP","JJ"},
"Mussolini-like":	{"JJ"},
"Mutants":	{"NNS"},
"Mutinies":	{"NNS"},
"Muzzling":	{"JJ"},
"Mycenaean":	{"JJ"},
"Mythical":	{"JJ"},
"Mythological":	{"JJ"},
"N-no":	{"UH"},
"N.C.-based":	{"JJ"},
"N.M.-based":	{"JJ"},
"N.Y.-based":	{"JJ"},
"NATO-led":	{"JJ"},
"NBC-owned":	{"JJ"},
"NCAAs":	{"NNS"},
"NEC-compatible":	{"JJ"},
"NGO":	{"NN"},
"NGOs":	{"NNS"},
"NI":	{"NN"},
"NIH-appointed":	{"JJ"},
"NT-proBNP":	{"NN"},
"Nacht":	{"FW"},
"Naderites":	{"NNS"},
"Nae":	{"UH"},
"Named":	{"VBN"},
"Namibian":	{"JJ"},
"Napkins":	{"NNS"},
"Naples":	{"NNS"},
"Naples-born":	{"JJ"},
"Napoleonic":	{"JJ"},
"Narrow-gauged":	{"JJ"},
"Nasdaq-traded":	{"JJ"},
"National":	{"NNP","JJ"},
"Nationalistic":	{"JJ"},
"Nationalized":	{"VBN"},
"Nations-monitored":	{"JJ"},
"Nattily":	{"RB"},
"Naturally":	{"RB"},
"Naturam":	{"FW"},
"Nauruan":	{"JJ","NNP"},
"Nazi":	{"NNP","JJ"},
"Nazi-minded":	{"JJ"},
"Nazi-occupied":	{"JJ"},
"Nazified":	{"VBD","VBN"},
"Nazifies":	{"VBZ"},
"Nazify":	{"VB","VBP"},
"Nazifying":	{"VBG"},
"Naziism":	{"NN"},
"Nazism":	{"NN"},
"Ne":	{"NN"},
"Neanderthal":	{"JJ"},
"Neapolitan":	{"NNP","JJ"},
"Near-Term":	{"RB"},
"Near-term":	{"JJ"},
"Nearly":	{"RB"},
"Neb.-based":	{"JJ"},
"Nebraska":	{"NNP","NN"},
"Nebraskan":	{"NNP","JJ"},
"Nec":	{"FW"},
"Ned":	{"VBD","VBN"},
"Needs":	{"NNS"},
"Negotiable":	{"JJ"},
"Negotiations":	{"NNS"},
"Negotiators":	{"NNS"},
"Negress":	{"NN"},
"Negresses":	{"NNS"},
"Negro-appeal":	{"JJ"},
"Negroes":	{"NNS"},
"Negroid":	{"JJ","NNP"},
"Nencrypted":	{"JJ"},
"Neoliberal":	{"JJ"},
"Nepalese":	{"NN","JJ"},
"Nerves":	{"NNS"},
"Netherlands-based":	{"JJ"},
"Network-access":	{"JJ"},
"Neuroscientists":	{"NNS"},
"Nevadan":	{"NNP","JJ"},
"Nevertheless":	{"RB"},
"New-home":	{"JJ"},
"New-issue":	{"JJ"},
"Newcomers":	{"NNS"},
"Newly":	{"RB"},
"Newport-based":	{"JJ"},
"Newspapermen":	{"NNS"},
"Newsstands":	{"NNS"},
"Newtonian":	{"JJ"},
"Next-Most-Remarkable":	{"JJ"},
"Nfamous":	{"JJ"},
"NiCad":	{"NN"},
"Nicaraguan":	{"JJ","NNP"},
"Niche-itis":	{"NNS"},
"Nickel-iron":	{"JJ"},
"Nigerian":	{"JJ","NNP"},
"Nine-month":	{"JJ"},
"Nineteen":	{"CD"},
"Nineteenth-century":	{"JJ"},
"Ninety":	{"CD"},
"Nipponese":	{"JJ"},
"Nmeaningful":	{"JJ"},
"No-o-o":	{"UH"},
"No.":	{"NN"},
"No.3":	{"JJ"},
"Nodding":	{"VBG"},
"Nominations":	{"NNS"},
"Non-Catholics":	{"NNS"},
"Non-God":	{"UH"},
"Non-actors":	{"NNS"},
"Non-bank":	{"JJ"},
"Non-callable":	{"JJ"},
"Non-clients":	{"NNS"},
"Non-cosmetic":	{"JJ"},
"Non-executive":	{"JJ"},
"Non-interest":	{"JJ"},
"Non-lawyers":	{"NNS"},
"Non-money":	{"JJ"},
"Non-performing":	{"JJ"},
"Non-residential":	{"JJ"},
"Non-smoking":	{"NN"},
"Non-steel":	{"JJ"},
"Non-subscribers":	{"NNS"},
"Nonbuilding":	{"JJ"},
"Nonconformist":	{"NN","JJ"},
"Nonconformists":	{"NNS"},
"Nonelectrical":	{"JJ"},
"Nonetheless":	{"RB"},
"Nonfinancial":	{"JJ"},
"Nonperformers":	{"NNS"},
"Nonrecurring":	{"JJ"},
"Nonresident":	{"JJ"},
"Nonresidential":	{"JJ"},
"Nonspecific":	{"JJ"},
"Norcross":	{"NNS"},
"Nordic":	{"JJ"},
"Noriegan":	{"JJ"},
"Noriegas":	{"NNS"},
"Norman":	{"NNP","JJ"},
"Norms":	{"NNS"},
"Norse":	{"JJ","NNP"},
"North":	{"NNP","JJ","RB"},
"Northeast":	{"NNP","JJ","RB"},
"Northeastern":	{"JJ"},
"Northern":	{"JJ"},
"Northumbrian":	{"NNP","JJ"},
"Northwest":	{"NNP","JJ","RB"},
"Northwestern":	{"JJ"},
"Norwegian":	{"JJ","NNP"},
"Nos":	{"NNS"},
"Nos.":	{"NNS"},
"Not-held":	{"JJ"},
"Notably":	{"RB"},
"Noting":	{"VBG"},
"Notitia":	{"NNS"},
"Nouns":	{"NNS"},
"Nourishing":	{"JJ"},
"Nowadays":	{"RB"},
"Nozze":	{"FW"},
"Nsustainability":	{"NN"},
"Ntrusted":	{"JJ"},
"Nubian":	{"NNP","JJ"},
"Nucor-like":	{"JJ"},
"Nuf":	{"RB"},
"Nuggets":	{"NNS"},
"Numerous":	{"JJ"},
"Nurses":	{"NNS"},
"Nutritionists":	{"NNS"},
"Nutritious":	{"JJ"},
"Nymphomaniacs":	{"NNS"},
"OCC-member":	{"JJ"},
"OD":	{"VB","VBP","NN"},
"OD'd":	{"VBD","VBN"},
"OD'ing":	{"VBG"},
"OD's":	{"VBZ","NNS"},
"OED":	{"NN"},
"OK":	{"UH","JJ","RB","VB","VBP","NN"},
"OL":	{"NN"},
"OSF":	{"IN"},
"OSHA":	{"NN"},
"OTC":	{"JJ"},
"OTC-market":	{"JJ"},
"Oaks":	{"NNS"},
"Oases":	{"NNS"},
"Oats":	{"NNS"},
"Obeying":	{"VBG"},
"Objections":	{"NNS"},
"Obligations":	{"NNS"},
"Obligingly":	{"RB"},
"Observers":	{"NNS"},
"Observing":	{"VBG"},
"Obstacles":	{"NNS"},
"Obviously":	{"RB"},
"Occasionally":	{"RB"},
"Occidentalisation":	{"NN"},
"Occidentalise":	{"VB","VBP"},
"Occidentalised":	{"VBD","VBN"},
"Occidentalises":	{"VBZ"},
"Occidentalising":	{"VBG"},
"Occidentalization":	{"NN"},
"Occidentalize":	{"VB","VBP"},
"Occidentalized":	{"VBD","VBN"},
"Occidentalizes":	{"VBZ"},
"Occidentalizing":	{"VBG"},
"Odd-lot":	{"JJ"},
"Odd-year":	{"JJ"},
"Oddly":	{"RB"},
"Odds":	{"NNS"},
"Off":	{"IN"},
"Off-price":	{"JJ"},
"Off-season":	{"JJ"},
"Offenses":	{"NNS"},
"Offers":	{"VBZ"},
"Offsetting":	{"VBG"},
"Oh-the-pain-of-it":	{"UH"},
"Ohio-based":	{"JJ"},
"Ohio-chartered":	{"JJ"},
"Oil-field":	{"NN"},
"Oil-related":	{"JJ"},
"Oilfields":	{"NNS"},
"Oils":	{"NNS"},
"Oklahoman":	{"NNP","JJ"},
"Ol":	{"JJ"},
"Old-time":	{"JJ"},
"Old-timers":	{"NNS"},
"Oleanders":	{"NNS"},
"Olympiad":	{"NN"},
"Olympian":	{"NNP","JJ"},
"Olympic":	{"JJ"},
"Omani":	{"JJ","NNP"},
"Once-only":	{"JJ"},
"Oncogenes":	{"NNS"},
"One-Horse":	{"JJ"},
"One-armed":	{"JJ"},
"One-day":	{"JJ"},
"One-inch":	{"JJ"},
"One-time":	{"JJ"},
"Onleh":	{"RB"},
"Onlookers":	{"NNS"},
"Onsets":	{"NNS"},
"Onstage":	{"RB"},
"Oooo":	{"UH"},
"Oops":	{"UH"},
"Opaque":	{"JJ"},
"Open-end":	{"JJ"},
"Open-flame":	{"JJ"},
"Operating-system":	{"JJ"},
"Operational":	{"JJ"},
"Operationally":	{"RB"},
"Opponents":	{"NNS"},
"Opposed":	{"VBN"},
"Oppressive":	{"JJ"},
"Optical-storage":	{"JJ"},
"Optimists":	{"NNS"},
"Ordinarily":	{"RB"},
"Ordovician":	{"JJ","NN"},
"Ore.-based":	{"JJ"},
"Organizational":	{"JJ"},
"Organizations":	{"NNS"},
"Organizers":	{"NNS"},
"Originals":	{"NNS"},
"Orleans-based":	{"JJ"},
"Orphic":	{"JJ"},
"Orthodontic":	{"JJ"},
"Orwellian":	{"JJ"},
"Ostentatious":	{"JJ"},
"Ostriches":	{"NNS"},
"Otherwise":	{"RB"},
"Ought":	{"MD"},
"Ours":	{"PRP"},
"Outbreaks":	{"NNS"},
"Outflows":	{"NNS"},
"Outgoing":	{"JJ"},
"Outlays":	{"NNS"},
"Outlooks":	{"NNS"},
"Outputs":	{"NNS"},
"Outraged":	{"JJ"},
"Outright":	{"JJ"},
"Outrunning":	{"VBG"},
"Outsiders":	{"NNS"},
"Outwardly":	{"RB"},
"Ovens":	{"NNS"},
"Over-50":	{"JJ"},
"Over-achievers":	{"NNS"},
"Overbuilt":	{"JJ"},
"Overfunding":	{"VBG"},
"Overhanging":	{"VBG"},
"Overly":	{"RB"},
"Overnight":	{"RB"},
"Overpriced":	{"VBD","VBN"},
"Overreacting":	{"VBG"},
"Overseeing":	{"VBG"},
"Oversized":	{"JJ"},
"Overt":	{"JJ"},
"Overtones":	{"NNS"},
"Overvalued":	{"JJ"},
"Overweight":	{"JJ"},
"Overwhelming":	{"JJ"},
"Owing":	{"RB"},
"Owls":	{"NNS"},
"Owning":	{"VBG"},
"Ozagenians":	{"NNS"},
"P.E.":	{"NN"},
"P.O.":	{"NN"},
"P.S.":	{"NN"},
"PA":	{"NN"},
"PAC":	{"NN"},
"PAYE":	{"NN"},
"PAs":	{"NNS"},
"PBS":	{"NN"},
"PC":	{"NN","JJ"},
"PC-magazine":	{"JJ"},
"PCBs":	{"NNS"},
"PCP":	{"NN"},
"PCs":	{"NNS"},
"PDA":	{"NN"},
"PHS":	{"NN"},
"PIA":	{"NN"},
"PID":	{"NN"},
"PLO":	{"NN"},
"PLO-backed":	{"JJ"},
"PM":	{"NN"},
"PO":	{"NN"},
"POB":	{"NN"},
"POE":	{"NN"},
"POPs":	{"NNS"},
"POTUS":	{"NN"},
"POW":	{"NN"},
"POWs":	{"NNS"},
"PR-wise":	{"JJ"},
"PS":	{"NN"},
"PTO":	{"NN"},
"PVC":	{"NN"},
"PWA-owned":	{"JJ"},
"PX":	{"NN"},
"Pa.-based":	{"JJ"},
"Paced":	{"VBN"},
"Pacific":	{"NNP","JJ"},
"Pacific-listed":	{"JJ"},
"Pacify":	{"VB"},
"Packaged-goods":	{"NNS"},
"Packages":	{"NNS"},
"Pacta":	{"FW"},
"Paddle":	{"VB"},
"Paganini":	{"NNS"},
"Pagans":	{"NNS"},
"Pageants":	{"NNS"},
"PaineWebber-involved":	{"JJ"},
"Painful":	{"JJ"},
"Pains":	{"NNS"},
"Painters":	{"NNS"},
"Paintings":	{"NNS"},
"Pakistani":	{"JJ","NNP"},
"Palestinian":	{"JJ","NNP"},
"Palms":	{"NNS"},
"Palmtops":	{"NNS"},
"Pan-American":	{"JJ"},
"Panama-based":	{"JJ"},
"Panama-incorporated":	{"JJ"},
"Panamanian":	{"JJ","NNP"},
"Panglossian":	{"JJ"},
"Pansies":	{"NNS"},
"Pantages":	{"NNS"},
"Pap-pap-pap-hey":	{"UH"},
"Papers":	{"NNS"},
"Papuan":	{"JJ","NNP"},
"Paraguayan":	{"JJ","NNP"},
"Paramedics":	{"NNS"},
"Parental":	{"JJ"},
"Parently":	{"RB"},
"Paris-based":	{"JJ"},
"Parisian":	{"NNP","JJ"},
"Park-affiliated":	{"JJ"},
"Parodis":	{"NNS"},
"Parsee":	{"NN","JJ"},
"Particularly":	{"RB"},
"Partisans":	{"NNS"},
"Partly":	{"RB"},
"Partnerships":	{"NNS"},
"Pas":	{"FW"},
"Pascal":	{"NNP","NN"},
"Passed":	{"VBN"},
"Patentees":	{"NNS"},
"Pati":	{"FW"},
"Patterns":	{"NNS"},
"Pausing":	{"VBG"},
"Pavlovian":	{"JJ"},
"Payers":	{"NNS"},
"Paying":	{"VBG"},
"Payouts":	{"NNS"},
"Peaceful":	{"JJ"},
"Pechora-class":	{"JJ"},
"Pediatricians":	{"NNS"},
"Pedigree-contemplating":	{"VBG"},
"Pedigrees":	{"NNS"},
"Pekinese":	{"NN","NNS"},
"Pekineses":	{"NNS"},
"Pekingese":	{"NNP","NNPS"},
"Pencils":	{"NNS"},
"Penna.":	{"FW"},
"Pennsylvania-based":	{"JJ"},
"Pennsylvanian":	{"NNP","JJ"},
"Pentagon-related":	{"JJ"},
"Pentecostal":	{"JJ"},
"Peppers":	{"NNS"},
"Per-capita":	{"JJ"},
"Per-share":	{"JJ"},
"Performers":	{"NNS"},
"Perhaps":	{"RB"},
"Periodically":	{"RB"},
"Permian":	{"JJ","NNP"},
"Perot-EDS":	{"JJ"},
"Perpetual":	{"JJ"},
"Pershare":	{"JJ"},
"Persian":	{"NNP","JJ"},
"Persianesque":	{"JJ"},
"Personages":	{"NNS"},
"Personally":	{"RB"},
"Perth-based":	{"JJ"},
"Peruvian":	{"NNP","JJ"},
"Pesticides":	{"NNS"},
"Petitions":	{"NNS"},
"Petrarchan":	{"JJ"},
"Pets":	{"NNS"},
"Pfc":	{"NN"},
"PhD":	{"NN"},
"PhDs":	{"NNS"},
"Pharisaic":	{"JJ"},
"Pharmaceuticals":	{"NNS"},
"Philadelphia-area":	{"JJ"},
"Philadelphia-based":	{"JJ"},
"Philco-sponsored":	{"JJ"},
"Philippians":	{"NNS"},
"Philippine":	{"JJ"},
"Philippines-backed":	{"JJ"},
"Phillipines":	{"NNS"},
"Philly":	{"RB"},
"Philosophic":	{"JJ"},
"Phoenicia":	{"NN"},
"Phoenician":	{"NNP","JJ"},
"Phoenicians":	{"NNS"},
"Phonemes":	{"NNS"},
"Photographic":	{"JJ"},
"Photos":	{"NNS"},
"Physicists":	{"NNS"},
"Physicochemical":	{"JJ"},
"Pianists":	{"NNS"},
"Piggybacking":	{"VBG"},
"Piloting":	{"VBG"},
"Pinned":	{"VBN"},
"Piovra":	{"FW"},
"Pistol-whipping":	{"IN"},
"Pitchers":	{"NNS"},
"Pitfalls":	{"NNS"},
"Pitted":	{"JJ"},
"Pittsburgh-based":	{"JJ"},
"Place-names":	{"NNS"},
"Plain-vanilla":	{"JJ"},
"Plaintiffs":	{"NNS"},
"Planes":	{"NNS"},
"Planned":	{"VBD","VBN"},
"Plata":	{"FW"},
"Plates":	{"NNS"},
"Platonic":	{"JJ"},
"Platonica":	{"FW"},
"Platoons":	{"NNS"},
"Playhouses":	{"NNS"},
"Playing":	{"NN","VBG"},
"Plebian":	{"JJ"},
"Pleiades":	{"NNS"},
"Pleistocene":	{"NN","JJ"},
"Plexiglas":	{"NN"},
"Pliocene":	{"NN","JJ"},
"Ploys":	{"NNS"},
"Plug-in":	{"JJ"},
"Plugging":	{"VBG"},
"Plunking":	{"VBG"},
"Plus-one":	{"JJ"},
"Pluses":	{"NNS"},
"Poachers":	{"NNS"},
"Pocketing":	{"VBG"},
"Podgers":	{"NNS"},
"Poets":	{"NNS"},
"Polack":	{"NN"},
"Polak":	{"NN"},
"Polaris":	{"NNS"},
"Polish":	{"JJ","NNP","NNPS"},
"Polished":	{"JJ"},
"Politicians":	{"NNS"},
"Politics-ridden":	{"JJ"},
"Polls":	{"NNS"},
"Pollution-control":	{"JJ"},
"Polynesian":	{"JJ","NNP"},
"Polyphosphates":	{"NNS"},
"Pooh-like":	{"JJ"},
"Poppea":	{"FW"},
"Popping":	{"VBG"},
"Pork-barrel":	{"JJ"},
"Porsche-like":	{"JJ"},
"Portfolios":	{"NNS"},
"Portuguese":	{"NNP","JJ"},
"Portuguese-language":	{"JJ"},
"Posh":	{"JJ"},
"Possibly":	{"RB"},
"Post-holiday":	{"JJ"},
"Post-tragedy":	{"RB"},
"Poussins":	{"NNS"},
"Power-generation":	{"JJ"},
"Pozsony":	{"NNP","FW"},
"Prayers":	{"NNS"},
"Pre-Raphaelite":	{"NN","JJ"},
"Pre-Raphaelites":	{"NNS"},
"Pre-attack":	{"JJ"},
"Pre-inaugural":	{"JJ"},
"Pre-refunded":	{"JJ"},
"Pre-shaped":	{"JJ"},
"Pre-trial":	{"JJ"},
"Preambles":	{"NNS"},
"Precambrian":	{"JJ"},
"Predictably":	{"RB"},
"Predictions":	{"NNS"},
"Predispositions":	{"NNS"},
"Preferably":	{"RB"},
"Preferred-dividend":	{"JJ"},
"Preparations":	{"NNS"},
"Prepayments":	{"NNS"},
"Presbyterian":	{"NNP","JJ"},
"Presbyterianism":	{"NN"},
"Prescribed":	{"VBN"},
"Presently":	{"RB"},
"Pressed":	{"VBN"},
"Pressure-happy":	{"JJ"},
"Presumably":	{"RB"},
"Presupposed":	{"VBN"},
"Prettier":	{"JJR"},
"Previously":	{"RB"},
"Price-boosting":	{"JJ"},
"Price-earnings":	{"JJ"},
"Pricey":	{"JJ"},
"Prickly":	{"JJ"},
"Primarily":	{"RB"},
"Prime-2":	{"JJ"},
"Prime-3":	{"JJ"},
"Primus":	{"NN"},
"Prince":	{"NNP","NN"},
"Prince-of-Wales'-heath":	{"NN"},
"Principal-only":	{"JJ"},
"Principals":	{"NNS"},
"Privately":	{"RB"},
"Prize-winning":	{"JJ"},
"Pro-Choice":	{"JJ"},
"Pro-choice":	{"JJ"},
"Pro-forma":	{"JJ"},
"Pro-life":	{"JJ"},
"Pro-rated":	{"JJ"},
"Probing":	{"VBG"},
"Proceedings":	{"NNS"},
"Program-Trading":	{"JJ"},
"Programs":	{"NNS"},
"Projecting":	{"VBG"},
"Promazine":	{"JJ"},
"Promises":	{"VBZ"},
"Promotional":	{"JJ"},
"Prompted":	{"VBN"},
"Promptly":	{"RB"},
"Proper":	{"JJ"},
"Property-tax":	{"JJ"},
"Proposals":	{"NNS"},
"Pros":	{"NNS"},
"Prosecutorial":	{"JJ"},
"Prosecutors":	{"NNS"},
"Protective":	{"JJ"},
"Protestant":	{"NNP","JJ"},
"Protestant-dominated":	{"JJ"},
"Protesters":	{"NNS"},
"Protista":	{"NN"},
"Protons":	{"NNS"},
"Prototypes":	{"NNS"},
"Provos":	{"NNS"},
"Prudential":	{"JJ"},
"Prussian":	{"NNP","JJ"},
"Psychical":	{"JJ"},
"Psychologists":	{"NNS"},
"Ptolemaic":	{"JJ"},
"Ptolemaist":	{"NN"},
"Ptolemaists":	{"NNS"},
"Public-spirited":	{"JJ"},
"Public-works":	{"NNS"},
"Publicly":	{"RB"},
"Pueri":	{"FW"},
"Puffing":	{"VBG"},
"Pullmans":	{"NNS"},
"Pummeled":	{"VBN"},
"Pundits":	{"NNS"},
"Punic":	{"JJ","NNP"},
"Punjabi":	{"NN","JJ"},
"Punjabis":	{"NNS"},
"Puny":	{"JJ"},
"Pupils":	{"NNS"},
"Puppis":	{"NN"},
"Purchases":	{"VBZ"},
"Puritan":	{"NNP","JJ"},
"Puritans":	{"NNS"},
"Puseyite":	{"NNP","JJ"},
"Push-ups":	{"NNS"},
"Pushing":	{"VBG"},
"Putting":	{"VBG"},
"Pvt.":	{"NN"},
"Pyhrric":	{"JJ"},
"Pyrrhic":	{"JJ"},
"QC":	{"NN"},
"QED":	{"NN"},
"Qatari":	{"JJ","NNP"},
"Quaker":	{"NNP","JJ"},
"Quatsch":	{"FW"},
"Qui":	{"FW"},
"Quietly":	{"RB"},
"Quod":	{"FW"},
"Quotas":	{"NNS"},
"Quoting":	{"VBG"},
"R-5th":	{"JJ"},
"R-shaped":	{"JJ"},
"R-stage":	{"JJ"},
"R.I.-based":	{"JJ"},
"RAF":	{"NN"},
"RAM":	{"NN"},
"RAS":	{"NN"},
"REITs":	{"NNS"},
"REMICs":	{"NNS"},
"RFD":	{"NN"},
"RI":	{"NN"},
"RICO-forfeiture":	{"JJ"},
"RISC":	{"NN"},
"RISC-based":	{"JJ"},
"RJR-style":	{"JJ"},
"RN":	{"NN"},
"RNA":	{"NN"},
"RNA-based":	{"JJ"},
"RNAS":	{"NNS"},
"RNAs":	{"NNS"},
"ROTC":	{"NN"},
"RTC-appointed":	{"JJ"},
"RTC-owned":	{"JJ"},
"RV":	{"NN"},
"RVs":	{"NNS"},
"Rabbits":	{"NNS"},
"Rabble-rousing":	{"JJ"},
"Rabelaisian":	{"JJ"},
"Raccoons":	{"NNS"},
"Race-drivers":	{"NNS"},
"Racial":	{"JJ"},
"Radioing":	{"VBG"},
"Ragged":	{"JJ"},
"Railbikers":	{"NNS"},
"Railbikes":	{"NNS"},
"Railroad-rate":	{"JJ"},
"Ramparts":	{"NNS"},
"Rankings":	{"NNS"},
"Raphaels":	{"NNS"},
"Rapids":	{"NNS"},
"Rapping":	{"VBG"},
"Rarely":	{"RB"},
"Rarer":	{"JJR"},
"Rasta":	{"NNP","JJ"},
"Rastafarian":	{"JJ","NNP"},
"Rated":	{"VBN"},
"Ratified":	{"VBN"},
"Rats":	{"VBZ"},
"Rau-Sed":	{"NN"},
"Ravel-like":	{"JJ"},
"Razors":	{"NNS"},
"Re-enactments":	{"NNS"},
"Reacting":	{"VBG"},
"Reactionaries":	{"NNS"},
"Reactions":	{"NNS"},
"Readers":	{"NNS"},
"Readily":	{"RB"},
"Reaffirming":	{"VBG"},
"Reagan-Republican":	{"JJ"},
"Reagan-like":	{"JJ"},
"Reaganauts":	{"NNS"},
"Reaganite":	{"JJ"},
"Rearding":	{"VBG"},
"Reasonable":	{"JJ"},
"Reasons":	{"NNS"},
"Rebates":	{"NNS"},
"Rebels":	{"NNS"},
"Receave":	{"VBP","VB"},
"Receivables":	{"NNS"},
"Recently":	{"RB"},
"Recherches":	{"FW"},
"Recklessly":	{"RB"},
"Reckon":	{"VB"},
"Recommendations":	{"NNS"},
"Reconsider":	{"VB"},
"Recounting":	{"VBG"},
"Recoup":	{"VB"},
"Recovering":	{"VBG"},
"Red-blooded":	{"JJ"},
"Red-prone":	{"JJ"},
"Redeemer":	{"NNP","NN"},
"Reducing":	{"VBG"},
"Reductions":	{"NNS"},
"Reefs":	{"NNS"},
"Reenact":	{"VB"},
"Reeves-type":	{"JJ"},
"Refcorps":	{"NNS"},
"Referrals":	{"NNS"},
"Referring":	{"VBG"},
"Refinements":	{"NNS"},
"Refiners":	{"NNS"},
"Reflecting":	{"VBG"},
"Regains":	{"VBZ"},
"Regarded":	{"VBN"},
"Regardless":	{"RB"},
"Regionally":	{"RB"},
"Regions":	{"NNS"},
"Registrations":	{"NNS"},
"Regretfully":	{"RB"},
"Regrettably":	{"RB"},
"Regulars":	{"NNS"},
"Regulative":	{"JJ"},
"Regulators":	{"NNS"},
"Regulus":	{"NNS"},
"Reichmann-controlled":	{"JJ"},
"Reinforcements":	{"NNS"},
"Reinforcing":	{"VBG"},
"Reintroducing":	{"VBG"},
"Rejoins":	{"VBZ"},
"Rekindled":	{"VBN"},
"Relatively":	{"RB"},
"Relatives":	{"NNS"},
"Relentlessly":	{"RB"},
"Reluctant":	{"JJ"},
"Relying":	{"VBG"},
"Remains":	{"NNS"},
"Remarketers":	{"NNS"},
"Remember":	{"VB"},
"Remic-related":	{"JJ"},
"Removed":	{"VBN"},
"Renaissance-style":	{"JJ"},
"Renewed":	{"VBN"},
"Reorganizing":	{"VBG"},
"Repeatedly":	{"RB"},
"Replies":	{"NNS"},
"Reprisals":	{"NNS"},
"Reproach":	{"VB"},
"Republican":	{"NNP","JJ"},
"Republican-controlled":	{"JJ"},
"Reputedly":	{"RB"},
"Requirements":	{"NNS"},
"Reservoirs":	{"NNS"},
"Reshaping":	{"VBG"},
"Residents":	{"NNS"},
"Resignedly":	{"RB"},
"Resourceful":	{"JJ"},
"Respecting":	{"VBG"},
"Responding":	{"VBG"},
"Responses":	{"NNS"},
"Restrict":	{"VB"},
"Rests":	{"VBZ"},
"Restudy":	{"VB"},
"Results":	{"NNS"},
"Retails":	{"NNS"},
"Retracing":	{"VBG"},
"Returns":	{"NNS"},
"Reveals":	{"VBZ"},
"Revenue-short":	{"JJ"},
"Reverently":	{"RB"},
"Reversing":	{"VBG"},
"Revitalized":	{"VBN"},
"Revivals":	{"NNS"},
"Revolutionibus":	{"FW"},
"Rewards":	{"NNS"},
"Rey-controlled":	{"JJ"},
"Reyes":	{"NNS"},
"Rh-negative":	{"JJ"},
"Rhenish":	{"JJ"},
"Rhodesian":	{"JJ","NNP"},
"Ribozymes":	{"NNS"},
"Rich-affiliated":	{"JJ"},
"Richmond-area":	{"JJ"},
"Richterian":	{"JJ"},
"Ridiculing":	{"VBG"},
"Rifkinesque":	{"JJ"},
"Right-to-Die":	{"JJ"},
"Rightly":	{"RB"},
"Rigid":	{"JJ"},
"Riiiing":	{"UH"},
"Rim-Fire":	{"JJ"},
"Rios-embryos":	{"NNS"},
"Ripples":	{"NNS"},
"Rising":	{"VBG"},
"Rivoli":	{"FW"},
"RoadRailing":	{"VBG"},
"Roasters":	{"NNS"},
"Robbers":	{"NNS"},
"Robusta-producing":	{"JJ"},
"Rocket-powered":	{"JJ"},
"Roles":	{"NNS"},
"Rolled":	{"VBN"},
"Romaic":	{"JJ","NNP"},
"Roman":	{"NNP","JJ"},
"Romanesque":	{"JJ"},
"Romani":	{"JJ","NNP"},
"Romanian":	{"NNP","JJ"},
"Romanic":	{"JJ"},
"Romanies":	{"NNS"},
"Romanisation":	{"NN"},
"Romanise":	{"VB","VBP"},
"Romanised":	{"VBD","VBN"},
"Romanises":	{"VBZ"},
"Romanising":	{"VBG"},
"Romanism":	{"NN"},
"Romanist":	{"NN"},
"Romanists":	{"NNS"},
"Romanization":	{"NN"},
"Romanize":	{"VB","VBP"},
"Romanized":	{"VBD","VBN"},
"Romanizes":	{"VBZ"},
"Romanizing":	{"VBG"},
"Romany":	{"NN","JJ"},
"Rome-based":	{"JJ"},
"Romish":	{"JJ"},
"Roneo":	{"NN","VB","VBP"},
"Roneoed":	{"VBD","VBN"},
"Roneoing":	{"VBG"},
"Roneos":	{"NNS","VBZ"},
"Roommates":	{"NNS"},
"Rooseveltian":	{"JJ"},
"Roquefort":	{"NN"},
"Roughly":	{"RB"},
"Roumanian":	{"JJ","NN"},
"Rousseauan":	{"JJ"},
"Rubenesquely":	{"JJ"},
"Rubins":	{"NNS"},
"Ruffians":	{"NNS"},
"Ruffled":	{"VBN"},
"Ruined":	{"VBN"},
"Rumanian":	{"JJ"},
"Rummaging":	{"VBG"},
"Run-down":	{"JJ"},
"Runners":	{"NNS"},
"Runways":	{"NNS"},
"Ruritanian":	{"JJ","NNP"},
"Russian":	{"JJ","NNP"},
"Russian-dominated":	{"JJ"},
"Russian-language":	{"JJ"},
"Russo-American":	{"JJ"},
"Rusting":	{"VBG"},
"Rwandan":	{"NNP","JJ"},
"S-s-sahjunt":	{"NN"},
"S.C.-based":	{"JJ"},
"S.O.B.s":	{"NNS"},
"SAS":	{"NN"},
"SIDS":	{"NN"},
"SKr1.5":	{"NNS"},
"SKr20":	{"NNS"},
"SKr205":	{"NNS"},
"SKr225":	{"NNS"},
"SKr29":	{"NNS"},
"SONGsters":	{"NNS"},
"SOS":	{"NN"},
"SP1-plus":	{"JJ"},
"SS-18s":	{"NNS"},
"SUV":	{"NN"},
"SUVs":	{"NNS"},
"SW":	{"NN","JJ","RB"},
"SWbS":	{"NN","JJ","RB"},
"SWbW":	{"NN","JJ","RB"},
"Sabbatarian":	{"NNP","JJ"},
"Sabinas":	{"FW"},
"Sabras":	{"NNS"},
"Sacramento-based":	{"JJ"},
"Sacrifices":	{"NNS"},
"Sadly":	{"RB"},
"Sagittarian":	{"JJ","NN"},
"Sagos":	{"NNS"},
"Saharan":	{"JJ","NNP"},
"Sailors":	{"NNS"},
"Saints":	{"NNS"},
"Sakellariadises":	{"NNS"},
"Salads":	{"NNS"},
"Salvadoran":	{"JJ","NNP"},
"Salvadorean":	{"NNP","JJ"},
"Samaritans":	{"NNS"},
"Same":	{"JJ"},
"Same-store":	{"JJ"},
"Samoan":	{"NNP","JJ"},
"Samoyed":	{"NNP","NNPS","JJ"},
"Samoyedic":	{"NN"},
"Samples":	{"NNS"},
"Sandwiched":	{"VBN"},
"Sardinian":	{"NNP","JJ"},
"Sashimi":	{"FW"},
"Satellites":	{"NNS"},
"Satisfying":	{"VBG"},
"Saturday-night":	{"JJ"},
"Saudi":	{"NNP","JJ"},
"Savings":	{"NNS"},
"Saxon":	{"NNP","JJ"},
"Says":	{"VBZ"},
"SbCs-type":	{"JJ"},
"Scandanavian":	{"JJ"},
"Scandinavian":	{"JJ","NNP"},
"Scenarios":	{"NNS"},
"Scenes":	{"NNS"},
"Schmalma":	{"UH"},
"Schmalzried":	{"VBD","VBN"},
"Schnabelian":	{"JJ"},
"Schubert-Beethoven-Mozart":	{"JJ"},
"Schwarzen":	{"FW"},
"Scientists":	{"NNS"},
"Scorpian":	{"JJ","NNP"},
"Scot":	{"NNP","NN"},
"Scotch":	{"JJ","NNP"},
"Scotch-and-soda":	{"NN"},
"Scotchman":	{"NN"},
"Scots":	{"JJ","NNP","NNPS"},
"Scottish":	{"JJ","NNP"},
"Scottish-born":	{"JJ"},
"Scouse":	{"NNP","JJ"},
"Scrambling":	{"VBG"},
"Scrapings":	{"NNS"},
"Scraps":	{"NNS"},
"Screwed":	{"VBD","VBN"},
"Scrooge-like":	{"JJ"},
"Scrupulous":	{"JJ"},
"Seasonally":	{"RB"},
"Seats":	{"NNS"},
"Seattle-based":	{"JJ"},
"Seattlites":	{"NNS"},
"Second-half":	{"JJ"},
"Second-highest":	{"JJ"},
"Second-tier":	{"JJ"},
"Secondly":	{"RB"},
"Seconds":	{"NNS"},
"Sections":	{"NNS"},
"Securities-trading":	{"JJ"},
"See-through":	{"JJ"},
"Seeds":	{"NNS"},
"Seeming":	{"VBG"},
"Seemingly":	{"RB"},
"Seizing":	{"VBG"},
"Seldom":	{"RB"},
"Selections":	{"NNS"},
"Selectmen":	{"NNS"},
"Self-contained":	{"JJ"},
"Self-designated":	{"JJ"},
"Self-expression":	{"NN"},
"Selkirkers":	{"NNS"},
"Semifinished":	{"VBN"},
"Semitic":	{"JJ","NNP"},
"Senate-backed":	{"JJ"},
"Senate-passed":	{"JJ"},
"Senegal":	{"NNP","JJ"},
"Senegalese":	{"JJ","NNP","NNPS"},
"Senium":	{"FW"},
"Sentiments":	{"NNS"},
"Separating":	{"VBG"},
"Sept":	{"NN"},
"Serb":	{"NNP","JJ"},
"Serbian":	{"NNP","JJ"},
"Serbo-Croatian":	{"NNP","JJ"},
"Servanda":	{"FW"},
"Seventy-nine":	{"JJ"},
"Seventy-six":	{"JJ"},
"Sewing":	{"NN","VBG"},
"Seychellois":	{"JJ","NNP"},
"Shades":	{"NNS"},
"Shakespearean":	{"JJ","NNP"},
"Shakespearian":	{"NNP","JJ"},
"Shan":	{"NNP","NNPS"},
"Shanghai-born":	{"JJ"},
"Shantytowns":	{"NNS"},
"Shaped":	{"JJ"},
"Sharing":	{"VBG","NN"},
"Sharp-witted":	{"JJ"},
"Sharply":	{"RB"},
"Shavian":	{"JJ","NNP"},
"Shays":	{"NNS"},
"Shia":	{"NN"},
"Shiite":	{"NNP","JJ"},
"Shingles":	{"NNS"},
"Shintoist":	{"JJ","NNP"},
"Shintoistic":	{"JJ"},
"Shipments":	{"NNS"},
"Shippin":	{"VB"},
"Shippings":	{"NNS"},
"Ships":	{"NNS"},
"Shivering":	{"VBG"},
"Shona":	{"NNP","NNPS"},
"Shoppers":	{"NNS"},
"Shoppsers":	{"NNS"},
"Shortages":	{"NNS"},
"Shortcuts":	{"NNS"},
"Shorted":	{"JJ"},
"Shortly":	{"RB"},
"Shotgun-type":	{"JJ"},
"Shotguns":	{"NNS"},
"Shouldering":	{"VBG"},
"Showrooms":	{"NNS"},
"Shrubs":	{"NNS"},
"Shrugged":	{"VBD","VBN"},
"Shu-tt":	{"VB"},
"Shucks":	{"UH"},
"Shunted":	{"VBN"},
"Shylockian":	{"JJ"},
"Siamese":	{"NNP","JJ","NNPS"},
"Siberian":	{"NNP","JJ"},
"Sicilian":	{"JJ","NNP"},
"Sicilians":	{"NNS"},
"Sidestepping":	{"VBG"},
"Siegfried":	{"VBD","VBN"},
"Sighing":	{"VBG"},
"Signed":	{"VBN"},
"Signers":	{"NNS"},
"Significantly":	{"RB"},
"Significants":	{"NNS"},
"Sikh":	{"NNP","JJ"},
"Silently":	{"RB"},
"Silurian":	{"JJ"},
"Similar":	{"JJ"},
"Similarly":	{"RB"},
"Simplex":	{"JJ"},
"Simply":	{"RB"},
"Simulated":	{"JJ"},
"Simultaneously":	{"RB"},
"Singaporean":	{"JJ","NNP"},
"Singhalese":	{"JJ","NNP"},
"Single-A-2":	{"JJ"},
"Single-A-3":	{"JJ"},
"Single-cell":	{"JJ"},
"Single-color":	{"JJ"},
"Single-seeded":	{"JJ"},
"Single-subject":	{"JJ"},
"Singles":	{"NNS"},
"Sinhala":	{"JJ","NNP"},
"Sinhalese":	{"NNP","NNPS","JJ"},
"Sinhalese-dominated":	{"JJ"},
"Sinitic":	{"JJ"},
"Sino-British":	{"JJ"},
"Sino-Soviet":	{"JJ"},
"Sino-foreign":	{"JJ"},
"Sintered":	{"VBN"},
"Sistine":	{"JJ"},
"Sitting":	{"VBG"},
"Situations":	{"NNS"},
"Six":	{"CD"},
"Six-year-old":	{"JJ"},
"Sizable":	{"JJ"},
"Sjaelland":	{"NNP","FW"},
"Skilled":	{"JJ"},
"Skills":	{"NNS"},
"Skinnerish":	{"JJ"},
"Skittish":	{"JJ"},
"Skulls":	{"NNS"},
"Slackened":	{"VBN"},
"Slav":	{"JJ","NNP"},
"Slavic":	{"NNP","JJ"},
"Slavonic":	{"JJ"},
"Sleep-disorder":	{"JJ"},
"Sleepers":	{"NNS"},
"Sleepily":	{"RB"},
"Sleepwalkers":	{"NNS"},
"Sleepy-eyed":	{"JJ"},
"Slides":	{"NNS"},
"Slightly":	{"RB"},
"Slipping":	{"VBG"},
"Slovak":	{"NNP","JJ"},
"Slovakian":	{"JJ","NNP"},
"Slovenian":	{"JJ"},
"Slowly":	{"RB"},
"Sluggish":	{"JJ"},
"Small-company":	{"JJ"},
"Small-lot":	{"JJ"},
"Smaller":	{"JJR"},
"Smaller-stock":	{"JJR"},
"Smiling":	{"VBG"},
"Smokers":	{"NNS"},
"Smoldering":	{"VBG"},
"Smug":	{"JJ"},
"Snatching":	{"VBG"},
"Sniffing":	{"VBG"},
"Snoozing":	{"VBG"},
"Soaring":	{"VBG"},
"Socialist-led":	{"JJ"},
"Socratic":	{"JJ"},
"Soft-Sell":	{"JJ"},
"Soft-spoken":	{"JJ"},
"Softer-than-expected":	{"JJ"},
"Softly":	{"RB"},
"Soignee":	{"FW"},
"Solar-powered":	{"JJ"},
"Solder":	{"VB"},
"Solemnly":	{"RB"},
"Solidarity-led":	{"JJ"},
"Solitudinem":	{"FW"},
"Solomon-like":	{"JJ"},
"Solomonic":	{"JJ"},
"Solutions":	{"NNS"},
"Solving":	{"VBG"},
"Somali":	{"JJ","NNP","NNPS"},
"Somalian":	{"JJ","NNP"},
"Someday":	{"RB"},
"Somehow":	{"RB"},
"Somersaults":	{"NNS"},
"Sometime":	{"RB"},
"Sometimes":	{"RB"},
"Sonet-based":	{"JJ"},
"Sonet-compatible":	{"JJ"},
"Sonntag":	{"FW"},
"Sonuvabitch":	{"UH"},
"Sony-owned":	{"JJ"},
"Soon":	{"RB"},
"Soothing":	{"VBG"},
"Sophisticated":	{"JJ"},
"Sophocles":	{"NNS"},
"Sophomores":	{"NNS"},
"Sorting":	{"VBG"},
"Soupy":	{"JJ"},
"South":	{"NNP","JJ","RB"},
"Southeast":	{"NNP","JJ","RB"},
"Southeastern":	{"JJ"},
"Southern":	{"JJ"},
"Southwest":	{"NNP","JJ","RB"},
"Soviet":	{"JJ","NNP"},
"Soviet-American":	{"JJ"},
"Soviet-Finnish":	{"JJ"},
"Soviet-Israeli":	{"JJ"},
"Soviet-Korean":	{"JJ"},
"Soviet-accredited":	{"JJ"},
"Soviet-backed":	{"JJ"},
"Soviet-bloc":	{"JJ"},
"Soviet-built":	{"JJ"},
"Soviet-controlled":	{"JJ"},
"Soviet-finished":	{"JJ"},
"Soviet-made":	{"JJ"},
"Soviet-style":	{"JJ"},
"Soviet-supplied":	{"JJ"},
"Soviet-trained":	{"JJ"},
"Sovietologists":	{"NNS"},
"Soviets":	{"NNS"},
"Sows":	{"NNS"},
"Soybeans":	{"NNS"},
"Spaced":	{"NNP","VBD","VBN"},
"Spagna":	{"FW"},
"Spanish":	{"JJ","NNP","NNPS"},
"Spanish-American":	{"NNP","JJ"},
"Spanish-born":	{"JJ"},
"Spanish-speaking":	{"JJ"},
"Spartan":	{"JJ","NNP"},
"Speaker":	{"NNP","NN"},
"Speakers":	{"NNS"},
"Special-interest":	{"JJ"},
"Specialists":	{"NNS"},
"Specially":	{"RB"},
"Specimens":	{"NNS"},
"Speculative":	{"JJ"},
"Speculators":	{"NNS"},
"Speeches":	{"NNS"},
"Spencerian":	{"JJ"},
"Spenglerian":	{"JJ"},
"Spherical":	{"JJ"},
"Spike-haired":	{"JJ"},
"Spinoffs":	{"NNS"},
"Spirited":	{"JJ"},
"Spirituals":	{"NNS"},
"Spokespersons":	{"NNS"},
"Spokeswomen":	{"NNS"},
"Sporadic":	{"JJ"},
"Sportscasters":	{"NNS"},
"Spots":	{"NNS"},
"Springing":	{"VBG"},
"Spumoni":	{"NNS"},
"Spurred":	{"VBN"},
"Squat-style":	{"JJ"},
"Squeezing":	{"VBG"},
"Stabilizing":	{"VBG"},
"Stadiums":	{"NNS"},
"Staffers":	{"NNS"},
"Staged":	{"VBD","VBN"},
"Staggeringly":	{"RB"},
"Staining":	{"VBG"},
"Stairs":	{"NNS"},
"Stalinist":	{"JJ","NNP"},
"Stalinist-corrupted":	{"JJ"},
"Stalled":	{"VBN"},
"Standard-issue":	{"JJ"},
"Standardized":	{"JJ"},
"Starks":	{"NNS"},
"Starlings":	{"NNS"},
"Starting":	{"VBG"},
"Startled":	{"VBN"},
"Starve":	{"VB"},
"State-controlled":	{"JJ"},
"State-financed":	{"JJ"},
"State-owned":	{"JJ"},
"State-run":	{"JJ"},
"Statements":	{"NNS"},
"States":	{"NNP","NNPS","NNS"},
"Statues":	{"NNS"},
"Status-roles":	{"NNS"},
"Statutes":	{"NNS"},
"Steelmakers":	{"NNS"},
"Sterilized":	{"JJ"},
"Stern-faced":	{"JJ"},
"Steroids":	{"NNS"},
"Stickers":	{"NNS"},
"Stigmata":	{"NNS"},
"Still":	{"RB"},
"Stimulates":	{"VBZ"},
"Stitched":	{"VBN"},
"Stoic-patristic":	{"JJ"},
"Stoics":	{"NNS"},
"Stooges":	{"NNS"},
"Stop-close-only":	{"JJ"},
"Stop-limit":	{"JJ"},
"Stop-loss":	{"NNS"},
"Storekeepers":	{"NNS"},
"Stories":	{"NNS"},
"Straighten":	{"VB"},
"Straightened":	{"VBN"},
"Straightening":	{"VBG"},
"Straights":	{"NNS"},
"Strategists":	{"NNS"},
"Stratford-upon-Avon":	{"NN"},
"Stratus":	{"NNS"},
"Street-inspired":	{"JJ"},
"Street-style":	{"JJ"},
"Strenuous":	{"JJ"},
"Stressed-out":	{"JJ"},
"Stretching":	{"VBG"},
"Stricken":	{"VB"},
"Strict":	{"JJ"},
"Strictly":	{"RB"},
"Stringing":	{"VBG"},
"Strippers":	{"NNS"},
"Strips":	{"NNS"},
"Strokes":	{"NNS"},
"Stroking":	{"VBG"},
"Strong-earnings":	{"NNS"},
"Strongly":	{"RB"},
"Studios":	{"NNS"},
"Stuffing":	{"VBG"},
"Stumbling":	{"JJ"},
"Stung":	{"VBN"},
"Stunned":	{"VBN"},
"Stuttgart-based":	{"JJ"},
"Stygian":	{"JJ"},
"Subcontractors":	{"NNS"},
"Subdued":	{"JJ"},
"Subgroups":	{"NNS"},
"Subjects":	{"NNS"},
"Submarines":	{"NNS"},
"Subscribers":	{"NNS"},
"Subscribing":	{"VBG"},
"Subsequent":	{"JJ"},
"Subsidizing":	{"VBG"},
"Substances":	{"NNS"},
"Substituting":	{"VBG"},
"Subsystems":	{"NNS"},
"Subways":	{"NNS"},
"Succeeding":	{"VBG"},
"Successors":	{"NNS"},
"Sudanese":	{"NNP","JJ","NNPS"},
"Suddenly":	{"RB"},
"Suffice":	{"VB"},
"Sufi":	{"JJ","NNP"},
"Sufic":	{"JJ"},
"Sugarman-led":	{"JJ"},
"Suggestions":	{"NNS"},
"Suites":	{"NNS"},
"Suitors":	{"NNS"},
"Sultans":	{"NNS"},
"Sumatran":	{"NNP","JJ"},
"Sumerian":	{"JJ","NNP"},
"Summarizing":	{"VBG"},
"Sunbelt":	{"NNP","NN"},
"Sundance-based":	{"JJ"},
"Sunday-school":	{"JJ"},
"Sunflowers":	{"NNS"},
"Sunni":	{"NNP","NNPS"},
"Suor":	{"FW"},
"Superconcentrates":	{"NNS"},
"Superconductors":	{"NNS"},
"Superintendents":	{"NNS"},
"Supermatic":	{"JJ"},
"Supplementing":	{"VBG"},
"Suppliers":	{"NNS"},
"Supplies":	{"NNS"},
"Supporting":	{"VBG"},
"Supportive":	{"JJ"},
"Supports":	{"NNS"},
"Suppose":	{"VB"},
"Supposedly":	{"RB"},
"Sure-sure":	{"JJ"},
"Surely":	{"RB"},
"Surgeons":	{"NNS"},
"Surging":	{"VBG"},
"Surinamese":	{"NNP","JJ","NNPS"},
"Surprises":	{"NNS"},
"Surprisingly":	{"RB"},
"Surrealists":	{"NNS"},
"Surrendering":	{"VBG"},
"Surrounded":	{"VBN"},
"Surrounding":	{"VBG"},
"Surveying":	{"VBG"},
"Svenskarna":	{"FW"},
"Swamped":	{"VBN"},
"Swazi":	{"NNP","NNPS"},
"Swears":	{"VBZ"},
"Swedes":	{"NNS"},
"Swedish":	{"JJ","NNP"},
"Sweepstakes":	{"NNS"},
"Sweet-scented":	{"JJ"},
"Sweet-sour":	{"JJ"},
"Swiftly":	{"RB"},
"Swiss":	{"JJ","NNP"},
"Swiss-German":	{"JJ"},
"Swiss-based":	{"JJ"},
"Swiss-born":	{"JJ"},
"Swiss-cheese":	{"NN"},
"Swissmade":	{"JJ"},
"Switches":	{"NNS"},
"Switzerland-based":	{"JJ"},
"Swiveling":	{"VBG"},
"Sydney-based":	{"JJ"},
"Syed":	{"VBD","VBN"},
"Synchronized":	{"VBN"},
"Syrian":	{"JJ"},
"System-specific":	{"JJ"},
"Systematically":	{"RB"},
"T-bill":	{"NN"},
"T-bills":	{"NNS"},
"T-bond":	{"NN"},
"T-bonds":	{"NNS"},
"T-bone":	{"NN"},
"T-cell":	{"NN"},
"T-cells":	{"NNS"},
"T-helper":	{"NN"},
"T-junction":	{"NN"},
"T-junctions":	{"NNS"},
"T-man":	{"NN"},
"T-men":	{"NNS"},
"T-shaped":	{"JJ"},
"T-shirt":	{"NN"},
"T-shirts":	{"NNS"},
"T-square":	{"NN"},
"T-squares":	{"NNS"},
"TA":	{"NN"},
"TB":	{"NN"},
"TCP":	{"NN"},
"TEDs":	{"NNS"},
"THB":	{"NN"},
"THz":	{"NN"},
"TM":	{"NN"},
"TMV":	{"NN"},
"TNF":	{"NN"},
"TNT":	{"NN"},
"TROs":	{"NNS"},
"TSH-treated":	{"JJ"},
"TV-production":	{"JJ"},
"TVs":	{"NNS"},
"Tabarro":	{"FW"},
"Tabellen":	{"FW"},
"Tables":	{"NNS"},
"Tabs":	{"NNS"},
"Tack-solder":	{"VB"},
"Tactically":	{"RB"},
"Tadjik":	{"NNP","NNPS"},
"Tadzhik":	{"NNP","NNPS"},
"Tahitian":	{"NNP","JJ"},
"Tai":	{"NNP","NNPS","JJ"},
"Tailors":	{"NNS"},
"Taiwan-born":	{"JJ"},
"Taiwanese":	{"JJ","NNP","NNPS"},
"Tajik":	{"NNP","JJ"},
"Tajikistani":	{"JJ","NNP"},
"Take-up":	{"JJ"},
"Takeover-stock":	{"JJ"},
"Tales":	{"NNS"},
"Talmudic":	{"JJ"},
"Tamil":	{"NNP","JJ","NNPS"},
"Tampa-based":	{"JJ"},
"Tampax":	{"NNP","NNPS"},
"Tampering":	{"VBG"},
"Tancred":	{"VBD","VBN"},
"Tangible":	{"JJ"},
"Tanin":	{"FW"},
"Tanks":	{"NNS"},
"Tanzanian":	{"JJ","NNP"},
"Taoist":	{"NNP","JJ"},
"Taped":	{"VBN"},
"Tappets":	{"NNS"},
"Tardily":	{"RB"},
"Targetted":	{"VBD","VBN"},
"Targo":	{"JJ"},
"Tarot-like":	{"JJ"},
"Tartar":	{"NNP","JJ"},
"Taser":	{"NN"},
"Tasmanian":	{"JJ","NNP"},
"Taurean":	{"JJ","NNP"},
"Tax-exempt":	{"JJ"},
"Tax-exempts":	{"NNS"},
"Taxes":	{"NNS"},
"Taxis":	{"NNS","NN"},
"Taxonomists":	{"NNS"},
"Tbond":	{"JJ"},
"Tchalo":	{"FW"},
"Tears":	{"NNS"},
"Technical-chart":	{"JJ"},
"Teen-age":	{"JJ"},
"Teen-agers":	{"NNS"},
"Teens":	{"NNS"},
"Teeth":	{"NNS"},
"Telephone-operations":	{"NNS"},
"Teletypes":	{"NNS"},
"Telford-made":	{"JJ"},
"Temperatures":	{"NNS"},
"Tempos":	{"NNS"},
"Ten":	{"CD"},
"Ten-thousand-dollar":	{"JJ"},
"Tendered":	{"JJ"},
"Tenderly":	{"RB"},
"Tenders":	{"NNS"},
"Tenements":	{"NNS"},
"Tenn.-based":	{"JJ"},
"Tennessean":	{"NNP","JJ"},
"Tens":	{"NNS"},
"Terminals":	{"NNS"},
"Terranomics":	{"NNS"},
"Terrours":	{"NNS"},
"Test-preparation":	{"JJ"},
"Testament-style":	{"JJ"},
"Testifying":	{"VBG"},
"Teutonic":	{"NNP","JJ"},
"Tex-Mex":	{"JJ"},
"Texan":	{"NNP","JJ"},
"Texas-based":	{"JJ"},
"Textbooks":	{"NNS"},
"Texts":	{"NNS"},
"Thai":	{"NNP","NNPS","JJ"},
"Thai-Cambodian":	{"JJ"},
"Thames":	{"NNS"},
"Thamnophis":	{"NNS"},
"Thankful":	{"JJ"},
"That-a-way":	{"RB"},
"Thatcher-style":	{"JJ"},
"Thatcherian":	{"JJ"},
"Thatcherite":	{"JJ"},
"Theaters":	{"NNS"},
"Theban":	{"JJ","NNP"},
"Thebe":	{"NN"},
"Thefts":	{"NNS"},
"Their":	{"PRP$"},
"Them":	{"PRP"},
"Then":	{"RB"},
"Theodosian":	{"JJ"},
"Theoretically":	{"RB"},
"Theorists":	{"NNS"},
"Theravada":	{"JJ"},
"Thereafter":	{"RB"},
"Thereby":	{"RB"},
"Thermoforming":	{"VBG"},
"Thermogravimetric":	{"JJ"},
"Thibetan":	{"JJ","NNP"},
"Thieves":	{"NNS"},
"Things":	{"NNS"},
"Third-Period":	{"JJ"},
"Third-party":	{"JJ"},
"Thirdly":	{"RB"},
"Thirty-one":	{"JJ"},
"Thracian":	{"JJ","NNP"},
"Thraco-Phrygian":	{"NNP","JJ"},
"Threaded":	{"VBN"},
"Threats":	{"NNS"},
"Three-and-a-half":	{"JJ"},
"Three-day":	{"JJ"},
"Three-fourths":	{"NNS"},
"Three-month":	{"JJ"},
"Three-part":	{"JJ"},
"Three-quarters":	{"NNS"},
"Three-year-old":	{"JJ"},
"Thrifts":	{"NNS"},
"Thriving":	{"JJ"},
"Throughout":	{"IN"},
"Throws":	{"VBZ"},
"Thunderbird":	{"NNP","NN"},
"Thursday-night":	{"JJ"},
"Thus":	{"RB"},
"Tian":	{"NN"},
"Tibetan":	{"NNP","JJ"},
"Tibetan-like":	{"JJ"},
"Tie-vole-ee":	{"NN"},
"Tiger-turned-Federal":	{"JJ"},
"Tigrean":	{"JJ"},
"Tiles":	{"NNS"},
"Tilted":	{"VBD","VBN"},
"Time-servers":	{"NNS"},
"Timidly":	{"RB"},
"Timorese":	{"JJ","NNP"},
"Titans":	{"NNS"},
"Titled":	{"VBN"},
"Tlingit":	{"NNP","NNPS"},
"Tobagonian":	{"JJ","NNP"},
"Togolese":	{"JJ","NNP","NNPS"},
"Tonal":	{"JJ"},
"Tongan":	{"JJ","NNP"},
"Tons":	{"NNS"},
"Tools":	{"NNS"},
"Toot-toot":	{"UH"},
"Top-20":	{"JJ"},
"Top-of-the-Line":	{"JJ"},
"Topping":	{"VBG"},
"Toronto-area":	{"JJ"},
"Torrio-Capone":	{"JJ"},
"Tory":	{"NNP","JJ"},
"Tossing":	{"VBG"},
"Totally":	{"RB"},
"Touches":	{"VBZ"},
"Toujours":	{"FW"},
"Towns":	{"NNS"},
"Toyotas":	{"NNS"},
"Traces":	{"NNS"},
"Tractarian":	{"NNP","JJ"},
"Tractarians":	{"NNS"},
"Trades":	{"NNS"},
"Traditionally":	{"RB"},
"Trained":	{"VBN"},
"Training":	{"NN","VBG"},
"Traits":	{"NNS"},
"Trans-illuminated":	{"JJ"},
"Transcaucasian":	{"JJ"},
"Translocations":	{"NNS"},
"Transylvanian":	{"JJ"},
"Trapp":	{"FW"},
"Trappist":	{"JJ"},
"Traps":	{"NNS"},
"Travellers":	{"NNS"},
"Treasonable":	{"JJ"},
"Treasury-bill":	{"NN"},
"Treasury-bond":	{"JJ"},
"Trend-following":	{"JJ"},
"Trendy":	{"JJ"},
"Triassic":	{"JJ"},
"Tribes":	{"NNS"},
"Trichrome":	{"JJ"},
"Triggering":	{"VBG"},
"Trim-your-own-franks":	{"VB"},
"Trinitarian":	{"NNP","JJ"},
"Trittico":	{"FW"},
"Trojan":	{"NNP","JJ"},
"Trompe":	{"FW"},
"Troopers":	{"NNS"},
"Trotskyist":	{"NNP","JJ"},
"Trotskyite":	{"NNP","JJ"},
"Trouble-free":	{"JJ"},
"Truckers":	{"NNS"},
"Trump-watchers":	{"NNS"},
"Trumpist":	{"JJ","NNP"},
"Trupin-related":	{"JJ"},
"Trustees":	{"NNS"},
"Tsk":	{"UH"},
"Tudor":	{"NNP","JJ"},
"Tudor-style":	{"JJ"},
"Tuitions":	{"NNS"},
"Tumbling":	{"JJ"},
"Tungus":	{"NNP","NNPS","JJ"},
"Tunisian":	{"NNP","JJ"},
"Turin-based":	{"JJ"},
"Turki":	{"JJ"},
"Turkic":	{"JJ","NN"},
"Turkish":	{"JJ","NNP"},
"Turkmen":	{"JJ","NNP"},
"Turned":	{"VBN"},
"Turnpike-widening":	{"JJ"},
"Turns":	{"VBZ"},
"Tuscan":	{"NNP","JJ"},
"Tutsi":	{"NNP","NNPS"},
"Twain":	{"NN","JJ"},
"Twenty":	{"CD"},
"Twenty-year-old":	{"JJ"},
"Twice":	{"RB"},
"Twigs":	{"NNS"},
"Two-Stem":	{"JJ"},
"Two-Year":	{"JJ"},
"Two-day":	{"JJ"},
"Two-month":	{"JJ"},
"Two-part":	{"JJ"},
"Two-thirds":	{"NNS"},
"Two-year":	{"JJ"},
"Tylenol-tampering":	{"JJ"},
"Type-O":	{"JJ"},
"Types":	{"NNS"},
"Typhoean":	{"JJ"},
"Typical":	{"JJ"},
"Typically":	{"RB"},
"Tyrolean":	{"JJ","NNP"},
"Tyson-Spinks":	{"JJ"},
"U-boat":	{"NN"},
"U-turn":	{"NN"},
"U-turns":	{"NNS"},
"U.K.-based":	{"JJ"},
"U.N.-backed":	{"JJ"},
"U.N.-chartered":	{"JJ"},
"U.N.-monitored":	{"JJ"},
"U.N.-sponsored":	{"JJ"},
"U.N.-supervised":	{"JJ"},
"U.S-based":	{"JJ"},
"U.S.-Czech":	{"JJ"},
"U.S.-European":	{"JJ"},
"U.S.-German":	{"JJ"},
"U.S.-Israel-Egyptian":	{"JJ"},
"U.S.-Japanese":	{"JJ"},
"U.S.-Korean":	{"JJ"},
"U.S.-Philippine":	{"JJ"},
"U.S.-about":	{"IN"},
"U.S.-backed":	{"JJ"},
"U.S.-based":	{"JJ"},
"U.S.-built":	{"JJ"},
"U.S.-developed":	{"JJ"},
"U.S.-dollar":	{"NN"},
"U.S.-dominated":	{"JJ"},
"U.S.-donated":	{"JJ"},
"U.S.-endorsed":	{"JJ"},
"U.S.-grown":	{"JJ"},
"U.S.-led":	{"JJ"},
"U.S.-made":	{"JJ"},
"U.S.-owned":	{"JJ"},
"U.S.-produced":	{"JJ"},
"U.S.-style":	{"JJ"},
"U.S.-supplied":	{"JJ"},
"U.S.Japan":	{"JJ"},
"U.S.backed":	{"JJ"},
"U.S.based":	{"JJ"},
"U.S.concerns":	{"NNS"},
"U.S.investors":	{"NNS"},
"UFO":	{"NN"},
"UFOs":	{"NNS"},
"UI":	{"NN"},
"UNtranslatability":	{"NN"},
"US":	{"NNP","JJ"},
"USDA-sponsored":	{"JJ"},
"UTLs":	{"NNS"},
"UV":	{"JJ"},
"Ugandan":	{"JJ","NNP"},
"Uh-huh":	{"UH"},
"Uh-uh":	{"UH"},
"Uhhu":	{"UH"},
"Ukrainian":	{"JJ","NNP"},
"Ultimately":	{"RB"},
"Ulysses":	{"NNS"},
"Umm":	{"UH"},
"Unable":	{"JJ"},
"Unamused":	{"JJ"},
"Unanalyzed":	{"JJ"},
"Unanimously":	{"RB"},
"Unbelievable":	{"JJ"},
"Uncomfortably":	{"RB"},
"Uncommon":	{"JJ"},
"Unconcerned":	{"JJ"},
"Unconscionable":	{"JJ"},
"Unconsciously":	{"RB"},
"Unconstitutional":	{"JJ"},
"Uncontrolled":	{"JJ"},
"Undaunted":	{"JJ"},
"Undergraduates":	{"NNS"},
"Understandably":	{"RB"},
"Undertaken":	{"VBN"},
"Undeterred":	{"JJ"},
"Undismayed":	{"JJ"},
"Unfilled":	{"JJ"},
"Unflattering":	{"JJ"},
"Unfortunately":	{"RB"},
"Unglazed":	{"VBN"},
"Ungrateful":	{"JJ"},
"Unhappily":	{"RB"},
"Uniat":	{"NN","JJ"},
"Uniate":	{"NNP","JJ"},
"Unificationist":	{"JJ"},
"Unificationists":	{"NNS"},
"Unionist":	{"NNP","JJ"},
"Unions":	{"NNS"},
"Unitarian":	{"NNP","JJ"},
"Unitholders":	{"NNS"},
"Universal":	{"JJ"},
"University":	{"NNP","NN"},
"University-based":	{"JJ"},
"Unleaded":	{"JJ"},
"Unless":	{"IN"},
"Unlike":	{"IN"},
"Unloading":	{"VBG"},
"Unloved":	{"NNP","VBD","VBN"},
"Unoccupied":	{"JJ"},
"Unofficial":	{"JJ"},
"Unpleasant":	{"JJ"},
"Unpopular":	{"JJ"},
"Unprovable":	{"JJ"},
"Unpublished":	{"JJ"},
"Unq":	{"NN"},
"Unquestionably":	{"RB"},
"Unreported":	{"JJ"},
"Unruly":	{"JJ"},
"Unseasonably":	{"RB"},
"Unsettling":	{"JJ"},
"Unstained":	{"JJ"},
"Unsuspecting":	{"JJ"},
"Until":	{"IN"},
"Unveiled":	{"VBN"},
"Unwarranted":	{"JJ"},
"Unwholesome":	{"JJ"},
"Unwilling":	{"JJ"},
"Unwinding":	{"VBG"},
"Upholds":	{"VBZ"},
"Upped":	{"VBN"},
"Upping":	{"VBG"},
"Ups":	{"VBZ"},
"Uralic":	{"NNP","JJ"},
"Urdu":	{"NNP","JJ"},
"Urged":	{"VBD","VBN"},
"Uruguayan":	{"JJ","NNP"},
"Usbeg":	{"NNP","JJ"},
"Usbek":	{"NNP","JJ"},
"Uses":	{"NNS"},
"Using":	{"VBG"},
"Usually":	{"RB"},
"Usurpations":	{"NNS"},
"Utahan":	{"NNP","JJ"},
"Utopian":	{"JJ","NNP"},
"Utopians":	{"NNS"},
"Uzbeg":	{"NNP","JJ"},
"Uzbek":	{"NNP","JJ"},
"Uzi-model":	{"JJ"},
"V-6-equipped":	{"JJ"},
"V-shaped":	{"JJ"},
"VA-backed":	{"JJ"},
"VCR":	{"NN"},
"VCRs":	{"NNS"},
"VDU":	{"NN"},
"VDUs":	{"NNS"},
"Va.-based":	{"JJ"},
"Vacancies":	{"NNS"},
"Valued":	{"VBN"},
"Vancouver-based":	{"JJ"},
"Vanderbilts":	{"NNS"},
"Vandyke":	{"NNP","JJ"},
"Vargas":	{"NNS"},
"Vases":	{"NNS"},
"Vastly":	{"RB"},
"Vaudois":	{"NNP","NNPS"},
"Vedic":	{"JJ"},
"Vegas-based":	{"JJ"},
"Vegetables":	{"NNS"},
"Veiling":	{"VBG"},
"Vendors":	{"NNS"},
"Venetian":	{"JJ","NNP"},
"Venezuelan":	{"JJ","NNP"},
"Venturesome":	{"JJ"},
"Vergessen":	{"FW"},
"Vermont-based":	{"JJ"},
"Veronica":	{"NNP","NN"},
"Vesuvian":	{"JJ"},
"Victor-brand":	{"JJ"},
"Victorian":	{"JJ","NNP"},
"Viennese":	{"JJ","NNP"},
"Vietnam-veteran":	{"JJ"},
"Vietnamese-backed":	{"JJ"},
"Viewed":	{"VBD","VBN"},
"Viewers":	{"NNS"},
"Views":	{"NNS"},
"Villagers":	{"NNS"},
"Villages":	{"NNS"},
"Virginian":	{"NNP","JJ"},
"Virgoan":	{"NNP","JJ"},
"Viruses":	{"NNS"},
"Visayan":	{"NNP","NNPS","JJ"},
"Viscerally":	{"RB"},
"Vitamins":	{"NNS"},
"Viva":	{"FW"},
"Vivaldi-at-brunch":	{"JJ"},
"Voices":	{"NNS"},
"Voltarean":	{"JJ"},
"Voltarian":	{"JJ"},
"Volumes":	{"NNS"},
"Votes":	{"NNS"},
"Vous":	{"FW"},
"Vowels":	{"NNS"},
"Vs.":	{"FW"},
"Vt.-based":	{"JJ"},
"Vulturidae":	{"NNS"},
"W-2s":	{"NNS"},
"W-region":	{"NN"},
"Wage-price":	{"JJ"},
"Wage-settlement":	{"JJ"},
"Wagnerian":	{"JJ"},
"Wagons":	{"NNS"},
"Waist-High":	{"JJ"},
"Waited":	{"VBN"},
"Waldensian":	{"JJ"},
"Walk-in":	{"JJ"},
"Walkman-style":	{"JJ"},
"Waning":	{"JJ"},
"Wants":	{"VBZ"},
"War-related":	{"JJ"},
"Warmongering":	{"VBG"},
"Warners":	{"NNS"},
"Warranties":	{"NNS"},
"Warrants":	{"NNS"},
"Warrens":	{"NNS"},
"Wary":	{"JJ"},
"Wash.-based":	{"JJ"},
"Washing":	{"NN","VBG"},
"Washington-area":	{"JJ"},
"Washington-based":	{"JJ"},
"Washingtonian":	{"NNP","JJ"},
"Water-soluble":	{"JJ"},
"Watergate-beleaguered":	{"JJ"},
"Waterways":	{"NNS"},
"Watts":	{"NNS"},
"Watusi":	{"NNP","NNPS"},
"Watutsi":	{"NNP","NNPS"},
"Weaken":	{"VB"},
"Weakens":	{"VBZ"},
"Weakest":	{"JJS"},
"Web":	{"NNP","FW"},
"Web-based":	{"JJ"},
"Weber-controlled":	{"JJ"},
"Wedged":	{"VBD","VBN"},
"Weeds":	{"NNS"},
"Weickerian":	{"JJ"},
"Weighing":	{"VBG"},
"Weighted":	{"VBD","VBN"},
"Well-Seasoned":	{"JJ"},
"Well-Tempered":	{"JJ"},
"Well-intentioned":	{"JJ"},
"Well-received":	{"JJ"},
"Well-stretched":	{"JJ"},
"Well-to-Do":	{"JJ"},
"Well-trained":	{"JJ"},
"Well-wishers":	{"NNS"},
"Welles":	{"NNS"},
"Welmers":	{"NNS"},
"Welsh":	{"NNP","NNPS","JJ"},
"Wesleyan":	{"NNP","JJ"},
"West":	{"NNP","JJ","RB"},
"West-German":	{"JJ"},
"Westerly":	{"RB"},
"Western":	{"JJ"},
"Western-Central":	{"JJ"},
"Western-owned":	{"JJ"},
"Western-style":	{"JJ"},
"Wetten":	{"FW"},
"Wha":	{"WP"},
"Whah":	{"WRB"},
"Wheaties-box":	{"JJ"},
"Whenever":	{"WRB"},
"Whether":	{"IN"},
"Which":	{"WDT"},
"Whipsawed":	{"JJ"},
"White-collar":	{"JJ"},
"White-haired":	{"JJ"},
"White-shirted":	{"JJ"},
"Whitsun":	{"NNP","JJ"},
"Wholesalers":	{"NNS"},
"Wholesome":	{"JJ"},
"Whosever":	{"WP"},
"Wiccan":	{"JJ","NNP"},
"Widely":	{"RB"},
"Widowers":	{"NNS"},
"Williamsesque":	{"JJ"},
"Willows":	{"NNS"},
"Wilson-to-Jim":	{"JJ"},
"Wilsonian":	{"JJ"},
"Winterthur-based":	{"JJ"},
"Wires":	{"NNS"},
"Wiry":	{"JJ"},
"Wis.-based":	{"JJ"},
"Wisely":	{"RB"},
"Wishing":	{"VBG"},
"Withdrawals":	{"NNS"},
"Within":	{"IN"},
"Wittgensteinian":	{"JJ"},
"Wolof":	{"NNP","NNPS"},
"Wonderful":	{"JJ"},
"Wondering":	{"VBG"},
"Wood-products":	{"NNS"},
"Wooded":	{"JJ"},
"Word":	{"NNP","NN"},
"Wordsworthian":	{"JJ"},
"Work-outs":	{"NNS"},
"Workmen":	{"NNS"},
"Workplaces":	{"NNS"},
"Worksheets":	{"NNS"},
"Workshops":	{"NNS"},
"Workstations":	{"NNS"},
"World-wide":	{"JJ"},
"Worn":	{"VBN"},
"Worriers":	{"NNS"},
"Worth-based":	{"JJ"},
"Would":	{"MD"},
"Would-be":	{"JJ"},
"Wright-style":	{"JJ"},
"Write-offs":	{"NNS"},
"Wrongdoers":	{"NNS"},
"Wuthering":	{"JJ"},
"X-chromosome":	{"NN"},
"X-gyro":	{"NN"},
"X-linked":	{"JJ"},
"X-marked":	{"JJ"},
"X-rated":	{"JJ"},
"X-ray":	{"NNP","VB","VBP"},
"X-ray-proof":	{"JJ"},
"X-rayed":	{"VBN","VBD"},
"X-rays":	{"NNS"},
"X-region":	{"NN"},
"X-tend":	{"NN"},
"Xanthomonas":	{"NNS"},
"Xe":	{"NN"},
"Xerox":	{"NNP","VB","VBP"},
"Xeroxed":	{"VBD","VBN"},
"Xeroxes":	{"NNPS","VBZ"},
"Xeroxing":	{"VBG"},
"Xhosa":	{"NN"},
"Xmas":	{"NN"},
"Y-cells":	{"NNS"},
"Y-region":	{"NN"},
"Y-regions":	{"NNS"},
"Yajur-Veda":	{"NN"},
"Yakut":	{"NN"},
"Yalagaloo":	{"UH"},
"Yalies":	{"NNS"},
"Yank-oriented":	{"JJ"},
"Yankee-come-lately":	{"JJ"},
"Yankees-Mets":	{"JJ"},
"Year-ago":	{"JJ"},
"Year-earlier":	{"JJ"},
"Year-round":	{"RB"},
"Year-to-date":	{"JJ"},
"Years":	{"NNS"},
"Yeatsian":	{"JJ"},
"Yehhh":	{"UH"},
"Yemeni":	{"NNP","JJ"},
"Yesiree":	{"UH"},
"Yff":	{"IN"},
"Yiddish":	{"NNP","JJ"},
"Yields":	{"NNS"},
"Yooee":	{"UH"},
"York-area":	{"JJ"},
"York-based":	{"JJ"},
"Yorkshire-based":	{"JJ"},
"Yoruba":	{"NN"},
"You":	{"PRP"},
"Youngish":	{"JJ"},
"Your":	{"PRP$"},
"Yr.":	{"NN"},
"Yucatec":	{"NN"},
"Yugoslav":	{"NNP","NN","JJ"},
"Yugoslav-born":	{"JJ"},
"Yugoslavs":	{"NNS"},
"Yuletide":	{"NN"},
"Yuman":	{"JJ","NN"},
"Yuppies":	{"NNS"},
"Yuppily":	{"RB"},
"Yurak-Samoyed":	{"NN"},
"Z-axis":	{"NN"},
"Z-gyro":	{"NN"},
"Zairean":	{"JJ"},
"Zambian":	{"NNP","JJ"},
"Zapotec":	{"JJ"},
"Zapotecan":	{"NN"},
"Zealand-based":	{"JJ"},
"Zealand-dollar":	{"NN"},
"Zechariah":	{"NN"},
"Zeitgeist":	{"NN"},
"Zen-like":	{"JJ"},
"Zephaniah":	{"NN"},
"Zetland":	{"NN"},
"Zey":	{"PRP"},
"Zimbabwean":	{"NNP","JJ"},
"Zingggg-O":	{"UH"},
"Zionist":	{"NN","JJ"},
"Zip":	{"NNP","JJ","NN","IN"},
"Zodiacal":	{"JJ"},
"Zones":	{"NNS"},
"Zoroastrian":	{"JJ","NNP"},
"Zulu":	{"NNP","JJ"},
"Zur":	{"FW"},
"Zurich-based":	{"JJ"},
"Zyrian":	{"NN","JJ"},
"a":	{"DT","SYM","LS"},
"a'man":	{"NN"},
"a-Ex-dividend":	{"NN"},
"a-Includes":	{"VBZ"},
"a-Monthly":	{"JJ"},
"a-bomb":	{"NN"},
"a-coming":	{"VBG"},
"a-crowing":	{"VBG"},
"a-drinking":	{"NN"},
"a-ex-dividend":	{"NN"},
"a-gracious":	{"JJ"},
"a-ha":	{"UH"},
"a-horizon":	{"NN"},
"a-includes":	{"VBZ"},
"a-la-Aristotle":	{"NN"},
"a-la-aristotle":	{"NN"},
"a-line":	{"NN"},
"a-list":	{"NN"},
"a-ok":	{"NN"},
"a-okay":	{"JJ"},
"a-one":	{"JJ"},
"a-raising":	{"VBG"},
"a-reflects":	{"VBZ"},
"a-tall":	{"JJ"},
"a-team":	{"NN"},
"a-wing":	{"NN"},
"a.d.":	{"RB"},
"a.e.":	{"NN"},
"a.k.a":	{"JJ"},
"a.k.a.":	{"RB"},
"a.m":	{"RB","NN"},
"a.m.":	{"NN","RB"},
"aNcel":	{"NN"},
"aa":	{"NN"},
"aaa":	{"NN"},
"aachen":	{"NN"},
"aah":	{"UH","NN","VB","VBP"},
"aahed":	{"VBD","VBN"},
"aahing":	{"VBG"},
"aahs":	{"NNS","VBZ"},
"aalborg":	{"NN"},
"aalii":	{"NN"},
"aalst":	{"NN"},
"aalto":	{"NN"},
"aar":	{"NN"},
"aardvark":	{"NN"},
"aardwolf":	{"NN"},
"aare":	{"NN"},
"aarhus":	{"NN"},
"aaron":	{"NN"},
"aarp":	{"NN"},
"aas":	{"NN"},
"aave":	{"NN"},
"ab":	{"NN"},
"aba":	{"NN"},
"abaca":	{"NN"},
"abacinate":	{"VB","VBP"},
"abacinated":	{"VBD","VBN"},
"abacinates":	{"VBZ"},
"abacinating":	{"VBG"},
"aback":	{"RB"},
"abactinal":	{"JJ"},
"abacus":	{"NN"},
"abacuses":	{"NNS"},
"abadan":	{"NN"},
"abaft":	{"RB","IN"},
"abalone":	{"NN"},
"abamp":	{"NN"},
"abampere":	{"NN"},
"abandon":	{"VB","NN","VBP"},
"abandoned":	{"VBN","VBD","JJ"},
"abandoning":	{"VBG"},
"abandonment":	{"NN"},
"abandons":	{"VBZ","NNS"},
"abaringe":	{"NN"},
"abarticulation":	{"NN"},
"abase":	{"VB","VBP"},
"abased":	{"VBD","VBN"},
"abasement":	{"NN"},
"abases":	{"VBZ"},
"abash":	{"VB","VBP"},
"abashed":	{"JJ","VBD","VBN"},
"abashes":	{"VBZ"},
"abashing":	{"VBG"},
"abashment":	{"NN"},
"abasia":	{"NN"},
"abasic":	{"JJ"},
"abasing":	{"VBG"},
"abatable":	{"JJ"},
"abate":	{"VB","VBP"},
"abated":	{"VBD","VBN"},
"abatement":	{"NN"},
"abates":	{"VBZ"},
"abatic":	{"JJ"},
"abating":	{"VBG"},
"abatis":	{"NN"},
"abator":	{"NN"},
"abattis":	{"NN"},
"abattoir":	{"NN"},
"abaxial":	{"JJ"},
"abaxially":	{"RB"},
"abaya":	{"NN"},
"abb":	{"NN"},
"abbacy":	{"NN"},
"abbatial":	{"JJ"},
"abbe":	{"NN"},
"abberations":	{"NNS"},
"abbess":	{"NN"},
"abbey":	{"NN"},
"abbot":	{"NN"},
"abbreviate":	{"VB","VBP"},
"abbreviated":	{"JJ","VBD","VBN"},
"abbreviates":	{"VBZ"},
"abbreviating":	{"VBG"},
"abbreviation":	{"NN"},
"abbreviations":	{"NNS"},
"abbreviator":	{"NN"},
"abby":	{"NN"},
"abc":	{"NN"},
"abc's":	{"NNS"},
"abcoulomb":	{"NN"},
"abdias":	{"NNS"},
"abdicable":	{"JJ"},
"abdicate":	{"VB","VBP"},
"abdicated":	{"VBD","VBN"},
"abdicates":	{"VBZ"},
"abdicating":	{"VBG"},
"abdication":	{"NN"},
"abdicator":	{"NN"},
"abdomen":	{"NN"},
"abdomens":	{"NNS"},
"abdominal":	{"JJ","NN"},
"abdominis":	{"NN"},
"abdominocentesis":	{"NN"},
"abdominoplasty":	{"NN"},
"abdominous":	{"JJ"},
"abdominousness":	{"NN"},
"abdominovesical":	{"JJ"},
"abduce":	{"VB","VBP"},
"abducens":	{"NNS"},
"abducent":	{"JJ","NN"},
"abduct":	{"VB","VBP"},
"abducted":	{"VBD","VBN"},
"abducting":	{"VBG","NN"},
"abduction":	{"NN"},
"abductor":	{"NN"},
"abducts":	{"VBZ"},
"abdul":	{"NN"},
"abeam":	{"RB"},
"abecedarian":	{"JJ","NN"},
"abecedarius":	{"NN"},
"abed":	{"RB","JJ"},
"abelard":	{"NN"},
"abele":	{"NN"},
"abelia":	{"NN"},
"abelmoschus":	{"NN"},
"abelmosk":	{"NN"},
"abenaki":	{"NN"},
"aber":	{"FW"},
"abercrombie":	{"NN"},
"aberdare":	{"NN"},
"aberdonian":	{"JJ"},
"aberrance":	{"NN"},
"aberrancy":	{"NN"},
"aberrant":	{"NN","JJ"},
"aberrantly":	{"RB"},
"aberrate":	{"VB","VBP"},
"aberrated":	{"VBD","VBN"},
"aberrates":	{"VBZ"},
"aberrating":	{"VBG"},
"aberration":	{"NN"},
"aberrations":	{"NNS"},
"abet":	{"VB","VBP"},
"abetalipoproteinemia":	{"NN"},
"abetment":	{"NN"},
"abets":	{"VBZ"},
"abettal":	{"NN"},
"abetted":	{"VBD","VBN"},
"abetter":	{"NN"},
"abetting":	{"VBG","NN"},
"abettor":	{"NN"},
"abeyance":	{"NN"},
"abeyant":	{"JJ"},
"abfarad":	{"NN"},
"abhenry":	{"NN"},
"abhor":	{"VB","VBP"},
"abhorred":	{"VBD","VBN"},
"abhorrence":	{"NN"},
"abhorrent":	{"JJ","NN"},
"abhorrently":	{"RB"},
"abhorrer":	{"NN"},
"abhorring":	{"VBG"},
"abhors":	{"VBZ"},
"abidance":	{"NN"},
"abide":	{"VB","VBP"},
"abided":	{"VBD","VBN"},
"abides":	{"VBZ"},
"abiding":	{"JJ","VBG"},
"abidjan":	{"NN"},
"abience":	{"NN"},
"abient":	{"JJ"},
"abies":	{"NN"},
"abigail":	{"NN"},
"abila":	{"NN"},
"abilities":	{"NNS"},
"ability":	{"NN"},
"abiogenesis":	{"NN"},
"abiogenetic":	{"JJ"},
"abiogenist":	{"NN"},
"abiotrophy":	{"NN"},
"abject":	{"JJ","NN"},
"abjection":	{"NN"},
"abjectly":	{"RB"},
"abjuration":	{"NN"},
"abjure":	{"VB","VBP"},
"abjurer":	{"NN"},
"abkhas":	{"NNS"},
"abkhasian":	{"NN"},
"abkhaz":	{"JJ","NN"},
"abkhazia":	{"NN"},
"abkhazian":	{"JJ","NN"},
"ablactate":	{"VB","VBP"},
"ablactated":	{"VBD","VBN"},
"ablactates":	{"VBZ"},
"ablactating":	{"VBG"},
"ablactation":	{"NN"},
"ablate":	{"VB","VBP"},
"ablated":	{"VBD","VBN"},
"ablation":	{"NN"},
"ablative":	{"JJ","NN"},
"ablaut":	{"NN"},
"ablaze":	{"JJ"},
"able":	{"JJ"},
"able-bodied":	{"JJ"},
"able-bodiedism":	{"NN"},
"able-bodiedness":	{"NN"},
"able-bodism":	{"NN"},
"able-bodyism":	{"NN"},
"ableism":	{"NN"},
"ablepharia":	{"NN"},
"abler":	{"JJ","NN"},
"ablism":	{"NN"},
"abloom":	{"JJ","NN"},
"abls":	{"NNS"},
"ablution":	{"NN"},
"ablutionary":	{"JJ"},
"ably":	{"RB"},
"abm":	{"NN"},
"abnaki":	{"JJ","NN"},
"abnegate":	{"VB","VBP"},
"abnegation":	{"NN"},
"abnegator":	{"NN"},
"abnormal":	{"JJ"},
"abnormalcy":	{"NN"},
"abnormalities":	{"NNS"},
"abnormality":	{"NN"},
"abnormally":	{"RB"},
"abo":	{"NN"},
"aboard":	{"IN","RP","RB"},
"abocclusion":	{"NN"},
"abode":	{"NN","VBN","VBD"},
"abohm":	{"NN"},
"abolish":	{"VB","VBP"},
"abolishable":	{"JJ"},
"abolished":	{"VBD","VBN"},
"abolishes":	{"VBZ"},
"abolishing":	{"VBG","NN"},
"abolishment":	{"NN"},
"abolition":	{"NN"},
"abolitionary":	{"JJ"},
"abolitionism":	{"NN"},
"abolitionist":	{"NN"},
"abolitionists":	{"NNS"},
"abomasal":	{"JJ"},
"abomasum":	{"NN"},
"abominable":	{"JJ"},
"abominably":	{"RB"},
"abominate":	{"VB","VBP"},
"abominated":	{"VBD","VBN"},
"abominates":	{"VBZ"},
"abominating":	{"VBG"},
"abomination":	{"NN"},
"abominator":	{"NN"},
"abor":	{"NN"},
"aborad":	{"RB"},
"aboral":	{"JJ"},
"aboriginal":	{"NN","JJ"},
"aborigine":	{"NN"},
"aborigines":	{"NNS"},
"aborning":	{"RB"},
"abort":	{"VB","VBP"},
"aborted":	{"JJ","VBD","VBN"},
"aborticide":	{"NN"},
"abortifacient":	{"NN","JJ"},
"aborting":	{"NN","VBG"},
"abortion":	{"NN"},
"abortion-funding":	{"JJ"},
"abortion-related":	{"JJ"},
"abortion-rights":	{"NNS","JJ"},
"abortionist":	{"NN"},
"abortions":	{"NNS"},
"abortive":	{"JJ","NN"},
"abortively":	{"RB"},
"aborts":	{"VBZ"},
"abortus":	{"NN"},
"abought":	{"VBD","VBN"},
"aboulia":	{"NN"},
"aboulic":	{"JJ"},
"abound":	{"VB","NN","VBP"},
"abounded":	{"VBD","VBN"},
"abounding":	{"JJ","VBG"},
"abounds":	{"VBZ","NNS"},
"about":	{"IN","RB","RP"},
"about-face":	{"NN","VB","VBP"},
"about-faced":	{"VBD","VBN"},
"about-faces":	{"NNS","VBZ"},
"about-facing":	{"VBG"},
"above":	{"IN","JJ","RB","NN"},
"above-average":	{"JJ"},
"above-ceiling":	{"NN"},
"above-ground":	{"JJ"},
"above-market":	{"JJ"},
"above-mentioned":	{"JJ"},
"above-named":	{"JJ"},
"above-normal":	{"JJ"},
"above-noted":	{"JJ"},
"above-target":	{"JJ"},
"above-water":	{"JJ"},
"aboveboard":	{"JJ","NN"},
"aboveground":	{"JJ"},
"abovementioned":	{"JJ"},
"abracadabra":	{"UH","NN"},
"abrachia":	{"NN"},
"abradant":	{"NN"},
"abrade":	{"VB","VBP"},
"abraded":	{"VBD","VBN"},
"abrader":	{"NN"},
"abrades":	{"VBZ"},
"abrading":	{"VBG"},
"abramis":	{"NN"},
"abranchial":	{"JJ"},
"abranchiate":	{"JJ"},
"abranchious":	{"JJ"},
"abrase":	{"VB","VBP"},
"abrased":	{"VBD","VBN"},
"abrases":	{"VBZ"},
"abrasing":	{"VBG"},
"abrasion":	{"NN"},
"abrasion-resistant":	{"NN"},
"abrasive":	{"NN","JJ"},
"abrasiveness":	{"NN"},
"abrasives":	{"NNS"},
"abreact":	{"VB","VBP"},
"abreaction":	{"NN"},
"abreast":	{"RB"},
"abridge":	{"VB","VBP"},
"abridged":	{"JJ","NN","VBD","VBN"},
"abridgement":	{"NN"},
"abridger":	{"NN"},
"abridges":	{"VBZ","NNS"},
"abridging":	{"VBG","NN"},
"abridgment":	{"NN"},
"abroach":	{"JJ"},
"abroad":	{"RB"},
"abroade":	{"RB"},
"abrocoma":	{"NN"},
"abrocome":	{"NN"},
"abrogate":	{"VB","VBP"},
"abrogated":	{"VBD","VBN"},
"abrogates":	{"VBZ"},
"abrogating":	{"VBG"},
"abrogation":	{"NN"},
"abrogator":	{"NN"},
"abronia":	{"NN"},
"abrupt":	{"JJ"},
"abruption":	{"NN"},
"abruptly":	{"RB"},
"abruptly-pinnate":	{"JJ"},
"abruptness":	{"NN"},
"abruzzi":	{"NN"},
"abs":	{"NNS"},
"abscam-indicted":	{"JJ"},
"abscess":	{"NN"},
"abscessed":	{"JJ","VBD","VBN"},
"abscesses":	{"NNS","VBZ"},
"abscessing":	{"VBG"},
"abscise":	{"VB","VBP"},
"abscised":	{"VBD","VBN"},
"abscises":	{"VBZ"},
"abscising":	{"VBG"},
"abscissa":	{"NN"},
"abscission":	{"NN"},
"abscond":	{"VB","VBP"},
"absconded":	{"VBD","VBN"},
"absconder":	{"NN"},
"absconders":	{"NNS"},
"absconding":	{"VBG"},
"abscondment":	{"NN"},
"absconds":	{"VBZ"},
"abseil":	{"NN","VB","VBP"},
"abseiler":	{"NN"},
"absence":	{"NN"},
"absences":	{"NNS"},
"absense":	{"NN"},
"absent":	{"JJ","VB","VBP"},
"absent-minded":	{"JJ"},
"absent-mindedly":	{"RB"},
"absented":	{"JJ","VBD","VBN"},
"absentee":	{"NN"},
"absentee-ballot":	{"NN"},
"absenteeism":	{"NN"},
"absentees":	{"NNS"},
"absentia":	{"NN"},
"absenting":	{"VBG"},
"absently":	{"RB"},
"absentminded":	{"JJ"},
"absentmindedly":	{"RB"},
"absentmindedness":	{"NN"},
"absents":	{"VBZ"},
"absinth":	{"NN"},
"absinthe":	{"NN"},
"absolute":	{"JJ","NN"},
"absolutely":	{"RB"},
"absoluteness":	{"NN"},
"absolutes":	{"NNS"},
"absolution":	{"NN"},
"absolutism":	{"NN"},
"absolutist":	{"NN","JJ"},
"absolutistic":	{"JJ"},
"absolve":	{"VB","VBP"},
"absolved":	{"VBD","VBN"},
"absolver":	{"NN"},
"absolves":	{"VBZ"},
"absolving":	{"VBG","NN"},
"absolvitory":	{"JJ"},
"absorb":	{"VB","VBP"},
"absorbable":	{"JJ"},
"absorbance":	{"NN"},
"absorbate":	{"NN"},
"absorbed":	{"JJ","VBD","VBN"},
"absorbefacient":	{"JJ"},
"absorbency":	{"NN"},
"absorbent":	{"JJ","NN"},
"absorber":	{"NN"},
"absorbers":	{"NNS"},
"absorbing":	{"NN","JJ","VBG"},
"absorbs":	{"VBZ"},
"absorptance":	{"NN"},
"absorption":	{"NN"},
"absorptions":	{"NNS"},
"absorptive":	{"JJ"},
"absorptivity":	{"NN"},
"absquatulate":	{"VB","VBP"},
"absquatulated":	{"VBD","VBN"},
"absquatulates":	{"VBZ"},
"absquatulating":	{"VBG"},
"abstain":	{"VB","VBP"},
"abstained":	{"VBD","VBN"},
"abstainer":	{"NN"},
"abstaining":	{"VBG","NN"},
"abstains":	{"VBZ"},
"abstemious":	{"JJ"},
"abstemiously":	{"RB"},
"abstemiousness":	{"NN"},
"abstention":	{"NN"},
"abstentions":	{"NNS"},
"abstentious":	{"JJ"},
"abstinence":	{"NN"},
"abstinent":	{"JJ","NN"},
"abstract":	{"JJ","NN","VBP","VB"},
"abstracted":	{"JJ","VBD","VBN"},
"abstractedly":	{"RB"},
"abstractedness":	{"NN"},
"abstracter":	{"NN"},
"abstracting":	{"VBG"},
"abstraction":	{"NN"},
"abstractionism":	{"NN"},
"abstractionist":	{"JJ","NN"},
"abstractionists":	{"NNS"},
"abstractions":	{"NNS"},
"abstractive":	{"JJ"},
"abstractly":	{"RB"},
"abstractness":	{"NN"},
"abstractor":	{"NN"},
"abstractors":	{"NNS"},
"abstracts":	{"NNS","VBZ"},
"abstruse":	{"JJ","NN"},
"abstrusely":	{"RB"},
"abstruseness":	{"NN"},
"abstrusenesses":	{"NNS"},
"abstrusity":	{"NN"},
"absurd":	{"JJ"},
"absurdist":	{"JJ"},
"absurdities":	{"NNS"},
"absurdity":	{"NN"},
"absurdly":	{"RB"},
"absurdness":	{"NN"},
"abudefduf":	{"NN"},
"abuja":	{"NN"},
"abukir":	{"NN"},
"abulia":	{"NN"},
"abulic":	{"JJ"},
"abundance":	{"NN"},
"abundant":	{"JJ"},
"abundantly":	{"RB"},
"abusable":	{"JJ"},
"abuse":	{"NN","VB","VBP"},
"abused":	{"VBD","VBN","JJ"},
"abuser":	{"NN"},
"abusers":	{"NNS"},
"abuses":	{"NNS","VBZ"},
"abusing":	{"VBG"},
"abusive":	{"JJ","VBP","VB"},
"abusively":	{"RB"},
"abustle":	{"JJ"},
"abut":	{"VB","VBP"},
"abutilon":	{"NN"},
"abutment":	{"NN"},
"abutments":	{"NNS"},
"abuts":	{"VBZ"},
"abutted":	{"VBD","VBN"},
"abutter":	{"NN"},
"abutting":	{"VBG"},
"abuzz":	{"JJ"},
"abvolt":	{"NN"},
"abwatt":	{"NN"},
"aby":	{"VB","VBP"},
"abydos":	{"NNS"},
"abye":	{"VB","VBP"},
"abyes":	{"VBZ"},
"abying":	{"VBG"},
"abyla":	{"NN"},
"abys":	{"VBZ"},
"abysm":	{"NN"},
"abysmal":	{"JJ","NN"},
"abysmally":	{"RB"},
"abyss":	{"NN"},
"abyssal":	{"JJ"},
"abyssinia":	{"NN"},
"abyssinian":	{"NN"},
"ac":	{"NN"},
"acacia":	{"NN"},
"academe":	{"NN"},
"academeh":	{"NN"},
"academia":	{"NN"},
"academic":	{"JJ","NN"},
"academically":	{"RB"},
"academician":	{"NN"},
"academicianship":	{"NN"},
"academicism":	{"NN"},
"academics":	{"NNS","NNPS"},
"academies":	{"NNS"},
"academism":	{"NN"},
"academy":	{"NN"},
"acadian":	{"NN"},
"acalypha":	{"NN"},
"acantha":	{"NN"},
"acanthaceae":	{"NN"},
"acanthion":	{"NN"},
"acanthisitta":	{"NN"},
"acanthisittidae":	{"NN"},
"acanthocephala":	{"NN"},
"acanthocephalan":	{"NN"},
"acanthocereus":	{"NN"},
"acanthocybium":	{"NN"},
"acanthocyte":	{"NN"},
"acanthocytosis":	{"NN"},
"acanthoid":	{"JJ"},
"acantholysis":	{"NN"},
"acanthoma":	{"NN"},
"acanthophis":	{"NN"},
"acanthopterygian":	{"NN"},
"acanthopterygii":	{"NN"},
"acanthoscelides":	{"NNS"},
"acanthosis":	{"NN"},
"acanthotic":	{"JJ"},
"acanthous":	{"JJ"},
"acanthuridae":	{"NN"},
"acanthurus":	{"NN"},
"acanthus":	{"NN"},
"acapnia":	{"NN"},
"acapnial":	{"JJ"},
"acapnic":	{"JJ"},
"acapnotic":	{"JJ"},
"acaracide":	{"NN"},
"acardia":	{"NN"},
"acariasis":	{"NN"},
"acaricide":	{"NN"},
"acarid":	{"NN"},
"acaridae":	{"NN"},
"acaridiasis":	{"NN"},
"acarina":	{"NN"},
"acarine":	{"NN"},
"acariosis":	{"NN"},
"acarophobia":	{"NN"},
"acarpellous":	{"JJ"},
"acarpelous":	{"JJ"},
"acarpous":	{"JJ"},
"acarus":	{"NN"},
"acaryote":	{"NN"},
"acatalectic":	{"JJ","NN"},
"acataphasia":	{"NN"},
"acathexia":	{"NN"},
"acathexis":	{"NN"},
"acaudal":	{"JJ"},
"acaudate":	{"JJ"},
"acaulescent":	{"JJ"},
"acc":	{"NN"},
"acccounting":	{"NN"},
"accede":	{"VB","VBP"},
"acceded":	{"VBD","VBN"},
"accedes":	{"VBZ"},
"acceding":	{"VBG"},
"accelerando":	{"JJ","NN","RB"},
"accelerant":	{"NN","JJ"},
"accelerants":	{"NNS"},
"accelerate":	{"VB","VBP"},
"accelerated":	{"VBD","VBN","JJ"},
"accelerates":	{"VBZ"},
"accelerating":	{"VBG","JJ"},
"acceleration":	{"NN"},
"accelerations":	{"NNS"},
"accelerative":	{"JJ"},
"accelerator":	{"NN"},
"accelerators":	{"NNS"},
"acceleratory":	{"JJ"},
"accelerometer":	{"NN"},
"accelerometers":	{"NNS"},
"accent":	{"NN","VB","VBP"},
"accented":	{"JJ","VBD","VBN"},
"accenting":	{"VBG","NN"},
"accentor":	{"NN"},
"accents":	{"VBZ","NNS"},
"accentual":	{"JJ"},
"accentuate":	{"VB","VBP"},
"accentuated":	{"VBD","VBN"},
"accentuates":	{"VBZ","NNS"},
"accentuating":	{"VBG"},
"accentuation":	{"NN"},
"accept":	{"VB","VBP"},
"acceptability":	{"NN"},
"acceptable":	{"JJ"},
"acceptableness":	{"NN"},
"acceptably":	{"RB"},
"acceptance":	{"NN"},
"acceptances":	{"NNS"},
"acceptant":	{"JJ"},
"acceptation":	{"NN"},
"accepted":	{"JJ","VBD","VBN"},
"accepting":	{"VBG"},
"acceptive":	{"JJ"},
"acceptor":	{"NN"},
"accepts":	{"VBZ"},
"accesory":	{"NN"},
"access":	{"NN","VB","VBP"},
"accessary":	{"JJ","NN"},
"accessed":	{"VBD","VBN"},
"accesses":	{"NNS","VBZ"},
"accessibility":	{"NN"},
"accessible":	{"JJ"},
"accessing":	{"VBG","NN"},
"accession":	{"NN"},
"accessional":	{"JJ"},
"accessioned":	{"VBD","VBN"},
"accessioning":	{"VBG"},
"accessions":	{"NNS","VBZ"},
"accessorial":	{"JJ"},
"accessories":	{"NNS"},
"accessory":	{"NN","JJ"},
"accho":	{"NN"},
"acciaccatura":	{"NN"},
"accidence":	{"NN"},
"accident":	{"NN"},
"accident-prone":	{"JJ"},
"accidental":	{"JJ","NN"},
"accidental-war":	{"NN"},
"accidentally":	{"RB"},
"accidently":	{"RB"},
"accidents":	{"NNS"},
"accipiter":	{"NN"},
"accipitridae":	{"NN"},
"accipitriformes":	{"NNS"},
"accipitrine":	{"JJ"},
"acclaim":	{"NN","VB","VBP"},
"acclaimed":	{"VBD","VBN","JJ"},
"acclaiming":	{"VBG"},
"acclaims":	{"VBZ"},
"acclamation":	{"NN"},
"acclimate":	{"VB","VBP"},
"acclimated":	{"VBD","VBN"},
"acclimates":	{"VBZ"},
"acclimating":	{"VBG"},
"acclimation":	{"NN"},
"acclimatisation":	{"NN"},
"acclimatise":	{"VB","VBP"},
"acclimatised":	{"VBD","VBN","JJ"},
"acclimatises":	{"VBZ"},
"acclimatising":	{"VBG"},
"acclimatization":	{"NN"},
"acclimatize":	{"VB","VBP"},
"acclimatized":	{"VBD","VBN","JJ"},
"acclimatizes":	{"VBZ"},
"acclimatizing":	{"VBG"},
"acclivitous":	{"JJ"},
"acclivity":	{"NN"},
"accolade":	{"NN"},
"accoladed":	{"VBD","VBN"},
"accolades":	{"NNS","VBZ"},
"accolading":	{"VBG"},
"accommodate":	{"VB","VBP"},
"accommodated":	{"VBD","VBN"},
"accommodates":	{"VBZ"},
"accommodating":	{"JJ","VBG"},
"accommodatingly":	{"RB"},
"accommodation":	{"NN"},
"accommodational":	{"JJ"},
"accommodationism":	{"NN"},
"accommodations":	{"NNS"},
"accommodative":	{"JJ"},
"accommodator":	{"NN"},
"accommodators":	{"NNS"},
"accompanied":	{"VBN","VBD"},
"accompanies":	{"VBZ"},
"accompaniment":	{"NN"},
"accompaniments":	{"NNS"},
"accompanist":	{"NN"},
"accompanists":	{"NNS"},
"accompany":	{"VB","VBP"},
"accompanying":	{"VBG"},
"accompanyist":	{"NN"},
"accompli":	{"FW"},
"accomplice":	{"NN"},
"accomplices":	{"NNS"},
"accomplish":	{"VB","VBP"},
"accomplishable":	{"JJ"},
"accomplished":	{"VBN","JJ","VBD"},
"accomplishes":	{"VBZ","NNS"},
"accomplishing":	{"VBG","NN"},
"accomplishment":	{"NN"},
"accomplishments":	{"NNS"},
"accompnaying":	{"VBG"},
"accord":	{"NN","VB","VBP"},
"accord-fighter":	{"JJ"},
"accordance":	{"NN"},
"accordant":	{"JJ"},
"accordatura":	{"NN"},
"accorded":	{"VBD","VBN"},
"according":	{"JJ","RB","VBG"},
"accordingly":	{"RB"},
"accordion":	{"NN","JJ"},
"accordion-folding":	{"JJ"},
"accordionist":	{"NN"},
"accords":	{"NNS","VBZ"},
"accost":	{"VB","VBP"},
"accosted":	{"VBN","VBD"},
"accosting":	{"VBG"},
"accosts":	{"VBZ"},
"accouchement":	{"NN"},
"accoucheur":	{"NN"},
"accoucheuse":	{"NN"},
"account":	{"NN","VBP","VB"},
"accountability":	{"NN"},
"accountable":	{"JJ"},
"accountancy":	{"NN"},
"accountant":	{"NN"},
"accountants":	{"NNS"},
"accountantship":	{"NN"},
"accounted":	{"VBD","VBN"},
"accounting":	{"NN","VBG"},
"accounting-profession":	{"NN"},
"accounting-rules":	{"JJ"},
"accounts":	{"NNS","VBZ"},
"accouter":	{"VB","VBP"},
"accoutered":	{"VBD","VBN","JJ"},
"accoutering":	{"VBG"},
"accouterment":	{"NN"},
"accouterments":	{"NNS"},
"accouters":	{"VBZ"},
"accoutre":	{"VB","VBP"},
"accoutred":	{"JJ","VBD","VBN"},
"accoutrement":	{"NN"},
"accoutrements":	{"NNS"},
"accoutres":	{"VBZ"},
"accoutring":	{"VBG"},
"accra":	{"NN"},
"accredit":	{"VB","VBP"},
"accreditation":	{"NN"},
"accredited":	{"JJ","VBD","VBN"},
"accrediting":	{"VBG"},
"accredits":	{"VBZ"},
"accrete":	{"VB","VBP"},
"accreted":	{"VBD","VBN"},
"accretion":	{"NN"},
"accretionary":	{"JJ"},
"accretions":	{"NNS"},
"accretive":	{"JJ"},
"accroides":	{"NNS"},
"accrual":	{"NN"},
"accruals":	{"NNS"},
"accrue":	{"VB","VBP"},
"accrued":	{"JJ","VBD","VBN"},
"accruement":	{"NN"},
"accrues":	{"VBZ"},
"accruing":	{"VBG"},
"acculturate":	{"VB","VBP"},
"acculturated":	{"VBD","VBN"},
"acculturates":	{"VBZ"},
"acculturating":	{"VBG"},
"acculturation":	{"NN"},
"acculturational":	{"JJ"},
"acculturative":	{"JJ"},
"accumbent":	{"JJ"},
"accumulate":	{"VB","VBP"},
"accumulated":	{"VBN","VBD"},
"accumulates":	{"VBZ"},
"accumulating":	{"VBG","NN"},
"accumulation":	{"NN"},
"accumulative":	{"JJ"},
"accumulator":	{"NN"},
"accuracy":	{"NN"},
"accurate":	{"JJ"},
"accurately":	{"RB"},
"accurse":	{"VB","VBP"},
"accursed":	{"JJ","VBD","VBN"},
"accursedly":	{"RB"},
"accursedness":	{"NN"},
"accurses":	{"VBZ"},
"accursing":	{"VBG"},
"accurst":	{"JJ"},
"accusal":	{"NN"},
"accusation":	{"NN"},
"accusations":	{"NNS"},
"accusative":	{"JJ","NN"},
"accusatorial":	{"JJ"},
"accusatory":	{"JJ"},
"accuse":	{"VB","VBP"},
"accused":	{"VBN","VBD","NN","NNS"},
"accuser":	{"NN"},
"accusers":	{"NNS"},
"accuses":	{"VBZ"},
"accusing":	{"VBG","JJ"},
"accusingly":	{"RB"},
"accusive":	{"JJ"},
"accustom":	{"VB","VBP"},
"accustomed":	{"VBN","JJ","VBD"},
"accustoming":	{"VBG"},
"accustoms":	{"VBZ"},
"ace":	{"NN","JJ","VB","VBP"},
"acebutolol":	{"NN"},
"aced":	{"VBD","VBN"},
"acedia":	{"NN"},
"acellular":	{"JJ"},
"acentric":	{"JJ"},
"acephalia":	{"NN"},
"acephalism":	{"NN"},
"acephalous":	{"JJ"},
"acephaly":	{"NN"},
"acer":	{"NN"},
"aceraceae":	{"NN"},
"acerate":	{"JJ"},
"acerb":	{"JJ"},
"acerbate":	{"VB","VBP"},
"acerbated":	{"VBD","VBN"},
"acerbates":	{"VBZ"},
"acerbating":	{"VBG"},
"acerbic":	{"JJ"},
"acerbity":	{"NN"},
"acerola":	{"NN"},
"acerose":	{"JJ"},
"acervate":	{"JJ"},
"acervulus":	{"NN"},
"aces":	{"NNS","VBZ"},
"acetabular":	{"JJ"},
"acetabulum":	{"NN"},
"acetal":	{"NN"},
"acetaldehyde":	{"NN"},
"acetaldol":	{"NN"},
"acetamide":	{"NN"},
"acetaminophen":	{"NN"},
"acetanilid":	{"NN"},
"acetanilide":	{"NN"},
"acetate":	{"NN"},
"acetic":	{"JJ"},
"acetification":	{"NN"},
"acetified":	{"VBD","VBN"},
"acetifier":	{"NN"},
"acetifiers":	{"NNS"},
"acetifies":	{"VBZ"},
"acetify":	{"VB","VBP"},
"acetifying":	{"VBG"},
"acetin":	{"NN"},
"acetominophen":	{"NN"},
"acetone":	{"NN"},
"acetonemia":	{"NN"},
"acetonic":	{"JJ"},
"acetonuria":	{"NN"},
"acetophenetidin":	{"NN"},
"acetose":	{"JJ"},
"acetous":	{"JJ"},
"acetphenetidin":	{"NN"},
"acetum":	{"NN"},
"acetyl":	{"NN"},
"acetylate":	{"VB","VBP"},
"acetylated":	{"VBD","VBN"},
"acetylates":	{"VBZ"},
"acetylating":	{"VBG"},
"acetylation":	{"NN"},
"acetylcholine":	{"NN"},
"acetylene":	{"NN"},
"acetylene-fueled":	{"JJ"},
"acetylenic":	{"JJ"},
"acetylic":	{"JJ"},
"acetylise":	{"VB","VBP"},
"acetylised":	{"VBD","VBN"},
"acetylises":	{"VBZ"},
"acetylising":	{"VBG"},
"acetylize":	{"VB","VBP"},
"acetylized":	{"VBD","VBN"},
"acetylizes":	{"VBZ"},
"acetylizing":	{"VBG"},
"achaea":	{"NN"},
"achaean":	{"JJ","NN"},
"achaian":	{"NN"},
"ache":	{"VB","VBP","NN"},
"ached":	{"VBD","VBN"},
"achene":	{"NN"},
"achenial":	{"JJ"},
"acheron":	{"NN"},
"acheronian":	{"JJ"},
"acherontia":	{"NN"},
"acherontic":	{"JJ"},
"aches":	{"NNS","VBZ"},
"acheta":	{"NN"},
"achievability":	{"NN"},
"achievable":	{"JJ","NN"},
"achieve":	{"VB","VBP"},
"achieved":	{"VBN","VBD","JJ"},
"achievement":	{"NN"},
"achievement-test":	{"NN"},
"achievements":	{"NNS"},
"achiever":	{"NN"},
"achieves":	{"VBZ","NNS"},
"achieving":	{"VBG"},
"achillea":	{"NN"},
"achimenes":	{"NNS"},
"aching":	{"JJ","NN","VBG"},
"achira":	{"NN"},
"achlamydeous":	{"JJ"},
"achlorhydria":	{"NN"},
"achlorhydric":	{"JJ"},
"achoerodus":	{"NN"},
"acholia":	{"NN"},
"achomawi":	{"NN"},
"achondrite":	{"NN"},
"achondritic":	{"JJ"},
"achondroplasia":	{"NN"},
"achondroplastic":	{"JJ"},
"achondroplasty":	{"NN"},
"achras":	{"NNS"},
"achromasia":	{"NN"},
"achromatic":	{"JJ"},
"achromaticity":	{"NN"},
"achromatin":	{"NN"},
"achromatinic":	{"JJ"},
"achromatisation":	{"NN"},
"achromatise":	{"VB","VBP"},
"achromatised":	{"VBD","VBN"},
"achromatises":	{"VBZ"},
"achromatising":	{"VBG"},
"achromatism":	{"NN"},
"achromatization":	{"NN"},
"achromatize":	{"VB","VBP"},
"achromatized":	{"VBD","VBN"},
"achromatizes":	{"VBZ"},
"achromatizing":	{"VBG"},
"achromatous":	{"JJ"},
"achromia":	{"NN"},
"achromic":	{"JJ"},
"achromous":	{"JJ"},
"achromycin":	{"NN"},
"achy":	{"JJ"},
"achylia":	{"NN"},
"acicula":	{"NN"},
"acicular":	{"JJ"},
"aciculate":	{"JJ"},
"acid":	{"NN","JJ"},
"acid-fast":	{"JJ"},
"acid-forming":	{"JJ"},
"acid-loving":	{"JJ"},
"acid-rain":	{"NN","JJ"},
"acid-tasting":	{"JJ"},
"acid-wash":	{"VB","VBP"},
"acid-washed":	{"JJ","VBD","VBN"},
"acid-washes":	{"VBZ"},
"acid-washing":	{"VBG"},
"acidemia":	{"NN"},
"acidic":	{"JJ","NN"},
"acidification":	{"NN"},
"acidified":	{"VBN","VBD"},
"acidifies":	{"VBZ"},
"acidify":	{"VB","VBP"},
"acidifying":	{"VBG"},
"acidimetric":	{"JJ"},
"acidimetry":	{"NN"},
"acidity":	{"NN"},
"acidly":	{"RB"},
"acidophil":	{"NN"},
"acidophile":	{"NN"},
"acidophilic":	{"JJ"},
"acidophilous":	{"JJ"},
"acidophilus":	{"NN"},
"acidosis":	{"NN"},
"acidotic":	{"JJ"},
"acids":	{"NNS"},
"acidulate":	{"VB","VBP"},
"acidulated":	{"VBD","VBN"},
"acidulates":	{"VBZ"},
"acidulating":	{"VBG"},
"acidulation":	{"NN"},
"acidulent":	{"JJ"},
"acidulous":	{"JJ"},
"acidulousness":	{"NN"},
"aciduria":	{"NN"},
"aciduric":	{"JJ"},
"acinar":	{"JJ"},
"acing":	{"VBG"},
"acinic":	{"JJ"},
"acinonyx":	{"NN"},
"acinos":	{"NNS"},
"acinose":	{"JJ"},
"acinous":	{"JJ"},
"acinus":	{"NN"},
"acipenser":	{"NN"},
"acipenseridae":	{"NN"},
"ack-ack":	{"NN"},
"ackee":	{"NN"},
"acknowledge":	{"VB","VBP"},
"acknowledgeable":	{"JJ"},
"acknowledged":	{"VBD","VBN","JJ"},
"acknowledgement":	{"NN"},
"acknowledges":	{"VBZ"},
"acknowledging":	{"VBG"},
"acknowledgment":	{"NN"},
"acknowledgments":	{"NNS"},
"aclant":	{"NN"},
"acme":	{"NN"},
"acne":	{"NN"},
"acned":	{"JJ"},
"acneiform":	{"JJ"},
"acnidosporidia":	{"NN"},
"acocanthera":	{"NN"},
"acokanthera":	{"NN"},
"acold":	{"JJ"},
"acolyte":	{"NN"},
"aconcagua":	{"NN"},
"aconite":	{"NN"},
"aconitum":	{"NN"},
"aconte":	{"NN"},
"acoraceae":	{"NN"},
"acorea":	{"NN"},
"acores":	{"NNS"},
"acorn":	{"NN"},
"acorn-shaped":	{"JJ"},
"acorns":	{"NNS"},
"acorus":	{"NN"},
"acourse":	{"NN"},
"acousma":	{"NN"},
"acoustic":	{"JJ","NN"},
"acoustical":	{"JJ"},
"acoustically":	{"RB"},
"acoustician":	{"NN"},
"acousticophobia":	{"NN"},
"acoustics":	{"NNS"},
"acquaint":	{"VB","VBP"},
"acquaintance":	{"NN"},
"acquaintances":	{"NNS","VBZ"},
"acquaintanceship":	{"NN"},
"acquainted":	{"JJ","VBD","VBN"},
"acquainting":	{"VBG"},
"acquaints":	{"VBZ"},
"acquiesce":	{"VB","VBP"},
"acquiesced":	{"VBD","VBN"},
"acquiescence":	{"NN"},
"acquiescent":	{"JJ","NN"},
"acquiesces":	{"VBZ"},
"acquiescing":	{"VBG"},
"acquiesence":	{"NN"},
"acquirable":	{"JJ"},
"acquire":	{"VB","VBP"},
"acquired":	{"VBN","VBD","JJ"},
"acquirement":	{"NN"},
"acquirer":	{"NN"},
"acquirers":	{"NNS"},
"acquires":	{"VBZ"},
"acquiring":	{"VBG"},
"acquisition":	{"NN"},
"acquisition-hungry":	{"JJ"},
"acquisition-minded":	{"JJ"},
"acquisition-proof":	{"JJ"},
"acquisitions":	{"NNS"},
"acquisitive":	{"JJ"},
"acquisitiveness":	{"NN"},
"acquisiton":	{"NN"},
"acquistion":	{"NN"},
"acquit":	{"VB","VBP"},
"acquits":	{"VBZ"},
"acquittal":	{"NN"},
"acquittance":	{"NN"},
"acquitted":	{"VBD","VBN"},
"acquitting":	{"VBG"},
"acragas":	{"NNS"},
"acrasiomycetes":	{"NNS"},
"acre":	{"NN"},
"acre-feet":	{"NNS"},
"acre-foot":	{"NN"},
"acreage":	{"NN"},
"acres":	{"NNS"},
"acrid":	{"JJ","NN"},
"acridid":	{"NN"},
"acrididae":	{"NN"},
"acridity":	{"NN"},
"acridness":	{"NN"},
"acridotheres":	{"NNS"},
"acrilan":	{"NN"},
"acrimonious":	{"JJ"},
"acrimony":	{"NN"},
"acris":	{"NN"},
"acritical":	{"JJ"},
"acroanaesthesia":	{"NN"},
"acroanesthesia":	{"NN"},
"acrobacy":	{"NN"},
"acrobat":	{"NN"},
"acrobates":	{"NNS"},
"acrobatic":	{"JJ","NN"},
"acrobatics":	{"NNS"},
"acrobats":	{"NNS"},
"acrocarp":	{"NN"},
"acrocarpous":	{"JJ"},
"acrocarpus":	{"NN"},
"acrocentric":	{"JJ"},
"acrocephalus":	{"NN"},
"acrocephaly":	{"NN"},
"acroclinium":	{"NN"},
"acrocomia":	{"NN"},
"acrocyanosis":	{"NN"},
"acrodont":	{"NN"},
"acrogen":	{"NN"},
"acrogenic":	{"JJ"},
"acrogenous":	{"JJ"},
"acrolein":	{"NN"},
"acromegalia":	{"NN"},
"acromegalic":	{"JJ"},
"acromegaly":	{"NN"},
"acromicria":	{"NN"},
"acromikria":	{"NN"},
"acromion":	{"NN"},
"acromphalus":	{"NN"},
"acromyotonia":	{"NN"},
"acronym":	{"NN"},
"acronymic":	{"JJ"},
"acronymous":	{"JJ"},
"acropetal":	{"JJ"},
"acrophobia":	{"NN"},
"acrophobic":	{"JJ"},
"acrophony":	{"NN"},
"acropolis":	{"NN"},
"acropora":	{"NN"},
"acroscopic":	{"JJ"},
"acrosome":	{"NN"},
"across":	{"IN","RP","RB"},
"across-the-board":	{"JJ"},
"across-the-board-cuts":	{"NNS"},
"acrostic":	{"NN","JJ"},
"acrostichum":	{"NN"},
"acrylamide":	{"NN"},
"acrylate":	{"NN"},
"acrylic":	{"NN","JJ"},
"acrylic-fiber":	{"JJ"},
"acrylonitrile":	{"NN"},
"acrylonitrile-butadiene-styrene":	{"NN"},
"act":	{"NN","VBP","VB"},
"actable":	{"JJ"},
"actaea":	{"NN"},
"acted":	{"VBD","VBN"},
"acth":	{"NN"},
"actias":	{"NN"},
"actifed":	{"NN"},
"actin":	{"NN"},
"actinal":	{"JJ"},
"actinaria":	{"NN"},
"acting":	{"VBG","JJ","NN"},
"actinia":	{"NN"},
"actinian":	{"NN"},
"actiniaria":	{"NN"},
"actiniarian":	{"NN"},
"actinic":	{"JJ","NN"},
"actinide":	{"NN"},
"actinidia":	{"NN"},
"actinidiaceae":	{"NN"},
"actiniopteris":	{"NN"},
"actinism":	{"NN"},
"actinium":	{"NN"},
"actinoid":	{"JJ","NN"},
"actinolite":	{"NN"},
"actinomeris":	{"NN"},
"actinometer":	{"NN"},
"actinometric":	{"JJ"},
"actinometrical":	{"JJ"},
"actinometry":	{"NN"},
"actinomorphic":	{"JJ"},
"actinomorphous":	{"JJ"},
"actinomyces":	{"NN"},
"actinomycetaceae":	{"NN"},
"actinomycetal":	{"JJ"},
"actinomycetales":	{"NNS"},
"actinomycete":	{"NN"},
"actinomycetous":	{"JJ"},
"actinomycin":	{"NN"},
"actinomycosis":	{"NN"},
"actinomycotic":	{"JJ"},
"actinomyxidia":	{"NN"},
"actinomyxidian":	{"NN"},
"actinon":	{"NN"},
"actinopod":	{"NN"},
"actinopoda":	{"NN"},
"actinotherapy":	{"NN"},
"actinozoa":	{"NN"},
"actinozoan":	{"NN"},
"action":	{"NN","VB","VBP"},
"action-adventure":	{"JJ"},
"action-oriented":	{"JJ"},
"action-packed":	{"JJ"},
"action-results":	{"NNS"},
"actionable":	{"JJ"},
"actioned":	{"VBD","VBN"},
"actioning":	{"VBG"},
"actions":	{"NNS","VBZ"},
"actitis":	{"NN"},
"actium":	{"NN"},
"activase":	{"NN"},
"activate":	{"VB","VBP"},
"activated":	{"JJ","VBD","VBN"},
"activates":	{"VBZ"},
"activating":	{"NN","VBG"},
"activation":	{"NN"},
"activator":	{"NN"},
"active":	{"JJ","NN"},
"active-matrix":	{"JJ","NN"},
"active-player":	{"NN"},
"actively":	{"RB"},
"activeness":	{"NN"},
"actives":	{"NNS"},
"activewear":	{"NN"},
"activism":	{"NN"},
"activist":	{"NN","JJ"},
"activistic":	{"JJ"},
"activists":	{"NNS"},
"activities":	{"NNS"},
"activity":	{"NN"},
"actomyosin":	{"NN"},
"acton":	{"NN"},
"actor":	{"NN"},
"actors":	{"NNS"},
"actress":	{"NN"},
"actresses":	{"NNS"},
"acts":	{"NNS","VBZ"},
"actual":	{"JJ"},
"actualisation":	{"NN"},
"actualise":	{"VB","VBP"},
"actualised":	{"VBD","VBN"},
"actualises":	{"VBZ"},
"actualising":	{"VBG"},
"actualities":	{"NNS"},
"actuality":	{"NN"},
"actualization":	{"NN"},
"actualize":	{"VB","VBP"},
"actualized":	{"VBD","VBN"},
"actualizes":	{"VBZ"},
"actualizing":	{"VBG"},
"actually":	{"RB"},
"actuarial":	{"JJ"},
"actuarially":	{"RB"},
"actuaries":	{"NNS"},
"actuary":	{"NN"},
"actuate":	{"VB","VBP"},
"actuated":	{"VBD","VBN"},
"actuates":	{"VBZ"},
"actuating":	{"VBG"},
"actuation":	{"NN"},
"actuator":	{"NN"},
"actuators":	{"NNS"},
"acuate":	{"JJ"},
"acuity":	{"NN"},
"acular":	{"NN"},
"aculea":	{"NN"},
"aculeate":	{"JJ"},
"aculeated":	{"JJ"},
"aculeus":	{"NN"},
"acumen":	{"NN"},
"acuminate":	{"JJ","VB","VBP"},
"acuminated":	{"VBD","VBN"},
"acuminates":	{"VBZ"},
"acuminating":	{"VBG"},
"acumination":	{"NN"},
"acupoints":	{"NNS"},
"acupressure":	{"NN"},
"acupuncture":	{"NN"},
"acupunctured":	{"VBD","VBN"},
"acupunctures":	{"VBZ"},
"acupuncturing":	{"VBG"},
"acupuncturist":	{"NN"},
"acura":	{"NN"},
"acute":	{"JJ","NN"},
"acute-care":	{"NN"},
"acutely":	{"RB"},
"acuteness":	{"NN"},
"acyclic":	{"JJ"},
"acyclovir":	{"NN"},
"acyl":	{"NN"},
"acylation":	{"NN"},
"acylglycerol":	{"NN"},
"ad":	{"NN","FW"},
"ad-agency":	{"NN"},
"ad-free":	{"JJ"},
"ad-hoc":	{"JJ"},
"ad-lib":	{"JJ","NN","VB","VBP"},
"ad-libbed":	{"VBD","VBN"},
"ad-libbing":	{"VBG"},
"ad-libs":	{"VBZ","NNS"},
"ad-rate":	{"NN"},
"ad-supported":	{"JJ"},
"ad-unit":	{"NN"},
"ada":	{"NN"},
"ada-scid":	{"NN"},
"adactylia":	{"NN"},
"adactylism":	{"NN"},
"adactylous":	{"JJ"},
"adactyly":	{"NN"},
"adad":	{"NN"},
"adage":	{"NN"},
"adagio":	{"NN","JJ","RB"},
"adagios":	{"NNS"},
"adalia":	{"NN"},
"adam":	{"NN"},
"adam-and-eve":	{"NN"},
"adamance":	{"NN"},
"adamancy":	{"NN"},
"adamant":	{"JJ","NN"},
"adamantine":	{"JJ"},
"adamantly":	{"RB"},
"adana":	{"NN"},
"adansonia":	{"NN"},
"adapa":	{"NN"},
"adapid":	{"NN"},
"adapin":	{"NN"},
"adapt":	{"VB","VBP"},
"adaptability":	{"NN"},
"adaptable":	{"JJ","NN"},
"adaptation":	{"NN"},
"adaptational":	{"JJ"},
"adaptations":	{"NNS"},
"adaptative":	{"JJ"},
"adapted":	{"VBN","VBD","JJ"},
"adapter":	{"NN"},
"adapters":	{"NNS"},
"adapting":	{"NN","VBG"},
"adaption":	{"NN"},
"adaptive":	{"JJ","NN"},
"adaptor":	{"NN"},
"adapts":	{"VBZ"},
"adar":	{"NN"},
"adaxial":	{"JJ"},
"adaxially":	{"RB"},
"add":	{"VB","VBP"},
"add-in":	{"NN"},
"add-on":	{"JJ","NN"},
"add-ons":	{"NNS"},
"addable":	{"JJ"},
"addax":	{"NN"},
"added":	{"VBD","VBN","JJ"},
"added-value":	{"JJ"},
"addend":	{"NN"},
"addendum":	{"NN"},
"adder":	{"NN"},
"addible":	{"JJ"},
"addict":	{"NN"},
"addicted":	{"NN","JJ","VBD","VBN"},
"addicting":	{"VBG"},
"addiction":	{"NN"},
"addiction-treatment":	{"JJ","NN"},
"addictionologist":	{"NN"},
"addictionologists":	{"NNS"},
"addictions":	{"NNS"},
"addictive":	{"JJ","NN"},
"addicts":	{"NNS","VBZ"},
"adding":	{"VBG"},
"addition":	{"NN"},
"additional":	{"JJ"},
"additionally":	{"RB"},
"additions":	{"NNS"},
"additive":	{"NN","JJ"},
"additives":	{"NNS"},
"addle":	{"VB","VBP"},
"addle-brained":	{"JJ"},
"addle-head":	{"NN"},
"addlebrained":	{"JJ"},
"addled":	{"JJ","VBD","VBN"},
"addlehead":	{"NN"},
"addlepated":	{"JJ"},
"addles":	{"VBZ"},
"addling":	{"VBG"},
"address":	{"NN","VB","VBP"},
"addressable":	{"JJ"},
"addressed":	{"VBN","VBD"},
"addressee":	{"NN"},
"addressees":	{"NNS"},
"addresses":	{"NNS","VBZ"},
"addressing":	{"VBG"},
"addressograph":	{"NN"},
"addresss":	{"NNS"},
"adds":	{"VBZ"},
"adduce":	{"VB","VBP"},
"adduced":	{"VBD","VBN"},
"adducent":	{"JJ"},
"adducer":	{"NN"},
"adduces":	{"VBZ"},
"adducing":	{"VBG","NN"},
"adduct":	{"NN","VB","VBP"},
"adducted":	{"VBD","VBN"},
"adducting":	{"VBG"},
"adduction":	{"NN"},
"adductive":	{"JJ"},
"adductor":	{"NN"},
"adductors":	{"NNS"},
"adducts":	{"NNS","VBZ"},
"adelges":	{"NNS"},
"adelgid":	{"NN"},
"adelgidae":	{"NN"},
"adelie":	{"NN"},
"adenanthera":	{"NN"},
"adenine":	{"NN"},
"adenitis":	{"NN"},
"adenium":	{"NN"},
"adenocarcinoma":	{"NN"},
"adenocarcinomatous":	{"JJ"},
"adenocard":	{"NN"},
"adenohypophysis":	{"NN"},
"adenoid":	{"JJ","NN"},
"adenoidal":	{"JJ"},
"adenoidectomy":	{"NN"},
"adenoma":	{"NN"},
"adenomas":	{"NNS"},
"adenomegaly":	{"NN"},
"adenomyosarcoma":	{"NN"},
"adenomyosis":	{"NN"},
"adenopathy":	{"NN"},
"adenosine":	{"NN"},
"adenosis":	{"NN"},
"adenota":	{"NN"},
"adenovirus":	{"JJ","NN"},
"adept":	{"JJ","NN"},
"adeptness":	{"NN"},
"adepts":	{"NNS"},
"adequacy":	{"NN"},
"adequate":	{"JJ"},
"adequately":	{"RB"},
"adequateness":	{"NN"},
"adermin":	{"NN"},
"adesite":	{"NN"},
"adh":	{"NN"},
"adhd":	{"NN"},
"adhere":	{"VB","VBP"},
"adhered":	{"VBN","VBD"},
"adherence":	{"NN"},
"adherent":	{"NN"},
"adherents":	{"NNS"},
"adheres":	{"VBZ"},
"adhering":	{"VBG"},
"adhesion":	{"NN"},
"adhesive":	{"NN","JJ"},
"adhesiveness":	{"NN"},
"adhesives":	{"NNS"},
"adhocracy":	{"NN"},
"adiabatic":	{"JJ"},
"adiantaceae":	{"NN"},
"adiantum":	{"NN"},
"adience":	{"NN"},
"adient":	{"JJ"},
"adieu":	{"NN"},
"adige":	{"NN"},
"adios":	{"UH"},
"adipic":	{"JJ"},
"adipose":	{"JJ","NN"},
"adiposeness":	{"NN"},
"adiposis":	{"NN"},
"adiposity":	{"NN"},
"adit":	{"NN"},
"aditi":	{"NN"},
"aditya":	{"NN"},
"adjacency":	{"NN"},
"adjacent":	{"JJ"},
"adjectival":	{"JJ","NN"},
"adjectivally":	{"RB"},
"adjective":	{"NN","JJ"},
"adjectively":	{"RB"},
"adjectives":	{"NNS"},
"adjoin":	{"VB","VBP"},
"adjoined":	{"VBD","VBN"},
"adjoining":	{"JJ","VBG"},
"adjoins":	{"VBZ","NNS"},
"adjourn":	{"VB","VBP"},
"adjourned":	{"VBD","VBN"},
"adjourning":	{"NN","VBG"},
"adjournment":	{"NN"},
"adjourns":	{"VBZ","NNS"},
"adjudge":	{"VB","VBP"},
"adjudged":	{"VBD","VBN"},
"adjudges":	{"VBZ"},
"adjudging":	{"VBG"},
"adjudicate":	{"VB","VBP"},
"adjudicated":	{"VBD","VBN"},
"adjudicates":	{"VBZ"},
"adjudicating":	{"VBG"},
"adjudication":	{"NN"},
"adjudicative":	{"JJ"},
"adjudicator":	{"NN"},
"adjudicators":	{"NNS"},
"adjudicatory":	{"JJ"},
"adjunct":	{"NN"},
"adjunction":	{"NN"},
"adjunctive":	{"JJ"},
"adjuncts":	{"NNS"},
"adjuration":	{"NN"},
"adjuratory":	{"JJ"},
"adjure":	{"VB","VBP"},
"adjured":	{"VBD","VBN"},
"adjures":	{"VBZ"},
"adjuring":	{"VBG"},
"adjust":	{"VB","VBP"},
"adjustable":	{"JJ"},
"adjustable-rate":	{"JJ"},
"adjustablerate":	{"NN"},
"adjustables":	{"NNS"},
"adjusted":	{"VBN","JJ","VBD"},
"adjuster":	{"NN"},
"adjusters":	{"NNS"},
"adjusting":	{"VBG","NN"},
"adjustive":	{"JJ"},
"adjustment":	{"NN"},
"adjustments":	{"NNS"},
"adjustor":	{"NN"},
"adjusts":	{"VBZ","NNS"},
"adjutant":	{"NN"},
"adjuvant":	{"JJ","NN"},
"adlet":	{"NN"},
"adlumia":	{"NN"},
"adman":	{"NN"},
"admass":	{"NN"},
"admeasure":	{"VB","VBP"},
"admeasured":	{"VBD","VBN"},
"admeasurement":	{"NN"},
"admeasurer":	{"NN"},
"admeasurers":	{"NNS"},
"admeasures":	{"VBZ"},
"admeasuring":	{"VBG"},
"admen":	{"NNS"},
"administer":	{"VB","VBP"},
"administered":	{"VBD","VBN"},
"administering":	{"VBG","NN"},
"administers":	{"NNS","VBZ"},
"administrable":	{"JJ"},
"administrate":	{"VB","VBP"},
"administrated":	{"VBD","VBN"},
"administrates":	{"VBZ"},
"administrating":	{"VBG"},
"administration":	{"NN"},
"administration-Fed":	{"JJ"},
"administration-fed":	{"JJ"},
"administration-insured":	{"JJ"},
"administrations":	{"NNS"},
"administrative":	{"JJ"},
"administratively":	{"RB"},
"administrator":	{"NN"},
"administrator-general":	{"NN"},
"administrators":	{"NNS"},
"administrivia":	{"NN"},
"adminstration":	{"NN"},
"adminstrative":	{"JJ"},
"admirability":	{"NN"},
"admirable":	{"JJ"},
"admirableness":	{"NN"},
"admirably":	{"RB"},
"admiral":	{"NN"},
"admirals":	{"NNS"},
"admiralty":	{"NN"},
"admiration":	{"NN"},
"admire":	{"VB","VBP"},
"admired":	{"VBD","VBN","JJ"},
"admirer":	{"NN"},
"admirers":	{"NNS"},
"admires":	{"VBZ","NNS"},
"admiring":	{"NN","JJ","VBG"},
"admiringly":	{"RB"},
"admissibility":	{"NN"},
"admissible":	{"JJ"},
"admission":	{"NN"},
"admissions":	{"NNS"},
"admissive":	{"JJ"},
"admit":	{"VB","VBP"},
"admits":	{"VBZ","NNS"},
"admittable":	{"JJ"},
"admittance":	{"NN"},
"admittances":	{"NNS"},
"admitted":	{"VBD","VBN","JJ"},
"admittedly":	{"RB"},
"admittees":	{"NNS"},
"admittible":	{"JJ"},
"admitting":	{"VBG"},
"admix":	{"VB","VBP"},
"admixed":	{"VBD","VBN"},
"admixes":	{"VBZ"},
"admixing":	{"VBG"},
"admixture":	{"NN"},
"admixtures":	{"NNS"},
"admonish":	{"VB","VBP"},
"admonished":	{"VBD","VBN"},
"admonisher":	{"NN"},
"admonishes":	{"VBZ"},
"admonishing":	{"VBG","NN"},
"admonishment":	{"NN"},
"admonishments":	{"NNS"},
"admonition":	{"NN"},
"admonitions":	{"NNS"},
"admonitory":	{"JJ","NN"},
"adnate":	{"JJ"},
"adnexa":	{"NN"},
"adnexal":	{"JJ"},
"adnoun":	{"NN"},
"ado":	{"NN"},
"adobe":	{"NN"},
"adobo":	{"NN"},
"adolesce":	{"VB","VBP"},
"adolesced":	{"VBD","VBN"},
"adolescence":	{"NN"},
"adolescent":	{"JJ","NN"},
"adolescents":	{"NNS"},
"adolesces":	{"VBZ"},
"adolescing":	{"VBG"},
"adolf":	{"NN"},
"adonic":	{"JJ","NN"},
"adopt":	{"VB","VBP"},
"adoptable":	{"JJ"},
"adopted":	{"VBN","VBD","JJ"},
"adoptee":	{"NN"},
"adoptees":	{"NNS"},
"adopter":	{"NN"},
"adopters":	{"NNS"},
"adopting":	{"VBG"},
"adoption":	{"NN"},
"adoption-assistance":	{"JJ"},
"adoption-business":	{"NN"},
"adoptions":	{"NNS"},
"adoptive":	{"JJ","NN"},
"adopts":	{"VBZ","NNS"},
"adorability":	{"NN"},
"adorable":	{"JJ","NN"},
"adorableness":	{"NN"},
"adorably":	{"RB"},
"adoration":	{"NN"},
"adore":	{"VB","VBP"},
"adored":	{"VBD","VBN"},
"adorer":	{"NN"},
"adores":	{"VBZ","NNS"},
"adoring":	{"JJ","VBG"},
"adoringly":	{"RB"},
"adorn":	{"VB","VBP"},
"adorned":	{"VBD","VBN"},
"adorning":	{"VBG"},
"adornment":	{"NN"},
"adornments":	{"NNS"},
"adorns":	{"VBZ"},
"adoxography":	{"NN"},
"adp":	{"NN"},
"adpersonin":	{"NN"},
"adpressed":	{"JJ"},
"adps":	{"NNS"},
"adrenal":	{"JJ","NN"},
"adrenalectomy":	{"NN"},
"adrenalin":	{"NN"},
"adrenaline":	{"NN"},
"adrenarche":	{"NN"},
"adrenergic":	{"JJ","NN"},
"adrenocortical":	{"JJ"},
"adrenocorticotrophic":	{"JJ"},
"adrenocorticotrophin":	{"NN"},
"adrenocorticotropic":	{"JJ"},
"adrenocorticotropin":	{"NN"},
"adrenosterone":	{"NN"},
"adrianopolis":	{"NNS"},
"adrift":	{"JJ","NN"},
"adroit":	{"JJ"},
"adroitly":	{"RB"},
"adroitness":	{"NN"},
"ads":	{"NNS"},
"adscititious":	{"JJ"},
"adscript":	{"JJ"},
"adscripted":	{"JJ"},
"adsorb":	{"VB","VBP"},
"adsorbable":	{"JJ"},
"adsorbate":	{"JJ","NN"},
"adsorbed":	{"VBN","VBD"},
"adsorbent":	{"JJ","NN"},
"adsorbing":	{"VBG"},
"adsorbs":	{"VBZ"},
"adsorption":	{"NN"},
"adsorptive":	{"JJ"},
"adulate":	{"VB","VBP"},
"adulated":	{"VBD","VBN"},
"adulates":	{"VBZ"},
"adulating":	{"VBG"},
"adulation":	{"NN"},
"adulator":	{"NN"},
"adulatory":	{"NN","JJ"},
"adult":	{"NN","JJ"},
"adult-literacy":	{"NN"},
"adult-training":	{"JJ"},
"adulterant":	{"NN","JJ"},
"adulterate":	{"VB","VBP"},
"adulterated":	{"JJ","VBD","VBN"},
"adulterates":	{"VBZ"},
"adulterating":	{"JJ","VBG"},
"adulteration":	{"NN"},
"adulterator":	{"NN"},
"adulterer":	{"NN"},
"adulterers":	{"NNS"},
"adulteress":	{"NN"},
"adulterine":	{"JJ"},
"adulterous":	{"JJ"},
"adulterously":	{"RB"},
"adultery":	{"NN"},
"adulthood":	{"NN"},
"adultlike":	{"JJ"},
"adults":	{"NNS"},
"adumbrate":	{"VB","VBP"},
"adumbrated":	{"VBD","VBN"},
"adumbrates":	{"VBZ"},
"adumbrating":	{"VBG"},
"adumbration":	{"NN"},
"adumbrations":	{"NNS"},
"adumbrative":	{"JJ"},
"adust":	{"JJ"},
"advance":	{"NN","VB","VBP","JJ"},
"advance-purchase":	{"JJ","NN"},
"advanced":	{"JJ","VBD","VBN"},
"advanced-ceramics":	{"NN","NNS"},
"advanced-materials":	{"JJ"},
"advanced-technology":	{"JJ","NN"},
"advancement":	{"NN"},
"advancements":	{"NNS"},
"advancer":	{"NN"},
"advancers":	{"NNS"},
"advances":	{"NNS","VBZ"},
"advancing":	{"VBG","JJ"},
"advantage":	{"NN","VB"},
"advantaged":	{"VBD","VBN","JJ"},
"advantageous":	{"JJ"},
"advantageously":	{"RB"},
"advantageousness":	{"NN"},
"advantages":	{"NNS","VBZ"},
"advantaging":	{"VBG"},
"advect":	{"VB","VBP"},
"advected":	{"VBD","VBN"},
"advecting":	{"VBG"},
"advection":	{"NN"},
"advective":	{"JJ"},
"advects":	{"VBZ"},
"advent":	{"NN"},
"adventism":	{"NN"},
"adventist":	{"NN"},
"adventitia":	{"NN"},
"adventitial":	{"JJ"},
"adventitious":	{"JJ"},
"adventive":	{"JJ"},
"adventure":	{"NN","VB","VBP"},
"adventure-based":	{"JJ"},
"adventure-loving":	{"JJ"},
"adventured":	{"VBD","VBN"},
"adventurer":	{"NN"},
"adventurers":	{"NNS"},
"adventures":	{"NNS","VBZ"},
"adventuresome":	{"JJ","NN"},
"adventuress":	{"NN"},
"adventuring":	{"VBG","NN"},
"adventurism":	{"NN"},
"adventurist":	{"NN","JJ"},
"adventuristic":	{"JJ"},
"adventurists":	{"NNS"},
"adventurous":	{"JJ","NN"},
"adventurously":	{"RB"},
"adventurousness":	{"NN"},
"adverb":	{"NN"},
"adverbial":	{"JJ","NN"},
"adverbially":	{"RB"},
"adverbials":	{"NNS"},
"adverbs":	{"NNS"},
"adversarial":	{"JJ"},
"adversaries":	{"NNS"},
"adversary":	{"NN"},
"adversative":	{"JJ","NN"},
"adverse":	{"JJ"},
"adversely":	{"RB"},
"adversities":	{"NNS"},
"adversity":	{"NN"},
"advert":	{"VB","VBP","NN"},
"adverted":	{"VBD","VBN"},
"advertence":	{"NN"},
"advertency":	{"NN"},
"advertent":	{"JJ"},
"advertently":	{"RB"},
"adverting":	{"VBG"},
"advertise":	{"VB","VBP"},
"advertised":	{"VBD","VBN","JJ"},
"advertisement":	{"NN"},
"advertisements":	{"NNS"},
"advertiser":	{"NN"},
"advertiser-bankrolled":	{"JJ"},
"advertiser-programming":	{"NN"},
"advertiser-sponsored":	{"JJ"},
"advertisers":	{"NNS"},
"advertises":	{"VBZ"},
"advertising":	{"NN","VBG"},
"advertising-backed":	{"JJ"},
"advertising-conscious":	{"JJ"},
"advertize":	{"VB"},
"advertizement":	{"NN"},
"advertizer":	{"NN"},
"advertizing":	{"NN"},
"advertorial":	{"JJ","NN"},
"adverts":	{"VBZ","NNS"},
"advice":	{"NN"},
"advisability":	{"NN"},
"advisable":	{"JJ"},
"advise":	{"VB","VBP"},
"advised":	{"VBD","VBN"},
"advisedly":	{"RB"},
"advisee":	{"NN"},
"advisement":	{"NN"},
"adviser":	{"NN"},
"advisers":	{"NNS"},
"advises":	{"VBZ"},
"advising":	{"VBG"},
"advisor":	{"NN"},
"advisories":	{"NNS"},
"advisors":	{"NNS"},
"advisory":	{"JJ","NN"},
"advocacy":	{"NN"},
"advocate":	{"NN","VBP","VB"},
"advocated":	{"VBD","VBN"},
"advocates":	{"NNS","VBZ"},
"advocating":	{"VBG"},
"advocator":	{"NN"},
"advowson":	{"NN"},
"adynamia":	{"NN"},
"adynamic":	{"JJ"},
"adz":	{"NN"},
"adze":	{"NN"},
"adzhar":	{"NN"},
"adzharia":	{"NN"},
"aec":	{"NN"},
"aecial":	{"JJ"},
"aeciospore":	{"NN"},
"aecium":	{"NN"},
"aedes":	{"NN"},
"aegates":	{"NNS"},
"aegiceras":	{"NNS"},
"aegilops":	{"NNS"},
"aegina":	{"NN"},
"aegir":	{"NN"},
"aegis":	{"NN"},
"aegis-class":	{"JJ"},
"aegisthus":	{"NN"},
"aegospotami":	{"NN"},
"aegospotamos":	{"NNS"},
"aegypiidae":	{"NN"},
"aegypius":	{"NN"},
"aegyptopithecus":	{"NN"},
"aeneas":	{"NNS"},
"aengus":	{"NN"},
"aeolia":	{"NN"},
"aeolian":	{"JJ","NN"},
"aeolic":	{"NN"},
"aeolis":	{"NN"},
"aeolotropic":	{"JJ"},
"aeolus":	{"NN"},
"aeon":	{"NN"},
"aeonian":	{"JJ"},
"aeonium":	{"NN"},
"aepyceros":	{"NN"},
"aepyornidae":	{"NN"},
"aepyorniformes":	{"NNS"},
"aepyornis":	{"NN"},
"aerate":	{"VB","VBP"},
"aerated":	{"JJ","VBD","VBN"},
"aerates":	{"VBZ"},
"aerating":	{"VBG"},
"aeration":	{"NN"},
"aerator":	{"NN"},
"aerial":	{"NN","JJ"},
"aerialist":	{"NN"},
"aerialists":	{"NNS"},
"aerially":	{"RB"},
"aerials":	{"NNS"},
"aerides":	{"NNS"},
"aerie":	{"NN"},
"aeriferous":	{"JJ"},
"aeriform":	{"JJ"},
"aerify":	{"VB"},
"aerobacter":	{"NN"},
"aerobatic":	{"JJ"},
"aerobatics":	{"NNS"},
"aerobe":	{"NN"},
"aerobic":	{"JJ"},
"aerobics":	{"NN"},
"aerobiosis":	{"NN"},
"aerobiotic":	{"JJ"},
"aerodontalgia":	{"NN"},
"aerodrome":	{"NN"},
"aerodynamic":	{"JJ"},
"aerodynamics":	{"NN"},
"aeroembolism":	{"NN"},
"aerofoil":	{"NN"},
"aerogenerator":	{"NN"},
"aerogenes":	{"NNS"},
"aerogram":	{"NN"},
"aerogramme":	{"NN"},
"aerolite":	{"NN"},
"aerolitic":	{"JJ"},
"aerological":	{"JJ"},
"aerology":	{"NN"},
"aeromechanic":	{"JJ"},
"aeromechanics":	{"NN"},
"aeromedical":	{"JJ"},
"aeromedicine":	{"NN"},
"aeronaut":	{"NN"},
"aeronautic":	{"JJ"},
"aeronautical":	{"JJ"},
"aeronautics":	{"NN"},
"aerophagia":	{"NN"},
"aerophilatelic":	{"JJ"},
"aerophilately":	{"NN"},
"aerophile":	{"NN"},
"aerophilic":	{"JJ"},
"aerophilous":	{"JJ"},
"aerophyte":	{"NN"},
"aeroplane":	{"NN"},
"aeroponic":	{"JJ"},
"aerosal":	{"NN"},
"aerosol":	{"NN"},
"aerosolise":	{"VB","VBP"},
"aerosolised":	{"JJ","VBD","VBN"},
"aerosolises":	{"VBZ"},
"aerosolising":	{"VBG"},
"aerosolize":	{"VB","VBP"},
"aerosolized":	{"JJ","VBD","VBN"},
"aerosolizes":	{"VBZ"},
"aerosolizing":	{"VBG"},
"aerosols":	{"NNS"},
"aerospace":	{"NN","JJ"},
"aerospace-industry":	{"NN"},
"aertex":	{"NN"},
"aery":	{"JJ","NN"},
"aeschylean":	{"JJ"},
"aeschynanthus":	{"NN"},
"aesculapian":	{"JJ"},
"aesculapius":	{"NN"},
"aesculus":	{"NN"},
"aesir":	{"NN"},
"aesop":	{"NN"},
"aesthesia":	{"NN"},
"aesthesis":	{"NN"},
"aesthete":	{"NN"},
"aesthetes":	{"NNS"},
"aesthetic":	{"JJ","NN"},
"aesthetical":	{"JJ"},
"aesthetically":	{"RB"},
"aesthetician":	{"NN"},
"aesthetics":	{"NN"},
"aestival":	{"JJ"},
"aestivate":	{"VB"},
"aestivation":	{"NN"},
"aeterna":	{"FW"},
"aeternitatis":	{"FW"},
"aether":	{"NN"},
"aethionema":	{"NN"},
"aethusa":	{"NN"},
"aetiologic":	{"JJ"},
"aetiological":	{"JJ"},
"aetiologist":	{"NN"},
"aetiology":	{"NN"},
"aetobatus":	{"NN"},
"af":	{"NN"},
"af-fold":	{"JJ"},
"af-inch":	{"JJ"},
"af-stage":	{"JJ"},
"af-values":	{"NNS"},
"afar":	{"RB"},
"afeard":	{"JJ"},
"afeared":	{"JJ"},
"afebrile":	{"JJ"},
"affability":	{"NN"},
"affable":	{"JJ"},
"affableness":	{"NN"},
"affably":	{"RB"},
"affadavit":	{"NN"},
"affair":	{"NN"},
"affaire":	{"NN"},
"affairs":	{"NNS"},
"affect":	{"VB","VBP"},
"affectation":	{"NN"},
"affectations":	{"NNS"},
"affected":	{"VBN","VBD","JJ"},
"affectedly":	{"RB"},
"affectedness":	{"NN"},
"affecting":	{"VBG","JJ"},
"affectingly":	{"RB"},
"affection":	{"NN"},
"affectional":	{"JJ"},
"affectionate":	{"JJ"},
"affectionately":	{"RB"},
"affectionateness":	{"NN"},
"affections":	{"NNS"},
"affective":	{"JJ"},
"affects":	{"VBZ"},
"affenpinscher":	{"NN"},
"afferent":	{"JJ","NN"},
"affiance":	{"VB","VBP"},
"affianced":	{"VBD","VBN"},
"affiances":	{"VBZ"},
"affiancing":	{"VBG"},
"affiant":	{"NN"},
"affidavit":	{"NN"},
"affidavits":	{"NNS"},
"affilates":	{"NNS"},
"affiliate":	{"NN","VB","VBP"},
"affiliated":	{"VBD","VBN","JJ"},
"affiliates":	{"VBZ","NNS"},
"affiliating":	{"VBG","NN"},
"affiliation":	{"NN"},
"affiliations":	{"NNS"},
"affiliative":	{"JJ"},
"affilliate":	{"NN"},
"affinal":	{"JJ"},
"affine":	{"JJ","NN"},
"affined":	{"JJ"},
"affinities":	{"NNS"},
"affinity":	{"NN"},
"affirm":	{"VB","NN","VBP"},
"affirmable":	{"JJ"},
"affirmation":	{"NN"},
"affirmations":	{"NNS"},
"affirmative":	{"JJ","NN"},
"affirmative-action":	{"NN"},
"affirmatively":	{"RB"},
"affirmativeness":	{"NN"},
"affirmatory":	{"JJ"},
"affirmed":	{"VBD","VBN"},
"affirmer":	{"NN"},
"affirming":	{"VBG","NN"},
"affirms":	{"VBZ","NNS"},
"affix":	{"VB","VBP","NN"},
"affixal":	{"JJ"},
"affixation":	{"NN"},
"affixed":	{"VBD","VBN"},
"affixes":	{"VBZ","NNS"},
"affixial":	{"JJ"},
"affixing":	{"VBG"},
"afflatus":	{"NN"},
"afflict":	{"VB","VBP"},
"afflicted":	{"VBD","VBN"},
"afflicting":	{"VBG"},
"affliction":	{"NN"},
"afflictions":	{"NNS"},
"afflictive":	{"JJ"},
"afflicts":	{"VBZ"},
"affluence":	{"NN"},
"affluent":	{"JJ"},
"afford":	{"VB","VBP"},
"affordability":	{"NN"},
"affordable":	{"JJ"},
"afforded":	{"VBD","VBN"},
"affording":	{"VBG","NN"},
"affords":	{"VBZ"},
"afforest":	{"VB"},
"afforestation":	{"NN"},
"afforested":	{"VBD","VBN"},
"afforesting":	{"VBG"},
"afforests":	{"VBZ"},
"affranchise":	{"VB"},
"affray":	{"NN"},
"affrays":	{"NNS"},
"affricate":	{"NN"},
"affrication":	{"NN"},
"affricative":	{"NN"},
"affright":	{"VB","VBP"},
"affrighted":	{"VBD","VBN"},
"affrighting":	{"VBG"},
"affrights":	{"VBZ"},
"affront":	{"NN","VB","VBP"},
"affronted":	{"VBN","VBD"},
"affronting":	{"VBG"},
"affronts":	{"VBZ","NNS"},
"affusion":	{"NN"},
"afghan-pakistan":	{"JJ"},
"afghani":	{"NN"},
"afghanistan":	{"NN"},
"afghanistani":	{"JJ","NN"},
"afghans":	{"NNS"},
"afibrinogenemia":	{"NN"},
"aficionado":	{"NN"},
"aficionados":	{"NNS","RB","IN","JJ"},
"afield":	{"RB"},
"afire":	{"JJ","RB"},
"afisr":	{"NN"},
"afl":	{"NN"},
"afl-cio":	{"NN"},
"aflame":	{"JJ","RB"},
"aflare":	{"JJ"},
"aflatoxin":	{"NN"},
"aflatoxin-free":	{"JJ"},
"aflatoxin-producing":	{"JJ"},
"aflatoxin-related":	{"JJ"},
"aflaxen":	{"NN"},
"aflicker":	{"JJ"},
"afloat":	{"JJ","RB"},
"aflutter":	{"JJ","NN"},
"afoot":	{"JJ","RB","NN"},
"aforementioned":	{"JJ","NN","NNS"},
"aforesaid":	{"JJ","NN"},
"aforethought":	{"JJ"},
"afoul":	{"RB"},
"afp":	{"NN"},
"afraid":	{"JJ"},
"aframomum":	{"NN"},
"afrasian":	{"NN"},
"afresh":	{"RB"},
"africa":	{"NN"},
"african-controlled":	{"JJ"},
"african-safari":	{"JJ"},
"africander":	{"NN"},
"afrikaans":	{"JJ","NN"},
"afrikander":	{"NN"},
"afrl":	{"NN"},
"afro":	{"NN","JJ"},
"afro-american":	{"JJ","NN"},
"afro-asiatic":	{"NN"},
"afro-cuban":	{"JJ"},
"afro-wig":	{"NN"},
"afroasiatic":	{"NN"},
"afrocarpus":	{"NN"},
"afropavo":	{"NN"},
"afspc":	{"NN"},
"aft":	{"JJ","RB"},
"after":	{"IN","RB","RP","JJ","CC"},
"after-dinner":	{"JJ"},
"after-duty":	{"JJ"},
"after-effects":	{"NNS"},
"after-hours":	{"JJ"},
"after-run":	{"JJ"},
"after-school":	{"JJ","NN"},
"after-shave":	{"NN"},
"after-tax":	{"JJ","NN"},
"after-the-fact":	{"JJ"},
"afterall":	{"RB"},
"afterbirth":	{"NN"},
"afterburner":	{"NN"},
"afterburners":	{"NNS"},
"aftercare":	{"NN"},
"afterdamp":	{"NN"},
"afterdeck":	{"NN"},
"aftereffect":	{"NN"},
"aftereffects":	{"NNS"},
"afterglow":	{"NN"},
"afterimage":	{"NN"},
"afterlife":	{"NN"},
"aftermarket":	{"NN"},
"aftermath":	{"NN"},
"aftermaths":	{"NNS"},
"aftermost":	{"JJ"},
"afternoon":	{"NN","UH"},
"afternoons":	{"NNS","RB"},
"afterpains":	{"NNS"},
"afterpiece":	{"NN"},
"afters":	{"NNS"},
"afterschool":	{"JJ"},
"aftersensation":	{"NN"},
"aftershaft":	{"NN"},
"aftershafted":	{"JJ"},
"aftershave":	{"NN"},
"aftershock":	{"NN"},
"aftershock-damping":	{"JJ"},
"aftershock-resistant":	{"JJ"},
"aftershocks":	{"NNS"},
"aftertaste":	{"NN"},
"aftertax":	{"JJ","NN"},
"afterthought":	{"NN"},
"afterward":	{"RB"},
"afterwards":	{"RB"},
"afterworld":	{"NN"},
"aftuh":	{"RB"},
"ag":	{"NN","JJ"},
"aga":	{"NN"},
"again":	{"RB"},
"against":	{"IN"},
"againt":	{"NN"},
"agal":	{"NN"},
"agalactia":	{"NN"},
"agalactosis":	{"NN"},
"agalinis":	{"NN"},
"agama":	{"NN"},
"agamete":	{"NN"},
"agamic":	{"JJ"},
"agamid":	{"NN"},
"agamidae":	{"NN"},
"agammaglobulinemia":	{"NN"},
"agamogenesis":	{"NN"},
"agamogenetic":	{"JJ"},
"agamous":	{"JJ"},
"agapanthus":	{"NN"},
"agape":	{"JJ","NN"},
"agapornis":	{"NN"},
"agar":	{"NN"},
"agar-agar":	{"NN"},
"agaric":	{"NN"},
"agaricaceae":	{"NN"},
"agaricales":	{"NNS"},
"agaricus":	{"NN"},
"agassiz":	{"NN"},
"agastache":	{"NN"},
"agate":	{"NN"},
"agates":	{"NNS"},
"agateware":	{"NN"},
"agatha":	{"NN"},
"agathis":	{"NN"},
"agavaceae":	{"NN"},
"agave":	{"NN"},
"agayne":	{"RB"},
"agaze":	{"JJ"},
"agdestis":	{"NN"},
"agdistis":	{"NN"},
"age":	{"NN","VBP","VB"},
"age-and-sex":	{"JJ"},
"age-bias":	{"JJ"},
"age-discrimination":	{"JJ","NN"},
"age-old":	{"JJ"},
"age-related":	{"JJ"},
"age-specific":	{"JJ"},
"aged":	{"VBN","JJ","VBD"},
"aged-care":	{"NN"},
"agedness":	{"NN"},
"agee":	{"NN"},
"ageing":	{"JJ","NN","VBG"},
"ageism":	{"NN"},
"agelaius":	{"NN"},
"ageless":	{"JJ","NN"},
"agelessness":	{"NN"},
"agelong":	{"JJ"},
"agencies":	{"NNS"},
"agency":	{"NN"},
"agency-dealing":	{"JJ"},
"agenda":	{"NN"},
"agenda-setter":	{"NN"},
"agendas":	{"NNS"},
"agendum":	{"NN"},
"agene":	{"NN"},
"agenesia":	{"NN"},
"agenesis":	{"NN"},
"agenise":	{"VB"},
"agenize":	{"VB"},
"agent":	{"NN"},
"agent-in-place":	{"NN"},
"agential":	{"JJ"},
"agents":	{"NNS"},
"agents-in-training":	{"NNS"},
"agerasia":	{"NN"},
"ageratina":	{"NN"},
"ageratum":	{"NN"},
"ages":	{"NNS","VBZ"},
"aggeus":	{"NN"},
"aggie":	{"NN"},
"agglomerate":	{"JJ","NN"},
"agglomerated":	{"VBD","VBN"},
"agglomeration":	{"NN"},
"agglomerative":	{"JJ"},
"agglomerator":	{"NN"},
"agglutinate":	{"JJ","VB"},
"agglutinated":	{"VBD","VBN"},
"agglutinates":	{"VBZ"},
"agglutinating":	{"VBG"},
"agglutination":	{"NN"},
"agglutinative":	{"JJ"},
"agglutinin":	{"NN"},
"agglutinins":	{"NNS"},
"agglutinogen":	{"NN"},
"aggrade":	{"VB"},
"aggrandise":	{"VB","VBP"},
"aggrandised":	{"VBD","VBN"},
"aggrandisement":	{"NN"},
"aggrandises":	{"VBZ"},
"aggrandising":	{"VBG"},
"aggrandize":	{"VB","VBP"},
"aggrandized":	{"VBD","VBN"},
"aggrandizement":	{"NN"},
"aggrandizes":	{"VBZ"},
"aggrandizing":	{"VBG"},
"aggravate":	{"VB","VBP"},
"aggravated":	{"JJ","VBD","VBN"},
"aggravates":	{"VBZ"},
"aggravating":	{"JJ","VBG"},
"aggravatingly":	{"RB"},
"aggravation":	{"NN"},
"aggravations":	{"NNS"},
"aggravator":	{"NN"},
"aggregate":	{"NN","VB","VBP","JJ"},
"aggregated":	{"JJ","VBD","VBN"},
"aggregates":	{"NNS","VBZ"},
"aggregating":	{"VBG"},
"aggregation":	{"NN"},
"aggregations":	{"NNS"},
"aggregative":	{"JJ"},
"aggregator":	{"NN"},
"aggress":	{"VB"},
"aggression":	{"NN"},
"aggressions":	{"NNS"},
"aggressive":	{"JJ"},
"aggressively":	{"RB"},
"aggressiveness":	{"NN"},
"aggressor":	{"NN"},
"aggrieve":	{"VB","VBP"},
"aggrieved":	{"VBD","VBN","JJ"},
"aggrieves":	{"VBZ"},
"aggrieving":	{"VBG"},
"aggro":	{"NN"},
"aggroup":	{"VB"},
"agha":	{"NN"},
"aghan":	{"NN"},
"aghast":	{"JJ"},
"agile":	{"JJ","NN"},
"agilely":	{"RB"},
"agility":	{"NN"},
"agin":	{"IN"},
"agincourt":	{"NN"},
"aging":	{"VBG","NN","JJ"},
"agio":	{"NN"},
"agiotage":	{"NN"},
"agism":	{"NN"},
"agitate":	{"VB","VBP"},
"agitated":	{"JJ","VBD","VBN"},
"agitates":	{"VBZ"},
"agitating":	{"VBG"},
"agitation":	{"NN"},
"agitative":	{"JJ"},
"agitator":	{"NN"},
"agitators":	{"NNS"},
"agitprop":	{"NN","JJ"},
"agkistrodon":	{"NN"},
"aglaia":	{"NN"},
"aglaomorpha":	{"NN"},
"aglaonema":	{"NN"},
"agleam":	{"JJ"},
"aglet":	{"NN"},
"aglimmering":	{"VBG"},
"aglitter":	{"JJ"},
"aglow":	{"JJ","NN"},
"agnail":	{"NN"},
"agnate":	{"JJ","NN"},
"agnatha":	{"NN"},
"agnathan":	{"NN"},
"agnatic":	{"JJ"},
"agnation":	{"NN"},
"agnelli-related":	{"JJ"},
"agnew":	{"NN"},
"agni":	{"NN"},
"agnise":	{"VB"},
"agnize":	{"VB"},
"agnomen":	{"NN"},
"agnosia":	{"NN"},
"agnostic":	{"JJ","NN"},
"agnostical":	{"JJ"},
"agnosticism":	{"NN"},
"agnostics":	{"NNS"},
"agnostids":	{"NNS"},
"ago":	{"RB"},
"agog":	{"JJ","NN"},
"agon":	{"NN"},
"agonadal":	{"JJ"},
"agonal":	{"JJ"},
"agone":	{"JJ"},
"agonidae":	{"NN"},
"agonies":	{"NNS"},
"agonise":	{"VB","VBP"},
"agonised":	{"JJ","VBD","VBN"},
"agonises":	{"VBZ"},
"agonising":	{"JJ","VBG","NN"},
"agonisingly":	{"RB"},
"agonist":	{"NN"},
"agonistic":	{"JJ"},
"agonistical":	{"JJ"},
"agonize":	{"VB","VBP"},
"agonized":	{"JJ","VBD","VBN"},
"agonizes":	{"VBZ"},
"agonizing":	{"JJ","VBG","NN"},
"agonizingly":	{"RB"},
"agonus":	{"NN"},
"agony":	{"NN"},
"agora":	{"NN"},
"agoraphobia":	{"NN"},
"agoraphobic":	{"JJ","NN"},
"agoraphobics":	{"NNS"},
"agouti":	{"NN"},
"agra":	{"NN"},
"agranulocytic":	{"JJ"},
"agranulocytosis":	{"NN"},
"agranulosis":	{"NN"},
"agrapha":	{"NN"},
"agraphia":	{"NN"},
"agraphic":	{"JJ"},
"agrarian":	{"JJ","NN"},
"agrarian-reform":	{"JJ"},
"agree":	{"VB","VBP"},
"agreeability":	{"NN"},
"agreeable":	{"JJ"},
"agreeableness":	{"NN"},
"agreeably":	{"RB"},
"agreed":	{"VBD","VBN","JJ"},
"agreed-on":	{"JJ"},
"agreed-to":	{"JJ"},
"agreed-upon":	{"JJ","NN"},
"agreeement":	{"NN"},
"agreeing":	{"VBG"},
"agreement":	{"NN"},
"agreements":	{"NNS"},
"agrees":	{"VBZ"},
"agressive":	{"JJ"},
"agrestic":	{"JJ"},
"agribusiness":	{"NN"},
"agricolas":	{"FW"},
"agricole":	{"FW"},
"agriculteurs":	{"FW"},
"agricultural":	{"JJ"},
"agricultural-research":	{"JJ"},
"agriculturalist":	{"NN"},
"agriculturally":	{"RB"},
"agriculturals":	{"NNS"},
"agriculture":	{"NN"},
"agriculture-based":	{"JJ"},
"agriculture-chemicals":	{"NNS"},
"agriculture-extension":	{"NN"},
"agriculture-ministry":	{"NN"},
"agriculture-related":	{"JJ"},
"agriculturist":	{"NN"},
"agrigento":	{"NN"},
"agrimonia":	{"NN"},
"agrimony":	{"NN"},
"agriocharis":	{"NN"},
"agrippina":	{"NN"},
"agriproducts":	{"NNS"},
"agro-chemicals":	{"NNS"},
"agro-industrial":	{"JJ"},
"agro-industry":	{"JJ"},
"agrobacterium":	{"NN"},
"agrobiologic":	{"JJ"},
"agrobiological":	{"JJ"},
"agrobiology":	{"NN"},
"agrochemical":	{"NN"},
"agrologic":	{"JJ"},
"agrological":	{"JJ"},
"agrology":	{"NN"},
"agromania":	{"NN"},
"agronomic":	{"JJ"},
"agronomical":	{"JJ"},
"agronomist":	{"NN"},
"agronomy":	{"NN"},
"agropyron":	{"NN"},
"agrostemma":	{"NN"},
"agrostis":	{"NN"},
"aground":	{"RB","JJ"},
"agrypnia":	{"NN"},
"agrypnotic":	{"JJ"},
"agua":	{"NN"},
"aguacate":	{"NN"},
"ague":	{"NN"},
"agueweed":	{"NN"},
"aguish":	{"JJ"},
"ah":	{"UH"},
"aha":	{"UH"},
"ahab":	{"NN"},
"ahdawam":	{"UH"},
"ahead":	{"RB","RP"},
"ahem":	{"UH"},
"ahern":	{"NN"},
"ahimsa":	{"NN"},
"ahistorical":	{"JJ"},
"aho":	{"NN"},
"ahold":	{"RB"},
"ahorse":	{"JJ","RB"},
"ahorseback":	{"JJ","RB"},
"ahoy":	{"UH"},
"ahpcrc":	{"NN"},
"ahriman":	{"NN"},
"ahs":	{"NNS"},
"ahuehuete":	{"NN"},
"ahura":	{"NN"},
"ahvenanmaa":	{"NN"},
"aia":	{"NN"},
"aiai":	{"NN"},
"aid":	{"NN","VB","VBP"},
"aid-to-education":	{"NN"},
"aide":	{"NN"},
"aide-de-camp":	{"NN"},
"aide-memoire":	{"NN"},
"aided":	{"VBN","VBD"},
"aides":	{"NNS"},
"aiding":	{"NN","VBG"},
"aidoneus":	{"NN"},
"aids":	{"NNS","VBZ"},
"aids-drug":	{"JJ"},
"aids-infected":	{"JJ"},
"aids-inspired":	{"JJ"},
"aids-like":	{"JJ"},
"aids-prevention":	{"JJ"},
"aids-related":	{"JJ"},
"aids-research":	{"JJ"},
"aids-treatment":	{"NN"},
"aigina":	{"NN"},
"aiglet":	{"NN"},
"aigret":	{"NN"},
"aigrette":	{"NN"},
"aiguilette":	{"NN"},
"aikido":	{"NN"},
"ail":	{"VB","VBP"},
"ailanthus":	{"NN"},
"ailed":	{"VBD","VBN"},
"aileron":	{"NN"},
"ailerons":	{"NNS"},
"ailing":	{"VBG","JJ"},
"ailment":	{"NN"},
"ailments":	{"NNS"},
"ails":	{"VBZ"},
"ailurophobia":	{"NN"},
"ailuropoda":	{"NN"},
"ailuropodidae":	{"NN"},
"ailurus":	{"NN"},
"aim":	{"NN","VB","VBP"},
"aimed":	{"VBN","VBD"},
"aiming":	{"VBG"},
"aimless":	{"JJ"},
"aimlessly":	{"RB"},
"aimlessness":	{"NN"},
"aims":	{"VBZ","NNS"},
"ain":	{"JJ","NN"},
"aioli":	{"NN"},
"air":	{"NN","VB","VBP"},
"air-breathing":	{"JJ"},
"air-cargo":	{"NN"},
"air-cell":	{"JJ"},
"air-charter":	{"JJ"},
"air-condition":	{"VB","VBP"},
"air-conditioned":	{"JJ","VBD","VBN"},
"air-conditioner":	{"NN"},
"air-conditioners":	{"NNS"},
"air-conditioning":	{"NN","VBG"},
"air-conditions":	{"VBZ"},
"air-cool":	{"VB","VBP"},
"air-cooled":	{"JJ","VBD","VBN"},
"air-cooling":	{"VBG","NN"},
"air-cools":	{"VBZ"},
"air-defense":	{"JJ"},
"air-dried":	{"JJ","VBD","VBN"},
"air-dries":	{"VBZ"},
"air-drop":	{"VB","VBP","NN"},
"air-dropped":	{"VBD","VBN"},
"air-dropping":	{"VBG"},
"air-drops":	{"VBZ","NNS"},
"air-dry":	{"JJ","VB","VBP"},
"air-drying":	{"VBG"},
"air-express":	{"NN"},
"air-filled":	{"JJ"},
"air-frame":	{"NN"},
"air-freight":	{"VB","VBP"},
"air-freight-forwarding":	{"JJ"},
"air-freighted":	{"VBD","VBN"},
"air-freighting":	{"VBG"},
"air-freights":	{"VBZ"},
"air-injection":	{"NN"},
"air-intake":	{"NN"},
"air-interdiction":	{"NN"},
"air-launched":	{"JJ"},
"air-passenger":	{"NN"},
"air-pollution":	{"NN"},
"air-quality":	{"NN"},
"air-raid":	{"JJ"},
"air-separation":	{"NN"},
"air-service":	{"NN"},
"air-ship":	{"VB"},
"air-slake":	{"VB"},
"air-sleeve":	{"NN"},
"air-tickets":	{"NNS"},
"air-tight":	{"JJ"},
"air-to-air":	{"JJ"},
"air-to-ground":	{"JJ"},
"air-to-surface":	{"JJ"},
"air-traffic":	{"NN"},
"air-traffic-control":	{"NN"},
"air-water":	{"JJ"},
"air-waybill":	{"JJ"},
"airbags":	{"NNS"},
"airborne":	{"JJ"},
"airborne-radar":	{"NN"},
"airbrake":	{"NN"},
"airbrush":	{"NN","VB","VBP"},
"airbrushed":	{"VBD","VBN"},
"airbrushes":	{"NNS","VBZ"},
"airbrushing":	{"VBG"},
"airburst":	{"NN"},
"airbus":	{"NN"},
"airconditioner":	{"NN"},
"airconditioners":	{"NNS"},
"aircraft":	{"NN","NNS"},
"aircraft-electronics":	{"NN"},
"aircraft-engine":	{"JJ","NN"},
"aircraft-engine-maintenance":	{"JJ"},
"aircraft-navigation":	{"NN"},
"aircraft-test":	{"JJ"},
"aircraftman":	{"NN"},
"aircrafts":	{"NNS"},
"aircraftsman":	{"NN"},
"aircrew":	{"NN"},
"aircrewman":	{"NN"},
"airdock":	{"NN"},
"airdrome":	{"NN"},
"airdrop":	{"NN","VB","VBP"},
"airdropped":	{"VBD","VBN"},
"airdropping":	{"VBG"},
"airdrops":	{"NNS","VBZ"},
"aire":	{"NN"},
"aired":	{"VBD","VBN"},
"airedale":	{"NN"},
"airfare":	{"NN"},
"airfares":	{"NNS"},
"airfield":	{"NN"},
"airfields":	{"NNS"},
"airflow":	{"NN"},
"airfoil":	{"NN"},
"airfones":	{"NNS"},
"airforce":	{"NN"},
"airframe":	{"NN"},
"airframes":	{"NNS"},
"airfreight":	{"NN"},
"airgun":	{"NN"},
"airhead":	{"NN"},
"airheaded":	{"JJ"},
"airheads":	{"NNS"},
"airily":	{"RB"},
"airiness":	{"NN"},
"airing":	{"NN","VBG"},
"airings":	{"NNS"},
"airless":	{"JJ"},
"airlift":	{"NN","VB","VBP"},
"airlifted":	{"VBD","VBN"},
"airlifter":	{"NN"},
"airlifters":	{"NNS"},
"airlifting":	{"VBG"},
"airlifts":	{"NNS","VBZ"},
"airlike":	{"JJ"},
"airline":	{"NN"},
"airline-acquisition":	{"JJ"},
"airline-crash":	{"JJ"},
"airline-deregulation":	{"NN"},
"airline-financed":	{"JJ"},
"airline-hostess":	{"NN"},
"airline-industry":	{"NN"},
"airline-interior":	{"JJ"},
"airline-landing":	{"JJ"},
"airline-related":	{"JJ"},
"airliner":	{"NN"},
"airliners":	{"NNS"},
"airlines":	{"NNS"},
"airlock":	{"NN"},
"airmail":	{"NN"},
"airmailed":	{"VBD","VBN","JJ"},
"airmailer":	{"NN"},
"airmailing":	{"VBG"},
"airmails":	{"VBZ"},
"airman":	{"NN"},
"airmanship":	{"NN"},
"airmen":	{"NNS"},
"airplane":	{"NN"},
"airplanes":	{"NNS","VBZ"},
"airplay":	{"NN"},
"airpocalypse":	{"NN"},
"airpocalypses":	{"NNS"},
"airport":	{"NN"},
"airports":	{"NNS"},
"airpost":	{"NN"},
"airpower":	{"NN"},
"airs":	{"NNS","VBZ"},
"airscrew":	{"NN"},
"airship":	{"NN"},
"airsick":	{"JJ"},
"airsickness":	{"NN"},
"airspace":	{"NN"},
"airspeed":	{"NN"},
"airstream":	{"NN"},
"airstrikes":	{"NNS","VBZ"},
"airstrip":	{"NN"},
"airstrips":	{"NNS"},
"airt":	{"NN"},
"airtight":	{"JJ","NN"},
"airtime":	{"NN"},
"airwave":	{"NN"},
"airwaves":	{"NNS"},
"airway":	{"NN"},
"airways":	{"NNS"},
"airwoman":	{"NN"},
"airworthiness":	{"NN"},
"airworthy":	{"JJ","NN"},
"airy":	{"JJ"},
"aisle":	{"NN"},
"aisles":	{"NNS"},
"aitchbone":	{"NN"},
"aix":	{"NN"},
"aix-la-chapelle":	{"NN"},
"aizoaceae":	{"NN"},
"ajaia":	{"NN"},
"ajar":	{"JJ","NN"},
"ajax":	{"NN"},
"ajuga":	{"NN"},
"ajury":	{"NN"},
"ak":	{"NN"},
"akaba":	{"NN"},
"akan":	{"NN"},
"akaryocyte":	{"NN"},
"akaryote":	{"NN"},
"akee":	{"NN"},
"aken":	{"NN"},
"akeridae":	{"NN"},
"akha":	{"NN"},
"akhbari":	{"NN"},
"akhenaten":	{"NN"},
"akhenaton":	{"NN"},
"akimbo":	{"JJ","RB"},
"akin":	{"JJ"},
"akinesia":	{"NN"},
"akinesis":	{"NN"},
"akka":	{"NN"},
"akkadian":	{"NN"},
"akko":	{"NN"},
"akmola":	{"NN"},
"aku":	{"NN"},
"akvavit":	{"NN"},
"akwa'ala":	{"NN"},
"al":	{"NN"},
"al-asifa":	{"NN"},
"al-fatah":	{"NN"},
"al-hakim":	{"NN"},
"al-haytham":	{"NN"},
"al-hudaydah":	{"NN"},
"al-iraq":	{"NN"},
"al-jihad":	{"NN"},
"al-ma'unah":	{"NN"},
"al-magrib":	{"NN"},
"al-muhajiroun":	{"NN"},
"al-mukalla":	{"NN"},
"al-qa'ida":	{"NN"},
"al-qaeda":	{"NN"},
"al-qaida":	{"NN"},
"al-qur'an":	{"NN"},
"al-tawhid":	{"NN"},
"al-ummah":	{"NN"},
"al.":	{"NNS"},
"ala":	{"NN"},
"alabama":	{"NN"},
"alabama-coushatta":	{"JJ"},
"alabaman":	{"NN"},
"alabamans":	{"NNS"},
"alabamas":	{"NN"},
"alabaster":	{"NN","JJ"},
"alabastrine":	{"JJ"},
"alacritous":	{"JJ"},
"alacrity":	{"NN"},
"alain":	{"NN"},
"alalia":	{"NN"},
"alamo":	{"NN"},
"alanine":	{"NN"},
"alaouite":	{"JJ"},
"alar":	{"JJ","NN"},
"alar-style":	{"JJ"},
"alaric":	{"NN"},
"alarm":	{"NN","VB","VBP"},
"alarmed":	{"JJ","VBD","VBN"},
"alarming":	{"JJ","VBG"},
"alarmingly":	{"RB"},
"alarmism":	{"NN"},
"alarmist":	{"JJ","NN"},
"alarmists":	{"NNS"},
"alarms":	{"NNS","VBZ"},
"alarum":	{"NN"},
"alary":	{"JJ"},
"alas":	{"RB","UH"},
"alaska":	{"NN"},
"alaska-based":	{"JJ"},
"alastrim":	{"NN"},
"alate":	{"JJ"},
"alated":	{"JJ"},
"alauda":	{"NN"},
"alaudidae":	{"NN"},
"alb":	{"NN"},
"albacore":	{"NN"},
"albatrellus":	{"NN"},
"albatross":	{"NN"},
"albatrosses":	{"NNS"},
"albedo":	{"NN"},
"albee":	{"NN"},
"albeit":	{"CC"},
"albers":	{"NNS"},
"albert":	{"NN"},
"alberta":	{"NN"},
"alberti":	{"NN"},
"albescent":	{"JJ"},
"albicans":	{"NNS"},
"albigenses":	{"NNS"},
"albigensian":	{"JJ"},
"albigensianism":	{"NN"},
"albinal":	{"JJ"},
"albinic":	{"JJ"},
"albinism":	{"NN"},
"albinistic":	{"JJ"},
"albino":	{"NN"},
"albinotic":	{"JJ"},
"albion":	{"NN"},
"albite":	{"NN"},
"albitic":	{"JJ"},
"albizia":	{"NN"},
"albizzia":	{"NN"},
"alborg":	{"NN"},
"albuca":	{"NN"},
"albuginaceae":	{"NN"},
"albuginea":	{"NN"},
"albugo":	{"NN"},
"albula":	{"NN"},
"albulidae":	{"NN"},
"album":	{"NN"},
"albumen":	{"NN"},
"albumin":	{"NN"},
"albuminoid":	{"NN"},
"albuminous":	{"JJ"},
"albuminuria":	{"NN"},
"albuminuric":	{"JJ"},
"albums":	{"NNS","NNPS"},
"albuquerque":	{"NN"},
"albuterol":	{"NN"},
"alca":	{"NN"},
"alcaeus":	{"NN"},
"alcahest":	{"NN"},
"alcaic":	{"NN"},
"alcalde":	{"NN"},
"alcalescent":	{"JJ"},
"alcapton":	{"NN"},
"alcaptonuria":	{"NN"},
"alcazar":	{"NN"},
"alcea":	{"NN"},
"alcedinidae":	{"NN"},
"alcedo":	{"NN"},
"alcelaphus":	{"NN"},
"alces":	{"NN"},
"alchemic":	{"JJ"},
"alchemical":	{"JJ"},
"alchemise":	{"VB"},
"alchemist":	{"NN"},
"alchemistic":	{"JJ"},
"alchemistical":	{"JJ"},
"alchemists":	{"NNS"},
"alchemize":	{"VB"},
"alchemy":	{"NN"},
"alcibiades":	{"NNS"},
"alcidae":	{"NN"},
"alcides":	{"NNS"},
"alcinous":	{"JJ"},
"alcohol":	{"NN"},
"alcohol-dependent":	{"JJ"},
"alcohol-powered":	{"JJ"},
"alcohol-producing":	{"JJ"},
"alcohol-related":	{"JJ"},
"alcohol-soluble":	{"JJ"},
"alcoholic":	{"JJ","NN"},
"alcoholic-beverage":	{"NN"},
"alcoholics":	{"NNS"},
"alcoholise":	{"VB"},
"alcoholism":	{"NN"},
"alcoholize":	{"VB"},
"alcohols":	{"NNS"},
"alcott":	{"NN"},
"alcove":	{"NN"},
"alcoves":	{"NNS"},
"alcyonacea":	{"NN"},
"alcyonaria":	{"NN"},
"alcyone":	{"NN"},
"aldactone":	{"NN"},
"aldebaran":	{"NN"},
"aldehyde":	{"NN"},
"aldehyde-alcohol":	{"NN"},
"aldehydic":	{"JJ"},
"alder":	{"NN"},
"alderfly":	{"NN"},
"alderman":	{"NN"},
"aldermanic":	{"JJ"},
"aldermanly":	{"JJ"},
"aldermen":	{"NNS"},
"alders":	{"NNS"},
"aldohexose":	{"NN"},
"aldol":	{"NN"},
"aldomet":	{"NN"},
"aldose":	{"NN"},
"aldosterone":	{"NN"},
"aldosteronism":	{"NN"},
"aldrovanda":	{"NN"},
"ale":	{"NN"},
"aleatory":	{"JJ","NN"},
"aleck":	{"NN"},
"alecost":	{"NN"},
"alectis":	{"NN"},
"alecto":	{"NN"},
"alectoria":	{"NN"},
"alectoris":	{"NN"},
"alectura":	{"NN"},
"alee":	{"RB"},
"alehoof":	{"NN"},
"alehouse":	{"NN"},
"alembic":	{"NN","JJ"},
"alendronate":	{"NN"},
"alep":	{"NN"},
"aleph":	{"NN"},
"aleph-nought":	{"NN"},
"aleph-null":	{"NN"},
"aleph-zero":	{"NN"},
"alepisaurus":	{"NN"},
"aleppo":	{"NN"},
"alert":	{"JJ","NN","VB","VBP"},
"alerted":	{"VBD","VBN","JJ"},
"alerting":	{"NN","VBG"},
"alertly":	{"RB"},
"alertness":	{"NN"},
"alerts":	{"VBZ","NNS"},
"aletris":	{"NN"},
"aleurites":	{"NNS"},
"aleurone":	{"NN"},
"aleuronic":	{"JJ"},
"aleut":	{"NN"},
"aleutian":	{"JJ","NN"},
"aleutians":	{"NNS"},
"aleve":	{"NN"},
"alewife":	{"NN"},
"alexander":	{"NN"},
"alexandria":	{"NN"},
"alexandrian":	{"JJ","NN"},
"alexandrite":	{"NN"},
"alexia":	{"NN"},
"alexic":	{"JJ","NN"},
"aleyrodes":	{"NNS"},
"aleyrodidae":	{"NN"},
"alfa":	{"NN"},
"alfalfa":	{"NN"},
"alfilaria":	{"NN"},
"alfileria":	{"NN"},
"alfonso":	{"NN"},
"alfred":	{"NN"},
"alfresco":	{"JJ","RB"},
"alga":	{"NN"},
"algae":	{"NNS"},
"algaecide":	{"NN"},
"algal":	{"JJ","NN"},
"algarobilla":	{"NN"},
"algarroba":	{"NN"},
"algarrobilla":	{"NN"},
"algebra":	{"NN"},
"algebraic":	{"JJ","NN"},
"algebraical":	{"JJ"},
"algebraically":	{"RB"},
"algebraist":	{"NN"},
"alger":	{"NN"},
"algeria":	{"NN"},
"algerian":	{"JJ","NN"},
"algerie":	{"NN"},
"algeripithecus":	{"NN"},
"algid":	{"JJ"},
"algidity":	{"NN"},
"algiers":	{"NNS"},
"algin":	{"NN"},
"alginates":	{"NNS"},
"algoid":	{"JJ"},
"algol":	{"NN"},
"algolagnia":	{"NN"},
"algolagnic":	{"JJ"},
"algology":	{"NN"},
"algometer":	{"NN"},
"algometric":	{"JJ"},
"algometrical":	{"JJ"},
"algometry":	{"NN"},
"algonkian":	{"JJ","NN"},
"algonkin":	{"NN"},
"algonquian":	{"JJ","NN"},
"algonquin":	{"JJ","NN"},
"algophilia":	{"NN"},
"algophobia":	{"NN"},
"algophobic":	{"JJ"},
"algorism":	{"NN"},
"algorithm":	{"NN"},
"algorithmic":	{"JJ"},
"algren":	{"NN"},
"alhacen":	{"NN"},
"alhambra":	{"NN"},
"alhazen":	{"NN"},
"alia":	{"FW"},
"alias":	{"NN","RB","IN"},
"alibi":	{"NN"},
"alibis":	{"NNS"},
"alidad":	{"NN"},
"alidade":	{"NN"},
"alien":	{"JJ","NN"},
"alienable":	{"JJ"},
"alienage":	{"NN"},
"alienate":	{"VB","VBP"},
"alienated":	{"JJ","VBD","VBN"},
"alienates":	{"VBZ"},
"alienating":	{"VBG"},
"alienation":	{"NN"},
"alienator":	{"NN"},
"aliened":	{"VBD","VBN"},
"alienee":	{"NN"},
"aliening":	{"VBG"},
"alienism":	{"NN"},
"alienist":	{"NN"},
"alienor":	{"NN"},
"aliens":	{"NNS","VBZ"},
"aliform":	{"JJ"},
"alight":	{"JJ","VB","VBP"},
"alighted":	{"VBD","VBN"},
"alighting":	{"VBG"},
"alights":	{"VBZ"},
"align":	{"VB","VBP"},
"aligned":	{"VBD","VBN"},
"aligning":	{"VBG"},
"alignment":	{"NN"},
"alignments":	{"NNS"},
"aligns":	{"VBZ"},
"alike":	{"RB","JJ"},
"alikeness":	{"NN"},
"aliment":	{"NN","VB","VBP"},
"alimental":	{"JJ"},
"alimentary":	{"JJ"},
"alimentation":	{"NN"},
"alimentative":	{"JJ"},
"alimented":	{"VBD","VBN"},
"alimenting":	{"VBG"},
"aliments":	{"VBZ"},
"alimony":	{"NN"},
"aline":	{"VB","VBP"},
"alined":	{"VBD","VBN"},
"alinement":	{"NN"},
"alines":	{"VBZ"},
"alining":	{"VBG"},
"aliphatic":	{"JJ"},
"aliquant":	{"NN"},
"aliquot":	{"JJ","NN"},
"aliquots":	{"NNS"},
"alir":	{"NN"},
"alisma":	{"NN"},
"alismales":	{"NNS"},
"alismataceae":	{"NN"},
"alismatidae":	{"NN"},
"alison":	{"NN"},
"alistair":	{"NN"},
"alit":	{"VBD","VBN"},
"aliterate":	{"NN"},
"alive":	{"JJ"},
"aliveness":	{"NN"},
"aliyah":	{"NN"},
"alizarin":	{"NN"},
"alizarine":	{"NN"},
"alka-seltzer":	{"NN"},
"alkahest":	{"NN"},
"alkahestic":	{"JJ"},
"alkalemia":	{"NN"},
"alkalescent":	{"JJ"},
"alkali":	{"NN"},
"alkalic":	{"JJ"},
"alkalify":	{"VB"},
"alkalimetry":	{"NN"},
"alkaline":	{"JJ","NN"},
"alkaline-loving":	{"JJ"},
"alkalinise":	{"VB"},
"alkalinity":	{"NN"},
"alkalinize":	{"VB"},
"alkalinuria":	{"NN"},
"alkalis":	{"NNS"},
"alkalise":	{"VB"},
"alkaliser":	{"NN"},
"alkalize":	{"VB"},
"alkalizer":	{"NN"},
"alkaloid":	{"NN","JJ"},
"alkaloidal":	{"JJ"},
"alkaloids":	{"NNS"},
"alkalosis":	{"NN"},
"alkalotic":	{"JJ"},
"alkaluria":	{"NN"},
"alkane":	{"NN"},
"alkanet":	{"NN"},
"alkapton":	{"NN"},
"alkaptonuria":	{"NN"},
"alkene":	{"NN"},
"alkeran":	{"NN"},
"alky":	{"NN"},
"alkyd":	{"NN"},
"alkyl":	{"NN"},
"alkylarysulfonate":	{"NN"},
"alkylbenzene":	{"NN"},
"alkylbenzenesulfonate":	{"NN"},
"alkylbenzenesulfonates":	{"NNS"},
"alkylic":	{"JJ"},
"alkyne":	{"NN"},
"all":	{"DT","PDT","RB"},
"all-America":	{"JJ"},
"all-American":	{"JJ"},
"all-American-boy":	{"NN"},
"all-Copland":	{"JJ"},
"all-Negro":	{"JJ"},
"all-Spanish":	{"JJ"},
"all-america":	{"JJ"},
"all-american":	{"JJ"},
"all-american-boy":	{"NN"},
"all-around":	{"JJ"},
"all-automatic":	{"JJ"},
"all-black":	{"JJ"},
"all-cargo":	{"JJ"},
"all-cash":	{"JJ"},
"all-college":	{"NN"},
"all-consuming":	{"JJ","NN"},
"all-copland":	{"JJ"},
"all-county":	{"JJ"},
"all-day":	{"JJ"},
"all-devouring":	{"JJ"},
"all-embracing":	{"JJ"},
"all-employee":	{"JJ"},
"all-encompassing":	{"JJ"},
"all-exclusive":	{"JJ"},
"all-expenses-paid":	{"JJ"},
"all-federal":	{"JJ"},
"all-female":	{"JJ"},
"all-fired":	{"JJ","RB"},
"all-important":	{"JJ"},
"all-in-all":	{"RB"},
"all-inclusive":	{"JJ"},
"all-knowing":	{"JJ"},
"all-lesbian":	{"JJ"},
"all-mains":	{"JJ"},
"all-male":	{"JJ","DT"},
"all-married":	{"JJ"},
"all-metal":	{"JJ"},
"all-natural":	{"JJ"},
"all-negro":	{"JJ"},
"all-news":	{"JJ"},
"all-night":	{"JJ"},
"all-nighters":	{"NNS"},
"all-options":	{"JJ"},
"all-or-none":	{"JJ"},
"all-or-nothing":	{"JJ"},
"all-out":	{"JJ"},
"all-over":	{"IN"},
"all-paper":	{"JJ","NN"},
"all-pervading":	{"JJ"},
"all-powerful":	{"JJ"},
"all-purpose":	{"JJ"},
"all-round":	{"JJ"},
"all-rounder":	{"NN"},
"all-something-or-the-other":	{"JJ"},
"all-spanish":	{"JJ"},
"all-star":	{"JJ","NN"},
"all-stars":	{"NNS"},
"all-stock":	{"JJ"},
"all-student":	{"JJ"},
"all-terrain":	{"JJ"},
"all-time":	{"JJ"},
"all-too-brief":	{"JJ"},
"all-too-familiar":	{"JJ"},
"all-too-sincere":	{"JJ"},
"all-victorious":	{"JJ"},
"all-weather":	{"JJ"},
"all-white":	{"JJ"},
"all-woman":	{"JJ"},
"allah":	{"NN"},
"allamanda":	{"NN"},
"allantoic":	{"JJ"},
"allantoid":	{"JJ"},
"allantois":	{"NN"},
"allargando":	{"JJ"},
"allay":	{"VB","VBP"},
"allayed":	{"VBD","VBN"},
"allayer":	{"NN"},
"allaying":	{"VBG"},
"allays":	{"VBZ"},
"allegation":	{"NN"},
"allegations":	{"NNS"},
"allege":	{"VB","VBP"},
"alleged":	{"JJ","VBN","VBD"},
"allegedly":	{"RB"},
"allegement":	{"NN"},
"alleges":	{"VBZ"},
"alleghenies":	{"NN"},
"allegheny":	{"NN"},
"allegiance":	{"NN"},
"allegiances":	{"NNS"},
"allegiant":	{"JJ"},
"alleging":	{"VBG"},
"allegoric":	{"JJ"},
"allegorical":	{"JJ","NN"},
"allegorically":	{"RB"},
"allegorise":	{"VB"},
"allegoriser":	{"NN"},
"allegorize":	{"VB"},
"allegorizer":	{"NN"},
"allegory":	{"NN"},
"allegretto":	{"RB","NN"},
"allegro":	{"NN","JJ"},
"allele":	{"NN"},
"allelic":	{"JJ"},
"allelomorph":	{"NN"},
"allelomorphic":	{"JJ"},
"allemande":	{"NN"},
"allen-film":	{"NN"},
"allentown":	{"NN"},
"allergen":	{"NN"},
"allergenic":	{"JJ"},
"allergic":	{"JJ","NN"},
"allergies":	{"NNS"},
"allergist":	{"NN"},
"allergology":	{"NN"},
"allergy":	{"NN"},
"alleviant":	{"NN"},
"alleviate":	{"VB","VBP"},
"alleviated":	{"VBD","VBN"},
"alleviates":	{"VBZ"},
"alleviating":	{"VBG"},
"alleviation":	{"NN"},
"alleviative":	{"JJ"},
"alleviator":	{"NN"},
"alleviatory":	{"JJ"},
"alley":	{"NN"},
"alleys":	{"NNS"},
"alleyway":	{"NN"},
"alleyways":	{"NNS"},
"allgedly":	{"RB"},
"allgood":	{"NN"},
"allhallows":	{"NNS"},
"allhallowtide":	{"NN"},
"alliaceae":	{"NN"},
"alliaceous":	{"JJ"},
"alliance":	{"NN"},
"alliances":	{"NNS"},
"alliaria":	{"NN"},
"allice":	{"NN"},
"allied":	{"VBN","VBD","JJ"},
"allies":	{"NNS","VBZ"},
"alligator":	{"NN","JJ"},
"alligatored":	{"JJ"},
"alligatorfish":	{"NN"},
"alligatoridae":	{"NN"},
"alligators":	{"NNS"},
"allionia":	{"NN"},
"allioniaceae":	{"NN"},
"allis":	{"NN"},
"alliterate":	{"VB","VBP"},
"alliterated":	{"VBD","VBN"},
"alliterates":	{"VBZ"},
"alliterating":	{"VBG"},
"alliteration":	{"NN"},
"alliterative":	{"JJ","NN"},
"alliteratively":	{"RB"},
"alliterator":	{"NN"},
"alliterators":	{"NNS"},
"allium":	{"NN"},
"allmouth":	{"NN"},
"allnight":	{"JJ"},
"alloantibody":	{"NN"},
"allocable":	{"JJ"},
"allocatable":	{"JJ"},
"allocate":	{"VB","VBP"},
"allocated":	{"VBN","VBD"},
"allocates":	{"VBZ"},
"allocating":	{"VBG"},
"allocation":	{"NN"},
"allocations":	{"NNS"},
"allocative":	{"JJ"},
"allocator":	{"NN"},
"allochronic":	{"JJ"},
"allochthonous":	{"JJ"},
"allocution":	{"NN"},
"allodially":	{"RB"},
"allogamous":	{"JJ"},
"allogamy":	{"NN"},
"allogeneic":	{"JJ"},
"allograft":	{"NN"},
"allograph":	{"NN"},
"allographic":	{"JJ"},
"allomerism":	{"NN"},
"allomerous":	{"JJ"},
"allometric":	{"JJ"},
"allometry":	{"NN"},
"allomorph":	{"NN"},
"allomorphic":	{"JJ"},
"allopathic":	{"JJ"},
"allopathy":	{"NN"},
"allopatric":	{"JJ"},
"allopatry":	{"NN"},
"allophone":	{"NN"},
"allophonic":	{"JJ"},
"allopurinol":	{"NN"},
"allosaur":	{"NN"},
"allosaurus":	{"NN"},
"allot":	{"VB","VBP"},
"allotment":	{"NN"},
"allotments":	{"NNS"},
"allotrope":	{"NN"},
"allotropic":	{"JJ"},
"allotropical":	{"JJ"},
"allotropism":	{"NN"},
"allotropy":	{"NN"},
"allots":	{"VBZ"},
"allotted":	{"JJ","VBD","VBN"},
"allotting":	{"VBG"},
"allout":	{"JJ"},
"allover":	{"NN","JJ"},
"allow":	{"VB","VBP"},
"allowable":	{"JJ"},
"allowably":	{"RB"},
"allowance":	{"NN","VB","VBP"},
"allowanced":	{"VBD","VBN"},
"allowances":	{"VBZ","NNS"},
"allowancing":	{"VBG"},
"allowed":	{"VBD","VBN"},
"allowing":	{"VBG"},
"allows":	{"VBZ"},
"alloy":	{"NN","VB","VBP"},
"alloyed":	{"VBD","VBN"},
"alloying":	{"VBG"},
"alloys":	{"NNS","VBZ"},
"allrightniks":	{"NNS"},
"allso":	{"RB"},
"allspice":	{"NN"},
"alltime":	{"NN"},
"allude":	{"VB","VBP"},
"alluded":	{"VBD","VBN"},
"alludes":	{"VBZ"},
"alluding":	{"VBG"},
"allure":	{"NN","VB","VBP"},
"allured":	{"VBD","VBN"},
"allurement":	{"NN"},
"allures":	{"VBZ"},
"alluring":	{"JJ","VBG"},
"allusion":	{"NN"},
"allusions":	{"NNS"},
"allusive":	{"JJ"},
"allusiveness":	{"NN"},
"alluvial":	{"JJ"},
"alluviation":	{"NN"},
"alluvion":	{"NN"},
"alluvium":	{"NN"},
"ally":	{"NN","VB","VBP"},
"allying":	{"VBG"},
"allyl":	{"NN"},
"allylic":	{"JJ"},
"alma":	{"NN","JJ"},
"alma-ata":	{"NN"},
"almanac":	{"NN"},
"almandine":	{"NN"},
"almandite":	{"NN"},
"almaty":	{"NN"},
"almighty":	{"JJ","NN"},
"almond":	{"NN"},
"almond-eyed":	{"JJ"},
"almond-scented":	{"JJ"},
"almond-shaped":	{"JJ"},
"almonds":	{"NNS"},
"almoner":	{"NN"},
"almoravid":	{"NN"},
"almost":	{"RB"},
"almost-industry":	{"NN"},
"alms":	{"NNS"},
"alms-giving":	{"NN"},
"almsgiver":	{"NN"},
"almsgiving":	{"NN"},
"alnico":	{"NN"},
"alnus":	{"NN"},
"alocasia":	{"NN"},
"aloe":	{"NN"},
"aloeaceae":	{"NN"},
"aloes":	{"NNS"},
"aloft":	{"RB"},
"aloha":	{"NN"},
"alone":	{"RB","JJ"},
"aloneness":	{"NN"},
"along":	{"IN","RB","RP"},
"alongside":	{"IN","RB"},
"alonso":	{"NN"},
"aloof":	{"JJ","NN"},
"aloofness":	{"NN"},
"alopecia":	{"NN"},
"alopecic":	{"JJ"},
"alopecurus":	{"NN"},
"alopex":	{"NN"},
"alopiidae":	{"NN"},
"alopius":	{"NN"},
"alors":	{"FW"},
"alosa":	{"NN"},
"alouatta":	{"NN"},
"aloud":	{"RB"},
"alp":	{"NN"},
"alpaca":	{"NN"},
"alpena":	{"NN"},
"alpenglow":	{"NN"},
"alpenstock":	{"NN"},
"alperts":	{"NNS"},
"alpestrine":	{"JJ"},
"alpha":	{"NN"},
"alpha-adrenoceptor":	{"NN"},
"alpha-beta-gammas":	{"NNS"},
"alpha-blocker":	{"NN"},
"alpha-interferon":	{"NN"},
"alpha-lipoprotein":	{"NN"},
"alpha-naphthol":	{"NN"},
"alpha-tocopheral":	{"NN"},
"alphabet":	{"NN"},
"alphabetic":	{"JJ","NN"},
"alphabetical":	{"JJ","NN"},
"alphabetically":	{"RB"},
"alphabetisation":	{"NN"},
"alphabetise":	{"VB","VBP"},
"alphabetised":	{"VBD","VBN"},
"alphabetiser":	{"NN"},
"alphabetises":	{"VBZ"},
"alphabetising":	{"VBG"},
"alphabetization":	{"NN"},
"alphabetize":	{"VB","VBP"},
"alphabetized":	{"VBD","VBN"},
"alphabetizer":	{"NN"},
"alphabetizes":	{"VBZ"},
"alphabetizing":	{"VBG"},
"alphameric":	{"JJ"},
"alphamerical":	{"JJ"},
"alphanumeric":	{"JJ"},
"alphanumerical":	{"JJ"},
"alphanumerics":	{"NN"},
"alphavirus":	{"NN"},
"alphonse":	{"NN"},
"alpine":	{"JJ","NN"},
"alpinia":	{"NN"},
"alpinism":	{"NN"},
"alpinist":	{"NN"},
"alprazolam":	{"NN"},
"alps":	{"NNS"},
"alreadeh":	{"RB"},
"already":	{"RB"},
"already-developed":	{"JJ"},
"already-expensive":	{"JJ"},
"already-identified":	{"JJ"},
"already-known":	{"JJ"},
"already-nervous":	{"NN"},
"already-reluctant":	{"JJ"},
"already-shaky":	{"JJ"},
"already-sizable":	{"JJ"},
"already-strained":	{"JJ"},
"already-tense":	{"JJ"},
"alright":	{"JJ","RB"},
"als":	{"NN"},
"alsace":	{"NN"},
"alsatia":	{"NN"},
"also":	{"RB"},
"also-ran":	{"NN","JJ"},
"alsobia":	{"NN"},
"alson":	{"NN"},
"alsophila":	{"NN"},
"alstonia":	{"NN"},
"alstroemeria":	{"NN"},
"alstroemeriaceae":	{"NN"},
"alt":	{"NN"},
"alt-right":	{"NN"},
"altace":	{"NN"},
"altaic":	{"JJ","NN"},
"altair":	{"NN"},
"altar":	{"NN"},
"altarpiece":	{"NN"},
"altazimuth":	{"NN"},
"alter":	{"VB","VBP"},
"alter-ego":	{"NN"},
"alter-parents":	{"NNS"},
"alterability":	{"NN"},
"alterable":	{"JJ"},
"alteration":	{"NN"},
"alterations":	{"NNS"},
"alterative":	{"JJ","NN"},
"altercate":	{"VB"},
"altercation":	{"NN"},
"altered":	{"VBN","VBD"},
"altering":	{"VBG"},
"alternanthera":	{"NN"},
"alternate":	{"JJ","VB","VBP"},
"alternated":	{"VBD","VBN"},
"alternately":	{"RB"},
"alternates":	{"NNS","VBZ"},
"alternating":	{"NN","VBG"},
"alternation":	{"NN"},
"alternative":	{"NN","JJ"},
"alternative-energy":	{"JJ"},
"alternative-fueled":	{"JJ"},
"alternative-fuels":	{"JJ","NNS"},
"alternative-operator":	{"NN"},
"alternatively":	{"RB"},
"alternatives":	{"NNS"},
"alternator":	{"NN"},
"alters":	{"VBZ","NNS"},
"althaea":	{"NN"},
"althea":	{"NN"},
"altho":	{"IN","CC"},
"although":	{"IN","CC"},
"altimeter":	{"NN"},
"altissimo":	{"JJ","NN"},
"altitude":	{"NN","VB","RB","VBP"},
"altitude-azimuth-mounted":	{"JJ"},
"altitudes":	{"NNS"},
"altitudinal":	{"JJ"},
"altitudinous":	{"JJ"},
"alto":	{"NN","JJ"},
"altocumulus":	{"NN"},
"altogether":	{"RB","NN"},
"altoist":	{"NN"},
"alton":	{"NN"},
"altoona":	{"NN"},
"altostratus":	{"NN"},
"altricial":	{"JJ"},
"altruism":	{"NN"},
"altruist":	{"NN"},
"altruistic":	{"JJ","NN"},
"altruistically":	{"RB"},
"altruists":	{"NNS"},
"alula":	{"NN"},
"alular":	{"JJ"},
"alum":	{"NN"},
"alumbloom":	{"NN"},
"alumina":	{"NN"},
"aluminate":	{"NN"},
"aluminiferous":	{"JJ"},
"aluminise":	{"VB"},
"aluminium":	{"NN"},
"aluminize":	{"VB"},
"aluminous":	{"JJ"},
"aluminum":	{"NN"},
"aluminum-bat":	{"NN"},
"aluminum-hulled":	{"JJ"},
"aluminum-industry":	{"NN"},
"aluminum-ingot":	{"NN"},
"aluminum-makers":	{"NNS"},
"alumna":	{"NN"},
"alumnae":	{"NNS"},
"alumni":	{"NNS"},
"alumnus":	{"NN"},
"alumroot":	{"NN"},
"alundum":	{"NN"},
"alupent":	{"NN"},
"alveolar":	{"NN","JJ"},
"alveolate":	{"JJ"},
"alveoli":	{"NNS"},
"alveolitis":	{"NN"},
"alveolus":	{"NN"},
"alvin":	{"NN"},
"alvine":	{"JJ"},
"always":	{"RB"},
"always-present":	{"JJ"},
"alyssum":	{"NN"},
"alytes":	{"NNS"},
"alzheimer's":	{"NNS"},
"alzheimers":	{"NNS"},
"am":	{"VBP","NN","RB"},
"ama":	{"NN"},
"amadavat":	{"NN"},
"amaethon":	{"NN"},
"amah":	{"NN"},
"amahs":	{"NNS"},
"amain":	{"RB"},
"amalgam":	{"NN"},
"amalgamate":	{"VB","VBP"},
"amalgamated":	{"VBD","VBN"},
"amalgamates":	{"VBZ"},
"amalgamating":	{"VBG"},
"amalgamation":	{"NN"},
"amalgamations":	{"NNS"},
"amalgamative":	{"JJ"},
"amalgamator":	{"NN"},
"amanita":	{"NN"},
"amanuensis":	{"NN"},
"amaranth":	{"NN"},
"amaranthaceae":	{"NN"},
"amaranthine":	{"JJ"},
"amaranthus":	{"NN"},
"amarelle":	{"NN"},
"amaretto":	{"NN"},
"amaryllidaceae":	{"NN"},
"amaryllis":	{"NN"},
"amass":	{"VB","VBP"},
"amassed":	{"VBD","VBN"},
"amasses":	{"VBZ"},
"amassing":	{"VBG"},
"amastia":	{"NN"},
"amaterasu":	{"NN"},
"amateur":	{"JJ","NN"},
"amateurish":	{"JJ"},
"amateurishly":	{"RB"},
"amateurishness":	{"NN"},
"amateurism":	{"NN"},
"amateurs":	{"NNS"},
"amati":	{"NN"},
"amative":	{"JJ"},
"amativeness":	{"NN"},
"amatory":	{"JJ"},
"amatungulu":	{"NN"},
"amauropelta":	{"NN"},
"amaurosis":	{"NN"},
"amaurotic":	{"JJ"},
"amaze":	{"VB","VBP"},
"amazed":	{"JJ","VBD","VBN"},
"amazement":	{"NN"},
"amazes":	{"VBZ"},
"amazing":	{"JJ","VBG"},
"amazingly":	{"RB"},
"amazon":	{"NN"},
"amazona":	{"NN"},
"amazonian":	{"JJ"},
"amazons":	{"NNS"},
"ambage":	{"NN"},
"ambages":	{"NNS"},
"ambagious":	{"JJ"},
"ambassador":	{"NN"},
"ambassadorial":	{"JJ","NN"},
"ambassadors":	{"NNS"},
"ambassadorship":	{"NN"},
"ambassadress":	{"NN"},
"amber":	{"NN","JJ"},
"amber-green":	{"JJ"},
"amberbell":	{"NN"},
"amberboa":	{"NN"},
"amberfish":	{"NN"},
"ambergris":	{"NN"},
"amberjack":	{"NN"},
"ambiance":	{"NN"},
"ambidexterity":	{"NN"},
"ambidextrous":	{"JJ"},
"ambidextrousness":	{"NN"},
"ambience":	{"NN"},
"ambient":	{"JJ","NN"},
"ambiguan":	{"JJ"},
"ambiguities":	{"NNS"},
"ambiguity":	{"NN"},
"ambiguous":	{"JJ"},
"ambiguously":	{"RB"},
"ambit":	{"NN"},
"ambition":	{"NN"},
"ambitioned":	{"VBD","VBN"},
"ambitioning":	{"VBG"},
"ambitionless":	{"JJ"},
"ambitions":	{"NNS","VBZ"},
"ambitious":	{"JJ"},
"ambitiously":	{"RB"},
"ambitiousness":	{"NN"},
"ambivalence":	{"NN"},
"ambivalency":	{"NN"},
"ambivalent":	{"JJ"},
"ambiversion":	{"NN"},
"ambiversive":	{"JJ"},
"amble":	{"VB","VBP","NN"},
"ambled":	{"VBD","VBN"},
"ambler":	{"NN"},
"ambles":	{"VBZ"},
"ambling":	{"VBG"},
"ambloplites":	{"NNS"},
"amblygonite":	{"NN"},
"amblyopia":	{"NN"},
"amblyopic":	{"JJ"},
"amblyrhynchus":	{"NN"},
"ambo":	{"NN"},
"amboyna":	{"NN"},
"ambrose":	{"NN"},
"ambrosia":	{"NN"},
"ambrosiaceae":	{"NN"},
"ambrosial":	{"JJ"},
"ambrosian":	{"JJ"},
"ambulacral":	{"JJ"},
"ambulacrum":	{"NN"},
"ambulance":	{"NN"},
"ambulances":	{"NNS","VBZ"},
"ambulant":	{"JJ"},
"ambulate":	{"VB"},
"ambulation":	{"NN"},
"ambulatory":	{"JJ","NN"},
"ambuscade":	{"NN","VB","VBP"},
"ambuscaded":	{"VBD","VBN"},
"ambuscades":	{"NNS","VBZ"},
"ambuscading":	{"VBG"},
"ambush":	{"NN","VB","VBP"},
"ambushed":	{"VBD","VBN"},
"ambusher":	{"NN"},
"ambushes":	{"NNS","VBZ"},
"ambushing":	{"VBG"},
"ambystoma":	{"NN"},
"ambystomatidae":	{"NN"},
"ambystomid":	{"NN"},
"amd":	{"NN"},
"ameba":	{"NN"},
"ameban":	{"JJ"},
"amebiasis":	{"NN"},
"amebic":	{"JJ"},
"amebiosis":	{"NN"},
"ameboid":	{"JJ"},
"amebous":	{"JJ"},
"ameer":	{"NN"},
"ameiuridae":	{"NN"},
"ameiurus":	{"NN"},
"amelanchier":	{"NN"},
"amelia":	{"NN"},
"ameliorate":	{"VB","VBP"},
"ameliorated":	{"VBD","VBN"},
"ameliorates":	{"VBZ"},
"ameliorating":	{"VBG"},
"amelioration":	{"NN"},
"ameliorative":	{"JJ"},
"amelioratory":	{"JJ"},
"ameloblast":	{"NN"},
"amelogenesis":	{"NN"},
"amen-ra":	{"NN"},
"amenability":	{"NN"},
"amenable":	{"JJ"},
"amenableness":	{"NN"},
"amend":	{"VB","VBP"},
"amendable":	{"JJ"},
"amendatory":	{"JJ"},
"amended":	{"VBD","VBN","JJ"},
"amending":	{"VBG"},
"amendment":	{"NN"},
"amendments":	{"NNS"},
"amends":	{"VBZ","NN"},
"amenia":	{"NN"},
"amenities":	{"NNS"},
"amenity":	{"NN"},
"amenorrhea":	{"NN"},
"amenorrheal":	{"JJ"},
"amenorrheic":	{"JJ"},
"amenorrhoea":	{"NN"},
"amenorrhoeal":	{"JJ"},
"amenorrhoeic":	{"JJ"},
"ament":	{"NN"},
"amentaceous":	{"JJ"},
"amentia":	{"NN"},
"amentiferae":	{"NN"},
"amentiferous":	{"JJ"},
"amerce":	{"VB"},
"amercement":	{"NN"},
"amerciable":	{"JJ"},
"american-built":	{"JJ"},
"american-developed":	{"JJ"},
"american-jewish":	{"JJ"},
"american-led":	{"JJ"},
"american-made":	{"JJ"},
"american-style":	{"JJ"},
"american-trained":	{"JJ"},
"americanisation":	{"NN"},
"americanise":	{"VB"},
"americanism":	{"NN"},
"americanization":	{"NN"},
"americanize":	{"VB"},
"americans":	{"NNS"},
"americium":	{"NN"},
"amerind":	{"JJ","NN"},
"amerindian":	{"NN"},
"amerindic":	{"JJ"},
"ames":	{"NN"},
"ametabolic":	{"JJ"},
"ametabolous":	{"JJ"},
"amethopterin":	{"NN"},
"amethyst":	{"NN","JJ"},
"amethystine":	{"JJ"},
"amethysts":	{"NNS"},
"ametria":	{"NN"},
"ametropia":	{"NN"},
"ametropic":	{"JJ"},
"amex":	{"NN"},
"amhara":	{"NN"},
"amharic":	{"JJ","NN"},
"amherst":	{"NN"},
"ami":	{"NN"},
"amia":	{"NN"},
"amiability":	{"NN"},
"amiable":	{"JJ"},
"amiableness":	{"NN"},
"amiably":	{"RB"},
"amianthum":	{"NN"},
"amicability":	{"NN"},
"amicable":	{"JJ"},
"amicableness":	{"NN"},
"amicably":	{"RB"},
"amici":	{"NNS"},
"amicus":	{"NN","JJ"},
"amid":	{"IN"},
"amide":	{"NN"},
"amidopyrine":	{"NN"},
"amidship":	{"JJ","RB"},
"amidships":	{"RB"},
"amidst":	{"IN"},
"amigo":	{"NN"},
"amiidae":	{"NN"},
"amin":	{"NN"},
"amination":	{"NN"},
"amine":	{"NN"},
"amines":	{"NNS"},
"aminic":	{"JJ"},
"amino":	{"JJ","NN"},
"aminoaciduria":	{"NN"},
"aminoalkane":	{"NN"},
"aminobenzine":	{"NN"},
"aminometha":	{"NN"},
"aminomethane":	{"NN"},
"aminopherase":	{"NN"},
"aminophylline":	{"NN"},
"aminoplast":	{"NN"},
"aminopyrine":	{"NN"},
"aminotransferase":	{"NN"},
"amiodarone":	{"NN"},
"amir":	{"NN"},
"amish":	{"NN"},
"amiss":	{"JJ","RB"},
"amitosis":	{"NN"},
"amitotic":	{"JJ"},
"amitriptyline":	{"NN"},
"amity":	{"NN"},
"amman":	{"NN"},
"ammeter":	{"NN"},
"ammine":	{"NN"},
"ammino":	{"JJ"},
"ammo":	{"NN"},
"ammobium":	{"NN"},
"ammodytes":	{"NNS"},
"ammodytidae":	{"NN"},
"ammonia":	{"NN"},
"ammoniac":	{"JJ","NN"},
"ammoniacal":	{"JJ"},
"ammoniate":	{"VB"},
"ammoniated":	{"JJ"},
"ammonification":	{"NN"},
"ammonify":	{"VB"},
"ammonite":	{"NN"},
"ammonitic":	{"JJ"},
"ammonium":	{"NN"},
"ammoniuria":	{"NN"},
"ammonoid":	{"NN"},
"ammotragus":	{"NN"},
"ammunition":	{"NN"},
"amnesia":	{"NN"},
"amnesiac":	{"JJ","NN"},
"amnesic":	{"JJ","NN"},
"amnestic":	{"JJ"},
"amnestied":	{"VBD","VBN"},
"amnesties":	{"NNS","VBZ"},
"amnesty":	{"NN","VB","VBP"},
"amnestying":	{"VBG"},
"amnic":	{"JJ"},
"amnio":	{"NN"},
"amniocentesis":	{"NN"},
"amnion":	{"NN"},
"amnionic":	{"JJ"},
"amnios":	{"NN"},
"amniota":	{"NN"},
"amniote":	{"NN"},
"amniotic":	{"JJ"},
"amobarbital":	{"NN"},
"amoco-led":	{"JJ"},
"amoeba":	{"NN"},
"amoeban":	{"JJ"},
"amoebiasis":	{"NN"},
"amoebic":	{"JJ"},
"amoebida":	{"NN"},
"amoebina":	{"NN"},
"amoebiosis":	{"NN"},
"amoeboid":	{"JJ","NN"},
"amoebous":	{"JJ"},
"amok":	{"RB","NN"},
"amomng":	{"JJ"},
"amon-ra":	{"NN"},
"among":	{"IN"},
"amongst":	{"IN","NN"},
"amontillado":	{"NN"},
"amor":	{"NN"},
"amora":	{"NN"},
"amoral":	{"JJ","NN"},
"amoralism":	{"NN"},
"amoralist":	{"NN"},
"amorality":	{"NN"},
"amorally":	{"RB"},
"amorist":	{"NN"},
"amoristic":	{"JJ"},
"amorous":	{"JJ"},
"amorously":	{"RB"},
"amorousness":	{"NN"},
"amorpha":	{"NN"},
"amorphophallus":	{"NN"},
"amorphous":	{"JJ"},
"amorphously":	{"RB"},
"amort":	{"JJ"},
"amortisation":	{"NN"},
"amortise":	{"VB","VBP"},
"amortised":	{"VBD","VBN"},
"amortises":	{"VBZ"},
"amortising":	{"VBG"},
"amortization":	{"NN"},
"amortize":	{"VB","VBP"},
"amortized":	{"VBD","VBN"},
"amortizes":	{"VBZ"},
"amortizing":	{"VBG"},
"amory":	{"NN"},
"amos":	{"NN"},
"amount":	{"NN","VB","VBP"},
"amounted":	{"VBD","VBN"},
"amounting":	{"NN","VBG"},
"amounts":	{"NNS","VBZ"},
"amour":	{"NN"},
"amours":	{"NNS"},
"amoxicillin":	{"NN"},
"amoxil":	{"NN"},
"amoy":	{"NN"},
"amp":	{"VB","VBP","NN"},
"amped":	{"VBD","VBN"},
"amped-up":	{"JJ"},
"amperage":	{"NN"},
"ampere":	{"NN"},
"ampere-hour":	{"NN"},
"ampere-minute":	{"NN"},
"ampere-second":	{"NN"},
"ampere-turn":	{"NN"},
"ampersand":	{"NN"},
"amphetamine":	{"NN"},
"amphetamines":	{"NNS"},
"amphibia":	{"NN"},
"amphibian":	{"JJ","NN"},
"amphibiotic":	{"JJ"},
"amphibious":	{"JJ"},
"amphibole":	{"NN"},
"amphibolips":	{"NNS"},
"amphibolite":	{"NN"},
"amphibology":	{"NN"},
"amphiboly":	{"NN"},
"amphibrach":	{"NN"},
"amphicarpa":	{"NN"},
"amphicarpaea":	{"NN"},
"amphictyony":	{"NN"},
"amphidiploid":	{"NN"},
"amphidiploidy":	{"NN"},
"amphigory":	{"NN"},
"amphimixis":	{"NN"},
"amphineura":	{"NN"},
"amphioxidae":	{"NN"},
"amphioxus":	{"NN"},
"amphipod":	{"NN","JJ"},
"amphipoda":	{"NN"},
"amphipods":	{"NNS"},
"amphiprion":	{"NN"},
"amphiprostylar":	{"JJ"},
"amphiprostyle":	{"JJ"},
"amphiprotic":	{"JJ"},
"amphisbaena":	{"NN"},
"amphisbaenia":	{"NN"},
"amphisbaenidae":	{"NN"},
"amphistylar":	{"JJ"},
"amphitheater":	{"NN"},
"amphitheatre":	{"NN"},
"amphitheatric":	{"JJ"},
"amphitheatrical":	{"JJ"},
"amphitropous":	{"JJ"},
"amphiuma":	{"NN"},
"amphiumidae":	{"NN"},
"amphobiles":	{"NNS"},
"amphora":	{"NN"},
"amphoric":	{"JJ"},
"amphoteric":	{"JJ"},
"amphotericin":	{"NN"},
"ampicillin":	{"NN"},
"amping":	{"VBG"},
"ample":	{"JJ"},
"ampleness":	{"NN"},
"amplification":	{"NN"},
"amplified":	{"VBD","VBN"},
"amplifier":	{"NN"},
"amplifiers":	{"NNS"},
"amplifies":	{"VBZ"},
"amplify":	{"VB","VBP"},
"amplifying":	{"VBG"},
"amplitude":	{"NN"},
"amply":	{"RB"},
"ampoule":	{"NN"},
"amps":	{"NNS","VBZ"},
"ampul":	{"NN"},
"ampule":	{"NN"},
"ampulla":	{"NN"},
"ampullar":	{"JJ"},
"ampullary":	{"JJ"},
"amputate":	{"VB","VBP"},
"amputated":	{"VBD","VBN"},
"amputates":	{"VBZ"},
"amputating":	{"VBG"},
"amputation":	{"NN"},
"amputations":	{"NNS"},
"amputator":	{"NN"},
"amputee":	{"NN"},
"amra":	{"NN"},
"amrinone":	{"NN"},
"amsinckia":	{"NN"},
"amsonia":	{"NN"},
"amsterdam":	{"NN"},
"amuck":	{"JJ","RB"},
"amulet":	{"NN"},
"amulets":	{"NNS"},
"amun":	{"NN"},
"amundsen":	{"NN"},
"amur":	{"NN"},
"amuse":	{"VB","VBP"},
"amused":	{"JJ","VBD","VBN"},
"amusedly":	{"RB"},
"amusement":	{"NN"},
"amusements":	{"NNS"},
"amuses":	{"VBZ"},
"amusing":	{"JJ","VBG"},
"amusingly":	{"RB"},
"amusive":	{"JJ"},
"amygdala":	{"NN"},
"amygdalaceae":	{"NN"},
"amygdaliform":	{"JJ"},
"amygdalin":	{"NN"},
"amygdaline":	{"JJ"},
"amygdaloid":	{"JJ","NN"},
"amygdaloidal":	{"JJ"},
"amygdalotomy":	{"NN"},
"amygdalus":	{"NN"},
"amyl":	{"NN"},
"amylaceous":	{"JJ"},
"amylase":	{"NN"},
"amyloid":	{"JJ","NN"},
"amyloidal":	{"JJ"},
"amyloidosis":	{"NN"},
"amylolysis":	{"NN"},
"amylolytic":	{"JJ"},
"amylum":	{"NN"},
"amyotonia":	{"NN"},
"amyotrophia":	{"NN"},
"amyotrophic":	{"JJ"},
"amyotrophy":	{"NN"},
"amytal":	{"NN"},
"amyxia":	{"NN"},
"an":	{"DT"},
"ana":	{"NN"},
"anabantidae":	{"NN"},
"anabaptism":	{"NN"},
"anabaptist":	{"NN"},
"anabas":	{"NN"},
"anabatic":	{"JJ"},
"anabiosis":	{"NN"},
"anabiotic":	{"JJ"},
"anabolic":	{"JJ"},
"anabolism":	{"NN"},
"anabrus":	{"NN"},
"anacanthini":	{"NN"},
"anacardiaceae":	{"NN"},
"anacardium":	{"NN"},
"anachronic":	{"JJ"},
"anachronism":	{"NN"},
"anachronisms":	{"NNS"},
"anachronistic":	{"JJ"},
"anachronistically":	{"RB"},
"anachronous":	{"JJ"},
"anaclinal":	{"JJ"},
"anaclisis":	{"NN"},
"anaclitic":	{"JJ"},
"anacoluthia":	{"NN"},
"anacoluthic":	{"JJ"},
"anacoluthon":	{"NN"},
"anaconda":	{"NN"},
"anacondas":	{"NNS","VBZ"},
"anacyclus":	{"NN"},
"anadenanthera":	{"NN"},
"anadiplosis":	{"NN"},
"anadromous":	{"JJ"},
"anaemia":	{"NN"},
"anaemic":	{"JJ"},
"anaerobe":	{"NN"},
"anaerobic":	{"JJ"},
"anaerobiotic":	{"JJ"},
"anaesthesia":	{"NN"},
"anaesthetic":	{"JJ","NN"},
"anaesthetics":	{"NNS"},
"anaesthetise":	{"VB","VBP"},
"anaesthetised":	{"VBD","VBN"},
"anaesthetises":	{"VBZ"},
"anaesthetising":	{"VBG"},
"anaesthetist":	{"NN"},
"anaesthetize":	{"VB","VBP"},
"anaesthetized":	{"VBD","VBN"},
"anaesthetizes":	{"VBZ"},
"anaesthetizing":	{"VBG"},
"anagallis":	{"NN"},
"anagasta":	{"NN"},
"anaglyph":	{"NN"},
"anaglyphic":	{"JJ"},
"anaglyphical":	{"JJ"},
"anaglyphy":	{"NN"},
"anaglyptic":	{"JJ"},
"anaglyptical":	{"JJ"},
"anagnost":	{"NN"},
"anagoge":	{"NN"},
"anagogic":	{"JJ"},
"anagogical":	{"JJ"},
"anagram":	{"NN"},
"anagrammatic":	{"JJ"},
"anagrammatical":	{"JJ"},
"anagrammatise":	{"VB"},
"anagrammatize":	{"VB"},
"anagrams":	{"NNS"},
"anagyris":	{"NN"},
"anaheim":	{"NN"},
"anal":	{"JJ"},
"analbuminemia":	{"NN"},
"analecta":	{"NN"},
"analects":	{"NN"},
"analeptic":	{"JJ"},
"analgesia":	{"NN"},
"analgesic":	{"NN","JJ"},
"analgetic":	{"JJ"},
"analog":	{"NN","JJ"},
"analogical":	{"JJ"},
"analogies":	{"NNS"},
"analogist":	{"NN"},
"analogize":	{"VB","VBP"},
"analogized":	{"VBD","VBN"},
"analogizes":	{"VBZ"},
"analogizing":	{"VBG"},
"analogous":	{"JJ","NN"},
"analogously":	{"RB"},
"analogue":	{"NN","JJ"},
"analogues":	{"NNS"},
"analogy":	{"NN"},
"analphabet":	{"NN"},
"analphabetic":	{"JJ","NN"},
"analphabetism":	{"NN"},
"analysand":	{"NN"},
"analyse":	{"VB","VBP"},
"analysed":	{"VBN","VBD"},
"analyser":	{"NN"},
"analysers":	{"NNS"},
"analyses":	{"VBZ"},
"analysing":	{"VBG"},
"analysis":	{"NN"},
"analyst":	{"NN"},
"analystics":	{"NNS"},
"analysts":	{"NNS"},
"analytic":	{"JJ","NN"},
"analytical":	{"JJ","NN"},
"analytical-instruments":	{"JJ"},
"analytically":	{"RB"},
"analyticity":	{"NN"},
"analyzable":	{"JJ"},
"analyze":	{"VB","VBP"},
"analyzed":	{"VBD","VBN"},
"analyzer":	{"NN"},
"analyzes":	{"VBZ"},
"analyzing":	{"VBG"},
"anamnesis":	{"NN"},
"anamnestic":	{"JJ"},
"anamorphic":	{"JJ"},
"anamorphism":	{"NN"},
"anamorphosis":	{"NN"},
"ananas":	{"NN"},
"ananias":	{"NNS"},
"anapaest":	{"NN"},
"anapaestic":	{"JJ"},
"anapest":	{"NN"},
"anapestic":	{"JJ"},
"anaphalis":	{"NN"},
"anaphase":	{"NN"},
"anaphasic":	{"JJ"},
"anaphor":	{"NN"},
"anaphora":	{"NN"},
"anaphoric":	{"JJ"},
"anaphrodisia":	{"NN"},
"anaphrodisiac":	{"JJ","NN"},
"anaphylactic":	{"JJ","NN"},
"anaphylaxis":	{"NN"},
"anaplasia":	{"NN"},
"anaplasmosis":	{"NN"},
"anaplastic":	{"JJ"},
"anaplasty":	{"NN"},
"anaprapath":	{"NN"},
"anaprox":	{"NN"},
"anapsid":	{"NN"},
"anapsida":	{"NN"},
"anapurna":	{"NN"},
"anarchic":	{"JJ","NN"},
"anarchical":	{"JJ"},
"anarchically":	{"RB"},
"anarchism":	{"NN"},
"anarchist":	{"NN"},
"anarchist-adventurers":	{"NNS"},
"anarchistic":	{"JJ"},
"anarchy":	{"NN"},
"anarhichadidae":	{"NN"},
"anarhichas":	{"NNS"},
"anarthria":	{"NN"},
"anas":	{"NNS"},
"anasa":	{"NN"},
"anasarca":	{"NN"},
"anasarcous":	{"JJ"},
"anasazi":	{"NN"},
"anaspid":	{"NN"},
"anaspida":	{"NN"},
"anastalsis":	{"NN"},
"anastatica":	{"NN"},
"anastigmat":	{"NN"},
"anastigmatic":	{"JJ"},
"anastomose":	{"VB"},
"anastomoses":	{"NNS","VBZ"},
"anastomosis":	{"NN"},
"anastomotic":	{"JJ"},
"anastomus":	{"NN"},
"anastrophe":	{"NN"},
"anastylosis":	{"NN"},
"anathema":	{"NN"},
"anathematisation":	{"NN"},
"anathematise":	{"VB"},
"anathematization":	{"NN"},
"anathematize":	{"VB"},
"anathemise":	{"VB"},
"anathemize":	{"VB"},
"anatidae":	{"NN"},
"anatolia":	{"NN"},
"anatolian":	{"NN"},
"anatomic":	{"JJ"},
"anatomical":	{"JJ","NN"},
"anatomically":	{"RB"},
"anatomicals":	{"NNS"},
"anatomise":	{"VB","VBP"},
"anatomised":	{"VBD","VBN"},
"anatomises":	{"VBZ"},
"anatomising":	{"VBG"},
"anatomist":	{"NN"},
"anatomize":	{"VB","VBP"},
"anatomized":	{"VBD","VBN"},
"anatomizes":	{"VBZ"},
"anatomizing":	{"VBG"},
"anatomy":	{"NN"},
"anatotitan":	{"NN"},
"anatoxin":	{"NN"},
"anatropous":	{"JJ"},
"anaxagoras":	{"NNS"},
"anaximander":	{"NN"},
"anaximenes":	{"NNS"},
"ancestor":	{"NN"},
"ancestors":	{"NNS"},
"ancestral":	{"JJ"},
"ancestress":	{"NN"},
"ancestry":	{"NN"},
"anchor":	{"NN","VB","VBP"},
"anchorage":	{"NN"},
"anchorages":	{"NNS"},
"anchored":	{"VBD","VBN"},
"anchoring":	{"VBG"},
"anchorite":	{"NN"},
"anchoritic":	{"JJ"},
"anchoritism":	{"NN"},
"anchorman":	{"NN"},
"anchormen":	{"NNS"},
"anchorperson":	{"NN"},
"anchors":	{"NNS","VBZ"},
"anchorwoman":	{"NN"},
"anchovy":	{"NN"},
"anchusa":	{"NN"},
"anchylosis":	{"NN"},
"ancient":	{"JJ","NN"},
"anciently":	{"RB"},
"ancientness":	{"NN"},
"ancients":	{"NNS"},
"ancillary":	{"JJ","NN"},
"ancistrodon":	{"NN"},
"ancohuma":	{"NN"},
"ancylidae":	{"NN"},
"ancylose":	{"VB"},
"ancylostomatidae":	{"NN"},
"ancylus":	{"NN"},
"and":	{"CC"},
"andalucia":	{"NN"},
"andalusia":	{"NN"},
"andalusian":	{"JJ"},
"andante":	{"JJ","RB","NN"},
"andantino":	{"JJ"},
"andean":	{"JJ"},
"andelmin":	{"NN"},
"anders":	{"NNS"},
"anderson":	{"NN"},
"andes":	{"NNS"},
"andesite":	{"NN"},
"andira":	{"NN"},
"andiron":	{"NN"},
"andorra":	{"NN"},
"andorran":	{"JJ","NN"},
"andradite":	{"NN"},
"andreaea":	{"NN"},
"andreaeales":	{"NNS"},
"andrena":	{"NN"},
"andrenid":	{"NN"},
"andrenidae":	{"NN"},
"andrew":	{"NN"},
"andricus":	{"NN"},
"androecium":	{"NN"},
"androgen":	{"NN"},
"androgenesis":	{"NN"},
"androgenetic":	{"JJ"},
"androgenic":	{"JJ"},
"androgenous":	{"JJ"},
"androgeny":	{"NN"},
"androglossia":	{"NN"},
"androgyne":	{"NN"},
"androgynous":	{"JJ"},
"androgyny":	{"NN"},
"android":	{"JJ","NN"},
"andromeda":	{"NN"},
"androphobia":	{"NN"},
"andropogon":	{"NN"},
"androsterone":	{"NN"},
"andryala":	{"NN"},
"andvari":	{"NN"},
"ane":	{"NN"},
"anecdotal":	{"JJ","NN"},
"anecdote":	{"NN"},
"anecdotes":	{"NNS"},
"anecdotic":	{"JJ"},
"anecdotical":	{"JJ"},
"anecdotist":	{"NN"},
"anechoic":	{"JJ"},
"aneides":	{"NNS"},
"anele":	{"VB"},
"anemated":	{"VBN"},
"anemia":	{"NN"},
"anemias":	{"NNS"},
"anemic":	{"JJ"},
"anemics":	{"NNS"},
"anemographic":	{"JJ"},
"anemography":	{"NN"},
"anemometer":	{"NN"},
"anemometric":	{"JJ"},
"anemometrical":	{"JJ"},
"anemometry":	{"NN"},
"anemone":	{"NN"},
"anemonella":	{"NN"},
"anemophilous":	{"JJ"},
"anemopsis":	{"NN"},
"anencephalia":	{"NN"},
"anencephalic":	{"JJ"},
"anencephalous":	{"JJ"},
"anencephaly":	{"NN"},
"anergy":	{"NN"},
"aneroid":	{"JJ","NN"},
"anesthesia":	{"NN"},
"anesthesiologist":	{"NN"},
"anesthesiology":	{"NN"},
"anesthetic":	{"NN","JJ"},
"anesthetically":	{"RB"},
"anesthetics":	{"NNS"},
"anesthetise":	{"VB","VBP"},
"anesthetised":	{"VBD","VBN"},
"anesthetises":	{"VBZ"},
"anesthetising":	{"VBG"},
"anesthetist":	{"NN"},
"anesthetists":	{"NNS"},
"anesthetize":	{"VB","VBP"},
"anesthetized":	{"VBD","VBN"},
"anesthetizes":	{"VBZ"},
"anesthetizing":	{"VBG"},
"anesthyl":	{"NN"},
"anestric":	{"JJ"},
"anestrous":	{"JJ"},
"anestrum":	{"NN"},
"anestrus":	{"NN"},
"anethum":	{"NN"},
"aneuploid":	{"JJ","NN"},
"aneuploidy":	{"NN"},
"aneurin":	{"NN"},
"aneurism":	{"NN"},
"aneurismal":	{"JJ"},
"aneurismatic":	{"JJ"},
"aneurysm":	{"NN"},
"aneurysmal":	{"JJ"},
"aneurysmatic":	{"JJ"},
"anew":	{"RB","NN"},
"anfractuous":	{"JJ"},
"ang":	{"NN"},
"angara":	{"NN"},
"angas":	{"NNS"},
"angel":	{"NN"},
"angeles-area":	{"JJ"},
"angeles-based":	{"JJ"},
"angelfish":	{"NN","NNS"},
"angelic":	{"JJ","NN"},
"angelica":	{"NN"},
"angelical":	{"JJ"},
"angelically":	{"RB"},
"angelim":	{"NN"},
"angelique":	{"NN"},
"angelology":	{"NN"},
"angels":	{"NNS"},
"angelus":	{"NN"},
"anger":	{"NN","VBP","VB"},
"angered":	{"VBD","VBN"},
"angering":	{"VBG","NN"},
"angers":	{"VBZ","NNS"},
"angevin":	{"NN"},
"angevine":	{"NN"},
"angiitis":	{"NN"},
"angina":	{"NN"},
"anginal":	{"JJ"},
"anginose":	{"JJ"},
"anginous":	{"JJ"},
"angiocardiogram":	{"NN"},
"angiocardiopathy":	{"NN"},
"angiocarp":	{"NN"},
"angiocarpic":	{"JJ"},
"angiocarpous":	{"JJ"},
"angioedema":	{"NN"},
"angiogenesis":	{"NN"},
"angiogram":	{"NN"},
"angiography":	{"NN"},
"angiohemophilia":	{"NN"},
"angiologist":	{"NN"},
"angiology":	{"NN"},
"angioma":	{"NN"},
"angiomatous":	{"JJ"},
"angiopathy":	{"NN"},
"angioplasty":	{"NN"},
"angiopteris":	{"NN"},
"angiosarcoma":	{"NN"},
"angioscope":	{"NN"},
"angiosperm":	{"NN"},
"angiospermae":	{"NN"},
"angiospermous":	{"JJ"},
"angiotelectasia":	{"NN"},
"angiotensin":	{"NN"},
"angiotonin":	{"NN"},
"angle":	{"NN","VB","VBP"},
"angle-park":	{"VB"},
"angled":	{"VBD","VBN"},
"angledozer":	{"NN"},
"angler":	{"NN"},
"anglerfish":	{"NN","NNS"},
"anglers":	{"NNS"},
"angles":	{"NNS","VBZ"},
"anglesea":	{"NN"},
"anglesey":	{"NN"},
"anglewing":	{"NN"},
"angleworm":	{"NN"},
"anglia":	{"NN"},
"anglicanism":	{"NN"},
"anglicans":	{"NNS"},
"anglicisation":	{"NN"},
"anglicise":	{"VB","VBP"},
"anglicised":	{"VBD","VBN"},
"anglicises":	{"VBZ"},
"anglicising":	{"VBG"},
"anglicism":	{"NN"},
"anglicization":	{"NN"},
"anglicize":	{"VB","VBP"},
"anglicized":	{"VBD","VBN"},
"anglicizes":	{"VBZ"},
"anglicizing":	{"VBG"},
"angling":	{"NN","VBG"},
"anglo":	{"NN"},
"anglo-american":	{"NN"},
"anglo-catholic":	{"JJ"},
"anglo-catholicism":	{"NN"},
"anglo-french":	{"NN"},
"anglo-indian":	{"JJ","NN"},
"anglo-irish":	{"JJ"},
"anglo-jewish":	{"JJ"},
"anglo-norman":	{"NN"},
"anglo-north":	{"JJ"},
"anglo-protestant":	{"JJ"},
"anglo-saxons":	{"NNS"},
"anglomania":	{"NN"},
"anglophil":	{"NN"},
"anglophile":	{"NN"},
"anglophilia":	{"NN"},
"anglophilic":	{"JJ"},
"anglophobe":	{"NN"},
"anglophobia":	{"NN"},
"anglophobic":	{"JJ"},
"angola":	{"NN"},
"angolan":	{"JJ","NN"},
"angolese":	{"NN"},
"angora":	{"NN"},
"angostura":	{"NN"},
"angraecum":	{"NN"},
"angrecum":	{"NN"},
"angrier":	{"JJR"},
"angriest":	{"JJS"},
"angrily":	{"RB"},
"angriness":	{"NN"},
"angry":	{"JJ"},
"angst":	{"NN"},
"angstrom":	{"NN"},
"anguidae":	{"NN"},
"anguilla":	{"NN"},
"anguillan":	{"JJ","NN"},
"anguillidae":	{"NN"},
"anguilliformes":	{"NNS"},
"anguillula":	{"NN"},
"anguine":	{"JJ"},
"anguis":	{"NN"},
"anguish":	{"NN","VB","VBP"},
"anguished":	{"JJ","VBD","VBN"},
"anguishes":	{"VBZ"},
"anguishing":	{"VBG"},
"angular":	{"JJ","NN"},
"angularity":	{"NN"},
"angulate":	{"JJ","VB"},
"angulation":	{"NN"},
"angwantibo":	{"NN"},
"anhedonia":	{"NN"},
"anhemolyticus":	{"NN"},
"anhidrosis":	{"NN"},
"anhima":	{"NN"},
"anhimidae":	{"NN"},
"anhinga":	{"NN"},
"anhingidae":	{"NN"},
"anhydride":	{"NN"},
"anhydrosis":	{"NN"},
"anhydrous":	{"JJ"},
"anhydrously":	{"RB"},
"ani":	{"NN"},
"anicteric":	{"JJ"},
"anigozanthus":	{"NN"},
"anil":	{"NN"},
"anile":	{"JJ"},
"aniline":	{"NN"},
"anima":	{"NN"},
"animadversion":	{"NN"},
"animadvert":	{"VB"},
"animadverted":	{"VBD","VBN"},
"animadverting":	{"VBG"},
"animadverts":	{"VBZ"},
"animal":	{"NN","JJ"},
"animal-based":	{"JJ"},
"animal-health":	{"NN"},
"animal-human":	{"NN"},
"animal-like":	{"JJ"},
"animal-protection":	{"NN"},
"animal-rights":	{"NNS","JJ","NN"},
"animal-worship":	{"NN"},
"animalcare":	{"JJ"},
"animalcule":	{"NN"},
"animalculum":	{"NN"},
"animalia":	{"NN"},
"animalisation":	{"NN"},
"animalise":	{"VB"},
"animalism":	{"NN"},
"animalistic":	{"JJ"},
"animality":	{"NN"},
"animalization":	{"NN"},
"animalize":	{"VB"},
"animals":	{"NNS"},
"animate":	{"VB","VBP","JJ"},
"animated":	{"JJ","VBN","VBD"},
"animatedly":	{"RB"},
"animateness":	{"NN"},
"animates":	{"VBZ"},
"animating":	{"VBG"},
"animation":	{"NN"},
"animations":	{"NNS"},
"animatism":	{"NN"},
"animatistic":	{"JJ"},
"animator":	{"NN"},
"animators":	{"NNS"},
"animatronics":	{"NN"},
"anime":	{"NN"},
"animise":	{"VB"},
"animism":	{"NN"},
"animist":	{"NN"},
"animistic":	{"JJ"},
"animize":	{"VB"},
"animized":	{"VBN"},
"animosities":	{"NNS"},
"animosity":	{"NN"},
"animus":	{"NN"},
"anion":	{"NN"},
"anionic":	{"JJ","NN"},
"anionics":	{"NNS"},
"anions":	{"NNS"},
"anise":	{"NN"},
"anise-scented":	{"JJ"},
"aniseed":	{"NN"},
"aniseikonia":	{"NN"},
"aniseikonic":	{"JJ"},
"anisette":	{"NN"},
"anisogamete":	{"NN"},
"anisogametic":	{"JJ"},
"anisogamic":	{"JJ"},
"anisogamous":	{"JJ"},
"anisogamy":	{"NN"},
"anisometric":	{"JJ"},
"anisometropia":	{"NN"},
"anisometropic":	{"JJ"},
"anisoptera":	{"NN"},
"anisotremus":	{"NN"},
"anisotropic":	{"JJ"},
"anisotropically":	{"RB"},
"anisotropy":	{"NN"},
"anjou":	{"NN"},
"ankara":	{"NN"},
"ankle":	{"NN"},
"ankle-deep":	{"JJ"},
"anklebone":	{"NN"},
"ankles":	{"NNS"},
"anklet":	{"NN"},
"anklets":	{"NNS"},
"ankus":	{"NN"},
"ankyloglossia":	{"NN"},
"ankylosaur":	{"NN"},
"ankylosaurus":	{"NN"},
"ankylose":	{"VB"},
"ankylosing":	{"VBG"},
"ankylosis":	{"NN"},
"ankylotic":	{"JJ"},
"anlage":	{"NN"},
"anlayst":	{"NN"},
"ann":	{"NN"},
"anna":	{"NN"},
"annaba":	{"NN"},
"annalist":	{"NN"},
"annalistic":	{"JJ"},
"annalists":	{"NNS"},
"annals":	{"NNS"},
"annam":	{"NN"},
"annamese":	{"NN"},
"annamite":	{"NN"},
"annapolis":	{"NN"},
"annapurna":	{"NN"},
"anne":	{"NN"},
"anneal":	{"VB","VBP"},
"annealed":	{"VBD","VBN"},
"annealing":	{"VBG"},
"anneals":	{"VBZ"},
"annee":	{"FW"},
"annelid":	{"JJ","NN"},
"annelida":	{"NN"},
"annelidan":	{"JJ"},
"annex":	{"VB","VBP","NN"},
"annexa":	{"NN"},
"annexal":	{"JJ"},
"annexation":	{"NN"},
"annexational":	{"JJ"},
"annexations":	{"NNS"},
"annexe":	{"NN"},
"annexed":	{"VBD","VBN"},
"annexes":	{"VBZ","NNS"},
"annexing":	{"VBG"},
"anniellidae":	{"NN"},
"annihilate":	{"VB","VBP"},
"annihilated":	{"VBD","VBN"},
"annihilates":	{"VBZ"},
"annihilating":	{"VBG"},
"annihilation":	{"NN"},
"annihilative":	{"JJ"},
"annihilator":	{"NN"},
"anniversaries":	{"NNS"},
"anniversary":	{"NN"},
"annnouncement":	{"NN"},
"annointed":	{"VBN"},
"annon":	{"NN"},
"annona":	{"NN"},
"annonaceae":	{"NN"},
"annotate":	{"VB","VBP"},
"annotated":	{"JJ","VBD","VBN"},
"annotates":	{"VBZ"},
"annotating":	{"VBG"},
"annotation":	{"NN"},
"annotations":	{"NNS"},
"annotator":	{"NN"},
"annotators":	{"NNS"},
"announce":	{"VB","VBP"},
"announced":	{"VBD","VBN"},
"announcement":	{"NN"},
"announcements":	{"NNS"},
"announcer":	{"NN"},
"announcers":	{"NNS"},
"announces":	{"VBZ"},
"announcing":	{"VBG"},
"annoy":	{"VB","NN","VBP"},
"annoyance":	{"NN"},
"annoyances":	{"NNS"},
"annoyed":	{"JJ","VBD","VBN"},
"annoyer":	{"NN"},
"annoying":	{"JJ","NN","VBG"},
"annoyingly":	{"RB"},
"annoys":	{"VBZ","NNS"},
"annual":	{"JJ","NN"},
"annual-income":	{"NN"},
"annualise":	{"VB","VBP"},
"annualised":	{"VBD","VBN"},
"annualises":	{"VBZ"},
"annualising":	{"VBG"},
"annualization":	{"NN"},
"annualize":	{"VB","VBP"},
"annualized":	{"VBD","VBN"},
"annualizes":	{"VBZ"},
"annualizing":	{"VBG"},
"annually":	{"RB"},
"annualry":	{"NN"},
"annuitant":	{"NN"},
"annuities":	{"NNS"},
"annuity":	{"NN"},
"annul":	{"VB","VBP"},
"annular":	{"JJ"},
"annulate":	{"JJ"},
"annulated":	{"JJ"},
"annulet":	{"NN"},
"annulled":	{"VBD","VBN"},
"annulling":	{"VBG"},
"annulment":	{"NN"},
"annuls":	{"VBZ"},
"annulus":	{"NN"},
"annum":	{"NN"},
"annunciate":	{"VB"},
"annunciated":	{"VBN"},
"annunciation":	{"NN"},
"annunciator":	{"NN"},
"annunciatory":	{"JJ"},
"annwfn":	{"NN"},
"annwn":	{"NN"},
"ano":	{"JJ"},
"anoa":	{"NN"},
"anobiidae":	{"NN"},
"anodal":	{"JJ"},
"anode":	{"NN"},
"anodes":	{"NNS"},
"anodic":	{"JJ"},
"anodise":	{"VB"},
"anodize":	{"VB"},
"anodonta":	{"NN"},
"anodyne":	{"NN","JJ"},
"anoectochilus":	{"NN"},
"anoestrous":	{"JJ"},
"anoestrum":	{"NN"},
"anoestrus":	{"NN"},
"anogramma":	{"NN"},
"anoint":	{"VB","VBP"},
"anointed":	{"VBD","VBN"},
"anointer":	{"NN"},
"anointing":	{"VBG","NN"},
"anointment":	{"NN"},
"anointments":	{"NNS"},
"anoints":	{"VBZ"},
"anole":	{"NN"},
"anolis":	{"NN"},
"anomala":	{"NN"},
"anomalies":	{"NNS"},
"anomalist":	{"NN"},
"anomalopidae":	{"NN"},
"anomalops":	{"NNS"},
"anomalopteryx":	{"NN"},
"anomalous":	{"JJ","NN"},
"anomalously":	{"RB"},
"anomalousness":	{"NN"},
"anomaly":	{"NN"},
"anomia":	{"NN"},
"anomic":	{"JJ"},
"anomie":	{"NN"},
"anomiidae":	{"NN"},
"anomy":	{"NN"},
"anon":	{"RB"},
"anonym":	{"NN"},
"anonymise":	{"VB","VBP"},
"anonymised":	{"VBD","VBN"},
"anonymises":	{"VBZ"},
"anonymising":	{"VBG"},
"anonymity":	{"NN"},
"anonymization":	{"NN"},
"anonymizations":	{"NNS"},
"anonymize":	{"VB","VBP"},
"anonymized":	{"VBD","VBN"},
"anonymizes":	{"VBZ"},
"anonymizing":	{"VBG"},
"anonymous":	{"JJ"},
"anonymously":	{"RB"},
"anoperineal":	{"JJ"},
"anopheles":	{"NNS","NN"},
"anopheline":	{"JJ","NN"},
"anopia":	{"NN"},
"anoplura":	{"NN"},
"anorak":	{"NN"},
"anorchia":	{"NN"},
"anorchidism":	{"NN"},
"anorchism":	{"NN"},
"anorectal":	{"JJ"},
"anorectic":	{"JJ","NN"},
"anorexia":	{"NN"},
"anorexic":	{"JJ","NN"},
"anorexigenic":	{"JJ"},
"anorgasmia":	{"NN"},
"anorthic":	{"JJ"},
"anorthite":	{"NN"},
"anorthitic":	{"JJ"},
"anorthography":	{"NN"},
"anorthopia":	{"NN"},
"anos":	{"NNS","FW","DT","IN"},
"anosmatic":	{"JJ"},
"anosmia":	{"NN"},
"anosmic":	{"JJ"},
"anostraca":	{"NN"},
"another":	{"DT","PRP"},
"anouilh":	{"NN"},
"anova":	{"NN"},
"anovulant":	{"NN"},
"anovulation":	{"NN"},
"anoxemia":	{"NN"},
"anoxemic":	{"JJ"},
"anoxia":	{"NN"},
"anoxic":	{"JJ"},
"anpu":	{"NN"},
"ans":	{"NNS"},
"ansaid":	{"NN"},
"anselm":	{"NN"},
"anser":	{"NN"},
"anseres":	{"NNS"},
"anseriformes":	{"NNS"},
"anserinae":	{"NN"},
"anserine":	{"JJ"},
"anshar":	{"NN"},
"anson":	{"NN"},
"answer":	{"NN","VB","VBP"},
"answerability":	{"NN"},
"answerable":	{"JJ"},
"answerableness":	{"NN"},
"answered":	{"VBD","VBN"},
"answerer":	{"NN"},
"answering":	{"VBG"},
"answers":	{"NNS","VBZ"},
"ant":	{"NN"},
"antabuse":	{"NN"},
"antacid":	{"NN","JJ"},
"antagonise":	{"VB","VBP"},
"antagonised":	{"VBD","VBN"},
"antagonises":	{"VBZ"},
"antagonising":	{"VBG"},
"antagonism":	{"NN"},
"antagonisms":	{"NNS"},
"antagonist":	{"NN"},
"antagonistic":	{"JJ"},
"antagonistically":	{"RB"},
"antagonists":	{"NNS"},
"antagonize":	{"VB","VBP"},
"antagonized":	{"VBD","VBN"},
"antagonizes":	{"VBZ"},
"antagonizing":	{"VBG"},
"antakiya":	{"NN"},
"antakya":	{"NN"},
"antalya":	{"NN"},
"antananarivo":	{"NN"},
"antapex":	{"NN"},
"antarctica":	{"NN"},
"antbird":	{"NN"},
"ante":	{"NN","VB","VBP"},
"ante-bellum":	{"FW","JJ","NN"},
"anteater":	{"NN"},
"anteaters":	{"NNS"},
"antebellum":	{"JJ"},
"antecede":	{"VB"},
"antecedence":	{"NN"},
"antecedency":	{"NN"},
"antecedent":	{"NN","JJ"},
"antecedently":	{"RB"},
"antecedents":	{"NNS"},
"antechamber":	{"NN"},
"antecubital":	{"JJ"},
"anted":	{"VBD","VBN"},
"antedate":	{"VB","VBP"},
"antedated":	{"VBD","VBN"},
"antedates":	{"VBZ"},
"antedating":	{"VBG"},
"antediluvial":	{"JJ"},
"antediluvian":	{"JJ","NN"},
"antedon":	{"NN"},
"antedonidae":	{"NN"},
"anteed":	{"VBD","VBN"},
"antefix":	{"NN"},
"anteing":	{"VBG"},
"antelope":	{"NN","NNS"},
"antelopes":	{"NNS"},
"antemeridian":	{"JJ"},
"antemortem":	{"JJ","NN"},
"antenatal":	{"JJ"},
"antenna":	{"NN"},
"antennae":	{"NNS"},
"antennal":	{"JJ"},
"antennaria":	{"NN"},
"antennariidae":	{"NN"},
"antennary":	{"JJ"},
"antennas":	{"NNS"},
"antenuptial":	{"JJ"},
"antepartum":	{"JJ","NN"},
"antepenult":	{"NN"},
"antepenultima":	{"NN"},
"antepenultimate":	{"JJ","NN"},
"anterior":	{"JJ","NN"},
"anteriority":	{"NN"},
"anteriorly":	{"RB"},
"anteriors":	{"NNS"},
"anterograde":	{"JJ","NN"},
"anteroom":	{"NN"},
"antes":	{"NNS","VBZ"},
"anthelminthic":	{"JJ","NN"},
"anthelmintic":	{"JJ","NN"},
"anthem":	{"NN"},
"anthemis":	{"NN"},
"anthems":	{"NNS"},
"anther":	{"NN"},
"antheraea":	{"NN"},
"antheral":	{"JJ"},
"anthericum":	{"NN"},
"antheridial":	{"JJ"},
"antheridiophore":	{"NN"},
"antheridium":	{"NN"},
"antheropeas":	{"NNS"},
"antherozoid":	{"NN"},
"anthers":	{"NNS"},
"anthesis":	{"NN"},
"anthidium":	{"NN"},
"anthill":	{"NN"},
"anthoceropsida":	{"NN"},
"anthoceros":	{"NNS"},
"anthocerotaceae":	{"NN"},
"anthocerotales":	{"NNS"},
"anthologise":	{"VB"},
"anthologist":	{"NN"},
"anthologize":	{"VB"},
"anthology":	{"NN"},
"anthonomus":	{"NN"},
"anthony":	{"NN"},
"anthophagous":	{"JJ"},
"anthophilous":	{"JJ"},
"anthophyllite":	{"NN"},
"anthophyta":	{"NN"},
"anthozoa":	{"NN"},
"anthozoan":	{"NN"},
"anthracite":	{"NN"},
"anthracitic":	{"JJ"},
"anthracosis":	{"NN"},
"anthrax":	{"NN"},
"anthriscus":	{"NN"},
"anthropic":	{"JJ","NN"},
"anthropical":	{"JJ"},
"anthropocentric":	{"JJ"},
"anthropocentricity":	{"NN"},
"anthropocentrism":	{"NN"},
"anthropogenesis":	{"NN"},
"anthropogenetic":	{"JJ"},
"anthropogenic":	{"JJ"},
"anthropogeny":	{"NN"},
"anthropoid":	{"NN","JJ"},
"anthropoidal":	{"JJ"},
"anthropoidea":	{"NN"},
"anthropoids":	{"NNS"},
"anthropolatry":	{"NN"},
"anthropologic":	{"JJ"},
"anthropological":	{"JJ","NN"},
"anthropological-religious":	{"JJ"},
"anthropologically":	{"RB"},
"anthropologise":	{"VB","VBP"},
"anthropologised":	{"VBD","VBN"},
"anthropologises":	{"VBZ"},
"anthropologising":	{"VBG"},
"anthropologist":	{"NN"},
"anthropologists":	{"NNS"},
"anthropologize":	{"VB","VBP"},
"anthropologized":	{"VBD","VBN"},
"anthropologizes":	{"VBZ"},
"anthropologizing":	{"VBG"},
"anthropology":	{"NN"},
"anthropometric":	{"JJ"},
"anthropometrical":	{"JJ"},
"anthropometry":	{"NN"},
"anthropomorphic":	{"JJ"},
"anthropomorphise":	{"VB"},
"anthropomorphism":	{"NN"},
"anthropomorphize":	{"VB","NN"},
"anthropomorphized":	{"VBD","VBN"},
"anthropomorphizes":	{"VBZ"},
"anthropomorphizing":	{"VBG"},
"anthropomorphous":	{"JJ"},
"anthropophagite":	{"NN"},
"anthropophagous":	{"JJ"},
"anthropophagus":	{"NN"},
"anthropophagy":	{"NN"},
"anthroposophy":	{"NN"},
"anthurium":	{"NN"},
"anthus":	{"NN"},
"anthyllis":	{"NN"},
"anti":	{"JJ","NN"},
"anti-AIDS":	{"JJ"},
"anti-American":	{"JJ"},
"anti-Americanism":	{"NN"},
"anti-Bork":	{"JJ"},
"anti-Castro":	{"JJ"},
"anti-Catholic":	{"JJ","NN"},
"anti-Catholicism":	{"NN"},
"anti-China":	{"JJ"},
"anti-Christian":	{"JJ"},
"anti-Colmer":	{"JJ"},
"anti-Communism":	{"NN"},
"anti-Communist":	{"JJ","NN"},
"anti-Communists":	{"NNS"},
"anti-European":	{"JJ","NN"},
"anti-Fascist":	{"JJ"},
"anti-French":	{"JJ"},
"anti-Galileo":	{"JJ"},
"anti-Honecker":	{"JJ"},
"anti-Japanese":	{"JJ"},
"anti-Kabul":	{"JJ"},
"anti-Kennedy":	{"JJ"},
"anti-LDP":	{"JJ"},
"anti-Moscow":	{"JJ"},
"anti-NATO":	{"JJ"},
"anti-Nazi":	{"JJ","NN"},
"anti-Nazis":	{"NNS"},
"anti-Negro":	{"JJ"},
"anti-Newtonian":	{"JJ"},
"anti-Noriega":	{"JJ"},
"anti-Sandinista":	{"JJ"},
"anti-Semitic":	{"JJ"},
"anti-Somoza":	{"JJ"},
"anti-Sony":	{"JJ"},
"anti-South":	{"JJ"},
"anti-Soviet":	{"JJ"},
"anti-Stalinist":	{"JJ"},
"anti-Taliban":	{"JJ"},
"anti-Turkish":	{"JJ"},
"anti-U.S.":	{"JJ"},
"anti-Western":	{"JJ"},
"anti-Yankee":	{"JJ"},
"anti-abortion":	{"JJ","NN"},
"anti-abortionist":	{"NN"},
"anti-abortionists":	{"NNS"},
"anti-acne":	{"NN"},
"anti-aids":	{"JJ"},
"anti-aircraft":	{"JJ"},
"anti-airline":	{"NN"},
"anti-airline-takeover":	{"JJ"},
"anti-alcohol":	{"JJ"},
"anti-american":	{"JJ","NN"},
"anti-androgen":	{"JJ","NN"},
"anti-androgens":	{"NNS"},
"anti-anemia":	{"NN"},
"anti-apartheid":	{"JJ","NN"},
"anti-army":	{"JJ"},
"anti-assignment":	{"JJ"},
"anti-authoritarian":	{"JJ"},
"anti-ballistic-missile":	{"JJ"},
"anti-bike":	{"JJ"},
"anti-bork":	{"JJ"},
"anti-business":	{"JJ"},
"anti-cancer":	{"JJ"},
"anti-cartel":	{"JJ"},
"anti-castro":	{"JJ"},
"anti-catholic":	{"JJ"},
"anti-catholicism":	{"NN"},
"anti-china":	{"JJ"},
"anti-choice":	{"JJ"},
"anti-cholesterol":	{"JJ"},
"anti-christian":	{"JJ"},
"anti-cigarette":	{"JJ"},
"anti-clericalism":	{"JJ"},
"anti-clotting":	{"JJ"},
"anti-colmer":	{"JJ"},
"anti-communism":	{"NN"},
"anti-communist":	{"JJ"},
"anti-competitive":	{"JJ"},
"anti-conservation":	{"JJ"},
"anti-contamination":	{"JJ"},
"anti-convulsive":	{"JJ"},
"anti-crime":	{"JJ"},
"anti-debt":	{"JJ"},
"anti-deer":	{"JJ"},
"anti-defense":	{"JJ"},
"anti-democratic":	{"JJ"},
"anti-depressant":	{"JJ","NN"},
"anti-development":	{"JJ"},
"anti-diabetes":	{"JJ"},
"anti-diarrheal":	{"JJ"},
"anti-dilutive":	{"JJ"},
"anti-discrimination":	{"JJ","NN"},
"anti-discriminatory":	{"JJ"},
"anti-drug":	{"JJ","NN"},
"anti-drug-law":	{"NN"},
"anti-dumping":	{"JJ"},
"anti-epilepsy":	{"JJ"},
"anti-epileptic":	{"JJ"},
"anti-european":	{"JJ"},
"anti-extortion":	{"NN"},
"anti-fascist":	{"JJ"},
"anti-flag-burning":	{"JJ"},
"anti-foreign":	{"JJ"},
"anti-foreigner":	{"NN"},
"anti-fraud":	{"JJ"},
"anti-freeze":	{"JJ","NN"},
"anti-french":	{"JJ"},
"anti-fungal":	{"JJ"},
"anti-galileo":	{"JJ"},
"anti-gay":	{"JJ"},
"anti-generic":	{"JJ"},
"anti-government":	{"JJ","NN"},
"anti-growth":	{"JJ"},
"anti-gun":	{"JJ"},
"anti-heroes":	{"NNS"},
"anti-homosexual":	{"JJ"},
"anti-honecker":	{"JJ"},
"anti-hooligan":	{"JJ"},
"anti-human":	{"JJ"},
"anti-hypertensive":	{"JJ"},
"anti-idiotypes":	{"NNS"},
"anti-immigrant":	{"JJ"},
"anti-infective":	{"JJ","NN"},
"anti-infectives":	{"NNS"},
"anti-inflammatory":	{"NN","JJ"},
"anti-inflation":	{"JJ"},
"anti-inflationary":	{"JJ"},
"anti-intellectual":	{"JJ","NN"},
"anti-intellectualism":	{"NN","JJ"},
"anti-japanese":	{"JJ"},
"anti-jones":	{"JJ"},
"anti-kabul":	{"JJ"},
"anti-kennedy":	{"JJ"},
"anti-ldp":	{"JJ"},
"anti-leak":	{"JJ"},
"anti-liquor":	{"JJ"},
"anti-lobbying":	{"JJ"},
"anti-lobbyist":	{"NN"},
"anti-lock":	{"NN","JJ"},
"anti-management":	{"JJ"},
"anti-market":	{"JJ"},
"anti-men":	{"JJ"},
"anti-militarists":	{"NNS"},
"anti-miscarriage":	{"JJ"},
"anti-missile":	{"JJ","NN"},
"anti-monopoly":	{"JJ"},
"anti-morning-sickness":	{"JJ"},
"anti-moscow":	{"JJ"},
"anti-nato":	{"JJ"},
"anti-nausea":	{"JJ"},
"anti-nazi":	{"JJ"},
"anti-negro":	{"JJ"},
"anti-newtonian":	{"JJ"},
"anti-noriega":	{"JJ"},
"anti-nuclear":	{"JJ"},
"anti-oil":	{"JJ"},
"anti-opera":	{"NN"},
"anti-organization":	{"JJ"},
"anti-outsider":	{"NN"},
"anti-party":	{"JJ"},
"anti-personality":	{"JJ"},
"anti-pesticide":	{"JJ"},
"anti-plaque":	{"JJ"},
"anti-pocketbook":	{"JJ"},
"anti-polio":	{"JJ"},
"anti-pollution":	{"JJ"},
"anti-price-fixing":	{"JJ"},
"anti-productive":	{"JJ"},
"anti-profiteering":	{"JJ"},
"anti-program":	{"JJ"},
"anti-program-trading":	{"JJ"},
"anti-programmers":	{"NNS"},
"anti-prostitution":	{"JJ"},
"anti-psychotic":	{"JJ"},
"anti-racism":	{"NN"},
"anti-racist":	{"NN","JJ"},
"anti-racketeering":	{"JJ"},
"anti-recession":	{"JJ"},
"anti-reformers":	{"NNS"},
"anti-rejection":	{"JJ"},
"anti-rightist":	{"JJ"},
"anti-sandinista":	{"JJ"},
"anti-science":	{"JJ"},
"anti-scientific":	{"JJ"},
"anti-secrecy":	{"JJ"},
"anti-seizure":	{"JJ"},
"anti-semite":	{"JJ","NN"},
"anti-semitic":	{"JJ"},
"anti-semitism":	{"NN"},
"anti-shock":	{"JJ"},
"anti-shoplifting":	{"JJ"},
"anti-slavery":	{"JJ"},
"anti-smokers":	{"NNS"},
"anti-smoking":	{"JJ","NN"},
"anti-social":	{"JJ"},
"anti-socialist":	{"JJ"},
"anti-somoza":	{"JJ"},
"anti-sony":	{"JJ"},
"anti-south":	{"JJ"},
"anti-soviet":	{"JJ"},
"anti-stalinist":	{"JJ"},
"anti-state":	{"JJ"},
"anti-statist":	{"NN"},
"anti-submarine":	{"JJ"},
"anti-swapo":	{"JJ"},
"anti-switching":	{"JJ"},
"anti-takeover":	{"JJ","NN"},
"anti-taliban":	{"JJ"},
"anti-tax":	{"JJ"},
"anti-tax-shelter":	{"JJ"},
"anti-terrorism":	{"JJ"},
"anti-tobacco":	{"JJ","NN","FW"},
"anti-toxic":	{"JJ"},
"anti-trust":	{"JJ"},
"anti-turkish":	{"JJ"},
"anti-ulcer":	{"JJ"},
"anti-union":	{"JJ"},
"anti-vaxxer":	{"NN"},
"anti-vaxxers":	{"NNS"},
"anti-viral":	{"JJ"},
"anti-virus":	{"JJ","NN"},
"anti-vivisectionists":	{"NNS"},
"anti-war":	{"JJ"},
"anti-war-related":	{"JJ"},
"anti-western":	{"JJ"},
"anti-white":	{"JJ"},
"anti-wrinkling":	{"JJ"},
"anti-yankee":	{"JJ"},
"antiCommunist":	{"JJ"},
"antiSony":	{"JJ"},
"antiacid":	{"NN"},
"antiadrenergic":	{"JJ"},
"antiaircraft":	{"JJ","NN"},
"antialiasing":	{"NN"},
"antianemia":	{"JJ"},
"antiapartheid":	{"JJ"},
"antiarrhythmic":	{"JJ","NN"},
"antiauthoritarian":	{"JJ"},
"antibacterial":	{"JJ","NN"},
"antibaryon":	{"NN"},
"antibiosis":	{"NN"},
"antibiotic":	{"NN","JJ"},
"antibiotics":	{"NNS"},
"antiblack":	{"JJ"},
"antibodies":	{"NNS"},
"antibody":	{"NN"},
"antibody-based":	{"JJ"},
"antibody-making":	{"JJ"},
"antibody-producing":	{"JJ"},
"antic":	{"NN","JJ"},
"anticancer":	{"JJ"},
"anticatalyst":	{"NN"},
"anticholinergic":	{"JJ","NN"},
"anticholinesterase":	{"NN"},
"antichrist":	{"NN"},
"anticipant":	{"JJ","NN"},
"anticipate":	{"VB","NN","VBP"},
"anticipated":	{"VBN","JJ","VBD"},
"anticipates":	{"VBZ"},
"anticipating":	{"VBG"},
"anticipation":	{"NN"},
"anticipations":	{"NNS"},
"anticipative":	{"JJ"},
"anticipator":	{"NN"},
"anticipatory":	{"JJ"},
"anticlimactic":	{"JJ"},
"anticlimactical":	{"JJ"},
"anticlimax":	{"NN"},
"anticlinal":	{"JJ"},
"anticlockwise":	{"JJ","RB"},
"anticoagulant":	{"JJ","NN"},
"anticoagulants":	{"NNS"},
"anticoagulation":	{"NN"},
"anticoagulative":	{"JJ"},
"anticolonialist":	{"NN","JJ"},
"anticolonialists":	{"NNS"},
"anticommunist":	{"JJ"},
"anticompetitive":	{"JJ"},
"anticonvulsant":	{"NN","JJ"},
"anticonvulsants":	{"NNS"},
"anticorporate":	{"JJ"},
"anticorruption":	{"JJ"},
"antics":	{"NNS"},
"anticult":	{"NN"},
"anticus":	{"NN"},
"anticyclone":	{"NN"},
"anticyclonic":	{"JJ"},
"antidepressant":	{"NN"},
"antidepressants":	{"NNS"},
"antidepressive":	{"JJ","NN"},
"antidepressives":	{"NNS"},
"antidiabetic":	{"NN","JJ"},
"antidiarrheal":	{"NN"},
"antidiuretic":	{"JJ","NN"},
"antido":	{"NN"},
"antidorcas":	{"NNS"},
"antidotal":	{"JJ"},
"antidote":	{"NN"},
"antidromic":	{"JJ"},
"antielectron":	{"NN"},
"antielitist":	{"JJ","NN"},
"antielitists":	{"NNS"},
"antiemetic":	{"JJ","NN"},
"antiepileptic":	{"NN"},
"antiestablishment":	{"JJ"},
"antiestablishmentarian":	{"NN"},
"antiestablishmentarianism":	{"NN"},
"antiestablishmentarianisms":	{"NNS"},
"antiestablishmentarians":	{"NNS"},
"antifeminism":	{"NN"},
"antifeminist":	{"NN","JJ"},
"antiferromagnetic":	{"JJ"},
"antiferromagnetism":	{"NN"},
"antifertility":	{"JJ"},
"antiflatulent":	{"NN"},
"antifraud":	{"JJ"},
"antifreeze":	{"NN"},
"antifundamentalist":	{"JJ"},
"antifungal":	{"JJ","NN"},
"antigen":	{"NN"},
"antigenic":	{"JJ"},
"antigone":	{"NN"},
"antigonia":	{"NN"},
"antigonus":	{"NN"},
"antigram":	{"NN"},
"antiguan":	{"JJ","NN"},
"antiheretical":	{"JJ"},
"antihero":	{"NN"},
"antihistamine":	{"NN"},
"antihistorical":	{"JJ"},
"antihypertensive":	{"JJ","NN"},
"antiknock":	{"NN"},
"antiknocking":	{"JJ"},
"antilepton":	{"NN"},
"antilles":	{"NNS"},
"antilocapra":	{"NN"},
"antilocapridae":	{"NN"},
"antilock":	{"NN","JJ"},
"antilog":	{"NN"},
"antilogarithm":	{"NN"},
"antilope":	{"NN"},
"antimacassar":	{"NN"},
"antimagnetic":	{"JJ"},
"antimalarial":	{"JJ","NN"},
"antimaterialism":	{"NN"},
"antimatter":	{"NN"},
"antimeson":	{"NN"},
"antimetabolite":	{"NN"},
"antimicrobial":	{"JJ","NN"},
"antimicrobic":	{"JJ","NN"},
"antimissile":	{"JJ","NN"},
"antimonial":	{"JJ","NN"},
"antimonic":	{"JJ"},
"antimonide":	{"NN"},
"antimonious":	{"JJ"},
"antimonopoly":	{"JJ"},
"antimony":	{"NN"},
"antimuon":	{"NN"},
"antimycin":	{"NN"},
"antimycotic":	{"NN"},
"antineoplastic":	{"JJ","NN"},
"antineutrino":	{"NN"},
"antineutron":	{"NN"},
"antinode":	{"NN"},
"antinomasia":	{"NN"},
"antinomian":	{"JJ","NN"},
"antinomianism":	{"NN"},
"antinomians":	{"NNS"},
"antinomy":	{"NN"},
"antioch":	{"NN"},
"antioxidant":	{"NN"},
"antiparallel":	{"JJ"},
"antiparticle":	{"NN"},
"antipasto":	{"NN"},
"antipathetic":	{"JJ"},
"antipathetical":	{"JJ"},
"antipathies":	{"NNS"},
"antipathy":	{"NN"},
"antipersonnel":	{"JJ"},
"antiperspirant":	{"NN"},
"antiperspirants":	{"NNS"},
"antiphlogistic":	{"JJ"},
"antiphon":	{"NN"},
"antiphonal":	{"JJ","NN"},
"antiphonary":	{"JJ","NN"},
"antiphony":	{"NN"},
"antiphrasis":	{"NN"},
"antipodal":	{"JJ","NN"},
"antipode":	{"NN"},
"antipodean":	{"JJ"},
"antipodes":	{"NNS"},
"antipollution":	{"JJ","NN"},
"antipope":	{"NN"},
"antipress":	{"JJ"},
"antiproton":	{"NN"},
"antiprotozoal":	{"NN"},
"antipruritic":	{"JJ"},
"antipsychotic":	{"JJ","NN"},
"antipyresis":	{"NN"},
"antipyretic":	{"JJ","NN"},
"antiquarian":	{"NN","JJ"},
"antiquarians":	{"NNS"},
"antiquark":	{"NN"},
"antiquary":	{"NN"},
"antiquate":	{"VB"},
"antiquated":	{"JJ"},
"antique":	{"JJ","NN"},
"antique-car":	{"NN"},
"antiqued":	{"JJ"},
"antiques":	{"NNS"},
"antiquities":	{"NNS"},
"antiquity":	{"NN"},
"antirealistic":	{"JJ"},
"antiredeposition":	{"NN"},
"antirevolutionaries":	{"NNS"},
"antirevolutionary":	{"NN"},
"antirrhinum":	{"NN"},
"antisatellite":	{"JJ"},
"antisemitic":	{"JJ"},
"antisemitism":	{"NN"},
"antisepsis":	{"NN"},
"antiseptic":	{"JJ","NN"},
"antisepticize":	{"VB"},
"antisera":	{"NNS"},
"antiserum":	{"NN"},
"antiserums":	{"NNS"},
"antislavery":	{"JJ","NN"},
"antismoking":	{"JJ"},
"antisocial":	{"JJ","NN"},
"antisony":	{"JJ"},
"antispasmodic":	{"JJ","NN"},
"antistrophe":	{"NN"},
"antistrophic":	{"JJ"},
"antisubmarine":	{"JJ"},
"antisyphilitic":	{"NN"},
"antitakeover":	{"JJ"},
"antitank":	{"JJ","NN"},
"antitauon":	{"NN"},
"antithesis":	{"NN"},
"antithetic":	{"JJ"},
"antithetical":	{"JJ"},
"antithetically":	{"RB"},
"antithyroid":	{"JJ"},
"antitoxic":	{"JJ"},
"antitoxin":	{"NN"},
"antitrade":	{"JJ","NN"},
"antitrades":	{"NNS"},
"antitrust":	{"JJ"},
"antitrust-law":	{"JJ","NN"},
"antitumor":	{"NN"},
"antitumour":	{"JJ"},
"antitussive":	{"JJ"},
"antitype":	{"NN"},
"antitypic":	{"JJ"},
"antitypical":	{"JJ"},
"antivenene":	{"NN"},
"antivenin":	{"NN"},
"antivert":	{"NN"},
"antiviral":	{"JJ","NN"},
"antiwar":	{"JJ","NN"},
"antler":	{"NN"},
"antler-like":	{"JJ"},
"antlered":	{"JJ"},
"antlers":	{"NNS"},
"antlia":	{"NN"},
"antlike":	{"JJ"},
"antlion":	{"NN"},
"antofagasta":	{"NN"},
"antoine":	{"NN"},
"antoinette":	{"NN"},
"antoninus":	{"NN"},
"antonio-based":	{"JJ"},
"antonius":	{"NN"},
"antony":	{"NN"},
"antonym":	{"NN"},
"antonymous":	{"JJ"},
"antonymy":	{"NN"},
"antrorse":	{"JJ"},
"antrozous":	{"NN"},
"antrum":	{"NN"},
"ants":	{"NNS"},
"antsy":	{"JJ"},
"antum":	{"NN"},
"antwerp":	{"NN"},
"antwerp-based":	{"JJ"},
"antwerpen":	{"NN"},
"anu":	{"NN"},
"anubis":	{"NN"},
"anunnaki":	{"NN"},
"anura":	{"NN"},
"anuran":	{"JJ","NN"},
"anuresis":	{"NN"},
"anuretic":	{"JJ"},
"anuria":	{"NN"},
"anuric":	{"JJ"},
"anurous":	{"JJ"},
"anus":	{"NN"},
"anvers":	{"NN"},
"anvil":	{"NN"},
"anwar":	{"NN"},
"anxieties":	{"NNS"},
"anxiety":	{"NN"},
"anxiety-free":	{"JJ"},
"anxiety-released":	{"NN"},
"anxiolytic":	{"JJ","NN"},
"anxious":	{"JJ"},
"anxiously":	{"RB"},
"anxiousness":	{"NN"},
"any":	{"DT","PRP","RB"},
"anybody":	{"PRP","NN"},
"anye":	{"JJ"},
"anyhow":	{"RB"},
"anylabel":	{"NN"},
"anymore":	{"RB"},
"anyone":	{"PRP"},
"anyplace":	{"RB"},
"anythin":	{"NN"},
"anything":	{"NN"},
"anytime":	{"RB"},
"anyway":	{"RB"},
"anyways":	{"RB"},
"anywhere":	{"RB"},
"anzac":	{"NN"},
"anzio":	{"NN"},
"aorist":	{"NN"},
"aoristic":	{"JJ"},
"aorta":	{"NN"},
"aortal":	{"JJ"},
"aortic":	{"JJ"},
"aortitis":	{"NN"},
"aotus":	{"NN"},
"aoudad":	{"NN"},
"apace":	{"RB"},
"apache":	{"NN"},
"apadana":	{"NN"},
"apalachicola":	{"NN"},
"apanage":	{"NN"},
"apar":	{"NN"},
"aparently":	{"RB"},
"apart":	{"RB","JJ","RP"},
"apartheid":	{"NN"},
"apartment":	{"NN"},
"apartment-building":	{"NN"},
"apartments":	{"NNS"},
"apathetic":	{"JJ"},
"apathetically":	{"RB"},
"apathy":	{"NN"},
"apatite":	{"NN"},
"apatosaur":	{"NN"},
"apatosaurus":	{"NN"},
"apatura":	{"NN"},
"apc":	{"NN"},
"ape":	{"NN","VB","VBP"},
"ape-man":	{"NN"},
"aped":	{"VBD","VBN"},
"apeldoorn":	{"NN"},
"apelike":	{"JJ","NN"},
"apennines":	{"NNS"},
"aper":	{"NN"},
"apercu":	{"NN"},
"aperea":	{"NN"},
"apergillus":	{"NN"},
"aperient":	{"JJ","NN"},
"aperiodic":	{"JJ"},
"aperitif":	{"NN"},
"aperture":	{"NN"},
"apery":	{"NN"},
"apes":	{"NNS","VBZ"},
"apetalous":	{"JJ"},
"apex":	{"NN"},
"aphaeresis":	{"NN"},
"aphaeretic":	{"JJ"},
"aphagia":	{"NN"},
"aphakia":	{"NN"},
"aphakic":	{"JJ","NN"},
"aphanite":	{"NN"},
"aphanitic":	{"JJ"},
"aphantasia":	{"NN"},
"aphasia":	{"NN"},
"aphasic":	{"JJ","NN"},
"aphasmidia":	{"NN"},
"aphelion":	{"NN"},
"apheresis":	{"NN"},
"apheretic":	{"JJ"},
"aphesis":	{"NN"},
"aphetic":	{"JJ"},
"aphid":	{"NN"},
"aphididae":	{"NN"},
"aphidoidea":	{"NN"},
"aphis":	{"NN"},
"aphonia":	{"NN"},
"aphonic":	{"JJ"},
"aphorise":	{"VB"},
"aphorism":	{"NN"},
"aphorisms":	{"NNS"},
"aphorist":	{"NN"},
"aphoristic":	{"JJ"},
"aphorize":	{"VB"},
"aphotic":	{"JJ"},
"aphriza":	{"NN"},
"aphrodisia":	{"NN"},
"aphrodisiac":	{"NN","JJ"},
"aphrodisiacal":	{"JJ"},
"aphrodite":	{"NN"},
"aphrophora":	{"NN"},
"aphyllanthaceae":	{"NN"},
"aphyllanthes":	{"NNS"},
"aphyllophorales":	{"NNS"},
"aphyllous":	{"JJ"},
"apia":	{"NN"},
"apiaceae":	{"NN"},
"apian":	{"JJ"},
"apiarian":	{"JJ"},
"apiarist":	{"NN"},
"apiary":	{"NN"},
"apical":	{"JJ"},
"apiculate":	{"JJ"},
"apicultural":	{"JJ"},
"apiculture":	{"NN"},
"apiculturist":	{"NN"},
"apidae":	{"NN"},
"apiece":	{"RB","JJ"},
"aping":	{"NN","VBG","JJ"},
"apios":	{"NN"},
"apis":	{"NN"},
"apish":	{"JJ"},
"apishamore":	{"NN"},
"apium":	{"NN"},
"apivorous":	{"JJ"},
"aplacental":	{"JJ"},
"aplacophora":	{"NN"},
"aplacophoran":	{"NN"},
"aplanatic":	{"JJ"},
"aplasia":	{"NN"},
"aplectrum":	{"NN"},
"aplenty":	{"JJ","RB"},
"aplite":	{"NN"},
"aplitic":	{"JJ"},
"aplodontia":	{"NN"},
"aplodontiidae":	{"NN"},
"aplomb":	{"NN"},
"aplysia":	{"NN"},
"aplysiidae":	{"NN"},
"apnea":	{"NN"},
"apneic":	{"JJ"},
"apnoeic":	{"JJ"},
"apoapsis":	{"NN"},
"apocalypse":	{"NN"},
"apocalyptic":	{"JJ","NN"},
"apocalyptical":	{"JJ"},
"apocalyptics":	{"NNS"},
"apocarpous":	{"JJ"},
"apochromatic":	{"JJ"},
"apocope":	{"NN"},
"apocrine":	{"JJ","NN"},
"apocrypha":	{"NN"},
"apocryphal":	{"JJ","NN"},
"apocynaceae":	{"NN"},
"apocynaceous":	{"JJ"},
"apocynum":	{"NN"},
"apodal":	{"JJ"},
"apodeictic":	{"JJ"},
"apodeme":	{"NN"},
"apodemus":	{"NN"},
"apodictic":	{"JJ"},
"apodidae":	{"NN"},
"apodiformes":	{"NNS"},
"apodous":	{"JJ"},
"apoenzyme":	{"NN"},
"apogametic":	{"JJ"},
"apogamic":	{"JJ"},
"apogamous":	{"JJ"},
"apogamy":	{"NN"},
"apogean":	{"JJ"},
"apogee":	{"NN"},
"apogon":	{"NN"},
"apogonidae":	{"NN"},
"apoidea":	{"NN"},
"apojove":	{"NN"},
"apolemia":	{"NN"},
"apolitical":	{"JJ"},
"apollinaire":	{"NN"},
"apollo":	{"NN"},
"apollonian":	{"JJ"},
"apologetic":	{"JJ","NN"},
"apologetically":	{"RB"},
"apologetics":	{"NN"},
"apologia":	{"NN"},
"apologies":	{"NNS"},
"apologise":	{"VB","VBP"},
"apologised":	{"VBD","VBN"},
"apologises":	{"VBZ"},
"apologising":	{"VBG"},
"apologist":	{"NN"},
"apologists":	{"NNS"},
"apologize":	{"VB","VBP"},
"apologized":	{"VBD","VBN"},
"apologizes":	{"VBZ"},
"apologizing":	{"VBG"},
"apologue":	{"NN"},
"apology":	{"NN"},
"apolune":	{"NN"},
"apomict":	{"NN"},
"apomictic":	{"JJ"},
"apomictical":	{"JJ"},
"apomixis":	{"NNS"},
"apomorphine":	{"NN"},
"aponeurosis":	{"NN"},
"aponeurotic":	{"JJ"},
"apopemptic":	{"JJ"},
"apophasis":	{"NN"},
"apophatic":	{"JJ"},
"apophatism":	{"NN"},
"apophthegm":	{"NN"},
"apophyseal":	{"JJ"},
"apophysis":	{"NN"},
"apoplectic":	{"JJ"},
"apoplectiform":	{"JJ"},
"apoplectoid":	{"JJ"},
"apoplexy":	{"NN"},
"apoptosis":	{"NN"},
"aporocactus":	{"NN"},
"aposelene":	{"NN"},
"aposiopesis":	{"NN"},
"aposiopetic":	{"JJ"},
"apostasy":	{"NN"},
"apostate":	{"NN"},
"apostates":	{"NNS"},
"apostatise":	{"VB"},
"apostatize":	{"VB"},
"apostatized":	{"VBD","VBN"},
"apostatizes":	{"VBZ"},
"apostatizing":	{"VBG"},
"apostle":	{"NN"},
"apostles":	{"NNS"},
"apostleship":	{"NN"},
"apostolic":	{"JJ"},
"apostolical":	{"JJ"},
"apostrophe":	{"NN"},
"apostrophic":	{"JJ"},
"apostrophise":	{"VB"},
"apostrophize":	{"VB"},
"apothecary":	{"NN","JJ"},
"apothecial":	{"JJ"},
"apothecium":	{"NN"},
"apothegm":	{"NN"},
"apothegmatic":	{"JJ"},
"apothegmatical":	{"JJ"},
"apotheose":	{"VB"},
"apotheosis":	{"NN"},
"apotheosise":	{"VB"},
"apotheosize":	{"VB"},
"apotropaic":	{"JJ"},
"appal":	{"VB","VBP"},
"appalachian":	{"JJ","NN"},
"appall":	{"VB","VBP"},
"appalled":	{"JJ","VBD","VBN"},
"appalling":	{"VBG","JJ"},
"appallingly":	{"RB"},
"appalls":	{"VBZ"},
"appaloosa":	{"NN"},
"appals":	{"VBZ"},
"appanage":	{"NN"},
"apparat":	{"NN"},
"apparatchik":	{"NN"},
"apparatchiks":	{"NNS"},
"apparate":	{"VB","VBP"},
"apparated":	{"VBD","VBN"},
"apparates":	{"VBZ"},
"apparating":	{"VBG"},
"apparats":	{"NNS"},
"apparatus":	{"NN","NNS"},
"apparatuses":	{"NNS"},
"apparel":	{"NN","VBP","VB"},
"apparel-maker":	{"NN"},
"appareled":	{"VBD","VBN"},
"appareling":	{"VBG"},
"apparelled":	{"VBD","VBN"},
"apparelling":	{"VBG"},
"apparels":	{"VBZ","VBZ"},
"apparency":	{"NN"},
"apparent":	{"JJ"},
"apparently":	{"RB"},
"apparentness":	{"NN"},
"apparition":	{"NN"},
"apparitional":	{"JJ"},
"apparitions":	{"NNS"},
"appartus":	{"NN"},
"appeal":	{"NN","VBP","VB"},
"appealable":	{"JJ"},
"appealed":	{"VBD","VBN"},
"appealing":	{"VBG","JJ"},
"appealingly":	{"RB"},
"appealingness":	{"NN"},
"appeals":	{"NNS","VBZ"},
"appeals-court":	{"NN","JJ"},
"appear":	{"VB","VBP"},
"appearance":	{"NN"},
"appearances":	{"NNS"},
"appeared":	{"VBD","VBN"},
"appearing":	{"VBG"},
"appears":	{"VBZ"},
"appeasable":	{"JJ"},
"appease":	{"VB","VBP"},
"appeased":	{"VBD","VBN"},
"appeasement":	{"NN"},
"appeaser":	{"NN"},
"appeases":	{"VBZ"},
"appeasing":	{"VBG"},
"appellant":	{"NN","JJ"},
"appellate":	{"JJ","NN"},
"appellate-court":	{"NN"},
"appellate-litigation":	{"NN","JJ"},
"appellation":	{"NN"},
"appellative":	{"JJ","NN"},
"append":	{"VB","VBP"},
"appendage":	{"NN"},
"appendaged":	{"JJ"},
"appendages":	{"NNS"},
"appendant":	{"JJ"},
"appendectomy":	{"NN"},
"appended":	{"VBD","VBN"},
"appendicectomy":	{"NN"},
"appendicitis":	{"NN"},
"appendicle":	{"NN"},
"appendicular":	{"JJ"},
"appendicularia":	{"NN"},
"appending":	{"VBG"},
"appendix":	{"NN"},
"appendixes":	{"NNS"},
"appends":	{"VBZ"},
"appenzeller":	{"NN"},
"apperceive":	{"VB"},
"apperception":	{"NN"},
"apperceptive":	{"JJ"},
"appertain":	{"VB","VBP"},
"appertained":	{"VBD","VBN"},
"appertaining":	{"VBG"},
"appertains":	{"VBZ"},
"appestat":	{"NN"},
"appetence":	{"NN"},
"appetency":	{"NN"},
"appetent":	{"JJ"},
"appetiser":	{"NN"},
"appetising":	{"JJ"},
"appetisingness":	{"NN"},
"appetite":	{"NN"},
"appetites":	{"NNS"},
"appetitive":	{"JJ"},
"appetizer":	{"NN"},
"appetizers":	{"NNS","VBZ"},
"appetizing":	{"JJ"},
"appetizingness":	{"NN"},
"applaud":	{"VB","VBP"},
"applaudable":	{"JJ"},
"applauded":	{"VBD","VBN"},
"applauder":	{"NN"},
"applauding":	{"VBG"},
"applauds":	{"VBZ"},
"applause":	{"NN"},
"applause-happy":	{"JJ"},
"apple":	{"NN"},
"apple-flavored":	{"JJ"},
"apple-industry":	{"NN"},
"apple-pie":	{"NN"},
"apple-scented":	{"JJ"},
"apple-shaped":	{"JJ"},
"apple-sized":	{"JJ"},
"apple-tree":	{"NN"},
"applecart":	{"NN"},
"applejack":	{"NN"},
"applelike":	{"JJ"},
"applemint":	{"NN"},
"apples":	{"NNS"},
"applesauce":	{"NN"},
"applet":	{"NN"},
"appleton":	{"NN"},
"applewood":	{"NN"},
"appliance":	{"NN"},
"appliance-controls":	{"NNS"},
"appliances":	{"NNS"},
"applicability":	{"NN"},
"applicable":	{"JJ"},
"applicant":	{"NN"},
"applicants":	{"NNS"},
"application":	{"NN"},
"applications":	{"NNS"},
"applicative":	{"JJ"},
"applicator":	{"NN"},
"applicators":	{"NNS"},
"applicatory":	{"JJ"},
"applied":	{"VBN","VBD","JJ"},
"applier":	{"NN"},
"applies":	{"VBZ"},
"applique":	{"NN","VB","VBP"},
"appliqued":	{"VBD","VBN"},
"appliques":	{"NNS","VBZ"},
"appliquing":	{"VBG"},
"apply":	{"VB","VBP"},
"applying":	{"VBG"},
"appoggiatura":	{"NN"},
"appoint":	{"VB","VBP"},
"appointed":	{"VBN","VBD","JJ"},
"appointee":	{"NN"},
"appointees":	{"NNS"},
"appointing":	{"VBG","NN"},
"appointive":	{"JJ"},
"appointment":	{"NN"},
"appointments":	{"NNS"},
"appoints":	{"VBZ"},
"apportion":	{"VB","VBP"},
"apportionable":	{"JJ"},
"apportioned":	{"VBD","VBN"},
"apportioning":	{"VBG"},
"apportionment":	{"NN"},
"apportionments":	{"NNS"},
"apportions":	{"VBZ"},
"apposable":	{"JJ"},
"appose":	{"VB"},
"apposite":	{"JJ","NN"},
"appositeness":	{"NN"},
"apposition":	{"NN"},
"appositional":	{"JJ"},
"appositive":	{"JJ","NN"},
"appositively":	{"RB"},
"appraisal":	{"NN"},
"appraisals":	{"NNS"},
"appraise":	{"VB","VBP"},
"appraised":	{"VBD","VBN"},
"appraiser":	{"NN"},
"appraisers":	{"NNS"},
"appraises":	{"VBZ"},
"appraising":	{"VBG"},
"appraisingly":	{"RB"},
"appreciable":	{"JJ"},
"appreciably":	{"RB"},
"appreciate":	{"VB","VBP"},
"appreciated":	{"VBD","VBN"},
"appreciates":	{"VBZ"},
"appreciating":	{"VBG"},
"appreciation":	{"NN"},
"appreciations":	{"NNS"},
"appreciative":	{"JJ"},
"appreciatively":	{"RB"},
"appreciativeness":	{"NN"},
"appreciator":	{"NN"},
"apprehend":	{"VB","VBP"},
"apprehended":	{"VBD","VBN"},
"apprehender":	{"NN"},
"apprehending":	{"VBG"},
"apprehends":	{"VBZ"},
"apprehensible":	{"JJ"},
"apprehension":	{"NN"},
"apprehensions":	{"NNS"},
"apprehensive":	{"JJ","NN"},
"apprehensively":	{"RB"},
"apprehensiveness":	{"NN"},
"apprentice":	{"NN","VB","VBP"},
"apprenticed":	{"VBD","VBN"},
"apprentices":	{"NNS","VBZ"},
"apprenticeship":	{"NN"},
"apprenticeships":	{"NNS"},
"apprenticing":	{"VBG"},
"appressed":	{"JJ"},
"apprisal":	{"NN"},
"apprise":	{"VB","VBP"},
"apprised":	{"VBD","VBN"},
"apprises":	{"VBZ"},
"apprising":	{"VBG"},
"apprize":	{"VB","VBP"},
"apprized":	{"VBD","VBN"},
"apprizes":	{"VBZ"},
"apprizing":	{"VBG"},
"appro":	{"NN"},
"approach":	{"NN","VB","VBP"},
"approachability":	{"NN"},
"approachable":	{"JJ"},
"approached":	{"VBD","VBN"},
"approaches":	{"NNS","VBZ"},
"approaching":	{"VBG"},
"approbate":	{"VB"},
"approbation":	{"NN"},
"approbative":	{"JJ"},
"approbatory":	{"JJ"},
"appropriable":	{"JJ"},
"appropriate":	{"JJ","VB","VBP"},
"appropriated":	{"VBD","VBN"},
"appropriately":	{"RB"},
"appropriateness":	{"NN"},
"appropriates":	{"VBZ"},
"appropriating":	{"VBG"},
"appropriation":	{"NN"},
"appropriations":	{"NNS"},
"appropriative":	{"JJ"},
"appropriator":	{"NN"},
"appropriators":	{"NNS"},
"approval":	{"NN"},
"approvals":	{"NNS"},
"approve":	{"VB","VBP"},
"approved":	{"VBN","VBD","JJ"},
"approver":	{"NN"},
"approves":	{"VBZ"},
"approving":	{"JJ","VBG"},
"approvingly":	{"RB"},
"approximate":	{"JJ","VB","VBP"},
"approximated":	{"VBD","VBN"},
"approximately":	{"RB"},
"approximates":	{"VBZ"},
"approximating":	{"VBG"},
"approximation":	{"NN"},
"approximations":	{"NNS"},
"approximative":	{"JJ"},
"apps":	{"NNS"},
"appurtenance":	{"NN"},
"appurtenant":	{"JJ"},
"apr":	{"NN"},
"apractic":	{"JJ"},
"apraxia":	{"NN"},
"apraxic":	{"JJ"},
"apresoline":	{"NN"},
"apricot":	{"NN","JJ"},
"apricots":	{"NNS"},
"apron":	{"NN"},
"aproned":	{"VBD","VBN"},
"aproning":	{"VBG"},
"aprons":	{"NNS","VBZ"},
"apropos":	{"JJ","RB"},
"apse":	{"NN"},
"apses":	{"NNS"},
"apsidal":	{"JJ"},
"apsis":	{"NN"},
"apsu":	{"NN"},
"apt":	{"JJ"},
"aptenodytes":	{"NNS"},
"apteral":	{"JJ"},
"apterous":	{"JJ"},
"apterygidae":	{"NN"},
"apterygiformes":	{"NNS"},
"apteryx":	{"NN"},
"aptitude":	{"NN"},
"aptitudes":	{"NNS"},
"aptitudinal":	{"JJ"},
"aptly":	{"RB"},
"aptness":	{"NN"},
"apulia":	{"NN"},
"apus":	{"NN"},
"aqaba":	{"NN"},
"aqua":	{"NN","JJ"},
"aqua-lung":	{"NN"},
"aquacultural":	{"JJ"},
"aquaculture":	{"NN"},
"aqualung":	{"NN"},
"aquam":	{"FW"},
"aquamarine":	{"NN","JJ"},
"aquamarines":	{"NNS"},
"aquanaut":	{"NN"},
"aquaphobia":	{"NN"},
"aquaphobic":	{"JJ"},
"aquaplane":	{"NN","VB","VBP"},
"aquaplaned":	{"VBD","VBN"},
"aquaplanes":	{"NNS","VBZ"},
"aquaplaning":	{"VBG"},
"aquarium":	{"NN"},
"aquarius":	{"NN"},
"aquatic":	{"JJ","NN"},
"aquatics":	{"NN"},
"aquatint":	{"NN"},
"aquavit":	{"NN"},
"aqueduct":	{"NN"},
"aqueducts":	{"NNS"},
"aqueous":	{"JJ"},
"aquicultural":	{"JJ"},
"aquiculture":	{"NN"},
"aquifer":	{"NN"},
"aquiferous":	{"JJ"},
"aquifers":	{"NNS"},
"aquifoliaceae":	{"NN"},
"aquila":	{"NN"},
"aquilege":	{"NN"},
"aquilegia":	{"NN"},
"aquiline":	{"JJ"},
"aquinas":	{"NNS"},
"aquisition":	{"NN"},
"aquisitions":	{"NNS"},
"aquitaine":	{"NN"},
"aquitania":	{"NN"},
"ar":	{"NN"},
"arab-berbers":	{"NNS"},
"arab-israeli":	{"JJ"},
"arab-sponsored":	{"JJ"},
"arabesque":	{"NN"},
"arabia":	{"NN"},
"arabidopsis":	{"NN"},
"arability":	{"NN"},
"arabis":	{"NN"},
"arabist":	{"NN"},
"arable":	{"JJ"},
"araceae":	{"NN"},
"araceous":	{"JJ"},
"arachis":	{"NN"},
"arachnid":	{"NN"},
"arachnida":	{"NN"},
"arachnidian":	{"JJ"},
"arachnoid":	{"JJ","NN"},
"arachnophobia":	{"NN"},
"arafat":	{"NN"},
"aragon":	{"NN"},
"aragonite":	{"NN"},
"araguaia":	{"NN"},
"araguaya":	{"NN"},
"arak":	{"NN"},
"aral":	{"NN"},
"arales":	{"NNS"},
"aralia":	{"NN"},
"araliaceae":	{"NN"},
"aram":	{"NN"},
"aramaean":	{"JJ","NN"},
"aramaic":	{"JJ","NN"},
"arame":	{"NN"},
"aramean":	{"JJ","NN"},
"aramid":	{"NN"},
"aramus":	{"NN"},
"aranea":	{"NN"},
"araneae":	{"NN"},
"araneida":	{"NN"},
"araneidal":	{"JJ"},
"araneidan":	{"JJ"},
"araneus":	{"NN"},
"aranyaka":	{"NN"},
"arapaho":	{"NN"},
"arapahoe":	{"NN"},
"ararat":	{"NN"},
"arariba":	{"NN"},
"araroba":	{"NN"},
"aras":	{"NNS"},
"arauca":	{"NN"},
"araucaria":	{"NN"},
"araucariaceae":	{"NN"},
"araujia":	{"NN"},
"arava":	{"NN"},
"arawak":	{"NN"},
"arawakan":	{"JJ","NN"},
"arawn":	{"NN"},
"araxes":	{"NNS"},
"arb":	{"NN"},
"arbalest":	{"NN"},
"arbalist":	{"NN"},
"arbiter":	{"NN"},
"arbitrable":	{"JJ"},
"arbitrage":	{"NN"},
"arbitrage-related":	{"JJ"},
"arbitraged":	{"VBD","VBN"},
"arbitrager":	{"NN"},
"arbitragers":	{"NNS"},
"arbitrages":	{"VBZ"},
"arbitrageur":	{"NN"},
"arbitrageurs":	{"NNS"},
"arbitraging":	{"NN","VBG"},
"arbitral":	{"JJ"},
"arbitrament":	{"NN"},
"arbitrarily":	{"RB"},
"arbitrariness":	{"NN"},
"arbitrary":	{"JJ"},
"arbitrate":	{"VB","VBP"},
"arbitrated":	{"VBD","VBN"},
"arbitrates":	{"VBZ"},
"arbitrating":	{"VBG"},
"arbitration":	{"NN"},
"arbitration-eligibility":	{"NN"},
"arbitrational":	{"JJ"},
"arbitrative":	{"JJ"},
"arbitrator":	{"NN"},
"arbitrators":	{"NNS"},
"arbitrement":	{"NN"},
"arbor":	{"NN"},
"arboraceous":	{"JJ"},
"arborary":	{"JJ"},
"arboreal":	{"JJ","NN"},
"arboreous":	{"JJ"},
"arborescent":	{"JJ"},
"arboresque":	{"JJ"},
"arboretum":	{"NN"},
"arborical":	{"JJ"},
"arboriculture":	{"NN"},
"arboriculturist":	{"NN"},
"arboriform":	{"JJ"},
"arborise":	{"VB"},
"arborist":	{"NN"},
"arborists":	{"NNS"},
"arborize":	{"VB"},
"arborolatry":	{"NN"},
"arborous":	{"JJ"},
"arborvirus":	{"NN"},
"arborvitae":	{"NN"},
"arbour":	{"NN"},
"arbovirus":	{"NN"},
"arbs":	{"NNS"},
"arbutus":	{"NN"},
"arc":	{"VB","VBP","NN"},
"arc-boutant":	{"NN"},
"arca":	{"NN"},
"arcade":	{"NN"},
"arcaded":	{"JJ","VBD","VBN"},
"arcades":	{"NNS","VBZ"},
"arcadia":	{"NN"},
"arcadic":	{"NN"},
"arcading":	{"VBG"},
"arcado-cyprians":	{"NNS"},
"arcane":	{"JJ"},
"arcanum":	{"NN"},
"arccos":	{"NN"},
"arccosecant":	{"NN"},
"arccosine":	{"NN"},
"arccotangent":	{"NN"},
"arcdegree":	{"NN"},
"arced":	{"VBD","VBN"},
"arcella":	{"NN"},
"arcellidae":	{"NN"},
"arceuthobium":	{"NN"},
"arch":	{"NN","VB","VBP","JJ"},
"arch-enemy":	{"NN"},
"arch-heretic":	{"NN"},
"arch-opponent":	{"NN"},
"arch-rival":	{"JJ","NN"},
"archaean":	{"NN","JJ"},
"archaebacteria":	{"NN"},
"archaebacterium":	{"NN"},
"archaeobacteria":	{"NN"},
"archaeologic":	{"JJ"},
"archaeological":	{"JJ","NN"},
"archaeologist":	{"NN"},
"archaeologists":	{"NNS"},
"archaeology":	{"NN"},
"archaeopteryx":	{"NN"},
"archaeornis":	{"NN"},
"archaeornithes":	{"NNS"},
"archaeozoic":	{"JJ","NN"},
"archaic":	{"JJ","NN"},
"archaicism":	{"NN"},
"archaise":	{"VB","VBP"},
"archaised":	{"VBD","VBN"},
"archaiser":	{"NN"},
"archaisers":	{"NNS"},
"archaises":	{"VBZ"},
"archaising":	{"VBG"},
"archaism":	{"NN"},
"archaist":	{"NN"},
"archaistic":	{"JJ"},
"archaists":	{"NNS"},
"archaize":	{"VB","VBP"},
"archaized":	{"VBD","VBN"},
"archaizer":	{"NN"},
"archaizers":	{"NNS"},
"archaizes":	{"VBZ"},
"archaizing":	{"VBG"},
"archangel":	{"NN"},
"archangelic":	{"JJ"},
"archangelical":	{"JJ"},
"archangels":	{"NNS"},
"archbishop":	{"NN"},
"archbishopric":	{"NN"},
"archbishops":	{"NNS"},
"archdeacon":	{"NN"},
"archdeaconry":	{"NN"},
"archdiocesan":	{"JJ"},
"archdiocese":	{"NN"},
"archducal":	{"JJ"},
"archduchess":	{"NN"},
"archduchy":	{"NN"},
"archduke":	{"NN"},
"archean":	{"JJ","NN"},
"arched":	{"JJ","VBD","VBN"},
"archegonial":	{"JJ"},
"archegoniate":	{"JJ"},
"archegonium":	{"NN"},
"archenemy":	{"NN"},
"archenteron":	{"NN"},
"archeobacteria":	{"NN"},
"archeologic":	{"JJ"},
"archeological":	{"JJ"},
"archeologist":	{"NN"},
"archeologists":	{"NNS"},
"archeology":	{"NN"},
"archeopteryx":	{"NN"},
"archeozoic":	{"JJ","NN"},
"archepiscopal":	{"JJ"},
"archer":	{"NN"},
"archerfish":	{"NN"},
"archery":	{"NN"},
"arches":	{"NNS","VBZ"},
"archespore":	{"NN"},
"archesporial":	{"JJ"},
"archesporium":	{"NN"},
"archetypal":	{"JJ","NN"},
"archetype":	{"NN"},
"archetypes":	{"NNS"},
"archetypical":	{"JJ"},
"archfool":	{"NN"},
"archiannelid":	{"NN"},
"archiannelida":	{"NN"},
"archidiaconal":	{"JJ"},
"archidiaconate":	{"NN"},
"archidiskidon":	{"NN"},
"archiepiscopal":	{"JJ"},
"archil":	{"NN"},
"archilochus":	{"NN"},
"archimandrite":	{"NN"},
"archimedes":	{"NNS"},
"archine":	{"NN"},
"arching":	{"VBG"},
"archipallium":	{"NN"},
"archipelagic":	{"JJ"},
"archipelago":	{"NN"},
"architect":	{"NN"},
"architect-developer":	{"NN"},
"architectonic":	{"JJ"},
"architectonics":	{"NN"},
"architects":	{"NNS"},
"architectural":	{"JJ"},
"architecturally":	{"RB"},
"architecture":	{"NN"},
"architectures":	{"NNS"},
"architeuthis":	{"NN"},
"architrave":	{"NN"},
"archival":	{"JJ"},
"archive":	{"VB","VBP","NN"},
"archived":	{"VBD","VBN"},
"archives":	{"NNS","VBZ"},
"archiving":	{"VBG","NN"},
"archivist":	{"NN"},
"archivists":	{"NNS"},
"archly":	{"RB"},
"archness":	{"NN"},
"archosargus":	{"NN"},
"archosaur":	{"NN"},
"archosauria":	{"NN"},
"archosaurian":	{"JJ","NN"},
"archpriest":	{"NN"},
"archrival":	{"NN"},
"archtype":	{"NN"},
"archway":	{"NN"},
"arcidae":	{"NN"},
"arciform":	{"JJ"},
"arcing":	{"VBG"},
"arcked":	{"VBD","VBN"},
"arcking":	{"VBG"},
"arclike":	{"JJ"},
"arcminute":	{"NN"},
"arco":	{"NN"},
"arcs":	{"VBZ","NNS"},
"arcsec":	{"NN"},
"arcsecant":	{"NN"},
"arcsecond":	{"NN"},
"arcsin":	{"NN"},
"arcsine":	{"NN"},
"arctan":	{"NN"},
"arctangent":	{"NN"},
"arctic":	{"JJ","NN"},
"arctictis":	{"NN"},
"arctiid":	{"NN"},
"arctiidae":	{"NN"},
"arctium":	{"NN"},
"arctocebus":	{"NN"},
"arctocephalus":	{"NN"},
"arctonyx":	{"NN"},
"arctostaphylos":	{"NN"},
"arctotis":	{"NN"},
"arcturus":	{"NN"},
"arcuate":	{"JJ","NN"},
"arcus":	{"NN"},
"arda":	{"NN"},
"ardea":	{"NN"},
"ardeb":	{"NN"},
"ardeidae":	{"NN"},
"arden":	{"NN"},
"ardennes":	{"NNS"},
"ardent":	{"JJ"},
"ardently":	{"RB"},
"ardisia":	{"NN"},
"ardor":	{"NN"},
"ardour":	{"NN"},
"ards":	{"NNS"},
"arduous":	{"JJ"},
"arduously":	{"RB"},
"arduousness":	{"NN"},
"are":	{"VBP"},
"area":	{"NN"},
"area-code":	{"JJ"},
"area-sales":	{"JJ"},
"area-wide":	{"JJ"},
"areal":	{"JJ","NN"},
"areas":	{"NNS"},
"areaway":	{"NN"},
"areaways":	{"NNS"},
"areca":	{"NN"},
"arecaceae":	{"NN"},
"arecidae":	{"NN"},
"areflexia":	{"NN"},
"arena":	{"NN"},
"arenaceous":	{"JJ"},
"arenaria":	{"NN"},
"arenaria-melanocephala":	{"NN"},
"arenas":	{"NNS"},
"arenaviridae":	{"NN"},
"arenavirus":	{"NN"},
"arendt":	{"NN"},
"arenga":	{"NN"},
"arenicolous":	{"JJ"},
"areola":	{"NN"},
"areolar":	{"JJ"},
"areolate":	{"JJ"},
"areopagite":	{"NN"},
"areopagus":	{"NN"},
"areosol":	{"NN"},
"arequipa":	{"NN"},
"arere":	{"RB"},
"arete":	{"NN"},
"arethusa":	{"NN"},
"argal":	{"NN"},
"argali":	{"NN","NNS"},
"argasid":	{"NN"},
"argasidae":	{"NN"},
"argemone":	{"NN"},
"argent":	{"JJ","NN"},
"argentic":	{"JJ"},
"argentiferous":	{"JJ"},
"argentinidae":	{"NN"},
"argentinosaur":	{"NN"},
"argentite":	{"NN"},
"argentous":	{"JJ"},
"argil":	{"NN"},
"argillaceous":	{"JJ"},
"argillite":	{"NN"},
"arginine":	{"NN"},
"argiope":	{"NN"},
"argiopidae":	{"NN"},
"argive":	{"JJ","NN"},
"argle-bargle":	{"NN"},
"argo":	{"NN"},
"argon":	{"NN"},
"argonaut":	{"NN"},
"argonauta":	{"NN"},
"argonautidae":	{"NN"},
"argonne":	{"NN"},
"argonon":	{"NN"},
"argos":	{"NNS"},
"argosy":	{"NN"},
"argot":	{"NN"},
"argriculture":	{"NN"},
"arguable":	{"JJ"},
"arguably":	{"RB"},
"argue":	{"VB","VBP"},
"argued":	{"VBD","VBN"},
"arguer":	{"NN"},
"argues":	{"VBZ"},
"argufy":	{"VB"},
"arguing":	{"VBG"},
"argument":	{"NN"},
"argumentation":	{"NN"},
"argumentative":	{"JJ"},
"argumentatively":	{"RB"},
"argumented":	{"VBD","VBN"},
"argumenting":	{"VBG"},
"arguments":	{"NNS","VBZ"},
"argun":	{"NN"},
"argus":	{"NN"},
"argus-eyed":	{"JJ"},
"argusianus":	{"NN"},
"argy-bargy":	{"NN"},
"argyle":	{"NN"},
"argyll":	{"NN"},
"argynnis":	{"NN"},
"argyranthemum":	{"NN"},
"argyreia":	{"NN"},
"argyrodite":	{"NN"},
"argyrol":	{"NN"},
"argyrotaenia":	{"NN"},
"argyroxiphium":	{"NN"},
"arhant":	{"NN"},
"arhat":	{"NN"},
"arhus":	{"NN"},
"aria":	{"NN"},
"ariadne":	{"NN"},
"ariana":	{"NN"},
"arianism":	{"NN"},
"arianist":	{"NN"},
"arianists":	{"NNS"},
"arianrhod":	{"NN"},
"arianrod":	{"NN"},
"arias":	{"NNS"},
"aricara":	{"NN"},
"arid":	{"JJ","NN"},
"aridity":	{"NN"},
"aridness":	{"NN"},
"aries":	{"NN"},
"arietta":	{"NN"},
"aright":	{"RB"},
"ariidae":	{"NN"},
"arikara":	{"NN"},
"aril":	{"NN"},
"ariled":	{"JJ"},
"arillate":	{"JJ"},
"arilus":	{"NN"},
"ariocarpus":	{"NN"},
"ariomma":	{"NN"},
"ariose":	{"JJ"},
"arioso":	{"NN"},
"arisaema":	{"NN"},
"arisarum":	{"NN"},
"arise":	{"VB","VBP"},
"arisen":	{"VBN"},
"arises":	{"VBZ"},
"arishth":	{"NN"},
"arising":	{"VBG"},
"arista":	{"NN"},
"aristarchus":	{"NN"},
"aristocort":	{"NN"},
"aristocracy":	{"NN"},
"aristocrat":	{"NN"},
"aristocratic":	{"JJ","NN"},
"aristocratical":	{"JJ"},
"aristocratically":	{"RB"},
"aristocrats":	{"NNS"},
"aristolochia":	{"NN"},
"aristolochiaceae":	{"NN"},
"aristolochiales":	{"NNS"},
"aristopak":	{"NN"},
"aristotelean":	{"JJ","NN"},
"aristotelia":	{"NN"},
"aristotelianism":	{"NN"},
"aristotelic":	{"JJ"},
"arithmancy":	{"NN"},
"arithmetic":	{"NN","JJ"},
"arithmetical":	{"JJ"},
"arithmetically":	{"RB"},
"arithmetician":	{"NN"},
"arithmetized":	{"VBN"},
"arity":	{"NN"},
"arius":	{"NN"},
"arizona":	{"NN"},
"arizona-related":	{"JJ"},
"arizonan":	{"NN"},
"arizonian":	{"NN"},
"arjuna":	{"NN"},
"ark":	{"NN"},
"arkansan":	{"NN"},
"arkansas":	{"NN"},
"arkansas-based":	{"JJ"},
"arkansawyer":	{"NN"},
"arkylbenzene":	{"NN"},
"arles":	{"NNS"},
"arlington":	{"NN"},
"arm":	{"NN","VB","VBP"},
"arm's-length":	{"JJ"},
"arm-elevation":	{"NN"},
"arm-levitation":	{"NN"},
"arm-rise":	{"NN"},
"arm-twisting":	{"NN"},
"armada":	{"NN"},
"armadillidiidae":	{"NN"},
"armadillidium":	{"NN"},
"armadillo":	{"NN"},
"armadillos":	{"NNS"},
"armageddon":	{"NN"},
"armagnac":	{"NN"},
"armament":	{"NN"},
"armamentarium":	{"NN"},
"armaments":	{"NNS"},
"armani":	{"NN"},
"armature":	{"NN"},
"armband":	{"NN"},
"armchair":	{"NN","JJ"},
"armchairs":	{"NNS"},
"armed":	{"JJ","VBN","VBD"},
"armenia":	{"NN"},
"armenian":	{"JJ","NN"},
"armeria":	{"NN"},
"armet":	{"NN"},
"armful":	{"NN"},
"armguard":	{"NN"},
"armhole":	{"NN"},
"armide":	{"NN"},
"armies":	{"NNS"},
"armiger":	{"NN"},
"armilla":	{"NN"},
"armillaria":	{"NN"},
"armillariella":	{"NN"},
"armillary":	{"JJ"},
"armin":	{"NN"},
"arming":	{"NN","VBG"},
"arminian":	{"JJ","NN"},
"arminianism":	{"NN"},
"arminius":	{"NN"},
"armistice":	{"NN"},
"armitage":	{"NN"},
"armless":	{"JJ"},
"armlet":	{"NN"},
"armlike":	{"JJ"},
"armload":	{"NN"},
"armoire":	{"NN"},
"armor":	{"NN"},
"armor-bearer":	{"NN"},
"armor-clad":	{"JJ"},
"armor-plated":	{"JJ"},
"armoracia":	{"NN"},
"armored":	{"JJ","VBD","VBN"},
"armored-vehicle":	{"JJ"},
"armorer":	{"NN"},
"armorial":	{"JJ"},
"armoring":	{"VBG"},
"armors":	{"VBZ"},
"armory":	{"NN"},
"armour":	{"NN"},
"armour-clad":	{"JJ"},
"armour-plated":	{"JJ"},
"armoured":	{"JJ"},
"armourer":	{"NN"},
"armoury":	{"NN"},
"armpit":	{"NN"},
"armpits":	{"NNS"},
"armrest":	{"NN"},
"arms":	{"NNS","VBZ"},
"arms-control":	{"NN","JJ"},
"arms-export":	{"JJ"},
"arms-kickback":	{"NN"},
"arms-making":	{"NN"},
"arms-production":	{"NN"},
"arms-reduction":	{"NN","JJ"},
"arms-runner":	{"NN"},
"arms-sales":	{"JJ"},
"army":	{"NN"},
"armyworm":	{"NN"},
"arng":	{"NN"},
"arnhem":	{"NN"},
"arnica":	{"NN"},
"arno":	{"NN"},
"arnoseris":	{"NN"},
"aroid":	{"JJ","NN"},
"aroma":	{"NN"},
"aromas":	{"NNS"},
"aromatherapy":	{"NN"},
"aromatic":	{"JJ","NN"},
"aromatick":	{"JJ"},
"aromatics":	{"NNS"},
"aromatise":	{"VB"},
"aromatize":	{"VB"},
"arose":	{"VBD"},
"arouet":	{"NN"},
"around":	{"IN","RB","RP"},
"around-the-clock":	{"JJ"},
"around-the-world":	{"JJ"},
"arousal":	{"NN"},
"arouse":	{"VB","VBP"},
"aroused":	{"VBD","VBN"},
"arouser":	{"NN"},
"arouses":	{"VBZ"},
"arousing":	{"VBG"},
"arp":	{"NN"},
"arpeggio":	{"NN"},
"arpeggios":	{"NNS"},
"arpent":	{"NN"},
"arquebus":	{"NN"},
"arrack":	{"NN"},
"arraign":	{"VB","VBP"},
"arraigned":	{"VBD","VBN"},
"arraigning":	{"VBG"},
"arraignment":	{"NN"},
"arraignments":	{"NNS"},
"arraigns":	{"VBZ"},
"arrange":	{"VB","VBP"},
"arranged":	{"VBN","VBD"},
"arrangement":	{"NN"},
"arrangements":	{"NNS"},
"arranger":	{"NN"},
"arrangers":	{"NNS"},
"arranges":	{"VBZ"},
"arranging":	{"VBG"},
"arrant":	{"JJ","NN"},
"arras":	{"NN"},
"array":	{"NN","VB","VBP"},
"arrayed":	{"VBD","VBN"},
"arraying":	{"VBG"},
"arrays":	{"NNS","VBZ"},
"arrearage":	{"NN"},
"arrearages":	{"NNS"},
"arrears":	{"NNS"},
"arrest":	{"NN","VB","VBP"},
"arrested":	{"VBN","VBD"},
"arrester":	{"NN"},
"arresting":	{"JJ","VBG"},
"arrests":	{"NNS","VBZ"},
"arrhenatherum":	{"NN"},
"arrhenius":	{"NN"},
"arrhythmia":	{"NN"},
"arrhythmic":	{"JJ"},
"arrhythmical":	{"JJ"},
"arrival":	{"NN"},
"arrivals":	{"NNS"},
"arrive":	{"VB","VBP"},
"arrived":	{"VBD","VBN"},
"arrivederci":	{"NN"},
"arriver":	{"NN"},
"arrives":	{"VBZ"},
"arriving":	{"VBG"},
"arriviste":	{"NN"},
"arrivistes":	{"NNS"},
"arroba":	{"NN"},
"arrogance":	{"NN"},
"arrogant":	{"JJ"},
"arrogantly":	{"RB"},
"arrogate":	{"VB","VBP"},
"arrogated":	{"VBD","VBN"},
"arrogates":	{"VBZ"},
"arrogating":	{"VBG"},
"arrogation":	{"NN"},
"arrogator":	{"NN"},
"arrow":	{"NN"},
"arrow-shaped":	{"JJ"},
"arrowed":	{"JJ"},
"arrowhead":	{"NN"},
"arrowheads":	{"NNS"},
"arrowroot":	{"NN"},
"arrows":	{"NNS"},
"arrowsmith":	{"NN"},
"arrowworm":	{"NN"},
"arroyo":	{"NN"},
"arse":	{"NN","VB","VBP"},
"arsed":	{"VBD","VBN"},
"arsehole":	{"NN"},
"arsenal":	{"NN","JJ"},
"arsenals":	{"NNS"},
"arsenate":	{"NN"},
"arsenic":	{"NN","JJ"},
"arsenical":	{"JJ","NN"},
"arsenide":	{"NN"},
"arsenio":	{"NN"},
"arsenious":	{"JJ"},
"arsenopyrite":	{"NN"},
"arses":	{"NNS","VBZ"},
"arside":	{"NN"},
"arsine":	{"NN"},
"arsines":	{"NNS"},
"arsing":	{"VBG"},
"arson":	{"NN"},
"arsonist":	{"NN"},
"art":	{"NN","VBP","VB"},
"art-acquisition":	{"JJ"},
"art-auction":	{"NN"},
"art-dealing":	{"JJ"},
"art-filled":	{"JJ"},
"art-historian":	{"NN"},
"art-historical":	{"JJ"},
"art-nouveau":	{"JJ"},
"art-shop":	{"NN"},
"art-world":	{"NN"},
"artamidae":	{"NN"},
"artamus":	{"NN"},
"artaxerxes":	{"NN"},
"arte":	{"NN"},
"artefact":	{"NN"},
"artefactual":	{"JJ"},
"artemia":	{"NN"},
"artemis":	{"NN"},
"artemisia":	{"NN"},
"arteria":	{"NN"},
"arterial":	{"JJ","NN"},
"arterialise":	{"VB"},
"arterialize":	{"VB"},
"arteriectasia":	{"NN"},
"arteriectasis":	{"NN"},
"arteries":	{"NNS"},
"arteriogram":	{"NN"},
"arteriography":	{"NN"},
"arteriola":	{"NN"},
"arteriolar":	{"JJ"},
"arteriolar-pulmonary":	{"JJ"},
"arteriole":	{"NN"},
"arterioles":	{"NNS"},
"arteriolosclerosis":	{"NN"},
"arteriosclerosis":	{"NN"},
"arteriosclerotic":	{"JJ"},
"arteriovenous":	{"JJ"},
"arteritis":	{"NN"},
"artery":	{"NN"},
"artery-clogging":	{"NN"},
"artery-pulmonary":	{"NN"},
"artesian":	{"JJ","NN"},
"artful":	{"JJ"},
"artfully":	{"RB"},
"artfulness":	{"NN"},
"arthralgia":	{"NN"},
"arthralgic":	{"JJ"},
"arthritic":	{"JJ","NN"},
"arthritis":	{"NN"},
"arthrocentesis":	{"NN"},
"arthrodesis":	{"NN"},
"arthrogram":	{"NN"},
"arthrography":	{"NN"},
"arthromere":	{"NN"},
"arthromeric":	{"JJ"},
"arthropathy":	{"NN"},
"arthroplasty":	{"NN"},
"arthropod":	{"JJ","NN"},
"arthropoda":	{"NN"},
"arthropodal":	{"JJ"},
"arthropodan":	{"JJ"},
"arthropodous":	{"JJ"},
"arthropteris":	{"NN"},
"arthroscope":	{"NN"},
"arthroscopic":	{"NN","JJ","VBN","DT"},
"arthroscopy":	{"NN"},
"arthrospore":	{"NN"},
"arthrosporic":	{"JJ"},
"arthrosporous":	{"JJ"},
"arthur":	{"NN"},
"arthurian":	{"JJ"},
"artichoke":	{"NN"},
"artichokes":	{"NNS","VBZ"},
"article":	{"NN","VB","VBP"},
"articled":	{"JJ","VBD","VBN"},
"articles":	{"NNS","VBZ"},
"articling":	{"VBG"},
"articular":	{"JJ"},
"articulary":	{"JJ"},
"articulate":	{"JJ","VB","VBP"},
"articulated":	{"JJ","VBD","VBN"},
"articulately":	{"RB"},
"articulateness":	{"NN"},
"articulates":	{"VBZ"},
"articulating":	{"VBG"},
"articulatio":	{"NN"},
"articulation":	{"NN"},
"articulations":	{"NNS"},
"articulative":	{"JJ"},
"articulator":	{"NN"},
"articulatory":	{"JJ"},
"articulo":	{"NN","IN","FW","TO"},
"articulos":	{"NNS","FW","IN"},
"artifact":	{"NN"},
"artifacts":	{"NNS"},
"artifactual":	{"JJ"},
"artifical":	{"JJ"},
"artifically":	{"RB"},
"artifice":	{"NN"},
"artificer":	{"NN"},
"artificial":	{"JJ"},
"artificial-heart":	{"JJ"},
"artificiality":	{"NN"},
"artificially":	{"RB"},
"artillerist":	{"NN"},
"artillerists":	{"NNS"},
"artillery":	{"NN"},
"artilleryman":	{"NN"},
"artiodactyl":	{"JJ","NN"},
"artiodactyla":	{"NN"},
"artiodactylous":	{"JJ"},
"artisan":	{"NN"},
"artisans":	{"NNS"},
"artist":	{"NN"},
"artist-author":	{"NN"},
"artist-nature":	{"NN"},
"artistas":	{"NNS"},
"artiste":	{"NN"},
"artistic":	{"JJ"},
"artistically":	{"RB"},
"artistry":	{"NN"},
"artists":	{"NNS"},
"artless":	{"JJ"},
"artlessly":	{"RB"},
"artlessness":	{"NN"},
"artocarpus":	{"NNS"},
"artois":	{"NN"},
"arts":	{"NNS"},
"artsd":	{"NN"},
"artsy":	{"JJ"},
"artsy-craftsy":	{"JJ"},
"artwork":	{"NN"},
"artworks":	{"NNS"},
"arty":	{"JJ"},
"arty-crafty":	{"JJ"},
"aruba":	{"NN"},
"arugula":	{"NN"},
"arui":	{"NN"},
"arulo":	{"NN"},
"arum":	{"NN"},
"arundinaceous":	{"JJ"},
"arundinaria":	{"NN"},
"arundo":	{"NN"},
"aruru":	{"NN"},
"arvicola":	{"NN"},
"aryan":	{"JJ","NN"},
"aryl":	{"NN"},
"arylesterase":	{"NN"},
"arylesterases":	{"NNS"},
"arytaenoid":	{"NN"},
"arytenoid":	{"NN"},
"as":	{"IN","RB","CC"},
"as-it-were":	{"RB"},
"as-yet":	{"RB"},
"asa":	{"NN"},
"asadha":	{"NN"},
"asafetida":	{"NN"},
"asafoetida":	{"NN"},
"asahikawa":	{"NN"},
"asala":	{"NN"},
"asama":	{"NN"},
"asamiya":	{"NN"},
"asana":	{"NN"},
"asanga":	{"NN"},
"asap":	{"RB"},
"asarabacca":	{"NN"},
"asarh":	{"NN"},
"asarum":	{"NN"},
"asat":	{"JJ"},
"asbestos":	{"NN"},
"asbestos-abatement":	{"JJ","NN"},
"asbestos-containing":	{"JJ"},
"asbestos-disease":	{"NN"},
"asbestos-related":	{"JJ"},
"asbestos-removal":	{"NN","JJ"},
"asbestosis":	{"NN"},
"asc":	{"NN"},
"ascaphidae":	{"NN"},
"ascaphus":	{"NN"},
"ascariasis":	{"NN"},
"ascaridae":	{"NN"},
"ascaridia":	{"NN"},
"ascaris":	{"NN"},
"ascend":	{"VB","VBP"},
"ascendable":	{"JJ"},
"ascendance":	{"NN"},
"ascendancy":	{"NN"},
"ascendant":	{"NN","JJ"},
"ascended":	{"VBD","VBN"},
"ascendence":	{"NN"},
"ascendency":	{"NN"},
"ascendent":	{"NN","JJ"},
"ascender":	{"NN"},
"ascendible":	{"JJ"},
"ascending":	{"JJ","VBG"},
"ascends":	{"VBZ"},
"ascension":	{"NN"},
"ascensional":	{"JJ"},
"ascensive":	{"JJ"},
"ascent":	{"NN"},
"ascents":	{"NNS"},
"ascertain":	{"VB","VBP"},
"ascertainable":	{"JJ"},
"ascertained":	{"VBD","VBN"},
"ascertaining":	{"VBG"},
"ascertainment":	{"NN"},
"ascertains":	{"VBZ"},
"ascesis":	{"NN"},
"ascetic":	{"JJ","NN"},
"ascetical":	{"JJ"},
"ascetically":	{"RB"},
"asceticism":	{"NN"},
"ascetics":	{"NNS"},
"asch":	{"NN"},
"aschelminthes":	{"NNS"},
"ascidiaceae":	{"NN"},
"ascidian":	{"NN"},
"ascii":	{"NN"},
"ascites":	{"NN"},
"ascitic":	{"JJ"},
"asclepiad":	{"NN"},
"asclepiadaceae":	{"NN"},
"asclepiadaceous":	{"JJ"},
"asclepias":	{"NN"},
"asclepius":	{"NN"},
"ascocarp":	{"NN"},
"ascocarpous":	{"JJ"},
"ascolichen":	{"NN"},
"ascoma":	{"NN"},
"ascomycete":	{"NN"},
"ascomycetes":	{"NNS"},
"ascomycetous":	{"JJ"},
"ascomycota":	{"NN"},
"ascomycotina":	{"NN"},
"ascophyllum":	{"NN"},
"ascospore":	{"NN"},
"ascosporic":	{"JJ"},
"ascosporous":	{"JJ"},
"ascot":	{"NN"},
"ascribable":	{"JJ"},
"ascribe":	{"VB","VBP"},
"ascribed":	{"VBD","VBN"},
"ascribes":	{"VBZ"},
"ascribing":	{"VBG"},
"ascription":	{"NN"},
"ascus":	{"NN"},
"asdic":	{"NN"},
"asea":	{"NN"},
"asepsis":	{"NN"},
"aseptic":	{"JJ"},
"aseptically":	{"RB"},
"asexual":	{"JJ"},
"asexuality":	{"NN"},
"asexually":	{"RB"},
"asgard":	{"NN"},
"ash":	{"NN"},
"ash-bin":	{"NN"},
"ash-blonde":	{"JJ"},
"ash-gray":	{"JJ"},
"ash-grey":	{"JJ"},
"ash-key":	{"NN"},
"ash-pan":	{"NN"},
"asham":	{"JJ"},
"ashamed":	{"JJ"},
"ashamedly":	{"RB"},
"ashare":	{"NN"},
"ashbin":	{"NN"},
"ashcake":	{"NN"},
"ashcan":	{"NN"},
"ashen":	{"JJ","NN"},
"asher":	{"NN"},
"ashes":	{"NNS"},
"asheville":	{"NN"},
"ashir":	{"NN"},
"ashkenazi":	{"NN"},
"ashkhabad":	{"NN"},
"ashland":	{"NN"},
"ashlar":	{"NN"},
"ashore":	{"RB","NN"},
"ashram":	{"NN"},
"ashton":	{"NN"},
"ashtoreth":	{"NN"},
"ashtray":	{"NN"},
"ashtrays":	{"NNS"},
"ashur":	{"NN"},
"ashurbanipal":	{"NN"},
"ashy":	{"JJ"},
"asia":	{"NN"},
"asian-american":	{"JJ"},
"asian-owned":	{"JJ"},
"asiatic":	{"JJ","NN"},
"aside":	{"RB","NN","IN","RP"},
"asides":	{"NNS"},
"asilidae":	{"NN"},
"asimina":	{"NN"},
"asimov":	{"NN"},
"asin":	{"NN"},
"asinine":	{"JJ","NN"},
"asininity":	{"NN"},
"asio":	{"NN"},
"ask":	{"VB","VBP","NN"},
"askance":	{"RB"},
"askant":	{"RB"},
"asked":	{"VBD","VBN"},
"asker":	{"NN"},
"askew":	{"JJ","RB"},
"asking":	{"VBG","NN"},
"asklepios":	{"NN"},
"asks":	{"VBZ"},
"asl":	{"NN"},
"aslant":	{"JJ","RB"},
"asleep":	{"JJ"},
"aslope":	{"JJ"},
"asmara":	{"NN"},
"asmera":	{"NN"},
"asocial":	{"JJ"},
"asp":	{"NN"},
"aspadana":	{"NN"},
"aspalathus":	{"NN"},
"asparagaceae":	{"NN"},
"asparaginase":	{"NN"},
"asparagine":	{"NN"},
"asparagus":	{"NN"},
"aspartame":	{"NN"},
"aspect":	{"NN"},
"aspects":	{"NNS"},
"aspectual":	{"JJ"},
"aspen":	{"NN"},
"aspens":	{"NNS"},
"asper":	{"NN"},
"aspergill":	{"NN"},
"aspergillaceae":	{"NN"},
"aspergillales":	{"NNS"},
"aspergillosis":	{"NN"},
"aspergillus":	{"NN"},
"asperity":	{"NN"},
"asperse":	{"VB"},
"aspersion":	{"NN"},
"aspersions":	{"NNS"},
"aspersorium":	{"NN"},
"asperula":	{"NN"},
"asphalt":	{"NN","VB","VBP"},
"asphalt-hard":	{"JJ"},
"asphalted":	{"VBD","VBN"},
"asphaltic":	{"JJ"},
"asphalting":	{"VBG"},
"asphalts":	{"VBZ"},
"aspheric":	{"JJ"},
"aspherical":	{"JJ"},
"asphodel":	{"NN"},
"asphodelaceae":	{"NN"},
"asphodeline":	{"NN"},
"asphodelus":	{"NN"},
"asphyxia":	{"NN"},
"asphyxiate":	{"VB","VBP"},
"asphyxiated":	{"VBD","VBN"},
"asphyxiates":	{"VBZ"},
"asphyxiating":	{"VBG"},
"asphyxiation":	{"NN"},
"asphyxiator":	{"NN"},
"aspic":	{"NN"},
"aspidelaps":	{"NNS"},
"aspidiotus":	{"NN"},
"aspidistra":	{"NN"},
"aspidophoroides":	{"NNS"},
"aspilia":	{"NN"},
"aspinwall":	{"NN"},
"aspirant":	{"NN","JJ"},
"aspirants":	{"NNS"},
"aspirate":	{"NN","VB","VBP"},
"aspirated":	{"VBD","VBN"},
"aspirates":	{"NNS","VBZ"},
"aspirating":	{"VBG"},
"aspiration":	{"NN"},
"aspirational":	{"JJ"},
"aspirations":	{"NNS"},
"aspirator":	{"NN"},
"aspire":	{"VB","VBP"},
"aspired":	{"VBD","VBN"},
"aspirer":	{"NN"},
"aspires":	{"VBZ"},
"aspirin":	{"NN","NNS"},
"aspiring":	{"JJ","VBG"},
"aspirins":	{"NNS"},
"aspis":	{"NN"},
"aspleniaceae":	{"NN"},
"asplenium":	{"NN"},
"asquint":	{"JJ"},
"ass":	{"NN"},
"ass-kisser":	{"NN"},
"assad":	{"NN"},
"assagai":	{"NN"},
"assai":	{"FW"},
"assail":	{"VB","VBP"},
"assailability":	{"NN"},
"assailable":	{"JJ"},
"assailant":	{"NN"},
"assailants":	{"NNS"},
"assailed":	{"VBD","VBN"},
"assailing":	{"VBG"},
"assails":	{"VBZ"},
"assam":	{"NN"},
"assamese":	{"JJ","NN"},
"assassin":	{"NN"},
"assassinate":	{"VB","VBP"},
"assassinated":	{"VBD","VBN"},
"assassinates":	{"VBZ"},
"assassinating":	{"VBG"},
"assassination":	{"NN"},
"assassinations":	{"NNS"},
"assassinator":	{"NN"},
"assassins":	{"NNS"},
"assault":	{"NN","VB","VBP"},
"assault-weapons":	{"JJ"},
"assaulted":	{"VBD","VBN"},
"assaulter":	{"NN"},
"assaulting":	{"VBG"},
"assaultive":	{"JJ"},
"assaults":	{"VBZ","NNS"},
"assay":	{"NN","VB","VBP"},
"assay-mark":	{"NN"},
"assayed":	{"VBD","VBN"},
"assayer":	{"NN"},
"assaying":	{"VBG"},
"assays":	{"NNS","VBZ"},
"asseet":	{"NN"},
"assegai":	{"NN"},
"assemblage":	{"NN"},
"assemblages":	{"NNS"},
"assemble":	{"VB","VBP"},
"assembled":	{"VBN","VBD"},
"assembler":	{"NN"},
"assemblers":	{"NNS"},
"assembles":	{"VBZ"},
"assemblies":	{"NNS"},
"assembling":	{"VBG"},
"assembly":	{"NN"},
"assembly-line":	{"NN"},
"assemblyman":	{"NN"},
"assemblywoman":	{"NN"},
"assent":	{"VB","VBP","NN"},
"assented":	{"VBD","VBN"},
"assenter":	{"NN"},
"assentient":	{"JJ"},
"assenting":	{"VBG"},
"assents":	{"VBZ"},
"assert":	{"VB","NN","VBP"},
"assertable":	{"JJ"},
"asserted":	{"VBD","VBN"},
"assertedly":	{"RB"},
"asserter":	{"NN"},
"asserting":	{"VBG"},
"assertion":	{"NN"},
"assertions":	{"NNS"},
"assertive":	{"JJ"},
"assertively":	{"RB"},
"assertiveness":	{"NN"},
"asserts":	{"VBZ"},
"asses":	{"NNS"},
"assesment":	{"NN"},
"assess":	{"VB","VBP"},
"assessable":	{"JJ"},
"assessed":	{"VBN","VBD"},
"assessee":	{"NN"},
"assesses":	{"VBZ"},
"assessing":	{"VBG"},
"assessment":	{"NN"},
"assessments":	{"NNS"},
"assessor":	{"NN"},
"assessories":	{"NNS"},
"assessors":	{"NNS"},
"asset":	{"NN"},
"asset-allocation":	{"JJ","NN"},
"asset-backed":	{"JJ"},
"asset-based":	{"JJ"},
"asset-forfeiture":	{"NN"},
"asset-growth":	{"NN"},
"asset-liability":	{"JJ","NN"},
"asset-management":	{"NN"},
"asset-quality":	{"JJ"},
"asset-rich":	{"JJ"},
"asset-sale":	{"JJ"},
"asset-stripping":	{"NN"},
"asset-trading":	{"NN"},
"asset-valuation":	{"NN"},
"assets":	{"NNS"},
"asseverate":	{"VB","VBP"},
"asseverated":	{"VBD","VBN"},
"asseverates":	{"VBZ"},
"asseverating":	{"VBG"},
"asseveration":	{"NN"},
"asseverations":	{"NNS"},
"asseverator":	{"NN"},
"asshole":	{"NN"},
"assholery":	{"NN"},
"assibilate":	{"VB"},
"assibilation":	{"NN"},
"assiduity":	{"NN"},
"assiduous":	{"JJ"},
"assiduously":	{"RB"},
"assiduousness":	{"NN"},
"assign":	{"VB","VBP"},
"assignable":	{"JJ"},
"assignation":	{"NN"},
"assigned":	{"VBD","VBN"},
"assigned-risk":	{"NN"},
"assignee":	{"NN"},
"assigning":	{"VBG"},
"assignment":	{"NN"},
"assignments":	{"NNS"},
"assignor":	{"NN"},
"assigns":	{"VBZ"},
"assimilable":	{"JJ"},
"assimilate":	{"VB","VBP"},
"assimilated":	{"VBD","VBN"},
"assimilates":	{"VBZ"},
"assimilating":	{"VBG"},
"assimilation":	{"NN"},
"assimilative":	{"JJ"},
"assimilator":	{"NN"},
"assimilatory":	{"JJ"},
"assist":	{"VBP","VB","NN"},
"assistance":	{"NN"},
"assistant":	{"NN","JJ"},
"assistants":	{"NNS"},
"assisted":	{"VBD","VBN","JJ"},
"assisted-living":	{"JJ"},
"assisting":	{"VBG"},
"assistive":	{"JJ"},
"assists":	{"NNS","VBZ"},
"assize":	{"NN"},
"assizes":	{"NNS"},
"associability":	{"NN"},
"associable":	{"JJ"},
"associableness":	{"NN"},
"associaitons":	{"NNS"},
"associate":	{"JJ","NN","VB","VBP"},
"associate-label":	{"JJ"},
"associated":	{"VBN","JJ","VBD"},
"associates":	{"NNS","VBZ"},
"associateship":	{"NN"},
"associating":	{"VBG","NN","JJ"},
"association":	{"NN"},
"associational":	{"JJ"},
"associationism":	{"NN"},
"associations":	{"NNS"},
"associative":	{"JJ"},
"associatively":	{"RB"},
"associatory":	{"JJ"},
"assoil":	{"VB"},
"assoiled":	{"VBD","VBN"},
"assoiling":	{"VBG"},
"assoils":	{"VBZ"},
"assonance":	{"NN"},
"assonant":	{"JJ"},
"assonate":	{"VB"},
"assort":	{"VB"},
"assorted":	{"JJ","VBN","VBD"},
"assorting":	{"VBG"},
"assortment":	{"NN"},
"assortments":	{"NNS"},
"assorts":	{"VBZ"},
"assouan":	{"NN"},
"assuage":	{"VB","VBP"},
"assuaged":	{"VBD","VBN"},
"assuagement":	{"NN"},
"assuages":	{"VBZ"},
"assuaging":	{"VBG"},
"assuan":	{"NN"},
"assuasive":	{"JJ"},
"assume":	{"VB","VBP"},
"assumed":	{"VBD","VBN","JJ"},
"assumes":	{"VBZ"},
"assuming":	{"VBG","JJ","IN"},
"assumption":	{"NN"},
"assumptions":	{"NNS"},
"assumptive":	{"JJ"},
"assur":	{"NN"},
"assurance":	{"NN"},
"assurances":	{"NNS"},
"assurbanipal":	{"NN"},
"assure":	{"VB","VBP"},
"assured":	{"VBN","VBD","JJ"},
"assuredly":	{"RB"},
"assuredness":	{"NN"},
"assures":	{"VBZ"},
"assurgent":	{"JJ"},
"assuring":	{"VBG"},
"assyriology":	{"NN"},
"ast":	{"JJ"},
"astacidae":	{"NN"},
"astacura":	{"NN"},
"astacus":	{"NN"},
"astaire":	{"NN"},
"astana":	{"NN"},
"astarte":	{"NN"},
"astasia":	{"NN"},
"astatic":	{"JJ"},
"astatine":	{"NN"},
"aster":	{"NN"},
"asteraceae":	{"NN"},
"astereognosis":	{"NN"},
"asteriated":	{"JJ"},
"asteridae":	{"NN"},
"asterion":	{"NN"},
"asterisk":	{"NN","VB","VBP"},
"asterisked":	{"VBD","VBN"},
"asterisking":	{"VBG"},
"asterisks":	{"NNS","VBZ"},
"asterism":	{"NN"},
"asterismal":	{"JJ"},
"astern":	{"RB"},
"asternal":	{"JJ"},
"asteroid":	{"NN"},
"asteroidal":	{"JJ"},
"asteroidea":	{"NN"},
"asteroids":	{"NNS"},
"asterope":	{"NN"},
"asters":	{"NNS"},
"asthenia":	{"NN"},
"asthenic":	{"JJ"},
"asthenopia":	{"NN"},
"asthenosphere":	{"NN"},
"astheny":	{"NN"},
"asthma":	{"NN"},
"asthmatic":	{"JJ","NN"},
"astigmatic":	{"JJ"},
"astigmatism":	{"NN"},
"astigmia":	{"NN"},
"astilbe":	{"NN"},
"astir":	{"JJ","NN"},
"astomatal":	{"JJ"},
"astomatous":	{"JJ"},
"astonied":	{"JJ"},
"astonish":	{"VB","VBP"},
"astonished":	{"JJ","VBD","VBN"},
"astonishes":	{"VBZ"},
"astonishing":	{"JJ","VBG"},
"astonishingly":	{"RB"},
"astonishment":	{"NN"},
"astor":	{"NN"},
"astound":	{"VB","VBP"},
"astounded":	{"JJ","VBD","VBN"},
"astounding":	{"JJ","VBG"},
"astoundingly":	{"RB"},
"astounds":	{"VBZ"},
"astra":	{"NN"},
"astraddle":	{"RB"},
"astragal":	{"NN"},
"astragalar":	{"JJ"},
"astragalus":	{"NN"},
"astrakhan":	{"NN"},
"astral":	{"JJ","NN"},
"astrantia":	{"NN"},
"astraphobia":	{"NN"},
"astray":	{"RB","NN"},
"astreus":	{"NN"},
"astride":	{"IN","NN"},
"astringe":	{"VB"},
"astringence":	{"NN"},
"astringency":	{"NN"},
"astringent":	{"JJ","NN"},
"astrobiology":	{"NN"},
"astrocyte":	{"NN"},
"astrocytic":	{"JJ"},
"astrodome":	{"NN"},
"astrodynamics":	{"NN"},
"astrogate":	{"VB"},
"astrogator":	{"NN"},
"astroglia":	{"NN"},
"astrolabe":	{"NN"},
"astrolatry":	{"NN"},
"astrologer":	{"NN"},
"astrological":	{"JJ","NN"},
"astrologist":	{"NN"},
"astrologists":	{"NNS"},
"astrology":	{"NN"},
"astroloma":	{"NN"},
"astrometry":	{"NN"},
"astronaut":	{"NN"},
"astronautic":	{"JJ"},
"astronautical":	{"JJ"},
"astronautics":	{"NN"},
"astronauts":	{"NNS"},
"astronavigation":	{"NN"},
"astronium":	{"NN"},
"astronomer":	{"NN"},
"astronomers":	{"NNS"},
"astronomic":	{"JJ"},
"astronomical":	{"JJ"},
"astronomically":	{"RB"},
"astronomy":	{"NN"},
"astrophysical":	{"JJ"},
"astrophysicist":	{"NN"},
"astrophysics":	{"NN"},
"astrophyton":	{"NN"},
"astropogon":	{"NN"},
"astute":	{"JJ"},
"astutely":	{"RB"},
"astuteness":	{"NN"},
"astylar":	{"JJ"},
"asuncion":	{"NN"},
"asunder":	{"RB"},
"asur":	{"NN"},
"asura":	{"NN"},
"asurbanipal":	{"NN"},
"asvina":	{"NN"},
"asvins":	{"NN"},
"asw":	{"NN"},
"aswan":	{"NN"},
"asylum":	{"NN"},
"asymmetric":	{"JJ","NN"},
"asymmetrical":	{"JJ","NN"},
"asymmetrically":	{"RB"},
"asymmetry":	{"NN"},
"asymptomatic":	{"JJ","NN"},
"asymptote":	{"NN"},
"asymptotic":	{"JJ"},
"asymptotically":	{"RB"},
"asynchronism":	{"NN"},
"asynchronous":	{"JJ"},
"asynchrony":	{"NN"},
"asynclitism":	{"NN"},
"asyndetic":	{"JJ"},
"asyndeton":	{"NN"},
"asynergia":	{"NN"},
"asynergic":	{"JJ"},
"asynergy":	{"NN"},
"asystole":	{"NN"},
"at":	{"IN","RP"},
"at-bat":	{"NN"},
"at-bats":	{"NNS"},
"at-home":	{"JJ"},
"at-large":	{"JJ"},
"at-market":	{"JJ"},
"at-risk":	{"JJ"},
"atabrine":	{"NN"},
"atactic":	{"JJ"},
"atakapa":	{"NN"},
"atakapan":	{"NN"},
"atar":	{"NN"},
"ataractic":	{"JJ","NN"},
"atarax":	{"NN"},
"ataraxia":	{"NN"},
"ataraxic":	{"JJ"},
"ataraxis":	{"NN"},
"ataturk":	{"NN"},
"atavism":	{"NN"},
"atavist":	{"NN"},
"atavistic":	{"JJ"},
"ataxia":	{"NN"},
"ataxic":	{"JJ"},
"ataxy":	{"NN"},
"atayalic":	{"NN"},
"ate":	{"VBD"},
"atelectasis":	{"NN"},
"ateleiosis":	{"NN"},
"ateleiotic":	{"JJ"},
"ateles":	{"NNS"},
"atelier":	{"NN"},
"ateliosis":	{"NN"},
"aten":	{"NN"},
"atenolol":	{"NN"},
"atf":	{"NN"},
"athabascan":	{"NN"},
"athabaskan":	{"NN"},
"athanasianism":	{"NN"},
"athanasius":	{"NN"},
"athanor":	{"NN"},
"athapascan":	{"NN"},
"athapaskan":	{"NN"},
"athar":	{"NN"},
"atharva-veda":	{"NN"},
"atheism":	{"NN"},
"atheist":	{"NN"},
"atheistic":	{"JJ"},
"atheistical":	{"JJ"},
"atheists":	{"NNS"},
"athelstan":	{"NN"},
"athena":	{"NN"},
"athenaeum":	{"NN"},
"athene":	{"NN"},
"atheneum":	{"NN"},
"athens":	{"NNS"},
"atherinidae":	{"NN"},
"atherinopsis":	{"NN"},
"atherodyde":	{"NN"},
"atherogenesis":	{"NN"},
"atheroma":	{"NN"},
"atheromatic":	{"JJ"},
"atheromatous":	{"JJ"},
"atherosclerosis":	{"NN"},
"atherosclerotic":	{"JJ","NN"},
"atherurus":	{"NN"},
"athetosis":	{"NN"},
"athinai":	{"NN"},
"athiorhodaceae":	{"NN"},
"athirst":	{"JJ"},
"athleisure":	{"NN"},
"athlete":	{"NN"},
"athlete-payoff":	{"JJ"},
"athlete-student":	{"NN"},
"athletes":	{"NNS"},
"athletic":	{"JJ"},
"athletic-shoe":	{"JJ","NN"},
"athletically":	{"RB"},
"athleticism":	{"NN"},
"athletics":	{"NN"},
"athodyd":	{"NN"},
"athos":	{"NN"},
"athrotaxis":	{"NN"},
"athwart":	{"RB","IN"},
"athyriaceae":	{"NN"},
"athyrium":	{"NN"},
"atilt":	{"JJ"},
"ativan":	{"NN"},
"atlanta-based":	{"JJ"},
"atlantes":	{"NNS"},
"atlantic":	{"JJ","NN"},
"atlantides":	{"NNS"},
"atlantis":	{"NN"},
"atlas":	{"NN"},
"atm":	{"NN"},
"atmometer":	{"NN"},
"atmosphere":	{"NN"},
"atmospheres":	{"NNS"},
"atmospheric":	{"JJ"},
"atmospherical":	{"JJ"},
"atmospherics":	{"NNS"},
"atms":	{"NNS"},
"atole":	{"NN"},
"atoll":	{"NN"},
"atolls":	{"NNS"},
"atom":	{"NN"},
"atom-bomb":	{"VB","VBP"},
"atom-bombed":	{"VBD","VBN"},
"atom-bombing":	{"VBG"},
"atom-bombs":	{"VBZ"},
"atom-like":	{"JJ"},
"atom-smashing":	{"NN"},
"atomic":	{"JJ"},
"atomisation":	{"NN"},
"atomise":	{"VB","VBP"},
"atomised":	{"VBD","VBN"},
"atomiser":	{"NN"},
"atomisers":	{"NNS"},
"atomises":	{"VBZ"},
"atomising":	{"VBG"},
"atomism":	{"NN"},
"atomistic":	{"JJ"},
"atomistical":	{"JJ"},
"atomization":	{"NN"},
"atomize":	{"VB","VBP"},
"atomized":	{"VBD","VBN"},
"atomizer":	{"NN"},
"atomizers":	{"NNS"},
"atomizes":	{"VBZ"},
"atomizing":	{"VBG"},
"atoms":	{"NNS"},
"atonal":	{"JJ"},
"atonalism":	{"NN"},
"atonalistic":	{"JJ"},
"atonality":	{"NN"},
"atonally":	{"RB"},
"atone":	{"VB","VBP"},
"atoned":	{"VBD","VBN"},
"atonement":	{"NN"},
"atones":	{"VBZ"},
"atonia":	{"NN"},
"atonic":	{"JJ"},
"atonicity":	{"NN"},
"atoning":	{"VBG"},
"atony":	{"NN"},
"atop":	{"IN"},
"atopognosia":	{"NN"},
"atopognosis":	{"NN"},
"atopy":	{"NN"},
"atorvastatin":	{"NN"},
"atoxic":	{"JJ"},
"atp":	{"NN"},
"atrabilious":	{"JJ"},
"atrazine":	{"NN"},
"atresia":	{"NN"},
"atreus":	{"NN"},
"atrial":	{"JJ","NN"},
"atrichornis":	{"NN"},
"atrichornithidae":	{"NN"},
"atrioventricular":	{"JJ"},
"atrip":	{"JJ"},
"atriplex":	{"NN"},
"atrium":	{"NN"},
"atrocious":	{"JJ"},
"atrociously":	{"RB"},
"atrociousness":	{"NN"},
"atrocities":	{"NNS"},
"atrocity":	{"NN"},
"atromid-s":	{"NN"},
"atropa":	{"NN"},
"atrophedema":	{"NN"},
"atrophic":	{"JJ"},
"atrophied":	{"VBD","VBN"},
"atrophies":	{"VBZ"},
"atrophy":	{"NN","VB","VBP"},
"atrophying":	{"VBG"},
"atropidae":	{"NN"},
"atropine":	{"NN"},
"atropos":	{"NNS"},
"atrovent":	{"NN"},
"atrun":	{"JJ"},
"atsugewi":	{"NN"},
"att":	{"NN"},
"attacapa":	{"NN"},
"attacapan":	{"NN"},
"attach":	{"VB","VBP"},
"attachable":	{"JJ"},
"attache":	{"NN"},
"attached":	{"VBN","VBD","JJ"},
"attaches":	{"VBZ"},
"attaching":	{"VBG"},
"attachment":	{"NN"},
"attachments":	{"NNS"},
"attack":	{"NN","VB","VBP"},
"attacked":	{"VBN","VBD"},
"attacker":	{"NN"},
"attackers":	{"NNS"},
"attacking":	{"VBG","NN"},
"attacks":	{"NNS","VBZ"},
"attactive":	{"JJ"},
"attain":	{"VB","VBP"},
"attainability":	{"NN"},
"attainable":	{"JJ"},
"attainableness":	{"NN"},
"attainder":	{"NN"},
"attained":	{"VBD","VBN"},
"attaining":	{"VBG"},
"attainment":	{"NN"},
"attainments":	{"NNS"},
"attains":	{"VBZ"},
"attaint":	{"VB","VBP","NN"},
"attainted":	{"VBD","VBN"},
"attainting":	{"VBG"},
"attaints":	{"VBZ"},
"attalea":	{"NN"},
"attar":	{"NN"},
"attarcks":	{"NNS"},
"attemper":	{"VB"},
"attempt":	{"NN","VB","VBP"},
"attempted":	{"VBD","VBN","JJ"},
"attempter":	{"NN"},
"attempting":	{"VBG"},
"attempts":	{"NNS","VBZ"},
"attend":	{"VB","VBP"},
"attendance":	{"NN"},
"attendances":	{"NNS"},
"attendant":	{"NN","JJ"},
"attendants":	{"NNS"},
"attended":	{"VBD","VBN"},
"attendee":	{"NN"},
"attendees":	{"NNS"},
"attendent":	{"NN"},
"attendents":	{"NNS"},
"attender":	{"NN"},
"attenders":	{"NNS"},
"attending":	{"VBG"},
"attends":	{"VBZ"},
"attention":	{"NN"},
"attention-getting":	{"JJ"},
"attention-grabbing":	{"JJ"},
"attentional":	{"JJ"},
"attentions":	{"NNS"},
"attentive":	{"JJ","NN"},
"attentively":	{"RB"},
"attentiveness":	{"NN"},
"attenuate":	{"VB","VBP"},
"attenuated":	{"VBD","VBN"},
"attenuates":	{"VBZ"},
"attenuating":	{"VBG"},
"attenuation":	{"NN"},
"attenuator":	{"NN"},
"attest":	{"VB","VBP"},
"attestant":	{"NN"},
"attestation":	{"NN"},
"attestator":	{"NN"},
"attested":	{"VBD","VBN","JJ"},
"attester":	{"NN"},
"attesting":	{"VBG"},
"attestor":	{"NN"},
"attests":	{"VBZ"},
"attic":	{"NN","JJ"},
"attica":	{"NN"},
"attics":	{"NNS"},
"atticus":	{"NN"},
"attila":	{"NN"},
"attilio":	{"NN"},
"attire":	{"NN","VB","VBP"},
"attired":	{"JJ","VBD","VBN"},
"attires":	{"VBZ"},
"attiring":	{"VBG"},
"attis":	{"NN"},
"attitude":	{"NN"},
"attitudes":	{"NNS"},
"attitudinal":	{"JJ","NN"},
"attitudinise":	{"VB"},
"attitudinize":	{"VB"},
"attitudinizing":	{"NN"},
"attlee":	{"NN"},
"attorn":	{"VB"},
"attorney":	{"NN"},
"attorney-client":	{"JJ"},
"attorney-consultant":	{"NN"},
"attorney-disciplinary":	{"JJ"},
"attorneys":	{"NNS"},
"attorneyship":	{"NN"},
"attosecond":	{"NN"},
"attract":	{"VB","VBP"},
"attractable":	{"JJ"},
"attractant":	{"NN"},
"attracted":	{"VBN","VBD"},
"attracter":	{"NN"},
"attracting":	{"VBG"},
"attraction":	{"NN"},
"attractions":	{"NNS"},
"attractive":	{"JJ"},
"attractively":	{"RB"},
"attractiveness":	{"NN"},
"attractor":	{"NN"},
"attracts":	{"VBZ"},
"attributable":	{"JJ"},
"attribute":	{"VB","NN","VBP"},
"attributed":	{"VBD","VBN"},
"attributes":	{"VBZ","NNS"},
"attributing":	{"VBG"},
"attribution":	{"NN"},
"attributions":	{"NNS"},
"attributive":	{"JJ"},
"attributively":	{"RB"},
"attrited":	{"JJ"},
"attrition":	{"NN"},
"attritional":	{"JJ"},
"attune":	{"VB","VBP"},
"attuned":	{"VBD","VBN","JJ"},
"attunes":	{"VBZ"},
"attuning":	{"VBG"},
"atune":	{"NN"},
"atwood":	{"NN"},
"atypical":	{"JJ","NN"},
"atypicality":	{"NN"},
"atypically":	{"JJ","NN"},
"au":	{"NN"},
"auberge":	{"NN"},
"aubergine":	{"NN"},
"auburn":	{"NN","JJ"},
"auc":	{"NN"},
"auchincloss":	{"NN"},
"auckland":	{"NN"},
"auction":	{"NN","VB","VBP"},
"auction-fee":	{"JJ"},
"auction-house":	{"NN"},
"auctioned":	{"VBD","VBN"},
"auctioneer":	{"NN"},
"auctioneers":	{"NNS"},
"auctioning":	{"VBG"},
"auctions":	{"NNS","VBZ"},
"auctorial":	{"JJ"},
"aucuba":	{"NN"},
"audacious":	{"JJ"},
"audaciously":	{"RB"},
"audaciousness":	{"NN"},
"audacity":	{"NN"},
"audad":	{"NN"},
"auden":	{"NN"},
"audenesque":	{"JJ"},
"audibility":	{"NN"},
"audible":	{"JJ","NN"},
"audibleness":	{"NN"},
"audibly":	{"RB"},
"audience":	{"NN","NNS"},
"audience-friendly":	{"JJ"},
"audiences":	{"NNS"},
"audile":	{"JJ","NN"},
"audio":	{"JJ","NN"},
"audio-lingual":	{"JJ"},
"audio-specialty":	{"NN"},
"audio-visual":	{"JJ","NN"},
"audiocassette":	{"NN"},
"audiocassettes":	{"NNS"},
"audiogram":	{"NN"},
"audiology":	{"NN"},
"audiometer":	{"NN"},
"audiometric":	{"JJ"},
"audiometry":	{"NN"},
"audiophiles":	{"NNS"},
"audiotape":	{"NN","VB","VBP"},
"audiotaped":	{"VBD","VBN"},
"audiotapes":	{"NNS","VBZ"},
"audiotaping":	{"VBG"},
"audiotex":	{"NN"},
"audiovisual":	{"JJ","NN"},
"audit":	{"NN","VB","VBP"},
"audited":	{"VBN","VBD"},
"auditing":	{"VBG"},
"audition":	{"NN","VB","VBP"},
"auditioned":	{"VBD","VBN"},
"auditioning":	{"VBG"},
"auditions":	{"NNS","VBZ"},
"auditive":	{"JJ"},
"auditor":	{"NN"},
"auditor-general":	{"NN"},
"auditoria":	{"NNS"},
"auditorium":	{"NN"},
"auditoriums":	{"NNS"},
"auditors":	{"NNS"},
"auditory":	{"JJ","NN"},
"audits":	{"NNS","VBZ"},
"audivi":	{"FW"},
"audrey":	{"NN"},
"audubon":	{"NN"},
"auf":	{"NN"},
"aug":	{"NN"},
"augean":	{"JJ"},
"augeas":	{"NNS"},
"augen":	{"FW"},
"augend":	{"NN"},
"auger":	{"NN"},
"aught":	{"PRP"},
"augite":	{"NN"},
"augitic":	{"JJ"},
"augment":	{"VB","VBP"},
"augmentation":	{"NN"},
"augmentative":	{"JJ"},
"augmented":	{"VBD","VBN","JJ"},
"augmentin":	{"NN"},
"augmenting":	{"VBG"},
"augments":	{"VBZ"},
"augur":	{"VB","VBP","NN"},
"augured":	{"VBD","VBN"},
"auguries":	{"NNS"},
"auguring":	{"VBG"},
"augurs":	{"VBZ","NNS"},
"augury":	{"NN"},
"augusta":	{"NN"},
"augustan":	{"JJ"},
"augustine":	{"NN"},
"augustinian":	{"NN"},
"augustus":	{"NN"},
"auk":	{"NN"},
"auklet":	{"NN"},
"aulacorhyncus":	{"NN"},
"auld":	{"NN","JJ"},
"aulostomidae":	{"NN"},
"aulostomus":	{"NN"},
"aum":	{"NN"},
"aung":	{"NN"},
"aunt":	{"NN"},
"auntie":	{"NN"},
"aunts":	{"NNS"},
"aunty":	{"NN"},
"aura":	{"NN"},
"aural":	{"JJ","NN"},
"aurally":	{"RB"},
"aureate":	{"JJ"},
"aurelius":	{"NN"},
"aureolaria":	{"NN"},
"aureole":	{"NN"},
"aureomycin":	{"NN"},
"aureus":	{"NN"},
"auric":	{"JJ"},
"auricle":	{"NN"},
"auricula":	{"NN"},
"auricular":	{"JJ"},
"auriculare":	{"NN"},
"auricularia":	{"NN"},
"auriculariaceae":	{"NN"},
"auriculariales":	{"NNS"},
"auriculate":	{"JJ"},
"auriculated":	{"JJ"},
"auriculectomy":	{"NN"},
"auriculoventricular":	{"JJ"},
"auriferous":	{"JJ"},
"auriform":	{"JJ"},
"aurify":	{"VB"},
"auriga":	{"NN"},
"auriparus":	{"NN"},
"auriscope":	{"NN"},
"aurochs":	{"NN","NNS"},
"aurora":	{"NN"},
"auroral":	{"JJ"},
"aurorean":	{"JJ"},
"auroscope":	{"NN"},
"aurous":	{"JJ"},
"auschwitz":	{"NN"},
"auscultate":	{"VB"},
"auscultation":	{"NN"},
"auscultatory":	{"JJ"},
"auspex":	{"NN"},
"auspicate":	{"VB"},
"auspice":	{"NN"},
"auspices":	{"NNS"},
"auspicious":	{"JJ"},
"auspiciously":	{"RB"},
"auspiciousness":	{"NN"},
"austen":	{"NN"},
"austenite":	{"NN"},
"austenitic":	{"JJ"},
"austere":	{"JJ"},
"austerely":	{"RB"},
"austereness":	{"NN"},
"austerity":	{"NN"},
"austerlitz":	{"NN"},
"austral":	{"JJ","NN"},
"australites":	{"NNS"},
"australopithecine":	{"JJ","NN"},
"australopithecus":	{"NNS"},
"austria":	{"NN"},
"austria-hungary":	{"NN"},
"austrian":	{"JJ","NN"},
"austrian-argentine":	{"JJ"},
"austro-asiatic":	{"NN"},
"austrocedrus":	{"NN"},
"austronesia":	{"NN"},
"austronesian":	{"JJ","NN"},
"austrotaxus":	{"NN"},
"autacoid":	{"NN"},
"autacoidal":	{"JJ"},
"autarchic":	{"JJ"},
"autarchical":	{"JJ"},
"autarchy":	{"NN"},
"autarkic":	{"JJ"},
"autarkical":	{"JJ"},
"autarky":	{"NN"},
"auteur":	{"NN"},
"authentic":	{"JJ"},
"authentically":	{"RB"},
"authenticate":	{"VB","VBP"},
"authenticated":	{"VBD","VBN"},
"authenticates":	{"VBZ"},
"authenticating":	{"VBG"},
"authentication":	{"NN"},
"authenticator":	{"NN"},
"authenticity":	{"NN"},
"author":	{"NN","VB","VBP"},
"authored":	{"VBD","VBN"},
"authoress":	{"NN"},
"authorial":	{"JJ","NN"},
"authoring":	{"VBG","NN"},
"authorisation":	{"NN"},
"authorisations":	{"NNS"},
"authorise":	{"VB","VBP"},
"authorised":	{"VBD","VBN"},
"authoriser":	{"NN"},
"authorises":	{"VBZ"},
"authorising":	{"VBG"},
"authoritarian":	{"JJ","NN"},
"authoritarianism":	{"NN"},
"authoritative":	{"JJ","NN"},
"authoritatively":	{"RB"},
"authorities":	{"NNS"},
"authority":	{"NN"},
"authorization":	{"NN"},
"authorizations":	{"NNS"},
"authorize":	{"VB","VBP"},
"authorized":	{"VBD","VBN","JJ"},
"authorizer":	{"NN"},
"authorizes":	{"VBZ"},
"authorizing":	{"VBG"},
"authors":	{"NNS","VBZ"},
"authorship":	{"NN"},
"autions":	{"NNS"},
"autism":	{"NN"},
"autistic":	{"JJ"},
"auto":	{"NN"},
"auto-assembly":	{"NN"},
"auto-buying":	{"NN"},
"auto-changer":	{"NN"},
"auto-da-fe":	{"NN"},
"auto-dealer":	{"NN"},
"auto-emission":	{"NN"},
"auto-emissions":	{"NNS"},
"auto-financing":	{"NN"},
"auto-immune":	{"JJ"},
"auto-industry":	{"NN","JJ"},
"auto-insurance":	{"NN"},
"auto-limitation":	{"NN"},
"auto-loaders":	{"NNS"},
"auto-loan":	{"JJ"},
"auto-maker":	{"NN"},
"auto-making":	{"NN"},
"auto-market":	{"NN"},
"auto-mechanic":	{"NN"},
"auto-obscuria":	{"NN"},
"auto-parts":	{"JJ","NNS"},
"auto-repair":	{"JJ"},
"auto-safety":	{"JJ"},
"auto-sales":	{"NNS"},
"auto-strop":	{"JJ"},
"auto-suggestion":	{"NN"},
"autoantibody":	{"NN"},
"autobahn":	{"NN"},
"autobiographer":	{"NN"},
"autobiographers":	{"NNS"},
"autobiographic":	{"JJ"},
"autobiographical":	{"JJ"},
"autobiographies":	{"NNS"},
"autobiography":	{"NN"},
"autobus":	{"NNS"},
"autocatalysis":	{"NN"},
"autocatalytic":	{"JJ"},
"autochthon":	{"NN"},
"autochthonal":	{"JJ"},
"autochthonic":	{"JJ"},
"autochthonous":	{"JJ"},
"autochthony":	{"NN"},
"autoclave":	{"NN","VB","VBP"},
"autoclaved":	{"VBD","VBN"},
"autoclaves":	{"NNS","VBZ"},
"autoclaving":	{"VBG"},
"autocoder":	{"NN"},
"autocoid":	{"NN"},
"autocollimator":	{"NN"},
"autocorrect":	{"NN","VB","VBP"},
"autocorrected":	{"VBD","VBN"},
"autocorrecting":	{"VBG"},
"autocorrects":	{"VBZ"},
"autocracies":	{"NNS"},
"autocracy":	{"NN"},
"autocrat":	{"NN"},
"autocratic":	{"JJ"},
"autocratically":	{"RB"},
"autocrats":	{"NNS"},
"autocue":	{"NN"},
"autodidact":	{"NN"},
"autodidactic":	{"JJ"},
"autoecious":	{"JJ"},
"autoed":	{"VBD","VBN"},
"autoerotic":	{"JJ"},
"autoeroticism":	{"NN"},
"autoerotism":	{"NN"},
"autofluorescence":	{"NN"},
"autofluorescent":	{"JJ"},
"autofocus":	{"NN"},
"autogamic":	{"JJ"},
"autogamous":	{"JJ"},
"autogamy":	{"NN"},
"autogenesis":	{"NN"},
"autogenetic":	{"JJ"},
"autogenic":	{"JJ"},
"autogenics":	{"NN"},
"autogenous":	{"JJ"},
"autogeny":	{"NN"},
"autogiro":	{"NN"},
"autograft":	{"NN"},
"autograph":	{"NN","VB","VBP"},
"autographed":	{"VBD","VBN"},
"autographer":	{"NN"},
"autographic":	{"JJ"},
"autographing":	{"VBG"},
"autographs":	{"NNS","VBZ"},
"autogyro":	{"NN"},
"autoicous":	{"JJ"},
"autoimmune":	{"JJ","NN"},
"autoimmunity":	{"NN"},
"autoing":	{"VBG"},
"autoinjector":	{"NN"},
"autolatry":	{"NN"},
"autoloader":	{"NN"},
"autoloading":	{"JJ"},
"autologous":	{"JJ"},
"autolysis":	{"NN"},
"autolytic":	{"JJ"},
"automaker":	{"NN"},
"automakers":	{"NNS"},
"automat":	{"NN"},
"automate":	{"VB","VBP"},
"automated":	{"VBD","VBN","JJ"},
"automated-pit-trading":	{"NN"},
"automated-quotation":	{"NN"},
"automated-teller":	{"JJ","NN"},
"automated-teller-machine":	{"JJ"},
"automated-trading":	{"NN"},
"automates":	{"VBZ"},
"automatic":	{"JJ","NN"},
"automatically":	{"RB"},
"automating":	{"VBG"},
"automation":	{"NN"},
"automatise":	{"VB"},
"automatism":	{"NN"},
"automatize":	{"VB","VBP"},
"automatized":	{"VBD","VBN"},
"automatizes":	{"VBZ"},
"automatizing":	{"VBG"},
"automaton":	{"NN"},
"automatonlike":	{"JJ"},
"automeris":	{"NN"},
"automobile":	{"NN"},
"automobile-manufacturing":	{"JJ"},
"automobile-parts":	{"JJ"},
"automobile-tire":	{"JJ"},
"automobiles":	{"NNS"},
"automobilist":	{"NN"},
"automotive":	{"JJ"},
"automotive-industry":	{"NN"},
"automotive-lighting":	{"JJ","NN"},
"automotive-parts":	{"JJ"},
"automotive-product":	{"NN"},
"automysophobia":	{"NN"},
"autonavigator":	{"NN"},
"autonomic":	{"JJ"},
"autonomic-somatic":	{"JJ"},
"autonomous":	{"JJ"},
"autonomously":	{"RB"},
"autonomy":	{"NN","JJ"},
"autophyte":	{"NN"},
"autophytic":	{"JJ"},
"autopilot":	{"NN"},
"autoplastic":	{"JJ"},
"autoplasty":	{"NN"},
"autopsied":	{"VBN"},
"autopsies":	{"NNS"},
"autopsy":	{"NN"},
"autoradiograph":	{"NN"},
"autoradiographic":	{"JJ"},
"autoradiography":	{"NN"},
"autoregulation":	{"NN"},
"autos":	{"NNS","VBZ"},
"autosemantic":	{"JJ"},
"autosexing":	{"NN"},
"autosomal":	{"JJ"},
"autosome":	{"NN"},
"autostrada":	{"NN"},
"autosuggestibility":	{"NN"},
"autosuggestion":	{"NN"},
"autotelic":	{"JJ"},
"autotelism":	{"NN"},
"autotomic":	{"JJ"},
"autotomise":	{"VB"},
"autotomize":	{"VB"},
"autotomy":	{"NN"},
"autotroph":	{"NN"},
"autotrophic":	{"JJ"},
"autotype":	{"NN"},
"autotypic":	{"JJ"},
"autotypy":	{"NN"},
"autumn":	{"NN"},
"autumn-blooming":	{"JJ"},
"autumn-flowering":	{"JJ"},
"autumn-touched":	{"JJ"},
"autumnal":	{"JJ","NN"},
"autumns":	{"NNS"},
"auvergne":	{"NN"},
"aux":	{"NN"},
"auxesis":	{"NN"},
"auxetic":	{"JJ"},
"auxiliaries":	{"NNS"},
"auxiliary":	{"JJ","NN"},
"auxin":	{"NN"},
"auxinic":	{"JJ"},
"av":	{"NN"},
"ava":	{"NN"},
"avadavat":	{"NN"},
"avahi":	{"NN"},
"avail":	{"NN","VB","VBP"},
"availabilities":	{"NNS"},
"availability":	{"NN"},
"available":	{"JJ"},
"availableness":	{"NN"},
"availed":	{"VBD","VBN"},
"availing":	{"VBG"},
"avails":	{"VBZ"},
"avalanche":	{"NN"},
"avalanches":	{"NNS"},
"avalanching":	{"VBG"},
"avaliable":	{"JJ"},
"avalokiteshvara":	{"NN"},
"avalokitesvara":	{"NN"},
"avalon":	{"NN"},
"avant":	{"JJ","NN"},
"avant-garde":	{"JJ","NN"},
"avaram":	{"NN"},
"avarice":	{"NN"},
"avaricious":	{"JJ"},
"avariciously":	{"RB"},
"avariciousness":	{"NN"},
"avaritia":	{"NN"},
"avascular":	{"JJ"},
"avatar":	{"NN"},
"avec":	{"NNP","FW"},
"avellan":	{"JJ"},
"avellane":	{"JJ"},
"avena":	{"NN"},
"avenge":	{"VB","VBP"},
"avenged":	{"VBD","VBN"},
"avenger":	{"NN"},
"avenges":	{"VBZ"},
"avenging":	{"VBG"},
"avens":	{"NN","NNS"},
"aventail":	{"NN"},
"aventurine":	{"NN"},
"avenue":	{"NN"},
"avenues":	{"NNS"},
"aver":	{"VB","VBP"},
"average":	{"JJ","NN","VB","VBP"},
"averaged":	{"VBD","VBN"},
"averageness":	{"NN"},
"averages":	{"NNS","VBZ"},
"averaging":	{"VBG"},
"averment":	{"NN"},
"averred":	{"VBD","VBN"},
"averrhoa":	{"NN"},
"averring":	{"VBG"},
"averroes":	{"NNS"},
"avers":	{"VBZ"},
"averse":	{"JJ","NN"},
"aversion":	{"NN"},
"aversive":	{"JJ"},
"avert":	{"VB","VBP"},
"avertable":	{"JJ"},
"averted":	{"VBD","VBN"},
"avertible":	{"JJ"},
"averting":	{"VBG"},
"averts":	{"VBZ"},
"aves":	{"NN"},
"avesta":	{"NN"},
"avestan":	{"JJ","NN"},
"avian":	{"JJ","NN"},
"avianise":	{"VB"},
"avianize":	{"VB"},
"aviary":	{"NN","JJ"},
"aviate":	{"VB"},
"aviation":	{"NN"},
"aviation-services":	{"NNS","JJ"},
"aviator":	{"NN"},
"aviators":	{"NNS"},
"aviatress":	{"NN"},
"aviatrix":	{"NN"},
"avicenna":	{"NN"},
"avicennia":	{"NN"},
"avicenniaceae":	{"NN"},
"avid":	{"JJ","NN"},
"avidity":	{"NN"},
"avidly":	{"RB"},
"avidness":	{"NN"},
"avifauna":	{"NN"},
"avifaunal":	{"JJ"},
"avifaunistic":	{"JJ"},
"avignon":	{"NN"},
"avionic":	{"JJ"},
"avionics":	{"NN"},
"avions":	{"FW"},
"avirulent":	{"JJ"},
"avitaminosis":	{"NN"},
"avitaminotic":	{"JJ"},
"avo":	{"NN"},
"avocado":	{"NN"},
"avocados":	{"NNS"},
"avocation":	{"NN"},
"avocational":	{"JJ"},
"avocet":	{"NN"},
"avogadro":	{"NN"},
"avoid":	{"VB","VBP"},
"avoidable":	{"JJ"},
"avoidance":	{"NN"},
"avoided":	{"VBN","VBD"},
"avoiding":	{"VBG"},
"avoids":	{"VBZ"},
"avoirdupois":	{"NN"},
"avouch":	{"VB"},
"avouchment":	{"NN"},
"avow":	{"VB","VBP"},
"avowal":	{"NN"},
"avowed":	{"JJ","VBD","VBN"},
"avowedly":	{"RB"},
"avower":	{"NN"},
"avowing":	{"VBG"},
"avows":	{"VBZ"},
"avulse":	{"VB"},
"avulsion":	{"NN"},
"avuncular":	{"JJ"},
"aw":	{"UH"},
"awa":	{"RB"},
"await":	{"VB","VBP"},
"awaited":	{"VBD","VBN"},
"awaiting":	{"VBG"},
"awaits":	{"VBZ"},
"awake":	{"JJ","VB","VBP"},
"awaked":	{"VBD","VBN"},
"awaken":	{"VB","VBP"},
"awakened":	{"VBD","VBN","JJ"},
"awakening":	{"NN","VBG"},
"awakenings":	{"NNS"},
"awakens":	{"VBZ"},
"awakes":	{"VBZ"},
"awaking":	{"VBG"},
"award":	{"NN","VB","VBP"},
"award-winning":	{"JJ"},
"awarded":	{"VBN","VBD"},
"awarding":	{"VBG"},
"awards":	{"NNS","VBZ"},
"aware":	{"JJ"},
"awareness":	{"NN"},
"awash":	{"JJ","RB"},
"away":	{"RB","JJ","RP"},
"away-from-home":	{"JJ"},
"awaye":	{"RB"},
"awayness":	{"NN"},
"awe":	{"VB","VBP","NN"},
"awe-inspiring":	{"JJ"},
"aweary":	{"JJ"},
"awed":	{"JJ","VBD","VBN"},
"aweigh":	{"JJ"},
"aweless":	{"JJ"},
"awes":	{"VBZ","NNS"},
"awesome":	{"JJ"},
"awestricken":	{"JJ"},
"awestruck":	{"JJ","NN"},
"awful":	{"JJ","RB"},
"awfully":	{"RB"},
"awfulness":	{"NN"},
"awheel":	{"RB"},
"awhile":	{"RB"},
"awing":	{"JJ","VBG"},
"awkward":	{"JJ"},
"awkwardly":	{"RB"},
"awkwardness":	{"NN"},
"awl":	{"NN"},
"awl-shaped":	{"JJ"},
"awless":	{"JJ"},
"awlwort":	{"NN"},
"awn":	{"NN"},
"awned":	{"JJ"},
"awning":	{"NN"},
"awninged":	{"JJ"},
"awnings":	{"NNS"},
"awnless":	{"JJ"},
"awny":	{"JJ"},
"awoke":	{"VBD"},
"awoken":	{"VBN"},
"awol":	{"JJ","NN"},
"awry":	{"JJ","RB"},
"ax":	{"NN","VB","VBP"},
"axe":	{"VB","VBP","NN"},
"axed":	{"VBD","VBN"},
"axel":	{"NN"},
"axelrod":	{"NN"},
"axenic":	{"JJ"},
"axerophthol":	{"NN"},
"axes":	{"NNS","VBZ"},
"axial":	{"JJ","NN"},
"axially":	{"RB"},
"axil":	{"NN"},
"axile":	{"JJ"},
"axilla":	{"NN"},
"axillary":	{"JJ","NN"},
"axing":	{"VBG"},
"axiological":	{"JJ"},
"axiology":	{"NN"},
"axiom":	{"NN"},
"axiomatic":	{"JJ"},
"axiomatical":	{"JJ"},
"axiomatically":	{"RB"},
"axioms":	{"NNS"},
"axis":	{"NN"},
"axle":	{"NN"},
"axle-breaking":	{"JJ"},
"axles":	{"NNS"},
"axletree":	{"NN"},
"axolemma":	{"NN"},
"axolotl":	{"NN"},
"axon":	{"NN"},
"axonal":	{"JJ"},
"axone":	{"NN"},
"axseed":	{"NN"},
"ay":	{"UH","RB","NN"},
"aya":	{"NN"},
"ayah":	{"NN"},
"ayala":	{"NN"},
"ayapana":	{"NN"},
"ayatollah":	{"NN"},
"aye":	{"UH","RB","NN"},
"aye-aye":	{"NN"},
"ayer":	{"NN"},
"ayes":	{"NNS"},
"ayin":	{"NN"},
"ayni":	{"NNS"},
"ayr":	{"NN"},
"ayrshire":	{"NN"},
"aythya":	{"NN"},
"ayurveda":	{"NN"},
"az":	{"NN"},
"azactam":	{"NN"},
"azadirachta":	{"NN"},
"azadirachtin":	{"NN"},
"azalea":	{"NN"},
"azaleas":	{"NNS"},
"azaleastrum":	{"NN"},
"azathioprine":	{"NN"},
"azedarach":	{"NN"},
"azederach":	{"NN"},
"azerbaijan":	{"NN"},
"azerbaijani":	{"JJ","NN"},
"azerbajdzhan":	{"NN"},
"azeri":	{"NN"},
"azide":	{"NN"},
"azido":	{"JJ"},
"azimuth":	{"NN"},
"azimuthal":	{"JJ"},
"azithromycin":	{"NN"},
"aziz":	{"NN"},
"azo":	{"JJ"},
"azoic":	{"JJ"},
"azoimide":	{"NN"},
"azolla":	{"NN"},
"azollaceae":	{"NN"},
"azonal":	{"JJ"},
"azonic":	{"JJ"},
"azores":	{"NNS"},
"azotaemia":	{"NN"},
"azote":	{"NN"},
"azotemia":	{"NN"},
"azotemic":	{"JJ"},
"azotic":	{"JJ"},
"azoturia":	{"NN"},
"azt":	{"NN"},
"azt-resistant":	{"JJ"},
"azt-treated":	{"JJ"},
"aztecan":	{"NN"},
"aztreonam":	{"NN"},
"azure":	{"JJ","NN"},
"azurite":	{"NN"},
"azygos":	{"JJ"},
"azygous":	{"JJ"},
"azymia":	{"NN"},
"b":	{"NN","SYM","LS"},
"b-52":	{"NN"},
"b-Includes":	{"VBZ"},
"b-Percent":	{"NN"},
"b-cell":	{"NN"},
"b-cells":	{"NNS"},
"b-flat":	{"NN"},
"b-girl":	{"NN"},
"b-horizon":	{"NN"},
"b-includes":	{"VBZ"},
"b-meson":	{"NN"},
"b-movie":	{"NN"},
"b-percent":	{"NN"},
"b-plane":	{"NN"},
"b-reflects":	{"VBZ"},
"b-scale":	{"NN"},
"b.c.":	{"RB"},
"b.c.e.":	{"RB"},
"b.o.":	{"NN"},
"b.t.u.":	{"NN"},
"b.th.u.":	{"NN"},
"ba":	{"NN"},
"ba-a-a":	{"UH"},
"baa":	{"NN","VBP","VB"},
"baa-lamb":	{"NN"},
"baaed":	{"VBD","VBN"},
"baaing":	{"VBG"},
"baal":	{"NN"},
"baas":	{"NNS","VBZ"},
"baba":	{"NN"},
"babar":	{"NN"},
"babassu":	{"NN"},
"babbino":	{"FW"},
"babbiting":	{"NN"},
"babbitry":	{"NN"},
"babbitted":	{"VBD","VBN"},
"babbitting":	{"VBG"},
"babbitts":	{"VBZ"},
"babble":	{"NN","VB","VBP"},
"babbled":	{"VBD","VBN"},
"babbler":	{"NN"},
"babblers":	{"NNS"},
"babbles":	{"VBZ"},
"babbling":	{"VBG"},
"babcock":	{"NN"},
"babe":	{"NN"},
"babel":	{"NN"},
"babelike":	{"JJ"},
"babelists":	{"NNS"},
"babes":	{"NNS"},
"babesiidae":	{"NN"},
"babied":	{"VBD","VBN"},
"babies":	{"NNS","VBZ"},
"babies'-breath":	{"NN"},
"babinski":	{"NN"},
"babiroussa":	{"NN"},
"babirusa":	{"NN"},
"babirussa":	{"NN"},
"babka":	{"NN"},
"baboo":	{"NN"},
"baboon":	{"NN"},
"baboonish":	{"JJ"},
"baboons":	{"NNS"},
"babu":	{"NN"},
"babushka":	{"NN"},
"baby":	{"NN","VB","VBP","JJ"},
"baby-boom":	{"NN"},
"baby-boomers":	{"NNS"},
"baby-faced":	{"JJ"},
"baby-food":	{"JJ"},
"baby-like":	{"RB"},
"baby-products":	{"JJ"},
"baby-sat":	{"VBD","VBN"},
"baby-sit":	{"VB","VBP"},
"baby-sits":	{"VBZ"},
"baby-sitter":	{"NN"},
"baby-sitting":	{"VBG","NN","JJ"},
"baby-walker":	{"NN"},
"baby-wise":	{"RB"},
"babyhood":	{"NN"},
"babying":	{"VBG"},
"babyish":	{"JJ"},
"babylon":	{"NN"},
"babylonia":	{"NN"},
"babyminder":	{"NN"},
"babyrousa":	{"NN"},
"babysat":	{"VBD","VBN"},
"babysit":	{"VB","VBP"},
"babysitter":	{"NN"},
"babysitters":	{"NNS"},
"babysitting":	{"NN","VBG"},
"babytalk":	{"NN"},
"bacca":	{"NN"},
"baccalaureate":	{"NN"},
"baccarat":	{"NN"},
"baccate":	{"JJ"},
"bacchanal":	{"NN"},
"bacchanalia":	{"NNS"},
"bacchanalian":	{"JJ"},
"bacchanals":	{"NNS"},
"bacchant":	{"NN"},
"bacchante":	{"NN"},
"bacchantic":	{"JJ"},
"baccharis":	{"NN"},
"bacchic":	{"JJ"},
"bacchus":	{"NN"},
"bacciferous":	{"JJ"},
"baccivorous":	{"JJ"},
"baccy":	{"NN"},
"bach":	{"NN","VB"},
"bachelor":	{"NN"},
"bachelor-at-arms":	{"NNS"},
"bachelor-type":	{"JJ"},
"bachelored":	{"VBD","VBN"},
"bachelorette":	{"NN"},
"bachelorhood":	{"NN"},
"bacheloring":	{"VBG"},
"bachelors":	{"NNS","VBZ"},
"baci":	{"NNS"},
"bacillaceae":	{"NN"},
"bacillar":	{"JJ"},
"bacillariophyceae":	{"NN"},
"bacillary":	{"JJ"},
"bacilli":	{"NNS"},
"bacilliform":	{"JJ"},
"bacillus":	{"NN"},
"bacitracin":	{"NN"},
"back":	{"RB","NN","RP","VB","VBP","JJ"},
"back-alley":	{"JJ"},
"back-blast":	{"NN"},
"back-breaker":	{"NN"},
"back-breakers":	{"NNS"},
"back-breaking":	{"JJ"},
"back-channel":	{"JJ"},
"back-dating":	{"VBG"},
"back-disability":	{"NN"},
"back-door":	{"JJ"},
"back-end":	{"JJ"},
"back-formation":	{"NN"},
"back-geared":	{"JJ"},
"back-heel":	{"NN","VB","VBP"},
"back-heeled":	{"VBD","VBN"},
"back-heeling":	{"VBG"},
"back-heels":	{"NNS","VBZ"},
"back-issue":	{"JJ"},
"back-lighted":	{"JJ"},
"back-number":	{"NN"},
"back-of-the-envelope":	{"JJ"},
"back-office":	{"NN","JJ"},
"back-offices":	{"NNS"},
"back-on-terra-firma":	{"JJ"},
"back-pain":	{"NN"},
"back-pass":	{"NN"},
"back-passes":	{"NNS"},
"back-pay":	{"NN"},
"back-room":	{"NN"},
"back-slapping":	{"JJ"},
"back-to-back":	{"JJ","RB","NN"},
"back-to-school":	{"JJ"},
"back-up":	{"NN","JJ"},
"back-ups":	{"NNS"},
"back-yard":	{"JJ","NN"},
"backache":	{"NN"},
"backband":	{"NN"},
"backbeat":	{"NN"},
"backbench":	{"JJ"},
"backbencher":	{"NN"},
"backbenchers":	{"NNS"},
"backbend":	{"NN"},
"backbends":	{"NNS"},
"backbite":	{"VB"},
"backbiter":	{"NN"},
"backblast":	{"NN"},
"backboard":	{"NN"},
"backbone":	{"NN"},
"backbreaker":	{"NN"},
"backbreakers":	{"NNS"},
"backbreaking":	{"JJ"},
"backchat":	{"NN"},
"backcloth":	{"NN"},
"backcountry":	{"NN"},
"backcourt":	{"NN","RB","IN","JJ"},
"backcross":	{"VB","VBP","NN"},
"backcrossed":	{"VBD","VBN"},
"backcrosses":	{"VBZ"},
"backcrossing":	{"VBG"},
"backdate":	{"VB","VBP"},
"backdated":	{"VBD","VBN"},
"backdates":	{"VBZ"},
"backdating":	{"VBG"},
"backdoor":	{"JJ","NN"},
"backdown":	{"NN"},
"backdrop":	{"NN"},
"backed":	{"VBN","VBD","JJ"},
"backed-up":	{"JJ"},
"backend":	{"NN"},
"backer":	{"NN"},
"backers":	{"NNS"},
"backfield":	{"NN"},
"backfire":	{"VB","VBP"},
"backfired":	{"VBD","VBN"},
"backfires":	{"VBZ"},
"backfiring":	{"VBG"},
"backflips":	{"VBZ"},
"backflow":	{"NN"},
"backflowing":	{"NN"},
"backgammon":	{"NN"},
"background":	{"NN"},
"backgrounded":	{"VBD","VBN"},
"backgrounder":	{"NN"},
"backgrounding":	{"NN","VBG"},
"backgrounds":	{"NNS","VBZ"},
"backhand":	{"JJ","NN"},
"backhanded":	{"JJ"},
"backhander":	{"NN"},
"backhanders":	{"NNS"},
"backhands":	{"NNS"},
"backheel":	{"NN","VB","VBP"},
"backheeled":	{"VBD","VBN"},
"backheeling":	{"VBG"},
"backheels":	{"NNS","VBZ"},
"backhoe":	{"NN"},
"backhome":	{"NN"},
"backing":	{"NN","VBG","JJ"},
"backlash":	{"NN"},
"backless":	{"JJ"},
"backlighting":	{"NN"},
"backlit":	{"JJ"},
"backlog":	{"NN"},
"backlogged":	{"VBD","VBN"},
"backlogging":	{"VBG"},
"backlogs":	{"NNS","VBZ"},
"backlots":	{"NNS"},
"backmost":	{"JJ"},
"backpack":	{"NN","VB","VBP"},
"backpacked":	{"VBD","VBN"},
"backpacker":	{"NN"},
"backpackers":	{"NNS"},
"backpacking":	{"VBG","NN"},
"backpacks":	{"NNS","VBZ"},
"backpedal":	{"VB","VBP"},
"backpedaled":	{"VBD","VBN"},
"backpedaling":	{"VBG"},
"backpedalled":	{"VBD","VBN"},
"backpedalling":	{"VBG"},
"backpedals":	{"VBZ"},
"backplate":	{"NN"},
"backrest":	{"NN"},
"backroom":	{"NN"},
"backrooms":	{"NNS"},
"backrub":	{"NN"},
"backrubs":	{"NNS"},
"backs":	{"NNS","VBZ"},
"backsaw":	{"NN"},
"backscatter":	{"NN","VB","VBP"},
"backscattered":	{"VBD","VBN"},
"backscattering":	{"VBG"},
"backscatters":	{"NNS","VBZ"},
"backscratcher":	{"NN"},
"backseat":	{"NN"},
"backsheesh":	{"NN"},
"backside":	{"NN"},
"backsides":	{"NNS"},
"backslap":	{"NN","VB","VBP"},
"backslapped":	{"VBD","VBN"},
"backslapper":	{"NN"},
"backslapping":	{"VBG","NN"},
"backslaps":	{"NNS","VBZ"},
"backslid":	{"VBD","VBN"},
"backslidden":	{"VBN"},
"backslide":	{"VB","VBP"},
"backslider":	{"NN"},
"backsliders":	{"NNS"},
"backslides":	{"VBZ"},
"backsliding":	{"VBG"},
"backspace":	{"NN","VB"},
"backspacer":	{"NN"},
"backspin":	{"NN"},
"backstab":	{"VB","VBP"},
"backstabbed":	{"VBD","VBN"},
"backstabber":	{"NN"},
"backstabbers":	{"NNS"},
"backstabbing":	{"VBG","NN","JJ"},
"backstabs":	{"VBZ"},
"backstage":	{"RB","JJ"},
"backstair":	{"JJ"},
"backstairs":	{"JJ"},
"backstay":	{"NN"},
"backstitch":	{"NN","VB","VBP"},
"backstitched":	{"VBD","VBN"},
"backstitches":	{"NNS","VBZ"},
"backstitching":	{"VBG"},
"backstop":	{"NN","VB","VBP"},
"backstopped":	{"VBD","VBN"},
"backstopping":	{"VBG"},
"backstops":	{"NNS","VBZ"},
"backstories":	{"NNS"},
"backstory":	{"NN"},
"backstroke":	{"NN"},
"backstroker":	{"NN"},
"backswept":	{"JJ"},
"backswimmer":	{"NN"},
"backsword":	{"NN"},
"backtalk":	{"NN"},
"backtrack":	{"VB","VBP"},
"backtracked":	{"VBD","VBN"},
"backtracking":	{"VBG"},
"backtracks":	{"VBZ"},
"backup":	{"NN","JJ"},
"backups":	{"NNS"},
"backward":	{"RB","JJ"},
"backwardness":	{"NN"},
"backwards":	{"RB"},
"backwash":	{"NN"},
"backwater":	{"NN"},
"backwoods":	{"NNS"},
"backwoods-and-sand-hill":	{"JJ"},
"backwoodsman":	{"NN"},
"backyard":	{"NN","JJ"},
"backyards":	{"NNS"},
"bacon":	{"NN"},
"bacteremia":	{"NN"},
"bacteremic":	{"JJ"},
"bacteria":	{"NNS"},
"bacteria-based":	{"JJ"},
"bacteria-contaminated":	{"JJ"},
"bacteria-free":	{"JJ"},
"bacteriacide":	{"NN"},
"bacteriaemia":	{"NN"},
"bacterial":	{"JJ","NN"},
"bacterially":	{"RB"},
"bactericidal":	{"JJ"},
"bactericide":	{"NN"},
"bacteriemia":	{"NN"},
"bacteriochlorophyll":	{"NN"},
"bacterioid":	{"JJ"},
"bacterioidal":	{"JJ"},
"bacteriologic":	{"JJ"},
"bacteriological":	{"JJ"},
"bacteriologist":	{"NN"},
"bacteriology":	{"NN"},
"bacteriolysis":	{"NN"},
"bacteriolytic":	{"JJ"},
"bacteriophage":	{"NN"},
"bacteriophagic":	{"JJ"},
"bacteriophagous":	{"JJ"},
"bacteriostasis":	{"NN"},
"bacteriostat":	{"NN"},
"bacteriostatic":	{"JJ"},
"bacterise":	{"VB"},
"bacterium":	{"NN"},
"bacterize":	{"VB"},
"bacteroid":	{"JJ","NN"},
"bacteroidaceae":	{"NN"},
"bacteroidal":	{"JJ"},
"bacteroides":	{"NNS"},
"baculiform":	{"JJ"},
"bad":	{"JJ","RB","NN"},
"bad-cop":	{"JJ"},
"bad-debt":	{"JJ"},
"bad-expectations":	{"JJ"},
"bad-fitting":	{"JJ"},
"bad-law":	{"NN"},
"bad-mannered":	{"JJ"},
"bad-mouthed":	{"VBD","VBN"},
"bad-mouthing":	{"VBG"},
"bad-mouths":	{"VBZ"},
"bad-neighbor":	{"JJ"},
"bad-news":	{"JJ","NN"},
"bad-risk":	{"JJ"},
"bad-smelling":	{"JJ"},
"bad-tempered":	{"JJ"},
"badaga":	{"NN"},
"badass":	{"NN"},
"baddebt":	{"JJ"},
"baddeleyite":	{"NN"},
"baddie":	{"NN"},
"bade":	{"VBD"},
"bader":	{"NN"},
"badge":	{"VB","NN"},
"badge-toter":	{"NN"},
"badger":	{"NN","VB","VBP"},
"badgered":	{"VBD","VBN"},
"badgerer":	{"NN"},
"badgering":	{"VBG"},
"badgers":	{"NNS","VBZ"},
"badges":	{"NNS"},
"badinage":	{"NN"},
"badlands":	{"NNS"},
"badly":	{"RB"},
"badly-needed":	{"JJ"},
"badmen":	{"NNS"},
"badminton":	{"NN"},
"badmouth":	{"NN"},
"badmouthed":	{"VBD","VBN"},
"badmouthes":	{"VBZ"},
"badmouthing":	{"VBG"},
"badness":	{"NN"},
"bads":	{"NNS"},
"baeda":	{"NN"},
"baedeker":	{"NN"},
"baffle":	{"NN","VB","VBP"},
"baffled":	{"JJ","VBD","VBN"},
"bafflement":	{"NN"},
"baffles":	{"NNS","VBZ"},
"baffling":	{"JJ","VBG"},
"bag":	{"NN","VB","VBP"},
"bag-shaped":	{"JJ"},
"bagascosis":	{"NN"},
"bagasse":	{"NN"},
"bagassosis":	{"NN"},
"bagatelle":	{"NN"},
"bagdad":	{"NN"},
"bagel":	{"NN"},
"bagels":	{"NNS"},
"bagful":	{"NN"},
"baggage":	{"NN"},
"baggageman":	{"NN"},
"bagged":	{"VBD","VBN"},
"bagger":	{"NN"},
"baggier":	{"JJR"},
"baggiest":	{"JJS"},
"baggily":	{"RB"},
"bagginess":	{"NN"},
"bagging":	{"VBG"},
"baggy":	{"JJ"},
"baghdad":	{"NN"},
"bagman":	{"NN"},
"bagnio":	{"NN"},
"bagpipe":	{"JJ"},
"bagpiper":	{"NN"},
"bagpipes":	{"NNS"},
"bags":	{"NNS","VBZ"},
"baguet":	{"NN"},
"baguette":	{"NN"},
"bah":	{"UH"},
"bahai":	{"JJ","NN"},
"bahaism":	{"NN"},
"bahamian":	{"JJ","NN"},
"bahasa":	{"NN"},
"bahrain":	{"NN"},
"bahraini":	{"JJ","NN"},
"bahrein":	{"NN"},
"bahreini":	{"NN"},
"baht":	{"NN","NNS"},
"bahts":	{"NNS"},
"bai":	{"NN"},
"baic":	{"NN"},
"baikal":	{"NN"},
"bail":	{"NN","VB","VBP"},
"bail-jumping":	{"NN"},
"bailable":	{"JJ"},
"bailed":	{"VBD","VBN"},
"bailee":	{"NN"},
"bailey":	{"NN"},
"bailiff":	{"NN"},
"bailiffs":	{"NNS"},
"bailiffship":	{"NN"},
"bailing":	{"VBG"},
"bailiwick":	{"NN"},
"bailment":	{"NN"},
"bailor":	{"NN"},
"bailout":	{"NN"},
"bailouts":	{"NNS"},
"bails":	{"VBZ","NNS"},
"bain-marie":	{"NN"},
"baiomys":	{"NNS"},
"bairava":	{"NN"},
"bairdiella":	{"NN"},
"bairiki":	{"NN"},
"bairn":	{"NN"},
"baisa":	{"NN"},
"baisakh":	{"NN"},
"bait":	{"NN","VB","VBP"},
"baited":	{"VBD","VBN"},
"baiting":	{"NN","VBG"},
"baits":	{"VBZ"},
"baiza":	{"NN"},
"baize":	{"NN"},
"bake":	{"VB","VBP","NN"},
"bake-offs":	{"NNS"},
"bake-oven":	{"NN"},
"bakeapple":	{"NN"},
"baked":	{"VBD","VBN"},
"bakehouse":	{"NN"},
"bakelite":	{"NN"},
"baker":	{"NN"},
"bakeries":	{"NNS"},
"bakers":	{"NNS"},
"bakersfield":	{"NN"},
"bakery":	{"NN"},
"bakery-mix":	{"JJ"},
"bakes":	{"VBZ","NNS"},
"bakeshop":	{"NN"},
"bakeware":	{"NN"},
"baking":	{"NN","VBG","JJ"},
"baklava":	{"NN"},
"baksheesh":	{"NN"},
"bakshis":	{"NN"},
"bakshish":	{"NN"},
"baku":	{"NN"},
"bakunin":	{"NN"},
"bal":	{"NN"},
"balaclava":	{"NN"},
"balaena":	{"NN"},
"balaeniceps":	{"NNS"},
"balaenicipitidae":	{"NN"},
"balaenidae":	{"NN"},
"balaenoptera":	{"NN"},
"balaenopteridae":	{"NN"},
"balagan":	{"NN"},
"balalaika":	{"NN"},
"balance":	{"NN","VB","VBP"},
"balance-of-payments":	{"NNS","JJ"},
"balance-sheet":	{"NN","JJ"},
"balance-wise":	{"JJ"},
"balanced":	{"JJ","VBN","VBD"},
"balanced-budget":	{"JJ","NN"},
"balancer":	{"NN"},
"balances":	{"VBZ","NNS"},
"balanchine":	{"NN"},
"balancing":	{"VBG","NN"},
"balanidae":	{"NN"},
"balanitis":	{"NN"},
"balanoposthitis":	{"NN"},
"balanus":	{"NN"},
"balarama":	{"NN"},
"balas":	{"NN"},
"balata":	{"NN"},
"balaton":	{"NN"},
"balboa":	{"NN"},
"balbriggan":	{"NN"},
"balconied":	{"JJ"},
"balconies":	{"NNS"},
"balcony":	{"NN"},
"bald":	{"JJ"},
"bald-faced":	{"JJ"},
"bald-headed":	{"JJ"},
"bald-pated":	{"JJ"},
"baldachin":	{"NN"},
"balder":	{"JJR"},
"balderdash":	{"NN"},
"baldest":	{"JJS"},
"baldhead":	{"NN"},
"balding":	{"JJ"},
"baldish":	{"JJ"},
"baldly":	{"RB"},
"baldness":	{"NN"},
"baldpate":	{"NN"},
"baldr":	{"NN"},
"baldric":	{"NN"},
"baldrick":	{"NN"},
"baldy":	{"NN"},
"bale":	{"NN","VB","VBP"},
"baled":	{"VBD","VBN"},
"baleen":	{"NN"},
"balefire":	{"NN"},
"baleful":	{"JJ"},
"balefully":	{"RB"},
"balefulness":	{"NN"},
"balenciaga":	{"NN"},
"bales":	{"NNS","VBZ"},
"balfour":	{"NN"},
"bali":	{"NN"},
"balibago":	{"NN"},
"balinese":	{"NN"},
"baling":	{"VBG"},
"balistes":	{"NNS"},
"balistidae":	{"NN"},
"balk":	{"VB","VBP","NN"},
"balkan":	{"NN"},
"balkanisation":	{"NN"},
"balkanise":	{"VB","VBP"},
"balkanised":	{"VBD","VBN"},
"balkanises":	{"VBZ"},
"balkanising":	{"VBG"},
"balkanization":	{"NN"},
"balkanize":	{"VB","VBP"},
"balkanized":	{"VBD","VBN","JJ"},
"balkanizes":	{"VBZ"},
"balkanizing":	{"VBG"},
"balkans":	{"NNS"},
"balked":	{"VBD","VBN"},
"balker":	{"NN"},
"balkiness":	{"NN"},
"balking":	{"VBG"},
"balkline":	{"NN"},
"balks":	{"VBZ"},
"balky":	{"JJ"},
"ball":	{"NN","VBP","VB"},
"ball-bearing":	{"NN"},
"ball-breaker":	{"NN"},
"ball-buster":	{"NN"},
"ball-carriers":	{"NNS"},
"ball-hawking":	{"JJ"},
"ball-shaped":	{"JJ"},
"ballad":	{"NN"},
"ballade":	{"NN"},
"balladeer":	{"NN"},
"ballads":	{"NNS"},
"ballard":	{"NN"},
"ballards":	{"NNS"},
"ballast":	{"VB","NN"},
"ballasted":	{"VBD","VBN"},
"ballasting":	{"VBG"},
"ballasts":	{"VBZ"},
"ballclub":	{"NN"},
"ballcock":	{"NN"},
"balldress":	{"NN"},
"balled":	{"VBD","VBN"},
"ballerina":	{"NN"},
"ballerinas":	{"NNS"},
"ballet":	{"NN"},
"balletic":	{"JJ"},
"balletomane":	{"NN"},
"balletomania":	{"NN"},
"ballets":	{"NNS"},
"ballfields":	{"NNS"},
"ballgame":	{"NN"},
"ballgowns":	{"NNS"},
"balling":	{"VBG"},
"ballista":	{"NN"},
"ballistic":	{"JJ"},
"ballistics":	{"NN"},
"ballistite":	{"NN"},
"ballistocardiogram":	{"NN"},
"ballistocardiograph":	{"NN"},
"ballock":	{"NN"},
"ballon":	{"NN"},
"balloon":	{"NN","VB","VBP"},
"ballooned":	{"VBD","VBN"},
"balloonfish":	{"NN"},
"ballooning":	{"NN","VBG"},
"balloonist":	{"NN"},
"balloonists":	{"NNS"},
"balloons":	{"NNS","VBZ"},
"ballot":	{"NN","VB","VBP"},
"ballot-burning":	{"JJ"},
"ballota":	{"NN"},
"balloted":	{"VBD","VBN"},
"balloting":	{"VBG"},
"ballots":	{"NNS","VBZ"},
"ballottement":	{"NN"},
"ballpark":	{"NN"},
"ballparks":	{"NNS"},
"ballpen":	{"NN"},
"ballplayer":	{"NN"},
"ballplayers":	{"NNS"},
"ballpoint":	{"NN"},
"ballroom":	{"NN"},
"balls":	{"NNS","VBZ","UH","VB","VBP"},
"balls-up":	{"NN"},
"ballsed":	{"VBD","VBN"},
"ballses":	{"VBZ"},
"ballsing":	{"VBG"},
"ballup":	{"NN"},
"bally":	{"JJ"},
"ballyhoo":	{"VB","VBP","NN"},
"ballyhooed":	{"VBN","VBD"},
"ballyhooey":	{"NN"},
"ballyhooing":	{"VBG"},
"ballyhoos":	{"VBZ"},
"ballyrag":	{"VB"},
"balm":	{"NN"},
"balm-of-Gilead":	{"NN"},
"balm-of-gilead":	{"NN"},
"balmily":	{"RB"},
"balminess":	{"NN"},
"balmoral":	{"NN"},
"balmy":	{"JJ","NN"},
"balochi":	{"NN"},
"baloney":	{"NN"},
"balsa":	{"NN"},
"balsam":	{"NN"},
"balsam-scented":	{"JJ"},
"balsamic":	{"JJ"},
"balsaminaceae":	{"NN"},
"balsamorhiza":	{"NN"},
"balsamroot":	{"NN"},
"balsams":	{"NNS"},
"balsamy":	{"JJ"},
"balthasar":	{"NN"},
"balthazar":	{"NN"},
"baltic":	{"JJ","NN"},
"baltic-finnic":	{"NN"},
"baltimore":	{"NN"},
"baltimore-based":	{"JJ"},
"balto-slavic":	{"NN"},
"balto-slavonic":	{"NN"},
"baluchi":	{"NN"},
"baluster":	{"NN"},
"balusters":	{"NNS"},
"balustrade":	{"NN"},
"balzac":	{"NN"},
"balzacian":	{"JJ"},
"bam":	{"UH"},
"bamako":	{"NN"},
"bambi-syndronists":	{"NNS"},
"bambino":	{"NN"},
"bamboo":	{"NN"},
"bamboozle":	{"VB","VBP"},
"bamboozled":	{"VBD","VBN"},
"bamboozles":	{"VBZ"},
"bamboozling":	{"VBG"},
"bambusa":	{"NN"},
"bambuseae":	{"NN"},
"ban":	{"NN","VB","VBP"},
"banal":	{"JJ","NN"},
"banalities":	{"NNS"},
"banality":	{"NN"},
"banalization":	{"NN"},
"banana":	{"NN","FW"},
"banana-exporting":	{"JJ"},
"bananas":	{"NNS","JJ"},
"banausic":	{"JJ"},
"band":	{"NN","VB","VBP"},
"band-wagon":	{"JJ"},
"bandage":	{"NN","VB","VBP"},
"bandaged":	{"VBD","VBN"},
"bandages":	{"NNS","VBZ"},
"bandaging":	{"VBG"},
"bandana":	{"NN"},
"bandanas":	{"NNS"},
"bandanna":	{"NN"},
"bandannas":	{"NNS"},
"bandbox":	{"NN"},
"bandeau":	{"NN"},
"banded":	{"VBD","VBN","JJ"},
"bandelet":	{"NN"},
"bandelette":	{"NN"},
"banderilla":	{"NN"},
"banderillero":	{"NN"},
"bandicoot":	{"NN"},
"bandied":	{"VBD","VBN"},
"bandier":	{"JJR"},
"bandies":	{"VBZ"},
"bandiest":	{"JJS"},
"banding":	{"NN","VBG"},
"bandit":	{"NN"},
"banditos":	{"NNS"},
"banditry":	{"NN"},
"bandits":	{"NNS"},
"bandleader":	{"NN"},
"bandlet":	{"NN"},
"bandmaster":	{"NN"},
"bandmate":	{"NN"},
"bandmates":	{"NNS"},
"bandoleer":	{"NN"},
"bandoleers":	{"NNS"},
"bandolier":	{"NN"},
"bandoneon":	{"NN"},
"bands":	{"NNS","VBZ"},
"bandsaw":	{"NN"},
"bandsman":	{"NN"},
"bandstand":	{"NN"},
"bandtail":	{"NN"},
"bandung":	{"NN"},
"bandwagon":	{"NN"},
"bandwidth":	{"NN"},
"bandy":	{"VB","VBP","JJ"},
"bandy-legged":	{"JJ"},
"bandying":	{"VBG"},
"bandyleg":	{"NN"},
"bane":	{"NN"},
"baneberry":	{"NN"},
"baneful":	{"JJ"},
"banefully":	{"RB"},
"banff":	{"NN"},
"bang":	{"NN","VB","VBP","RB","UH"},
"bang-sashes":	{"NNS"},
"bang-up":	{"JJ"},
"banged":	{"VBD","VBN"},
"banger":	{"NN"},
"bangers":	{"NNS"},
"bangiaceae":	{"NN"},
"banging":	{"VBG"},
"bangish":	{"JJ"},
"bangkok-based":	{"JJ"},
"bangla":	{"NN"},
"bangle":	{"NN"},
"bangles":	{"NNS"},
"bangor":	{"NN"},
"bangs":	{"NNS","VBZ"},
"bangtail":	{"NN"},
"banian":	{"NN"},
"banish":	{"VB","NN"},
"banished":	{"VBD","VBN"},
"banishes":	{"VBZ","NNS"},
"banishing":	{"VBG","NN"},
"banishment":	{"NN"},
"banister":	{"NN"},
"banisters":	{"NNS"},
"banjo":	{"NN"},
"banjul":	{"NN"},
"bank":	{"NN","VB","VBP"},
"bank-affiliated":	{"JJ"},
"bank-backed":	{"JJ"},
"bank-baiting":	{"JJ"},
"bank-branch":	{"JJ"},
"bank-credit":	{"NN"},
"bank-debt":	{"NN"},
"bank-director":	{"NN"},
"bank-embezzlement":	{"JJ"},
"bank-fraud":	{"NN","JJ"},
"bank-holding":	{"JJ","VBG","NN"},
"bank-looting":	{"JJ"},
"bank-owned":	{"JJ"},
"bank-sponsored":	{"JJ"},
"bank-teller":	{"NN"},
"bankable":	{"JJ"},
"bankbook":	{"NN"},
"banked":	{"VBD","VBN","JJ"},
"banker":	{"NN"},
"banker-editor":	{"NN"},
"bankers":	{"NNS"},
"bankhead":	{"NN"},
"bankholding":	{"VBG"},
"bankia":	{"NN"},
"banking":	{"NN","VBG","NN","JJ"},
"banking-related":	{"JJ"},
"banknote":	{"NN"},
"bankroll":	{"NN","VB","VBP"},
"bankrolled":	{"VBD","VBN"},
"bankrolling":	{"VBG"},
"bankrolls":	{"VBZ"},
"bankrupcy":	{"NN"},
"bankrupt":	{"JJ","VB","VBP","NN"},
"bankruptcies":	{"NNS"},
"bankruptcy":	{"NN"},
"bankruptcy-court":	{"NN","JJ"},
"bankruptcy-law":	{"NN","JJ"},
"bankruptcy-proceedings":	{"NNS"},
"bankruptcy-reorganization":	{"NN"},
"bankruptcylaw":	{"NN"},
"bankrupted":	{"VBD","VBN"},
"bankrupting":	{"VBG"},
"bankrupts":	{"JJ","VBZ"},
"bankrupty-law":	{"NN"},
"banks":	{"NNS","VBZ"},
"banksia":	{"NN"},
"banlieue":	{"NN"},
"banlieues":	{"NNS"},
"banned":	{"JJ","VBN","VBD"},
"banner":	{"NN","VB","VBP","JJ"},
"bannered":	{"VBD","VBN","JJ"},
"banneret":	{"NN"},
"bannering":	{"VBG"},
"bannerlike":	{"RB"},
"banners":	{"VBZ","NNS"},
"banning":	{"VBG"},
"banning-order":	{"NN"},
"bannister":	{"NN"},
"bannock":	{"NN"},
"bannockburn":	{"NN"},
"banns":	{"NNS"},
"banquet":	{"NN","VB","VBP"},
"banquet-hall":	{"NN"},
"banqueted":	{"VBD","VBN"},
"banqueting":	{"VBG","JJ"},
"banquets":	{"NNS","VBZ"},
"banquette":	{"NN"},
"banquettes":	{"NNS"},
"bans":	{"NNS","VBZ"},
"banshee":	{"NN"},
"banshees":	{"NNS"},
"banshie":	{"NN"},
"bantam":	{"NN","JJ"},
"bantamweight":	{"NN"},
"banteng":	{"NN"},
"banter":	{"NN","VB","VBP"},
"bantered":	{"VBD","VBN"},
"bantering":	{"JJ","VBG"},
"banteringly":	{"RB"},
"banters":	{"VBZ"},
"banting":	{"NN"},
"bantoid":	{"JJ"},
"bantu":	{"JJ","NN"},
"bantu-speaking":	{"JJ"},
"banyan":	{"NN"},
"banzai":	{"UH"},
"baobab":	{"NN"},
"bap":	{"NN"},
"baphia":	{"NN"},
"baptise":	{"VB","VBP"},
"baptised":	{"VBD","VBN"},
"baptises":	{"VBZ"},
"baptisia":	{"NN"},
"baptising":	{"VBG"},
"baptism":	{"NN"},
"baptismal":	{"JJ"},
"baptisms":	{"NNS"},
"baptistery":	{"NN"},
"baptistic":	{"JJ"},
"baptistry":	{"NN"},
"baptize":	{"VB","VBP"},
"baptized":	{"VBD","VBN"},
"baptizes":	{"VBZ"},
"baptizing":	{"VBG"},
"bar":	{"NN","VB","VBP","IN"},
"bar-buddy":	{"NN"},
"bar-code":	{"JJ"},
"bar-shaped":	{"JJ"},
"bar-staged":	{"JJ"},
"baraka":	{"NN"},
"baranduki":	{"NN"},
"barany":	{"NN"},
"barb":	{"NN","VB","VBP"},
"barbacan":	{"NN"},
"barbadian":	{"JJ","NN"},
"barbados":	{"NNS"},
"barbarea":	{"NN"},
"barbarian":	{"NN"},
"barbarians":	{"NNS"},
"barbaric":	{"JJ","NN"},
"barbarisation":	{"NN"},
"barbarise":	{"VB","VBP"},
"barbarised":	{"VBD","VBN"},
"barbarises":	{"VBZ"},
"barbarising":	{"VBG"},
"barbarism":	{"NN"},
"barbarisms":	{"NNS"},
"barbarity":	{"NN"},
"barbarization":	{"NN"},
"barbarize":	{"VB","VBP"},
"barbarized":	{"VBD","VBN"},
"barbarizes":	{"VBZ"},
"barbarizing":	{"VBG"},
"barbarossa":	{"NN"},
"barbarous":	{"JJ"},
"barbarously":	{"RB"},
"barbarousness":	{"NN"},
"barbary":	{"NN"},
"barbasco":	{"NN"},
"barbate":	{"JJ"},
"barbecue":	{"NN","VB","VBP"},
"barbecued":	{"VBD","VBN"},
"barbecues":	{"NNS","VBZ"},
"barbecuing":	{"VBG"},
"barbed":	{"JJ","NN","VBN","VBD"},
"barbed-wire":	{"JJ","NN"},
"barbel":	{"NN"},
"barbell":	{"NN"},
"barbellate":	{"JJ"},
"barbeque":	{"NN","VB","VBP"},
"barbequed":	{"VBD","VBN"},
"barbeques":	{"NNS","VBZ"},
"barbequing":	{"VBG"},
"barber":	{"VB","VBP","NN"},
"barbered":	{"VBD","VBN"},
"barbering":	{"VBG"},
"barberry":	{"NN"},
"barbers":	{"NNS","VBZ"},
"barbershop":	{"NN","JJ"},
"barbet":	{"NN"},
"barbette":	{"NN"},
"barbican":	{"NN"},
"barbing":	{"VBG"},
"barbital":	{"NN"},
"barbitone":	{"NN"},
"barbiturate":	{"NN"},
"barbs":	{"NNS","VBZ"},
"barbu":	{"NN"},
"barbuda":	{"NN"},
"barbwire":	{"NN"},
"barcarole":	{"NN"},
"barcarolle":	{"NN"},
"barcelona":	{"NN"},
"barcelona-based":	{"JJ"},
"barcode":	{"NN"},
"bard":	{"NN"},
"barde":	{"VB"},
"barded":	{"VBD","VBN"},
"bardeen":	{"NN"},
"bardian":	{"JJ"},
"bardic":	{"JJ"},
"barding":	{"VBG"},
"bardolatry":	{"NN"},
"bards":	{"NNS","VBZ"},
"bare":	{"JJ","VB","VBP"},
"bare-armed":	{"JJ"},
"bare-ass":	{"JJ"},
"bare-assed":	{"JJ"},
"bare-bones":	{"JJ"},
"bare-breasted":	{"JJ"},
"bare-faced":	{"JJ"},
"bare-footed":	{"JJ"},
"bare-knuckle":	{"JJ"},
"bare-knuckled":	{"JJ"},
"bare-metal":	{"JJ"},
"bareback":	{"JJ","RB"},
"bareboat":	{"NN"},
"bareboating":	{"NN"},
"bared":	{"VBD","VBN"},
"barefaced":	{"JJ"},
"barefacedly":	{"RB"},
"barefoot":	{"RB","JJ"},
"barefooted":	{"RB","JJ"},
"barehanded":	{"JJ"},
"bareheaded":	{"JJ","RB"},
"barelegged":	{"JJ"},
"barely":	{"RB"},
"bareness":	{"NN"},
"barer":	{"JJR"},
"bares":	{"VBZ"},
"barest":	{"JJS"},
"barf":	{"VB","VBP","NN"},
"barfed":	{"VBD","VBN"},
"barfing":	{"VBG"},
"barflies":	{"NNS"},
"barfs":	{"VBZ"},
"bargain":	{"NN","VB","VBP"},
"bargain-basement":	{"JJ","NN"},
"bargain-buying":	{"JJ"},
"bargain-hunter":	{"NN"},
"bargain-hunters":	{"NNS"},
"bargain-hunting":	{"NN","JJ"},
"bargain-priced":	{"JJ"},
"bargained":	{"VBD","VBN"},
"bargainer":	{"NN"},
"bargainers":	{"NNS"},
"bargaining":	{"NN","VBG"},
"bargaining-chip":	{"NN"},
"bargains":	{"NNS","VBZ"},
"barge":	{"NN","VB","VBP"},
"barged":	{"VBD","VBN"},
"bargee":	{"NN"},
"bargees":	{"NNS"},
"bargelike":	{"JJ"},
"bargello":	{"NN"},
"bargeman":	{"NN"},
"bargemen":	{"NNS"},
"bargen":	{"VBP","VB"},
"barges":	{"NNS","VBZ"},
"barging":	{"VBG","NN"},
"bari":	{"NN"},
"baric":	{"JJ"},
"barilla":	{"NN"},
"baring":	{"NN","VBG"},
"barish":	{"NN"},
"barista":	{"NN"},
"baristas":	{"NNS"},
"barite":	{"NN"},
"baritone":	{"NN","JJ"},
"barium":	{"NN"},
"bark":	{"NN","VB","VBP"},
"bark-louse":	{"NN"},
"bark-nibbling":	{"JJ"},
"barked":	{"VBD","VBN"},
"barkeep":	{"NN"},
"barkeeper":	{"NN"},
"barkeepers":	{"NNS"},
"barkeeps":	{"NNS"},
"barker":	{"NN"},
"barking":	{"NN","VBG"},
"barkley":	{"NN"},
"barks":	{"NNS","VBZ"},
"barky":	{"JJ"},
"barley":	{"NN"},
"barley-sugar":	{"NN"},
"barleycorn":	{"NN"},
"barlow":	{"NN"},
"barm":	{"NN"},
"barmaid":	{"NN"},
"barman":	{"NN"},
"barmbrack":	{"NN"},
"barmy":	{"JJ"},
"barn":	{"NN"},
"barn-burner":	{"NN"},
"barnacle":	{"NN"},
"barnacles":	{"NNS"},
"barnburner":	{"NN"},
"barndoor":	{"NN"},
"barnful":	{"NN"},
"barns":	{"NNS"},
"barnsful":	{"NN"},
"barnstorm":	{"VB","VBP"},
"barnstormed":	{"VBD","VBN"},
"barnstormer":	{"NN"},
"barnstormers":	{"NNS"},
"barnstorming":	{"VBG","JJ"},
"barnstorms":	{"VBZ"},
"barnum":	{"NN"},
"barnyard":	{"NN"},
"barnyards":	{"NNS"},
"barograph":	{"NN"},
"barographic":	{"JJ"},
"barometer":	{"NN"},
"barometers":	{"NNS"},
"barometric":	{"JJ"},
"barometrical":	{"JJ"},
"baron":	{"NN"},
"baronage":	{"NN"},
"baronduki":	{"NN"},
"baroness":	{"NN"},
"baronet":	{"NN"},
"baronetage":	{"NN"},
"baronetcy":	{"NN"},
"baronetise":	{"VB"},
"baronetize":	{"VB"},
"barong":	{"NN"},
"baronial":	{"JJ","NN"},
"barons":	{"NNS"},
"barony":	{"NN"},
"baroque":	{"NN","JJ"},
"baroqueness":	{"NN"},
"baroreceptor":	{"NN"},
"barosaur":	{"NN"},
"barosaurus":	{"NN"},
"barouche":	{"NN"},
"barque":	{"NN"},
"barrack":	{"NN","VBP","VB"},
"barracked":	{"VBD","VBN"},
"barracking":	{"NN","VBG"},
"barracks":	{"NNS","VBZ"},
"barracouta":	{"NN"},
"barracuda":	{"NN"},
"barrage":	{"NN","VB","VBP"},
"barraged":	{"VBD","VBN"},
"barrages":	{"NNS","VBZ"},
"barraging":	{"VBG"},
"barramundi":	{"NN"},
"barranquilla":	{"NN"},
"barrater":	{"NN"},
"barrator":	{"NN"},
"barratry":	{"NN"},
"barred":	{"VBN","VBD","JJ"},
"barrel":	{"NN","VB","VBP"},
"barrel-a-day":	{"JJ"},
"barrel-chested":	{"JJ"},
"barrel-per-day":	{"JJ"},
"barrel-shaped":	{"JJ"},
"barrel-vaulted":	{"JJ"},
"barrel-wide":	{"JJ"},
"barreled":	{"VBD","VBN"},
"barrelfish":	{"NN"},
"barrelful":	{"NN"},
"barrelhouse":	{"NN"},
"barreling":	{"VBG"},
"barrelled":	{"VBD","VBN"},
"barrelling":	{"VBG"},
"barrels":	{"NNS","VBZ"},
"barrels-a-day":	{"JJ"},
"barren":	{"JJ","NN"},
"barrenness":	{"NN"},
"barrenwort":	{"NN"},
"barrette":	{"NN"},
"barretter":	{"NN"},
"barricade":	{"NN","VB","VBP"},
"barricaded":	{"VBD","VBN"},
"barricades":	{"NNS","VBZ"},
"barricading":	{"VBG"},
"barrie":	{"NN"},
"barrier":	{"NN"},
"barrier-free":	{"JJ"},
"barrier-island":	{"NN"},
"barriers":	{"NNS"},
"barring":	{"VBG","IN"},
"barrio":	{"NN"},
"barrios":	{"NNS"},
"barrister":	{"NN"},
"barristers":	{"NNS"},
"barroom":	{"NN"},
"barrow":	{"NN"},
"barrow-boy":	{"NN"},
"barrow-man":	{"NN"},
"barrowful":	{"NN"},
"barrymore":	{"NN"},
"bars":	{"NNS","VBZ"},
"barstow":	{"NN"},
"bart":	{"NN"},
"bartender":	{"NN"},
"bartenders":	{"NNS"},
"barter":	{"VB","VBP","NN"},
"bartered":	{"VBD","VBN"},
"barterer":	{"NN"},
"bartering":	{"VBG"},
"barters":	{"VBZ"},
"barth":	{"NN"},
"barthelme":	{"NN"},
"bartholdi":	{"NN"},
"bartholin":	{"NN"},
"bartlesville":	{"NN"},
"bartlett":	{"NN"},
"bartok":	{"NN"},
"bartonia":	{"NN"},
"bartramia":	{"NN"},
"barunduki":	{"NN"},
"barycenter":	{"NN"},
"barye":	{"NN"},
"baryon":	{"NN"},
"baryshnikov":	{"NN"},
"baryta":	{"NN"},
"barytes":	{"NN"},
"barytic":	{"JJ"},
"barytone":	{"NN"},
"bas-relief":	{"JJ","NN"},
"bas-reliefs":	{"NNS"},
"basal":	{"JJ","NN"},
"basalt":	{"NN"},
"basaltic":	{"JJ"},
"bascially":	{"RB"},
"bascule":	{"NN"},
"base":	{"NN","JJ","VB","VBP"},
"base-forming":	{"JJ"},
"base-metal":	{"NN"},
"base-metals":	{"NNS"},
"base-price":	{"NN"},
"base-rate":	{"JJ"},
"base-runner":	{"NN"},
"base-stealing":	{"JJ"},
"base-wage":	{"JJ"},
"baseball":	{"NN"},
"baseball-card":	{"JJ"},
"baseball-loving":	{"JJ"},
"baseball-watching":	{"JJ"},
"baseballight":	{"NN"},
"baseballs":	{"NNS"},
"baseboard":	{"NN"},
"baseborn":	{"JJ"},
"based":	{"JJ","VBN","VBD"},
"basel":	{"NN"},
"basel-based":	{"JJ"},
"baseless":	{"JJ"},
"baseline":	{"NN","JJ"},
"basely":	{"RB"},
"baseman":	{"NN"},
"basement":	{"NN"},
"basements":	{"NNS"},
"baseness":	{"NN"},
"basenji":	{"NN"},
"baser":	{"JJR"},
"bases":	{"NNS","VBZ"},
"basest":	{"JJS"},
"bash":	{"VB","VBP","NN"},
"bashed":	{"VBD","VBN"},
"bashes":	{"NNS","VBZ"},
"bashful":	{"JJ"},
"bashfully":	{"RB"},
"bashfulness":	{"NN"},
"bashing":	{"VBG","NN"},
"basia":	{"NN"},
"basic":	{"JJ"},
"basic-cable":	{"JJ"},
"basically":	{"RB"},
"basics":	{"NNS"},
"basidial":	{"JJ"},
"basidiocarp":	{"NN"},
"basidiolichen":	{"NN"},
"basidiomycete":	{"NN"},
"basidiomycetes":	{"NN"},
"basidiomycetous":	{"JJ"},
"basidiomycota":	{"NN"},
"basidiomycotina":	{"NN"},
"basidiospore":	{"NN"},
"basidiosporous":	{"JJ"},
"basidium":	{"NN"},
"basifixed":	{"JJ"},
"basify":	{"VB"},
"basil":	{"NN"},
"basilar":	{"JJ","NN"},
"basilary":	{"JJ"},
"basileis":	{"NNS"},
"basileus":	{"NN"},
"basilica":	{"NN"},
"basilican":	{"JJ"},
"basilicata":	{"NN"},
"basiliscus":	{"NN"},
"basilisk":	{"NN"},
"basin":	{"NN"},
"basinal":	{"JJ"},
"basined":	{"JJ"},
"basinet":	{"NN"},
"basinful":	{"NN"},
"basing":	{"VBG","NN","JJ"},
"basins":	{"NNS"},
"basipetal":	{"JJ"},
"basis":	{"NN"},
"basis-point":	{"NN"},
"basiscopic":	{"JJ"},
"bask":	{"VB","VBP"},
"basked":	{"VBD","VBN"},
"basket":	{"NN"},
"basket-shaped":	{"JJ"},
"basketball":	{"NN"},
"basketball-cutback":	{"NN"},
"basketball-playing":	{"NN"},
"basketeer":	{"NN"},
"basketful":	{"NN"},
"basketmaker":	{"NN"},
"basketry":	{"NN"},
"baskets":	{"NNS"},
"basketweaver":	{"NN"},
"basking":	{"VBG"},
"basks":	{"VBZ"},
"basle":	{"NN"},
"basophil":	{"NN"},
"basophile":	{"NN"},
"basophilia":	{"NN"},
"basophilic":	{"JJ"},
"basotho":	{"NN"},
"basque":	{"NN"},
"basra":	{"NN"},
"bass":	{"NN","NNS","JJ"},
"bassariscidae":	{"NN"},
"bassariscus":	{"NN"},
"bassarisk":	{"NN"},
"basse-normandie":	{"NN"},
"basses":	{"NNS"},
"basset":	{"NN"},
"basseterre":	{"NN"},
"bassia":	{"NN"},
"bassine":	{"NN"},
"bassinet":	{"NN"},
"bassist":	{"NN"},
"bassists":	{"NNS"},
"bassline":	{"NN"},
"basslines":	{"NNS"},
"basso":	{"NN"},
"bassoon":	{"NN"},
"bassoonist":	{"NN"},
"bassoonists":	{"NNS"},
"bassoons":	{"NNS"},
"basswood":	{"NN"},
"bast":	{"NN"},
"bastard":	{"NN"},
"bastardisation":	{"NN"},
"bastardise":	{"VB","VBP"},
"bastardised":	{"VBD","VBN","JJ"},
"bastardises":	{"VBZ"},
"bastardising":	{"VBG"},
"bastardization":	{"NN"},
"bastardize":	{"VB","VBP"},
"bastardized":	{"VBD","VBN","JJ"},
"bastardizes":	{"VBZ"},
"bastardizing":	{"VBG"},
"bastardly":	{"JJ"},
"bastards":	{"NNS"},
"bastardy":	{"NN"},
"baste":	{"VB","VBP"},
"basted":	{"VBD","VBN"},
"baster":	{"NN"},
"bastes":	{"VBZ"},
"bastille":	{"NN"},
"bastinado":	{"NN","VB","VBP"},
"bastinadoed":	{"VBD","VBN"},
"bastinadoing":	{"VBG"},
"bastinados":	{"NNS","VBZ"},
"basting":	{"VBG"},
"bastion":	{"NN"},
"bastioned":	{"JJ"},
"bastions":	{"NNS"},
"bastnaesite":	{"NN"},
"bastnasite":	{"NN"},
"basuco":	{"NN"},
"basuto":	{"NN"},
"basutoland":	{"NN"},
"bat":	{"NN","VB","VBP"},
"bat-roost":	{"JJ"},
"bata":	{"NN"},
"bataan":	{"NN"},
"batch":	{"NN","VBP","VB"},
"batched":	{"VBD","VBN"},
"batches":	{"NNS","VBZ"},
"batching":	{"VBG"},
"bate":	{"VB","NN"},
"bateau":	{"NN"},
"bated":	{"VBD","VBN","JJ"},
"bates":	{"VBZ"},
"batfish":	{"NN"},
"batfowl":	{"VB"},
"bath":	{"NN","VBP","VB"},
"bath-supplies":	{"NNS"},
"bathe":	{"VB","VBP","NN"},
"bathed":	{"VBD","VBN","JJ"},
"bather":	{"NN"},
"bathers":	{"NNS"},
"bathes":	{"VBZ"},
"bathetic":	{"JJ"},
"bathhouse":	{"NN"},
"bathing":	{"NN","VBG","VBG"},
"batholite":	{"NN"},
"batholith":	{"NN"},
"batholithic":	{"JJ"},
"batholitic":	{"JJ"},
"bathometer":	{"NN"},
"bathos":	{"NN"},
"bathrobe":	{"NN"},
"bathrobes":	{"NNS"},
"bathroom":	{"NN"},
"bathrooms":	{"NNS"},
"baths":	{"NNS","VBZ"},
"bathsheba":	{"NN"},
"bathtime":	{"NN"},
"bathtimes":	{"NNS"},
"bathtub":	{"NN"},
"bathtubs":	{"NNS"},
"bathwater":	{"NN"},
"bathyal":	{"JJ"},
"bathyergidae":	{"NN"},
"bathyergus":	{"NN"},
"bathymeter":	{"NN"},
"bathymetric":	{"JJ"},
"bathymetrical":	{"JJ"},
"bathymetry":	{"NN"},
"bathyscape":	{"NN"},
"bathyscaph":	{"NN"},
"bathyscaphe":	{"NN"},
"bathysphere":	{"NN"},
"batidaceae":	{"NN"},
"batik":	{"NN"},
"bating":	{"VBG"},
"batis":	{"NNS"},
"batiste":	{"NN"},
"batman":	{"NN"},
"batmobile":	{"NN"},
"batna":	{"NN"},
"batoidei":	{"NN"},
"baton":	{"NN"},
"batrachia":	{"NN"},
"batrachian":	{"JJ","NN"},
"batrachoididae":	{"NN"},
"batrachomyomachia":	{"NN"},
"batrachoseps":	{"NNS"},
"bats":	{"NNS","VBZ"},
"batshit":	{"NN"},
"batshittery":	{"NN"},
"batsman":	{"NN"},
"batswana":	{"NN"},
"battalion":	{"NN"},
"battalions":	{"NNS"},
"batted":	{"VBD","VBN"},
"batten":	{"NN","VB","VBP"},
"battened":	{"VBD","VBN"},
"battening":	{"VBG"},
"battens":	{"VBZ","NNS"},
"batter":	{"NN","VB","VBP"},
"batter-fried":	{"JJ"},
"battercake":	{"NN"},
"battered":	{"VBD","VBN","JJ"},
"batterie":	{"NN"},
"batteries":	{"NNS"},
"battering":	{"NN","VBG"},
"batters":	{"NNS","VBZ"},
"battery":	{"NN"},
"battery-acid":	{"NN"},
"battery-driven":	{"JJ"},
"battery-operated":	{"JJ"},
"battery-powered":	{"JJ"},
"batting":	{"VBG","NN"},
"battle":	{"NN","VB","VBP"},
"battle-ax":	{"NN"},
"battle-axe":	{"NN"},
"battle-cries":	{"NN"},
"battle-cry":	{"NN"},
"battle-scarred":	{"JJ"},
"battle-shattered":	{"JJ"},
"battle-tested":	{"JJ"},
"battled":	{"VBD","VBN"},
"battledore":	{"NN"},
"battlefield":	{"NN"},
"battlefield-electronic":	{"JJ"},
"battlefields":	{"NNS"},
"battlefront":	{"NN"},
"battleful":	{"JJ"},
"battleground":	{"NN"},
"battlegrounds":	{"NNS"},
"battlegroups":	{"NNS"},
"battlement":	{"NN"},
"battlemented":	{"JJ"},
"battlements":	{"NNS"},
"battler":	{"NN"},
"battles":	{"NNS","VBZ"},
"battleship":	{"NN"},
"battlesight":	{"NN"},
"battlespace":	{"NN"},
"battlespaces":	{"NNS"},
"battlewagon":	{"NN"},
"battling":	{"VBG","NN"},
"battue":	{"NN"},
"batty":	{"NN","JJ"},
"batwing":	{"JJ","NN"},
"batwings":	{"NNS"},
"bauble":	{"NN","JJ"},
"baubles":	{"NNS"},
"baud":	{"NN"},
"baudelaire":	{"NN"},
"bauhaus":	{"NN"},
"bauhinia":	{"NN"},
"baulk":	{"NN","VB","VBP"},
"baulk-line":	{"NN"},
"baulked":	{"VBD","VBN"},
"baulker":	{"NN"},
"baulking":	{"VBG"},
"baulks":	{"VBZ"},
"bauxite":	{"NN"},
"bauxitic":	{"JJ"},
"bavaria":	{"NN"},
"bavarian":	{"NN","JJ"},
"bawbee":	{"NN"},
"bawd":	{"NN"},
"bawdily":	{"RB"},
"bawdiness":	{"NN"},
"bawdry":	{"NN"},
"bawdy":	{"JJ"},
"bawdyhouse":	{"NN"},
"bawh":	{"NN"},
"bawhs":	{"NNS"},
"bawl":	{"VB","VBP"},
"bawled":	{"VBD","VBN"},
"bawler":	{"NN"},
"bawling":	{"VBG"},
"bawls":	{"VBZ"},
"bay":	{"NN","VBP","VB","JJ"},
"bay-area":	{"JJ"},
"bay-front":	{"JJ"},
"baya":	{"NN"},
"bayard":	{"NN"},
"bayat":	{"NN"},
"bayberry":	{"NN"},
"baycol":	{"NN"},
"bayed":	{"VBD","VBN"},
"bayer":	{"NN"},
"bayes":	{"NNS"},
"bayesian":	{"JJ"},
"baying":	{"NN","VBG","JJ"},
"baykal":	{"NN"},
"bayleefe":	{"NN"},
"bayly":	{"NN"},
"bayonet":	{"NN","VBP","VB"},
"bayoneted":	{"VBD","VBN"},
"bayoneting":	{"VBG"},
"bayonets":	{"NNS","VBZ"},
"bayonetted":	{"VBD","VBN"},
"bayonetting":	{"VBG"},
"bayonne":	{"NN"},
"bayou":	{"NN"},
"bayrut":	{"NN"},
"bays":	{"NNS","VBZ"},
"bazaar":	{"NN"},
"bazaars":	{"NNS"},
"bazar":	{"NN"},
"bazillion":	{"NN"},
"bazillions":	{"NNS"},
"bazooka":	{"NN"},
"bb":	{"NN"},
"bbl":	{"NN"},
"bbs":	{"NN"},
"bc":	{"RB"},
"bce":	{"RB"},
"bcs":	{"NN"},
"bd":	{"NN"},
"bdellium":	{"NN"},
"be":	{"VB"},
"be-thonged":	{"JJ"},
"beach":	{"NN","VB","VBP"},
"beach-drift":	{"NN"},
"beach-head":	{"NN"},
"beach-house":	{"NN"},
"beach-party":	{"NN"},
"beachball":	{"NN"},
"beachcomber":	{"NN"},
"beachcombers":	{"NNS"},
"beached":	{"VBD","VBN"},
"beaches":	{"NNS","VBZ"},
"beachfront":	{"JJ"},
"beachgoing":	{"NN"},
"beachhead":	{"NN"},
"beachheads":	{"NNS"},
"beaching":	{"VBG"},
"beachward":	{"RB"},
"beachwear":	{"NN"},
"beacon":	{"NN","VB","VBP"},
"beaconed":	{"VBD","VBN"},
"beaconing":	{"VBG"},
"beacons":	{"NNS","VBZ"},
"bead":	{"VB","NN"},
"bead-like":	{"JJ"},
"beaded":	{"JJ","VBD","VBN"},
"beading":	{"NN","VBG"},
"beadle":	{"NN"},
"beadlike":	{"JJ"},
"beads":	{"NNS","VBZ"},
"beadsman":	{"NN"},
"beadwork":	{"NN"},
"beady":	{"JJ"},
"beady-eyed":	{"JJ"},
"beagle":	{"NN"},
"beagling":	{"NN"},
"beak":	{"NN"},
"beaked":	{"JJ"},
"beaker":	{"NN"},
"beakers":	{"NNS"},
"beakless":	{"JJ"},
"beaklike":	{"JJ"},
"beaks":	{"NNS"},
"beam":	{"NN","VB","VBP"},
"beam-ends":	{"NNS"},
"beamed":	{"VBN","VBD"},
"beaming":	{"JJ","VBG"},
"beamish":	{"JJ"},
"beams":	{"VBZ","NNS"},
"beamy":	{"JJ"},
"bean":	{"NN","VBP","VB"},
"bean-counting":	{"NN"},
"bean-shaped":	{"JJ"},
"beanbag":	{"NN"},
"beanball":	{"NN"},
"beanballs":	{"NNS"},
"beaned":	{"VBD","VBN"},
"beaner":	{"NN"},
"beanfeast":	{"NN"},
"beanie":	{"NN"},
"beaning":	{"VBG"},
"beano":	{"NN"},
"beans":	{"NNS","VBZ"},
"beanstalk":	{"NN"},
"beantown":	{"NN"},
"beany":	{"NN"},
"bear":	{"VB","NN","VBP"},
"bear-like":	{"JJ"},
"bear-market":	{"NN"},
"bear-sized":	{"JJ"},
"bearable":	{"JJ"},
"bearberry":	{"NN"},
"bearcat":	{"NN"},
"beard":	{"NN","VB","VBP"},
"bearded":	{"JJ","VBD","VBN"},
"bearding":	{"VBG"},
"beardless":	{"JJ"},
"beardown":	{"JJ"},
"beards":	{"NNS","VBZ"},
"bearer":	{"NN"},
"bearing":	{"VBG","NN"},
"bearings":	{"NNS"},
"bearish":	{"JJ"},
"bearishly":	{"RB"},
"bearishness":	{"NN"},
"bearnaise":	{"NN"},
"bears":	{"VBZ","NNS"},
"bearskin":	{"NN"},
"bearwood":	{"NN"},
"beast":	{"NN"},
"beasties":	{"NNS"},
"beastliness":	{"NN"},
"beastly":	{"JJ","RB"},
"beasts":	{"NNS"},
"beat":	{"VB","VBD","NN","VBP","JJ"},
"beat-up":	{"JJ"},
"beatable":	{"JJ"},
"beatdown":	{"NN"},
"beatdowns":	{"NNS"},
"beaten":	{"VBN","JJ"},
"beaten-up":	{"JJ"},
"beater":	{"NN"},
"beatific":	{"JJ"},
"beatification":	{"NN"},
"beatified":	{"VBD","VBN"},
"beatifies":	{"VBZ"},
"beatify":	{"VB","VBP"},
"beatifying":	{"VBG"},
"beating":	{"VBG","NN"},
"beatings":	{"NNS"},
"beatitude":	{"NN"},
"beatnik":	{"NN"},
"beatniks":	{"NNS"},
"beats":	{"NNS","VBZ"},
"beatty":	{"NN"},
"beau":	{"NN"},
"beaugregory":	{"NN"},
"beaumontia":	{"NN"},
"beaut":	{"NN"},
"beauteous":	{"JJ"},
"beauteousness":	{"NN"},
"beautician":	{"NN"},
"beauticians":	{"NNS"},
"beauties":	{"NNS"},
"beautification":	{"NN"},
"beautified":	{"VBD","VBN"},
"beautifies":	{"VBZ"},
"beautiful":	{"JJ"},
"beautifully":	{"RB"},
"beautifully-built":	{"JJ"},
"beautifully-tapered":	{"JJ"},
"beautify":	{"VB","VBP"},
"beautifying":	{"VBG","NN"},
"beauty":	{"NN"},
"beauty-care":	{"JJ"},
"beauty-idiom":	{"NN"},
"beauvoir":	{"NN"},
"beaver":	{"NN","VB","VBP"},
"beavered":	{"VBD","VBN"},
"beavering":	{"VBG"},
"beavers":	{"NNS","VBZ"},
"beavertail":	{"NN"},
"bebop":	{"NN","VB","VBP"},
"bebopped":	{"VBD","VBN"},
"bebopping":	{"VBG"},
"bebops":	{"VBZ"},
"becalm":	{"VB"},
"becalmed":	{"JJ","VBD","VBN"},
"becalming":	{"VBG"},
"becalms":	{"VBZ"},
"became":	{"VBD"},
"becase":	{"IN"},
"because":	{"CC","IN"},
"bechamel":	{"NN"},
"bechance":	{"VB"},
"becharm":	{"VB"},
"bechuana":	{"NN"},
"beck":	{"NN"},
"becket":	{"NN"},
"beckley":	{"NN"},
"beckon":	{"VB","VBP"},
"beckoned":	{"VBD","VBN"},
"beckoning":	{"VBG"},
"beckons":	{"VBZ"},
"becloud":	{"VB","NN"},
"beclouded":	{"VBD","VBN"},
"beclouding":	{"VBG"},
"beclouds":	{"VBZ"},
"become":	{"VB","VBN","VBP","VBD"},
"becomed":	{"VBN"},
"becomes":	{"VBZ"},
"becometh":	{"VBZ"},
"becoming":	{"VBG","JJ"},
"becomingly":	{"RB"},
"becomingness":	{"NN"},
"becquerel":	{"NN"},
"bed":	{"NN","VB","VBP"},
"bed-and-breakfast":	{"NN"},
"bed-ground":	{"NN"},
"bed-hop":	{"VB","VBP"},
"bed-hopped":	{"VBD","VBN"},
"bed-hopper":	{"NN"},
"bed-hoppers":	{"NNS"},
"bed-hopping":	{"VBG"},
"bed-hops":	{"VBZ"},
"bed-liner":	{"NN"},
"bed-time":	{"NN"},
"bed-type":	{"JJ"},
"bed-wetting":	{"NN"},
"beda":	{"NN"},
"bedamn":	{"VB"},
"bedaub":	{"VB"},
"bedaubed":	{"JJ","VBD","VBN"},
"bedaubing":	{"VBG"},
"bedaubs":	{"VBZ"},
"bedaze":	{"VB"},
"bedazzle":	{"VB","VBP"},
"bedazzled":	{"VBD","VBN"},
"bedazzlement":	{"NN"},
"bedazzles":	{"VBZ"},
"bedazzling":	{"VBG"},
"bedbug":	{"NN"},
"bedbugs":	{"NNS"},
"bedchamber":	{"NN"},
"bedclothes":	{"NNS"},
"bedcover":	{"NN"},
"bedded":	{"VBD","VBN","JJ"},
"bedder":	{"NN"},
"bedding":	{"NN","VBG"},
"bede":	{"NN"},
"bedeck":	{"VB","VBP"},
"bedecked":	{"VBD","VBN"},
"bedecking":	{"VBG"},
"bedecks":	{"VBZ"},
"bedesman":	{"NN"},
"bedevil":	{"VB","VBP"},
"bedeviled":	{"VBD","VBN"},
"bedeviling":	{"VBG"},
"bedevilled":	{"VBD","VBN"},
"bedevilling":	{"VBG"},
"bedevilment":	{"NN"},
"bedevils":	{"VBZ"},
"bedew":	{"VB"},
"bedewed":	{"JJ"},
"bedfast":	{"JJ"},
"bedfellow":	{"NN"},
"bedfellows":	{"NNS"},
"bedford":	{"NN"},
"bedframe":	{"NN"},
"bedground":	{"NN"},
"bedhop":	{"VB"},
"bedight":	{"VB"},
"bedighted":	{"VBD","VBN"},
"bedighting":	{"VBG"},
"bedights":	{"VBZ"},
"bedim":	{"VB","VBP"},
"bedimmed":	{"VBD","VBN"},
"bedimming":	{"VBG"},
"bedims":	{"VBZ"},
"bedizen":	{"VB"},
"bedizened":	{"VBD","VBN"},
"bedizening":	{"VBG"},
"bedizens":	{"VBZ"},
"bedlam":	{"NN"},
"bedlamite":	{"NN"},
"bedless":	{"JJ"},
"bedouin":	{"NN"},
"bedouins":	{"NNS"},
"bedpan":	{"NN"},
"bedpans":	{"NNS"},
"bedpost":	{"NN"},
"bedraggle":	{"VB"},
"bedraggled":	{"JJ","VBD","VBN"},
"bedrest":	{"NN"},
"bedrid":	{"JJ"},
"bedridden":	{"JJ"},
"bedrock":	{"NN"},
"bedroll":	{"NN"},
"bedroom":	{"NN"},
"bedrooms":	{"NNS"},
"beds":	{"NNS","VBZ"},
"bedsheet":	{"NN"},
"bedsheets":	{"NNS"},
"bedside":	{"NN","JJ"},
"bedsit":	{"NN"},
"bedsitter":	{"NN"},
"bedsore":	{"NN"},
"bedspread":	{"NN"},
"bedspring":	{"NN"},
"bedsprings":	{"NNS"},
"bedstead":	{"NN"},
"bedstraw":	{"NN"},
"bedtime":	{"NN"},
"beduin":	{"NN"},
"bedwetter":	{"NN"},
"bee":	{"NN"},
"beebalm":	{"NN"},
"beebread":	{"NN"},
"beech":	{"NN"},
"beechen":	{"JJ"},
"beechnut":	{"NN"},
"beechwood":	{"NN"},
"beef":	{"NN","VB","VBP"},
"beef-fat":	{"JJ"},
"beef-feeding":	{"JJ"},
"beef-hungry":	{"JJ"},
"beef-import":	{"JJ"},
"beef-jerky":	{"NN"},
"beefalo":	{"NN"},
"beefburger":	{"NN"},
"beefburgers":	{"NNS"},
"beefcake":	{"NN"},
"beefcakes":	{"NNS"},
"beefeater":	{"NN"},
"beefed":	{"VBN","VBD"},
"beefed-up":	{"JJ"},
"beefier":	{"JJR"},
"beefiest":	{"JJS"},
"beefiness":	{"NN"},
"beefing":	{"VBG"},
"beefore":	{"IN"},
"beefs":	{"NNS","VBZ"},
"beefsteak":	{"NN"},
"beefwood":	{"NN"},
"beefy":	{"JJ"},
"beehive":	{"NN"},
"beekeeper":	{"NN"},
"beekeeping":	{"NN"},
"beeline":	{"NN","VB","VBP"},
"beelined":	{"VBD","VBN"},
"beelines":	{"NNS","VBZ"},
"beelining":	{"VBG"},
"beelzebub":	{"NN"},
"been":	{"VBN"},
"beep":	{"NN","VB","VBP"},
"beeped":	{"VBD","VBN"},
"beeper":	{"NN"},
"beepers":	{"NNS"},
"beeping":	{"VBG"},
"beeps":	{"NNS","VBZ"},
"beer":	{"NN"},
"beer-bellied":	{"JJ"},
"beer-belly":	{"NN"},
"beer-cooling":	{"VBG"},
"beer-distribution":	{"NN"},
"beer-drinker":	{"NN"},
"beer-guzzling":	{"JJ"},
"beer-industry":	{"NN"},
"beer-related":	{"JJ"},
"beer-runner":	{"NN"},
"beer-runners":	{"NNS"},
"beer-running":	{"NN"},
"beer-tax":	{"JJ"},
"beerbohm":	{"NN"},
"beers":	{"NNS"},
"beery":	{"JJ"},
"bees":	{"NNS"},
"beeswax":	{"NN"},
"beet":	{"NN"},
"beethovenian":	{"JJ"},
"beetle":	{"NN","VB","VBP"},
"beetle-browed":	{"JJ"},
"beetled":	{"VBD","VBN"},
"beetles":	{"NNS","VBZ"},
"beetleweed":	{"NN"},
"beetling":	{"JJ","VBG"},
"beetroot":	{"NN"},
"beets":	{"NNS"},
"befall":	{"VB","VBP"},
"befallen":	{"VBN"},
"befalling":	{"VBG"},
"befalls":	{"VBZ"},
"befell":	{"VBD"},
"befit":	{"VB","VBP"},
"befits":	{"VBZ"},
"befitted":	{"VBD","VBN"},
"befitting":	{"VBG","JJ"},
"befittingly":	{"RB"},
"befog":	{"NN"},
"befogged":	{"JJ","VBD","VBN"},
"befogging":	{"VBG"},
"befogs":	{"VBZ"},
"befoh":	{"RB"},
"befool":	{"VB"},
"befooled":	{"VBD","VBN"},
"befooling":	{"NN","VBG"},
"befools":	{"VBZ"},
"before":	{"CC","IN","RB","RP"},
"before-and-after":	{"JJ"},
"before-school":	{"JJ"},
"before-tax":	{"JJ"},
"beforehand":	{"RB"},
"befoul":	{"VB","VBP"},
"befouled":	{"VBD","VBN"},
"befouling":	{"VBG"},
"befoulment":	{"NN"},
"befouls":	{"VBZ"},
"befriend":	{"VB","VBP"},
"befriended":	{"VBD","VBN"},
"befriending":	{"VBG"},
"befriends":	{"VBZ"},
"befuddle":	{"VB","VBP"},
"befuddled":	{"VBD","VBN","JJ"},
"befuddlement":	{"NN"},
"befuddles":	{"VBZ"},
"befuddling":	{"VBG"},
"beg":	{"VB","VBP"},
"began":	{"VBD"},
"begat":	{"VBD"},
"beget":	{"VB","VBP"},
"begets":	{"VBZ"},
"begetter":	{"NN"},
"begetters":	{"NNS"},
"begetting":	{"VBG"},
"beggar":	{"NN","VB","VBP"},
"beggar's-ticks":	{"NNS"},
"beggar-my-neighbor":	{"NN"},
"beggar-my-neighbour":	{"NN"},
"beggar-thy-neighbor":	{"JJ"},
"beggar-ticks":	{"NNS"},
"beggared":	{"VBD","VBN"},
"beggaring":	{"VBG"},
"beggarly":	{"JJ"},
"beggarman":	{"NN"},
"beggars":	{"VBZ","NNS"},
"beggarweed":	{"NN"},
"beggarwoman":	{"NN"},
"beggary":	{"NN"},
"begged":	{"VBD","VBN"},
"begging":	{"VBG"},
"begild":	{"VB","VBP"},
"begin":	{"VB","VBP"},
"beginner":	{"NN"},
"beginners":	{"NNS"},
"beginning":	{"VBG","JJ","NN"},
"beginnings":	{"NNS"},
"begins":	{"VBZ"},
"begonia":	{"NN"},
"begoniaceae":	{"NN"},
"begonias":	{"NNS"},
"begot":	{"VBD"},
"begotten":	{"VBN"},
"begrime":	{"VB","VBP"},
"begrimed":	{"VBD","VBN"},
"begrimes":	{"VBZ"},
"begriming":	{"VBG"},
"begrudge":	{"VB","VBP"},
"begrudged":	{"VBD","VBN"},
"begrudges":	{"VBZ"},
"begrudging":	{"VBG"},
"begs":	{"VBZ"},
"beguile":	{"VB","VBP"},
"beguiled":	{"VBD","VBN"},
"beguilement":	{"NN"},
"beguiler":	{"NN"},
"beguiles":	{"VBZ"},
"beguiling":	{"JJ","VBG"},
"beguilingly":	{"RB"},
"beguine":	{"NN"},
"begum":	{"NN"},
"begun":	{"VBN"},
"behahn":	{"RB"},
"behalf":	{"NN"},
"behave":	{"VB","VBP"},
"behaved":	{"VBD","VBN"},
"behaves":	{"VBZ"},
"behaving":	{"VBG"},
"behavior":	{"NN"},
"behavior-modification":	{"NN"},
"behavioral":	{"JJ"},
"behaviorally":	{"RB"},
"behaviorism":	{"NN"},
"behaviorist":	{"NN"},
"behavioristic":	{"JJ"},
"behaviors":	{"NNS"},
"behaviour":	{"NN"},
"behavioural":	{"JJ","NN"},
"behaviourism":	{"NN"},
"behaviourist":	{"NN"},
"behaviouristic":	{"JJ"},
"behaviours":	{"NNS"},
"behead":	{"VB","VBP"},
"beheaded":	{"VBD","VBN"},
"beheading":	{"VBG","NN"},
"beheads":	{"VBZ"},
"beheld":	{"NN","VBD","VBN"},
"behemoth":	{"NN"},
"behemoths":	{"NNS"},
"behest":	{"NN"},
"behind":	{"IN","RB","NN","RP"},
"behind-schedule":	{"JJ"},
"behind-the-scenes":	{"JJ"},
"behindhand":	{"JJ","RB"},
"behmen":	{"NN"},
"behmenism":	{"NN"},
"behold":	{"VB","VBP"},
"beholden":	{"JJ"},
"beholder":	{"NN"},
"beholders":	{"NNS"},
"beholding":	{"VBG"},
"beholds":	{"VBZ"},
"behoove":	{"VB","VBP"},
"behooved":	{"VBD","VBN"},
"behooves":	{"VBZ"},
"behove":	{"VB","VBP"},
"behoved":	{"VBD","VBN"},
"behoves":	{"VBZ"},
"behrens":	{"NNS"},
"behring":	{"NN"},
"behynde":	{"IN"},
"beige":	{"NN","JJ"},
"beigel":	{"NN"},
"beignet":	{"NN"},
"bein":	{"JJ","VB","VBP","RB"},
"beined":	{"VBD","VBN"},
"being":	{"VBG","NN"},
"beinge":	{"VBG"},
"beingness":	{"NN"},
"beings":	{"NNS"},
"beining":	{"VBG"},
"beins":	{"VBZ"},
"bejewel":	{"VB","VBP"},
"bejeweled":	{"VBD","VBN","JJ"},
"bejeweling":	{"VBG"},
"bejewelled":	{"VBD","VBN","JJ"},
"bejewelling":	{"VBG"},
"bejewels":	{"VBZ"},
"bekaa":	{"NN"},
"bel":	{"NN"},
"bel-merodach":	{"NN"},
"belabor":	{"VB","VBP"},
"belabored":	{"VBD","VBN"},
"belaboring":	{"VBG"},
"belabors":	{"VBZ"},
"belabour":	{"VB","VBP"},
"belaboured":	{"VBD","VBN"},
"belabouring":	{"VBG"},
"belabours":	{"VBZ"},
"belamcanda":	{"NN"},
"belated":	{"JJ"},
"belatedly":	{"RB"},
"belau":	{"NN"},
"belay":	{"VB","VBP","NN"},
"belayed":	{"VBD","VBN"},
"belaying":	{"VBG"},
"belays":	{"VBZ"},
"belch":	{"VB","VBP","NN"},
"belched":	{"VBD","VBN"},
"belches":	{"VBZ","NNS"},
"belching":	{"VBG"},
"beldam":	{"NN"},
"beldame":	{"NN"},
"beleaguer":	{"VB","VBP"},
"beleaguered":	{"VBD","VBN","JJ"},
"beleaguering":	{"VBG"},
"beleaguers":	{"VBZ"},
"belem":	{"NN"},
"belemnite":	{"NN"},
"belemnitic":	{"JJ"},
"belemnitidae":	{"NN"},
"belemnoidea":	{"NN"},
"belfries":	{"NNS"},
"belfry":	{"NN"},
"belgique":	{"NN"},
"belie":	{"VB","VBP"},
"belied":	{"VBD","VBN"},
"belief":	{"NN"},
"beliefs":	{"NNS"},
"belies":	{"VBZ"},
"believability":	{"NN"},
"believable":	{"JJ"},
"believably":	{"RB"},
"believe":	{"VB","VBP"},
"believed":	{"VBD","VBN"},
"believer":	{"NN"},
"believers":	{"NNS"},
"believes":	{"VBZ"},
"believing":	{"VBG"},
"believingly":	{"RB"},
"belike":	{"RB"},
"belinda":	{"NN"},
"belisarius":	{"NNS"},
"belittle":	{"VB","VBP"},
"belittled":	{"VBD","VBN"},
"belittlement":	{"NN"},
"belittles":	{"VBZ"},
"belittling":	{"VBG","JJ"},
"bell":	{"NN"},
"bell-bottom":	{"JJ"},
"bell-bottomed":	{"JJ"},
"bell-bottoms":	{"NNS"},
"bell-ringer":	{"NN"},
"bell-ringers":	{"NNS"},
"bell-ringing":	{"NN"},
"bell-shaped":	{"JJ"},
"belladonna":	{"NN"},
"bellarmine":	{"NN"},
"bellarmino":	{"NN"},
"bellbird":	{"NN"},
"bellbottom":	{"NN","JJ"},
"bellboy":	{"NN"},
"bellboys":	{"NNS"},
"belle":	{"NN"},
"belled":	{"JJ"},
"bellerophon":	{"NN"},
"belles":	{"NNS"},
"belles-lettres":	{"NNS"},
"belletristic":	{"JJ"},
"bellevue":	{"NN"},
"bellflower":	{"NN"},
"bellhop":	{"NN"},
"bellhops":	{"NNS"},
"bellicose":	{"JJ"},
"bellicoseness":	{"NN"},
"bellicosity":	{"NN"},
"bellied":	{"JJ","VBD","VBN"},
"bellies":	{"NNS","VBZ"},
"belligerence":	{"NN"},
"belligerency":	{"NN"},
"belligerent":	{"JJ"},
"belligerently":	{"RB"},
"belling":	{"NN","VBG"},
"bellis":	{"NN"},
"bellman":	{"NN"},
"belloc":	{"NN"},
"bellow":	{"VB","VBP","NN"},
"bellowed":	{"VBD","VBN"},
"bellower":	{"NN"},
"bellowing":	{"VBG"},
"bellows":	{"NNS","VBZ"},
"bellpull":	{"NN"},
"bellringers":	{"NNS"},
"bells":	{"NNS","VBZ"},
"bellwether":	{"NN"},
"bellwethers":	{"NNS"},
"bellwort":	{"NN"},
"belly":	{"NN","VBP","VB"},
"belly-flop":	{"VB","VBP"},
"belly-flopped":	{"VBD","VBN"},
"belly-flopping":	{"VBG"},
"belly-flops":	{"VBZ"},
"belly-land":	{"VB"},
"belly-up":	{"RB"},
"bellyache":	{"NN","VB","VBP"},
"bellyached":	{"VBD","VBN"},
"bellyacher":	{"NN"},
"bellyaches":	{"NNS","VBZ"},
"bellyaching":	{"VBG"},
"bellyband":	{"NN"},
"bellybutton":	{"NN"},
"bellyflop":	{"VB","VBP"},
"bellyflopped":	{"VBD","VBN"},
"bellyflopping":	{"VBG"},
"bellyflops":	{"VBZ"},
"bellyful":	{"NN","JJ"},
"bellyfull":	{"NN"},
"bellying":	{"JJ","VBG"},
"bellylaugh":	{"VB"},
"bellyless":	{"JJ"},
"belmont":	{"NN"},
"belong":	{"VB","VBP"},
"belonged":	{"VBD","VBN"},
"belonging":	{"NN","VBG"},
"belongings":	{"NNS"},
"belongs":	{"VBZ"},
"belonidae":	{"NN"},
"belorussia":	{"NN"},
"belostomatidae":	{"NN"},
"beloved":	{"JJ","VBD","VBN"},
"below":	{"IN","RB"},
"below-average":	{"JJ"},
"below-investment":	{"JJ"},
"below-investment-grade":	{"JJ"},
"below-market":	{"JJ"},
"belowground":	{"JJ"},
"belsen":	{"NN"},
"belt":	{"NN","VB","VBP"},
"belt-driven":	{"JJ"},
"belt-fed":	{"JJ"},
"belt-like":	{"JJ"},
"belt-shaped":	{"JJ"},
"belt-tightening":	{"NN"},
"belted":	{"JJ","VBD","VBN"},
"belting":	{"NN","VBG"},
"beltless":	{"JJ"},
"beltlike":	{"JJ"},
"belts":	{"NNS","VBZ"},
"beltway":	{"NN"},
"beltways":	{"NNS"},
"beluga":	{"NN"},
"belvedere":	{"NN"},
"belying":	{"VBG"},
"bema":	{"NN"},
"bemaddening":	{"VBG"},
"bemidji":	{"NN"},
"bemire":	{"VB"},
"bemisia":	{"NN"},
"bemoan":	{"VB","VBP"},
"bemoaned":	{"VBD","VBN"},
"bemoaning":	{"VBG"},
"bemoans":	{"VBZ"},
"bemock":	{"VB"},
"bemocked":	{"VBD","VBN"},
"bemocking":	{"VBG"},
"bemocks":	{"VBZ"},
"bemuse":	{"VB","VBP"},
"bemused":	{"JJ","VBD","VBN"},
"bemusedly":	{"RB"},
"bemusement":	{"NN"},
"bemuses":	{"VBZ"},
"bemusing":	{"VBG"},
"ben":	{"NN"},
"benadryl":	{"NN"},
"bench":	{"NN","VB","VBP"},
"benched":	{"VBN","VBD"},
"benches":	{"NNS","VBZ"},
"benching":	{"VBG"},
"benchmark":	{"NN","VB","VBP"},
"benchmarked":	{"VBD","VBN"},
"benchmarking":	{"VBG","NN"},
"benchmarks":	{"NNS","VBZ"},
"bend":	{"VB","VBP","NN"},
"bendability":	{"NN"},
"bendable":	{"JJ"},
"benday":	{"NN"},
"bended":	{"JJ"},
"bender":	{"NN"},
"bending":	{"VBG"},
"bendopa":	{"NN"},
"bends":	{"NNS","VBZ"},
"beneath":	{"IN","RB"},
"benedick":	{"NN"},
"benedict":	{"NN"},
"benediction":	{"NN"},
"benedictive":	{"JJ"},
"benedictory":	{"NN"},
"benefact":	{"VB"},
"benefaction":	{"NN"},
"benefactor":	{"NN"},
"benefactors":	{"NNS"},
"benefactress":	{"NN"},
"benefic":	{"JJ"},
"benefice":	{"NN","VB"},
"beneficed":	{"JJ"},
"beneficence":	{"NN"},
"beneficent":	{"JJ","NN"},
"beneficial":	{"JJ"},
"beneficially":	{"RB"},
"beneficiaries":	{"NNS"},
"beneficiary":	{"NN"},
"beneficiate":	{"VB"},
"beneficiation":	{"NN"},
"beneficient":	{"JJ"},
"benefit":	{"NN","VB","VBP"},
"benefit-plan":	{"JJ"},
"benefit-seeking":	{"NN"},
"benefited":	{"VBD","VBN"},
"benefiting":	{"VBG"},
"benefits":	{"NNS","VBZ"},
"benefits-consulting":	{"JJ"},
"benefits-for-all":	{"JJ"},
"benefits-services":	{"JJ"},
"benefitted":	{"VBD","VBN"},
"benefitting":	{"VBG"},
"benelux":	{"NN"},
"benet":	{"NN"},
"benetton":	{"NN"},
"benevolence":	{"NN"},
"benevolent":	{"JJ","NN"},
"benevolently":	{"RB"},
"benficiate":	{"VB"},
"bengals-browns":	{"JJ"},
"benghazi":	{"NN"},
"benight":	{"VB","VBP"},
"benighted":	{"JJ","VBD","VBN"},
"benighting":	{"VBG"},
"benights":	{"VBZ"},
"benign":	{"JJ"},
"benignancy":	{"NN"},
"benignant":	{"JJ"},
"benignantly":	{"RB"},
"benignity":	{"NN"},
"benignly":	{"RB"},
"benin":	{"NN"},
"beninese":	{"JJ","NN"},
"benison":	{"NN"},
"benjamin":	{"NN"},
"benne":	{"NN"},
"bennet":	{"NN"},
"bennettitaceae":	{"NN"},
"bennettitales":	{"NNS"},
"bennettitis":	{"NN"},
"benni":	{"NN"},
"bennie":	{"NN"},
"benniseed":	{"VBD","VBN"},
"benny":	{"NN"},
"bent":	{"NN","JJ","VBD","VBN"},
"bent-grass":	{"NN"},
"benthal":	{"JJ"},
"benthic":	{"JJ"},
"benthonic":	{"JJ"},
"benthos":	{"NNS"},
"bentonite":	{"NN"},
"bentonitic":	{"JJ"},
"bentsen":	{"NN"},
"bentwood":	{"JJ","NN"},
"benumb":	{"VB"},
"benumbed":	{"JJ","VBD","VBN"},
"benumbing":	{"VBG"},
"benumbs":	{"VBZ"},
"benweed":	{"VBD","VBN"},
"benzene":	{"NN"},
"benzenoid":	{"JJ"},
"benzine":	{"NN"},
"benzoate":	{"NN"},
"benzocaine":	{"NN"},
"benzodiazepine":	{"NN"},
"benzodiazepines":	{"NNS"},
"benzofuran":	{"NN"},
"benzoic":	{"JJ"},
"benzoin":	{"NN"},
"benzol":	{"NN"},
"benzoquinone":	{"NN"},
"benzyl":	{"NN"},
"benzylic":	{"JJ"},
"benzylpenicillin":	{"NN"},
"beograd":	{"NN"},
"beplaster":	{"VB"},
"bequeath":	{"VB","VBP"},
"bequeathed":	{"VBD","VBN"},
"bequeathing":	{"VBG"},
"bequeaths":	{"VBZ"},
"bequest":	{"NN"},
"bequests":	{"NNS"},
"berate":	{"VB","VBP"},
"berated":	{"VBD","VBN"},
"berates":	{"VBZ"},
"berating":	{"VBG"},
"berberidaceae":	{"NN"},
"berberis":	{"NN"},
"berceuse":	{"NN"},
"bercy":	{"NN"},
"bereave":	{"VB","VBP"},
"bereaved":	{"JJ","VBD","VBN","NN","NNS"},
"bereavement":	{"NN"},
"bereavements":	{"NNS"},
"bereaves":	{"VBZ"},
"bereaving":	{"VBG"},
"bereft":	{"JJ","NN","VBD","VBN"},
"beret":	{"NN"},
"berettas":	{"NNS"},
"berg":	{"NN"},
"bergall":	{"NN"},
"bergamot":	{"NN"},
"bergenia":	{"NN"},
"bergs":	{"NNS"},
"beria":	{"NN"},
"beribboned":	{"JJ"},
"beriberi":	{"NN"},
"berit":	{"NN"},
"berith":	{"NN"},
"berk":	{"NN"},
"berkelium":	{"NN"},
"berkshire":	{"NN"},
"berkshires":	{"NNS"},
"berlage":	{"NN"},
"berlin":	{"NN"},
"berliner":	{"NN"},
"berlioz":	{"NN"},
"berm":	{"NN"},
"berman":	{"NN"},
"berms":	{"NNS"},
"bermuda-based":	{"JJ"},
"bermuda-registered":	{"JJ"},
"bermudan":	{"JJ","NN"},
"bermudas":	{"NNS"},
"bermudian":	{"NN"},
"bern":	{"NN"},
"bernard":	{"NN"},
"berne":	{"NN"},
"bernhardt":	{"NN"},
"bernini":	{"NN"},
"bernoulli":	{"NN"},
"bernstein":	{"NN"},
"bernz-o-matic":	{"NN"},
"beroe":	{"NN"},
"berretta":	{"NN"},
"berried":	{"JJ","VBD","VBN"},
"berries":	{"NNS","VBZ"},
"berry":	{"VB","VBP","NN"},
"berrying":	{"VBG"},
"berrylike":	{"JJ"},
"berserk":	{"JJ","NN"},
"berserker":	{"NN"},
"berteroa":	{"NN"},
"berth":	{"NN","VB","VBP"},
"berthed":	{"VBD","VBN"},
"berthing":	{"VBG"},
"bertholletia":	{"NN"},
"berths":	{"VBZ","NNS"},
"bertillon":	{"NN"},
"bertolucci":	{"NN"},
"bertrand":	{"NN"},
"berycomorphi":	{"NN"},
"beryl":	{"NN"},
"beryllium":	{"NN"},
"berzelius":	{"NN"},
"beseech":	{"VB","VBP"},
"beseeched":	{"VBD","VBN"},
"beseeches":	{"VBZ"},
"beseeching":	{"JJ","VBG"},
"beseechingly":	{"RB"},
"beseem":	{"VB"},
"beseemed":	{"VBD","VBN"},
"beseeming":	{"VBG"},
"beseems":	{"VBZ"},
"beseiged":	{"VBN"},
"beset":	{"VB","VBP","VBD","VBN"},
"besets":	{"VBZ"},
"besetting":	{"VBG","JJ"},
"beshrew":	{"VB"},
"beside":	{"IN","RB"},
"besides":	{"IN","RB"},
"besiege":	{"VB","VBP"},
"besieged":	{"VBD","VBN"},
"besieger":	{"NN"},
"besiegers":	{"NNS"},
"besieges":	{"VBZ"},
"besieging":	{"VBG"},
"besmear":	{"VB"},
"besmeared":	{"VBD","VBN"},
"besmearing":	{"VBG"},
"besmears":	{"VBZ"},
"besmirch":	{"VB","VBP"},
"besmirched":	{"VBD","VBN"},
"besmirches":	{"VBZ"},
"besmirching":	{"VBG"},
"besom":	{"NN"},
"besot":	{"VB"},
"besotted":	{"JJ"},
"besought":	{"VBD","VBN"},
"bespangle":	{"VB"},
"bespatter":	{"VB"},
"bespattered":	{"VBD","VBN"},
"bespattering":	{"VBG"},
"bespatters":	{"VBZ"},
"bespeak":	{"VB","VBP"},
"bespeaking":	{"VBG"},
"bespeaks":	{"VBZ"},
"bespeckle":	{"VB"},
"bespectacled":	{"JJ"},
"bespoke":	{"JJ","VBD","VBN"},
"bespoken":	{"VBN"},
"bespot":	{"VB","VBP"},
"bespoted":	{"VBD","VBN"},
"bespoting":	{"VBG"},
"bespots":	{"VBZ"},
"besprent":	{"JJ"},
"besprinkle":	{"VB"},
"bess":	{"NN"},
"bessel":	{"NN"},
"bessemer":	{"NN"},
"bessera":	{"NN"},
"besseya":	{"NN"},
"bessie":	{"NN"},
"best":	{"JJS","RBS","NN","VB","VBP"},
"best-case":	{"JJ","NN"},
"best-educated":	{"JJ"},
"best-financed":	{"JJ"},
"best-gaited":	{"JJ"},
"best-hearted":	{"JJ"},
"best-known":	{"JJS"},
"best-looking":	{"JJ"},
"best-loved":	{"JJ"},
"best-managed":	{"JJ"},
"best-of-seven":	{"JJ"},
"best-off":	{"JJS"},
"best-pitcher":	{"JJ"},
"best-preserved":	{"JJ"},
"best-seller":	{"NN"},
"best-sellers":	{"NNS"},
"best-selling":	{"JJ"},
"best-tempered":	{"JJ"},
"bested":	{"VBN","VBD"},
"bestes":	{"NNS"},
"bestial":	{"JJ","NN"},
"bestialise":	{"VB","VBP"},
"bestialised":	{"VBD","VBN"},
"bestialises":	{"VBZ"},
"bestialising":	{"VBG"},
"bestiality":	{"NN"},
"bestialize":	{"VB","VBP"},
"bestialized":	{"VBD","VBN"},
"bestializes":	{"VBZ"},
"bestializing":	{"VBG"},
"bestially":	{"RB"},
"bestiary":	{"NN"},
"bestie":	{"NN"},
"besties":	{"NNS"},
"besting":	{"VBG"},
"bestioles":	{"NNS"},
"bestir":	{"VB","VBP"},
"bestirred":	{"VBD","VBN"},
"bestirring":	{"VBG"},
"bestirs":	{"VBZ"},
"bestow":	{"VB","VBP"},
"bestowal":	{"NN"},
"bestowed":	{"VBD","VBN"},
"bestower":	{"NN"},
"bestowing":	{"VBG"},
"bestowment":	{"NN"},
"bestows":	{"VBZ"},
"bestrew":	{"VB","VBP"},
"bestrewed":	{"VBD","VBN"},
"bestrewing":	{"VBG"},
"bestrews":	{"VBZ"},
"bestridden":	{"VBN"},
"bestride":	{"VB","VBP"},
"bestrides":	{"VBZ"},
"bestriding":	{"VBG"},
"bestrode":	{"VBD"},
"bests":	{"VBZ"},
"bestseller":	{"NN"},
"bestsellers":	{"NNS"},
"bestselling":	{"JJ"},
"bestubbled":	{"JJ"},
"besuboru":	{"FW"},
"bet":	{"NN","VB","VBP","VBN","VBD"},
"beta":	{"NN"},
"beta-adrenoceptor":	{"NN"},
"beta-blocker":	{"JJ","NN"},
"beta-carotene":	{"NN"},
"beta-interferon":	{"NN"},
"beta-lactamase":	{"NN"},
"beta-lipoprotein":	{"NN"},
"beta-naphthol":	{"NN"},
"beta-thalassemia":	{"NN"},
"betaine":	{"NN"},
"betas":	{"NNS"},
"betatron":	{"NN"},
"bete":	{"NN"},
"betel":	{"NN"},
"betel-stained":	{"JJ"},
"betelgeuse":	{"NN"},
"beth":	{"NN"},
"bethe":	{"NN"},
"bethel":	{"NN"},
"bethink":	{"VB","VBP"},
"bethinking":	{"VBG"},
"bethinks":	{"VBZ"},
"bethle":	{"NN"},
"bethlehem":	{"NN"},
"bethlehem-judah":	{"NN"},
"bethought":	{"VBD","VBN"},
"bethune":	{"NN"},
"betide":	{"VB","VBP"},
"betided":	{"VBD","VBN"},
"betides":	{"VBZ"},
"betiding":	{"VBG"},
"betimes":	{"RB"},
"betise":	{"NN"},
"betoken":	{"VB","VBP"},
"betokened":	{"VBD","VBN"},
"betokening":	{"VBG"},
"betokens":	{"VBZ"},
"betray":	{"VB","NN","VBP"},
"betrayal":	{"NN"},
"betrayed":	{"VBD","VBN"},
"betrayer":	{"NN"},
"betraying":	{"VBG"},
"betrays":	{"VBZ","NNS"},
"betroth":	{"VB","VBP"},
"betrothal":	{"NN"},
"betrothals":	{"NNS"},
"betrothed":	{"JJ","VBD","VBN","NN"},
"betrothing":	{"VBG"},
"betroths":	{"VBZ"},
"bets":	{"NNS","VBZ"},
"betsy":	{"NN"},
"betted":	{"VBD","VBN"},
"better":	{"JJR","RBR","NN","VB","VBP"},
"better-capitalized":	{"JJ"},
"better-educated":	{"JJ"},
"better-known":	{"JJR"},
"better-looking":	{"JJ"},
"better-off":	{"JJR"},
"better-paying":	{"JJ"},
"better-prepared":	{"JJ"},
"better-quality":	{"JJ"},
"better-remembered":	{"JJ"},
"better-safe-than":	{"JJ"},
"better-selling":	{"JJ"},
"better-than-average":	{"JJ"},
"better-than-expected":	{"JJ","NN"},
"better-than-thou":	{"JJ"},
"bettered":	{"VBD","VBN"},
"bettering":	{"VBG"},
"betterment":	{"NN"},
"betters":	{"NNS","VBZ"},
"betties":	{"NNS"},
"betting":	{"VBG","NN"},
"bettong":	{"NN"},
"bettongia":	{"NN"},
"bettor":	{"NN"},
"betts":	{"NNS"},
"betula":	{"NN"},
"betulaceae":	{"NN"},
"betulaceous":	{"JJ"},
"between":	{"IN","RB"},
"betweenbrain":	{"NN"},
"betwixt":	{"RB","IN"},
"bevacizumab":	{"NN"},
"bevatron":	{"NN"},
"bevel":	{"NN","VB","VBP"},
"beveled":	{"VBN","VBD","JJ"},
"beveling":	{"VBG"},
"bevelled":	{"VBD","VBN","JJ"},
"bevelling":	{"VBG"},
"bevels":	{"NNS","VBZ"},
"beverage":	{"NN"},
"beverages":	{"NNS"},
"beveridge":	{"NN"},
"beverly":	{"NN"},
"bevin":	{"NN"},
"bevor":	{"NN"},
"bevy":	{"NN"},
"bewail":	{"VB","VBP"},
"bewailed":	{"VBD","VBN"},
"bewailing":	{"VBG"},
"bewails":	{"VBZ"},
"beware":	{"VB","VBP"},
"bewared":	{"VBD","VBN"},
"bewares":	{"VBZ"},
"bewaring":	{"VBG"},
"beween":	{"NN"},
"bewhisker":	{"VB"},
"bewhiskered":	{"JJ"},
"bewilder":	{"VB","VBP"},
"bewildered":	{"JJ","VBD","VBN"},
"bewilderedly":	{"RB"},
"bewildering":	{"JJ","VBG"},
"bewilderingly":	{"RB"},
"bewilderment":	{"NN"},
"bewilders":	{"VBZ"},
"bewitch":	{"VB","VBP"},
"bewitched":	{"VBD","VBN"},
"bewitchery":	{"NN"},
"bewitches":	{"VBZ"},
"bewitching":	{"JJ","VBG"},
"bewitchingly":	{"RB"},
"bewitchment":	{"NN"},
"bewray":	{"VB"},
"bewrayed":	{"VBD","VBN"},
"bewraying":	{"VBG"},
"bewrays":	{"VBZ"},
"bewteen":	{"IN"},
"bextra":	{"NN"},
"bey":	{"NN"},
"beyond":	{"IN","RB","NN"},
"beyond-normal":	{"JJ"},
"bezant":	{"NN"},
"bezel":	{"NN"},
"bezique":	{"NN"},
"bezzant":	{"NN"},
"bh":	{"NN"},
"bhadon":	{"NN"},
"bhadrapada":	{"NN"},
"bhaga":	{"NN"},
"bhagat":	{"NN"},
"bhagavad-gita":	{"NN"},
"bhagavadgita":	{"NN"},
"bhakti":	{"NN"},
"bhang":	{"NN"},
"bharat":	{"NN"},
"bhoy":	{"NN"},
"bhutan":	{"NN"},
"bhutanese":	{"JJ","NN"},
"bhutani":	{"NN"},
"bi-modal":	{"JJ"},
"bi-monthly":	{"JJ"},
"bi-polar":	{"JJ"},
"bi-regional":	{"JJ"},
"bialy":	{"NN"},
"bialystoker":	{"NN"},
"bianco":	{"NN"},
"biannual":	{"JJ"},
"biannually":	{"RB"},
"bias":	{"NN","VBP","JJ","RB","VB"},
"biased":	{"JJ","VBD","VBN"},
"biases":	{"VBZ","NNS"},
"biasing":	{"VBG"},
"biassed":	{"VBD","VBN"},
"biasses":	{"VBZ"},
"biassing":	{"VBG"},
"biaural":	{"JJ"},
"biauricular":	{"JJ"},
"biaxal":	{"JJ"},
"biaxate":	{"JJ"},
"biaxial":	{"JJ"},
"bib":	{"NN"},
"bib-and-tucker":	{"NN"},
"bibbed":	{"JJ","VBD","VBN"},
"bibbing":	{"VBG"},
"bible":	{"NN"},
"bible-emancipated":	{"JJ"},
"bible-loving":	{"JJ"},
"bible-worship":	{"NN"},
"bibles":	{"NNS"},
"bibless":	{"JJ"},
"biblical":	{"JJ","NN"},
"biblically":	{"RB"},
"bibliographer":	{"NN"},
"bibliographic":	{"JJ"},
"bibliographical":	{"JJ"},
"bibliographies":	{"NNS"},
"bibliography":	{"NN"},
"bibliolatrous":	{"JJ"},
"bibliolatry":	{"NN"},
"bibliomania":	{"NN"},
"bibliomaniacal":	{"JJ"},
"bibliometrics":	{"NN"},
"bibliophile":	{"NN"},
"bibliophiles":	{"NNS"},
"bibliophilic":	{"JJ"},
"bibliopole":	{"NN"},
"bibliopolic":	{"JJ"},
"bibliopolist":	{"NN"},
"bibliothec":	{"NN"},
"bibliotheca":	{"NN"},
"bibliothecal":	{"JJ"},
"bibliothecarial":	{"JJ"},
"bibliotic":	{"JJ"},
"bibliotics":	{"NN"},
"bibliotist":	{"NN"},
"bibos":	{"NN"},
"bibs":	{"NNS","VBZ"},
"bibulous":	{"JJ"},
"bicameral":	{"JJ"},
"bicapsular":	{"JJ"},
"bicarbonate":	{"NN"},
"bicentenary":	{"NN","JJ"},
"bicentennial":	{"NN","JJ"},
"bicentric":	{"JJ"},
"bicep":	{"NN"},
"bicephalous":	{"JJ"},
"biceps":	{"NNS"},
"bich":	{"NN"},
"biches":	{"NNS"},
"bichloride":	{"NN"},
"bichromate":	{"NN"},
"bichromated":	{"JJ"},
"bichrome":	{"JJ"},
"bicipital":	{"JJ"},
"bicker":	{"VB","VBP"},
"bickered":	{"VBD","VBN"},
"bickering":	{"NN","VBG"},
"bickers":	{"VBZ"},
"bicolor":	{"NN"},
"bicolored":	{"JJ"},
"bicolour":	{"JJ"},
"bicoloured":	{"JJ"},
"biconcave":	{"JJ"},
"biconvex":	{"JJ"},
"bicorn":	{"JJ","NN"},
"bicornate":	{"JJ"},
"bicorne":	{"NN"},
"bicorned":	{"JJ"},
"bicornuate":	{"JJ"},
"bicornuous":	{"JJ"},
"bicuspid":	{"JJ","NN"},
"bicuspidate":	{"JJ"},
"bicycle":	{"NN","VBP","VB"},
"bicycle-auto":	{"JJ"},
"bicycle-built-for-two":	{"NN"},
"bicycled":	{"VBD","VBN"},
"bicycler":	{"NN"},
"bicycles":	{"NNS","VBZ"},
"bicyclic":	{"JJ"},
"bicycling":	{"VBG","NN"},
"bicyclist":	{"NN"},
"bicylindrical":	{"JJ"},
"bid":	{"NN","VB","VBD","VBN","VBP"},
"bid-asked":	{"JJ"},
"bid-rigging":	{"NN"},
"bid-to-cover":	{"JJ","NN"},
"bid-wanted":	{"JJ"},
"bida":	{"NN"},
"biddable":	{"JJ"},
"bidden":	{"VBN"},
"bidder":	{"NN"},
"bidders":	{"NNS"},
"biddies":	{"NNS"},
"bidding":	{"NN","VBG"},
"biddy":	{"NN"},
"bide":	{"VB","VBP"},
"bided":	{"VBD","VBN"},
"biden":	{"NN"},
"bidens":	{"NNS"},
"bidentate":	{"JJ"},
"bides":	{"VBZ"},
"bidet":	{"NN"},
"bidets":	{"NNS"},
"biding":	{"VBG"},
"bidirectional":	{"JJ"},
"bids":	{"NNS","VBZ"},
"biedermeier":	{"JJ"},
"bien":	{"FW"},
"biennial":	{"NN","JJ"},
"biennially":	{"RB"},
"biennium":	{"NN"},
"bier":	{"NN"},
"bierce":	{"NN"},
"biface":	{"JJ"},
"bifacial":	{"JJ"},
"biff":	{"NN","VB","VBP"},
"biffed":	{"VBD","VBN"},
"biffing":	{"VBG"},
"biffs":	{"VBZ","NNS"},
"bifid":	{"JJ"},
"bifilar":	{"JJ"},
"biflagellate":	{"JJ"},
"bifocal":	{"JJ"},
"bifocals":	{"NNS"},
"bifoliate":	{"JJ"},
"biform":	{"JJ"},
"bifurcate":	{"VB","VBP"},
"bifurcated":	{"VBD","VBN"},
"bifurcates":	{"VBZ"},
"bifurcating":	{"VBG"},
"bifurcation":	{"NN"},
"bifurcations":	{"NNS"},
"big":	{"JJ","RB","VB","VBP"},
"big-bellied":	{"JJ"},
"big-boned":	{"JJ"},
"big-borrowing":	{"JJ"},
"big-bucks":	{"JJ"},
"big-budget":	{"JJ"},
"big-business":	{"JJ","NN"},
"big-chested":	{"JJ"},
"big-city":	{"JJ","NN"},
"big-company":	{"JJ"},
"big-daddy":	{"JJ"},
"big-deposit":	{"JJ"},
"big-fee":	{"JJ"},
"big-game":	{"JJ"},
"big-hearted":	{"JJ"},
"big-large":	{"NN"},
"big-league":	{"JJ"},
"big-money":	{"JJ"},
"big-name":	{"JJ"},
"big-risk":	{"JJ"},
"big-screen":	{"JJ"},
"big-selling":	{"JJ"},
"big-shouldered":	{"JJ"},
"big-souled":	{"JJ"},
"big-stage":	{"JJ"},
"big-stakes":	{"JJ"},
"big-stock":	{"JJ"},
"big-ticket":	{"JJ"},
"big-time":	{"JJ"},
"big-town":	{"JJ"},
"big-tube":	{"JJ"},
"bigamist":	{"NN"},
"bigamous":	{"JJ"},
"bigamy":	{"NN"},
"bigarade":	{"NN"},
"bigeminal":	{"JJ"},
"bigeneric":	{"JJ"},
"bigeye":	{"NN"},
"bigged":	{"VBD","VBN"},
"bigger":	{"JJR"},
"bigger-than-expected":	{"JJ"},
"biggest":	{"JJS"},
"biggest-ever":	{"JJ"},
"biggest-selling":	{"JJ"},
"biggie":	{"NN"},
"biggin":	{"NN"},
"bigging":	{"VBG"},
"biggish":	{"JJ"},
"bighead":	{"NN"},
"bigheaded":	{"JJ"},
"bighearted":	{"JJ"},
"bigheartedness":	{"NN"},
"bighorn":	{"NN"},
"bight":	{"NN","VB","VBP"},
"bighted":	{"VBD","VBN"},
"bighting":	{"VBG"},
"bights":	{"NNS","VBZ"},
"bigmouthed":	{"JJ"},
"bigness":	{"NN"},
"bignonia":	{"NN"},
"bignoniaceae":	{"NN"},
"bignoniaceous":	{"JJ"},
"bignoniad":	{"NN"},
"bigos":	{"NNS"},
"bigot":	{"NN"},
"bigoted":	{"JJ"},
"bigotry":	{"NN"},
"bigots":	{"NNS"},
"bigram":	{"NN"},
"bigs":	{"VBZ"},
"bigticket":	{"NN"},
"bigwig":	{"NN"},
"bihar":	{"NN"},
"bihari":	{"NN"},
"bijections":	{"NNS"},
"bijou":	{"JJ","NN"},
"bijouterie":	{"FW"},
"bikable":	{"JJ"},
"bike":	{"NN","VBP","VB"},
"bikeable":	{"JJ"},
"biked":	{"VBD","VBN"},
"biker":	{"NN"},
"bikers":	{"NNS"},
"bikes":	{"NNS","VBZ"},
"biking":	{"VBG","NN"},
"bikini":	{"NN"},
"bikinis":	{"NNS"},
"bilabial":	{"JJ","NN"},
"bilabiate":	{"JJ"},
"bilateral":	{"JJ","NN"},
"bilateralism":	{"NN"},
"bilaterality":	{"NN"},
"bilaterally":	{"RB"},
"bilbao":	{"NN"},
"bilberry":	{"NN"},
"bilby":	{"NN"},
"bile":	{"NN"},
"bilestone":	{"NN"},
"bilevel":	{"JJ"},
"bilge":	{"NN"},
"bilged":	{"VBD","VBN"},
"bilges":	{"NNS","VBZ"},
"bilgewater":	{"NN"},
"bilging":	{"VBG"},
"bilgy":	{"JJ"},
"bilharzia":	{"NN"},
"bilharziasis":	{"NN"},
"biliary":	{"JJ","NN"},
"bilimbi":	{"NN"},
"bilinear":	{"JJ"},
"bilingual":	{"JJ","NN"},
"bilingualism":	{"NN"},
"bilingualist":	{"NN"},
"bilingually":	{"RB"},
"bilious":	{"JJ"},
"biliousness":	{"NN"},
"bilirubin":	{"NN"},
"bilk":	{"VB","VBP"},
"bilked":	{"VBD","VBN"},
"bilking":	{"VBG"},
"bilks":	{"VBZ"},
"bill":	{"NN","VB","VBP"},
"bill-introduced":	{"NN"},
"billable":	{"JJ"},
"billabong":	{"NN"},
"billboard":	{"VB","NN"},
"billboarded":	{"VBD","VBN"},
"billboarding":	{"VBG"},
"billboards":	{"VBZ","NNS"},
"billed":	{"VBD","VBN"},
"billet":	{"NN","VB","VBP"},
"billeted":	{"VBD","VBN"},
"billeting":	{"VBG"},
"billets":	{"NNS","VBZ"},
"billfish":	{"NN"},
"billfold":	{"NN"},
"billhook":	{"NN"},
"billiard":	{"JJ","NN"},
"billiards":	{"NN"},
"billie":	{"NN"},
"billing":	{"NN","VBG"},
"billings":	{"NNS"},
"billingsgate":	{"NN"},
"billion":	{"CD","NN","NNS"},
"billion-a":	{"JJ"},
"billion-asset":	{"JJ"},
"billion-dollar":	{"JJ"},
"billion-franc":	{"NN"},
"billion-peso":	{"JJ"},
"billion-pound":	{"JJ"},
"billion-share":	{"JJ"},
"billion-yen":	{"JJ"},
"billionaire":	{"NN"},
"billionaires":	{"NNS"},
"billions":	{"NNS"},
"billionth":	{"NN","JJ"},
"billon":	{"NN"},
"billow":	{"VB","VBP","NN"},
"billowed":	{"VBD","VBN"},
"billowing":	{"VBG"},
"billows":	{"VBZ","NNS"},
"billowy":	{"JJ"},
"bills":	{"NNS","VBZ"},
"bills-measures":	{"JJ"},
"billy":	{"NN"},
"billy-ho":	{"NN"},
"billyo":	{"NN"},
"billyoh":	{"NN"},
"billystick":	{"NN"},
"bilobate":	{"JJ"},
"bilobated":	{"JJ"},
"bilobed":	{"JJ"},
"bilocation":	{"NN"},
"bilocular":	{"JJ"},
"biloculate":	{"JJ"},
"biloxi":	{"NN"},
"bilsted":	{"VBD","VBN"},
"biltong":	{"NN"},
"bimanual":	{"JJ"},
"bimbo":	{"NN"},
"bimbos":	{"NNS"},
"bimester":	{"NN"},
"bimestrial":	{"JJ"},
"bimetal":	{"JJ","NN"},
"bimetallic":	{"JJ"},
"bimetallism":	{"NN"},
"bimetallist":	{"NN"},
"bimetallistic":	{"JJ"},
"bimillenary":	{"NN"},
"bimillenial":	{"JJ"},
"bimillennium":	{"NN"},
"bimli":	{"NN"},
"bimodal":	{"JJ"},
"bimolecular":	{"JJ"},
"bimonthly":	{"RB","JJ"},
"bimorphemic":	{"JJ"},
"bimotored":	{"JJ"},
"bin":	{"NN","VBP","VB"},
"binary":	{"JJ","NN"},
"binate":	{"JJ"},
"binational":	{"JJ"},
"binaural":	{"JJ"},
"binaurally":	{"RB"},
"bind":	{"VB","NN","VBP"},
"bindable":	{"JJ"},
"binder":	{"NN"},
"binders":	{"NNS"},
"bindery":	{"NN"},
"binding":	{"JJ","NN","VBG"},
"bindle":	{"NN"},
"binds":	{"VBZ","NNS"},
"bindweed":	{"NN"},
"bine":	{"NN"},
"binet":	{"NN"},
"binful":	{"NN"},
"bing":	{"NN"},
"binge":	{"VB","VBP","NN"},
"binged":	{"VBD","VBN"},
"bingeing":	{"VBG"},
"binger":	{"NN"},
"binges":	{"NNS","VBZ"},
"binghamton":	{"NN"},
"binging":	{"VBG"},
"bingle":	{"NN"},
"bingles":	{"NNS"},
"bingo":	{"NN","UH"},
"bingo-like":	{"JJ"},
"binnacle":	{"NN"},
"binned":	{"VBD","VBN"},
"binning":	{"VBG"},
"binocular":	{"JJ"},
"binoculars":	{"NNS"},
"binomial":	{"JJ","NN"},
"binominal":	{"JJ"},
"bins":	{"NNS","VBZ"},
"binturong":	{"NN"},
"binuclear":	{"JJ"},
"binucleate":	{"JJ"},
"binucleated":	{"JJ"},
"bio":	{"NN"},
"bio-analytical":	{"JJ"},
"bio-assay":	{"NN"},
"bio-medical":	{"JJ"},
"bio-medicine":	{"NN"},
"bio-research":	{"NN"},
"bio-secure":	{"JJ"},
"bio-security":	{"NN"},
"bioactive":	{"JJ"},
"bioactivity":	{"NN"},
"bioarm":	{"NN"},
"bioassay":	{"NN","VB"},
"bioattack":	{"NN"},
"biocatalyst":	{"NN"},
"biocatalytic":	{"JJ"},
"biochar":	{"NN"},
"biochemical":	{"JJ"},
"biochemically":	{"RB"},
"biochemicals":	{"NNS"},
"biochemist":	{"NN"},
"biochemistry":	{"NN"},
"biochemists":	{"NNS"},
"biochip":	{"NN"},
"bioclimatic":	{"JJ"},
"bioclimatology":	{"NN"},
"biodefence":	{"NN"},
"biodefense":	{"NN"},
"biodegradability":	{"NN"},
"biodegradable":	{"JJ"},
"biodegradation":	{"NN"},
"biodegrade":	{"VB","VBP"},
"biodegraded":	{"VBD","VBN"},
"biodegrades":	{"VBZ"},
"biodegrading":	{"VBG"},
"biodiverse":	{"JJ"},
"biodiversity":	{"NN"},
"bioelectricity":	{"NN"},
"bioengineer":	{"NN"},
"bioengineering":	{"NN"},
"bioengineers":	{"NNS"},
"bioequivalence-therapeutic-equivalence":	{"JJ"},
"bioequivalent":	{"JJ"},
"bioethics":	{"NN"},
"biofeedback":	{"NN"},
"bioflavinoid":	{"NN"},
"biofuels":	{"NNS"},
"biogenesis":	{"NN"},
"biogenetic":	{"JJ"},
"biogenic":	{"JJ"},
"biogenous":	{"JJ"},
"biogeny":	{"NN"},
"biogeographic":	{"JJ"},
"biogeographical":	{"JJ"},
"biogeography":	{"NN"},
"biographer":	{"NN"},
"biographers":	{"NNS"},
"biographic":	{"JJ"},
"biographical":	{"JJ","NN"},
"biographies":	{"NNS"},
"biography":	{"NN"},
"biohacking":	{"NN"},
"biohazard":	{"NN"},
"bioherbicide":	{"NN"},
"bioinsecticides":	{"NNS"},
"bioko":	{"NN"},
"biolab":	{"NN"},
"biolabs":	{"NNS"},
"biologic":	{"JJ"},
"biological":	{"JJ"},
"biologically":	{"RB"},
"biologism":	{"NN"},
"biologist":	{"NN"},
"biologistic":	{"JJ"},
"biologists":	{"NNS"},
"biology":	{"NN"},
"bioluminescence":	{"NN"},
"bioluminescent":	{"JJ"},
"biomass":	{"NN"},
"biome":	{"NN"},
"biomedical":	{"JJ"},
"biomedical-products":	{"NNS"},
"biomedicine":	{"NN"},
"biometrics":	{"NN"},
"biometry":	{"NN"},
"bionic":	{"JJ"},
"bionics":	{"NN"},
"bionomic":	{"JJ"},
"bionomical":	{"JJ"},
"bionomics":	{"NN"},
"biont":	{"NN"},
"biopesticide":	{"NN"},
"biopharmaceutical":	{"JJ"},
"biophysical":	{"JJ"},
"biophysicist":	{"NN"},
"biophysics":	{"NN"},
"biopiracy":	{"NN"},
"biopsies":	{"NNS"},
"biopsy":	{"NN"},
"bioremediation":	{"NN"},
"bioresearch":	{"NN"},
"biosafety":	{"NN"},
"bioscience":	{"NN"},
"bioscope":	{"NN"},
"biosecure":	{"JJ"},
"biosecurity":	{"NN"},
"biosphere":	{"NN"},
"biostatistics":	{"NN"},
"biosynthesis":	{"NN"},
"biosynthesized":	{"VBN"},
"biosynthetic":	{"JJ"},
"biosystematic":	{"JJ"},
"biosystematics":	{"NN"},
"biosystematy":	{"NN"},
"biota":	{"NN"},
"biotech":	{"NN"},
"biotechnology":	{"NN"},
"biotechnology-based":	{"JJ"},
"bioterrorism":	{"NN"},
"biotic":	{"JJ"},
"biotin":	{"NN"},
"biotite":	{"NN"},
"biotitic":	{"JJ"},
"biotype":	{"NN"},
"biotypic":	{"JJ"},
"biovular":	{"JJ"},
"bioweapon":	{"NN"},
"biparous":	{"JJ"},
"bipartisan":	{"JJ"},
"bipartisanship":	{"NN"},
"bipartite":	{"JJ"},
"bipartizan":	{"JJ"},
"biped":	{"NN"},
"bipedal":	{"JJ"},
"bipedalism":	{"NN"},
"bipeds":	{"NNS"},
"bipinnate":	{"JJ"},
"bipinnatifid":	{"JJ"},
"biplane":	{"NN"},
"biplanes":	{"NNS"},
"bipolar":	{"JJ"},
"biprism":	{"NN"},
"biquadrate":	{"NN"},
"biquadratic":	{"JJ","NN"},
"biracial":	{"JJ","NN"},
"biradial":	{"JJ"},
"biradially":	{"RB"},
"biramous":	{"JJ"},
"birch":	{"NN","VB","VBP"},
"birch-paneled":	{"JJ"},
"birchbark":	{"NN"},
"birched":	{"VBD","VBN"},
"birchen":	{"JJ"},
"birches":	{"NNS","VBZ"},
"birching":	{"VBG"},
"bird":	{"NN"},
"bird's-eye":	{"JJ"},
"bird-brain":	{"NN","JJ"},
"bird-brains":	{"NNS"},
"bird-nest":	{"VB"},
"bird-on-the-wing":	{"NN"},
"bird-scarer":	{"NN"},
"bird-watcher":	{"NN"},
"bird-watchers":	{"NNS"},
"birdbath":	{"NN"},
"birdbrain":	{"NN"},
"birdbrained":	{"JJ"},
"birdcage":	{"NN"},
"birdcall":	{"NN"},
"birded":	{"VBD","VBN"},
"birder":	{"NN"},
"birdfeeder":	{"NN"},
"birdhouse":	{"NN"},
"birdie":	{"NN","VB","VBP"},
"birdied":	{"VBD","VBN"},
"birdieing":	{"VBG"},
"birdies":	{"NNS","VBZ"},
"birding":	{"VBG"},
"birdlike":	{"JJ"},
"birdlime":	{"NN","VB"},
"birdnest":	{"NN","VB"},
"birdnesting":	{"NN"},
"birds":	{"NNS","VBZ"},
"birdseed":	{"NN"},
"birdsong":	{"NN"},
"birdwatch":	{"VB","NN"},
"birdwatcher":	{"NN"},
"birdwatchers":	{"NNS"},
"birefringence":	{"NN"},
"birefringent":	{"JJ"},
"biretta":	{"NN"},
"biriani":	{"NN"},
"birken":	{"JJ"},
"birl":	{"VB"},
"birle":	{"VB"},
"birling":	{"NN"},
"birmingham":	{"NN"},
"biro":	{"NN"},
"birr":	{"NN"},
"birretta":	{"NN"},
"birth":	{"NN"},
"birth-control":	{"JJ","NN"},
"birth-defect":	{"NN"},
"birth-prevention":	{"NN"},
"birthcontrol":	{"NN"},
"birthday":	{"NN"},
"birthdays":	{"NNS"},
"birthed":	{"JJ","VBD","VBN"},
"birther":	{"NN"},
"birtherism":	{"NN"},
"birthers":	{"NNS"},
"birthing":	{"VBG","NN","JJ"},
"birthland":	{"NN"},
"birthmark":	{"NN"},
"birthplace":	{"NN"},
"birthrate":	{"NN"},
"birthright":	{"NN"},
"birthroot":	{"NN"},
"births":	{"NNS","VBZ"},
"birthwort":	{"NN"},
"biryani":	{"NN"},
"bisayan":	{"NN"},
"bisayas":	{"NNS"},
"biscotti":	{"NN"},
"biscuit":	{"NN"},
"biscuits":	{"NNS"},
"biscutella":	{"NN"},
"bise":	{"NN"},
"bisect":	{"VB","VBP"},
"bisected":	{"VBD","VBN"},
"bisecting":	{"VBG"},
"bisection":	{"NN"},
"bisectional":	{"JJ"},
"bisects":	{"VBZ"},
"biserrate":	{"JJ"},
"bisexual":	{"JJ","NN"},
"bisexuality":	{"NN"},
"bisexuals":	{"NNS"},
"bishkek":	{"NN"},
"bishop":	{"NN"},
"bishopric":	{"NN"},
"bishopry":	{"NN"},
"bishops":	{"NNS","NNPS","VBZ"},
"biskek":	{"NN"},
"bismarck":	{"NN"},
"bismarckian":	{"JJ"},
"bismark":	{"NN"},
"bismuth":	{"NN"},
"bismuthal":	{"JJ"},
"bismuthic":	{"JJ"},
"bison":	{"NN","NNS"},
"bisons":	{"NNS"},
"bisontine":	{"JJ"},
"bisque":	{"NN"},
"bissau":	{"NN"},
"bister":	{"NN"},
"bistered":	{"JJ"},
"bistre":	{"NN"},
"bistred":	{"JJ"},
"bistro":	{"NN"},
"bistroic":	{"JJ"},
"bistros":	{"NNS"},
"bisulcate":	{"JJ"},
"bit":	{"NN","VBD","VBN","RB"},
"bit-by-bit":	{"JJ"},
"bit-like":	{"JJ"},
"bitartrate":	{"NN"},
"bitch":	{"NN","VB","VBP"},
"bitched":	{"VBD","VBN"},
"bitchery":	{"NN"},
"bitches":	{"NNS","VBZ"},
"bitchily":	{"RB"},
"bitchin":	{"JJ"},
"bitchiness":	{"NN"},
"bitching":	{"VBG"},
"bitchy":	{"JJ"},
"bitcoin":	{"NN"},
"bitcoins":	{"NNS"},
"bite":	{"VB","VBP","NN"},
"bite-sized":	{"JJ"},
"bitee":	{"NN"},
"biteplate":	{"NN"},
"biter":	{"NN"},
"bites":	{"VBZ","NNS"},
"bitewing":	{"NN"},
"bithynia":	{"NN"},
"biting":	{"JJ","VBG"},
"bitingly":	{"RB"},
"bitis":	{"NN"},
"bitmap":	{"NN"},
"bitok":	{"NN"},
"bits":	{"NNS","VBZ"},
"bitstock":	{"NN"},
"bitt":	{"NN","VB","VBP"},
"bittacidae":	{"NN"},
"bitted":	{"VBD","VBN"},
"bitten":	{"VBN"},
"bitter":	{"JJ","NN","RB","VBP","VB"},
"bitter-bark":	{"NN"},
"bittercress":	{"NN"},
"bittered":	{"VBD","VBN"},
"bitterest":	{"JJS"},
"bittering":	{"VBG"},
"bitterish":	{"JJ"},
"bitterly":	{"RB"},
"bittern":	{"NN"},
"bitterness":	{"NN"},
"bitternut":	{"NN"},
"bitterroot":	{"NN"},
"bitters":	{"NNS","VBZ","NN"},
"bittersweet":	{"JJ","NN"},
"bitterweed":	{"NN"},
"bitterwood":	{"NN"},
"bitthead":	{"NN"},
"bittie":	{"NN"},
"bitting":	{"VBG"},
"bitts":	{"VBZ"},
"bitty":	{"JJ"},
"bitumastic":	{"NN"},
"bitumen":	{"NN"},
"bitumenoid":	{"JJ"},
"bituminise":	{"VB"},
"bituminize":	{"VB"},
"bituminoid":	{"JJ"},
"bituminous":	{"JJ"},
"biu-mandara":	{"NN"},
"bivalent":	{"JJ"},
"bivalve":	{"JJ","NN"},
"bivalved":	{"JJ"},
"bivalvia":	{"NN"},
"bivariate":	{"JJ"},
"bivouac":	{"NN","VBP","VB"},
"bivouacked":	{"VBD","VBN"},
"bivouacking":	{"VBG"},
"bivouacs":	{"NNS","VBZ"},
"biwa":	{"FW"},
"biweekly":	{"JJ","RB","NN"},
"biyearly":	{"JJ","RB"},
"biz":	{"NN"},
"bizarre":	{"JJ"},
"bizarrely":	{"RB"},
"bizarreness":	{"NN"},
"bize":	{"NN"},
"bizet":	{"NN"},
"bizonal":	{"JJ"},
"bja":	{"NN"},
"bjs":	{"NNS"},
"bk":	{"NN"},
"bl":	{"NN"},
"blab":	{"VB","VBP"},
"blabbed":	{"VBD","VBN"},
"blabber":	{"VB","VBP","NN"},
"blabbered":	{"VBD","VBN"},
"blabbering":	{"VBG"},
"blabbermouth":	{"NN"},
"blabbermouthed":	{"JJ"},
"blabbers":	{"VBZ"},
"blabbing":	{"VBG"},
"blabby":	{"JJ"},
"blaberus":	{"NN"},
"blabs":	{"VBZ"},
"black":	{"JJ","NN","VB","VBP"},
"black-and-blue":	{"JJ"},
"black-and-orange":	{"JJ"},
"black-and-tan":	{"JJ"},
"black-and-white":	{"JJ","NN"},
"black-and-yellow":	{"JJ"},
"black-balled":	{"VBN"},
"black-barred":	{"JJ"},
"black-bearded":	{"JJ"},
"black-body":	{"JJ","NN"},
"black-clad":	{"JJ"},
"black-coated":	{"JJ"},
"black-consumer":	{"NN"},
"black-crowned":	{"JJ"},
"black-draped":	{"JJ"},
"black-eyed":	{"JJ"},
"black-figured":	{"JJ"},
"black-gray":	{"JJ"},
"black-grey":	{"JJ"},
"black-haired":	{"JJ"},
"black-hearted":	{"JJ"},
"black-majority":	{"JJ"},
"black-marked":	{"JJ"},
"black-market":	{"NN"},
"black-on-black":	{"JJ"},
"black-owned":	{"JJ"},
"black-robed":	{"JJ"},
"black-seeded":	{"JJ"},
"black-tie":	{"JJ"},
"black-tipped":	{"JJ"},
"black-white":	{"JJ"},
"blackamoor":	{"NN"},
"blackball":	{"VB","VBP"},
"blackballed":	{"VBD","VBN"},
"blackballing":	{"VBG"},
"blackballs":	{"VBZ"},
"blackbeard":	{"NN"},
"blackbeetle":	{"NN"},
"blackberry":	{"NN"},
"blackberry-basil":	{"NN"},
"blackberry-lily":	{"NN"},
"blackbird":	{"NN"},
"blackbirds":	{"NNS"},
"blackboard":	{"NN"},
"blackbody":	{"NN"},
"blackbuck":	{"NN"},
"blackburn":	{"NN"},
"blackcap":	{"NN"},
"blackcock":	{"NN"},
"blackdamp":	{"NN"},
"blacked":	{"VBD","VBN"},
"blacked-in":	{"JJ"},
"blacked-out":	{"JJ"},
"blacken":	{"VB","VBP"},
"blackened":	{"VBD","VBN"},
"blackening":	{"VBG"},
"blackens":	{"VBZ"},
"blacker":	{"JJR"},
"blackest":	{"JJS"},
"blackface":	{"NN"},
"blackfish":	{"NN"},
"blackfly":	{"NN"},
"blackfoot":	{"NN"},
"blackfriar":	{"NN"},
"blackguard":	{"NN","VB","VBP"},
"blackguarded":	{"VBD","VBN"},
"blackguarding":	{"VBG"},
"blackguardism":	{"NN"},
"blackguardly":	{"JJ","RB"},
"blackguards":	{"NNS","VBZ"},
"blackhead":	{"NN"},
"blackheart":	{"NN"},
"blackhearted":	{"JJ"},
"blacking":	{"NN","VBG"},
"blackish":	{"JJ"},
"blackish-brown":	{"JJ"},
"blackish-gray":	{"JJ"},
"blackish-grey":	{"JJ"},
"blackish-red":	{"JJ"},
"blackjack":	{"NN","VB","VBP"},
"blackjacked":	{"VBD","VBN"},
"blackjacking":	{"VBG"},
"blackjacks":	{"NNS","VBZ"},
"blacklead":	{"VB"},
"blackleg":	{"NN","VB"},
"blacklist":	{"NN","VB","VBP"},
"blacklisted":	{"VBD","VBN"},
"blacklisting":	{"VBG"},
"blacklists":	{"NNS","VBZ"},
"blackmail":	{"NN","VB","VBP"},
"blackmailed":	{"VBN","VBD"},
"blackmailer":	{"NN"},
"blackmailers":	{"NNS"},
"blackmailing":	{"VBG"},
"blackmails":	{"VBZ"},
"blackness":	{"NN"},
"blackout":	{"NN"},
"blackouts":	{"NNS"},
"blackpoll":	{"NN"},
"blackpool":	{"NN"},
"blacks":	{"NNS","VBZ"},
"blacksburg":	{"NN"},
"blackseed":	{"NN"},
"blackshirt":	{"NN"},
"blacksmith":	{"NN"},
"blacksnake":	{"NN"},
"blackspot":	{"NN"},
"blacktail":	{"NN"},
"blackthorn":	{"NN"},
"blacktop":	{"VB","NN"},
"blacktopping":	{"NN"},
"blackwash":	{"NN","VB"},
"blackwater":	{"NN"},
"blackwood":	{"NN"},
"bladder":	{"NN"},
"bladderlike":	{"JJ"},
"bladdernose":	{"NN"},
"bladderpod":	{"NN"},
"bladderwort":	{"NN"},
"bladderwrack":	{"NN"},
"bladdery":	{"JJ"},
"blade":	{"NN"},
"bladed":	{"JJ"},
"bladelike":	{"JJ"},
"blades":	{"NNS"},
"blae":	{"JJ"},
"blaeberry":	{"NN"},
"blah":	{"NN","JJ"},
"blahs":	{"NNS"},
"blain":	{"NN"},
"blair":	{"NN"},
"blake":	{"NN"},
"blakes":	{"NNS"},
"blamable":	{"JJ"},
"blame":	{"VB","NN","VBP"},
"blameable":	{"JJ"},
"blamed":	{"VBD","VBN"},
"blameful":	{"JJ"},
"blameless":	{"JJ"},
"blamelessly":	{"RB"},
"blamelessness":	{"NN"},
"blames":	{"VBZ"},
"blameworthiness":	{"NN"},
"blameworthy":	{"JJ"},
"blaming":	{"VBG"},
"blanch":	{"VB","VBP"},
"blanched":	{"VBD","VBN"},
"blanches":	{"VBZ"},
"blanching":	{"VBG"},
"blancmange":	{"NN"},
"bland":	{"JJ","NN"},
"blander":	{"JJR"},
"blandest":	{"JJS"},
"blandfordia":	{"NN"},
"blandish":	{"VB","VBP"},
"blandished":	{"VBD","VBN"},
"blandishes":	{"VBZ"},
"blandishing":	{"VBG"},
"blandishment":	{"NN"},
"blandishments":	{"NNS"},
"blandly":	{"RB"},
"blandness":	{"NN"},
"blank":	{"JJ","NN","VB","VBP"},
"blank-faced":	{"JJ"},
"blanked":	{"VBD","VBN"},
"blanket":	{"NN","VB","VBP","JJ"},
"blanketed":	{"VBD","VBN"},
"blanketing":	{"VBG"},
"blanketly":	{"RB"},
"blankets":	{"NNS","VBZ"},
"blanking":	{"VBG"},
"blankly":	{"RB"},
"blankness":	{"NN"},
"blanks":	{"NNS","VBZ"},
"blanquillo":	{"NN"},
"blantyre":	{"NN"},
"blare":	{"VB","VBP","NN"},
"blared":	{"VBD","VBN"},
"blares":	{"VBZ"},
"blarina":	{"NN"},
"blaring":	{"VBG"},
"blarney":	{"NN"},
"blase":	{"JJ"},
"blaspheme":	{"VB","VBP"},
"blasphemed":	{"VBD","VBN"},
"blasphemer":	{"NN"},
"blasphemers":	{"NNS"},
"blasphemes":	{"VBZ"},
"blasphemies":	{"NNS"},
"blaspheming":	{"VBG"},
"blasphemous":	{"JJ"},
"blasphemously":	{"RB"},
"blasphemy":	{"NN"},
"blast":	{"NN","VB","VBP","UH"},
"blastdown":	{"NN"},
"blasted":	{"JJ","VBD","VBN"},
"blastema":	{"NN"},
"blastemal":	{"JJ"},
"blastematic":	{"JJ"},
"blastemic":	{"JJ"},
"blaster":	{"NN"},
"blasting":	{"NN","VBG"},
"blastocele":	{"NN"},
"blastocladia":	{"NN"},
"blastocladiales":	{"NNS"},
"blastocoel":	{"NN"},
"blastocoele":	{"NN"},
"blastocoelic":	{"JJ"},
"blastocyst":	{"NN"},
"blastocyte":	{"NN"},
"blastocytoma":	{"NN"},
"blastoderm":	{"NN"},
"blastodermatic":	{"JJ"},
"blastodermic":	{"JJ"},
"blastodiaceae":	{"NN"},
"blastodisc":	{"NN"},
"blastoff":	{"NN"},
"blastogenesis":	{"NN"},
"blastogenetic":	{"JJ"},
"blastoma":	{"NN"},
"blastomere":	{"NN"},
"blastomeric":	{"JJ"},
"blastomyces":	{"NN"},
"blastomycete":	{"NN"},
"blastomycosis":	{"NN"},
"blastomycotic":	{"JJ"},
"blastoporal":	{"JJ"},
"blastopore":	{"NN"},
"blastoporic":	{"JJ"},
"blastosphere":	{"NN"},
"blastospheric":	{"JJ"},
"blasts":	{"NNS","VBZ"},
"blastula":	{"NN"},
"blastular":	{"JJ"},
"blat":	{"VB","VBP","NN"},
"blatancy":	{"NN"},
"blatant":	{"JJ"},
"blatantly":	{"RB"},
"blate":	{"JJ"},
"blather":	{"VB","VBP","NN"},
"blathered":	{"VBD","VBN"},
"blathering":	{"VBG"},
"blathers":	{"VBZ","NNS"},
"blatherskite":	{"NN"},
"blatta":	{"NN"},
"blattaria":	{"NN"},
"blattella":	{"NN"},
"blattidae":	{"NN"},
"blattodea":	{"NN"},
"blaxploitation":	{"NN"},
"blaze":	{"NN","VB","VBP"},
"blazed":	{"VBD","VBN"},
"blazer":	{"NN"},
"blazes":	{"NNS","VBZ"},
"blazing":	{"JJ","VBG"},
"blazon":	{"VB","VBP","NN"},
"blazoned":	{"VBD","VBN"},
"blazoning":	{"VBG"},
"blazonry":	{"NN"},
"blazons":	{"VBZ","NNS"},
"bleach":	{"NN","VB","VBP"},
"bleached":	{"VBD","VBN","JJ"},
"bleacher":	{"NN"},
"bleacher-type":	{"JJ"},
"bleachers":	{"NNS"},
"bleaches":	{"VBZ"},
"bleaching":	{"VBG"},
"bleak":	{"JJ"},
"bleaker":	{"JJR"},
"bleakest":	{"JJS"},
"bleakly":	{"RB"},
"bleakness":	{"NN"},
"blear":	{"VB","VBP"},
"blear-eyed":	{"JJ"},
"bleared":	{"VBD","VBN"},
"blearily":	{"RB"},
"bleariness":	{"NN"},
"blearing":	{"VBG"},
"blears":	{"VBZ"},
"bleary":	{"JJ"},
"bleary-eyed":	{"JJ"},
"bleat":	{"VB","VBP","NN"},
"bleated":	{"VBD","VBN"},
"bleater":	{"NN"},
"bleaters":	{"NNS"},
"bleating":	{"VBG","JJ"},
"bleatingly":	{"RB"},
"bleats":	{"NNS","VBZ"},
"bleb":	{"NN"},
"blebbed":	{"JJ"},
"blebby":	{"JJ"},
"blebs":	{"NNS"},
"blechnaceae":	{"NN"},
"blechnum":	{"NN"},
"bled":	{"VBD","VBN"},
"bleed":	{"VBD","VBN","VBP","VB"},
"bleeder":	{"NN"},
"bleeders":	{"NNS"},
"bleeding":	{"NN","JJ","VBG"},
"bleedings":	{"NNS"},
"bleeds":	{"VBZ"},
"bleep":	{"NN","VB","VBP"},
"bleeped":	{"VBD","VBN"},
"bleeping":	{"VBG"},
"bleeps":	{"NNS","VBZ"},
"blem":	{"NN"},
"blemish":	{"NN","VB","VBP"},
"blemished":	{"VBD","VBN","JJ"},
"blemishes":	{"NNS","VBZ"},
"blemishing":	{"VBG"},
"blench":	{"VB"},
"blenched":	{"VBD","VBN"},
"blenches":	{"VBZ"},
"blenching":	{"VBG"},
"blend":	{"VB","VBP","NN"},
"blende":	{"NN"},
"blended":	{"VBD","VBN","JJ"},
"blender":	{"NN"},
"blenders":	{"NNS"},
"blending":	{"VBG","NN"},
"blends":	{"NNS","VBZ"},
"blenheim":	{"NN"},
"blenniidae":	{"NN"},
"blennioid":	{"NN"},
"blennioidea":	{"NN"},
"blennius":	{"NN"},
"blenny":	{"NN"},
"blent":	{"VBD","VBN"},
"blepharism":	{"NN"},
"blepharitis":	{"NN"},
"blepharospasm":	{"NN"},
"blephilia":	{"NN"},
"bleriot":	{"NN"},
"bless":	{"VB","VBP"},
"blessed":	{"JJ","VBD","VBN"},
"blessedly":	{"RB"},
"blessedness":	{"NN"},
"blesses":	{"VBZ"},
"blessing":	{"NN","VBG"},
"blessings":	{"NNS"},
"blest":	{"NN","VBD","VBN"},
"blether":	{"NN","VB","VBP"},
"blethered":	{"VBD","VBN"},
"blethering":	{"VBG"},
"blethers":	{"NNS","VBZ"},
"bletia":	{"NN"},
"bletilla":	{"NN"},
"bleu":	{"JJ","NN"},
"blew":	{"VBD"},
"blewits":	{"NNS"},
"blida":	{"NN"},
"bligh":	{"NN"},
"blighia":	{"NN"},
"blight":	{"NN","VB","VBP"},
"blighted":	{"JJ","VBD","VBN"},
"blighter":	{"NN"},
"blighters":	{"NNS"},
"blighting":	{"VBG"},
"blights":	{"VBZ","NNS"},
"blimp":	{"NN"},
"blimpish":	{"JJ"},
"blind":	{"JJ","NN","RB","VB","VBP"},
"blind-folded":	{"JJ"},
"blind-pool":	{"JJ"},
"blind-sided":	{"JJ","VBN"},
"blinded":	{"JJ","VBD","VBN"},
"blinder":	{"NN"},
"blinders":	{"NNS"},
"blindfold":	{"NN","VB","VBP","JJ","RB"},
"blindfolded":	{"VBD","VBN"},
"blindfolding":	{"VBG"},
"blindfolds":	{"NNS","VBZ"},
"blinding":	{"JJ","VBG"},
"blindingly":	{"RB"},
"blindly":	{"RB"},
"blindness":	{"NN"},
"blinds":	{"NNS","VBZ"},
"blindside":	{"VB","VBP"},
"blindsided":	{"VBD","VBN"},
"blindworm":	{"NN"},
"bling":	{"NN"},
"blini":	{"NNS"},
"blink":	{"VB","VBP","NN"},
"blinked":	{"VBD","VBN"},
"blinker":	{"NN"},
"blinkers":	{"NNS"},
"blinking":	{"RB","JJ","VBG"},
"blinks":	{"VBZ","NNS"},
"blintz":	{"NN"},
"blintze":	{"NN"},
"bliny":	{"NN"},
"blip":	{"NN","VB","VBP"},
"blipped":	{"VBD","VBN"},
"blipping":	{"VBG"},
"blips":	{"NNS","VBZ"},
"bliss":	{"NN"},
"blissful":	{"JJ"},
"blissfully":	{"RB"},
"blissfulness":	{"NN"},
"blissus":	{"NN"},
"blister":	{"NN","VB","VBP"},
"blistered":	{"VBN","VBD","JJ"},
"blistering":	{"JJ","VBG"},
"blisteringly":	{"RB"},
"blisters":	{"NNS","VBZ"},
"blistery":	{"JJ"},
"blithe":	{"JJ","NN"},
"blithely":	{"RB"},
"blitheness":	{"NN"},
"blither":	{"VB"},
"blithered":	{"VBD","VBN"},
"blithering":	{"VBG"},
"blithers":	{"VBZ"},
"blithesome":	{"JJ"},
"blitt":	{"NN"},
"blitz":	{"NN","VB","VBP"},
"blitzed":	{"VBD","VBN"},
"blitzes":	{"NNS","VBZ"},
"blitzing":	{"VBG"},
"blitzkrieg":	{"NN"},
"blitzkriegs":	{"NNS"},
"blixen":	{"NN"},
"blizzard":	{"NN"},
"blizzards":	{"NNS"},
"bloat":	{"VB","VBP"},
"bloated":	{"JJ","VBN","VBD"},
"bloater":	{"NN"},
"bloating":	{"NN","VBG"},
"bloats":	{"VBZ"},
"blob":	{"NN","VB","VBP"},
"blobbed":	{"VBD","VBN"},
"blobbing":	{"VBG"},
"blobby":	{"JJ"},
"blobfish":	{"NN","NNS"},
"blobs":	{"NNS","VBZ"},
"bloc":	{"NN"},
"blocadren":	{"NN"},
"bloch":	{"NN"},
"block":	{"NN","VB","VBP"},
"block-buster":	{"NN"},
"block-grant":	{"JJ","NN"},
"block-trading":	{"NN"},
"blockade":	{"NN","VB","VBP"},
"blockade-runner":	{"NN"},
"blockaded":	{"VBD","VBN"},
"blockades":	{"VBZ"},
"blockading":	{"VBG"},
"blockage":	{"NN"},
"blockages":	{"NNS"},
"blockbuster":	{"NN","VB","JJ","IN","VBG","VBN"},
"blockbusters":	{"NNS"},
"blockchain":	{"NN"},
"blocked":	{"VBN","VBD"},
"blocker":	{"NN"},
"blockers":	{"NNS"},
"blockhead":	{"NN"},
"blockheaded":	{"JJ"},
"blockhouse":	{"NN"},
"blocking":	{"VBG"},
"blockish":	{"JJ"},
"blocks":	{"NNS","VBZ"},
"blocky":	{"JJ","NN"},
"blocs":	{"NNS"},
"bloemfontein":	{"NN"},
"blog":	{"NN","VB","VBP"},
"blogged":	{"VBD","VBN"},
"blogger":	{"NN"},
"bloggers":	{"NNS"},
"blogging":	{"VBG","NN"},
"blogs":	{"NNS","VBZ"},
"blok":	{"NN"},
"bloke":	{"NN"},
"blokes":	{"NNS"},
"blolly":	{"NN"},
"blond":	{"JJ","NN"},
"blonde":	{"JJ","NN"},
"blondeness":	{"NN"},
"blonder":	{"JJR"},
"blondes":	{"NNS"},
"blondest":	{"JJS"},
"blondish":	{"JJ"},
"blondness":	{"NN"},
"blonds":	{"NNS"},
"blood":	{"NN","VBP","VB"},
"blood-alcohol":	{"NN"},
"blood-and-guts":	{"JJ"},
"blood-bought":	{"JJ"},
"blood-cell":	{"NN"},
"blood-chilling":	{"JJ"},
"blood-clot":	{"NN"},
"blood-clotting":	{"JJ"},
"blood-filled":	{"JJ"},
"blood-flecked":	{"JJ"},
"blood-flow":	{"NNS"},
"blood-forming":	{"JJ"},
"blood-in-the-streets":	{"NNS"},
"blood-kinship":	{"NN"},
"blood-letting":	{"NN"},
"blood-lust":	{"NN"},
"blood-pressure":	{"JJ","NN"},
"blood-red":	{"JJ","NN"},
"blood-related":	{"JJ"},
"blood-soaked":	{"JJ"},
"blood-specked":	{"JJ"},
"blood-sport":	{"JJ"},
"blood-stained":	{"JJ"},
"blood-thirsty":	{"JJ"},
"blood-twig":	{"NN"},
"bloodbath":	{"NN"},
"bloodberry":	{"NN"},
"bloodcurdling":	{"JJ"},
"blooded":	{"JJ","VBD","VBN"},
"bloodguilt":	{"NN"},
"bloodguilty":	{"JJ"},
"bloodhound":	{"NN"},
"bloodhounds":	{"NNS"},
"bloodied":	{"VBD","VBN"},
"bloodier":	{"JJR"},
"bloodies":	{"VBZ"},
"bloodiest":	{"JJS"},
"bloodily":	{"RB"},
"bloodiness":	{"NN"},
"blooding":	{"VBG"},
"bloodleaf":	{"NN"},
"bloodless":	{"JJ"},
"bloodlessly":	{"RB"},
"bloodletting":	{"NN"},
"bloodline":	{"NN"},
"bloodlust":	{"NN"},
"bloodmobile":	{"NN"},
"bloodroot":	{"NN"},
"bloods":	{"NNS","VBZ"},
"bloodshed":	{"NN","JJ"},
"bloodshot":	{"JJ","NN"},
"bloodspots":	{"NNS"},
"bloodstain":	{"NN"},
"bloodstained":	{"JJ"},
"bloodstains":	{"NNS"},
"bloodstock":	{"NN"},
"bloodstone":	{"NN"},
"bloodstream":	{"NN"},
"bloodsucker":	{"NN"},
"bloodsucking":	{"JJ"},
"bloodthirstiness":	{"NN"},
"bloodthirsty":	{"JJ","NN"},
"bloodworm":	{"NN"},
"bloodwort":	{"NN"},
"bloody":	{"JJ","RB","VB","VBP"},
"bloody-minded":	{"JJ"},
"bloody-mindedness":	{"NN"},
"bloodying":	{"VBG"},
"bloom":	{"NN","VB","VBP"},
"bloomed":	{"VBD","VBN"},
"bloomer":	{"NN"},
"bloomeria":	{"NN"},
"bloomers":	{"NNS"},
"bloomfield":	{"NN"},
"blooming":	{"VBG","JJ","RB"},
"bloomington":	{"NN"},
"blooms":	{"NNS","VBZ"},
"blooper":	{"NN"},
"bloopers":	{"NNS"},
"bloops":	{"NNS"},
"blossom":	{"NN","VB","VBP"},
"blossomed":	{"VBD","VBN"},
"blossoming":	{"VBG"},
"blossoms":	{"NNS","VBZ"},
"blot":	{"NN","VB","VBP"},
"blot-appearance":	{"NN"},
"blot-like":	{"JJ"},
"blotch":	{"NN","VB","VBP"},
"blotched":	{"JJ","VBD","VBN"},
"blotches":	{"NNS","VBZ"},
"blotching":	{"VBG"},
"blotchy":	{"JJ"},
"blots":	{"NNS","VBZ"},
"blotted":	{"VBD","VBN"},
"blotter":	{"NN"},
"blotters":	{"NNS"},
"blotting":	{"VBG"},
"blotto":	{"JJ"},
"blount":	{"NN"},
"blouse":	{"NN"},
"bloused":	{"VBD","VBN"},
"blouses":	{"NNS","VBZ"},
"blousing":	{"VBG"},
"bloviate":	{"VB","VBP"},
"bloviated":	{"VBD","VBN"},
"bloviates":	{"VBZ"},
"bloviating":	{"VBG"},
"bloviation":	{"NN"},
"bloviator":	{"NN"},
"bloviators":	{"NNS"},
"blow":	{"NN","VB","VBP"},
"blow-by-blow":	{"JJ"},
"blow-dried":	{"VBD","VBN"},
"blow-dries":	{"VBZ","NNS"},
"blow-dry":	{"VB","VBP","NN"},
"blow-drying":	{"VBG"},
"blow-up":	{"NN"},
"blow-ups":	{"NNS"},
"blowback":	{"NN"},
"blowball":	{"NN"},
"blower":	{"NN"},
"blowers":	{"NNS"},
"blowfish":	{"NN"},
"blowfly":	{"NN"},
"blowgun":	{"NN"},
"blowhard":	{"NN"},
"blowhole":	{"NN"},
"blowing":	{"VBG","NN"},
"blowjob":	{"NN"},
"blowlamp":	{"NN"},
"blowlamps":	{"NNS"},
"blown":	{"VBN"},
"blown-up":	{"JJ"},
"blowout":	{"NN"},
"blowpipe":	{"NN"},
"blows":	{"VBZ","NNS"},
"blowsy":	{"JJ"},
"blowtorch":	{"NN"},
"blowtorches":	{"NNS"},
"blowtube":	{"NN"},
"blowup":	{"NN"},
"blowy":	{"JJ"},
"blowzy":	{"JJ"},
"blt":	{"NN"},
"blu-82":	{"NN"},
"blub":	{"VB","VBP"},
"blubbed":	{"VBD","VBN"},
"blubber":	{"NN","VB","VBP"},
"blubbered":	{"VBD","VBN"},
"blubberer":	{"NN"},
"blubbering":	{"VBG"},
"blubbers":	{"VBZ"},
"blubbery":	{"JJ"},
"blubbing":	{"VBG"},
"blucher":	{"NN"},
"bludgeon":	{"VB","VBP","NN"},
"bludgeoned":	{"VBD","VBN"},
"bludgeoner":	{"NN"},
"bludgeoning":	{"VBG"},
"bludgeons":	{"VBZ","NNS"},
"blue":	{"JJ","NN"},
"blue-belly":	{"NN"},
"blue-black":	{"JJ"},
"blue-blind":	{"JJ"},
"blue-blindness":	{"NN"},
"blue-blood":	{"JJ","NN"},
"blue-blooded":	{"JJ"},
"blue-carpeted":	{"JJ"},
"blue-chip":	{"JJ"},
"blue-chips":	{"NNS"},
"blue-collar":	{"JJ"},
"blue-collar-mail":	{"JJ","NN"},
"blue-draped":	{"JJ"},
"blue-eyed":	{"JJ"},
"blue-eyes":	{"NNS"},
"blue-flowered":	{"JJ"},
"blue-fruited":	{"JJ"},
"blue-glazed":	{"JJ"},
"blue-gray":	{"JJ"},
"blue-green":	{"JJ"},
"blue-grey":	{"JJ"},
"blue-lilac":	{"JJ"},
"blue-pencil":	{"VB","VBP"},
"blue-penciled":	{"VBD","VBN"},
"blue-penciling":	{"VBG"},
"blue-pencilled":	{"VBD","VBN"},
"blue-pencilling":	{"VBG"},
"blue-pencils":	{"VBZ"},
"blue-purple":	{"JJ"},
"blue-ribbon":	{"JJ"},
"blue-sky":	{"JJ"},
"blue-uniformed":	{"JJ"},
"blue-violet":	{"JJ"},
"blue-white":	{"JJ"},
"bluebeard":	{"NN"},
"bluebell":	{"NN"},
"blueberries":	{"NNS"},
"blueberry":	{"NN"},
"bluebill":	{"NN"},
"bluebird":	{"NN"},
"bluebloods":	{"NNS"},
"bluebonnet":	{"NN"},
"bluebonnets":	{"NNS"},
"bluebook":	{"NN"},
"bluebottle":	{"NN"},
"bluebush":	{"NN"},
"bluechip":	{"JJ"},
"bluecoat":	{"NN"},
"blued":	{"VBD","VBN"},
"bluefin":	{"NN"},
"bluefish":	{"NN"},
"bluegill":	{"NN"},
"bluegrass":	{"NN"},
"bluehead":	{"NN"},
"blueing":	{"VBG"},
"blueish":	{"JJ"},
"bluejacket":	{"NN"},
"blueness":	{"NN"},
"bluenose":	{"NN"},
"bluepoint":	{"NN"},
"blueprint":	{"NN"},
"blueprinted":	{"VBD","VBN"},
"blueprinting":	{"VBG"},
"blueprints":	{"NNS","VBZ"},
"bluer":	{"JJR"},
"blues":	{"NNS","VBZ"},
"bluest":	{"JJS"},
"bluestem":	{"NN"},
"bluestocking":	{"NN"},
"bluestone":	{"NN"},
"bluesy":	{"JJ"},
"bluethroat":	{"NN"},
"bluetick":	{"NN"},
"bluetongue":	{"NN"},
"blueweed":	{"NN"},
"bluewing":	{"NN"},
"bluff":	{"VB","VBP","NN","JJ"},
"bluffed":	{"VBD","VBN"},
"bluffer":	{"NN"},
"bluffing":	{"VBG"},
"bluffly":	{"RB"},
"bluffness":	{"NN"},
"bluffs":	{"VBZ","NNS"},
"bluing":	{"NN","VBG"},
"bluish":	{"JJ"},
"bluish-gray":	{"JJ"},
"bluish-grey":	{"JJ"},
"bluish-lilac":	{"JJ"},
"bluish-purple":	{"JJ"},
"bluish-violet":	{"JJ"},
"bluish-white":	{"JJ"},
"blumenthal":	{"NN"},
"blunder":	{"NN","VB","VBP"},
"blunderbuss":	{"NN"},
"blundered":	{"VBD","VBN"},
"blunderer":	{"NN"},
"blundering":	{"VBG","JJ"},
"blunders":	{"NNS","VBZ"},
"blunt":	{"JJ","VB","VBP"},
"blunted":	{"VBD","VBN"},
"blunter":	{"JJR"},
"bluntest":	{"JJS"},
"blunting":	{"VBG"},
"bluntly":	{"RB"},
"bluntness":	{"NN"},
"blunts":	{"VBZ"},
"blur":	{"NN","VB","VBP"},
"blurb":	{"NN"},
"blurbs":	{"NNS"},
"blurred":	{"VBN","JJ","VBD"},
"blurriness":	{"NN"},
"blurring":	{"VBG"},
"blurry":	{"JJ"},
"blurs":	{"NNS","VBZ"},
"blurt":	{"VB","VBP"},
"blurted":	{"VBD","VBN"},
"blurting":	{"VBG"},
"blurts":	{"VBZ"},
"blush":	{"VB","VBP","NN"},
"blushed":	{"VBD","VBN"},
"blusher":	{"NN"},
"blushers":	{"NNS"},
"blushes":	{"VBZ","NNS"},
"blushful":	{"JJ"},
"blushing":	{"VBG"},
"bluster":	{"VB","VBP","NN"},
"blustered":	{"VBD","VBN"},
"blusterer":	{"NN"},
"blustering":	{"JJ","VBG"},
"blusterous":	{"JJ"},
"blusters":	{"VBZ"},
"blustery":	{"JJ"},
"blutwurst":	{"NN"},
"blvd":	{"NN"},
"bm":	{"NN"},
"bmdo":	{"NN"},
"bmi":	{"NN"},
"bmr":	{"NN"},
"bmus":	{"NN"},
"bns":	{"NNS"},
"bo's'n":	{"NN"},
"bo'sun":	{"NN"},
"boa":	{"NN"},
"boann":	{"NN"},
"boar":	{"NN"},
"board":	{"NN","VB","VBP"},
"board-level":	{"JJ"},
"board-listed":	{"JJ"},
"board-traded":	{"JJ"},
"boarded":	{"VBD","VBN"},
"boarder":	{"NN"},
"boarding":	{"NN","VBG"},
"boarding-home":	{"NN"},
"boardinghouse":	{"NN"},
"boardinghouses":	{"NNS"},
"boardings":	{"NNS"},
"boardroom":	{"NN"},
"boardrooms":	{"NNS"},
"boards":	{"NNS","VBZ"},
"boardwalk":	{"NN"},
"boardwalks":	{"NNS"},
"boarfish":	{"NN"},
"boarhound":	{"NN"},
"boast":	{"VB","NN","VBP"},
"boasted":	{"VBD","VBN"},
"boaster":	{"NN"},
"boastful":	{"JJ"},
"boastfully":	{"RB"},
"boastfulness":	{"NN"},
"boasting":	{"NN","VBG"},
"boastings":	{"NNS"},
"boasts":	{"VBZ"},
"boat":	{"NN","VB","VBP"},
"boat-building":	{"NN"},
"boat-race":	{"VB"},
"boat-shaped":	{"JJ"},
"boat-yard":	{"NN"},
"boatbill":	{"NN"},
"boatbuilder":	{"NN"},
"boatbuilding":	{"NN"},
"boated":	{"VBD","VBN"},
"boatel":	{"NN"},
"boatels":	{"NNS"},
"boater":	{"NN"},
"boaters":	{"NNS"},
"boathouse":	{"NN"},
"boathouses":	{"NNS"},
"boating":	{"NN","VBG"},
"boatload":	{"NN"},
"boatloads":	{"NNS"},
"boatman":	{"NN"},
"boatmanship":	{"NN"},
"boats":	{"NNS","VBZ"},
"boatsmen":	{"NNS"},
"boatswain":	{"NN"},
"boatyard":	{"NN"},
"boatyards":	{"NNS"},
"bob":	{"VB","VBP","NN"},
"bobbed":	{"VBD","VBN"},
"bobber":	{"NN"},
"bobbies":	{"NNS"},
"bobbin":	{"NN"},
"bobbin-to-cone":	{"JJ"},
"bobbing":	{"VBG"},
"bobbins":	{"NNS"},
"bobble":	{"NN","VB","VBP"},
"bobbled":	{"VBD","VBN"},
"bobbles":	{"NNS","VBZ"},
"bobbling":	{"VBG"},
"bobby":	{"NN"},
"bobby-socker":	{"NN"},
"bobby-sox":	{"NNS"},
"bobby-soxer":	{"NN"},
"bobby-soxers":	{"NNS"},
"bobbysock":	{"NN"},
"bobbysocks":	{"NNS"},
"bobbysoxer":	{"NN"},
"bobbysoxers":	{"NNS"},
"bobcat":	{"NN"},
"bobcats":	{"NNS"},
"bobettes":	{"NNS"},
"bobfloat":	{"NN"},
"bobolink":	{"NN"},
"bobs":	{"VBZ"},
"bobsled":	{"NN","VB","VBP"},
"bobsledded":	{"VBD","VBN"},
"bobsledding":	{"VBG"},
"bobsleds":	{"NNS","VBZ"},
"bobsleigh":	{"NN","VB","VBP"},
"bobsleighed":	{"VBD","VBN"},
"bobsleighing":	{"VBG"},
"bobsleighs":	{"NNS","VBZ"},
"bobtail":	{"NN"},
"bobtailed":	{"JJ"},
"bobwhite":	{"NN"},
"boca":	{"NN"},
"boccaccio":	{"NN"},
"bocce":	{"NN"},
"bocci":	{"NN"},
"boccie":	{"NN"},
"bocconia":	{"NN"},
"boche":	{"NN"},
"bock":	{"NN"},
"bockwurst":	{"NN"},
"bod":	{"NN"},
"bodacious":	{"JJ"},
"boddhisatva":	{"NN"},
"bode":	{"VB","VBP","VBD"},
"boded":	{"VBD","VBN"},
"bodega":	{"NN"},
"bodegas":	{"NNS"},
"bodensee":	{"NN"},
"bodes":	{"VBZ","NNS"},
"bodge":	{"NN","VB","VBP"},
"bodged":	{"VBD","VBN"},
"bodges":	{"NNS","VBZ"},
"bodging":	{"VBG"},
"bodhi":	{"NN"},
"bodhisattva":	{"NN"},
"bodice":	{"NN"},
"bodied":	{"JJ","VBD","VBN"},
"bodies":	{"NNS","VBZ"},
"bodiless":	{"JJ"},
"bodily":	{"JJ","RB"},
"boding":	{"NN","VBG"},
"bodkin":	{"NN"},
"bodo-garo":	{"NN"},
"bodoni":	{"NN"},
"bods":	{"NNS"},
"body":	{"NN"},
"body-and-assembly":	{"JJ"},
"body-build":	{"NN"},
"body-building":	{"JJ"},
"body-numbing":	{"JJ"},
"body-surf":	{"VB"},
"body-tissue":	{"NN"},
"bodybuilder":	{"NN"},
"bodybuilders":	{"NNS"},
"bodybuilding":	{"NN"},
"bodyguard":	{"NN"},
"bodyguards":	{"NNS"},
"bodying":	{"VBG"},
"bodyless":	{"JJ"},
"bodypaint":	{"VB"},
"bodyweight":	{"NN"},
"bodywide":	{"JJ"},
"bodywork":	{"NN"},
"bodyworkers":	{"NNS"},
"boehm":	{"NN"},
"boehme":	{"NN"},
"boehmenism":	{"NN"},
"boehmeria":	{"NN"},
"boeing":	{"NN"},
"boell":	{"NN"},
"boeotia":	{"NN"},
"boeotian":	{"JJ"},
"boer":	{"NN"},
"boesky-greed-is-good":	{"JJ"},
"boethius":	{"NNS"},
"boeuf":	{"NN"},
"boffin":	{"NN"},
"boffo":	{"NN","JJ"},
"bog":	{"NN","VB","VBP"},
"bogart":	{"VB","VBP"},
"bogarted":	{"VBD","VBN"},
"bogartian":	{"JJ"},
"bogarting":	{"VBG"},
"bogarts":	{"VBZ"},
"bogbean":	{"NN"},
"bogey":	{"NN","JJ"},
"bogey-symbol":	{"NN"},
"bogeyman":	{"NN"},
"bogeymen":	{"NNS"},
"bogeys":	{"NNS"},
"bogged":	{"VBD","VBN"},
"bogging":	{"VBG"},
"boggle":	{"VB","VBP"},
"boggled":	{"VBD","VBN"},
"boggles":	{"VBZ"},
"boggling":	{"VBG"},
"boggy":	{"JJ"},
"bogie":	{"NN"},
"bogies":	{"NNS"},
"bogle":	{"NN"},
"bogmat":	{"NN"},
"bogs":	{"NNS","VBZ"},
"bogus":	{"JJ"},
"bogy":	{"NN"},
"bohemia":	{"NN"},
"bohemian":	{"NN","JJ"},
"bohemianism":	{"NN"},
"bohme":	{"NN"},
"bohr":	{"NN"},
"bohrium":	{"NN"},
"boidae":	{"NN"},
"boies":	{"NNS"},
"boil":	{"VB","NN","VBP"},
"boiled":	{"VBD","VBN","JJ"},
"boiler":	{"NN"},
"boiler-burner":	{"NN"},
"boiler-room":	{"NN"},
"boilerplate":	{"NN"},
"boilers":	{"NNS"},
"boilersuit":	{"NN"},
"boiling":	{"NN","JJ","RB","VBG"},
"boils":	{"VBZ","NNS"},
"bois":	{"FW"},
"boise":	{"NN"},
"boisterous":	{"JJ","NN"},
"boisterously":	{"RB"},
"boisterousness":	{"NN"},
"boite":	{"NN"},
"boites":	{"NNS"},
"bokkos":	{"NN"},
"bokmaal":	{"NN"},
"bokmal":	{"NN"},
"bola":	{"NN"},
"bolanci":	{"NN"},
"bolbitis":	{"NNS"},
"bold":	{"JJ"},
"bolder":	{"JJR"},
"boldest":	{"JJS"},
"boldface":	{"NN","JJ"},
"boldfaced":	{"JJ"},
"boldly":	{"RB"},
"boldness":	{"NN"},
"bole":	{"NN"},
"bolero":	{"NN"},
"boletaceae":	{"NN"},
"bolete":	{"NN"},
"boletellus":	{"NNS"},
"boletus":	{"NN"},
"boleyn":	{"NN"},
"bolide":	{"NN"},
"bolingbroke":	{"NN"},
"bolivar":	{"NN"},
"bolivars":	{"NNS"},
"bolivia":	{"NN"},
"bolivian":	{"JJ","NN"},
"boliviano":	{"NN"},
"boll":	{"NN"},
"bollard":	{"NN"},
"bollix":	{"NN"},
"bollock":	{"NN"},
"bollocked":	{"VBD","VBN"},
"bollocking":	{"VBG"},
"bollocks":	{"NN","NNS","VBZ"},
"bollworm":	{"NN"},
"bollywood":	{"NN"},
"bolo":	{"NN"},
"bologna":	{"NN"},
"bolognaise":	{"FW"},
"bologram":	{"NN"},
"bolograph":	{"NN"},
"bolographic":	{"JJ"},
"bolometer":	{"NN"},
"bolometric":	{"JJ"},
"boloney":	{"NN"},
"bolsa":	{"NN"},
"bolshevik":	{"NN","JJ"},
"bolshevise":	{"VB"},
"bolshevism":	{"NN"},
"bolshevist":	{"JJ","NN"},
"bolshevistic":	{"JJ"},
"bolshevize":	{"VB"},
"bolshie":	{"JJ"},
"bolshier":	{"JJR"},
"bolshiest":	{"JJS"},
"bolshiness":	{"NN"},
"bolshy":	{"JJ","NN"},
"bolster":	{"VB","VBP","NN"},
"bolstered":	{"VBN","VBD"},
"bolstering":	{"VBG"},
"bolsters":	{"VBZ"},
"bolt":	{"NN","VB","VBP","RB"},
"bolt-action":	{"JJ"},
"bolt-hole":	{"NN"},
"bolt-holes":	{"NNS"},
"bolted":	{"VBD","VBN"},
"bolti":	{"NN"},
"bolting":	{"VBG"},
"boltonia":	{"NN"},
"bolts":	{"NNS","VBZ"},
"boltzmann":	{"NN"},
"bolus":	{"NN"},
"bolzano":	{"NN"},
"bomarea":	{"NN"},
"bomb":	{"NN","VB","VBP"},
"bomb-detection":	{"JJ"},
"bomb-plant":	{"JJ"},
"bomb-proof":	{"JJ"},
"bombacaceae":	{"NN"},
"bombard":	{"VB","VBP"},
"bombarded":	{"VBD","VBN"},
"bombardier":	{"NN"},
"bombardiers":	{"NNS"},
"bombarding":	{"VBG"},
"bombardment":	{"NN"},
"bombardments":	{"NNS"},
"bombardon":	{"NN"},
"bombards":	{"VBZ"},
"bombast":	{"NN"},
"bombastic":	{"JJ"},
"bombastically":	{"RB"},
"bombax":	{"NN"},
"bombazine":	{"NN"},
"bombed":	{"VBD","VBN","JJ"},
"bomber":	{"NN"},
"bombers":	{"NNS"},
"bombie":	{"NN"},
"bombilate":	{"VB","VBP"},
"bombilation":	{"NN"},
"bombina":	{"NN"},
"bombinate":	{"VB","VBP"},
"bombinated":	{"VBD","VBN"},
"bombinates":	{"VBZ"},
"bombinating":	{"VBG"},
"bombination":	{"NN"},
"bombing":	{"VBG","NN"},
"bombings":	{"NNS"},
"bomblet":	{"NN"},
"bomblets":	{"NNS"},
"bombproof":	{"JJ"},
"bombs":	{"NNS","VBZ"},
"bombshell":	{"NN"},
"bombshells":	{"NNS"},
"bombsight":	{"NN"},
"bombus":	{"NN"},
"bombycid":	{"NN"},
"bombycidae":	{"NN"},
"bombycilla":	{"NN"},
"bombycillidae":	{"NN"},
"bombyliidae":	{"NN"},
"bombyx":	{"NN"},
"bona":	{"JJ"},
"bonaire":	{"NN"},
"bonanza":	{"NN"},
"bonanzas":	{"NNS"},
"bonasa":	{"NN"},
"bonavist":	{"NN"},
"bonbon":	{"NN"},
"bonce":	{"NN"},
"bonces":	{"NNS"},
"bond":	{"NN","VBP","VB"},
"bond-equivalent":	{"JJ","NN"},
"bond-financed":	{"JJ"},
"bond-fund":	{"NN"},
"bond-futures":	{"NNS"},
"bond-holders":	{"NNS"},
"bond-insurance":	{"JJ"},
"bond-market":	{"JJ"},
"bond-price":	{"JJ"},
"bond-rating":	{"JJ"},
"bond-trading":	{"JJ","NN"},
"bond-underwriting":	{"JJ"},
"bondable":	{"JJ"},
"bondage":	{"NN"},
"bonded":	{"VBN","JJ","VBD"},
"bonderise":	{"VB"},
"bonderize":	{"VB"},
"bondholder":	{"NN"},
"bondholders":	{"NNS"},
"bondholdings":	{"NNS"},
"bonding":	{"NN","VBG"},
"bondmaid":	{"NN"},
"bondman":	{"NN"},
"bondmarket":	{"NN"},
"bonds":	{"NNS","VBZ"},
"bondsman":	{"NN"},
"bondswoman":	{"NN"},
"bonduc":	{"NN"},
"bondwoman":	{"NN"},
"bone":	{"NN","VB","VBP"},
"bone-covered":	{"JJ"},
"bone-deep":	{"JJ"},
"bone-dry":	{"JJ"},
"bone-idle":	{"JJ"},
"bone-lazy":	{"JJ"},
"bone-loss":	{"NN"},
"bone-marrow":	{"NN"},
"bone-weary":	{"JJ"},
"boned":	{"JJ","VBD","VBN"},
"bonefish":	{"NN"},
"bonehead":	{"NN"},
"boneheaded":	{"JJ"},
"boneheadedly":	{"RB"},
"boneheads":	{"NNS"},
"boneless":	{"JJ"},
"bonelet":	{"NN"},
"bonelike":	{"JJ"},
"bonemeal":	{"NN"},
"boner":	{"NN"},
"bones":	{"NNS","VBZ"},
"boneset":	{"NN"},
"bonesetter":	{"NN"},
"boneshaker":	{"NN"},
"bonete":	{"NN"},
"boney":	{"NN","JJ"},
"bonfire":	{"NN"},
"bonfires":	{"NNS"},
"bong":	{"NN"},
"bongo":	{"NN"},
"bongoes":	{"NNS"},
"bongos":	{"NNS"},
"bonheur":	{"NN"},
"bonhoeffer":	{"NN"},
"bonhomie":	{"NN"},
"bonier":	{"JJR"},
"boniest":	{"JJS"},
"boniface":	{"NN"},
"boniness":	{"NN"},
"boning":	{"VBG"},
"bonito":	{"NN"},
"bonk":	{"VB","VBP","NN"},
"bonked":	{"VBD","VBN"},
"bonkers":	{"JJ"},
"bonking":	{"VBG"},
"bonks":	{"VBZ","NNS"},
"bonnet":	{"NN"},
"bonnethead":	{"NN"},
"bonnets":	{"NNS"},
"bonnie":	{"JJ"},
"bonnier":	{"JJR"},
"bonniest":	{"JJS"},
"bonnily":	{"RB"},
"bonny":	{"JJ"},
"bono":	{"FW"},
"bonobo":	{"NN"},
"bons":	{"NNS"},
"bonsai":	{"NN","JJ"},
"bontemps":	{"NNS"},
"bonus":	{"NN"},
"bonuses":	{"NNS"},
"bonxie":	{"NN"},
"bony":	{"JJ"},
"bony-plated":	{"JJ"},
"bonyness":	{"NN"},
"bonzer":	{"JJ"},
"bonzes":	{"NNS"},
"boo":	{"VB","VBP","NN","UH"},
"boo-boo":	{"NN"},
"boob":	{"NN","VBP","VB"},
"booboisie":	{"NN"},
"booboo":	{"NN"},
"booboos":	{"NNS"},
"booby":	{"NN","JJ"},
"booby-trap":	{"NN","VB","VBP"},
"booby-trapped":	{"VBD","VBN","JJ"},
"booby-trapping":	{"VBG"},
"booby-traps":	{"NNS","VBZ"},
"boodle":	{"NN"},
"boodleoo":	{"UH"},
"booed":	{"VBD","VBN"},
"booger":	{"NN"},
"boogeyman":	{"NN"},
"boogie":	{"NN","VBP","VB"},
"boogie-woogie":	{"NN"},
"boogieman":	{"NN"},
"booing":	{"VBG","NN"},
"book":	{"NN","VB","VBP"},
"book-breaking":	{"JJ"},
"book-burning":	{"JJ"},
"book-buying":	{"JJ"},
"book-end":	{"NN","VB","VBP"},
"book-ended":	{"VBD","VBN"},
"book-ending":	{"VBG"},
"book-ends":	{"NNS","VBZ"},
"book-entry":	{"JJ"},
"book-flogging":	{"JJ"},
"book-lined":	{"JJ"},
"book-publishing":	{"NN","JJ"},
"book-review":	{"NN"},
"book-selection":	{"NN"},
"book-to-bill":	{"JJ","NN"},
"bookable":	{"JJ"},
"bookbinder":	{"NN"},
"bookbindery":	{"NN"},
"bookbinding":	{"NN"},
"bookcase":	{"NN"},
"bookcases":	{"NNS"},
"bookclub":	{"NN"},
"bookcrossing":	{"NN"},
"bookdealer":	{"NN"},
"booked":	{"VBD","VBN"},
"bookend":	{"NN","VB","VBP"},
"bookended":	{"VBD","VBN"},
"bookending":	{"VBG"},
"bookends":	{"NNS","VBZ"},
"booker":	{"NN"},
"bookers":	{"NNS"},
"bookfair":	{"NN"},
"bookie":	{"NN"},
"bookies":	{"NNS"},
"booking":	{"NN","VBG"},
"bookings":	{"NNS"},
"bookish":	{"JJ","NN"},
"bookishness":	{"NN"},
"bookkeeper":	{"NN"},
"bookkeeping":	{"NN"},
"booklet":	{"NN"},
"booklets":	{"NNS"},
"booklist":	{"NN"},
"booklists":	{"NNS"},
"booklouse":	{"NN"},
"booklover":	{"NN"},
"bookmaker":	{"NN"},
"bookman":	{"NN"},
"bookmark":	{"NN","VB","VBP"},
"bookmarked":	{"VBD","VBN"},
"bookmarker":	{"NN"},
"bookmarking":	{"VBG"},
"bookmarks":	{"NNS","VBZ"},
"bookmobile":	{"NN"},
"bookplate":	{"NN"},
"books":	{"NNS","VBZ"},
"bookseller":	{"NN"},
"booksellers":	{"NNS"},
"bookshelf":	{"NN"},
"bookshelves":	{"NNS"},
"bookshop":	{"NN"},
"bookstall":	{"NN"},
"bookstore":	{"NN"},
"bookstores":	{"NNS"},
"bookworm":	{"NN"},
"boole":	{"NN"},
"boolean":	{"JJ"},
"boom":	{"NN","VB","VBP"},
"boom-and-bust":	{"JJ"},
"boom-boom-boom":	{"JJ"},
"boom-boxes":	{"NNS"},
"boom-or-bust":	{"JJ"},
"boomed":	{"VBD","VBN"},
"boomer":	{"NN"},
"boomerang":	{"NN","VBP","VB"},
"boomeranged":	{"VBD","VBN"},
"boomeranging":	{"VBG"},
"boomerangs":	{"NNS","VBZ"},
"boomers":	{"NNS"},
"booming":	{"JJ","VBG"},
"booms":	{"VBZ","NNS"},
"boomtown":	{"NN"},
"boon":	{"NN","JJ"},
"boondocks":	{"NNS"},
"boondoggle":	{"VB","NN"},
"boondoggler":	{"NN"},
"boondoggles":	{"NNS"},
"boone":	{"NN"},
"boor":	{"NN"},
"boorish":	{"JJ"},
"boorishly":	{"RB"},
"boorishness":	{"NN"},
"boors":	{"NNS"},
"boos":	{"VBZ","NNS"},
"boost":	{"VB","NN","VBP"},
"boosted":	{"VBD","VBN"},
"booster":	{"NN"},
"boosters":	{"NNS"},
"boosting":	{"VBG"},
"boosts":	{"VBZ","NNS"},
"boot":	{"NN","VB","VBP"},
"boot-shaped":	{"JJ"},
"boot-stomping":	{"JJ"},
"boot-wearer":	{"JJ"},
"bootblack":	{"NN"},
"bootboys":	{"NNS"},
"booted":	{"JJ","VBD","VBN"},
"bootee":	{"NN"},
"bootees":	{"NNS"},
"booth":	{"NN"},
"boothose":	{"NN"},
"booths":	{"NNS"},
"bootie":	{"NN"},
"booties":	{"NNS"},
"booting":	{"VBG","NN"},
"bootjack":	{"NN"},
"bootlace":	{"NN"},
"bootlaces":	{"NNS"},
"bootleg":	{"NN","JJ","VB","VBP"},
"bootlegged":	{"JJ","VBD","VBN"},
"bootlegger":	{"NN"},
"bootleggers":	{"NNS"},
"bootlegging":	{"NN","VBG"},
"bootlegs":	{"NNS","VBZ"},
"bootless":	{"JJ"},
"bootlick":	{"VB","VBP"},
"bootlicked":	{"VBD","VBN"},
"bootlicker":	{"NN"},
"bootlicking":	{"VBG"},
"bootlicks":	{"VBZ"},
"bootmaker":	{"NN"},
"boots":	{"NNS","VBZ"},
"bootstrap":	{"NN","VB","VBP","JJ"},
"bootstrapped":	{"VBD","VBN"},
"bootstrapping":	{"VBG"},
"bootstraps":	{"VBZ"},
"booty":	{"NN"},
"booyong":	{"NN"},
"booze":	{"NN","VB","VBP"},
"booze-up":	{"NN"},
"booze-ups":	{"NNS"},
"boozed":	{"VBD","VBN","JJ"},
"boozed-out":	{"JJ"},
"boozer":	{"NN"},
"boozers":	{"NNS"},
"boozes":	{"VBZ"},
"boozing":	{"NN","VBG"},
"boozy":	{"JJ"},
"bop":	{"NN","VB","VBP"},
"bopeep":	{"NN"},
"bopped":	{"VBD","VBN"},
"bopper":	{"NN"},
"boppers":	{"NNS"},
"bopping":	{"VBG"},
"bops":	{"NNS","VBZ"},
"boracic":	{"JJ"},
"borage":	{"NN"},
"boraginaceae":	{"NN"},
"borago":	{"NN"},
"borassus":	{"NN"},
"borate":	{"NN"},
"borated":	{"JJ"},
"borates":	{"NNS"},
"borax":	{"NN"},
"bordelaise":	{"NN"},
"bordello":	{"NN"},
"borden":	{"NN"},
"border":	{"NN","VB","VBP"},
"bordered":	{"VBD","VBN"},
"borderer":	{"NN"},
"bordering":	{"VBG"},
"borderland":	{"NN"},
"borderlands":	{"NNS"},
"borderline":	{"NN","JJ"},
"borderlines":	{"NNS"},
"borders":	{"NNS","VBZ"},
"bordetella":	{"NN"},
"bore":	{"VBD","NN","VB","VBP"},
"bore-hole":	{"NN"},
"boreal":	{"JJ","NN"},
"boreas":	{"NNS"},
"borecole":	{"NN"},
"bored":	{"JJ","VBD","VBN"},
"boredom":	{"NN"},
"borer":	{"NN"},
"borers":	{"NNS"},
"bores":	{"NNS","VBZ"},
"boric":	{"JJ"},
"boring":	{"JJ","NN","VBG"},
"boringly":	{"RB"},
"boringness":	{"NN"},
"borings":	{"NNS"},
"born":	{"VBN","JJ"},
"born-again":	{"JJ"},
"born-to-shop":	{"JJ"},
"borne":	{"JJ","NN","VBN"},
"bornean":	{"NN"},
"borneo":	{"NN"},
"bornite":	{"NN"},
"borodin":	{"NN"},
"borodino":	{"NN"},
"boron":	{"NN"},
"boronic":	{"JJ"},
"borosilicate":	{"NN"},
"borough":	{"NN"},
"boroughs":	{"NNS"},
"borrelia":	{"NN"},
"borrow":	{"VB","VBP"},
"borrowed":	{"VBN","VBD","JJ"},
"borrower":	{"NN"},
"borrowers":	{"NNS"},
"borrowing":	{"NN","VBG"},
"borrowings":	{"NNS"},
"borrows":	{"VBZ"},
"borsch":	{"NN"},
"borscht":	{"NN"},
"borsh":	{"NN"},
"borshch":	{"NN"},
"borsht":	{"NN"},
"borstal":	{"NN"},
"bortsch":	{"NN"},
"borzoi":	{"NN"},
"bos":	{"NN"},
"bos'n":	{"NN"},
"bosc":	{"NN"},
"bosch":	{"NN"},
"bose":	{"NN"},
"boselaphus":	{"NNS"},
"bosh":	{"NN","UH"},
"bosie":	{"NN"},
"bosk":	{"NN"},
"boskopoid":	{"JJ"},
"bosky":	{"NN","JJ"},
"bosnia":	{"NN"},
"bosnia-herzegovina":	{"NN"},
"bosnian":	{"JJ"},
"bosom":	{"VB","NN","JJ"},
"bosomed":	{"JJ","VBD","VBN"},
"bosoming":	{"VBG"},
"bosoms":	{"NNS","VBZ"},
"bosomy":	{"JJ"},
"boson":	{"NN"},
"bosons":	{"NNS"},
"bosporus":	{"NN"},
"boss":	{"NN","VB","VBP","JJ"},
"boss-eyed":	{"JJ"},
"bossed":	{"VBN","VBD"},
"bosses":	{"NNS","VBZ"},
"bossier":	{"JJR"},
"bossiest":	{"JJS"},
"bossily":	{"RB"},
"bossiness":	{"NN"},
"bossing":	{"VBG"},
"bossism":	{"NN"},
"bossman":	{"NN"},
"bossy":	{"JJ"},
"boston":	{"NN"},
"boston-area":	{"JJ"},
"bostonian":	{"NN"},
"bosun":	{"NN"},
"boswell":	{"NN"},
"boswellia":	{"NN"},
"bot":	{"NN"},
"bota":	{"NN"},
"botanic":	{"JJ","NN"},
"botanical":	{"JJ","NN"},
"botanise":	{"VB"},
"botanist":	{"NN"},
"botanists":	{"NNS"},
"botanize":	{"VB"},
"botany":	{"NN"},
"botaurus":	{"NN"},
"botch":	{"VB","VBP","NN"},
"botch-up":	{"NN"},
"botch-ups":	{"NNS"},
"botched":	{"VBD","VBN"},
"botcher":	{"NN"},
"botchers":	{"NNS"},
"botches":	{"VBZ","NNS"},
"botching":	{"VBG"},
"botchy":	{"JJ"},
"botfly":	{"NN"},
"both":	{"DT","PDT","CC"},
"bother":	{"VB","VBP","NN","UH"},
"botheration":	{"UH"},
"bothered":	{"VBN","VBD","JJ"},
"bothering":	{"VBG"},
"bothers":	{"VBZ","NNS"},
"bothersome":	{"JJ"},
"bothidae":	{"NN"},
"bothrops":	{"NNS"},
"botonee":	{"JJ"},
"botonnee":	{"JJ"},
"botox":	{"NN"},
"botrychium":	{"NN"},
"botryoid":	{"JJ"},
"botryoidal":	{"JJ"},
"botswana":	{"NN"},
"botswanan":	{"JJ"},
"botticelli":	{"NN"},
"bottle":	{"NN","VB","VBP"},
"bottle-fed":	{"JJ","VBD","VBN"},
"bottle-feed":	{"VB","VBP"},
"bottle-feeding":	{"VBG","NN"},
"bottle-feeds":	{"VBZ"},
"bottle-grass":	{"NN"},
"bottle-green":	{"JJ"},
"bottle-shaped":	{"JJ"},
"bottle-tree":	{"NN"},
"bottlebrush":	{"NN"},
"bottlecap":	{"NN"},
"bottled":	{"JJ","VBD","VBN"},
"bottled-water":	{"JJ","NN"},
"bottlefed":	{"VBD","VBN"},
"bottlefeed":	{"VB","VBP"},
"bottlefeeding":	{"VBG"},
"bottleful":	{"NN"},
"bottleneck":	{"NN","JJ","VB","VBP"},
"bottlenecked":	{"VBD","VBN"},
"bottlenecking":	{"VBG"},
"bottlenecks":	{"NNS","VBZ"},
"bottlenose":	{"NN"},
"bottler":	{"NN"},
"bottlers":	{"NNS"},
"bottles":	{"NNS","VBZ"},
"bottling":	{"VBG"},
"bottom":	{"NN","JJ","VB","VBP"},
"bottom-down":	{"JJ"},
"bottom-dweller":	{"NN"},
"bottom-dwelling":	{"JJ"},
"bottom-feeder":	{"NN"},
"bottom-feeding":	{"JJ"},
"bottom-fishers":	{"NNS"},
"bottom-fishing":	{"NN"},
"bottom-line":	{"JJ"},
"bottom-living":	{"JJ"},
"bottom-of-the-barrel":	{"JJ"},
"bottom-up":	{"JJ"},
"bottomed":	{"JJ","VBD","VBN"},
"bottoming":	{"VBG"},
"bottomland":	{"NN"},
"bottomless":	{"JJ","NN"},
"bottomlessness":	{"NN"},
"bottommost":	{"JJ"},
"bottoms":	{"NNS","VBZ"},
"botuliform":	{"JJ"},
"botulin":	{"NN"},
"botulinal":	{"JJ"},
"botulinum":	{"NN"},
"botulinus":	{"NN"},
"botulism":	{"NN"},
"botulismotoxin":	{"NN"},
"bouanahsha":	{"FW"},
"bouchee":	{"NN"},
"boucle":	{"NN"},
"boudoir":	{"NN"},
"bouffant":	{"JJ","NN"},
"bouffe":	{"NN"},
"bougainvillaea":	{"NN"},
"bougainville":	{"NN"},
"bougainvillea":	{"NN"},
"bough":	{"NN"},
"boughed":	{"JJ"},
"boughless":	{"JJ"},
"boughs":	{"NNS"},
"bought":	{"VBD","VBN"},
"boughten":	{"NN"},
"bouillabaisse":	{"NN"},
"bouillon":	{"NN"},
"boulangerie":	{"NN","FW"},
"boulangeries":	{"NNS","FW"},
"boulder":	{"NN"},
"bouldered":	{"JJ"},
"bouldering":	{"NN"},
"boulders":	{"NNS"},
"bouldery":	{"JJ"},
"boule":	{"NN"},
"boulevard":	{"NN"},
"boulevardier":	{"NN"},
"boulevards":	{"NNS"},
"boulez":	{"NN"},
"boulle":	{"NN"},
"boun":	{"NN"},
"bounce":	{"VB","VBP","NN"},
"bounced":	{"VBD","VBN"},
"bouncer":	{"NN"},
"bouncers":	{"NNS"},
"bounces":	{"VBZ","NNS"},
"bouncily":	{"RB"},
"bounciness":	{"NN"},
"bouncing":	{"JJ","VBG"},
"bouncy":	{"JJ"},
"bound":	{"VBN","VBD","JJ","NN","VB","VBP"},
"boundaries":	{"NNS"},
"boundary":	{"NN"},
"bounded":	{"VBD","VBN"},
"boundedness":	{"NN"},
"bounden":	{"JJ"},
"bounder":	{"NN"},
"bounderish":	{"JJ"},
"bounders":	{"NNS"},
"bounding":	{"VBG"},
"boundless":	{"JJ"},
"boundlessly":	{"RB"},
"boundlessness":	{"NN"},
"bounds":	{"NNS","VBZ"},
"bounteous":	{"JJ"},
"bounteously":	{"RB"},
"bounteousness":	{"NN"},
"bountied":	{"JJ"},
"bountiful":	{"JJ","NN"},
"bountifully":	{"RB"},
"bountifulness":	{"NN"},
"bounty":	{"NN"},
"bounty-hunting":	{"NN"},
"bountyhunters":	{"NNS"},
"bouquet":	{"NN"},
"bouquets":	{"NNS"},
"bourbon":	{"NN"},
"bourbons":	{"NNS"},
"bourdon":	{"NN"},
"bourgeois":	{"JJ","NN"},
"bourgeois-bashing":	{"JJ"},
"bourgeoisie":	{"NN"},
"bourgeon":	{"VB"},
"bourgogne":	{"NN"},
"bourguignon":	{"NN"},
"bourn":	{"NN"},
"bourne":	{"NN"},
"bourse":	{"NN"},
"bourses":	{"NNS"},
"bourtree":	{"NN"},
"bouse":	{"VB"},
"boustrophedon":	{"NN"},
"boustrophedonic":	{"JJ"},
"bout":	{"NN"},
"bout-de-souffle":	{"FW"},
"bouteloua":	{"NN"},
"boutique":	{"NN"},
"boutique-lined":	{"JJ"},
"boutique-store":	{"NN"},
"boutiques":	{"NNS"},
"boutonniere":	{"NN"},
"bouts":	{"NNS"},
"bouvines":	{"NNS"},
"bouyei":	{"NN"},
"bovid":	{"JJ","NN"},
"bovidae":	{"NN"},
"bovinae":	{"NN"},
"bovine":	{"JJ","NN"},
"bovines":	{"NNS"},
"bovini":	{"NN"},
"bovril":	{"NN"},
"bow":	{"NN","VB","VBP"},
"bow-tie":	{"NN"},
"bow-tied":	{"JJ"},
"bow-wow":	{"NN"},
"bowditch":	{"NN"},
"bowdler":	{"NN"},
"bowdlerisation":	{"NN"},
"bowdlerise":	{"VB","VBP"},
"bowdlerised":	{"VBD","VBN"},
"bowdleriser":	{"NN"},
"bowdlerises":	{"VBZ"},
"bowdlerising":	{"VBG"},
"bowdlerism":	{"NN"},
"bowdlerization":	{"NN"},
"bowdlerize":	{"VB","VBP"},
"bowdlerized":	{"VBD","VBN"},
"bowdlerizer":	{"NN"},
"bowdlerizes":	{"VBZ"},
"bowdlerizing":	{"VBG"},
"bowed":	{"JJ","VBD","VBN"},
"bowel":	{"NN"},
"bowelless":	{"JJ"},
"bowels":	{"NNS"},
"bowenized":	{"VBN"},
"bower":	{"NN"},
"bowerbird":	{"NN"},
"bowered":	{"VBD","VBN"},
"bowering":	{"VBG"},
"bowers":	{"NNS","VBZ"},
"bowery":	{"JJ","NN"},
"bowfin":	{"NN"},
"bowfront":	{"JJ"},
"bowhead":	{"NN"},
"bowie":	{"NN"},
"bowiea":	{"NN"},
"bowing":	{"JJ","NN","VBG"},
"bowknot":	{"NN"},
"bowl":	{"NN","VBP","VB"},
"bowl-shaped":	{"JJ"},
"bowlder":	{"NN"},
"bowled":	{"VBD","VBN"},
"bowleg":	{"JJ","NN"},
"bowlegged":	{"JJ"},
"bowler":	{"NN"},
"bowlful":	{"NN"},
"bowline":	{"NN"},
"bowling":	{"NN","VBG"},
"bowling-league":	{"NN"},
"bowling-related":	{"JJ"},
"bowls":	{"NNS","VBZ"},
"bowman":	{"NN"},
"bows":	{"NNS","VBZ"},
"bowse":	{"VB"},
"bowser":	{"NN"},
"bowsprit":	{"NN"},
"bowstring":	{"NN"},
"bowtie":	{"NN"},
"box":	{"NN","VB","VBP"},
"box-office":	{"NN"},
"box-shaped":	{"JJ"},
"box-sized":	{"JJ"},
"boxberry":	{"NN"},
"boxcar":	{"NN"},
"boxcars":	{"NNS"},
"boxed":	{"JJ","VBD","VBN"},
"boxed-in":	{"JJ"},
"boxer":	{"NN"},
"boxers":	{"NNS"},
"boxershorts":	{"NNS"},
"boxes":	{"NNS","VBZ"},
"boxfish":	{"NN"},
"boxful":	{"NN"},
"boxing":	{"NN","VBG"},
"boxlike":	{"JJ"},
"boxthorn":	{"NN"},
"boxwood":	{"NN"},
"boxy":	{"JJ"},
"boy":	{"NN","UH"},
"boy-furiendo":	{"NN"},
"boy-manager":	{"NN"},
"boy-meets-girl":	{"NN"},
"boy-name":	{"NN"},
"boyars":	{"NNS"},
"boycott":	{"VB","VBP","NN"},
"boycotted":	{"VBD","VBN"},
"boycotting":	{"VBG"},
"boycotts":	{"VBZ","NNS"},
"boyfriend":	{"NN"},
"boyfriends":	{"NNS"},
"boyhood":	{"NN"},
"boyish":	{"JJ","NN"},
"boyish-looking":	{"JJ"},
"boyishly":	{"RB"},
"boyishness":	{"NN"},
"boykinia":	{"NN"},
"boyle":	{"NN"},
"boylike":	{"JJ","RB"},
"boyne":	{"NN"},
"boys":	{"NNS"},
"boys-and-girls":	{"NNS"},
"boysenberry":	{"NN"},
"boytrose":	{"JJ"},
"bozeman":	{"NN"},
"bozo":	{"NN"},
"bph":	{"NN"},
"bpi":	{"NN"},
"bpm":	{"NN"},
"bps":	{"NN"},
"br":	{"NN"},
"bra":	{"NN"},
"brabble":	{"VB"},
"brace":	{"NN","VB","VBP","NNS"},
"braced":	{"VBD","VBN"},
"bracelet":	{"NN"},
"bracelets":	{"NNS"},
"bracer":	{"NN"},
"bracero":	{"NN"},
"braces":	{"NNS","VBZ"},
"brachial":	{"JJ"},
"brachiate":	{"JJ"},
"brachiation":	{"NN"},
"brachii":	{"NNS"},
"brachinus":	{"NN"},
"brachiopod":	{"NN"},
"brachiopoda":	{"NN"},
"brachiopodous":	{"JJ"},
"brachium":	{"NN"},
"brachycephalic":	{"JJ"},
"brachycephalism":	{"NN"},
"brachycephaly":	{"NN"},
"brachychiton":	{"NN"},
"brachycome":	{"NN"},
"brachycranial":	{"JJ"},
"brachycranic":	{"JJ"},
"brachydactylia":	{"NN"},
"brachydactylic":	{"JJ"},
"brachydactylous":	{"JJ"},
"brachydactyly":	{"NN"},
"brachypterous":	{"JJ"},
"brachystegia":	{"NN"},
"brachyura":	{"NN"},
"brachyuran":	{"NN"},
"brachyurous":	{"JJ"},
"bracing":	{"JJ","VBG"},
"bracken":	{"NN"},
"bracket":	{"NN","VB","VBP"},
"bracketed":	{"VBD","VBN"},
"bracketing":	{"VBG"},
"brackets":	{"NNS","VBZ"},
"brackish":	{"JJ"},
"brackishness":	{"NN"},
"bract":	{"NN"},
"bracteal":	{"JJ"},
"bracteate":	{"JJ"},
"bracted":	{"JJ"},
"bracteolate":	{"JJ"},
"bracteole":	{"NN"},
"bractlet":	{"NN"},
"brad":	{"NN","VB","VBP"},
"bradawl":	{"NN"},
"bradbury":	{"NN"},
"bradded":	{"VBD","VBN"},
"bradding":	{"VBG"},
"bradford":	{"NN"},
"bradley":	{"NN"},
"brads":	{"NNS","VBZ"},
"bradstreet":	{"NN"},
"brady":	{"NN"},
"brady-type":	{"JJ"},
"bradycardia":	{"NN"},
"bradykinin":	{"NN"},
"bradypodidae":	{"NN"},
"bradypus":	{"NNS"},
"brae":	{"NN"},
"brag":	{"VB","VBP","NN"},
"braga":	{"NN"},
"brage":	{"NN"},
"bragg":	{"NN"},
"braggadocio":	{"NN"},
"braggart":	{"NN"},
"braggarts":	{"NNS"},
"bragged":	{"VBD","VBN"},
"bragger":	{"NN"},
"bragging":	{"VBG"},
"braggy":	{"JJ"},
"bragi":	{"NN"},
"brags":	{"VBZ","NNS"},
"brah":	{"FW"},
"brahe":	{"NN"},
"brahma":	{"NN"},
"brahman":	{"NN"},
"brahmana":	{"NN"},
"brahmanism":	{"NN"},
"brahmaputra":	{"NN"},
"brahmi":	{"NN"},
"brahmin":	{"NN"},
"brahminic":	{"JJ"},
"brahminical":	{"JJ"},
"brahminism":	{"NN"},
"brahms":	{"NNS"},
"brahui":	{"NN"},
"braid":	{"NN","VB","VBP"},
"braided":	{"JJ","VBD","VBN"},
"braiding":	{"VBG"},
"braids":	{"NNS","VBZ"},
"brail":	{"NN","VB"},
"braille":	{"VB","NN"},
"brain":	{"NN","VBP","VB"},
"brain-damaged":	{"JJ"},
"brain-fag":	{"NN"},
"brain-stem":	{"NN"},
"brain-teaser":	{"NN"},
"brain-wave":	{"JJ"},
"brain-worker":	{"NN"},
"brain-wracking":	{"JJ"},
"braincase":	{"NN"},
"brainchild":	{"NN"},
"brained":	{"VBD","VBN"},
"brainiac":	{"NN"},
"brainiacs":	{"NNS"},
"braining":	{"VBG"},
"brainish":	{"JJ"},
"brainless":	{"JJ"},
"brainlessly":	{"RB"},
"brainpan":	{"NN"},
"brainpower":	{"NN"},
"brains":	{"NNS","VBZ"},
"brainsick":	{"JJ"},
"brainstem":	{"NN"},
"brainstorm":	{"NN","VB","VBP"},
"brainstormed":	{"VBD","VBN"},
"brainstorming":	{"NN","VBG"},
"brainstorms":	{"NNS","VBZ"},
"braintree":	{"NN"},
"braintrusters":	{"NNS"},
"brainwash":	{"VB","VBP"},
"brainwashed":	{"VBD","VBN"},
"brainwashes":	{"VBZ"},
"brainwashing":	{"NN","VBG"},
"brainwave":	{"NN"},
"brainworker":	{"NN"},
"brainy":	{"JJ","NN"},
"braise":	{"VB","VBP"},
"braised":	{"JJ","VBD","VBN"},
"braises":	{"VBZ"},
"braising":	{"VBG"},
"brake":	{"NN","VB","VBP"},
"brake-horsepower":	{"NN"},
"brake-shoe":	{"NN"},
"braked":	{"VBD","VBN"},
"brakeman":	{"NN"},
"brakes":	{"NNS","VBZ"},
"braking":	{"VBG"},
"brakke":	{"NN"},
"braky":	{"JJ"},
"braless":	{"JJ"},
"brama":	{"NN"},
"bramante":	{"NN"},
"bramble":	{"NN","JJ"},
"brambles":	{"NNS"},
"brambling":	{"NN"},
"brambly":	{"JJ"},
"bramidae":	{"NN"},
"bran":	{"NN"},
"bran-new":	{"JJ"},
"bran-processing":	{"JJ"},
"branch":	{"NN","VB","VBP"},
"branch-by-branch":	{"RB"},
"branched":	{"VBD","VBN"},
"branches":	{"NNS","VBZ"},
"branchia":	{"NN"},
"branchial":	{"JJ"},
"branchiate":	{"JJ"},
"branching":	{"NN","VBG"},
"branchiobdella":	{"NN"},
"branchiobdellidae":	{"NN"},
"branchiopod":	{"JJ","NN"},
"branchiopoda":	{"NN"},
"branchiopodan":	{"JJ","NN"},
"branchiopodous":	{"JJ"},
"branchiostegidae":	{"NN"},
"branchiostomidae":	{"NN"},
"branchiura":	{"NN"},
"branchless":	{"JJ"},
"branchlet":	{"NN"},
"branchline":	{"JJ"},
"branchy":	{"JJ"},
"brancusi":	{"NN"},
"brand":	{"NN","VB","VBP"},
"brand-loyal":	{"JJ"},
"brand-name":	{"NN"},
"brand-new":	{"JJ"},
"brand-newness":	{"NN"},
"branded":	{"VBD","VBN","JJ"},
"brandenburg":	{"NN"},
"brandied":	{"JJ","VBD","VBN"},
"brandies":	{"NNS","VBZ"},
"branding":	{"NN","VBG"},
"brandish":	{"VB","VBP"},
"brandished":	{"VBD","VBN"},
"brandishes":	{"VBZ"},
"brandishing":	{"VBG"},
"brandmark":	{"NN"},
"brands":	{"NNS","VBZ"},
"brandt":	{"NN"},
"brandy":	{"NN","VB","VBP"},
"brandy-snap":	{"NN"},
"brandy-snaps":	{"NNS"},
"brandyball":	{"NN"},
"brandying":	{"VBG"},
"branson":	{"NN"},
"brant":	{"NN","NNS"},
"brants":	{"NNS"},
"braque":	{"NN"},
"bras":	{"NNS"},
"brasenia":	{"NN"},
"brash":	{"JJ"},
"brasher":	{"JJR"},
"brashest":	{"JJS"},
"brashly":	{"RB"},
"brashness":	{"NN"},
"brasier":	{"NN"},
"brasil":	{"NN"},
"brasilia":	{"NN"},
"brasov":	{"NN"},
"brass":	{"NN"},
"brass-bound":	{"JJ"},
"brassard":	{"NN"},
"brassavola":	{"NN"},
"brassbound":	{"JJ"},
"brasserie":	{"NN"},
"brasses":	{"NNS"},
"brassia":	{"NN"},
"brassica":	{"NN"},
"brassicaceae":	{"NN"},
"brassie":	{"NN"},
"brassiere":	{"NN"},
"brassieres":	{"NNS"},
"brassiness":	{"NN"},
"brasslike":	{"JJ"},
"brassy":	{"JJ","NN"},
"brat":	{"NN"},
"bratislava":	{"NN"},
"brats":	{"NNS"},
"brattice":	{"NN","VB"},
"brattish":	{"JJ"},
"brattle":	{"VB"},
"brattleboro":	{"NN"},
"bratty":	{"JJ","NN"},
"bratwurst":	{"NN"},
"braun":	{"NN"},
"braunschweig":	{"NN"},
"bravado":	{"NN"},
"brave":	{"JJ","NN","VB","VBP"},
"braved":	{"VBD","VBN"},
"bravely":	{"RB"},
"braveness":	{"NN"},
"braver":	{"JJR"},
"bravery":	{"NN"},
"braves":	{"VBZ"},
"bravest":	{"JJS"},
"bravest-feathered":	{"JJ"},
"braving":	{"VBG"},
"bravo":	{"NN","VB","VBP","UH"},
"bravoed":	{"VBD","VBN"},
"bravoes":	{"NNS","VBZ"},
"bravoing":	{"VBG"},
"bravura":	{"NN","JJ"},
"braw":	{"JJ"},
"braweling":	{"VBG"},
"brawl":	{"NN","VB","VBP"},
"brawle":	{"NN"},
"brawled":	{"VBD","VBN"},
"brawler":	{"NN"},
"brawling":	{"VBG"},
"brawls":	{"NNS","VBZ"},
"brawn":	{"NN"},
"brawnier":	{"JJR"},
"brawniest":	{"JJS"},
"brawniness":	{"NN"},
"brawny":	{"JJ"},
"bray":	{"NN","VB","VBP"},
"brayed":	{"VBD","VBN"},
"braying":	{"VBG"},
"brays":	{"NNS","VBZ"},
"braze":	{"VB"},
"brazen":	{"JJ","VB","VBP"},
"brazen-faced":	{"JJ"},
"brazened":	{"VBD","VBN"},
"brazening":	{"VBG"},
"brazenly":	{"RB"},
"brazenness":	{"NN"},
"brazens":	{"VBZ"},
"brazier":	{"NN"},
"brazilwood":	{"NN"},
"brazos":	{"NN"},
"brazzaville":	{"NN"},
"breach":	{"NN","VB","VBP"},
"breach-of-contract":	{"JJ"},
"breached":	{"VBD","VBN"},
"breaches":	{"NNS","VBZ"},
"breaching":	{"VBG"},
"bread":	{"NN","VB","VBP"},
"bread-and-butter":	{"JJ"},
"bread-bin":	{"NN"},
"bread-making":	{"NN"},
"bread-stick":	{"NN"},
"bread-winner":	{"NN"},
"bread-winners":	{"NNS"},
"breadbasket":	{"NN"},
"breadboard":	{"NN"},
"breadboards":	{"NNS"},
"breadbox":	{"NN"},
"breadboxes":	{"NNS"},
"breadcrumb":	{"NN"},
"breadcrumbs":	{"NNS"},
"breaded":	{"VBD","VBN","JJ"},
"breadfruit":	{"NN","NNS"},
"breading":	{"VBG"},
"breadline":	{"NN"},
"breadroot":	{"NN"},
"breads":	{"NNS","VBZ"},
"breadstick":	{"NN"},
"breadstuff":	{"NN"},
"breadth":	{"NN"},
"breadths":	{"NNS"},
"breadthways":	{"RB"},
"breadthwise":	{"RB"},
"breadwinner":	{"NN"},
"breadwinners":	{"NNS"},
"breadwinning":	{"JJ","NN"},
"break":	{"VB","NN","VBP"},
"break-away":	{"NN"},
"break-axe":	{"NN"},
"break-dance":	{"VB","VBP"},
"break-danced":	{"VBD","VBN"},
"break-dancer":	{"NN"},
"break-dancers":	{"NNS"},
"break-dances":	{"VBZ"},
"break-dancing":	{"VBG","NN"},
"break-down":	{"NN"},
"break-even":	{"JJ"},
"break-in":	{"JJ","NN"},
"break-neck":	{"JJ"},
"break-the-rules":	{"JJ"},
"break-through":	{"NN"},
"break-up":	{"NN","JJ"},
"breakability":	{"NN"},
"breakable":	{"JJ","NN"},
"breakableness":	{"NN"},
"breakables":	{"NNS"},
"breakage":	{"NN"},
"breakaway":	{"NN","JJ"},
"breakax":	{"NN"},
"breakaxe":	{"NN"},
"breakdance":	{"NN","VB","VBP"},
"breakdanced":	{"VBD","VBN"},
"breakdancer":	{"NN"},
"breakdancers":	{"NNS"},
"breakdances":	{"NNS","VBZ"},
"breakdancing":	{"NN","VBG"},
"breakdown":	{"NN"},
"breakdowns":	{"NNS"},
"breaker":	{"NN"},
"breakers":	{"NNS"},
"breakeven":	{"NN"},
"breakevens":	{"NNS"},
"breakfast":	{"NN","VB","VBP"},
"breakfast-table":	{"NN"},
"breakfasted":	{"VBD","VBN"},
"breakfasting":	{"VBG"},
"breakfasts":	{"NNS","VBZ"},
"breakin":	{"NN"},
"breaking":	{"VBG","NN","JJ"},
"breaking-out":	{"NN"},
"breakingly":	{"RB"},
"breakneck":	{"JJ","NN"},
"breakoff":	{"JJ"},
"breakout":	{"NN"},
"breaks":	{"NNS","VBZ"},
"breakstone":	{"NN"},
"breakthrough":	{"NN"},
"breakthroughs":	{"NNS"},
"breakup":	{"NN"},
"breakups":	{"NNS"},
"breakwater":	{"NN"},
"breakwaters":	{"NNS"},
"bream":	{"NN","NNS","VB","VBP"},
"breamed":	{"VBD","VBN"},
"breaming":	{"VBG"},
"breams":	{"NNS","VBZ"},
"breast":	{"NN","VB","VBP"},
"breast-cancer":	{"NN"},
"breast-deep":	{"RB"},
"breast-fed":	{"JJ","VBD","VBN"},
"breast-feed":	{"VB","VBP"},
"breast-feeding":	{"VBG","NN"},
"breast-feeds":	{"VBZ"},
"breast-high":	{"RB"},
"breastbone":	{"NN"},
"breastbones":	{"NNS"},
"breasted":	{"VBD","VBN"},
"breastfed":	{"VBD","VBN","JJ"},
"breastfeed":	{"VB","VBP"},
"breastfeeding":	{"VBG","NN"},
"breastfeeds":	{"VBZ"},
"breasting":	{"VBG"},
"breastless":	{"JJ"},
"breastpin":	{"NN"},
"breastplate":	{"NN"},
"breastplates":	{"NNS"},
"breasts":	{"NNS","VBZ"},
"breaststroke":	{"NN"},
"breaststroker":	{"NN"},
"breastwork":	{"NN"},
"breastworks":	{"NNS"},
"breath":	{"NN"},
"breath-taking":	{"JJ","NN"},
"breathalyse":	{"VB","VBP"},
"breathalysed":	{"VBD","VBN"},
"breathalyser":	{"NN"},
"breathalyses":	{"VBZ"},
"breathalysing":	{"VBG"},
"breathalyze":	{"VB","VBP"},
"breathalyzed":	{"VBD","VBN"},
"breathalyzer":	{"NN"},
"breathalyzes":	{"VBZ"},
"breathalyzing":	{"VBG"},
"breathe":	{"VB","VBP"},
"breathed":	{"VBD","JJ","VBN"},
"breather":	{"NN"},
"breathes":	{"VBZ","NNS"},
"breathing":	{"NN","VBG"},
"breathless":	{"JJ"},
"breathlessly":	{"RB"},
"breathlessness":	{"NN"},
"breaths":	{"NNS"},
"breathtaking":	{"JJ"},
"breathy":	{"JJ"},
"breccia":	{"NN"},
"brecciate":	{"VB"},
"brecht":	{"NN"},
"brechtian":	{"JJ"},
"bred":	{"VBD","VBN"},
"breech":	{"NN"},
"breech-loading":	{"JJ"},
"breechblock":	{"NN"},
"breechcloth":	{"NN"},
"breechclout":	{"NN"},
"breeched":	{"JJ"},
"breeches":	{"NNS"},
"breechloader":	{"NN"},
"breed":	{"NN","VB","VBP"},
"breeder":	{"NN"},
"breeders":	{"NNS"},
"breeding":	{"NN","VBG"},
"breeds":	{"VBZ","NNS"},
"breeze":	{"NN","VB","VBP"},
"breezed":	{"VBD","VBN"},
"breezes":	{"NNS","VBZ"},
"breezier":	{"JJR"},
"breeziest":	{"JJS"},
"breezily":	{"RB"},
"breeziness":	{"NN"},
"breezing":	{"VBG"},
"breezy":	{"JJ"},
"bregma":	{"NN"},
"bregmatic":	{"JJ"},
"breiz":	{"NN"},
"bremen":	{"NN"},
"bremerhaven":	{"NN"},
"bremsstrahlung":	{"NN"},
"bren":	{"NN"},
"brent":	{"NN"},
"brents":	{"NNS"},
"brescia":	{"NN"},
"breslau":	{"NN"},
"brest":	{"NN"},
"bretagne":	{"NN"},
"brethren":	{"NNS"},
"breton":	{"NN"},
"breuer":	{"NN"},
"breughel":	{"NN"},
"breve":	{"NN"},
"brevet":	{"NN","VB","VBP"},
"breveted":	{"VBD","VBN"},
"breveting":	{"VBG"},
"brevets":	{"VBZ"},
"brevetted":	{"VBD","VBN"},
"brevetting":	{"VBG"},
"breviary":	{"NN"},
"brevibloc":	{"NN"},
"brevicipitidae":	{"NN"},
"brevity":	{"NN"},
"brevoortia":	{"NN"},
"brew":	{"VB","VBP","NN"},
"brewage":	{"NN"},
"brewed":	{"VBD","VBN"},
"brewer":	{"NN"},
"breweries":	{"NNS"},
"brewers":	{"NNS"},
"brewery":	{"NN"},
"brewery-scion-turned-banker":	{"NN"},
"brewing":	{"VBG"},
"brewing-assets":	{"NNS"},
"brewpub":	{"NN"},
"brews":	{"VBZ","NNS"},
"brezhnev":	{"NN"},
"briar":	{"NN"},
"briard":	{"NN"},
"briarroot":	{"NN"},
"briarwood":	{"NN"},
"briary":	{"JJ"},
"bribable":	{"JJ"},
"bribe":	{"NN","VB","VBP"},
"bribed":	{"VBD","VBN"},
"briber":	{"NN"},
"bribers":	{"NNS"},
"bribery":	{"NN"},
"bribery-related":	{"JJ"},
"bribes":	{"NNS","VBZ"},
"bribing":	{"VBG"},
"bric-a-brac":	{"NN","JJ"},
"brick":	{"NN","VB","VBP"},
"brick-and-mortar":	{"JJ"},
"brick-shaped":	{"JJ"},
"brickbat":	{"NN"},
"brickbats":	{"NNS"},
"bricked":	{"VBD","VBN"},
"brickellia":	{"NN"},
"brickfield":	{"NN"},
"bricking":	{"VBG"},
"brickkiln":	{"NN"},
"bricklayer":	{"NN"},
"bricklayers":	{"NNS"},
"bricklaying":	{"NN"},
"brickle":	{"JJ"},
"brickly":	{"JJ"},
"bricks":	{"NNS","VBZ"},
"brickwork":	{"NN"},
"brickyard":	{"NN"},
"bricole":	{"NN"},
"bridal":	{"NN","JJ"},
"bridal-wreath":	{"NN"},
"bride":	{"NN"},
"bride-gift":	{"NN"},
"bride-to-be":	{"NN"},
"bridecake":	{"NN"},
"bridegroom":	{"NN"},
"brides":	{"NNS"},
"bridesmaid":	{"NN"},
"bridesmaids":	{"NNS"},
"bridge":	{"NN","VB","VBP"},
"bridge-financing":	{"JJ"},
"bridge-lending":	{"JJ"},
"bridge-loan":	{"JJ"},
"bridgeable":	{"JJ"},
"bridged":	{"VBD","VBN"},
"bridged-t":	{"NN"},
"bridgehead":	{"NN"},
"bridgeheads":	{"NNS"},
"bridgeport":	{"NN"},
"bridges":	{"NNS","VBZ"},
"bridget":	{"NN"},
"bridgework":	{"NN"},
"bridging":	{"NN","VBG"},
"bridle":	{"NN","VB","VBP"},
"bridled":	{"VBD","VBN"},
"bridles":	{"NNS","VBZ"},
"bridling":	{"VBG"},
"bridoon":	{"NN"},
"brie":	{"NN"},
"brief":	{"JJ","NN","VB","VBP"},
"briefcase":	{"NN"},
"briefcases":	{"NNS"},
"briefed":	{"VBD","VBN"},
"briefer":	{"JJR","NN"},
"briefers":	{"NNS"},
"briefest":	{"JJS"},
"briefing":	{"NN","VBG"},
"briefings":	{"NNS"},
"briefless":	{"JJ"},
"briefly":	{"RB"},
"briefly-illumed":	{"VBN"},
"briefness":	{"NN"},
"briefs":	{"NNS","VBZ"},
"brien":	{"NN"},
"brier":	{"NN"},
"brier-wood":	{"NN"},
"brierley-controlled":	{"JJ"},
"brierpatch":	{"NN"},
"brierwood":	{"NN"},
"briery":	{"JJ"},
"brig":	{"NN"},
"brigade":	{"VB","NN"},
"brigaded":	{"VBD","VBN"},
"brigades":	{"VBZ","NNS"},
"brigadier":	{"NN"},
"brigading":	{"VBG"},
"brigand":	{"NN"},
"brigandine":	{"NN"},
"brigands":	{"NNS"},
"brigantine":	{"NN"},
"bright":	{"JJ","RB"},
"bright-eyed":	{"JJ"},
"bright-green":	{"JJ"},
"bright-looking":	{"JJ"},
"bright-red":	{"JJ"},
"brighten":	{"VB","VBP"},
"brightened":	{"VBD","VBN"},
"brightener":	{"NN"},
"brightening":	{"VBG"},
"brightens":	{"VBZ"},
"brighter":	{"JJR"},
"brightest":	{"JJS"},
"brightly":	{"RB"},
"brightly-colored":	{"JJ"},
"brightly-coloured":	{"JJ"},
"brightness":	{"NN"},
"brigid":	{"NN"},
"brigit":	{"NN"},
"brihaspati":	{"NN"},
"brill":	{"NN","JJ"},
"brilliance":	{"NN"},
"brilliancy":	{"NN"},
"brilliant":	{"JJ"},
"brilliantine":	{"NN"},
"brilliantly":	{"RB"},
"brillo":	{"NN"},
"brim":	{"NN","VB","VBP"},
"brimful":	{"JJ"},
"brimfull":	{"JJ"},
"brimless":	{"JJ"},
"brimmed":	{"VBD","VBN","JJ"},
"brimming":	{"VBG"},
"brims":	{"NNS","VBZ"},
"brimstone":	{"NN"},
"brinded":	{"JJ"},
"brindisi":	{"NN"},
"brindle":	{"NN","JJ"},
"brindled":	{"JJ"},
"brine":	{"NN"},
"brine-cured":	{"JJ"},
"brined":	{"VBD","VBN"},
"brines":	{"VBZ"},
"bring":	{"VB","VBP"},
"bringing":	{"VBG"},
"brings":	{"VBZ"},
"brininess":	{"NN"},
"brining":	{"VBG"},
"brinjal":	{"NN"},
"brink":	{"NN"},
"brinkmanship":	{"NN"},
"brinksmanship":	{"NN"},
"brinton":	{"NN"},
"briny":	{"JJ","NN"},
"brio":	{"NN"},
"brioche":	{"NN"},
"briony":	{"NN"},
"brioschi":	{"NN"},
"briquet":	{"NN"},
"briquette":	{"NN"},
"briquettes":	{"NNS"},
"bris":	{"NN"},
"brisance":	{"NN"},
"brisant":	{"JJ"},
"brisbane":	{"NN"},
"brisk":	{"JJ","VB","VBP"},
"brisked":	{"VBD","VBN"},
"brisken":	{"VB"},
"brisker":	{"JJR"},
"briskest":	{"JJS"},
"brisket":	{"NN"},
"brisking":	{"VBG"},
"briskly":	{"RB"},
"briskness":	{"NN"},
"brisks":	{"VBZ"},
"brisling":	{"NN"},
"briss":	{"NN"},
"bristle":	{"NN","VB","VBP"},
"bristle-pointed":	{"JJ"},
"bristled":	{"VBD","VBN"},
"bristlegrass":	{"NN"},
"bristlelike":	{"JJ"},
"bristles":	{"VBZ","NNS"},
"bristletail":	{"NN"},
"bristliness":	{"NN"},
"bristling":	{"JJ","VBG"},
"bristly":	{"JJ"},
"bristol":	{"NN"},
"brit":	{"NN"},
"britain":	{"NN"},
"britain-dominated":	{"JJ"},
"britannic":	{"JJ"},
"britches":	{"NNS"},
"brith":	{"NN"},
"briticism":	{"NN"},
"britishism":	{"NN"},
"briton":	{"JJ","NN"},
"brits":	{"NNS"},
"britt":	{"NN"},
"brittanic":	{"NN"},
"brittany":	{"NN"},
"britten":	{"NN"},
"brittle":	{"JJ","NN"},
"brittle-star":	{"NN"},
"brittlebush":	{"NN"},
"brittleness":	{"NN"},
"brno":	{"NN"},
"bro":	{"NN"},
"broach":	{"VB","VBP"},
"broached":	{"VBD","VBN"},
"broaches":	{"VBZ"},
"broaching":	{"VBG"},
"broad":	{"JJ","NN","RB"},
"broad-appeal":	{"JJ"},
"broad-based":	{"JJ"},
"broad-bean":	{"NN"},
"broad-brimmed":	{"JJ"},
"broad-headed":	{"JJ"},
"broad-leafed":	{"JJ"},
"broad-leaved":	{"JJ"},
"broad-minded":	{"JJ"},
"broad-mindedly":	{"RB"},
"broad-mindedness":	{"NN"},
"broad-nibbed":	{"JJ"},
"broad-scale":	{"JJ"},
"broad-scaled":	{"JJ"},
"broad-shouldered":	{"JJ"},
"broadax":	{"NN"},
"broadaxe":	{"NN"},
"broadband":	{"JJ","NN"},
"broadbands":	{"NNS"},
"broadbill":	{"NN"},
"broadcast":	{"NN","VB","VBP","VBN","VBD","JJ"},
"broadcast-and-cable":	{"JJ"},
"broadcaster":	{"NN"},
"broadcasters":	{"NNS"},
"broadcasting":	{"NN","VBG"},
"broadcasts":	{"NNS","VBZ"},
"broadcloth":	{"NN"},
"broaden":	{"VB","VBP"},
"broadened":	{"VBD","VBN"},
"broadening":	{"VBG"},
"broadens":	{"VBZ"},
"broader":	{"JJR"},
"broadest":	{"JJS"},
"broadleaf":	{"JJ","NN"},
"broadleaves":	{"NNS"},
"broadloom":	{"NN"},
"broadly":	{"RB"},
"broadness":	{"NN"},
"broadnosed":	{"JJ"},
"broadsheet":	{"NN"},
"broadside":	{"NN","RB","VB","VBP"},
"broadsided":	{"VBD","VBN"},
"broadsides":	{"NNS","VBZ"},
"broadsiding":	{"VBG"},
"broadsword":	{"NN"},
"broadtail":	{"NN"},
"broadwise":	{"RB"},
"brobdingnag":	{"NN"},
"brobdingnagian":	{"JJ"},
"broca":	{"NN"},
"brocade":	{"NN"},
"brocaded":	{"JJ"},
"brocadopa":	{"NN"},
"broccoli":	{"NN"},
"brochette":	{"NN"},
"brochure":	{"NN"},
"brochures":	{"NNS"},
"brock":	{"NN"},
"brocket":	{"NN"},
"brockhouse":	{"NN"},
"brockle":	{"NN"},
"brodiaea":	{"NN"},
"brogan":	{"NN"},
"broglie":	{"NN"},
"brogue":	{"NN"},
"broider":	{"VB","VBP"},
"broidered":	{"VBD","VBN"},
"broidering":	{"VBG"},
"broiders":	{"VBZ"},
"broidery":	{"NN"},
"broil":	{"VB","VBP"},
"broiled":	{"VBD","VBN"},
"broiler":	{"NN"},
"broilers":	{"NNS"},
"broiling":	{"JJ","VBG"},
"broils":	{"VBZ"},
"broke":	{"VBD","JJ"},
"broken":	{"VBN","JJ"},
"broken-backed":	{"JJ"},
"broken-down":	{"JJ"},
"broken-field":	{"JJ"},
"broken-nosed":	{"JJ"},
"brokenhearted":	{"JJ"},
"brokenheartedness":	{"NN"},
"brokenly":	{"RB"},
"broker":	{"NN","VBP","VB"},
"broker-dealer":	{"NN"},
"broker-dealers":	{"NNS"},
"broker-sold":	{"JJ"},
"brokerage":	{"NN"},
"brokerage-by-brokerage":	{"JJ"},
"brokerage-firm":	{"JJ"},
"brokerage-house":	{"NN"},
"brokerage-stock":	{"NN"},
"brokerages":	{"NNS"},
"brokered":	{"VBD","VBN"},
"brokering":	{"VBG","NN"},
"brokers":	{"NNS","VBZ"},
"brolly":	{"NN"},
"bromate":	{"NN","VB","VBP"},
"bromated":	{"VBD","VBN"},
"bromates":	{"VBZ"},
"bromating":	{"VBG"},
"bromberg":	{"NN"},
"brome":	{"NN"},
"bromegrass":	{"NN"},
"bromelia":	{"NN"},
"bromeliaceae":	{"NN"},
"bromeosin":	{"NN"},
"bromic":	{"JJ"},
"bromide":	{"NN"},
"bromides":	{"NNS"},
"bromidic":	{"JJ"},
"brominate":	{"VB"},
"bromine":	{"NN"},
"bromo-seltzer":	{"NN"},
"bromoform":	{"NN"},
"bromphenol":	{"NN"},
"bromus":	{"NN"},
"bronc":	{"NN"},
"bronchi":	{"NNS"},
"bronchial":	{"JJ"},
"bronchiolar":	{"JJ"},
"bronchiole":	{"NN"},
"bronchioles":	{"NNS"},
"bronchiolitis":	{"NN"},
"bronchitic":	{"JJ"},
"bronchitis":	{"NN"},
"broncho":	{"NN"},
"bronchodilator":	{"NN"},
"bronchopneumonia":	{"NN"},
"bronchoscope":	{"NN"},
"bronchoscopic":	{"JJ"},
"bronchospasm":	{"NN"},
"bronchus":	{"NN"},
"bronco":	{"NN"},
"broncobuster":	{"NN"},
"broncs":	{"NNS"},
"bronte":	{"NN"},
"brontosaur":	{"NN"},
"brontosaurus":	{"NN"},
"bronx":	{"NN"},
"bronze":	{"VB","NN","JJ"},
"bronze-red":	{"JJ"},
"bronzed":	{"JJ","VBD","VBN"},
"bronzes":	{"NNS","VBZ"},
"bronzing":	{"VBG"},
"bronzy":	{"JJ"},
"bronzy-green-gold":	{"JJ"},
"brooch":	{"NN"},
"brood":	{"NN","VB","VBP"},
"brooded":	{"VBD","VBN"},
"brooder":	{"NN"},
"broodier":	{"JJR"},
"broodiest":	{"JJS"},
"broodily":	{"RB"},
"broodiness":	{"NN"},
"brooding":	{"JJ","VBG"},
"broodingly":	{"RB"},
"broodmare":	{"NN"},
"broods":	{"NNS","VBZ"},
"broody":	{"JJ"},
"brook":	{"NN","VB","VBP"},
"brooked":	{"VBD","VBN"},
"brooking":	{"VBG"},
"brooklet":	{"NN"},
"brooklime":	{"NN"},
"brooklyn-born":	{"JJ"},
"brooks":	{"NNS","VBZ"},
"brookweed":	{"NN"},
"broom":	{"NN"},
"broom-weed":	{"NN"},
"broomcorn":	{"NN"},
"brooms":	{"NNS"},
"broomstick":	{"NN"},
"broomweed":	{"NN"},
"bros":	{"NNS"},
"brosmius":	{"NN"},
"broth":	{"NN"},
"brothel":	{"NN"},
"brothels":	{"NNS"},
"brother":	{"NN","UH"},
"brother-in-law":	{"NN"},
"brotherhood":	{"NN"},
"brotherhoods":	{"NNS"},
"brotherism":	{"NN"},
"brotherlike":	{"JJ"},
"brotherly":	{"JJ"},
"brothers":	{"NNS"},
"brotula":	{"NN"},
"brotulidae":	{"NN"},
"brougham":	{"NN"},
"brought":	{"VBD","VBN"},
"brouhaha":	{"NN"},
"broussonetia":	{"NN"},
"brow":	{"NN"},
"brow-beating":	{"NN"},
"browallia":	{"NN"},
"browbeat":	{"VB","VBP","VBD"},
"browbeaten":	{"VB","VBN"},
"browbeating":	{"VBG"},
"browbeats":	{"VBZ"},
"brown":	{"JJ","NN","VB","VBP"},
"brown-black":	{"JJ"},
"brown-coal":	{"NN"},
"brown-edged":	{"JJ"},
"brown-gray":	{"JJ"},
"brown-green":	{"JJ"},
"brown-grey":	{"JJ"},
"brown-haired":	{"JJ"},
"brown-nose":	{"VB","VBP"},
"brown-nosed":	{"VBD","VBN"},
"brown-noser":	{"NN"},
"brown-nosers":	{"NNS"},
"brown-noses":	{"VBZ"},
"brown-nosing":	{"VBG","NN"},
"brown-paper":	{"JJ"},
"brown-purple":	{"JJ"},
"brown-speckled":	{"JJ"},
"brown-striped":	{"JJ"},
"brown-tobacco":	{"JJ"},
"browne":	{"NN"},
"browned":	{"VBD","VBN"},
"browner":	{"JJR"},
"brownest":	{"JJS"},
"brownie":	{"NN"},
"brownies":	{"NNS"},
"browning":	{"VBG"},
"brownish":	{"JJ"},
"brownish-black":	{"JJ"},
"brownish-gray":	{"JJ"},
"brownish-green":	{"JJ"},
"brownish-grey":	{"JJ"},
"brownish-orange":	{"JJ"},
"brownish-purple":	{"JJ"},
"brownish-red":	{"JJ"},
"brownish-speckled":	{"JJ"},
"brownish-striped":	{"JJ"},
"brownish-yellow":	{"JJ"},
"brownness":	{"NN"},
"brownout":	{"NN"},
"brownouts":	{"NNS"},
"browns":	{"NNS","VBZ"},
"brownshirt":	{"NN"},
"brownstone":	{"NN"},
"brownstones":	{"NNS"},
"brownsville":	{"NN"},
"browntail":	{"NN"},
"browny":	{"JJ"},
"browny-haired":	{"JJ"},
"brows":	{"NNS"},
"browse":	{"VB","NN","VBP"},
"browsed":	{"VBD","VBN"},
"browser":	{"NN"},
"browsers":	{"NNS"},
"browses":	{"VBZ"},
"browsing":	{"NN","VBG"},
"bruce":	{"NN"},
"brucella":	{"NN"},
"brucellosis":	{"NN"},
"bruch":	{"NN"},
"bruchidae":	{"NN"},
"bruchus":	{"NN"},
"brucine":	{"NN"},
"bruckenthalia":	{"NN"},
"bruckner":	{"NN"},
"bruddah":	{"FW","NN"},
"bruegel":	{"NN"},
"brueghel":	{"NN"},
"bruges":	{"NNS"},
"brugmansia":	{"NN"},
"bruin":	{"NN"},
"bruinish":	{"JJ"},
"bruise":	{"VB","VBP","NN"},
"bruised":	{"JJ","VBD","VBN"},
"bruiser":	{"NN"},
"bruisers":	{"NNS"},
"bruises":	{"NNS","VBZ"},
"bruising":	{"JJ","NN","VBG"},
"bruit":	{"VB","VBP"},
"bruited":	{"VBD","VBN"},
"bruiting":	{"VBG"},
"bruits":	{"VBZ"},
"brule":	{"NN"},
"brumaire":	{"NN"},
"brumal":	{"JJ"},
"brummagem":	{"NN"},
"brummell":	{"NN"},
"brummie":	{"NN"},
"brummy":	{"NN"},
"brumous":	{"JJ"},
"brunanburh":	{"NN"},
"brunch":	{"NN"},
"brunches":	{"NNS"},
"brunei":	{"NN"},
"bruneian":	{"JJ","NN"},
"brunelleschi":	{"NN"},
"brunet":	{"JJ","NN"},
"brunette":	{"NN"},
"brunettes":	{"NNS"},
"brunfelsia":	{"NN"},
"brunhild":	{"NN"},
"brunn":	{"NN"},
"brunnhilde":	{"NN"},
"bruno":	{"NN"},
"brunswick":	{"NN"},
"brunt":	{"NN"},
"brusa":	{"NN"},
"brush":	{"NN","VB","VBP"},
"brush-off":	{"NN"},
"brushbacks":	{"NNS"},
"brushcut":	{"NN"},
"brushed":	{"JJ","VBD","VBN"},
"brushes":	{"VBZ","NNS"},
"brushfire":	{"NN"},
"brushing":	{"NN","VBG"},
"brushlike":	{"JJ"},
"brushoff":	{"NN"},
"brushup":	{"NN"},
"brushwood":	{"NN"},
"brushwork":	{"NN"},
"brushy":	{"JJ"},
"brusk":	{"JJ"},
"brusque":	{"JJ"},
"brusquely":	{"RB"},
"brusqueness":	{"NN"},
"brut":	{"NN","JJ"},
"brutal":	{"JJ"},
"brutal-and":	{"JJ","CC"},
"brutalisation":	{"NN"},
"brutalise":	{"VB","VBP"},
"brutalised":	{"VBD","VBN"},
"brutalises":	{"VBZ"},
"brutalising":	{"VBG"},
"brutalism":	{"NN"},
"brutalities":	{"NNS"},
"brutality":	{"NN"},
"brutalization":	{"NN"},
"brutalize":	{"VB","VBP"},
"brutalized":	{"VBD","VBN"},
"brutalizes":	{"VBZ"},
"brutalizing":	{"VBG"},
"brutally":	{"RB"},
"brute":	{"NN","JJ"},
"brutes":	{"NNS"},
"brutish":	{"JJ"},
"brutishly":	{"RB"},
"brutus":	{"NN"},
"bruxelles":	{"NNS"},
"bruxism":	{"NN"},
"brya":	{"NN"},
"bryaceae":	{"NN"},
"bryales":	{"NNS"},
"bryanthus":	{"NN"},
"bryce":	{"NN"},
"brynge":	{"VBP","VB"},
"brynhild":	{"NN"},
"bryony":	{"NN"},
"bryophyta":	{"NN"},
"bryophyte":	{"NN"},
"bryophytic":	{"JJ"},
"bryopsida":	{"NN"},
"bryozoa":	{"NN"},
"bryozoan":	{"NN"},
"brythonic":	{"NN"},
"bryum":	{"NN"},
"bs":	{"NN"},
"bsarch":	{"NN"},
"bse":	{"NN"},
"btu":	{"NN"},
"bubaline":	{"JJ"},
"bubalus":	{"NN"},
"bubble":	{"NN","VBP","VB"},
"bubbled":	{"VBD","VBN"},
"bubblegum":	{"NN","JJ"},
"bubblejet":	{"NN"},
"bubblelike":	{"JJ"},
"bubbler":	{"NN"},
"bubbles":	{"NNS","VBZ"},
"bubbliness":	{"NN"},
"bubbling":	{"JJ","VBG"},
"bubbly":	{"NN","JJ"},
"buber":	{"NN"},
"bubo":	{"NN"},
"bubonic":	{"JJ"},
"bubulcus":	{"NNS"},
"buccal":	{"JJ"},
"buccaneer":	{"NN"},
"buccaneering":	{"JJ"},
"buccaneers":	{"NNS"},
"buccinidae":	{"NN"},
"buccolic":	{"JJ"},
"bucconidae":	{"NN"},
"buccula":	{"NN"},
"bucephala":	{"NN"},
"buceros":	{"NN"},
"bucerotidae":	{"NN"},
"buchanan":	{"NN"},
"bucharest":	{"NN"},
"bucharesti":	{"NN"},
"buchenwald":	{"NN"},
"buchloe":	{"NN"},
"buchner":	{"NN"},
"buck":	{"NN","NNS","VB","VBP","RB"},
"buck-and-wing":	{"NN"},
"buck-teeth":	{"NNS"},
"buck-tooth":	{"NN"},
"buck-toothed":	{"JJ"},
"buckaroo":	{"NN"},
"buckaroos":	{"NNS"},
"buckbean":	{"NN"},
"buckboard":	{"NN"},
"buckboards":	{"NNS"},
"bucked":	{"VBD","VBN","JJ"},
"buckeroo":	{"NN"},
"bucket":	{"NN","VB","VBP"},
"bucket-shop":	{"JJ"},
"bucketed":	{"VBD","VBN"},
"bucketful":	{"NN"},
"bucketing":	{"VBG"},
"buckets":	{"VBZ","NNS"},
"buckeye":	{"NN"},
"buckhannon":	{"NN"},
"buckhorn":	{"NN"},
"bucking":	{"VBG"},
"bucking-up":	{"NN"},
"buckle":	{"NN","VB","VBP"},
"buckle-on":	{"JJ"},
"buckled":	{"VBD","VBN","JJ"},
"buckler":	{"NN"},
"buckles":	{"VBZ","NNS"},
"buckleya":	{"NN"},
"buckling":	{"VBG"},
"buckminsterfullerene":	{"NN"},
"buckram":	{"NN","JJ","VB","VBP"},
"buckramed":	{"VBD","VBN"},
"buckraming":	{"VBG"},
"buckrams":	{"VBZ"},
"bucks":	{"VBZ","NNS"},
"bucksaw":	{"NN"},
"buckshee":	{"JJ","RB"},
"buckshot":	{"NN"},
"buckskin":	{"NN"},
"buckskins":	{"NNS"},
"buckthorn":	{"NN"},
"bucktooth":	{"NN"},
"buckwheat":	{"NN"},
"buckyball":	{"NN"},
"bucolic":	{"JJ","NN"},
"bucuresti":	{"NN"},
"bud":	{"NN","VB","VBP"},
"budapest":	{"NN"},
"budded":	{"VBD","VBN"},
"buddha":	{"NN"},
"buddhism":	{"NN"},
"buddhistic":	{"JJ"},
"buddied":	{"VBD","VBN"},
"buddies":	{"NNS","VBZ"},
"budding":	{"JJ","VBG"},
"buddleia":	{"NN"},
"buddy":	{"NN","VB","VBP"},
"buddy-buddy":	{"JJ"},
"buddying":	{"VBG"},
"budge":	{"VB","VBP"},
"budged":	{"VBD","VBN"},
"budgereegah":	{"NN"},
"budgerigar":	{"NN"},
"budgerygah":	{"NN"},
"budges":	{"VBZ"},
"budget":	{"NN","VB","VBP","JJ"},
"budget-altering":	{"JJ"},
"budget-cutting":	{"NN"},
"budget-hotel":	{"NN"},
"budget-making":	{"JJ"},
"budget-priced":	{"JJ"},
"budget-reconciliation":	{"JJ","NN"},
"budget-reduction":	{"JJ"},
"budget-sensitive":	{"JJ"},
"budget-strapped":	{"JJ"},
"budget-wise":	{"JJ"},
"budgetary":	{"JJ"},
"budgeted":	{"VBD","VBN"},
"budgeteers":	{"NNS"},
"budgeting":	{"NN","VBG"},
"budgets":	{"NNS","VBZ"},
"budgie":	{"NN"},
"budgies":	{"NNS"},
"budging":	{"VBG"},
"budorcas":	{"NNS"},
"buds":	{"NNS","VBZ"},
"budworm":	{"NN"},
"buff":	{"NN","JJ","VB","VBP"},
"buff-brown":	{"JJ"},
"buff-colored":	{"JJ"},
"buff-coloured":	{"JJ"},
"buffalo":	{"NN"},
"buffaloed":	{"VBD","VBN"},
"buffaloes":	{"VBZ","NNS"},
"buffalofish":	{"NN"},
"buffaloing":	{"VBG"},
"buffed":	{"VBD","VBN"},
"buffer":	{"NN","VB","VBP"},
"buffered":	{"VBD","VBN"},
"buffering":	{"VBG"},
"buffers":	{"NNS","VBZ"},
"buffet":	{"NN","VB","VBP"},
"buffeted":	{"VBD","VBN"},
"buffeting":	{"NN","VBG"},
"buffetings":	{"NNS"},
"buffets":	{"VBZ","NNS"},
"buffing":	{"VBG","NN"},
"bufflehead":	{"NN"},
"buffoon":	{"NN"},
"buffoonery":	{"NN"},
"buffoonish":	{"NN"},
"buffoons":	{"NNS"},
"buffs":	{"NNS","VBZ"},
"bufo":	{"NN"},
"bufonidae":	{"NN"},
"bug":	{"NN","VB","VBP"},
"bug-free":	{"JJ"},
"bug-hunter":	{"NN"},
"bugaboo":	{"NN"},
"bugaboos":	{"NNS"},
"buganda":	{"NN"},
"bugbane":	{"NN"},
"bugbear":	{"NN"},
"bugeyed":	{"JJ"},
"bugged":	{"VBD","VBN"},
"bugger":	{"NN","VB","VBP","UH"},
"bugger-all":	{"NN"},
"buggered":	{"VBD","VBN","JJ"},
"buggering":	{"VBG"},
"buggers":	{"NNS","VBZ"},
"buggery":	{"NN"},
"buggies":	{"NNS"},
"bugginess":	{"NN"},
"bugging":	{"VBG"},
"buggy":	{"NN"},
"bugle":	{"NN","VB","VBP"},
"bugled":	{"VBD","VBN"},
"bugler":	{"NN"},
"buglers":	{"NNS"},
"bugles":	{"NNS","VBZ"},
"bugless":	{"JJ"},
"bugleweed":	{"NN"},
"buglike":	{"JJ"},
"bugling":	{"VBG"},
"bugloss":	{"NN"},
"bugologist":	{"NN"},
"bugology":	{"NN"},
"bugs":	{"NNS","VBZ"},
"buhl":	{"NN"},
"build":	{"VB","VBP","NN"},
"build-better-for-less":	{"JJ"},
"build-up":	{"NN"},
"build-ups":	{"NNS"},
"builder":	{"NN"},
"builder-dealer":	{"JJ"},
"builders":	{"NNS"},
"buildin":	{"NN","JJ"},
"building":	{"NN","VBG"},
"building-control":	{"NN"},
"building-materials":	{"NNS"},
"building-products":	{"NNS"},
"building-related":	{"JJ"},
"building-society":	{"JJ"},
"building-supplies":	{"NNS"},
"buildings":	{"NNS"},
"builds":	{"VBZ","NNS"},
"buildup":	{"NN"},
"built":	{"VBN","VBD","JJ"},
"built-detergent":	{"JJ"},
"built-from-kit":	{"JJ"},
"built-in":	{"JJ","NN"},
"built-soap":	{"NN"},
"built-up":	{"JJ"},
"builtin":	{"JJ"},
"buirdly":	{"JJ"},
"bujumbura":	{"NN"},
"bukharin":	{"NN"},
"bulawayo":	{"NN"},
"bulb":	{"NN"},
"bulb-making":	{"JJ"},
"bulb-shaped":	{"JJ"},
"bulbaceous":	{"JJ"},
"bulbar":	{"JJ"},
"bulbed":	{"JJ"},
"bulbil":	{"NN"},
"bulblet":	{"NN"},
"bulblike":	{"JJ"},
"bulbous":	{"JJ"},
"bulbs":	{"NNS"},
"bulbul":	{"NN"},
"bulge":	{"NN","VB","VBP"},
"bulged":	{"VBD","VBN"},
"bulges":	{"NNS","VBZ"},
"bulghur":	{"NN"},
"bulginess":	{"NN"},
"bulging":	{"VBG"},
"bulgur":	{"NN"},
"bulgy":	{"JJ"},
"bulimarexia":	{"NN"},
"bulimia":	{"NN"},
"bulimic":	{"JJ","NN"},
"bulk":	{"NN","VB","VBP","JJ"},
"bulk-buying":	{"JJ"},
"bulk-chemical":	{"NN","JJ","JJ"},
"bulk-mail":	{"NN"},
"bulked":	{"VBD","VBN","JJ"},
"bulked-up":	{"JJ"},
"bulkhead":	{"NN"},
"bulkheads":	{"NNS"},
"bulkiness":	{"NN"},
"bulking":	{"VBG"},
"bulks":	{"NNS","VBZ"},
"bulky":	{"JJ"},
"bull":	{"NN","UH","VBP","VB"},
"bull's-eye":	{"NN"},
"bull's-eyes":	{"NNS"},
"bull-headed":	{"JJ"},
"bull-like":	{"JJ"},
"bull-market":	{"NN"},
"bull-necked":	{"JJ"},
"bull-roaring":	{"JJ"},
"bull-sessions":	{"NNS"},
"bull-snake":	{"NN"},
"bulla":	{"NN"},
"bullace":	{"NN"},
"bullate":	{"JJ"},
"bullbat":	{"NN"},
"bullbrier":	{"NN"},
"bulldog":	{"NN","VB","VBP"},
"bulldogged":	{"VBD","VBN"},
"bulldogging":	{"VBG"},
"bulldogs":	{"NNS","VBZ"},
"bulldoze":	{"VB","VBP"},
"bulldozed":	{"VBD","VBN"},
"bulldozer":	{"NN"},
"bulldozers":	{"NNS"},
"bulldozes":	{"VBZ"},
"bulldozing":	{"VBG"},
"bulled":	{"VBD","VBN"},
"bullet":	{"NN"},
"bullet-headed":	{"JJ"},
"bullet-proof":	{"JJ"},
"bullet-riddled":	{"JJ"},
"bullethead":	{"NN"},
"bulletin":	{"NN","VB","VBP"},
"bulletin-board":	{"NN"},
"bulletined":	{"VBD","VBN"},
"bulletining":	{"VBG"},
"bulletins":	{"NNS","VBZ"},
"bulletproof":	{"JJ"},
"bullets":	{"NNS"},
"bullfight":	{"NN"},
"bullfighter":	{"NN"},
"bullfighters":	{"NNS"},
"bullfighting":	{"NN"},
"bullfights":	{"NNS"},
"bullfinch":	{"NN"},
"bullfinches":	{"NNS"},
"bullfrog":	{"NN"},
"bullfrogs":	{"NNS"},
"bullhead":	{"NN"},
"bullheaded":	{"JJ"},
"bullheadedly":	{"RB"},
"bullheadedness":	{"NN"},
"bullhide":	{"NN"},
"bullhorn":	{"NN"},
"bullhorns":	{"NNS"},
"bullied":	{"VBD","VBN"},
"bullies":	{"VBZ","NNS"},
"bulling":	{"VBG"},
"bullion":	{"NN"},
"bullish":	{"JJ"},
"bullishly":	{"RB"},
"bullishness":	{"NN"},
"bullnecked":	{"JJ"},
"bullnose":	{"NN"},
"bullock":	{"NN"},
"bullocks":	{"NNS"},
"bullocky":	{"JJ"},
"bullpen":	{"NN"},
"bullring":	{"NN"},
"bullrings":	{"NNS"},
"bullrush":	{"NN"},
"bulls":	{"NNS","VBZ"},
"bullshit":	{"NN","VB","VBP"},
"bullshits":	{"VBZ"},
"bullshitted":	{"VBD","VBN"},
"bullshitter":	{"NN"},
"bullshitters":	{"NNS"},
"bullshitting":	{"VBG"},
"bullshot":	{"NN"},
"bullterrier":	{"NN"},
"bullwhackers":	{"NNS"},
"bully":	{"NN","JJ","VBP","VB","UH"},
"bully-off":	{"NN"},
"bully-offs":	{"NNS"},
"bullyboy":	{"NN"},
"bullyboys":	{"NNS"},
"bullying":	{"VBG","NN"},
"bullyrag":	{"VB"},
"bulnesia":	{"NN"},
"bulrush":	{"NN"},
"bultmann":	{"NN"},
"bulwark":	{"NN","VB","VBP"},
"bulwarked":	{"VBD","VBN"},
"bulwarking":	{"VBG"},
"bulwarks":	{"NNS","VBZ"},
"bulwer-lytton":	{"NN"},
"bum":	{"NN","VB","VBP","JJ"},
"bumble":	{"VB","VBP"},
"bumble-bee":	{"NN"},
"bumblebee":	{"NN"},
"bumblebees":	{"NNS"},
"bumbled":	{"VBD","VBN"},
"bumbler":	{"NN"},
"bumbles":	{"VBZ"},
"bumbling":	{"JJ","VBG"},
"bumboat":	{"NN"},
"bumelia":	{"NN"},
"bumf":	{"NN"},
"bummed":	{"VBD","VBN"},
"bummer":	{"NN"},
"bummers":	{"NNS"},
"bumming":	{"VBG"},
"bump":	{"VB","VBP","NN","RB"},
"bumped":	{"VBD","VBN"},
"bumper":	{"NN","JJ"},
"bumper-sticker":	{"NN"},
"bumper-to-bumper":	{"JJ"},
"bumpers":	{"NNS"},
"bumph":	{"NN"},
"bumpier":	{"JJR"},
"bumpiest":	{"JJS"},
"bumpiness":	{"NN"},
"bumping":	{"VBG"},
"bumpkin":	{"NN"},
"bumpkinly":	{"JJ"},
"bumpkins":	{"NNS"},
"bumps":	{"NNS","VBZ"},
"bumptious":	{"JJ"},
"bumptiously":	{"RB"},
"bumptiousness":	{"NN"},
"bumpy":	{"JJ"},
"bums":	{"VBZ","NNS"},
"bun":	{"NN"},
"bun-fight":	{"NN"},
"buna":	{"NN"},
"bunce":	{"NN"},
"bunch":	{"NN","VB","VBP"},
"buncha":	{"NN"},
"bunchberry":	{"NN"},
"bunche":	{"NN"},
"bunched":	{"VBN","VBD"},
"bunches":	{"NNS","VBZ"},
"bunchgrass":	{"NN"},
"bunching":	{"VBG"},
"bunchy":	{"JJ"},
"bunco":	{"NN","VB","VBP"},
"buncoed":	{"VBD","VBN"},
"buncoing":	{"VBG"},
"buncombe":	{"NN"},
"buncos":	{"NNS","VBZ"},
"bund":	{"NN","JJ","VBN"},
"bundesbank":	{"NN"},
"bundesbank-meeting":	{"NN"},
"bundle":	{"NN","VB","VBP"},
"bundled":	{"VBN","VBD"},
"bundled-up":	{"JJ"},
"bundles":	{"NNS","VBZ"},
"bundling":	{"VBG"},
"bunds":	{"NNS"},
"bunfight":	{"NN"},
"bung":	{"NN","VB","VBP"},
"bunga":	{"NN"},
"bungaloid":	{"JJ"},
"bungalow":	{"NN"},
"bungalows":	{"NNS"},
"bungarus":	{"NN"},
"bunged":	{"VBD","VBN"},
"bungee":	{"NN"},
"bunghole":	{"NN"},
"bunging":	{"VBG"},
"bungle":	{"VB","VBP","NN"},
"bungled":	{"VBD","VBN","JJ"},
"bungler":	{"NN"},
"bunglers":	{"NNS"},
"bungles":	{"VBZ","NNS"},
"bunglesome":	{"JJ"},
"bungling":	{"VBG","JJ"},
"bungs":	{"NNS","VBZ"},
"bunion":	{"NN"},
"bunji-bunji":	{"NN"},
"bunk":	{"NN","VB","VBP"},
"bunked":	{"VBD","VBN"},
"bunker":	{"NN","VB","VBP"},
"bunkered":	{"VBD","VBN"},
"bunkering":	{"VBG"},
"bunkers":	{"NNS","VBZ"},
"bunking":	{"VBG"},
"bunkmate":	{"NN"},
"bunkmates":	{"NNS"},
"bunko":	{"NN","VB","VBP"},
"bunko-forgery":	{"NN"},
"bunkoed":	{"VBD","VBN"},
"bunkoing":	{"VBG"},
"bunkos":	{"NNS","VBZ"},
"bunks":	{"NNS","VBZ"},
"bunkum":	{"NN"},
"bunnies":	{"NNS"},
"bunny":	{"NN"},
"buns":	{"NNS"},
"bunsen":	{"NN"},
"bunt":	{"NN","VB","VBP"},
"buntal":	{"NN"},
"bunted":	{"VBD","VBN"},
"bunter":	{"NN"},
"bunters":	{"NNS"},
"bunting":	{"NN","VBG"},
"bunts":	{"VBZ","NNS"},
"bunuel":	{"NN"},
"bunyan":	{"NN"},
"bunyaviridae":	{"NN"},
"bunyavirus":	{"NN"},
"buoy":	{"NN","VB","VBP"},
"buoyancy":	{"NN"},
"buoyant":	{"JJ"},
"buoyantly":	{"RB"},
"buoyed":	{"VBD","VBN"},
"buoying":	{"VBG"},
"buoys":	{"NNS","VBZ"},
"buphthalmum":	{"NN"},
"bur":	{"NN","VB","VBP"},
"bura":	{"NN"},
"burbage":	{"NN"},
"burbank":	{"NN"},
"burberry":	{"NN"},
"burble":	{"VB","VBP","NN"},
"burbled":	{"VBD","VBN"},
"burbles":	{"VBZ"},
"burbling":	{"VBG"},
"burbly":	{"JJ"},
"burbot":	{"NN"},
"burden":	{"NN","VB","VBP"},
"burden-sharing":	{"NN"},
"burdened":	{"JJ","VBD","VBN"},
"burdening":	{"VBG"},
"burdenless":	{"JJ"},
"burdens":	{"NNS","VBZ"},
"burdensome":	{"JJ"},
"burdensomeness":	{"NN"},
"burdock":	{"NN"},
"bureacracy":	{"NN"},
"bureacratic":	{"JJ"},
"bureau":	{"NN"},
"bureau-sponsored":	{"JJ"},
"bureaucracies":	{"NNS"},
"bureaucracy":	{"NN"},
"bureaucrat":	{"NN"},
"bureaucratic":	{"JJ"},
"bureaucratically":	{"RB"},
"bureaucraticized":	{"JJ"},
"bureaucratism":	{"NN"},
"bureaucratization":	{"NN"},
"bureaucrats":	{"NNS"},
"bureauracy":	{"NN"},
"bureaus":	{"NN","NNS"},
"buret":	{"NN"},
"burette":	{"NN"},
"burg":	{"NN"},
"burgeon":	{"VB","VBP"},
"burgeoned":	{"VBD","VBN"},
"burgeoning":	{"VBG"},
"burgeons":	{"VBZ"},
"burger":	{"NN"},
"burger-heavy":	{"JJ"},
"burgers":	{"NNS"},
"burgess":	{"NN"},
"burgesses":	{"NNS"},
"burgh":	{"NN"},
"burgher":	{"NN"},
"burglar":	{"NN"},
"burglaries":	{"NNS"},
"burglarious":	{"JJ"},
"burglarize":	{"VB","VBP"},
"burglarized":	{"VBD","VBN"},
"burglarizes":	{"VBZ"},
"burglarizing":	{"VBG"},
"burglarproof":	{"JJ"},
"burglars":	{"NNS"},
"burglary":	{"NN"},
"burgle":	{"VB","VBP"},
"burgled":	{"VBD","VBN"},
"burgles":	{"VBZ"},
"burgling":	{"VBG"},
"burgomaster":	{"NN"},
"burgoo":	{"NN"},
"burgoyne":	{"NN"},
"burgrass":	{"NN"},
"burgrave":	{"NN"},
"burgs":	{"NNS"},
"burgundian":	{"JJ"},
"burgundies":	{"NNS"},
"burgundy":	{"NN","JJ"},
"burhinidae":	{"NN"},
"burhinus":	{"NN"},
"burial":	{"NN"},
"burials":	{"NNS"},
"buried":	{"VBN","VBD","JJ"},
"buries":	{"VBZ"},
"burin":	{"NN"},
"burk":	{"NN"},
"burka":	{"NN"},
"burke":	{"NN","VB"},
"burked":	{"JJ","VBD","VBN"},
"burkes":	{"VBZ"},
"burking":	{"VBG"},
"burl":	{"NN"},
"burlap":	{"NN"},
"burled":	{"JJ","VBD","VBN"},
"burlesque":	{"NN","JJ","VB","VBP"},
"burlesqued":	{"VBD","VBN"},
"burlesques":	{"NNS","VBZ"},
"burlesquing":	{"VBG"},
"burley":	{"NN"},
"burling":	{"VBG"},
"burlington":	{"NN"},
"burls":	{"VBZ"},
"burly":	{"JJ"},
"burma":	{"NN"},
"burmannia":	{"NN"},
"burmanniaceae":	{"NN"},
"burmeisteria":	{"NN"},
"burmese-yi":	{"NN"},
"burn":	{"VB","VBP","NN"},
"burnability":	{"NN"},
"burnable":	{"JJ"},
"burned":	{"VBN","VBD","JJ"},
"burned-out":	{"JJ"},
"burned-over":	{"JJ"},
"burner":	{"NN"},
"burners":	{"NNS"},
"burnett":	{"NN"},
"burnham":	{"NN"},
"burning":	{"VBG","NN","JJ","RB"},
"burningly":	{"RB"},
"burnings":	{"NNS"},
"burnish":	{"VB","VBP"},
"burnished":	{"VBD","VBN","JJ"},
"burnishes":	{"VBZ"},
"burnishing":	{"VBG"},
"burnley":	{"NN"},
"burnoose":	{"NN"},
"burnous":	{"NN"},
"burnouse":	{"NN"},
"burnout":	{"NN"},
"burnouts":	{"NNS"},
"burns":	{"NNS","VBZ"},
"burnside":	{"NN"},
"burnt":	{"JJ","VBN","VBD"},
"burnt-orange":	{"JJ"},
"burnt-out":	{"JJ"},
"burnt-red":	{"JJ"},
"burnup":	{"NN"},
"burp":	{"VB","VBP","NN"},
"burped":	{"VBD","VBN"},
"burping":	{"VBG"},
"burps":	{"VBZ","NNS"},
"burqa":	{"NN"},
"burr":	{"NN","VB","VBP"},
"burr-headed":	{"JJ"},
"burrawong":	{"NN"},
"burred":	{"VBD","VBN"},
"burrfish":	{"NN"},
"burring":	{"VBG"},
"burrito":	{"NN"},
"burrlike":	{"JJ"},
"burro":	{"NN"},
"burroughs":	{"NNS"},
"burrow":	{"NN","VB","VBP"},
"burrowed":	{"VBD","VBN"},
"burrowing":	{"VBG"},
"burrows":	{"VBZ","NNS"},
"burrs":	{"NNS","VBZ"},
"burry":	{"JJ"},
"burs":	{"NNS","VBZ"},
"bursa":	{"NN"},
"bursal":	{"JJ"},
"bursar":	{"NN"},
"bursary":	{"NN"},
"bursera":	{"NN"},
"burseraceae":	{"NN"},
"bursiform":	{"JJ"},
"bursitis":	{"NN"},
"burst":	{"NN","VBD","VB","VBN","VBP"},
"burster":	{"NN"},
"bursting":	{"VBG"},
"bursts":	{"NNS","VBZ"},
"burt":	{"NN"},
"burthen":	{"NN","VB","VBP"},
"burton":	{"NN"},
"burundi":	{"JJ","NN"},
"burundian":	{"JJ","NN"},
"burunduki":	{"NN"},
"bury":	{"VB","VBP"},
"burying":	{"VBG"},
"bus":	{"NN","VB","VBP"},
"bus-shelter":	{"NN"},
"bus-shelters":	{"NNS"},
"bus-stop":	{"NN"},
"bus-stops":	{"NNS"},
"busbar":	{"NN"},
"busboy":	{"NN"},
"busby":	{"NN"},
"bused":	{"VBD","VBN"},
"buses":	{"NNS","VBZ"},
"bush":	{"NN"},
"bush-league":	{"JJ"},
"bush-supported":	{"JJ"},
"bushbaby":	{"NN"},
"bushbuck":	{"NN","NNS"},
"bushbucks":	{"NNS"},
"bushed":	{"JJ","VBD","VBN"},
"bushel":	{"NN"},
"busheled":	{"VBD","VBN"},
"busheling":	{"VBG"},
"bushelled":	{"VBD","VBN"},
"bushelling":	{"VBG"},
"bushels":	{"NNS","VBZ"},
"bushes":	{"NNS","VBZ"},
"bushido":	{"NN"},
"bushier":	{"JJR"},
"bushiest":	{"JJS"},
"bushiness":	{"NN"},
"bushing":	{"NN","VBG"},
"bushman":	{"NN"},
"bushnell":	{"NN"},
"bushtit":	{"NN"},
"bushwhack":	{"VB","VBP"},
"bushwhacked":	{"VBD","VBN"},
"bushwhacker":	{"NN"},
"bushwhacking":	{"VBG"},
"bushwhacks":	{"VBZ"},
"bushy":	{"JJ"},
"bushy-tailed":	{"JJ"},
"busied":	{"JJ","VBD","VBN"},
"busier":	{"JJR"},
"busies":	{"VBZ"},
"busiest":	{"JJS"},
"busily":	{"RB"},
"business":	{"NN"},
"business-as-usual":	{"JJ"},
"business-automation":	{"NN"},
"business-class":	{"JJ","NN","RB"},
"business-communications":	{"NNS"},
"business-credit":	{"NN"},
"business-development":	{"NN"},
"business-interruption":	{"JJ"},
"business-judgment":	{"NN"},
"business-like":	{"JJ"},
"business-machines":	{"NNS"},
"business-migration":	{"NN"},
"business-minded":	{"JJ"},
"business-oriented":	{"JJ"},
"business-partners":	{"NNS"},
"business-promotion":	{"NN"},
"business-related":	{"JJ"},
"business-services":	{"JJ"},
"business-telephone":	{"JJ"},
"business-to-business":	{"JJ","NN"},
"business-venture":	{"JJ"},
"businesses":	{"NNS"},
"businesslike":	{"JJ"},
"businessman":	{"NN"},
"businessmen":	{"NNS"},
"businessmen-authors":	{"NNS"},
"businesspeople":	{"NN"},
"businessperson":	{"NN"},
"businesswoman":	{"NN"},
"businesswomen":	{"NNS"},
"busing":	{"VBG","NN"},
"busk":	{"VB","VBP"},
"busked":	{"VBD","VBN"},
"busker":	{"NN"},
"buskers":	{"NNS"},
"buskin":	{"NN"},
"busking":	{"VBG","NN"},
"busks":	{"VBZ"},
"busload":	{"NN"},
"busloads":	{"NNS"},
"busman":	{"NN"},
"buspar":	{"NN"},
"buspirone":	{"NN"},
"buss":	{"NN","VBP","VB"},
"bussed":	{"VBN","VBD"},
"busses":	{"NNS","VBZ"},
"bussing":	{"VBG"},
"bust":	{"NN","JJ","VB","VBP","VBD","VBN"},
"bust-up":	{"NN"},
"bust-ups":	{"NNS"},
"bustard":	{"NN"},
"busted":	{"JJ","VBD","VBN"},
"buster":	{"NN"},
"busters":	{"NNS"},
"bustier":	{"NN"},
"bustiers":	{"NNS"},
"busting":	{"VBG"},
"bustle":	{"VB","VBP","NN"},
"bustled":	{"VBD","VBN"},
"bustles":	{"VBZ"},
"bustling":	{"JJ","VBG"},
"busts":	{"NNS","VBZ"},
"busty":	{"JJ"},
"busy":	{"JJ","VB","VBP"},
"busy-work":	{"NN"},
"busybodied":	{"JJ"},
"busybodies":	{"NNS"},
"busybody":	{"NN"},
"busying":	{"VBG"},
"busyness":	{"NN"},
"busywork":	{"NN"},
"but":	{"RB","CC","IN"},
"but-bulls":	{"IN"},
"butacaine":	{"NN"},
"butadiene":	{"NN"},
"butadiene-emulsions":	{"NNS"},
"butane":	{"NN"},
"butanol":	{"NN"},
"butanone":	{"NN"},
"butat":	{"NN"},
"butazolidin":	{"NN"},
"butch":	{"JJ","NN"},
"butcher":	{"VB","VBP","NN"},
"butcherbird":	{"NN"},
"butchered":	{"VBD","VBN"},
"butchering":	{"VBG"},
"butcherly":	{"JJ"},
"butchers":	{"VBZ","NNS"},
"butchery":	{"NN"},
"butchness":	{"NN"},
"butea":	{"NN"},
"butene":	{"NN"},
"buteo":	{"NN"},
"buteonine":	{"JJ","NN"},
"butler":	{"NN"},
"butlers":	{"NNS"},
"buts":	{"NNS"},
"butt":	{"NN","VB","VBP"},
"butt-weld":	{"VB","VBP"},
"butt-welding":	{"NN"},
"butte":	{"NN"},
"butted":	{"VBN","VBD"},
"butter":	{"NN","VBP","VB"},
"butter-and-eggs":	{"NNS"},
"butter-flower":	{"NN"},
"butter-print":	{"NN"},
"butterball":	{"NN"},
"butterbean":	{"NN"},
"butterbeer":	{"NN"},
"butterbur":	{"NN"},
"buttercrunch":	{"NN"},
"buttercup":	{"NN"},
"buttered":	{"VBD","VBN"},
"butterfat":	{"NN"},
"butterfat-rich":	{"JJ"},
"butterfield":	{"NN"},
"butterfingered":	{"JJ"},
"butterfingers":	{"NN"},
"butterfish":	{"NN"},
"butterflied":	{"VBD","VBN"},
"butterflies":	{"VBZ","NNS"},
"butterflower":	{"NN"},
"butterfly":	{"NN","VB","VBP"},
"butterfly-shaped":	{"JJ"},
"butterflyfish":	{"NN"},
"butterflying":	{"VBG"},
"buttering":	{"VBG"},
"buttermilk":	{"NN"},
"butternut":	{"NN"},
"butters":	{"VBZ"},
"butterscotch":	{"NN"},
"butterweed":	{"NN"},
"butterwort":	{"NN"},
"butterworth":	{"NN"},
"buttery":	{"JJ"},
"butting":	{"VBG"},
"buttinsky":	{"NN"},
"buttock":	{"NN"},
"buttocks":	{"NNS"},
"button":	{"NN","VB","VBP"},
"button-down":	{"JJ"},
"button-quail":	{"NN"},
"button-shaped":	{"JJ"},
"buttoned":	{"JJ","VBD","VBN"},
"buttoned-down":	{"JJ"},
"buttoned-up":	{"JJ"},
"buttonhole":	{"NN","VB","VBP"},
"buttonholed":	{"VBD","VBN"},
"buttonholes":	{"NNS","VBZ"},
"buttonholing":	{"VBG"},
"buttonhook":	{"NN"},
"buttoning":	{"VBG"},
"buttonlike":	{"JJ"},
"buttons":	{"NNS","VBZ"},
"buttonwood":	{"NN"},
"buttony":	{"JJ"},
"buttress":	{"NN","VB","VBP"},
"buttressed":	{"VBD","VBN"},
"buttresses":	{"NNS","VBZ"},
"buttressing":	{"VBG"},
"butts":	{"NNS","VBZ"},
"buttweld":	{"VB"},
"butty":	{"NN"},
"butut":	{"NN"},
"butyl":	{"JJ","NN"},
"butyl-lithium":	{"NN"},
"butylate":	{"VB"},
"butylene":	{"NN"},
"butyraceous":	{"JJ"},
"butyrate":	{"NN"},
"butyric":	{"JJ"},
"butyrin":	{"NN"},
"buxaceae":	{"NN"},
"buxom":	{"JJ","NN"},
"buxomly":	{"RB"},
"buxomness":	{"NN"},
"buxus":	{"NNS"},
"buy":	{"VB","NN","VBP"},
"buy-and-hold":	{"JJ","CD"},
"buy-back":	{"NN"},
"buy-backs":	{"NNS"},
"buy-now":	{"JJ"},
"buy-out":	{"NN"},
"buy-out-related":	{"JJ"},
"buy-outs":	{"NNS"},
"buy-sell":	{"JJ"},
"buy-stop":	{"JJ"},
"buyback":	{"NN"},
"buybacks":	{"NNS","VBZ"},
"buyer":	{"NN"},
"buyers":	{"NNS"},
"buyi":	{"NN"},
"buyin":	{"NN"},
"buying":	{"VBG","NN"},
"buyings":	{"NNS"},
"buyout":	{"NN"},
"buyouts":	{"NNS"},
"buys":	{"VBZ","NNS"},
"buzz":	{"NN","VB","VBP","JJ"},
"buzz-buzz-buzz":	{"NN"},
"buzzard":	{"NN"},
"buzzards":	{"NNS"},
"buzzed":	{"VBD","VBN"},
"buzzer":	{"NN"},
"buzzers":	{"NNS"},
"buzzes":	{"NNS","VBZ"},
"buzzing":	{"NN","VBG"},
"buzzsaw":	{"NN"},
"buzzsaws":	{"NNS"},
"buzzword":	{"NN"},
"buzzwords":	{"NNS"},
"bvd":	{"NN"},
"bvd's":	{"NN"},
"bvi-based":	{"JJ"},
"bvislander":	{"NN"},
"bvislanders":	{"NNS"},
"bw":	{"NN"},
"bwr":	{"NN"},
"by":	{"IN","RB","RP"},
"by-and-by":	{"NN"},
"by-bid":	{"VB"},
"by-blow":	{"NN"},
"by-catch":	{"NN"},
"by-election":	{"NN"},
"by-gone":	{"JJ"},
"by-laws":	{"NNS"},
"by-line":	{"NN"},
"by-pass":	{"NN"},
"by-passed":	{"VBN"},
"by-passes":	{"VBZ"},
"by-passing":	{"VBG"},
"by-product":	{"NN"},
"by-products":	{"NNS"},
"by-roads":	{"NNS"},
"by-the-book":	{"JJ"},
"by-ways":	{"NNS"},
"by-wheelchair":	{"JJ"},
"by-word":	{"JJ"},
"byblos":	{"NNS"},
"bycatch":	{"NN"},
"bydgoszcz":	{"NN"},
"bye":	{"NN","JJ","UH"},
"bye-bye":	{"UH"},
"bye-election":	{"NN"},
"byelarus":	{"NN"},
"byelorussia":	{"NN"},
"byelorussian":	{"NN"},
"bygone":	{"JJ","NN"},
"byinge":	{"VBG"},
"bylaw":	{"NN"},
"bylaws":	{"NNS"},
"byline":	{"NN"},
"bylines":	{"NNS"},
"byname":	{"NN"},
"bypass":	{"NN","VB","VBP"},
"bypassed":	{"VBD","VBN"},
"bypasses":	{"NNS","VBZ"},
"bypassing":	{"VBG"},
"bypast":	{"JJ"},
"bypath":	{"NN"},
"byplay":	{"NN"},
"byproduct":	{"NN"},
"byproducts":	{"NNS"},
"byrd":	{"NN"},
"byre":	{"NN"},
"byrnie":	{"NN"},
"byroad":	{"NN"},
"byron":	{"NN"},
"byronic":	{"JJ"},
"byronism":	{"NN"},
"byssus":	{"NNS"},
"bystander":	{"NN"},
"bystanders":	{"NNS"},
"byte":	{"NN"},
"bytes":	{"NNS"},
"byting":	{"VBG"},
"byway":	{"NN"},
"byways":	{"NNS"},
"byword":	{"NN"},
"byzant":	{"NN"},
"byzantinism":	{"NN"},
"byzantium":	{"NN"},
"c":	{"NN","SYM","LS"},
"c'mon":	{"UH"},
"c-clamp":	{"NN"},
"c-horizon":	{"NN"},
"c-minus":	{"JJ"},
"c-note":	{"NN"},
"c-plane":	{"NN"},
"c-ration":	{"NN"},
"c-reflects":	{"VBZ"},
"c-section":	{"NN"},
"c-word":	{"NN"},
"c.e.":	{"RB"},
"c.i.f":	{"JJ"},
"c.o.d.":	{"RB"},
"c.p.u.":	{"NN"},
"c2h6":	{"NN"},
"ca":	{"MD"},
"ca-ca":	{"NN"},
"ca.":	{"IN","NN"},
"caaba":	{"NN"},
"cab":	{"NN"},
"cabal":	{"NN"},
"cabala":	{"NN"},
"cabalism":	{"NN"},
"cabalist":	{"NN"},
"cabalistic":	{"JJ"},
"cabana":	{"NN"},
"cabanas":	{"NNS"},
"cabaret":	{"NN"},
"cabaret-like":	{"JJ"},
"cabasset":	{"NN"},
"cabassous":	{"NN"},
"cabbage":	{"NN"},
"cabbageworm":	{"NN"},
"cabbala":	{"NN"},
"cabbalah":	{"NN"},
"cabbed":	{"VBD","VBN"},
"cabbing":	{"VBG"},
"cabby":	{"NN"},
"cabdriver":	{"NN"},
"cabell":	{"NN"},
"caber":	{"NN"},
"cabernet":	{"NN"},
"cabg":	{"NN"},
"cabin":	{"NN","VB","VBP"},
"cabin-crew":	{"NN"},
"cabined":	{"VBD","VBN"},
"cabinet":	{"NN"},
"cabinet-level":	{"JJ","NN"},
"cabinetmaker":	{"NN"},
"cabinetmakers":	{"NNS"},
"cabinetmaking":	{"NN"},
"cabinetry":	{"NN"},
"cabinets":	{"NNS"},
"cabinetwork":	{"NN"},
"cabining":	{"VBG"},
"cabins":	{"NNS","VBZ"},
"cable":	{"NN","VB","VBP"},
"cable-TV-system":	{"NN"},
"cable-programming":	{"JJ"},
"cable-system":	{"NN"},
"cable-television":	{"NN"},
"cable-television-equipped":	{"JJ"},
"cable-televison":	{"NN"},
"cable-tv-system":	{"NN"},
"cabled":	{"VBD","VBN"},
"cablegram":	{"NN"},
"cables":	{"NNS","VBZ"},
"cabling":	{"VBG","NN"},
"cabman":	{"NN"},
"cabochon":	{"NN"},
"cabomba":	{"NN"},
"cabombaceae":	{"NN"},
"caboodle":	{"NN"},
"caboose":	{"NN"},
"cabot":	{"NN"},
"cabotage":	{"NN"},
"cabriolet":	{"NN"},
"cabs":	{"VBZ","NNS"},
"cabstand":	{"NN"},
"caca":	{"NN"},
"cacajao":	{"NN"},
"cacalia":	{"NN"},
"cacao":	{"NN"},
"cacatua":	{"NN"},
"cachalot":	{"NN"},
"cache":	{"NN","VB","VBP"},
"cachectic":	{"JJ"},
"cached":	{"VBD","VBN"},
"caches":	{"VBZ","NNS"},
"cachet":	{"NN"},
"cachexia":	{"NN"},
"cachexy":	{"NN"},
"cachi":	{"NN"},
"caching":	{"VBG"},
"cachinnate":	{"VB","VBP"},
"cachinnated":	{"VBD","VBN"},
"cachinnates":	{"VBZ"},
"cachinnating":	{"VBG"},
"cachinnation":	{"NN"},
"cachou":	{"NN"},
"cacicus":	{"NN"},
"cacique":	{"NN"},
"cackel":	{"VB"},
"cackle":	{"NN","VB","VBP"},
"cackled":	{"VBD","VBN"},
"cackler":	{"NN"},
"cackles":	{"VBZ"},
"cackling":	{"VBG"},
"cackly":	{"JJ"},
"cacodaemon":	{"NN"},
"cacodaemonic":	{"JJ"},
"cacodemon":	{"NN"},
"cacodemonic":	{"JJ"},
"cacodyl":	{"NN"},
"cacodylic":	{"JJ"},
"cacoethes":	{"NNS"},
"cacogenesis":	{"NN"},
"cacogenic":	{"JJ"},
"cacogenics":	{"NN"},
"cacography":	{"NN"},
"cacomistle":	{"NN"},
"cacomixle":	{"NN"},
"cacophonic":	{"JJ"},
"cacophonous":	{"JJ"},
"cacophony":	{"NN"},
"cactaceae":	{"NN"},
"cacti":	{"NNS"},
"cactus":	{"NN"},
"cactuses":	{"NNS"},
"cacuminal":	{"JJ"},
"cad":	{"NN"},
"cadaster":	{"NN"},
"cadastral":	{"JJ"},
"cadastre":	{"NN"},
"cadaver":	{"NN"},
"cadaveric":	{"JJ"},
"cadaverine":	{"NN"},
"cadaverous":	{"JJ"},
"caddice-fly":	{"NN"},
"caddie":	{"NN","VB","VBP"},
"caddied":	{"VBD","VBN"},
"caddies":	{"NNS","VBZ"},
"caddis-fly":	{"NN"},
"caddish":	{"JJ"},
"caddisworm":	{"NN"},
"caddo":	{"NN"},
"caddoan":	{"NN"},
"caddy":	{"NN","VB","VBP"},
"caddying":	{"VBG"},
"cadence":	{"NN"},
"cadenced":	{"JJ"},
"cadency":	{"NN"},
"cadent":	{"JJ"},
"cadenza":	{"NN"},
"cadet":	{"NN"},
"cadets":	{"NNS"},
"cadetship":	{"NN"},
"cadge":	{"VB","VBP"},
"cadged":	{"VBD","VBN"},
"cadger":	{"NN"},
"cadges":	{"VBZ"},
"cadging":	{"VBG"},
"cadillac":	{"NN"},
"cadiz":	{"NN"},
"cadmium":	{"NN"},
"cadmus":	{"NN"},
"cadra":	{"NN"},
"cadre":	{"NN"},
"cadres":	{"NNS"},
"caducean":	{"JJ"},
"caduceus":	{"NN"},
"caducous":	{"JJ"},
"caecal":	{"JJ"},
"caeciliadae":	{"NN"},
"caecilian":	{"JJ","NN"},
"caeciliidae":	{"NN"},
"caecum":	{"NN"},
"caelum":	{"NN"},
"caenogenesis":	{"NN"},
"caenolestes":	{"NNS"},
"caenolestidae":	{"NN"},
"caesalpinia":	{"NN"},
"caesalpiniaceae":	{"NN"},
"caesalpinioideae":	{"NN"},
"caesar":	{"NN"},
"caesarea":	{"NN"},
"caesarian":	{"JJ","NN"},
"caesarism":	{"NN"},
"caesaropapism":	{"NN"},
"caesium":	{"NN"},
"caespitose":	{"JJ"},
"caesura":	{"NN"},
"caesural":	{"JJ"},
"cafe":	{"NN"},
"cafes":	{"NNS"},
"cafeteria":	{"NN"},
"cafeteria-style":	{"JJ"},
"cafeterias":	{"NNS"},
"caff":	{"NN"},
"caffeic":	{"JJ"},
"caffein":	{"NN"},
"caffeine":	{"NN"},
"caffeine-free":	{"JJ"},
"caffeinic":	{"JJ"},
"caffeinism":	{"NN"},
"caffer":	{"NN"},
"caffre":	{"NN"},
"caftan":	{"NN"},
"cage":	{"NN","VBP","VB"},
"caged":	{"JJ","VBD","VBN"},
"cager":	{"NN"},
"cages":	{"VBZ","NNS"},
"cagey":	{"JJ","NN"},
"cagily":	{"RB"},
"caging":	{"VBG"},
"cagliostro":	{"NN"},
"cagney":	{"NN"},
"cagoule":	{"NN"},
"cagy":	{"JJ"},
"cahita":	{"NN"},
"cahoot":	{"NN"},
"cahoots":	{"NNS"},
"caiman":	{"NN"},
"caimitillo":	{"NN"},
"caimito":	{"NN"},
"cainogenesis":	{"NN"},
"cairene":	{"NN"},
"cairina":	{"NN"},
"cairn":	{"NN"},
"cairned":	{"JJ"},
"cairngorm":	{"NN"},
"cairns":	{"NNS"},
"cairo":	{"NN"},
"cairo-sponsored":	{"JJ"},
"caisson":	{"NN"},
"caitiff":	{"JJ","NN"},
"caitra":	{"NN"},
"cajanus":	{"NN"},
"cajole":	{"VB","VBP"},
"cajoled":	{"VBD","VBN"},
"cajolery":	{"NN"},
"cajoles":	{"VBZ"},
"cajoling":	{"VBG"},
"cajolingly":	{"RB"},
"cakchiquel":	{"NN"},
"cake":	{"NN","VBP","VB"},
"caked":	{"VBD","VBN"},
"cakehole":	{"NN"},
"cakes":	{"NNS","VBZ"},
"cakewalk":	{"VB","NN"},
"cakile":	{"NN"},
"caking":	{"VBG"},
"calaba":	{"NN"},
"calabash":	{"NN"},
"calabazilla":	{"NN"},
"calabrese":	{"NN"},
"calabria":	{"NN"},
"calabura":	{"NN"},
"caladenia":	{"NN"},
"caladium":	{"NN"},
"calais":	{"NN"},
"calamagrostis":	{"NNS"},
"calamari":	{"NN"},
"calamary":	{"NN"},
"calamine":	{"NN"},
"calamint":	{"NN"},
"calamintha":	{"NN"},
"calamities":	{"NNS"},
"calamitous":	{"JJ"},
"calamity":	{"NN"},
"calamus":	{"NN"},
"calan":	{"NN"},
"calando":	{"JJ"},
"calandrinia":	{"NN"},
"calanthe":	{"NN"},
"calapooya":	{"NN"},
"calapuya":	{"NN"},
"calash":	{"NN"},
"calaveras":	{"NNS"},
"calc-tufa":	{"NN"},
"calcaneal":	{"JJ"},
"calcaneus":	{"NN"},
"calcareous":	{"JJ"},
"calced":	{"JJ"},
"calcedony":	{"NN"},
"calceiform":	{"JJ"},
"calceolaria":	{"NN"},
"calceolate":	{"JJ"},
"calceus":	{"NNS"},
"calcic":	{"JJ"},
"calcicolous":	{"JJ"},
"calciferol":	{"NN"},
"calciferous":	{"JJ"},
"calcific":	{"JJ"},
"calcification":	{"NN"},
"calcified":	{"VBD","VBN"},
"calcifies":	{"VBZ"},
"calcifugous":	{"JJ"},
"calcify":	{"VB","VBP"},
"calcifying":	{"VBG"},
"calcimine":	{"NN","VB","VBP"},
"calcimined":	{"VBD","VBN"},
"calcimines":	{"VBZ"},
"calcimining":	{"VBG"},
"calcination":	{"NN"},
"calcine":	{"VB","VBP"},
"calcined":	{"VBD","VBN"},
"calcines":	{"VBZ"},
"calcining":	{"VBG"},
"calcite":	{"NN"},
"calcitic":	{"JJ"},
"calcitonin":	{"NN"},
"calcium":	{"NN"},
"calcium-cyanamide":	{"NN"},
"calcium-supplemented":	{"JJ"},
"calculable":	{"JJ"},
"calculate":	{"VB","VBP"},
"calculated":	{"VBN","VBD","JJ"},
"calculates":	{"VBZ"},
"calculating":	{"JJ","VBG"},
"calculatingly":	{"RB"},
"calculation":	{"NN"},
"calculations":	{"NNS"},
"calculative":	{"JJ"},
"calculator":	{"NN"},
"calculator-toting":	{"JJ"},
"calculators":	{"NNS"},
"calculi":	{"NNS"},
"calculous":	{"JJ"},
"calculus":	{"NN"},
"calculuses":	{"NNS"},
"calcutta":	{"NN"},
"calcuttan":	{"JJ"},
"calder":	{"NN"},
"caldera":	{"NN"},
"calderon":	{"NN"},
"caldron":	{"NN"},
"caldwell":	{"NN"},
"calean":	{"NN"},
"caleche":	{"NN"},
"caledonia":	{"NN"},
"calefacient":	{"JJ"},
"calefaction":	{"NN"},
"calefactive":	{"JJ"},
"calefactory":	{"JJ"},
"calendar":	{"NN","VB","VBP"},
"calendared":	{"VBD","VBN"},
"calendaring":	{"VBG"},
"calendars":	{"NNS","VBZ"},
"calender":	{"NN","VB","VBP"},
"calendered":	{"VBD","VBN"},
"calendering":	{"VBG"},
"calenders":	{"VBZ","NNS"},
"calendric":	{"JJ"},
"calendrical":	{"JJ"},
"calendula":	{"NN"},
"calf":	{"NN"},
"calfskin":	{"NN"},
"calgary":	{"NN"},
"calgary-based":	{"JJ"},
"cali":	{"NN"},
"caliber":	{"NN"},
"calibers":	{"NNS"},
"calibrate":	{"VB","VBP"},
"calibrated":	{"VBD","VBN"},
"calibrates":	{"VBZ"},
"calibrating":	{"VBG"},
"calibration":	{"NN"},
"calibrations":	{"NNS"},
"calibre":	{"NN"},
"caliche":	{"NN"},
"caliche-topped":	{"JJ"},
"calico":	{"NN"},
"calicular":	{"JJ"},
"caliculus":	{"NN"},
"calidris":	{"NN"},
"calif":	{"NN"},
"californication":	{"NN"},
"californium":	{"NN"},
"caliginous":	{"JJ"},
"caligula":	{"NN"},
"calinda":	{"NN"},
"caliper":	{"NN"},
"calipers":	{"NNS"},
"caliph":	{"NN"},
"caliphate":	{"NN"},
"caliphs":	{"NNS"},
"calisaya":	{"NN"},
"calisthenic":	{"JJ"},
"calisthenics":	{"NN"},
"calk":	{"VB","VBP"},
"calked":	{"VBD","VBN"},
"calking":	{"VBG"},
"calks":	{"VBZ"},
"call":	{"VB","NN","VBP"},
"call-back":	{"JJ","NN"},
"call-backs":	{"NNS"},
"call-board":	{"NN"},
"call-in":	{"NN"},
"call-out":	{"NN"},
"call-ups":	{"NNS"},
"calla":	{"NN"},
"callable":	{"JJ"},
"callan":	{"NN"},
"callas":	{"NNS"},
"callathump":	{"NN"},
"callback":	{"NN"},
"called":	{"VBD","VBN"},
"caller":	{"NN"},
"caller-out":	{"NN"},
"caller-up":	{"NN"},
"callers":	{"NNS"},
"calliandra":	{"NN"},
"callicebus":	{"NN"},
"calligraph":	{"VB"},
"calligrapher":	{"NN"},
"calligraphers":	{"NNS"},
"calligraphic":	{"JJ"},
"calligraphical":	{"JJ"},
"calligraphist":	{"NN"},
"calligraphy":	{"NN"},
"callimorpha":	{"NN"},
"callin":	{"NN"},
"callinectes":	{"NNS"},
"calling":	{"VBG","NN"},
"callionymidae":	{"NN"},
"calliope":	{"NN"},
"calliophis":	{"NN"},
"calliopsis":	{"NN"},
"calliper":	{"NN"},
"callipers":	{"NNS"},
"calliphora":	{"NN"},
"calliphoridae":	{"NN"},
"callipygian":	{"JJ"},
"callipygous":	{"JJ"},
"callirhoe":	{"NN"},
"callisaurus":	{"NN"},
"callistephus":	{"NNS"},
"callisthenics":	{"NN"},
"callisto":	{"NN"},
"callithricidae":	{"NN"},
"callithrix":	{"NN"},
"callithump":	{"NN"},
"callithumpian":	{"JJ"},
"callitrichaceae":	{"NN"},
"callitriche":	{"NN"},
"callitris":	{"NNS"},
"callophis":	{"NN"},
"callorhinus":	{"NN"},
"callosectomy":	{"NN"},
"callosity":	{"NN"},
"callosotomy":	{"NN"},
"callous":	{"JJ","VB","VBP"},
"calloused":	{"JJ","VBD","VBN"},
"callouses":	{"VBZ"},
"callousing":	{"VBG"},
"callously":	{"RB"},
"callousness":	{"NN"},
"callow":	{"NN","JJ"},
"callowness":	{"NN"},
"calls":	{"VBZ","NNS"},
"calluna":	{"NN"},
"callus":	{"NN","VB","VBP"},
"callused":	{"VBD","VBN"},
"calluses":	{"NNS","VBZ"},
"callusing":	{"VBG"},
"calm":	{"JJ","VB","NN","VBP"},
"calmed":	{"VBD","VBN"},
"calmer":	{"JJR"},
"calmest":	{"JJS"},
"calming":	{"NN","VBG","JJ"},
"calmly":	{"RB"},
"calmness":	{"NN"},
"calms":	{"VBZ"},
"calocarpum":	{"NN"},
"calocedrus":	{"NN"},
"calochortus":	{"NNS"},
"calomel":	{"NN"},
"caloocan":	{"NN"},
"caloosahatchee":	{"NN"},
"calophyllum":	{"NN"},
"calopogon":	{"NN"},
"caloric":	{"JJ","NN"},
"calorie":	{"NN"},
"calorie-free":	{"JJ"},
"calorie-heavy":	{"JJ"},
"calories":	{"NNS"},
"calorifacient":	{"JJ"},
"calorific":	{"JJ"},
"calorimeter":	{"NN"},
"calorimetric":	{"JJ"},
"calorimetry":	{"NN"},
"calosoma":	{"NN"},
"calostomataceae":	{"NN"},
"calpac":	{"NN"},
"calpack":	{"NN"},
"calpe":	{"NN"},
"calque":	{"NN"},
"caltha":	{"NN"},
"caltrop":	{"NN"},
"calumet":	{"NN"},
"calumniate":	{"VB","VBP"},
"calumniated":	{"VBD","VBN"},
"calumniates":	{"VBZ"},
"calumniating":	{"VBG"},
"calumniation":	{"NN"},
"calumniatory":	{"JJ"},
"calumnious":	{"JJ"},
"calumniously":	{"RB"},
"calumny":	{"NN"},
"calvados":	{"NNS"},
"calvaria":	{"NN"},
"calvatia":	{"NN"},
"calve":	{"VB","VBP"},
"calved":	{"VBD","VBN"},
"calves":	{"NNS","VBZ"},
"calving":	{"VBG"},
"calvinistic":	{"JJ"},
"calvinistical":	{"JJ"},
"calvino":	{"NN"},
"calx":	{"NN"},
"calycanthaceae":	{"NN"},
"calycanthus":	{"NNS"},
"calyceal":	{"JJ"},
"calycinal":	{"JJ"},
"calycine":	{"JJ"},
"calycle":	{"NN"},
"calycled":	{"JJ"},
"calycophyllum":	{"NN"},
"calycular":	{"JJ"},
"calyculate":	{"JJ"},
"calyculus":	{"NN"},
"calymmatobacterium":	{"NN"},
"calypso":	{"NN"},
"calypter":	{"NN"},
"calyptra":	{"NN"},
"calyptrate":	{"JJ"},
"calystegia":	{"NN"},
"calyx":	{"NN"},
"cam":	{"NN"},
"camachile":	{"NN"},
"camail":	{"NN"},
"camaraderie":	{"NN"},
"camarilla":	{"NN"},
"camaros":	{"NNS"},
"camas":	{"NNS"},
"camash":	{"NN"},
"camass":	{"NN"},
"camassia":	{"NN"},
"cambarus":	{"NN"},
"camber":	{"NN","VB","VBP"},
"cambered":	{"VBD","VBN"},
"cambering":	{"VBG"},
"cambers":	{"NNS","VBZ"},
"cambial":	{"JJ"},
"cambium":	{"NN"},
"cambodia":	{"NN"},
"cambria":	{"NN"},
"cambric":	{"NN"},
"cambridge":	{"NN"},
"camcorder":	{"NN"},
"camcorders":	{"NNS"},
"camden":	{"NN"},
"came":	{"VBD"},
"camel":	{"NN"},
"camelhair":	{"NN"},
"camelia":	{"NN"},
"camelidae":	{"NN"},
"camelina":	{"NN"},
"camellia":	{"NN"},
"camellias":	{"NNS"},
"camelopard":	{"NN"},
"camelot":	{"NN"},
"camelpox":	{"NN"},
"camels":	{"NNS","VBZ"},
"camelus":	{"NNS"},
"camembert":	{"NN"},
"cameo":	{"NN"},
"cameo-like":	{"JJ"},
"cameos":	{"NNS"},
"camera":	{"NN"},
"cameraman":	{"NN"},
"cameramen":	{"NN"},
"cameras":	{"NNS"},
"cameroon":	{"NN"},
"cameroonian":	{"JJ","NN"},
"cameroun":	{"NN"},
"camilla":	{"NN"},
"camille":	{"NN"},
"camion":	{"NN"},
"camise":	{"NN"},
"camisole":	{"NN"},
"camlan":	{"NN"},
"camlet":	{"NN"},
"camo":	{"JJ","NN"},
"camomile":	{"NN"},
"camorra":	{"NN"},
"camosh":	{"NN"},
"camouflage":	{"NN","VB","VBP"},
"camouflaged":	{"VBD","VBN"},
"camouflages":	{"NNS","VBZ"},
"camouflaging":	{"VBG"},
"camp":	{"NN","VB","VBP","JJ"},
"camp-made":	{"JJ"},
"campagna":	{"NN"},
"campaign":	{"NN","VB","VBP"},
"campaign-decided":	{"NN"},
"campaign-finance":	{"JJ"},
"campaigned":	{"VBD","VBN"},
"campaigner":	{"NN"},
"campaigners":	{"NNS"},
"campaigning":	{"VBG","NN"},
"campaigns":	{"NNS","VBZ"},
"campana":	{"NN"},
"campania":	{"NN"},
"campanile":	{"NN"},
"campanula":	{"NN"},
"campanulaceae":	{"NN"},
"campanulales":	{"NNS"},
"campanular":	{"JJ"},
"campanulate":	{"JJ"},
"campanulated":	{"JJ"},
"campbell":	{"NN"},
"campbell-brand":	{"JJ"},
"campeachy":	{"NN"},
"campeau-owned":	{"JJ"},
"campeau-related":	{"JJ"},
"campeau-unit":	{"JJ"},
"campeche":	{"NN"},
"camped":	{"VBD","VBN","JJ"},
"campephilus":	{"NNS"},
"camper":	{"NN"},
"campers":	{"NNS"},
"campervan":	{"NN"},
"campestral":	{"JJ"},
"campfire":	{"NN"},
"campground":	{"NN"},
"campgrounds":	{"NNS"},
"camphor":	{"NN"},
"camphoraceous":	{"JJ"},
"camphorate":	{"VB"},
"camphorated":	{"JJ"},
"camphoric":	{"JJ"},
"camphorweed":	{"NN"},
"camping":	{"NN","VBG"},
"camping-out":	{"JJ"},
"campion":	{"NN"},
"campmate":	{"NN"},
"campong":	{"NN"},
"camponotus":	{"NN"},
"camps":	{"NNS","VBZ"},
"campsite":	{"NN"},
"campsites":	{"NNS"},
"campstool":	{"NN"},
"camptosorus":	{"NN"},
"campus":	{"NN"},
"campuses":	{"NNS"},
"campy":	{"NN","JJ"},
"campyloneurum":	{"NN"},
"campylorhynchus":	{"NNS"},
"campylotropous":	{"JJ"},
"cams":	{"NNS"},
"camshaft":	{"NN"},
"camus":	{"NN"},
"camwood":	{"NN"},
"can":	{"MD","NN","VB","VBP"},
"can-do":	{"JJ"},
"canaan":	{"NN"},
"canaanite":	{"NN"},
"canaanitic":	{"NN"},
"canachites":	{"NNS"},
"canada":	{"NN"},
"canadian-dollar":	{"JJ"},
"canadian-fisheries":	{"NNS"},
"canadian-owned":	{"JJ"},
"canafistola":	{"NN"},
"canafistula":	{"NN"},
"canal":	{"VB","NN"},
"canaled":	{"VBD","VBN"},
"canalicular":	{"JJ"},
"canaliculate":	{"JJ"},
"canaliculus":	{"NNS"},
"canaling":	{"VBG"},
"canalisation":	{"NN"},
"canalise":	{"VB","VBP"},
"canalised":	{"VBD","VBN"},
"canalises":	{"VBZ"},
"canalising":	{"VBG"},
"canalization":	{"NN"},
"canalize":	{"VB","VBP"},
"canalized":	{"VBD","VBN"},
"canalizes":	{"VBZ"},
"canalizing":	{"VBG"},
"canalled":	{"VBD","VBN"},
"canalling":	{"VBG"},
"canals":	{"VBZ","NNS"},
"cananga":	{"NN"},
"canangium":	{"NN"},
"canape":	{"NN"},
"canara":	{"NN"},
"canard":	{"NN"},
"canards":	{"NNS"},
"canarese":	{"NN"},
"canaries":	{"NNS"},
"canary":	{"NN"},
"canary-colored":	{"JJ"},
"canary-yellow":	{"JJ"},
"canasta":	{"NN"},
"canavalia":	{"NN"},
"canavanine":	{"NN"},
"canaveral":	{"NN"},
"canberra":	{"NN"},
"cancan":	{"NN"},
"cancel":	{"VB","VBP"},
"canceled":	{"VBN","VBD"},
"canceling":	{"VBG"},
"cancellate":	{"JJ"},
"cancellated":	{"JJ"},
"cancellation":	{"NN"},
"cancellations":	{"NNS"},
"cancelled":	{"VBD","VBN"},
"cancelling":	{"VBG"},
"cancellous":	{"JJ"},
"cancels":	{"VBZ"},
"cancer":	{"NN"},
"cancer-causing":	{"JJ"},
"cancer-gene":	{"JJ"},
"cancer-related":	{"JJ"},
"cancer-ridden":	{"JJ"},
"cancer-suppressing":	{"JJ"},
"cancer-suppressors":	{"NNS"},
"cancer-susceptible":	{"JJ"},
"cancerous":	{"JJ"},
"cancers":	{"NNS"},
"cancerweed":	{"NN"},
"cancridae":	{"NN"},
"cancroid":	{"JJ","NN"},
"cancun":	{"NN"},
"candace":	{"NN"},
"candela":	{"NN"},
"candelabra":	{"NN","NNS"},
"candelabras":	{"NNS"},
"candelabrum":	{"NN"},
"candelilla":	{"NN"},
"candent":	{"JJ"},
"candescent":	{"JJ"},
"candid":	{"JJ"},
"candida":	{"NN"},
"candidacy":	{"NN"},
"candidate":	{"NN"},
"candidate-picking":	{"JJ"},
"candidates":	{"NNS"},
"candidature":	{"NN"},
"candidiasis":	{"NN"},
"candidly":	{"RB"},
"candidness":	{"NN"},
"candied":	{"JJ","NN","VBD","VBN"},
"candies":	{"NNS","VBZ"},
"candle":	{"NN"},
"candle-lit":	{"JJ"},
"candleberry":	{"NN"},
"candled":	{"VBD","VBN"},
"candlelight":	{"NN"},
"candlemaker":	{"NN"},
"candlemas":	{"NN"},
"candlenut":	{"NN"},
"candlepin":	{"NN"},
"candlepins":	{"NNS"},
"candlepower":	{"NN"},
"candles":	{"NNS","VBZ"},
"candlesnuffer":	{"NN"},
"candlestick":	{"NN"},
"candlewick":	{"NN"},
"candlewood":	{"NN"},
"candling":	{"VBG"},
"candor":	{"NN"},
"candour":	{"NN"},
"candy":	{"NN"},
"candy-like":	{"JJ"},
"candy-scented":	{"JJ"},
"candybar":	{"NN"},
"candyfloss":	{"NN"},
"candying":	{"VBG"},
"candymaker":	{"NN"},
"candys":	{"NNS"},
"candytuft":	{"NN"},
"candyweed":	{"VBD","VBN"},
"cane":	{"NN","VB","VBP"},
"cane-sugar":	{"NN"},
"canebrake":	{"NN"},
"canecutter":	{"NN"},
"caned":	{"VBD","VBN"},
"canella":	{"NN"},
"canella-alba":	{"NN"},
"canellaceae":	{"NN"},
"canes":	{"NNS","VBZ"},
"canescent":	{"JJ"},
"canetti":	{"NN"},
"canfield":	{"NN"},
"canful":	{"NN"},
"cangue":	{"NN"},
"canicula":	{"NN"},
"canicular":	{"JJ"},
"canicule":	{"NN"},
"canid":	{"NN"},
"canidae":	{"NN"},
"canine":	{"JJ","NN"},
"caning":	{"NN","VBG"},
"canis":	{"NN"},
"canistel":	{"NN"},
"canister":	{"NN"},
"canisters":	{"NNS"},
"canker":	{"NN","VB","VBP"},
"cankered":	{"VBD","VBN"},
"cankering":	{"VBG"},
"cankerous":	{"JJ"},
"cankers":	{"NNS","VBZ"},
"cankerweed":	{"NN"},
"cankerworm":	{"NN"},
"cankerworms":	{"NNS"},
"canna":	{"NN"},
"cannabidaceae":	{"NN"},
"cannabin":	{"NN"},
"cannabinoid":	{"NN"},
"cannabinoids":	{"NNS"},
"cannabis":	{"NN"},
"cannaceae":	{"NN"},
"cannae":	{"NN"},
"canned":	{"JJ","VBN","VBD"},
"canned-food":	{"NN"},
"canned-foods":	{"NNS","JJ"},
"canned-mushroom":	{"JJ"},
"cannelloni":	{"NN"},
"canneries":	{"NNS"},
"canners":	{"NNS"},
"cannery":	{"NN"},
"cannes":	{"NNS"},
"cannibal":	{"NN"},
"cannibalic":	{"JJ"},
"cannibalise":	{"VB","VBP"},
"cannibalised":	{"VBD","VBN"},
"cannibalises":	{"VBZ"},
"cannibalising":	{"VBG"},
"cannibalism":	{"NN"},
"cannibalistic":	{"JJ"},
"cannibalize":	{"VB","VBP"},
"cannibalized":	{"VBD","VBN"},
"cannibalizes":	{"VBZ"},
"cannibalizing":	{"VBG"},
"cannibals":	{"NNS"},
"cannikin":	{"NN"},
"cannily":	{"RB"},
"canning":	{"NN","VBG"},
"cannister":	{"NN"},
"cannisters":	{"NNS"},
"cannon":	{"NN","VBP","VB"},
"cannonade":	{"NN"},
"cannonball":	{"NN","VB","VBP"},
"cannonballed":	{"VBD","VBN"},
"cannonballing":	{"VBG"},
"cannonballs":	{"NNS","VBZ"},
"cannoned":	{"VBD","VBN"},
"cannoneer":	{"NN"},
"cannoning":	{"VBG"},
"cannons":	{"NNS","VBZ"},
"cannot":	{"MD"},
"cannula":	{"NN"},
"cannular":	{"JJ"},
"cannulate":	{"VB"},
"cannulation":	{"NN"},
"cannulisation":	{"NN"},
"cannulise":	{"VB"},
"cannulization":	{"NN"},
"cannulize":	{"VB"},
"canny":	{"JJ","NN"},
"canoe":	{"NN","VB","VBP"},
"canoed":	{"VBD","VBN"},
"canoeing":	{"VBG","NN"},
"canoeist":	{"NN"},
"canoeists":	{"NNS"},
"canoes":	{"NNS","VBZ"},
"canola":	{"NN"},
"canon":	{"NN"},
"canonic":	{"JJ"},
"canonical":	{"JJ","NN"},
"canonically":	{"RB"},
"canonisation":	{"NN"},
"canonise":	{"VB","VBP"},
"canonised":	{"VBD","VBN"},
"canonises":	{"VBZ"},
"canonising":	{"VBG"},
"canonist":	{"JJ","NN"},
"canonization":	{"NN"},
"canonize":	{"VB","VBP"},
"canonized":	{"VBD","VBN"},
"canonizes":	{"VBZ"},
"canonizing":	{"VBG"},
"canons":	{"NNS"},
"canoodle":	{"VB","VBP"},
"canoodled":	{"VBD","VBN"},
"canoodles":	{"VBZ"},
"canoodling":	{"VBG"},
"canopied":	{"JJ","VBD","VBN"},
"canopies":	{"NNS","VBZ"},
"canopus":	{"NN"},
"canopy":	{"NN","VB","VBP"},
"canopying":	{"VBG"},
"canorous":	{"JJ"},
"cans":	{"NNS","VBZ"},
"cant":	{"NN","VB","VBP"},
"cantabile":	{"JJ"},
"cantabrigian":	{"NN"},
"cantala":	{"NN"},
"cantaloup":	{"NN"},
"cantaloupe":	{"NN"},
"cantankerous":	{"JJ","NN"},
"cantankerously":	{"RB"},
"cantata":	{"NN"},
"canted":	{"VBD","VBN"},
"canteen":	{"NN"},
"canter":	{"NN","VB","VBP"},
"canterbury":	{"NN"},
"cantered":	{"VBD","VBN"},
"cantering":	{"VBG"},
"canters":	{"NNS","VBZ"},
"cantharellus":	{"NNS"},
"canthus":	{"NN"},
"canticle":	{"NN"},
"canticles":	{"NNS"},
"cantilever":	{"NN"},
"cantilevers":	{"NNS"},
"cantillate":	{"VB"},
"cantillation":	{"NN"},
"canting":	{"JJ","VBG"},
"cantle":	{"NN"},
"cantles":	{"NNS"},
"canto":	{"NN"},
"canton":	{"NN","VB","VBP"},
"cantonal":	{"JJ"},
"cantoned":	{"VBD","VBN"},
"cantoning":	{"VBG"},
"cantonment":	{"NN"},
"cantons":	{"NNS","VBZ"},
"cantor":	{"NN"},
"cants":	{"VBZ"},
"canty":	{"JJ"},
"canuck":	{"NN"},
"canulate":	{"VB"},
"canulation":	{"NN"},
"canulisation":	{"NN"},
"canulization":	{"NN"},
"canute":	{"NN"},
"canvas":	{"NN"},
"canvasback":	{"NN","NNS"},
"canvasbacks":	{"NNS"},
"canvases":	{"NNS"},
"canvass":	{"VB","VBP","NN"},
"canvassed":	{"VBD","VBN"},
"canvasser":	{"NN"},
"canvassers":	{"NNS"},
"canvasses":	{"VBZ"},
"canvassing":	{"VBG"},
"canyon":	{"NN"},
"canyons":	{"NNS"},
"canyonside":	{"NN"},
"caoutchouc":	{"NN"},
"cap":	{"NN","VB","VBP"},
"cap-a-pie":	{"RB"},
"cap-and-ball":	{"JJ"},
"cap.":	{"NN"},
"capabilities":	{"NNS"},
"capability":	{"NN"},
"capable":	{"JJ"},
"capableness":	{"NN"},
"capably":	{"RB"},
"capacious":	{"JJ"},
"capaciousness":	{"NN"},
"capacitance":	{"NN"},
"capacitate":	{"VB"},
"capacities":	{"NNS"},
"capacitive":	{"JJ"},
"capacitor":	{"NN"},
"capacitors":	{"NNS"},
"capacity":	{"NN"},
"capacity-controlled":	{"JJ"},
"capacity-expansion":	{"JJ","NN"},
"caparison":	{"VB","VBP","NN"},
"caparisoned":	{"VBD","VBN"},
"caparisoning":	{"VBG"},
"caparisons":	{"VBZ","NNS"},
"cape":	{"NN"},
"capek":	{"NN"},
"capelan":	{"NN"},
"capelin":	{"NN"},
"capella":	{"NN"},
"caper":	{"VB","VBP","NN"},
"capercaillie":	{"NN"},
"capercailzie":	{"NN"},
"capered":	{"VBD","VBN"},
"capering":	{"VBG"},
"capers":	{"NNS","VBZ"},
"capes":	{"NNS"},
"capet":	{"NN"},
"capetian":	{"JJ","NN"},
"capeweed":	{"VBD","VBN"},
"capful":	{"NN"},
"capibara":	{"NN"},
"capillarity":	{"NN"},
"capillary":	{"NN","JJ"},
"capita":	{"NN"},
"capital":	{"NN","JJ"},
"capital-appreciation":	{"NN"},
"capital-assets":	{"NNS"},
"capital-boosting":	{"JJ"},
"capital-coverage":	{"NN"},
"capital-draining":	{"VBG"},
"capital-equipment":	{"NN"},
"capital-formation":	{"NN"},
"capital-gain":	{"JJ"},
"capital-gains":	{"NNS","JJ","NN"},
"capital-gains-cut":	{"JJ"},
"capital-gains-tax":	{"JJ"},
"capital-goods":	{"NNS"},
"capital-improvement":	{"NN"},
"capital-intensive":	{"JJ"},
"capital-market":	{"JJ","NN"},
"capital-markets":	{"JJ"},
"capital-punishment":	{"NN"},
"capital-raising":	{"JJ","NN"},
"capital-reserve":	{"JJ"},
"capital-spending":	{"JJ","NN"},
"capital-to-asset":	{"NN","JJ"},
"capital-to-assets":	{"JJ","NNS"},
"capitales":	{"NNS","FW"},
"capitalgains":	{"NNS"},
"capitalincludes":	{"NNS"},
"capitalisation":	{"NN"},
"capitalise":	{"VB","VBP"},
"capitalised":	{"VBD","VBN"},
"capitalises":	{"VBZ"},
"capitalising":	{"VBG"},
"capitalism":	{"NN"},
"capitalist":	{"JJ","NN"},
"capitalist-democratic":	{"JJ"},
"capitalist-exploiters-greedy-American-consumers-gl":	{"JJ"},
"capitalist-exploiters-greedy-american-consumers-gl":	{"JJ"},
"capitalistic":	{"JJ"},
"capitalists":	{"NNS"},
"capitalization":	{"NN"},
"capitalizations":	{"NNS"},
"capitalize":	{"VB","VBP"},
"capitalized":	{"VBN","VBD"},
"capitalizes":	{"VBZ"},
"capitalizing":	{"VBG"},
"capitalmarket":	{"NN"},
"capitals":	{"NNS"},
"capitate":	{"JJ","NN"},
"capitation":	{"NN"},
"capitonidae":	{"NN"},
"capitular":	{"JJ"},
"capitulary":	{"JJ","NN"},
"capitulate":	{"VB","VBP"},
"capitulated":	{"VBD","VBN"},
"capitulates":	{"VBZ"},
"capitulating":	{"VBG"},
"capitulation":	{"NN"},
"capitulations":	{"NNS"},
"capitulum":	{"NN"},
"capiz":	{"NN"},
"caplin":	{"NN"},
"capo":	{"NN"},
"capon":	{"NN"},
"capone":	{"NN"},
"caponise":	{"VB"},
"caponize":	{"VB"},
"caporetto":	{"NN"},
"capos":	{"NNS"},
"capote":	{"NN"},
"capoten":	{"NN"},
"cappadocia":	{"NN"},
"cappadocian":	{"JJ"},
"capparidaceae":	{"NN"},
"capparis":	{"NN"},
"capped":	{"JJ","VBD","VBN"},
"cappelletti":	{"NN"},
"capping":	{"VBG","NN"},
"cappuccino":	{"NN"},
"capra":	{"NN"},
"caprella":	{"NN"},
"capreolus":	{"NN"},
"capriccio":	{"NN"},
"caprice":	{"NN"},
"capricious":	{"JJ"},
"capriciously":	{"RB"},
"capriciousness":	{"NN"},
"capricorn":	{"NN"},
"capricornis":	{"NNS"},
"capricornus":	{"NN"},
"caprifig":	{"NN"},
"caprifoliaceae":	{"NN"},
"caprimulgid":	{"NN"},
"caprimulgidae":	{"NN"},
"caprimulgiformes":	{"NNS"},
"caprimulgus":	{"NN"},
"caprine":	{"JJ"},
"capriole":	{"NN","VB","VBP"},
"caprioled":	{"VBD","VBN"},
"caprioles":	{"NNS","VBZ"},
"caprioling":	{"VBG"},
"caproidae":	{"NN"},
"capromyidae":	{"NN"},
"capros":	{"NN"},
"caps":	{"NNS","VBZ"},
"capsaicin":	{"NN"},
"capsella":	{"NN"},
"capsicum":	{"NN"},
"capsid":	{"NN"},
"capsidae":	{"NN"},
"capsize":	{"VB","VBP"},
"capsized":	{"VBD","VBN"},
"capsizes":	{"VBZ"},
"capsizing":	{"VBG"},
"capstan":	{"NN"},
"capstone":	{"NN"},
"capsular":	{"JJ"},
"capsulate":	{"JJ"},
"capsulated":	{"JJ"},
"capsule":	{"NN","JJ","VB","VBP"},
"capsuled":	{"VBD","VBN"},
"capsules":	{"NNS","VBZ"},
"capsuling":	{"VBG"},
"capsulise":	{"VB","VBP"},
"capsulised":	{"VBD","VBN"},
"capsulises":	{"VBZ"},
"capsulising":	{"VBG"},
"capsulize":	{"VB","VBP"},
"capsulized":	{"VBD","VBN"},
"capsulizes":	{"VBZ"},
"capsulizing":	{"VBG"},
"captain":	{"NN","VBP","VB"},
"captaincy":	{"NN"},
"captained":	{"VBD","VBN"},
"captaining":	{"VBG"},
"captains":	{"VBZ","NNS"},
"captainship":	{"NN"},
"caption":	{"NN","VB","VBP"},
"captioned":	{"VBD","VBN"},
"captioning":	{"VBG"},
"captions":	{"NNS","VBZ"},
"captious":	{"JJ"},
"captiously":	{"RB"},
"captivate":	{"VB","VBP"},
"captivated":	{"VBD","VBN"},
"captivates":	{"VBZ"},
"captivating":	{"JJ","VBG"},
"captivatingly":	{"RB"},
"captivation":	{"NN"},
"captive":	{"NN","JJ"},
"captives":	{"NNS"},
"captivity":	{"NN"},
"captopril":	{"NN"},
"captor":	{"NN"},
"captors":	{"NNS"},
"capture":	{"VB","VBP","NN"},
"captured":	{"VBN","VBD"},
"capturer":	{"NN"},
"captures":	{"VBZ","NNS"},
"capturing":	{"NN","VBG"},
"capuchin":	{"NN"},
"capulin":	{"NN"},
"caput":	{"NN"},
"capybara":	{"NN"},
"car":	{"NN"},
"car-assembly":	{"NN"},
"car-buff":	{"JJ"},
"car-care":	{"JJ"},
"car-crash":	{"JJ"},
"car-dealers":	{"NNS"},
"car-development":	{"NN"},
"car-ferry":	{"NN"},
"car-free":	{"JJ"},
"car-happy":	{"JJ"},
"car-industry":	{"NN"},
"car-leasing":	{"NN"},
"car-maker":	{"NN"},
"car-market":	{"JJ","NN"},
"car-mechanic":	{"NN"},
"car-owners":	{"NNS"},
"car-parking":	{"JJ"},
"car-parts":	{"JJ"},
"car-pool":	{"NN","VB","VBP"},
"car-pooled":	{"VBD","VBN"},
"car-pooling":	{"VBG"},
"car-pools":	{"NNS","VBZ"},
"car-rental":	{"JJ","NN"},
"car-safety":	{"JJ","NN"},
"car-sales":	{"NNS"},
"carabao":	{"NN"},
"carabidae":	{"NN"},
"carabineer":	{"NN"},
"carabiner":	{"NN"},
"carabinier":	{"NN"},
"caracal":	{"NN"},
"caracara":	{"NN"},
"caracas":	{"NN"},
"carack":	{"NN"},
"caracole":	{"NN","VB","VBP"},
"caracoled":	{"VBD","VBN"},
"caracoles":	{"NNS","VBZ"},
"caracoling":	{"VBG"},
"caracolito":	{"NN"},
"caracul":	{"NN"},
"carafate":	{"NN"},
"carafe":	{"NN"},
"caragana":	{"NN"},
"carageen":	{"NN"},
"carambola":	{"NN"},
"caramel":	{"NN"},
"caramelise":	{"VB","VBP"},
"caramelised":	{"VBD","VBN","JJ"},
"caramelises":	{"VBZ"},
"caramelising":	{"VBG"},
"caramelize":	{"VB","VBP"},
"caramelized":	{"VBD","VBN","JJ"},
"caramelizes":	{"VBZ"},
"caramelizing":	{"VBG"},
"carancha":	{"NN"},
"caranda":	{"NN"},
"caranday":	{"NN"},
"carangid":	{"JJ","NN"},
"carangidae":	{"NN"},
"caranx":	{"NN"},
"carapace":	{"NN"},
"carapidae":	{"NN"},
"carassius":	{"NNS"},
"carat":	{"NN"},
"carats":	{"NNS"},
"caravaggio":	{"NN"},
"caravan":	{"NN","VB","VBP"},
"caravaned":	{"VBD","VBN"},
"caravaning":	{"VBG","NN"},
"caravanned":	{"VBD","VBN"},
"caravanning":	{"VBG","NN"},
"caravans":	{"NNS","VBZ"},
"caravansary":	{"NN"},
"caravanserai":	{"NN"},
"caraway":	{"NN"},
"carbamate":	{"NN"},
"carbamazepine":	{"NN"},
"carbamide":	{"NN"},
"carbapenem":	{"NN"},
"carbaryl":	{"NN"},
"carbide":	{"NN"},
"carbide-products":	{"NNS"},
"carbine":	{"NN"},
"carbineer":	{"NN"},
"carbines":	{"NNS"},
"carbocyclic":	{"JJ"},
"carbohydrate":	{"NN"},
"carbohydrates":	{"NNS","VBZ"},
"carbolated":	{"JJ"},
"carboloy":	{"NN"},
"carbomycin":	{"NN"},
"carbon":	{"NN"},
"carbon-14":	{"NN"},
"carbon-dioxide":	{"NN"},
"carbon-halogen":	{"NN"},
"carbon-impregnated":	{"JJ"},
"carbon-monoxide":	{"NN"},
"carbonaceous":	{"JJ"},
"carbonado":	{"NN"},
"carbonara":	{"NN"},
"carbonate":	{"NN","VB","VBP"},
"carbonated":	{"JJ","VBD","VBN"},
"carbonates":	{"NNS","VB","VBZ"},
"carbonating":	{"VBG"},
"carbonation":	{"NN"},
"carbondale":	{"NN"},
"carbonic":	{"JJ"},
"carboniferous":	{"JJ"},
"carbonisation":	{"NN"},
"carbonise":	{"VB","VBP"},
"carbonised":	{"VBD","VBN","JJ"},
"carbonises":	{"VBZ"},
"carbonising":	{"VBG"},
"carbonization":	{"NN"},
"carbonize":	{"VB","VBP"},
"carbonized":	{"VBD","VBN","JJ"},
"carbonizes":	{"VBZ"},
"carbonizing":	{"VBG"},
"carbonous":	{"JJ"},
"carbons":	{"NNS"},
"carbonyl":	{"JJ","NN"},
"carbonylic":	{"JJ"},
"carborundum":	{"NN"},
"carboxy-labeled":	{"JJ"},
"carboxyl":	{"JJ","NN"},
"carboxylate":	{"VB"},
"carboxylic":	{"JJ"},
"carboxymethyl":	{"NN"},
"carboy":	{"NN"},
"carbuncle":	{"NN"},
"carbuncled":	{"JJ"},
"carbuncular":	{"JJ"},
"carburet":	{"VB"},
"carbureted":	{"VBD","VBN"},
"carbureting":	{"VBG"},
"carburetor":	{"NN"},
"carburets":	{"VBZ"},
"carburetted":	{"VBD","VBN"},
"carburetting":	{"VBG"},
"carburettor":	{"NN"},
"carburise":	{"VB"},
"carburize":	{"VB"},
"carcajou":	{"NN"},
"carcase":	{"NN"},
"carcass":	{"NN"},
"carcasses":	{"NNS"},
"carcharhinidae":	{"NN"},
"carcharhinus":	{"NN"},
"carcharias":	{"NN"},
"carchariidae":	{"NN"},
"carcharodon":	{"NN"},
"carcinoembryonic":	{"JJ"},
"carcinogen":	{"NN"},
"carcinogenic":	{"JJ"},
"carcinogens":	{"NNS"},
"carcinoid":	{"JJ"},
"carcinoma":	{"NN"},
"carcinomatous":	{"JJ"},
"carcinosarcoma":	{"NN"},
"card":	{"NN","VBP","VB"},
"card-activated":	{"JJ"},
"card-carrying":	{"JJ"},
"card-holder":	{"NN"},
"card-house":	{"NN"},
"card-member":	{"JJ","NN"},
"card-playing":	{"JJ"},
"cardamine":	{"NN"},
"cardamom":	{"NN"},
"cardamon":	{"NN"},
"cardamum":	{"NN"},
"cardboard":	{"NN","JJ"},
"cardcase":	{"NN"},
"cardcastle":	{"NN"},
"carded":	{"VBD","VBN"},
"cardholder":	{"NN"},
"cardholders":	{"NNS"},
"cardhouse":	{"NN"},
"cardia":	{"NN"},
"cardiac":	{"JJ","NN"},
"cardiac-drug":	{"JJ"},
"cardiff":	{"NN"},
"cardigan":	{"NN"},
"cardiidae":	{"NN"},
"cardinal":	{"NN","JJ"},
"cardinalate":	{"NN"},
"cardinalfish":	{"NN"},
"cardinality":	{"NN"},
"cardinals":	{"NNS"},
"cardinalship":	{"NN"},
"carding":	{"VBG"},
"cardiogram":	{"NN"},
"cardiograph":	{"NN"},
"cardiographic":	{"JJ"},
"cardiography":	{"NN"},
"cardioid":	{"NN"},
"cardiologic":	{"JJ"},
"cardiologist":	{"NN"},
"cardiologists":	{"NNS"},
"cardiology":	{"NN"},
"cardiomegaly":	{"NN"},
"cardiomyopathy":	{"NN"},
"cardiopathy":	{"NN"},
"cardiopulmonary":	{"JJ","NN"},
"cardiorespiratory":	{"NN","JJ"},
"cardiospasm":	{"NN"},
"cardiospermum":	{"NN"},
"cardiovascular":	{"JJ","NN"},
"cardioversion":	{"NN"},
"carditis":	{"NN"},
"cardium":	{"NN"},
"cardizem":	{"NN"},
"cardmember":	{"NN"},
"cardmembers":	{"NNS"},
"cardoon":	{"NN"},
"cardroom":	{"NN"},
"cards":	{"NNS","VBZ"},
"cardsharp":	{"NN"},
"cardsharper":	{"NN"},
"carducci":	{"NN"},
"carduelinae":	{"NN"},
"carduelis":	{"NN"},
"cardura":	{"NN"},
"carduus":	{"NN"},
"care":	{"NN","VB","VBP"},
"care-adviser":	{"NN"},
"care-free":	{"JJ"},
"care-laden":	{"JJ"},
"cared":	{"VBD","VBN"},
"cared-for":	{"JJ"},
"careen":	{"VB","VBP"},
"careened":	{"VBD","VBN"},
"careening":	{"VBG"},
"careens":	{"VBZ"},
"career":	{"NN","VB","VBP"},
"career-bound":	{"JJ"},
"career-high":	{"JJ","NN"},
"career-risking":	{"JJ"},
"careered":	{"VBD","VBN"},
"careering":	{"VBG"},
"careerism":	{"NN"},
"careerist":	{"NN","JJ"},
"careerists":	{"NNS"},
"careers":	{"NNS","VBZ"},
"carefree":	{"JJ"},
"carefreeness":	{"NN"},
"careful":	{"JJ"},
"carefully":	{"RB"},
"carefulness":	{"NN"},
"caregiver":	{"NN"},
"caregivers":	{"NNS"},
"careless":	{"JJ"},
"carelessly":	{"RB"},
"carelessness":	{"NN"},
"carelian":	{"NN"},
"cares":	{"VBZ","NNS"},
"caress":	{"VB","VBP","NN"},
"caressed":	{"VBD","VBN"},
"caresses":	{"NNS","VBZ"},
"caressing":	{"VBG"},
"caret":	{"NN"},
"caretaker":	{"NN"},
"caretta":	{"NN"},
"carew":	{"NN"},
"careworn":	{"JJ","NN"},
"carex":	{"NN"},
"carfare":	{"NN"},
"carful":	{"NN"},
"cargo":	{"NN"},
"cargo-handling":	{"NN"},
"cargoes":	{"NNS"},
"carhop":	{"NN"},
"cariama":	{"NN"},
"cariamidae":	{"NN"},
"carib":	{"NN"},
"caribbean":	{"NN"},
"caribe":	{"NN"},
"caribees":	{"NNS"},
"caribou":	{"NN","NNS"},
"caribous":	{"NNS"},
"carica":	{"NN"},
"caricaceae":	{"NN"},
"caricature":	{"NN","VB","VBP"},
"caricatured":	{"VBD","VBN"},
"caricatures":	{"NNS","VBZ"},
"caricaturing":	{"VBG"},
"caricaturist":	{"NN"},
"caricaturists":	{"NNS"},
"caries":	{"NN"},
"carillon":	{"NN"},
"carillonneur":	{"NN"},
"carillons":	{"NNS"},
"carina":	{"NN"},
"carinal":	{"JJ"},
"carinate":	{"JJ","NN"},
"carinated":	{"JJ"},
"caring":	{"VBG","JJ"},
"carinii":	{"NN"},
"carioca":	{"NN"},
"carious":	{"JJ"},
"carissa":	{"NN"},
"carjack":	{"VB","VBP"},
"carjacked":	{"VBD","VBN"},
"carjacker":	{"NN"},
"carjackers":	{"NN"},
"carjacking":	{"NN","VBG"},
"carjacks":	{"VBZ"},
"cark":	{"VB"},
"carlin":	{"NN"},
"carlina":	{"NN"},
"carload":	{"NN"},
"carloading":	{"NN"},
"carloads":	{"NNS"},
"carlovingian":	{"NN"},
"carlsbad":	{"NN"},
"carlson":	{"NN"},
"carlyle":	{"NN"},
"carmaker":	{"NN"},
"carmakers":	{"NNS"},
"carmelite":	{"JJ","NN"},
"carmichael":	{"NN"},
"carminative":	{"JJ","NN"},
"carmine":	{"NN","JJ"},
"carnage":	{"NN"},
"carnal":	{"JJ","NN"},
"carnalise":	{"VB","VBP"},
"carnalised":	{"VBD","VBN"},
"carnalises":	{"VBZ"},
"carnalising":	{"VBG"},
"carnality":	{"NN"},
"carnalize":	{"VB","VBP"},
"carnalized":	{"VBD","VBN"},
"carnalizes":	{"VBZ"},
"carnalizing":	{"VBG"},
"carnallite":	{"NN"},
"carnally":	{"RB"},
"carnassial":	{"JJ"},
"carnation":	{"NN"},
"carnauba":	{"NN"},
"carne":	{"NN"},
"carnegie":	{"NN"},
"carnegiea":	{"NN"},
"carnelian":	{"NN"},
"carnify":	{"VB"},
"carnitas":	{"NNS"},
"carnival":	{"NN"},
"carnivora":	{"NN"},
"carnivore":	{"NN"},
"carnivores":	{"NNS"},
"carnivorous":	{"JJ"},
"carnosaur":	{"NN"},
"carnosaura":	{"NN"},
"carnot":	{"NN"},
"carnotite":	{"NN"},
"carob":	{"NN"},
"caroche":	{"NN"},
"carol":	{"NN","VB","VBP"},
"carolean":	{"JJ"},
"caroled":	{"VBD","VBN"},
"caroler":	{"NN"},
"caroline":	{"JJ"},
"caroling":	{"VBG"},
"carolingian":	{"JJ","NN"},
"carolled":	{"VBD","VBN"},
"caroller":	{"NN"},
"carolling":	{"VBG"},
"carols":	{"NNS","VBZ"},
"carolus":	{"NN"},
"carom":	{"NN","VB","VBP"},
"caromed":	{"VBD","VBN"},
"caroming":	{"VBG"},
"caroms":	{"NNS","VBZ"},
"carotene":	{"NN"},
"carotenemia":	{"NN"},
"carotenoid":	{"NN","JJ"},
"carothers":	{"NNS"},
"carotid":	{"JJ","NN"},
"carotin":	{"NN"},
"carousal":	{"NN"},
"carouse":	{"VB","VBP"},
"caroused":	{"VBD","VBN"},
"carousel":	{"NN"},
"carousels":	{"NNS"},
"carouser":	{"NN"},
"carouses":	{"VBZ"},
"carousing":	{"VBG"},
"carp":	{"NN","NNS","VB","VBP"},
"carpal":	{"JJ","NN"},
"carpathians":	{"NNS"},
"carped":	{"VBD","VBN"},
"carpel":	{"NN"},
"carpellary":	{"JJ"},
"carpellate":	{"JJ"},
"carpentaria":	{"NN"},
"carpenter":	{"NN"},
"carpentered":	{"VBD","VBN"},
"carpenteria":	{"NN"},
"carpentering":	{"VBG"},
"carpenters":	{"NNS","VBZ"},
"carpentry":	{"NN"},
"carper":	{"NN"},
"carpet":	{"NN","VB","VBP"},
"carpet-cleaning":	{"JJ"},
"carpetbag":	{"NN"},
"carpetbagger":	{"NN"},
"carpetbaggers":	{"NNS"},
"carpetbagging":	{"NN"},
"carpeted":	{"VBD","VBN"},
"carpeting":	{"NN","VBG"},
"carpets":	{"NNS","VBZ"},
"carpetweed":	{"VBD","VBN"},
"carphophis":	{"NN"},
"carpinaceae":	{"NN"},
"carping":	{"NN","VBG"},
"carpinus":	{"NN"},
"carpobrotus":	{"NNS"},
"carpocapsa":	{"NN"},
"carpodacus":	{"NN"},
"carpool":	{"NN","VB","VBP"},
"carpooled":	{"VBD","VBN"},
"carpooling":	{"VBG"},
"carpools":	{"NNS","VBZ"},
"carpophagous":	{"JJ"},
"carpophore":	{"NN"},
"carport":	{"NN"},
"carpospore":	{"NN"},
"carposporic":	{"JJ"},
"carposporous":	{"JJ"},
"carps":	{"VBZ","NNS"},
"carpus":	{"NN"},
"carrack":	{"NN"},
"carrageen":	{"NN"},
"carrageenan":	{"NN"},
"carrageenin":	{"NN"},
"carragheen":	{"NN"},
"carreer":	{"NN"},
"carrefour":	{"NN"},
"carrel":	{"NN"},
"carrell":	{"NN"},
"carrere":	{"NN"},
"carriage":	{"NN"},
"carriage-step":	{"NN"},
"carriages":	{"NNS"},
"carriageway":	{"NN"},
"carrie":	{"NN"},
"carried":	{"VBD","VBN"},
"carrier":	{"NN"},
"carrier-based":	{"JJ"},
"carrier-current":	{"JJ"},
"carriers":	{"NNS"},
"carries":	{"VBZ"},
"carrion":	{"NN"},
"carrizo":	{"NN"},
"carroll":	{"NN"},
"carrot":	{"NN"},
"carrots":	{"NNS"},
"carrottop":	{"NN"},
"carroty":	{"JJ"},
"carrousel":	{"NN"},
"carrozza":	{"NN"},
"carry":	{"VB","NN","VBP"},
"carry-forward":	{"NN"},
"carry-forwards":	{"NNS"},
"carry-in":	{"JJ"},
"carry-on":	{"JJ","NN"},
"carry-over":	{"NN"},
"carryall":	{"NN"},
"carrycot":	{"NN"},
"carryforwards":	{"NNS"},
"carrying":	{"VBG","NN"},
"carryover":	{"NN"},
"carryovers":	{"NNS"},
"cars":	{"NNS"},
"carshare":	{"VB","VBP","NN"},
"carshared":	{"VBD","VBN"},
"carshares":	{"VBZ","NNS"},
"carsharing":	{"VBG","NN"},
"carsick":	{"JJ"},
"carson":	{"NN"},
"cart":	{"NN","VB","VBP"},
"cartage":	{"NN"},
"cartagena":	{"NN"},
"carte":	{"NN"},
"carted":	{"VBD","VBN"},
"cartel":	{"NN"},
"cartelized":	{"VBN"},
"cartels":	{"NNS"},
"carter":	{"NN"},
"cartesian":	{"JJ","NN"},
"carthage":	{"NN"},
"carthaginian":	{"JJ","NN"},
"carthamus":	{"NN"},
"carthorse":	{"NN"},
"carthusian":	{"JJ","NN"},
"cartier":	{"NN"},
"cartilage":	{"NN"},
"cartilaginification":	{"NN"},
"cartilaginous":	{"JJ"},
"carting":	{"NN","VBG"},
"cartload":	{"NN"},
"cartographer":	{"NN"},
"cartographic":	{"JJ"},
"cartographical":	{"JJ"},
"cartography":	{"NN"},
"carton":	{"VB","NN"},
"cartoned":	{"VBD","VBN"},
"cartonful":	{"NN"},
"cartoning":	{"VBG"},
"cartons":	{"NNS","VBZ"},
"cartoon":	{"NN"},
"cartooned":	{"VBD","VBN"},
"cartooning":	{"VBG"},
"cartoonish":	{"JJ"},
"cartoonishly":	{"RB"},
"cartoonishness":	{"NN"},
"cartoonist":	{"NN"},
"cartoonists":	{"NNS"},
"cartoonlike":	{"JJ"},
"cartoons":	{"NNS","VBZ"},
"cartouch":	{"NN"},
"cartouche":	{"NN"},
"cartridge":	{"NN"},
"cartridges":	{"NNS"},
"cartroad":	{"NN"},
"carts":	{"NNS","VBZ"},
"cartwheel":	{"NN","VB","VBP"},
"cartwheeled":	{"VBD","VBN"},
"cartwheeling":	{"VBG"},
"cartwheels":	{"NNS","VBZ"},
"cartwright":	{"NN"},
"carum":	{"NN"},
"caruncle":	{"NN"},
"caruncula":	{"NN"},
"caruncular":	{"JJ"},
"carunculate":	{"JJ"},
"carunculated":	{"JJ"},
"carunculous":	{"JJ"},
"caruso":	{"NN"},
"carve":	{"VB","VBP"},
"carved":	{"VBN","VBD"},
"carved-out-of-solid":	{"JJ"},
"carvedilol":	{"NN"},
"carvel-built":	{"JJ"},
"carver":	{"NN"},
"carvers":	{"NNS"},
"carves":	{"VBZ"},
"carving":	{"NN","VBG"},
"carvings":	{"NNS"},
"carya":	{"NN"},
"caryatid":	{"NN"},
"caryatides":	{"NNS"},
"caryocar":	{"NN"},
"caryocaraceae":	{"NN"},
"caryophyllaceae":	{"NN"},
"caryophyllaceous":	{"JJ"},
"caryophyllales":	{"NNS"},
"caryophyllidae":	{"NN"},
"caryopsis":	{"NN"},
"caryota":	{"NN"},
"casaba":	{"NN"},
"casablanca":	{"NN"},
"casals":	{"NN"},
"casanova":	{"NN"},
"casava":	{"NN"},
"casbah":	{"NN"},
"casca":	{"NN"},
"cascabel":	{"NN"},
"cascade":	{"NN","VB","VBP"},
"cascaded":	{"VBD","VBN"},
"cascades":	{"NNS","VBZ"},
"cascading":	{"VBG"},
"cascara":	{"NN"},
"cascarilla":	{"NN"},
"case":	{"NN","VB","VBP"},
"case-by-case":	{"JJ"},
"case-hardened":	{"JJ"},
"case-history":	{"NN"},
"case-law":	{"NN"},
"case-to-case":	{"JJ"},
"caseate":	{"VB"},
"casebook":	{"NN"},
"cased":	{"JJ","VBD","VBN"},
"caseful":	{"NN"},
"casein":	{"NN"},
"caseload":	{"NN"},
"caseloads":	{"NNS"},
"casement":	{"NN"},
"caseous":	{"JJ"},
"casern":	{"NN"},
"cases":	{"NNS","VBZ"},
"casework":	{"NN"},
"caseworker":	{"NN"},
"caseworkers":	{"NNS"},
"caseworm":	{"NN"},
"cash":	{"NN","VB","VBP"},
"cash-and-carries":	{"NNS"},
"cash-and-carry":	{"NN"},
"cash-and-stock":	{"JJ"},
"cash-back":	{"JJ"},
"cash-deferred":	{"JJ"},
"cash-draw":	{"JJ"},
"cash-equivalent":	{"JJ"},
"cash-flow":	{"JJ","NN"},
"cash-flush":	{"JJ"},
"cash-heavy":	{"JJ"},
"cash-hungry":	{"JJ"},
"cash-interest":	{"JJ"},
"cash-laden":	{"JJ"},
"cash-management":	{"JJ"},
"cash-only":	{"JJ"},
"cash-or-shares":	{"JJ"},
"cash-pressed":	{"JJ"},
"cash-raising":	{"JJ","NN"},
"cash-rich":	{"JJ"},
"cash-short":	{"JJ"},
"cash-squeeze":	{"NN"},
"cash-squeezed":	{"JJ"},
"cash-starved":	{"JJ"},
"cash-strapped":	{"JJ"},
"cash-up-front":	{"NN"},
"cash-value":	{"JJ"},
"cashable":	{"JJ"},
"cashbox":	{"NN"},
"cashcard":	{"NN"},
"cashed":	{"VBD","VBN"},
"cashes":	{"VBZ"},
"cashew":	{"NN"},
"cashews":	{"NNS"},
"cashflow":	{"NN"},
"cashier":	{"NN","VB","VBP"},
"cashiered":	{"VBD","VBN"},
"cashiering":	{"VBG"},
"cashiers":	{"NNS","VBZ"},
"cashing":	{"VBG"},
"cashmere":	{"NN"},
"casing":	{"NN","VBG"},
"casings":	{"NNS"},
"casino":	{"NN"},
"casino-company":	{"NN"},
"casino-hotel":	{"NN"},
"casinos":	{"NNS"},
"cask":	{"NN"},
"casket":	{"NN"},
"casketed":	{"VBD","VBN"},
"casketing":	{"VBG"},
"caskets":	{"NNS","VBZ"},
"caskful":	{"NN"},
"casks":	{"NNS"},
"casmerodius":	{"NNS"},
"caspar":	{"NN"},
"caspase":	{"NN"},
"casper":	{"NN"},
"caspian":	{"NN"},
"caspita-brand":	{"JJ"},
"casque":	{"NN"},
"casquet":	{"NN"},
"casquetel":	{"NN"},
"cass":	{"NN"},
"cassandra":	{"NN"},
"cassareep":	{"NN"},
"cassava":	{"NN"},
"casserole":	{"NN","VBP","VB"},
"cassette":	{"NN"},
"cassettes":	{"NNS"},
"cassia":	{"NN"},
"cassie":	{"NN"},
"cassino":	{"NN"},
"cassiope":	{"NN"},
"cassiopeia":	{"NN"},
"cassirer":	{"NN"},
"cassiri":	{"NN"},
"cassite":	{"NN"},
"cassiterite":	{"NN"},
"cassius":	{"NN"},
"cassock":	{"NN"},
"cassocked":	{"JJ"},
"cassowary":	{"NN"},
"cast":	{"NN","VBD","VBN","VB","VBP"},
"cast-iron":	{"JJ"},
"cast-off":	{"JJ","NN"},
"cast-offs":	{"NNS"},
"cast-proof":	{"JJ"},
"castanea":	{"NN"},
"castanets":	{"NNS"},
"castanopsis":	{"NN"},
"castanospermum":	{"NN"},
"castaway":	{"NN"},
"caste":	{"NN"},
"casteless":	{"JJ"},
"castellated":	{"JJ"},
"caster":	{"NN"},
"casters":	{"NNS"},
"castigate":	{"VB","VBP"},
"castigated":	{"VBD","VBN"},
"castigates":	{"VBZ"},
"castigating":	{"VBG"},
"castigation":	{"NN"},
"castile":	{"NN"},
"castilian":	{"NN"},
"castilla":	{"NN"},
"castilleia":	{"NN"},
"castilleja":	{"NN"},
"castillian":	{"NN"},
"casting":	{"VBG","NN"},
"castings":	{"NNS"},
"castle":	{"NN","VB","VBP"},
"castle-like":	{"JJ"},
"castle-themed":	{"JJ"},
"castled":	{"JJ","VBD","VBN"},
"castlelike":	{"JJ"},
"castles":	{"NNS","VBZ"},
"castling":	{"NN","VBG"},
"castlings":	{"NNS"},
"castmate":	{"NN"},
"castmates":	{"NNS"},
"castoff":	{"NN","JJ"},
"castoffs":	{"NNS"},
"castor":	{"NN"},
"castor-oil":	{"NN"},
"castorbean":	{"NN"},
"castorbeans":	{"NNS"},
"castoridae":	{"NN"},
"castoroides":	{"NNS"},
"castrate":	{"VB","VBP"},
"castrated":	{"VBD","VBN"},
"castrates":	{"VBZ"},
"castrating":	{"VBG"},
"castration":	{"NN"},
"castrations":	{"NNS"},
"castrato":	{"NN"},
"castries":	{"NN"},
"castro-held":	{"JJ"},
"castro-led":	{"JJ"},
"castroism":	{"NN"},
"casts":	{"NNS","VBZ"},
"casual":	{"NN","JJ"},
"casually":	{"RB"},
"casualness":	{"NN"},
"casuals":	{"NNS"},
"casualties":	{"NNS"},
"casualty":	{"NN"},
"casualty-insurance":	{"NN","JJ"},
"casualty-loss":	{"JJ"},
"casuaridae":	{"NN"},
"casuariiformes":	{"NNS"},
"casuarina":	{"NN"},
"casuarinaceae":	{"NN"},
"casuarinales":	{"NNS"},
"casuarius":	{"NN"},
"casuist":	{"NN"},
"casuistic":	{"JJ"},
"casuistical":	{"JJ"},
"casuistry":	{"NN"},
"cat":	{"NN"},
"cat's-claw":	{"NN"},
"cat's-ear":	{"NN"},
"cat's-paw":	{"NN"},
"cat's-tail":	{"NN"},
"cat-and-mouse":	{"JJ"},
"cat-like":	{"JJ"},
"cat-o'-nine-tails":	{"NNS"},
"cata-cornered":	{"JJ"},
"catabatic":	{"JJ"},
"catabiosis":	{"NN"},
"catabolic":	{"JJ"},
"catabolise":	{"VB"},
"catabolism":	{"NN"},
"catabolize":	{"VB"},
"catacala":	{"NN"},
"catachresis":	{"NN"},
"catachrestic":	{"JJ"},
"catachrestical":	{"JJ"},
"cataclinal":	{"JJ"},
"cataclysm":	{"NN"},
"cataclysmal":	{"JJ"},
"cataclysmic":	{"JJ","NN"},
"cataclysms":	{"NNS"},
"catacomb":	{"NN"},
"catacorner":	{"JJ"},
"catadromous":	{"JJ"},
"catafalque":	{"NN"},
"cataflam":	{"NN"},
"catalan":	{"NN"},
"catalase":	{"NN"},
"catalatic":	{"JJ"},
"catalectic":	{"JJ","NN"},
"catalepsy":	{"NN"},
"cataleptic":	{"JJ","NN"},
"catalexis":	{"NN"},
"catalog":	{"NN","VB","VBP"},
"catalog-clothing-merchandiser":	{"NN"},
"cataloged":	{"VBD","VBN"},
"cataloger":	{"NN"},
"cataloging":	{"VBG"},
"catalogs":	{"NNS","VBZ"},
"catalogue":	{"NN","VB","VBP"},
"catalogued":	{"VBN","VBD"},
"cataloguer":	{"NN"},
"catalogues":	{"VBZ","NNS"},
"cataloguing":	{"VBG"},
"catalonia":	{"NN"},
"catalpa":	{"NN"},
"catalufa":	{"NN"},
"catalyse":	{"VB","VBP"},
"catalysed":	{"VBD","VBN"},
"catalyses":	{"VBZ"},
"catalysing":	{"VBG"},
"catalysis":	{"NN"},
"catalyst":	{"NN"},
"catalysts":	{"NNS"},
"catalytic":	{"JJ"},
"catalytically":	{"RB"},
"catalyze":	{"VB","VBP"},
"catalyzed":	{"VBD","VBN"},
"catalyzes":	{"VBZ"},
"catalyzing":	{"VBG"},
"catamaran":	{"NN"},
"catamenia":	{"NN"},
"catamenial":	{"JJ"},
"catamite":	{"NN"},
"catamount":	{"NN"},
"catamountain":	{"NN"},
"catananche":	{"NN"},
"cataphasia":	{"NN"},
"cataphatic":	{"JJ"},
"cataphatism":	{"NN"},
"cataphile":	{"NN"},
"cataphiles":	{"NNS"},
"cataphoresis":	{"NN"},
"cataphoretic":	{"JJ"},
"cataphract":	{"NN"},
"cataphyll":	{"NN"},
"cataplasia":	{"NN"},
"cataplasm":	{"NN"},
"cataplastic":	{"JJ"},
"catapres":	{"NNS"},
"catapult":	{"NN","VB","VBP"},
"catapulted":	{"VBD","VBN"},
"catapultian":	{"JJ"},
"catapultic":	{"JJ"},
"catapulting":	{"VBG"},
"catapults":	{"VBZ","NNS"},
"cataract":	{"NN"},
"cataracts":	{"NNS"},
"catarrh":	{"NN"},
"catarrhal":	{"JJ"},
"catarrhine":	{"JJ","NN"},
"catarrhinian":	{"JJ"},
"catasetum":	{"NN"},
"catastrophe":	{"NN"},
"catastrophes":	{"NNS"},
"catastrophic":	{"JJ"},
"catastrophic-care":	{"NN","JJ"},
"catastrophic-health":	{"JJ","NN"},
"catastrophic-health-care":	{"NN"},
"catastrophic-healthcare":	{"JJ"},
"catastrophic-illness":	{"NN","JJ"},
"catastrophically":	{"RB"},
"catatonia":	{"NN"},
"catatonic":	{"JJ","NN"},
"catawba":	{"NN"},
"catbird":	{"NN"},
"catboat":	{"NN"},
"catbrier":	{"NN"},
"catcall":	{"NN","VB","VBP"},
"catcalled":	{"VBD","VBN"},
"catcalling":	{"VBG"},
"catcalls":	{"NNS","VBZ"},
"catch":	{"VB","NN","VBP"},
"catch-all":	{"JJ","NN"},
"catch-alls":	{"NNS"},
"catch-up":	{"NN"},
"catchall":	{"NN"},
"catchalls":	{"NNS"},
"catcher":	{"NN"},
"catchers":	{"NNS"},
"catches":	{"NNS","VBZ"},
"catchfly":	{"NN"},
"catchier":	{"JJR"},
"catchiest":	{"JJS"},
"catching":	{"VBG","JJ"},
"catchline":	{"NN"},
"catchlines":	{"NNS"},
"catchment":	{"NN"},
"catchments":	{"NNS"},
"catchpenny":	{"JJ"},
"catchphrase":	{"NN"},
"catchup":	{"JJ","NN"},
"catchweed":	{"NN"},
"catchword":	{"NN"},
"catchwords":	{"NNS"},
"catchy":	{"JJ"},
"catclaw":	{"NN"},
"cate":	{"NN"},
"catechesis":	{"NN"},
"catechetic":	{"JJ"},
"catechetical":	{"JJ"},
"catechin":	{"NN"},
"catechise":	{"VB"},
"catechism":	{"NN"},
"catechismal":	{"JJ"},
"catechist":	{"NN"},
"catechistic":	{"JJ"},
"catechize":	{"VB"},
"catecholamine":	{"NN"},
"catecholamines":	{"NNS"},
"catechu":	{"NN"},
"catechumen":	{"NN"},
"categorem":	{"NN"},
"categorematic":	{"JJ"},
"categoreme":	{"NN"},
"categorial":	{"JJ"},
"categorias":	{"NNS","FW","NN"},
"categoric":	{"JJ"},
"categorical":	{"JJ"},
"categorically":	{"RB"},
"categories":	{"NNS"},
"categorisation":	{"NN"},
"categorise":	{"VB","VBP"},
"categorised":	{"VBD","VBN"},
"categorises":	{"VBZ"},
"categorising":	{"VBG"},
"categorization":	{"NN"},
"categorize":	{"VB","VBP"},
"categorized":	{"VBD","VBN"},
"categorizes":	{"VBZ"},
"categorizing":	{"VBG"},
"category":	{"NN"},
"catena":	{"NN"},
"catenary":	{"JJ","NN"},
"catenate":	{"VB"},
"catenulate":	{"JJ","VB"},
"cater":	{"VB","VBP"},
"cater-cornered":	{"JJ"},
"catercorner":	{"JJ"},
"catered":	{"VBD","VBN"},
"caterer":	{"NN"},
"caterers":	{"NNS"},
"catering":	{"VBG","NN"},
"caterpillar":	{"NN"},
"caterpillar-tracked":	{"JJ"},
"caterpillars":	{"NNS"},
"caters":	{"VBZ"},
"caterwaul":	{"NN","VB","VBP"},
"caterwauled":	{"VBD","VBN"},
"caterwauling":	{"VBG","NN"},
"caterwauls":	{"NNS","VBZ"},
"catfish":	{"NN","NNS"},
"catgut":	{"NN"},
"catha":	{"NN"},
"catharacta":	{"NN"},
"catharanthus":	{"NN"},
"cathari":	{"NN"},
"catharism":	{"NN"},
"cathars":	{"NN"},
"catharsis":	{"NN"},
"cathartes":	{"NNS"},
"cathartic":	{"JJ","NN"},
"cathartid":	{"NN"},
"cathartidae":	{"NN"},
"cathay":	{"NN"},
"cathaya":	{"NN"},
"cathect":	{"VB","VBP"},
"cathected":	{"VBD","VBN"},
"cathectic":	{"JJ"},
"cathecting":	{"VBG"},
"cathects":	{"VBZ"},
"cathedra":	{"NN"},
"cathedral":	{"NN"},
"cathedrals":	{"NNS"},
"cather":	{"NN"},
"catherine":	{"NN"},
"catheter":	{"NN"},
"catheterisation":	{"NN"},
"catheterise":	{"VB"},
"catheterization":	{"NN"},
"catheterize":	{"VB"},
"catheters":	{"NNS"},
"cathexis":	{"NN"},
"cathode":	{"NN"},
"cathode-ray":	{"NN"},
"cathoderay":	{"NN"},
"cathodes":	{"NNS"},
"cathodic":	{"JJ"},
"cathodoluminescent":	{"JJ"},
"cathodophoretic":	{"JJ"},
"catholicise":	{"VB"},
"catholicity":	{"NN"},
"catholicize":	{"VB"},
"catholicon":	{"NN"},
"catholicos":	{"NN"},
"cathouse":	{"NN"},
"cating":	{"NN","VBG"},
"cation":	{"NN"},
"cationic":	{"JJ"},
"catkin":	{"NN"},
"catkinate":	{"JJ"},
"catkins":	{"NNS"},
"catlike":	{"JJ","NN"},
"catling":	{"NN"},
"catmint":	{"NN"},
"catnap":	{"NN","VB","VBP"},
"catnapped":	{"VBD","VBN"},
"catnapping":	{"VBG"},
"catnaps":	{"NNS","VBZ"},
"catnip":	{"NN"},
"cato":	{"NN"},
"catoptric":	{"JJ"},
"catoptrical":	{"JJ"},
"catoptrics":	{"NN"},
"catoptrophorus":	{"NN"},
"catostomid":	{"NN"},
"catostomidae":	{"NN"},
"catostomus":	{"NN"},
"cats":	{"NNS","VBZ"},
"catskills":	{"NNS"},
"catsup":	{"NN"},
"cattail":	{"NN"},
"cattalo":	{"NN"},
"cattaloe":	{"NN"},
"catted":	{"VBD","VBN"},
"cattell":	{"NN"},
"cattie":	{"NN"},
"cattiness":	{"NN"},
"catting":	{"VBG"},
"cattish":	{"JJ"},
"cattle":	{"NNS"},
"cattle-car":	{"NN"},
"cattle-lifter":	{"NN"},
"cattleman":	{"NN"},
"cattlemen":	{"NNS"},
"cattleship":	{"NN"},
"cattleya":	{"NN"},
"catty":	{"JJ","NN"},
"catty-corner":	{"RB"},
"catty-cornered":	{"JJ"},
"catullus":	{"NNS"},
"catv":	{"NN"},
"catwalk":	{"NN"},
"caucasia":	{"NN"},
"caucasians":	{"NNS"},
"caucasic":	{"JJ"},
"caucasoid":	{"JJ"},
"caucasus":	{"NNS"},
"caucus":	{"NN","VB","VBP"},
"caucused":	{"VBD","VBN"},
"caucuses":	{"NNS","VBZ"},
"caucusing":	{"VBG"},
"cauda":	{"NN"},
"caudal":	{"JJ","NN"},
"caudally":	{"RB"},
"caudata":	{"NN"},
"caudate":	{"JJ","NN"},
"caudated":	{"JJ"},
"caudex":	{"NN"},
"caught":	{"VBN","VBD"},
"caul":	{"NN"},
"cauldron":	{"NN"},
"caulescent":	{"JJ"},
"cauliflower":	{"NN"},
"cauline":	{"JJ"},
"caulk":	{"VB","VBP"},
"caulked":	{"VBD","VBN"},
"caulking":	{"VBG"},
"caulks":	{"VBZ"},
"caulophyllum":	{"NN"},
"causa":	{"NN"},
"causal":	{"JJ"},
"causalgia":	{"NN"},
"causality":	{"NN"},
"causally":	{"RB"},
"causation":	{"NN"},
"causative":	{"JJ","NN"},
"cause":	{"NN","VB","VBG","VBP"},
"cause-and-effect":	{"JJ"},
"caused":	{"VBN","VBD"},
"causeless":	{"JJ"},
"causerie":	{"NN"},
"causes":	{"VBZ","NNS"},
"causeway":	{"NN"},
"causewayed":	{"VBD","VBN"},
"causewaying":	{"VBG"},
"causeways":	{"NNS","VBZ"},
"causing":	{"VBG"},
"caustic":	{"JJ","NN"},
"caustically":	{"RB"},
"cauterant":	{"NN"},
"cauterisation":	{"NN"},
"cauterise":	{"VB","VBP"},
"cauterised":	{"VBD","VBN"},
"cauterises":	{"VBZ"},
"cauterising":	{"VBG"},
"cauterization":	{"NN"},
"cauterize":	{"VB","VBP"},
"cauterized":	{"VBD","VBN"},
"cauterizes":	{"VBZ"},
"cauterizing":	{"VBG"},
"cautery":	{"NN"},
"caution":	{"NN","VBP","VB"},
"cautionary":	{"JJ"},
"cautioned":	{"VBD","VBN"},
"cautioning":	{"VBG","NN"},
"cautions":	{"VBZ","NNS"},
"cautious":	{"JJ"},
"cautiously":	{"RB"},
"cautiousness":	{"NN"},
"cavalcade":	{"NN"},
"cavalcades":	{"NNS"},
"cavalier":	{"JJ","NN"},
"cavalierly":	{"RB"},
"cavaliers":	{"NNS"},
"cavalla":	{"NN"},
"cavallinis":	{"NNS"},
"cavalry":	{"NN"},
"cavalryman":	{"NN"},
"cavalrymen":	{"NNS"},
"cave":	{"NN","VB","VBP"},
"cave-in":	{"NN"},
"cave-like":	{"JJ"},
"cave-men":	{"NNS"},
"caveat":	{"NN","VB","VBP"},
"caveated":	{"VBD","VBN"},
"caveating":	{"VBG"},
"caveats":	{"NNS","VBZ"},
"caveatted":	{"VBD","VBN"},
"caveatting":	{"VBG"},
"caved":	{"VBD","VBN"},
"cavell":	{"NN"},
"caveman":	{"NN"},
"cavemen":	{"NNS"},
"cavern":	{"NN","VB","VBP"},
"caverned":	{"VBD","VBN"},
"caverning":	{"VBG"},
"cavernous":	{"JJ"},
"caverns":	{"NNS","VBZ"},
"caves":	{"NNS","VBZ"},
"cavetto":	{"NN"},
"cavia":	{"NN"},
"caviar":	{"NN"},
"caviare":	{"NN"},
"caviidae":	{"NN"},
"cavil":	{"VB","VBP","NN"},
"caviled":	{"VBD","VBN"},
"caviler":	{"NN"},
"caviling":	{"VBG"},
"cavilled":	{"VBD","VBN"},
"caviller":	{"NN"},
"cavilling":	{"VBG"},
"cavils":	{"VBZ","NNS"},
"caving":	{"NN","VBG"},
"cavitied":	{"JJ"},
"cavities":	{"NNS"},
"cavity":	{"NN"},
"cavity-fighting":	{"JJ"},
"cavort":	{"VB","VBP"},
"cavorted":	{"VBD","VBN"},
"cavorting":	{"VBG"},
"cavorts":	{"VBZ"},
"cavum":	{"NN"},
"cavy":	{"NN"},
"caw":	{"NN","VB","VBP"},
"cawed":	{"VBD","VBN"},
"cawing":	{"VBG"},
"caws":	{"NNS","VBZ"},
"caxton":	{"NN"},
"cay":	{"NN"},
"cayenne":	{"NN"},
"cayman":	{"NN"},
"cayuga":	{"NN"},
"cayuse":	{"NN"},
"cazique":	{"NN"},
"cb-radio-style":	{"JJ"},
"cbc":	{"NN"},
"cbr":	{"NN"},
"cbs-owned":	{"JJ"},
"cc":	{"JJ","NN"},
"cc.":	{"NN","NNS"},
"ccc":	{"JJ"},
"cck-related":	{"JJ"},
"ccrc":	{"NN"},
"cd":	{"NN"},
"cd-r":	{"NN"},
"cd-rom":	{"NN"},
"cd-type":	{"JJ"},
"cd-wo":	{"NN"},
"cd4":	{"NN"},
"cd8":	{"NN"},
"cdc":	{"NN"},
"cdna":	{"NN"},
"ce":	{"NN","RB"},
"ceartaine":	{"JJ"},
"cease":	{"VB","VBP","NN"},
"cease-and-desist":	{"JJ","NN"},
"cease-fire":	{"NN"},
"ceased":	{"VBD","VBN"},
"ceasefire":	{"NN"},
"ceasefires":	{"NNS"},
"ceaseless":	{"JJ"},
"ceaselessly":	{"RB"},
"ceaselessness":	{"NN"},
"ceases":	{"VBZ","NNS"},
"ceasing":	{"VBG"},
"cebidae":	{"NN"},
"cebu":	{"NN"},
"cebuan":	{"NN"},
"cebuano":	{"NN"},
"cebuella":	{"NN"},
"cebus":	{"NN"},
"cecal":	{"JJ"},
"cecidomyidae":	{"NN"},
"cecilia":	{"NN"},
"cecity":	{"NN"},
"cecropia":	{"NN"},
"cecropiaceae":	{"NN"},
"cecum":	{"NN"},
"cedar":	{"NN"},
"cedar-roofed":	{"JJ"},
"cedar-scented":	{"JJ"},
"cedarbird":	{"NN"},
"cedarn":	{"JJ"},
"cedars":	{"NNS"},
"cedarwood":	{"NN"},
"cede":	{"VB","VBP"},
"ceded":	{"VBD","VBN"},
"cedes":	{"VBZ"},
"cedi":	{"NN"},
"cedilla":	{"NN"},
"cedillas":	{"NNS"},
"ceding":	{"VBG"},
"cedrela":	{"NN"},
"cedric":	{"NN"},
"cedrus":	{"NN"},
"cefadroxil":	{"NN"},
"cefobid":	{"NN"},
"cefoperazone":	{"NN"},
"cefotaxime":	{"NN"},
"ceftazidime":	{"NN"},
"ceftin":	{"NN"},
"ceftriaxone":	{"NN"},
"cefuroxime":	{"NN"},
"ceiba":	{"NN"},
"ceibo":	{"NN"},
"ceiled":	{"VBD","VBN"},
"ceilidh":	{"NN"},
"ceiling":	{"NN","VBG"},
"ceilinged":	{"JJ"},
"ceilings":	{"NNS"},
"ceils":	{"VBZ"},
"celandine":	{"NN"},
"celastraceae":	{"NN"},
"celastrus":	{"NN"},
"celebes":	{"NNS"},
"celebrant":	{"NN"},
"celebrants":	{"NNS"},
"celebrate":	{"VB","VBP"},
"celebrated":	{"VBD","JJ","VBN"},
"celebrater":	{"NN"},
"celebrates":	{"VBZ","NNS"},
"celebrating":	{"VBG"},
"celebration":	{"NN"},
"celebrations":	{"NNS"},
"celebrator":	{"NN"},
"celebrators":	{"NNS"},
"celebratory":	{"JJ"},
"celebrex":	{"NN"},
"celebrities":	{"NNS"},
"celebrity":	{"NN"},
"celebrity-driven":	{"JJ"},
"celebrity-oriented":	{"JJ"},
"celebutante":	{"NN"},
"celebutantes":	{"NNS"},
"celecoxib":	{"NN"},
"celeriac":	{"NN"},
"celerity":	{"NN"},
"celery":	{"NN"},
"celesbian":	{"NN"},
"celesbians":	{"NNS"},
"celesta":	{"NN"},
"celestial":	{"JJ"},
"celestite":	{"NN"},
"celiac":	{"JJ"},
"celibacy":	{"NN"},
"celibate":	{"JJ","NN"},
"celine":	{"NN"},
"celiocentesis":	{"NN"},
"celioma":	{"NN"},
"celioscopy":	{"NN"},
"cell":	{"NN"},
"cell-free":	{"JJ"},
"cell-like":	{"JJ"},
"cell-phone":	{"NN"},
"cell-phones":	{"NNS"},
"cellar":	{"NN"},
"cellarage":	{"NN"},
"cellared":	{"VBD","VBN"},
"cellaret":	{"NN"},
"cellaring":	{"VBG"},
"cellars":	{"NNS","VBZ"},
"cellblock":	{"NN"},
"celled":	{"VBD","VBN"},
"celling":	{"VBG"},
"cellini":	{"NN"},
"cellist":	{"NN"},
"cellists":	{"NNS"},
"cello":	{"NN"},
"cellophane":	{"NN"},
"cellphone":	{"NN"},
"cellphones":	{"NNS"},
"cells":	{"NNS","VBZ"},
"cellular":	{"JJ"},
"cellular-phone":	{"NN"},
"cellular-telephone":	{"JJ","NN"},
"cellularity":	{"NN"},
"cellulite":	{"NN"},
"cellulitis":	{"NN"},
"celluloid":	{"NN"},
"celluloids":	{"NNS"},
"cellulose":	{"NN"},
"celluloses":	{"NNS"},
"cellulosic":	{"JJ"},
"cellulosid":	{"JJ"},
"celom":	{"NN"},
"celoma":	{"NN"},
"celosia":	{"NN"},
"celt":	{"NN"},
"celtis":	{"NN"},
"celtuce":	{"NN"},
"cembalo":	{"NN"},
"cement":	{"NN","VB","VBP"},
"cement-and-glass":	{"JJ"},
"cement-makers":	{"NNS"},
"cement-making":	{"JJ"},
"cement-mixing":	{"JJ"},
"cement-truck":	{"JJ"},
"cemented":	{"VBN","VBD"},
"cementing":	{"VBG"},
"cementite":	{"NN"},
"cementitious":	{"JJ"},
"cements":	{"VBZ"},
"cementum":	{"NN"},
"cemeteries":	{"NNS"},
"cemetery":	{"NN"},
"cenchrus":	{"NN"},
"cenobite":	{"NN"},
"cenobitic":	{"JJ"},
"cenobitical":	{"JJ"},
"cenogenesis":	{"NN"},
"cenogenetic":	{"JJ"},
"cenotaph":	{"NN"},
"cenozoic":	{"JJ","NN"},
"cense":	{"VB","VBP"},
"censed":	{"VBD","VBN"},
"censer":	{"NN"},
"censes":	{"VBZ"},
"censing":	{"VBG"},
"censor":	{"VB","VBP","NN"},
"censored":	{"VBD","VBN"},
"censorial":	{"JJ"},
"censoring":	{"VBG"},
"censorious":	{"JJ"},
"censoriously":	{"RB"},
"censoriousness":	{"NN"},
"censors":	{"NNS","VBZ"},
"censorship":	{"NN"},
"censurable":	{"JJ"},
"censure":	{"NN","VB","VBP"},
"censured":	{"VBD","VBN"},
"censures":	{"NNS","VBZ"},
"censuring":	{"VBG"},
"census":	{"NN"},
"censuses":	{"NNS"},
"cent":	{"NN"},
"cent-a-bushel":	{"JJ"},
"cent-per-barrel":	{"JJ"},
"cental":	{"NN"},
"centare":	{"NN"},
"centas":	{"NN"},
"centaur":	{"NN"},
"centaurea":	{"NN"},
"centaurium":	{"NN"},
"centaurus":	{"NN"},
"centaury":	{"NN"},
"centavo":	{"NN"},
"centavos":	{"NNS","NN","JJ"},
"centenarian":	{"NN"},
"centenarians":	{"NNS"},
"centenary":	{"NN","JJ"},
"centennial":	{"JJ","NN"},
"centennially":	{"RB"},
"center":	{"NN","VB","VBP"},
"center-aisle":	{"NN"},
"center-field":	{"NN"},
"center-fire":	{"JJ"},
"center-left":	{"JJ","NN"},
"center-right":	{"JJ"},
"center-stage":	{"JJ"},
"center-vented":	{"JJ"},
"centerboard":	{"NN"},
"centered":	{"VBN","VBD","JJ"},
"centerfield":	{"NN"},
"centerfielder":	{"NN"},
"centerfold":	{"NN"},
"centering":	{"VBG"},
"centerline":	{"NN"},
"centerpiece":	{"NN"},
"centers":	{"NNS","VBZ"},
"centerstage":	{"NN"},
"centesimal":	{"JJ"},
"centesimo":	{"NN"},
"centesis":	{"NN"},
"centigrade":	{"JJ","NN"},
"centile":	{"NN"},
"centiliter":	{"NN"},
"centilitre":	{"NN"},
"centime":	{"NN"},
"centimeter":	{"NN"},
"centimeters":	{"NNS"},
"centimetre":	{"NN"},
"centimo":	{"NN"},
"centipede":	{"NN"},
"centner":	{"NN"},
"central":	{"JJ","NN"},
"central-bank":	{"NN","JJ"},
"central-city":	{"NN"},
"central-district":	{"JJ"},
"central-planning":	{"JJ"},
"centralheating":	{"NN"},
"centralisation":	{"NN"},
"centralise":	{"VB","VBP"},
"centralised":	{"JJ","VBD","VBN"},
"centralises":	{"VBZ"},
"centralising":	{"VBG"},
"centralism":	{"NN"},
"centralist":	{"NN"},
"centralistic":	{"JJ"},
"centralists":	{"NNS"},
"centrality":	{"NN"},
"centralization":	{"NN"},
"centralize":	{"VB","VBP"},
"centralized":	{"JJ","VBD","VBN"},
"centralizes":	{"VBZ"},
"centralizing":	{"VBG"},
"centrally":	{"RB"},
"centranthus":	{"NNS"},
"centrarchid":	{"NN"},
"centrarchidae":	{"NN"},
"centre":	{"NN","VBP","JJ","VB"},
"centre-right":	{"JJ"},
"centreboard":	{"NN"},
"centred":	{"VBD","VBN","JJ"},
"centrefold":	{"NN"},
"centrepiece":	{"NN"},
"centres":	{"VBZ"},
"centrex":	{"NN"},
"centric":	{"JJ"},
"centrical":	{"JJ"},
"centrifugal":	{"JJ"},
"centrifugally":	{"RB"},
"centrifugate":	{"VB","VBP"},
"centrifugation":	{"NN"},
"centrifuge":	{"NN","VB","VBP"},
"centrifuged":	{"VBD","VBN"},
"centrifuges":	{"NNS","VBZ"},
"centrifuging":	{"VBG"},
"centring":	{"VBG"},
"centriole":	{"NN"},
"centripetal":	{"JJ"},
"centriscidae":	{"NN"},
"centrism":	{"NN"},
"centrist":	{"JJ","NN"},
"centrocercus":	{"NNS"},
"centroid":	{"NN"},
"centroidal":	{"JJ"},
"centrolobium":	{"NN"},
"centromere":	{"NN"},
"centromeric":	{"JJ"},
"centropomidae":	{"NN"},
"centropomus":	{"NNS"},
"centropristis":	{"NN"},
"centropus":	{"NN"},
"centrosema":	{"NN"},
"centrosome":	{"NN"},
"centrosomic":	{"JJ"},
"centrospermae":	{"NN"},
"centrosymmetric":	{"JJ"},
"centrum":	{"NN"},
"cents":	{"NNS"},
"cents-a-share":	{"JJ"},
"cents-a-unit":	{"JJ"},
"cents-off":	{"JJ"},
"cents-per-hour":	{"JJ"},
"centum":	{"NN"},
"centunculus":	{"NNS"},
"centuried":	{"JJ"},
"centuries":	{"NNS"},
"centuries-old":	{"JJ"},
"centurion":	{"NN"},
"centurions":	{"NNS"},
"century":	{"NN"},
"century-old":	{"JJ"},
"ceo":	{"NN"},
"ceo-designate":	{"NN"},
"cephalalgia":	{"NN"},
"cephalanthera":	{"NN"},
"cephalaspid":	{"NN"},
"cephalaspida":	{"NN"},
"cephalexin":	{"NN"},
"cephalhematoma":	{"NN"},
"cephalic":	{"JJ"},
"cephalitis":	{"NN"},
"cephalobidae":	{"NN"},
"cephalochordata":	{"NN"},
"cephalochordate":	{"NN"},
"cephaloglycin":	{"NN"},
"cephalohematoma":	{"NN"},
"cephalometry":	{"NN"},
"cephalopod":	{"NN"},
"cephalopoda":	{"NN"},
"cephalopodan":	{"JJ"},
"cephalopterus":	{"NN"},
"cephaloridine":	{"NN"},
"cephalosporin":	{"NN"},
"cephalotaceae":	{"NN"},
"cephalotaxaceae":	{"NN"},
"cephalotaxus":	{"NN"},
"cephalothin":	{"NN"},
"cephalotus":	{"NNS"},
"cepheus":	{"NN"},
"cepphus":	{"NN"},
"cer":	{"NN"},
"cerambycidae":	{"NN"},
"ceramic":	{"JJ","NN"},
"ceramicist":	{"NN"},
"ceramics":	{"NN","NNS"},
"ceramist":	{"NN"},
"cerapteryx":	{"NN"},
"ceras":	{"NN"},
"cerastes":	{"NNS"},
"cerastium":	{"NN"},
"cerate":	{"NN"},
"ceratin":	{"NN"},
"ceratitis":	{"NN"},
"ceratodontidae":	{"NN"},
"ceratodus":	{"NN"},
"ceratonia":	{"NN"},
"ceratopetalum":	{"NN"},
"ceratophyllaceae":	{"NN"},
"ceratophyllum":	{"NN"},
"ceratopogon":	{"NN"},
"ceratopogonidae":	{"NN"},
"ceratopsia":	{"NN"},
"ceratopsian":	{"NN"},
"ceratopsidae":	{"NN"},
"ceratopteris":	{"NN"},
"ceratosaur":	{"NN"},
"ceratosaurus":	{"NN"},
"ceratostomataceae":	{"NN"},
"ceratostomella":	{"NN"},
"ceratotherium":	{"NN"},
"ceratozamia":	{"NN"},
"cerberus":	{"NN"},
"cercaria":	{"NN"},
"cercarial":	{"JJ"},
"cercidiphyllaceae":	{"NN"},
"cercidiphyllum":	{"NN"},
"cercidium":	{"NN"},
"cercis":	{"NN"},
"cercocebus":	{"NN"},
"cercopidae":	{"NN"},
"cercopithecidae":	{"NN"},
"cercopithecus":	{"NN"},
"cercospora":	{"NN"},
"cercosporella":	{"NN"},
"cere":	{"NN","VB"},
"cereal":	{"NN","JJ"},
"cereals":	{"NNS"},
"cerebellar":	{"JJ","NN"},
"cerebellum":	{"NN"},
"cerebral":	{"JJ","NN"},
"cerebrally":	{"RB"},
"cerebrate":	{"VB"},
"cerebrated":	{"VBD","VBN"},
"cerebration":	{"NN"},
"cerebromeningitis":	{"NN"},
"cerebrospinal":	{"JJ"},
"cerebrovascular":	{"JJ"},
"cerebrum":	{"NN"},
"cerecloth":	{"NN"},
"cerement":	{"NN"},
"ceremonial":	{"JJ","NN"},
"ceremonially":	{"RB"},
"ceremonies":	{"NNS"},
"ceremonious":	{"JJ"},
"ceremoniously":	{"RB"},
"ceremoniousness":	{"NN"},
"ceremony":	{"NN"},
"ceres":	{"NNS"},
"ceresin":	{"NN"},
"cereus":	{"NN"},
"cerevisiae":	{"NN"},
"cerf":	{"NN"},
"ceric":	{"JJ"},
"ceriman":	{"NN"},
"cerise":	{"NN","JJ"},
"cerium":	{"NN"},
"cerivastatin":	{"NN"},
"cernuous":	{"JJ"},
"cero":	{"NN"},
"cerous":	{"JJ"},
"ceroxylon":	{"NN"},
"cert":	{"NN"},
"certain":	{"JJ","PRP"},
"certainly":	{"RB"},
"certainties":	{"NNS"},
"certainty":	{"NN"},
"certhia":	{"NN"},
"certhiidae":	{"NN"},
"certifiable":	{"JJ"},
"certificate":	{"NN","VB","VBP"},
"certificate-of-need":	{"NN"},
"certificated":	{"JJ","VBD","VBN"},
"certificates":	{"NNS","VBZ"},
"certificating":	{"VBG"},
"certification":	{"NN"},
"certificatory":	{"JJ"},
"certified":	{"JJ","VBN","VBD"},
"certifies":	{"VBZ"},
"certify":	{"VB","VBP"},
"certifying":	{"VBG"},
"certin":	{"NN"},
"certiorari":	{"NN"},
"certitude":	{"NN"},
"certitudes":	{"NNS"},
"cerulean":	{"JJ","NN"},
"cerumen":	{"NN"},
"ceruminous":	{"JJ"},
"ceruse":	{"NN"},
"cerussite":	{"NN"},
"cervantes":	{"NNS"},
"cervelat":	{"NN"},
"cervical":	{"JJ"},
"cervicitis":	{"NN"},
"cervid":	{"NN"},
"cervidae":	{"NN"},
"cervine":	{"JJ"},
"cervix":	{"NN"},
"cervus":	{"NNS"},
"ceryle":	{"NN"},
"cesar":	{"NN"},
"cesarean":	{"JJ","NN"},
"cesarian":	{"JJ","NN"},
"cesium":	{"NN"},
"cesium-137":	{"NN"},
"cespitose":	{"JJ"},
"cessation":	{"NN"},
"cession":	{"NN"},
"cesspit":	{"NN"},
"cesspool":	{"NN"},
"cesspools":	{"NNS"},
"cestida":	{"NN"},
"cestidae":	{"NN"},
"cestoda":	{"NN"},
"cestode":	{"NN"},
"cestrum":	{"NN"},
"cestum":	{"NN"},
"cetacea":	{"NN"},
"cetacean":	{"JJ","NN"},
"cetaceous":	{"JJ"},
"cetchup":	{"NN"},
"cetera":	{"NN","FW"},
"ceterach":	{"NN"},
"ceteras":	{"FW"},
"cetonia":	{"NN"},
"cetoniidae":	{"NN"},
"cetorhinidae":	{"NN"},
"cetorhinus":	{"NN"},
"cetraria":	{"NN"},
"cetrimide":	{"NN"},
"cetus":	{"NN"},
"cewa":	{"NN"},
"ceylon":	{"NN"},
"ceylonese":	{"JJ"},
"ceylonite":	{"NN"},
"cezanne":	{"NN"},
"cf":	{"VB","VBP"},
"cf.":	{"VB","VBP"},
"cftr":	{"NN"},
"cg":	{"NN"},
"cgs":	{"NNS"},
"ch'i":	{"NN"},
"ch'in":	{"NN"},
"ch'ing":	{"NN"},
"cha-cha":	{"NN","VB","VBP"},
"cha-cha-cha":	{"NN","VB","VBP"},
"cha-cha-chaed":	{"VBD","VBN"},
"cha-cha-chaing":	{"VBG"},
"cha-cha-chas":	{"NNS","VBZ"},
"cha-chaed":	{"VBD","VBN"},
"cha-chaing":	{"VBG"},
"cha-chas":	{"NNS","VBZ"},
"chabad":	{"NN"},
"chabad-lubavitch":	{"NN"},
"chabasite":	{"NN"},
"chabazite":	{"NN"},
"chachalaca":	{"NN"},
"chachka":	{"NN"},
"chacma":	{"NN"},
"chadar":	{"NN"},
"chaddar":	{"NN"},
"chadian":	{"JJ","NN"},
"chadic":	{"NN"},
"chadlock":	{"NN"},
"chador":	{"NN"},
"chads":	{"NNS"},
"chaenactis":	{"NN"},
"chaenomeles":	{"NN"},
"chaenopsis":	{"NN"},
"chaeronea":	{"NN"},
"chaeta":	{"NN"},
"chaetal":	{"JJ"},
"chaetodipterus":	{"NN"},
"chaetodon":	{"NN"},
"chaetodontidae":	{"NN"},
"chaetognath":	{"NN"},
"chaetognatha":	{"NN"},
"chaetognathan":	{"JJ"},
"chaetognathous":	{"JJ"},
"chafe":	{"VB","VBP","NN"},
"chafed":	{"VBD","VBN"},
"chafes":	{"VBZ"},
"chaff":	{"NN","VB","VBP"},
"chaffed":	{"VBD","VBN"},
"chaffer":	{"VB","VBP"},
"chaffered":	{"VBD","VBN"},
"chaffering":	{"VBG"},
"chaffers":	{"VBZ"},
"chaffinch":	{"NN"},
"chaffinches":	{"NNS"},
"chaffing":	{"VBG"},
"chafflike":	{"JJ"},
"chaffs":	{"VBZ"},
"chaffy":	{"JJ"},
"chafing":	{"VBG"},
"chaga":	{"NN"},
"chagall":	{"NN"},
"chagatai":	{"NN"},
"chagga":	{"NN"},
"chagrin":	{"NN","VBP","VB"},
"chagrined":	{"JJ","VBD","VBN"},
"chagrining":	{"VBG"},
"chagrins":	{"VBZ"},
"chahta":	{"NN"},
"chai":	{"NN"},
"chain":	{"NN","VBP","VB"},
"chain-link":	{"NN","JJ"},
"chain-of-command":	{"NN"},
"chain-reaction":	{"NN"},
"chain-smoke":	{"VB","VBP"},
"chain-smoked":	{"VBD","VBN"},
"chain-smoker":	{"NN"},
"chain-smokers":	{"NNS"},
"chain-smokes":	{"VBZ"},
"chain-smoking":	{"VBG"},
"chain-store":	{"NN"},
"chain-stores":	{"NNS"},
"chained":	{"JJ","VBD","VBN"},
"chaining":	{"VBG"},
"chainlike":	{"JJ","NN"},
"chains":	{"NNS","VBZ"},
"chainsaw":	{"NN"},
"chair":	{"NN","VB","VBP"},
"chairbound":	{"JJ"},
"chaired":	{"VBD","VBN"},
"chairing":	{"VBG","NN"},
"chairlift":	{"NN"},
"chairman":	{"NN","VB","VBP"},
"chairman-elect":	{"NN"},
"chairmaned":	{"VBD","VBN"},
"chairmaning":	{"VBG"},
"chairmanned":	{"VBD","VBN"},
"chairmanning":	{"VBG"},
"chairmans":	{"VBZ"},
"chairmanship":	{"NN"},
"chairmanships":	{"NNS"},
"chairmen":	{"NNS"},
"chairperson":	{"NN"},
"chairpersons":	{"NNS"},
"chairs":	{"NNS","VBZ"},
"chairwoman":	{"NN"},
"chaise":	{"NN"},
"chait":	{"NN"},
"chaja":	{"NN"},
"chalaza":	{"NN"},
"chalazion":	{"NN"},
"chalcanthite":	{"NN"},
"chalcedon":	{"NN"},
"chalcedony":	{"NN"},
"chalcid":	{"NN"},
"chalcidae":	{"NN"},
"chalcidfly":	{"NN"},
"chalcididae":	{"NN"},
"chalcis":	{"NNS"},
"chalcocite":	{"NN"},
"chalcopyrite":	{"NN"},
"chalcostigma":	{"NN"},
"chaldaea":	{"NN"},
"chaldaean":	{"JJ","NN"},
"chaldea":	{"NN"},
"chaldean":	{"JJ","NN"},
"chaldee":	{"JJ","NN"},
"chaldron":	{"NN"},
"chalet":	{"NN"},
"chalice":	{"NN"},
"chalk":	{"NN","VB","VBP"},
"chalk-white":	{"JJ"},
"chalkboard":	{"NN"},
"chalked":	{"VBN","VBD"},
"chalkiness":	{"NN"},
"chalking":	{"VBG"},
"chalkpit":	{"NN"},
"chalks":	{"VBZ"},
"chalkstone":	{"NN"},
"chalky":	{"JJ"},
"challah":	{"NN"},
"challenge":	{"NN","VB","VBP"},
"challengeable":	{"JJ"},
"challenged":	{"JJ","VBN","VBD"},
"challenger":	{"NN"},
"challengers":	{"NNS"},
"challenges":	{"NNS","VBZ"},
"challenging":	{"VBG","JJ"},
"challis":	{"NN"},
"chalons":	{"NNS"},
"chalons-sur-marne":	{"NN"},
"chalybeate":	{"JJ"},
"chalybite":	{"NN"},
"chamaea":	{"NN"},
"chamaecrista":	{"NN"},
"chamaecyparis":	{"NN"},
"chamaecytisus":	{"NNS"},
"chamaedaphne":	{"NN"},
"chamaeleo":	{"NN"},
"chamaeleon":	{"NN"},
"chamaeleonidae":	{"NN"},
"chamaeleontidae":	{"NN"},
"chamaemelum":	{"NN"},
"chamber":	{"NN"},
"chamber-music":	{"JJ"},
"chambered":	{"JJ","VBD","VBN"},
"chambering":	{"VBG"},
"chamberlain":	{"NN"},
"chambermaid":	{"NN"},
"chambermaids":	{"NNS"},
"chamberpot":	{"NN"},
"chambers":	{"NNS","VBZ"},
"chambray":	{"NN"},
"chambre":	{"FW"},
"chameleon":	{"NN"},
"chameleons":	{"NNS"},
"chamfer":	{"NN","VB","VBP"},
"chamfered":	{"VBD","VBN"},
"chamfering":	{"VBG"},
"chamfers":	{"NNS","VBZ"},
"chamfron":	{"NN"},
"chammy":	{"NN"},
"chamois":	{"NN","NNS"},
"chamomile":	{"NN"},
"chamosite":	{"NN"},
"champ":	{"NN","VB","VBP"},
"champagne":	{"NN"},
"champagne-ardenne":	{"NN"},
"champagnes":	{"NNS"},
"champaign":	{"NN"},
"champed":	{"VBD","VBN"},
"champerty":	{"NN"},
"champing":	{"VBG"},
"champion":	{"NN","JJ","VB","VBP"},
"championed":	{"VBD","VBN"},
"championing":	{"VBG","NN"},
"champions":	{"NNS","VBZ"},
"championship":	{"NN"},
"championship-team":	{"JJ"},
"championships":	{"NNS"},
"champlain":	{"NN"},
"champleve":	{"JJ"},
"champollion":	{"NN"},
"champs":	{"NNS","VBZ"},
"chanal":	{"NN"},
"chanar":	{"NN"},
"chance":	{"NN","VB","VBP","JJ"},
"chance-medley":	{"NN"},
"chanced":	{"VBD","VBN"},
"chanceful":	{"JJ"},
"chancel":	{"NN"},
"chancellery":	{"NN"},
"chancellor":	{"NN"},
"chancellorship":	{"NN"},
"chancellorsville":	{"NN"},
"chanceries":	{"NNS"},
"chancery":	{"NN"},
"chances":	{"NNS","VBZ"},
"chancing":	{"VBG"},
"chancre":	{"NN"},
"chancroid":	{"NN"},
"chancroidal":	{"JJ"},
"chancrous":	{"JJ"},
"chancy":	{"JJ","NN"},
"chandelier":	{"NN"},
"chandeliers":	{"NNS"},
"chandelle":	{"NN","VB","VBP"},
"chandelled":	{"VBD","VBN"},
"chandelles":	{"NNS","VBZ"},
"chandelling":	{"VBG"},
"chandi":	{"NN"},
"chandler":	{"NN"},
"chandlery":	{"NN"},
"chanfron":	{"NN"},
"chang":	{"NN"},
"changan":	{"NN"},
"change":	{"NN","VB","VBP"},
"change-of-pace":	{"NN"},
"change-over":	{"NN"},
"change-ringing":	{"NN"},
"change-up":	{"NN"},
"changeability":	{"NN"},
"changeable":	{"JJ"},
"changeableness":	{"NN"},
"changed":	{"VBN","VBD","JJ"},
"changeful":	{"JJ"},
"changefulness":	{"NN"},
"changeless":	{"JJ"},
"changelessness":	{"NN"},
"changeling":	{"NN"},
"changeover":	{"NN"},
"changer":	{"NN"},
"changes":	{"NNS","VBZ"},
"changeup":	{"NN"},
"changeups":	{"NNS"},
"changing":	{"VBG","JJ","NN"},
"changjiang":	{"NN"},
"changtzu":	{"NN"},
"channel":	{"NN","VB","VBP"},
"channel-surf":	{"VB","VBP"},
"channel-surfed":	{"VBD","VBN"},
"channel-surfing":	{"VBG","NN"},
"channel-surfs":	{"VBZ"},
"channel-type":	{"NN"},
"channel-zapping":	{"JJ"},
"channeled":	{"VBN","VBD"},
"channeling":	{"VBG"},
"channelisation":	{"NN"},
"channelise":	{"VB"},
"channelization":	{"NN"},
"channelize":	{"VB"},
"channelled":	{"VBN","VBD"},
"channelling":	{"VBG"},
"channels":	{"NNS","VBZ"},
"channidae":	{"NN"},
"channukah":	{"NN"},
"channukkah":	{"NN"},
"chanoyu":	{"NN"},
"chans":	{"NNS"},
"chansons":	{"NNS"},
"chant":	{"NN","VB","VBP"},
"chantarelle":	{"NN"},
"chanted":	{"VBD","VBN"},
"chanter":	{"NN"},
"chanterelle":	{"NN"},
"chanteuse":	{"NN"},
"chantey":	{"NN"},
"chantier":	{"FW"},
"chanting":	{"VBG"},
"chantlike":	{"JJ"},
"chantries":	{"NNS"},
"chantry":	{"NN"},
"chants":	{"NNS","VBZ"},
"chanty":	{"NN"},
"chanukah":	{"NN"},
"chanukkah":	{"NN"},
"chaos":	{"NN"},
"chaotic":	{"JJ"},
"chaotically":	{"RB"},
"chap":	{"NN","VB","VBP"},
"chap.":	{"NN"},
"chaparral":	{"NN"},
"chapati":	{"NN"},
"chapatti":	{"NN"},
"chapeau":	{"NN"},
"chapel":	{"NN"},
"chapel-like":	{"JJ"},
"chapelgoer":	{"NN"},
"chapels":	{"NNS"},
"chaperon":	{"NN","VB","VBP"},
"chaperone":	{"NN","VB","VBP"},
"chaperoned":	{"VBD","VBN"},
"chaperones":	{"NNS","VBZ"},
"chaperoning":	{"VBG"},
"chapfallen":	{"JJ"},
"chapiter":	{"NN"},
"chaplain":	{"NN"},
"chaplaincies":	{"NNS"},
"chaplaincy":	{"NN"},
"chaplains":	{"NNS"},
"chaplainship":	{"NN"},
"chaplet":	{"NN"},
"chapleted":	{"JJ"},
"chaplin-like":	{"JJ"},
"chapman":	{"NN"},
"chapped":	{"JJ","VBD","VBN"},
"chapping":	{"VBG"},
"chaps":	{"NNS","VBZ"},
"chapter":	{"NN"},
"chapterhouse":	{"NN"},
"chapters":	{"NNS"},
"chapultepec":	{"NN"},
"char":	{"VB","VBP","NN"},
"char-broiled":	{"JJ"},
"char-grilled":	{"JJ"},
"chara":	{"NN"},
"charabanc":	{"NN"},
"characeae":	{"NN"},
"characid":	{"NN"},
"characidae":	{"NN"},
"characin":	{"NN"},
"characinidae":	{"NN"},
"character":	{"NN","VB","VBP"},
"character-education":	{"NN"},
"character-recognition":	{"NN"},
"charactered":	{"VBD","VBN"},
"charactering":	{"VBG"},
"characterisation":	{"NN"},
"characterisations":	{"NNS"},
"characterise":	{"VB"},
"characterised":	{"VBD","VBN"},
"characterises":	{"VBZ"},
"characterising":	{"VBG"},
"characteristic":	{"JJ","NN"},
"characteristically":	{"RB"},
"characteristics":	{"NNS"},
"characterization":	{"NN"},
"characterizations":	{"NNS"},
"characterize":	{"VB","VBP"},
"characterized":	{"VBD","VBN"},
"characterizes":	{"VBZ"},
"characterizing":	{"VBG"},
"characterless":	{"JJ"},
"characters":	{"NNS","VBZ"},
"charade":	{"NN"},
"charades":	{"NNS"},
"charadrii":	{"NN"},
"charadriidae":	{"NN"},
"charadriiformes":	{"NNS"},
"charadrius":	{"NNS"},
"charales":	{"NNS"},
"charbroil":	{"VB","VBP"},
"charbroiled":	{"VBD","VBN","JJ"},
"charbroiling":	{"VBG"},
"charbroils":	{"VBZ"},
"charcoal":	{"NN","JJ","VB","VBP"},
"charcoal-broiled":	{"JJ"},
"charcoal-gray":	{"JJ"},
"charcoal-grey":	{"JJ"},
"charcoaled":	{"VBD","VBN"},
"charcoaling":	{"VBG"},
"charcoals":	{"VBZ"},
"charcot":	{"NN"},
"charcuterie":	{"NN"},
"chard":	{"NN"},
"chardonnay-sipping":	{"JJ"},
"charge":	{"NN","VB","VBP"},
"charge-a-plate":	{"NN"},
"charge-card":	{"JJ"},
"charge-excess":	{"NN"},
"charge-offs":	{"NNS"},
"chargeable":	{"JJ"},
"charged":	{"VBN","VBD","JJ"},
"chargeman":	{"NN"},
"charger":	{"NN"},
"charges":	{"NNS","VBZ"},
"charging":	{"VBG","NN"},
"chari":	{"NN"},
"chari-nile":	{"NN"},
"charily":	{"RB"},
"charina":	{"NN"},
"chariness":	{"NN"},
"chariot":	{"NN"},
"charioted":	{"VBD","VBN"},
"charioteer":	{"NN"},
"charioting":	{"VBG"},
"chariots":	{"NNS","VBZ"},
"charisma":	{"NN"},
"charismatic":	{"JJ","NN"},
"charitable":	{"JJ"},
"charitableness":	{"NN"},
"charitably":	{"RB"},
"charities":	{"NNS"},
"charity":	{"NN"},
"charivari":	{"NN"},
"charlatan":	{"NN"},
"charlatanism":	{"NN"},
"charlatanry":	{"NN"},
"charlatans":	{"NNS"},
"charlemagne":	{"NN"},
"charleroi":	{"NN"},
"charlestown":	{"NN"},
"charley-horse":	{"NN"},
"charlock":	{"NN"},
"charlottetown":	{"NN"},
"charlton":	{"NN"},
"charm":	{"NN","VB","VBP"},
"charmed":	{"VBD","VBN","JJ"},
"charmer":	{"NN"},
"charmers":	{"NNS"},
"charming":	{"JJ","VBG"},
"charmingly":	{"RB"},
"charms":	{"NNS","VBZ"},
"charnel":	{"NN","JJ"},
"charolais":	{"NNS"},
"charon":	{"NN"},
"charophyceae":	{"NN"},
"charr":	{"NN","NNS"},
"charred":	{"JJ","VBD","VBN"},
"charring":	{"VBG","NN"},
"charronia":	{"NN"},
"charrs":	{"NNS"},
"chars":	{"VBZ","NNS"},
"chart":	{"NN","VB","VBP"},
"chart-room":	{"JJ"},
"chartaceos":	{"NNS"},
"chartaceous":	{"JJ"},
"charted":	{"VBD","VBN"},
"charter":	{"NN","VB","VBP"},
"charter-boat":	{"NN"},
"charter-shipping":	{"JJ"},
"charter-type":	{"JJ"},
"chartered":	{"JJ","VBD","VBN"},
"charterhouse":	{"NN"},
"chartering":	{"VBG"},
"charters":	{"VBZ","NNS"},
"charting":	{"NN","VBG"},
"chartings":	{"NNS"},
"chartism":	{"NN"},
"chartist":	{"NN"},
"chartists":	{"NNS"},
"chartless":	{"JJ"},
"chartres":	{"NNS"},
"chartreuse":	{"NN"},
"chartroom":	{"NN"},
"charts":	{"NNS","VBZ"},
"charwoman":	{"NN"},
"chary":	{"JJ"},
"charybdis":	{"NN"},
"chase":	{"VB","NN","VBP"},
"chased":	{"VBD","VBN"},
"chaser":	{"NN"},
"chasers":	{"NNS"},
"chases":	{"NNS","VBZ"},
"chasid":	{"NN"},
"chasidic":	{"JJ"},
"chasidim":	{"NN"},
"chasidism":	{"NN"},
"chasing":	{"VBG","NN"},
"chasm":	{"NN"},
"chasse":	{"NN"},
"chassid":	{"NN"},
"chassidic":	{"JJ"},
"chassidim":	{"NN"},
"chassidism":	{"NN"},
"chassis":	{"NN","NNS"},
"chaste":	{"JJ","NN"},
"chastely":	{"RB"},
"chasten":	{"VB","VBP"},
"chastened":	{"VBD","VBN","JJ"},
"chasteness":	{"NN"},
"chastening":	{"VBG","JJ"},
"chastens":	{"VBZ"},
"chastise":	{"VB","VBP"},
"chastised":	{"VBD","VBN"},
"chastisement":	{"NN"},
"chastises":	{"VBZ"},
"chastising":	{"VBG"},
"chastity":	{"NN"},
"chasuble":	{"NN"},
"chat":	{"NN","VBP","VB"},
"chateau":	{"NN"},
"chateau-thierry":	{"NN"},
"chateaubriand":	{"NN"},
"chateaux":	{"NNS"},
"chatelaine":	{"NN"},
"chateura":	{"NN"},
"chatoyant":	{"JJ"},
"chatroom":	{"NN"},
"chatrooms":	{"NNS"},
"chats":	{"NNS","VBZ"},
"chattahoochee":	{"NN"},
"chattanooga":	{"NN"},
"chatte":	{"FW"},
"chatted":	{"VBD","VBN"},
"chattel":	{"NN"},
"chattels":	{"NNS"},
"chatter":	{"VB","VBP","NN"},
"chatter-proofed":	{"JJ"},
"chatterbox":	{"NN"},
"chatterboxes":	{"NNS"},
"chattered":	{"VBD","VBN"},
"chatterer":	{"NN"},
"chatterers":	{"NNS"},
"chattering":	{"NN","VBG"},
"chatters":	{"VBZ"},
"chattily":	{"RB"},
"chatting":	{"NN","VBG"},
"chatty":	{"JJ","NN"},
"chaucer":	{"NN"},
"chauffeur":	{"NN","VB","VBP"},
"chauffeur-driven":	{"JJ"},
"chauffeured":	{"VBD","VBN"},
"chauffeuring":	{"VBG"},
"chauffeurs":	{"NNS","VBZ"},
"chauffeuse":	{"NN"},
"chaulmoogra":	{"NN"},
"chaulmugra":	{"NN"},
"chauna":	{"NN"},
"chauvinism":	{"NN"},
"chauvinist":	{"NN","JJ"},
"chauvinistic":	{"JJ"},
"chauvinisticlly":	{"RB"},
"chauvinists":	{"NNS"},
"chaw":	{"VB","NN"},
"chawbacon":	{"NN"},
"chawed":	{"VBD","VBN"},
"chawing":	{"VBG"},
"chaws":	{"VBZ"},
"che":	{"NN"},
"cheap":	{"JJ","RB","NN"},
"cheap-jack":	{"NN"},
"cheap-money":	{"NN"},
"cheap-shot":	{"JJ"},
"cheap-to-make":	{"JJ"},
"cheap-wine":	{"JJ"},
"cheapen":	{"VB","VBP"},
"cheapened":	{"VBD","VBN"},
"cheapening":	{"VBG"},
"cheapens":	{"VBZ"},
"cheaper":	{"JJR"},
"cheapest":	{"JJS"},
"cheapjack":	{"JJ","NN"},
"cheaply":	{"RB"},
"cheapness":	{"NN"},
"cheapskate":	{"NN"},
"cheat":	{"VB","NN","VBP"},
"cheated":	{"VBD","VBN"},
"cheater":	{"NN"},
"cheaters":	{"NNS"},
"cheatgrass":	{"NN"},
"cheating":	{"NN","VBG"},
"cheats":	{"VBZ"},
"chebab":	{"NN"},
"chechen":	{"JJ","NN"},
"chechenia":	{"NN"},
"chechnya":	{"NN"},
"check":	{"VB","NN","VBP"},
"check-in":	{"JJ","NN"},
"check-ins":	{"NNS"},
"check-kiting":	{"JJ"},
"check-out":	{"JJ","NN"},
"check-processing":	{"JJ","NN"},
"check-ups":	{"NNS"},
"checkbook":	{"NN"},
"checkbooks":	{"NNS"},
"checked":	{"VBN","VBD","JJ"},
"checker":	{"NN"},
"checkerberry":	{"NN"},
"checkerbloom":	{"NN"},
"checkerboard":	{"NN","JJ"},
"checkerboards":	{"NNS"},
"checkered":	{"JJ","VBN","VBD"},
"checkering":	{"VBG"},
"checkers":	{"NNS","VBZ"},
"checking":	{"VBG","NN"},
"checking-account":	{"JJ"},
"checklist":	{"NN"},
"checkmate":	{"NN","VB","VBP"},
"checkmated":	{"VBD","VBN"},
"checkmates":	{"VBZ"},
"checkmating":	{"VBG"},
"checkout":	{"NN"},
"checkout-stand":	{"NN"},
"checkpoint":	{"NN"},
"checkpoints":	{"NNS"},
"checkrein":	{"NN"},
"checkroom":	{"NN"},
"checkrow":	{"VB"},
"checks":	{"NNS","VBZ"},
"checksum":	{"NN"},
"checkup":	{"NN"},
"checkups":	{"NNS"},
"cheddar":	{"NN"},
"cheek":	{"NN","VBP","VB"},
"cheek-by-jowl":	{"JJ"},
"cheek-to-cheek":	{"JJ"},
"cheek-to-jowl":	{"RB"},
"cheekbone":	{"NN"},
"cheekbones":	{"NNS"},
"cheeked":	{"VBD","VBN"},
"cheekily":	{"RB"},
"cheekiness":	{"NN"},
"cheeking":	{"VBG"},
"cheekpiece":	{"NN"},
"cheeks":	{"NNS","VBZ"},
"cheeky":	{"JJ"},
"cheep":	{"NN","VB","VBP"},
"cheeped":	{"VBD","VBN"},
"cheeping":	{"VBG"},
"cheeps":	{"VBZ"},
"cheer":	{"VB","NN","VBP"},
"cheere":	{"VBP","VB"},
"cheered":	{"VBD","VBN"},
"cheerer":	{"NN"},
"cheerful":	{"JJ"},
"cheerfully":	{"RB"},
"cheerfulness":	{"NN"},
"cheerily":	{"RB"},
"cheering":	{"JJ","VBG"},
"cheerio":	{"NN"},
"cheerios-brand":	{"JJ"},
"cheerlead":	{"NN"},
"cheerleader":	{"NN"},
"cheerleaders":	{"NNS"},
"cheerleading":	{"NN"},
"cheerless":	{"JJ"},
"cheerlessly":	{"RB"},
"cheerlessness":	{"NN"},
"cheers":	{"UH","NNS","VBZ"},
"cheery":	{"JJ","NN"},
"cheese":	{"NN","VBP","VB"},
"cheeseboard":	{"NN"},
"cheeseburger":	{"NN"},
"cheeseburgers":	{"NNS"},
"cheesecake":	{"NN"},
"cheesecloth":	{"NN"},
"cheesed":	{"VBD","VBN"},
"cheeseflower":	{"NN"},
"cheeseheads":	{"NNS"},
"cheeselike":	{"JJ"},
"cheesemonger":	{"NN"},
"cheesemongers":	{"NNS"},
"cheeseparing":	{"NN"},
"cheeses":	{"VBZ","NNS"},
"cheesing":	{"VBG"},
"cheesy":	{"JJ"},
"cheetah":	{"NN"},
"cheetal":	{"JJ"},
"cheever":	{"NN"},
"cheewink":	{"NN"},
"chef":	{"NN"},
"chef-d'oeuvre":	{"NN"},
"chefs":	{"NNS"},
"cheilanthes":	{"NNS"},
"cheilitis":	{"NN"},
"cheiloschisis":	{"NN"},
"cheilosis":	{"NN"},
"cheiranthus":	{"NN"},
"chekhov":	{"NN"},
"chekhovian":	{"JJ"},
"chekov":	{"NN"},
"chekovian":	{"JJ"},
"chela":	{"NN"},
"chelas":	{"NNS"},
"chelatable":	{"JJ"},
"chelate":	{"JJ","VB","VBP","NN"},
"chelated":	{"VBD","VBN"},
"chelates":	{"VBZ"},
"chelating":	{"VBG"},
"chelation":	{"NN"},
"chelicera":	{"NN"},
"cheliceral":	{"JJ"},
"chelicerata":	{"NN"},
"chelicerate":	{"JJ"},
"chelicerates":	{"NNS"},
"chelicerous":	{"JJ"},
"chelidonium":	{"NN"},
"chelifer":	{"NN"},
"cheliferous":	{"JJ"},
"cheloid":	{"NN"},
"chelone":	{"NN"},
"chelonethida":	{"NN"},
"chelonia":	{"NN"},
"chelonian":	{"JJ","NN"},
"chelonidae":	{"NN"},
"cheloniidae":	{"NN"},
"chelyabinsk":	{"NN"},
"chelydra":	{"NN"},
"chelydridae":	{"NN"},
"chemakuan":	{"NN"},
"chemakum":	{"NN"},
"chemcial":	{"JJ"},
"chemic":	{"JJ"},
"chemical":	{"NN","JJ"},
"chemical-and-resource":	{"JJ"},
"chemical-arms":	{"NNS","JJ"},
"chemical-arms-control":	{"JJ"},
"chemical-bomb":	{"NN"},
"chemical-industry":	{"NN"},
"chemical-weapon":	{"NN"},
"chemical-weapons":	{"NNS","JJ"},
"chemically":	{"RB"},
"chemicals":	{"NNS"},
"chemicals-industry":	{"NN"},
"chemiluminescence":	{"NN"},
"chemiluminescent":	{"JJ"},
"chemise":	{"NN"},
"chemisorb":	{"VB"},
"chemisorption":	{"NN"},
"chemisorptive":	{"JJ"},
"chemist":	{"NN"},
"chemist's":	{"NN"},
"chemist-turned-entrepreneur":	{"NN"},
"chemistries":	{"NNS"},
"chemistry":	{"NN"},
"chemists":	{"NNS"},
"chemnitz":	{"NN"},
"chemoimmunology":	{"NN"},
"chemokines":	{"NNS"},
"chemophobia":	{"NN"},
"chemoreceptive":	{"JJ"},
"chemoreceptor":	{"NN"},
"chemosis":	{"NN"},
"chemosorption":	{"NN"},
"chemosorptive":	{"JJ"},
"chemosurgery":	{"NN"},
"chemosynthesis":	{"NN"},
"chemotaxis":	{"NN"},
"chemotherapeutic":	{"JJ"},
"chemotherapeutical":	{"JJ"},
"chemotherapy":	{"NN","JJ"},
"chemulpo":	{"NN"},
"chen":	{"NN"},
"chenfish":	{"NN"},
"chenille":	{"NN"},
"chennai":	{"NN"},
"chenopodiaceae":	{"NN"},
"chenopodiales":	{"NNS"},
"chenopodium":	{"NN"},
"cheops":	{"NNS"},
"cheque":	{"NN"},
"chequebook":	{"NN"},
"chequer":	{"NN","VB"},
"chequered":	{"JJ"},
"cherbourg":	{"NN"},
"cheremis":	{"NNS"},
"cheremiss":	{"NN"},
"cherepovets":	{"NNS"},
"cherimolla":	{"NN"},
"cherimoya":	{"NN"},
"cherish":	{"VB","NN","VBP"},
"cherished":	{"VBD","VBN"},
"cherishes":	{"VBZ","NNS"},
"cherishing":	{"VBG"},
"chermidae":	{"NN"},
"chernobyl":	{"NN"},
"chernobyl-type":	{"JJ"},
"cherokees":	{"NNS"},
"cheroot":	{"NN"},
"cherries":	{"NNS"},
"cherry":	{"NN","JJ"},
"cherry-flavored":	{"JJ"},
"cherry-red":	{"JJ"},
"cherry-sized":	{"JJ"},
"cherrystone":	{"NN"},
"chert":	{"NN"},
"cherty":	{"JJ"},
"cherub":	{"NN"},
"cherubic":	{"JJ"},
"cherubim":	{"NNS"},
"cherubini":	{"NN"},
"cherubs":	{"NNS"},
"chervil":	{"NN"},
"chesapeake":	{"NN"},
"chess":	{"NN"},
"chessboard":	{"NN"},
"chessman":	{"NN"},
"chest":	{"NN"},
"chest-back-lat-shoulder":	{"JJ"},
"chest-back-shoulder":	{"JJ"},
"chest-high":	{"JJ"},
"chest-swelling":	{"JJ"},
"chester":	{"NN"},
"chesterfield":	{"NN"},
"chesterton":	{"NN"},
"chestnut":	{"NN","JJ"},
"chestnut-brown":	{"JJ"},
"chestnut-colored":	{"JJ"},
"chestnut-coloured":	{"JJ"},
"chestnuts":	{"NNS"},
"chests":	{"NNS"},
"chesty":	{"NN","JJ"},
"chet":	{"NN"},
"chetah":	{"NN"},
"chetrum":	{"NN"},
"cheung":	{"NN"},
"cheval-de-frise":	{"NN"},
"chevalier":	{"NN"},
"chevaux":	{"NN"},
"chevaux-de-frise":	{"NN"},
"cheviot":	{"NN"},
"cheviots":	{"NNS"},
"chevre":	{"NN"},
"chevron":	{"NN"},
"chevrotain":	{"NN"},
"chevvy":	{"VB"},
"chevy":	{"VB"},
"chew":	{"VB","NN","VBP"},
"chewa":	{"NN"},
"chewable":	{"JJ"},
"chewed":	{"VBD","VBN"},
"chewer":	{"NN"},
"chewing":	{"NN","VBG"},
"chewink":	{"NN"},
"chews":	{"VBZ","NNS"},
"chewy":	{"JJ","NN"},
"cheyenne":	{"NN"},
"cheyennes":	{"NNS"},
"chg":	{"NN"},
"chi":	{"NN"},
"chi-chi":	{"FW","JJ"},
"chian":	{"JJ"},
"chianti":	{"NN"},
"chiaroscuro":	{"NN"},
"chiasm":	{"NN"},
"chiasma":	{"NN"},
"chiasmal":	{"JJ"},
"chiasmatic":	{"JJ"},
"chiasmic":	{"JJ"},
"chiasmus":	{"NN"},
"chic":	{"JJ","NN"},
"chicago-area":	{"JJ"},
"chicago-based":	{"JJ"},
"chicago-centric":	{"JJ"},
"chicago-style":	{"JJ"},
"chicane":	{"NN"},
"chicanery":	{"NN"},
"chicano":	{"NN","JJ"},
"chicanos":	{"NNS"},
"chicha":	{"NN"},
"chichewa":	{"NN"},
"chichi":	{"JJ","NN"},
"chichipe":	{"NN"},
"chick":	{"NN"},
"chickadee":	{"NN"},
"chickamauga":	{"NN"},
"chickasaw":	{"NN"},
"chicken":	{"NN","JJ","VBP","VB"},
"chicken-and-egg":	{"JJ"},
"chicken-breasted":	{"JJ"},
"chicken-fight":	{"VB"},
"chicken-mutilating":	{"JJ"},
"chicken-wire":	{"JJ","NN"},
"chickened":	{"VBD","VBN"},
"chickenfeed":	{"NN"},
"chickenfight":	{"VB"},
"chickenhawk":	{"NN"},
"chickenhawks":	{"NNS"},
"chickenhearted":	{"JJ"},
"chickening":	{"VBG"},
"chickenpox":	{"NN"},
"chickens":	{"NNS","VBZ"},
"chickenshit":	{"NN","JJ"},
"chickeree":	{"NN"},
"chickpea":	{"NN"},
"chicks":	{"NNS"},
"chickweed":	{"NN"},
"chicle":	{"NN"},
"chicly":	{"RB"},
"chicness":	{"NN"},
"chico":	{"NN"},
"chicory":	{"NN"},
"chicot":	{"NN"},
"chid":	{"VBD","VBN"},
"chidden":	{"VBN"},
"chide":	{"VB","VBP"},
"chided":	{"VBD","VBN"},
"chides":	{"VBZ"},
"chiding":	{"VBG"},
"chief":	{"JJ","NN"},
"chiefdom":	{"NN"},
"chiefdoms":	{"NNS"},
"chiefly":	{"RB"},
"chiefs":	{"NNS","JJ"},
"chieftain":	{"NN"},
"chieftaincy":	{"NN"},
"chieftains":	{"NNS"},
"chieftainship":	{"NN"},
"chien":	{"NN"},
"chiffon":	{"NN"},
"chiffonier":	{"NN"},
"chigetai":	{"NN"},
"chigger":	{"NN"},
"chiggerflower":	{"NN"},
"chiggers":	{"NNS"},
"chignon":	{"NN"},
"chigoe":	{"NN"},
"chihiro":	{"FW"},
"chihuahua":	{"NN"},
"chilblain":	{"NN"},
"chilblained":	{"JJ"},
"chilblains":	{"NNS"},
"child":	{"NN"},
"child-abuse":	{"NN","JJ"},
"child-as-required-yuppie-possession":	{"NN"},
"child-bearing":	{"NN"},
"child-care":	{"JJ","NN"},
"child-centered":	{"JJ"},
"child-cloud":	{"NN"},
"child-development":	{"NN"},
"child-face":	{"NN"},
"child-oriented":	{"JJ"},
"child-parent":	{"JJ"},
"child-proofed":	{"VBD","VBN"},
"child-proofing":	{"VBG"},
"child-proofs":	{"VBZ"},
"child-protection":	{"NN"},
"child-rearing":	{"NN"},
"child-safety":	{"JJ"},
"childbearing":	{"NN"},
"childbed":	{"NN"},
"childbirth":	{"NN"},
"childcare":	{"NN"},
"childhood":	{"NN"},
"childish":	{"JJ"},
"childishly":	{"RB"},
"childishness":	{"NN"},
"childless":	{"JJ"},
"childlessness":	{"NN"},
"childlike":	{"JJ","NN"},
"childly":	{"JJ"},
"childproof":	{"JJ","VB","VBP"},
"childrearing":	{"NN"},
"children":	{"NNS"},
"chiles":	{"NNS"},
"chili":	{"NN"},
"chiliad":	{"NN"},
"chiliasm":	{"NN"},
"chiliast":	{"NN"},
"chiliastic":	{"JJ"},
"chilies":	{"NNS"},
"chill":	{"NN","VB","VBP","JJ"},
"chillax":	{"VB","VBP"},
"chillaxed":	{"VBD","VBN"},
"chillaxes":	{"VBZ"},
"chillaxing":	{"VBG","JJ"},
"chilled":	{"JJ","VBD","VBN"},
"chiller":	{"NN"},
"chilli":	{"NN"},
"chillier":	{"JJR"},
"chillies":	{"NNS"},
"chilliest":	{"JJS"},
"chilliness":	{"NN"},
"chilling":	{"JJ","VBG"},
"chillingly":	{"RB"},
"chills":	{"NNS","VBZ"},
"chilly":	{"JJ"},
"chiloe":	{"NN"},
"chilomastix":	{"NN"},
"chilomeniscus":	{"NN"},
"chilomycterus":	{"NN"},
"chilopoda":	{"NN"},
"chilopsis":	{"NN"},
"chiluba":	{"NN"},
"chimaera":	{"NN"},
"chimaeridae":	{"NN"},
"chimakum":	{"NN"},
"chimaphila":	{"NN"},
"chimariko":	{"NN"},
"chimborazo":	{"NN"},
"chime":	{"NN","VB","VBP"},
"chimed":	{"VBD","VBN"},
"chimera":	{"NN"},
"chimera-chasing":	{"JJ"},
"chimeral":	{"JJ"},
"chimeric":	{"JJ"},
"chimerical":	{"JJ"},
"chimes":	{"NNS","VBZ"},
"chiming":	{"VBG"},
"chimiques":	{"FW"},
"chimney":	{"NN"},
"chimneypiece":	{"NN"},
"chimneypot":	{"NN"},
"chimneys":	{"NNS"},
"chimneystack":	{"NN"},
"chimneysweep":	{"NN"},
"chimneysweeper":	{"NN"},
"chimonanthus":	{"NN"},
"chimp":	{"NN"},
"chimpanzee":	{"NN"},
"chimpanzees":	{"NNS"},
"chimps":	{"NNS"},
"chimwini":	{"NN"},
"chin":	{"NN","VB","VBP"},
"chin-out":	{"JJ"},
"chin-up":	{"NN"},
"chin-ups":	{"NNS"},
"chin-use":	{"VB"},
"chin-wag":	{"NN"},
"chin-wagging":	{"NN"},
"china":	{"NN"},
"china-bound":	{"JJ"},
"china-investment":	{"JJ"},
"china-watcher":	{"NN"},
"chinaberry":	{"NN"},
"chinaman":	{"NN"},
"chinaware":	{"NN"},
"chincapin":	{"NN"},
"chinch":	{"NN"},
"chincherinchee":	{"NN"},
"chinchilla":	{"NN"},
"chinchillidae":	{"NN"},
"chinchillon":	{"NN"},
"chinchona":	{"NN"},
"chinchy":	{"JJ"},
"chine":	{"NN","VB","VBP"},
"chined":	{"VBD","VBN"},
"chines":	{"NNS"},
"chinese-american-canadian":	{"JJ"},
"chinese-british":	{"JJ"},
"chinese-inspired":	{"JJ"},
"chinese-red":	{"JJ"},
"chinese-style":	{"NN"},
"chingpo":	{"NN"},
"chining":	{"VBG"},
"chink":	{"NN","VB","VBP"},
"chinkapin":	{"NN"},
"chinked":	{"VBD","VBN"},
"chinking":	{"VBG"},
"chinks":	{"NNS","VBZ"},
"chinless":	{"JJ"},
"chinned":	{"VBD","VBN"},
"chinning":	{"NN","VBG"},
"chino":	{"NN"},
"chinoiserie":	{"NN"},
"chinook":	{"NN"},
"chinookan":	{"NN"},
"chinooks":	{"NNS"},
"chinos":	{"NNS"},
"chinquapin":	{"NN"},
"chins":	{"NNS","VBZ"},
"chintz":	{"NN"},
"chintzily":	{"RB"},
"chintzy":	{"JJ","NN"},
"chiococca":	{"NN"},
"chionanthus":	{"NN"},
"chios":	{"NNS"},
"chip":	{"NN","VB","VBP"},
"chip-design":	{"JJ"},
"chip-making":	{"NN"},
"chip-packaging":	{"NN"},
"chipboard":	{"NN"},
"chipewyan":	{"NN"},
"chipmaker":	{"NN"},
"chipmakers":	{"NNS"},
"chipmunk":	{"NN"},
"chipolata":	{"NN"},
"chipotle":	{"NN"},
"chipped":	{"VBN","VBD","JJ"},
"chipper":	{"JJ"},
"chippewa":	{"NN"},
"chippewaian":	{"NN"},
"chippewyan":	{"NN"},
"chipping":	{"VBG"},
"chips":	{"NNS","VBZ"},
"chiral":	{"JJ"},
"chiralgia":	{"NN"},
"chirality":	{"NN"},
"chirico":	{"NN"},
"chirk":	{"VB"},
"chirked":	{"VBD","VBN"},
"chirking":	{"VBG"},
"chirks":	{"VBZ"},
"chirocephalus":	{"NNS"},
"chirography":	{"NN"},
"chirology":	{"NN"},
"chiromance":	{"VB"},
"chiromancer":	{"NN"},
"chiromancy":	{"NN"},
"chiromantic":	{"JJ"},
"chiron":	{"NN"},
"chironomidae":	{"NN"},
"chironomus":	{"NNS"},
"chiropodist":	{"NN"},
"chiropody":	{"NN"},
"chiropractic":	{"NN","JJ"},
"chiropractor":	{"NN"},
"chiroptera":	{"NN"},
"chiropteran":	{"NN"},
"chirp":	{"NN","VB","VBP"},
"chirped":	{"VBD","VBN"},
"chirpier":	{"JJR"},
"chirpiest":	{"JJS"},
"chirpily":	{"RB"},
"chirpiness":	{"NN"},
"chirping":	{"VBG"},
"chirps":	{"VBZ","NNS"},
"chirpy":	{"JJ"},
"chirr":	{"NN"},
"chirrup":	{"NN","VB","VBP"},
"chirruped":	{"VBD","VBN"},
"chirruping":	{"VBG"},
"chirrups":	{"VBZ"},
"chisel":	{"NN","VB","VBP"},
"chisel-like":	{"JJ"},
"chiseled":	{"JJ","VBD","VBN"},
"chiseler":	{"NN"},
"chiseling":	{"VBG"},
"chiselled":	{"VBD","VBN","JJ"},
"chiseller":	{"NN"},
"chiselling":	{"VBG"},
"chisels":	{"NNS","VBZ"},
"chishona":	{"NN"},
"chisinau":	{"NN"},
"chislev":	{"NN"},
"chit":	{"NN"},
"chit-chat":	{"NN","VB","VBP"},
"chit-chated":	{"VBD","VBN"},
"chit-chating":	{"VBG"},
"chit-chats":	{"NNS","VBZ"},
"chitchat":	{"NN","VB","VBP"},
"chitchats":	{"NNS","VBZ"},
"chitchatted":	{"VBD","VBN"},
"chitchatting":	{"VBG"},
"chitin":	{"NN"},
"chitinous":	{"JJ"},
"chitlings":	{"NNS"},
"chitlins":	{"NNS"},
"chiton":	{"NN"},
"chittagong":	{"NN"},
"chittamwood":	{"NN"},
"chitter":	{"VB","VBP"},
"chittered":	{"VBD","VBN"},
"chittering":	{"VBG"},
"chitterling":	{"NN"},
"chitterlings":	{"NNS"},
"chitters":	{"VBZ"},
"chittimwood":	{"NN"},
"chivalric":	{"JJ"},
"chivalrous":	{"JJ"},
"chivalrously":	{"RB"},
"chivalry":	{"NN"},
"chivaree":	{"NN"},
"chive":	{"NN"},
"chives":	{"NNS"},
"chivied":	{"VBD","VBN"},
"chivies":	{"VBZ"},
"chivvied":	{"VBD","VBN"},
"chivvies":	{"VBZ"},
"chivvy":	{"VB","VBP"},
"chivvying":	{"VBG"},
"chivy":	{"VB"},
"chivying":	{"NN","VBG"},
"chiwere":	{"NN"},
"chlamydeous":	{"JJ"},
"chlamydera":	{"NN"},
"chlamydia":	{"NN"},
"chlamydiaceae":	{"NN"},
"chlamydial":	{"JJ"},
"chlamydomonadaceae":	{"NN"},
"chlamydomonas":	{"NNS"},
"chlamydosaurus":	{"NN"},
"chlamydospore":	{"NN"},
"chlamyphore":	{"NN"},
"chlamyphorus":	{"NN"},
"chlamys":	{"NNS"},
"chloasma":	{"NN"},
"chlor-trimeton":	{"NN"},
"chlorambucil":	{"NN"},
"chloramine":	{"NN"},
"chloramine-t":	{"NN"},
"chloramphenicol":	{"NN"},
"chloranthaceae":	{"NN"},
"chloranthus":	{"NN"},
"chlorate":	{"NN"},
"chlorazepate":	{"NN"},
"chlordiazepoxide":	{"NN"},
"chlorella":	{"NN"},
"chlorenchyma":	{"NN"},
"chlorhexidine":	{"NN"},
"chloride":	{"NN"},
"chlorides":	{"NNS"},
"chlorinate":	{"VB","VBP"},
"chlorinated":	{"VBD","VBN"},
"chlorinates":	{"VBZ"},
"chlorinating":	{"VBG"},
"chlorination":	{"NN"},
"chlorine":	{"NN"},
"chlorine-carbon":	{"NN"},
"chlorinity":	{"NN"},
"chloris":	{"NNS"},
"chlorite":	{"NN"},
"chloroacetophenone":	{"NN"},
"chlorobenzene":	{"NN"},
"chlorobenzylidenemalononitrile":	{"NN"},
"chlorococcales":	{"NNS"},
"chlorococcum":	{"NN"},
"chlorofluorocarbon":	{"NN"},
"chlorofluorocarbons":	{"NNS"},
"chloroform":	{"VB","VBP","NN"},
"chloroformed":	{"VBD","VBN"},
"chloroforming":	{"VBG"},
"chloroforms":	{"VBZ"},
"chlorofucin":	{"NN"},
"chloromycetin":	{"NN"},
"chlorophis":	{"NN"},
"chlorophoneus":	{"NNS"},
"chlorophthalmidae":	{"NN"},
"chlorophyceae":	{"NN"},
"chlorophyl":	{"NN"},
"chlorophyll":	{"NN"},
"chlorophyllose":	{"JJ"},
"chlorophyllous":	{"JJ"},
"chlorophyta":	{"NN"},
"chlorophyte":	{"NN"},
"chloropicrin":	{"NN"},
"chloroplast":	{"NN"},
"chloroprene":	{"NN"},
"chloroquine":	{"NN"},
"chlorosis":	{"NN"},
"chlorothiazide":	{"NN"},
"chlorotic":	{"JJ"},
"chloroxylon":	{"NN"},
"chlorpromazine":	{"NN"},
"chlorpyrifos":	{"NNS"},
"chlortetracycline":	{"NN"},
"chlorthalidone":	{"NN"},
"chlorura":	{"NN"},
"choanocyte":	{"NN"},
"choc":	{"NN"},
"choc-ice":	{"NN"},
"chock":	{"NN","VB","VBP","RB"},
"chock-a-block":	{"JJ"},
"chock-full":	{"JJ"},
"chockablock":	{"NN"},
"chocked":	{"VBD","VBN"},
"chockful":	{"JJ"},
"chockfull":	{"JJ"},
"chocking":	{"VBG"},
"chocks":	{"NNS","VBZ"},
"chocolate":	{"NN","JJ"},
"chocolate-brown":	{"JJ"},
"chocolate-colored":	{"JJ"},
"chocolate-coloured":	{"JJ"},
"chocolates":	{"NNS"},
"choctaw":	{"NN"},
"choeronycteris":	{"NNS"},
"choice":	{"NN","JJ"},
"choiceness":	{"NN"},
"choices":	{"NNS"},
"choicest":	{"NN"},
"choir":	{"NN","VB","VBP"},
"choirboy":	{"NN"},
"choirboys":	{"NNS"},
"choired":	{"VBD","VBN"},
"choiring":	{"VBG"},
"choirmaster":	{"NN"},
"choirmasters":	{"NNS"},
"choirs":	{"NNS","VBZ"},
"choke":	{"VB","VBP","NN"},
"choke-full":	{"JJ"},
"chokecherries":	{"NNS"},
"chokecherry":	{"NN"},
"choked":	{"JJ","VBD","VBN"},
"chokedamp":	{"NN"},
"chokehold":	{"NN"},
"chokepoint":	{"NN"},
"choker":	{"NN"},
"chokers":	{"NNS"},
"chokes":	{"VBZ","NNS"},
"chokey":	{"NN"},
"choking":	{"VBG"},
"choky":	{"NN","JJ"},
"cholangiography":	{"NN"},
"cholangitis":	{"NN"},
"chole":	{"NN"},
"cholecalciferol":	{"NN"},
"cholecystectomy":	{"NN"},
"cholecystitis":	{"NN"},
"cholecystokinin":	{"NN"},
"choledoch":	{"NN"},
"cholelithiasis":	{"NN"},
"cholelithotomy":	{"NN"},
"choler":	{"NN"},
"cholera":	{"NN"},
"choleraic":	{"JJ"},
"choleric":	{"JJ"},
"cholestasis":	{"NN"},
"cholesterin":	{"NN"},
"cholesterol":	{"NN"},
"cholesterol-fearing":	{"JJ"},
"cholesterol-free":	{"JJ"},
"cholesterol-lowering":	{"JJ"},
"cholesterol-reduction":	{"NN"},
"cholesterol-rich":	{"JJ"},
"choline":	{"NN"},
"cholinergic":	{"JJ"},
"cholinesterase":	{"NN"},
"cholla":	{"NN"},
"choloepus":	{"NN"},
"cholorfluorocarbons":	{"NNS"},
"chomp":	{"VB","VBP"},
"chomped":	{"VBD","VBN"},
"chomping":	{"VBG"},
"chomps":	{"VBZ"},
"chomsky":	{"NN"},
"chon":	{"NN"},
"chondrichthian":	{"NN"},
"chondrichthyes":	{"NNS"},
"chondrify":	{"VB"},
"chondrin":	{"NN"},
"chondriosome":	{"NN"},
"chondrite":	{"NN"},
"chondritic":	{"JJ"},
"chondrodystrophy":	{"NN"},
"chondroma":	{"NN"},
"chondrosarcoma":	{"NN"},
"chondrule":	{"NN"},
"chondrus":	{"NN"},
"chong":	{"NN"},
"chongqing":	{"NN"},
"choo-choo":	{"NN"},
"choose":	{"VB","VBP"},
"chooser":	{"NN"},
"chooses":	{"VBZ"},
"choosey":	{"JJ"},
"choosier":	{"JJR"},
"choosiest":	{"JJS"},
"choosiness":	{"NN"},
"choosing":	{"VBG"},
"choosy":	{"JJ"},
"chop":	{"VB","VBP","NN"},
"chop-chop":	{"RB","UH"},
"chopfallen":	{"JJ"},
"chophouse":	{"NN"},
"chopine":	{"NN"},
"chopped":	{"VBD","VBN","JJ"},
"chopper":	{"NN"},
"choppers":	{"NNS"},
"choppier":	{"JJR"},
"choppiest":	{"JJS"},
"choppiness":	{"NN"},
"chopping":	{"VBG"},
"choppy":	{"JJ"},
"chops":	{"NNS","VBZ"},
"chopsteak":	{"NN"},
"chopstick":	{"NN"},
"chopsticks":	{"NNS"},
"choragic":	{"JJ"},
"choragus":	{"NN"},
"choral":	{"JJ","NN"},
"chorale":	{"NN"},
"chorally":	{"RB"},
"chord":	{"NN"},
"chordal":	{"JJ"},
"chordamesoderm":	{"NN"},
"chordata":	{"NN"},
"chordate":	{"NN","JJ"},
"chorded":	{"VBD","VBN"},
"chordeiles":	{"NNS"},
"chording":	{"VBG"},
"chorditis":	{"NN"},
"chordomesoderm":	{"NN"},
"chordophone":	{"NN"},
"chordospartium":	{"NN"},
"chords":	{"NNS","VBZ"},
"chore":	{"NN"},
"chorea":	{"NN"},
"choreograph":	{"VB","VBP"},
"choreographed":	{"VBD","VBN"},
"choreographer":	{"NN"},
"choreographers":	{"NNS"},
"choreographic":	{"JJ"},
"choreographing":	{"VBG"},
"choreographs":	{"VBZ"},
"choreography":	{"NN"},
"chores":	{"NNS"},
"choric":	{"JJ"},
"chorine":	{"NN"},
"chorines":	{"NNS"},
"choring":	{"NN","VBG"},
"chorioallantois":	{"NN"},
"choriomeningitis":	{"NN"},
"chorion":	{"NN"},
"chorionic":	{"JJ","NN"},
"chorioretinitis":	{"NN"},
"choriotis":	{"NN"},
"chorister":	{"NN"},
"chorizagrotis":	{"NN"},
"chorizema":	{"NN"},
"chorizo":	{"NN"},
"choroid":	{"NN","JJ"},
"chortle":	{"VB","VBP","NN"},
"chortled":	{"VBD","VBN"},
"chortles":	{"VBZ","NNS"},
"chortling":	{"VBG"},
"chorus":	{"NN","VB","VBP"},
"chorus-girl":	{"NN"},
"chorused":	{"VBD","VBN"},
"choruses":	{"VBZ","NNS"},
"chorusing":	{"VBG"},
"chose":	{"VBD"},
"chosen":	{"VBN","JJ"},
"chou":	{"NN"},
"chough":	{"NN"},
"chouise":	{"NN"},
"chouse":	{"NN","VB","VBP"},
"choused":	{"VBD","VBN"},
"chouses":	{"NNS","VBZ"},
"chousing":	{"VBG"},
"chow":	{"NN","VB","VBP"},
"chowchow":	{"NN"},
"chowder":	{"NN"},
"chowders":	{"NNS"},
"chowed":	{"VBD","VBN"},
"chowing":	{"VBG"},
"chows":	{"NNS","VBZ"},
"chrestomathy":	{"NN"},
"chrism":	{"NN"},
"chrisom":	{"NN"},
"christ's-thorn":	{"NN"},
"christ-like":	{"JJ"},
"christchurch":	{"NN"},
"christella":	{"NN"},
"christen":	{"VB","VBP"},
"christendom":	{"NN"},
"christened":	{"VBD","VBN"},
"christening":	{"NN","VBG"},
"christenings":	{"NNS"},
"christens":	{"VBZ"},
"christian-dominated":	{"JJ"},
"christian-moslem":	{"JJ"},
"christiania":	{"NN"},
"christianisation":	{"NN"},
"christianise":	{"VB"},
"christianity":	{"NN"},
"christianization":	{"NN"},
"christianize":	{"VB"},
"christianizing":	{"VBG"},
"christianly":	{"JJ"},
"christie":	{"NN"},
"christless":	{"JJ"},
"christlike":	{"JJ"},
"christly":	{"JJ"},
"christmas-like":	{"JJ"},
"christmas-season":	{"NN"},
"christmas-time":	{"JJ"},
"christmas-tree":	{"NN"},
"christmasberry":	{"NN"},
"christmastide":	{"NN"},
"christmastime":	{"NN"},
"christological":	{"JJ"},
"christology":	{"NN"},
"christopher":	{"NN"},
"christsake":	{"NN"},
"christy":	{"NN"},
"chroma":	{"NN"},
"chromaesthesia":	{"NN"},
"chromate":	{"NN"},
"chromatic":	{"JJ"},
"chromatically":	{"RB"},
"chromaticity":	{"NN"},
"chromatics":	{"NNS"},
"chromatid":	{"NN"},
"chromatin":	{"NN"},
"chromatinic":	{"JJ"},
"chromatism":	{"NN"},
"chromatogram":	{"NN"},
"chromatographic":	{"JJ"},
"chromatographical":	{"JJ"},
"chromatographically":	{"RB"},
"chromatography":	{"NN"},
"chrome":	{"NN"},
"chromed":	{"VBD","VBN"},
"chromes":	{"VBZ"},
"chromesthesia":	{"NN"},
"chromic":	{"JJ"},
"chroming":	{"VBG"},
"chromite":	{"NN"},
"chromium":	{"NN"},
"chromium-plate":	{"VB"},
"chromium-plated":	{"JJ"},
"chromium-substituted":	{"JJ"},
"chromoblastomycosis":	{"NN"},
"chromogen":	{"NN"},
"chromolithography":	{"NN"},
"chromophore":	{"NN"},
"chromoplast":	{"NN"},
"chromosomal":	{"NN","JJ"},
"chromosome":	{"NN"},
"chromosomes":	{"NNS"},
"chromosphere":	{"NN"},
"chronic":	{"JJ","NN"},
"chronically":	{"RB"},
"chronicle":	{"NN","VB","VBP"},
"chronicled":	{"VBD","VBN"},
"chronicler":	{"NN"},
"chroniclers":	{"NNS"},
"chronicles":	{"NNS","VBZ"},
"chronicling":	{"VBG"},
"chronograph":	{"NN"},
"chronological":	{"JJ"},
"chronologically":	{"RB"},
"chronologise":	{"VB"},
"chronologize":	{"VB"},
"chronology":	{"NN"},
"chronometer":	{"NN"},
"chronoperates":	{"NNS"},
"chronoscope":	{"NN"},
"chrysalis":	{"NN"},
"chrysalises":	{"NNS"},
"chrysanthemum":	{"NN"},
"chrysanthemums":	{"NNS"},
"chrysaora":	{"NN"},
"chrysarobin":	{"NN"},
"chrysemys":	{"NNS"},
"chrysler-brand":	{"JJ"},
"chrysobalanus":	{"NN"},
"chrysoberyl":	{"NN"},
"chrysochloridae":	{"NN"},
"chrysochloris":	{"NN"},
"chrysolepis":	{"NN"},
"chrysolite":	{"NN"},
"chrysolophus":	{"NN"},
"chrysomelid":	{"NN"},
"chrysomelidae":	{"NN"},
"chrysophrys":	{"NNS"},
"chrysophyceae":	{"NN"},
"chrysophyllum":	{"NN"},
"chrysophyta":	{"NN"},
"chrysopid":	{"NN"},
"chrysopidae":	{"NN"},
"chrysoprase":	{"NN"},
"chrysopsis":	{"NN"},
"chrysosplenium":	{"NN"},
"chrysothamnus":	{"NN"},
"chrysotherapy":	{"NN"},
"chrysotile":	{"NN"},
"chthonian":	{"JJ"},
"chthonic":	{"JJ"},
"chuang-tzu":	{"NN"},
"chub":	{"NN"},
"chubbiness":	{"NN"},
"chubby":	{"JJ","NN"},
"chuck":	{"VB","VBP","NN"},
"chuck-a-luck":	{"NN"},
"chuck-full":	{"JJ"},
"chuck-will's-widow":	{"NN"},
"chucked":	{"VBD","VBN"},
"chucker-out":	{"NN"},
"chuckhole":	{"NN"},
"chucking":	{"VBG"},
"chuckle":	{"VB","VBP","NN"},
"chuckled":	{"VBD","VBN"},
"chuckles":	{"NNS","VBZ"},
"chuckling":	{"NN","VBG"},
"chucks":	{"VBZ","NNS"},
"chuckwalla":	{"NN"},
"chuddar":	{"NN"},
"chufa":	{"NN"},
"chuff":	{"NN","VB","VBP"},
"chuffed":	{"JJ","VBD","VBN"},
"chuffing":	{"VBG"},
"chuffs":	{"VBZ"},
"chug":	{"VB","VBP","NN"},
"chugged":	{"VBD","VBN"},
"chugging":	{"VBG"},
"chugs":	{"VBZ"},
"chukaku-ha":	{"NN"},
"chukchi":	{"NN"},
"chukka":	{"NN"},
"chukker":	{"NN"},
"chukker-brown":	{"JJ"},
"chum":	{"NN","VB","VBP"},
"chummed":	{"VBD","VBN"},
"chumminess":	{"NN"},
"chumming":	{"VBG"},
"chummy":	{"JJ","NN"},
"chump":	{"NN","VB","VBP"},
"chumped":	{"VBD","VBN"},
"chumping":	{"VBG"},
"chumps":	{"NNS","VBZ"},
"chums":	{"NNS","VBZ"},
"chunga":	{"NN"},
"chungking":	{"NN"},
"chunk":	{"NN"},
"chunked":	{"VBD","VBN"},
"chunking":	{"NN","VBG"},
"chunks":	{"NNS","VBZ"},
"chunky":	{"JJ","NN"},
"chunnel":	{"NN"},
"church":	{"NN","NNP"},
"church-goers":	{"NNS"},
"church-going":	{"JJ"},
"church-owned":	{"JJ"},
"church-state":	{"NN"},
"church-supported":	{"JJ"},
"churched":	{"VBD","VBN"},
"churches":	{"NNS","VBZ"},
"churchgoer":	{"NN"},
"churchgoers":	{"NNS"},
"churchgoing":	{"NN"},
"churchill":	{"NN"},
"churchillian":	{"JJ"},
"churching":	{"VBG"},
"churchly":	{"RB"},
"churchman":	{"NN"},
"churchmen":	{"NNS"},
"churchwarden":	{"NN"},
"churchyard":	{"NN"},
"churidars":	{"NNS"},
"churl":	{"NN"},
"churlish":	{"JJ","NN"},
"churlishly":	{"RB"},
"churn":	{"VB","VBP","NN"},
"churned":	{"VBD","VBN"},
"churned-up":	{"JJ"},
"churning":	{"JJ","VBG"},
"churns":	{"VBZ","NNS"},
"churr":	{"VB"},
"churred":	{"VBD","VBN"},
"churrigueresco":	{"JJ"},
"churrigueresque":	{"JJ"},
"churring":	{"VBG"},
"churrs":	{"VBZ"},
"chute":	{"NN"},
"chute-the-chute":	{"NN"},
"chutes":	{"NNS"},
"chutney":	{"NN"},
"chutneys":	{"NNS"},
"chutzpa":	{"NN"},
"chutzpah":	{"NN"},
"chutzpanik":	{"NN"},
"chuvash":	{"NN"},
"chylaceous":	{"JJ"},
"chyle":	{"NN"},
"chylifactive":	{"JJ"},
"chylifactory":	{"JJ"},
"chyliferous":	{"JJ"},
"chylific":	{"JJ"},
"chyloderma":	{"NN"},
"chylomicron":	{"NN"},
"chylous":	{"JJ"},
"chyme":	{"NN"},
"chymosin":	{"NN"},
"chytridiaceae":	{"NN"},
"chytridiales":	{"NNS"},
"chytridiomycetes":	{"NNS"},
"ci":	{"NN"},
"cialis":	{"NN"},
"cials":	{"NNS"},
"ciao":	{"UH"},
"ciardi":	{"NN"},
"ciba-geigy":	{"JJ"},
"cibotium":	{"NN"},
"cicada":	{"NN"},
"cicadas":	{"NNS"},
"cicadellidae":	{"NN"},
"cicadidae":	{"NN"},
"cicala":	{"NN"},
"cicatrice":	{"NN"},
"cicatrise":	{"VB"},
"cicatrix":	{"NN"},
"cicatrize":	{"VB"},
"cicer":	{"NN"},
"cicero":	{"NN"},
"cicerone":	{"NN"},
"ciceronian":	{"JJ"},
"cichlid":	{"NN"},
"cichlidae":	{"NN"},
"cichorium":	{"NN"},
"cicindelidae":	{"NN"},
"ciconia":	{"NN"},
"ciconiidae":	{"NN"},
"ciconiiformes":	{"NNS"},
"cicuta":	{"NN"},
"cider":	{"NN"},
"ciderpress":	{"NN"},
"cigar":	{"NN"},
"cigar-chomping":	{"JJ"},
"cigar-making":	{"JJ"},
"cigar-shaped":	{"JJ"},
"cigaret":	{"NN"},
"cigarette":	{"NN"},
"cigarette-tax":	{"NN"},
"cigarette-vending":	{"JJ"},
"cigarettes":	{"NNS"},
"cigarfish":	{"NN"},
"cigarillo":	{"NN"},
"cigars":	{"NNS"},
"cilantro":	{"NN"},
"cilia":	{"NNS"},
"cilial":	{"JJ"},
"ciliary":	{"JJ"},
"ciliata":	{"NN"},
"ciliate":	{"JJ","NN"},
"ciliated":	{"JJ"},
"ciliates":	{"NNS"},
"cilioflagellata":	{"NN"},
"ciliophora":	{"NN"},
"ciliophoran":	{"NN"},
"cilium":	{"NN"},
"cim":	{"NN"},
"cimabue":	{"NN"},
"cimarron":	{"NN"},
"cimetidine":	{"NN"},
"cimex":	{"NN"},
"cimicidae":	{"NN"},
"cimicifuga":	{"NN"},
"cimmerian":	{"JJ"},
"cinch":	{"NN","VB","VBP"},
"cinched":	{"VBD","VBN"},
"cinches":	{"VBZ"},
"cinching":	{"VBG"},
"cinchona":	{"NN"},
"cinchonine":	{"NN"},
"cincinnati":	{"NN"},
"cincinnati-based":	{"JJ"},
"cincinnatus":	{"NNS"},
"cinclidae":	{"NN"},
"cinclus":	{"NN"},
"cincture":	{"NN"},
"cinder":	{"NN"},
"cinder-block":	{"JJ"},
"cinderblock":	{"NN"},
"cindered":	{"VBD","VBN"},
"cindering":	{"VBG"},
"cinders":	{"NNS","VBZ"},
"cine-camera":	{"NN"},
"cine-film":	{"NN"},
"cinema":	{"NN"},
"cinematic":	{"JJ","NN"},
"cinematise":	{"VB"},
"cinematize":	{"VB"},
"cinematographer":	{"NN"},
"cinematography":	{"NN"},
"cinerama":	{"NN"},
"cineraria":	{"NN"},
"cinerarium":	{"NN"},
"cinerary":	{"JJ"},
"cingulum":	{"NN"},
"cinnabar":	{"NN"},
"cinnamene":	{"NN"},
"cinnamomum":	{"NN"},
"cinnamon":	{"NN","JJ"},
"cinnamon-colored":	{"JJ"},
"cinnamon-coloured":	{"JJ"},
"cinnamon-red":	{"JJ"},
"cinnamon-scented":	{"JJ"},
"cinq":	{"FW"},
"cinque":	{"NN"},
"cinquefoil":	{"NN"},
"cio":	{"NN"},
"cipher":	{"NN","VB","VBP"},
"ciphered":	{"VBD","VBN"},
"ciphering":	{"VBG"},
"ciphers":	{"NNS","VBZ"},
"cipro":	{"NN"},
"ciprofloxacin":	{"NN"},
"cira":	{"NN"},
"circa":	{"IN"},
"circadian":	{"JJ"},
"circaea":	{"NN"},
"circaetus":	{"NNS"},
"circassian":	{"NN"},
"circe":	{"NN"},
"circinate":	{"JJ"},
"circinus":	{"NN"},
"circle":	{"NN","VB","VBP"},
"circled":	{"VBD","VBN"},
"circles":	{"NNS","VBZ"},
"circlet":	{"NN"},
"circling":	{"VBG"},
"circonscription":	{"NN"},
"circonscriptions":	{"NNS"},
"circuit":	{"NN"},
"circuit-board":	{"NN"},
"circuit-breaker":	{"NN","JJ"},
"circuited":	{"VBD","VBN"},
"circuiting":	{"VBG"},
"circuitous":	{"JJ"},
"circuitry":	{"NN"},
"circuits":	{"NNS","VBZ"},
"circular":	{"JJ","NN"},
"circular-knit":	{"JJ"},
"circularisation":	{"NN"},
"circularise":	{"VB"},
"circularity":	{"NN"},
"circularization":	{"NN"},
"circularize":	{"VB"},
"circularly":	{"RB"},
"circulars":	{"NNS"},
"circulate":	{"VB","VBP"},
"circulated":	{"VBD","VBN"},
"circulates":	{"VBZ"},
"circulating":	{"VBG"},
"circulation":	{"NN"},
"circulations":	{"NNS"},
"circulative":	{"JJ"},
"circulatory":	{"JJ"},
"circumambulate":	{"VB","VBP"},
"circumambulated":	{"VBD","VBN"},
"circumambulates":	{"VBZ"},
"circumambulating":	{"VBG"},
"circumambulation":	{"NN"},
"circumambulator":	{"NN"},
"circumambulatory":	{"JJ"},
"circumboreal":	{"JJ"},
"circumcise":	{"VB","VBP"},
"circumcised":	{"VBD","VBN"},
"circumcises":	{"VBZ"},
"circumcising":	{"VBG"},
"circumcision":	{"NN"},
"circumduction":	{"NN"},
"circumference":	{"NN"},
"circumferent":	{"JJ"},
"circumferential":	{"JJ"},
"circumflex":	{"NN"},
"circumfuse":	{"VB"},
"circumlocution":	{"NN"},
"circumlocutious":	{"JJ"},
"circumlocutory":	{"JJ"},
"circumnavigate":	{"VB","VBP"},
"circumnavigated":	{"VBD","VBN"},
"circumnavigates":	{"VBZ"},
"circumnavigating":	{"VBG"},
"circumnavigation":	{"NN"},
"circumnavigations":	{"NNS"},
"circumpolar":	{"JJ","NN"},
"circumscribe":	{"VB","VBP"},
"circumscribed":	{"VBD","VBN"},
"circumscribes":	{"VBZ"},
"circumscribing":	{"VBG"},
"circumscription":	{"NN"},
"circumscriptions":	{"NNS"},
"circumspect":	{"JJ"},
"circumspection":	{"NN"},
"circumspectly":	{"RB"},
"circumstance":	{"NN"},
"circumstanced":	{"VBD","VBN"},
"circumstances":	{"NNS","VBZ"},
"circumstancing":	{"VBG"},
"circumstantial":	{"JJ"},
"circumstantially":	{"RB"},
"circumstantiate":	{"VB"},
"circumvallate":	{"VB"},
"circumvent":	{"VB","VBP"},
"circumvented":	{"VBD","VBN"},
"circumventing":	{"VBG"},
"circumvention":	{"NN"},
"circumvents":	{"VBZ"},
"circumvolute":	{"VB"},
"circumvolution":	{"NN"},
"circumvolve":	{"VB"},
"circus":	{"NN"},
"circuses":	{"NNS"},
"cirio":	{"NN"},
"cirque":	{"NN"},
"cirrhosa":	{"NN"},
"cirrhosis":	{"NN"},
"cirrhus":	{"NNS"},
"cirriped":	{"NN"},
"cirripede":	{"NN"},
"cirripedia":	{"NN"},
"cirrocumulus":	{"NNS"},
"cirrostratus":	{"NN"},
"cirrus":	{"NN"},
"cirsium":	{"NN"},
"cis":	{"NN"},
"cisalpine":	{"JJ"},
"cisc":	{"NN"},
"cisco":	{"NN"},
"cisgender":	{"JJ"},
"cisgendered":	{"JJ"},
"cislunar":	{"JJ"},
"cismontane":	{"JJ"},
"cissies":	{"NNS"},
"cissy":	{"JJ","NN"},
"cistaceae":	{"NN"},
"cistercian":	{"NN"},
"cistern":	{"NN"},
"cisterna":	{"NN"},
"cistothorus":	{"NN"},
"cistron":	{"NN"},
"cistus":	{"NN"},
"cit":	{"NN"},
"citadel":	{"NN"},
"citadels":	{"NNS"},
"citation":	{"NN"},
"citations":	{"NNS"},
"cite":	{"VB","NN","VBP"},
"cited":	{"VBD","VBN"},
"citellus":	{"NNS"},
"cites":	{"VBZ"},
"citharichthys":	{"NNS"},
"cither":	{"NN"},
"cithern":	{"NN"},
"cities":	{"NNS"},
"citified":	{"JJ"},
"citify":	{"VB"},
"citing":	{"VBG"},
"citizen":	{"NN"},
"citizen-plaintiffs":	{"NNS"},
"citizen-sparked":	{"JJ"},
"citizenry":	{"NN"},
"citizens":	{"NNS"},
"citizenship":	{"NN"},
"citlaltepetl":	{"NN"},
"cito":	{"FW"},
"citole":	{"NN"},
"citrange":	{"NN"},
"citrate":	{"NN"},
"citrated":	{"JJ"},
"citric":	{"JJ"},
"citrin":	{"NN"},
"citrine":	{"NN","JJ"},
"citroen":	{"NN"},
"citron":	{"NN"},
"citroncirus":	{"NN"},
"citronwood":	{"NN"},
"citrous":	{"JJ"},
"citrulline":	{"NN"},
"citrullus":	{"NNS"},
"citrus":	{"NN","JJ"},
"cittern":	{"NN"},
"city":	{"NN"},
"city-based":	{"JJ"},
"city-born":	{"JJ"},
"city-bred":	{"JJ"},
"city-charter":	{"NN"},
"city-dweller":	{"NN"},
"city-like":	{"JJ"},
"city-owned":	{"JJ"},
"city-state":	{"JJ","NN"},
"city-states":	{"NNS"},
"city-trading":	{"NN"},
"city-type":	{"JJ"},
"city-wide":	{"JJ"},
"citya":	{"NN"},
"citybred":	{"JJ"},
"cityfied":	{"JJ"},
"cityscape":	{"NN"},
"cityscapes":	{"NNS"},
"citywide":	{"JJ","NN"},
"civ":	{"NN"},
"cive":	{"NN"},
"civet":	{"NN"},
"civic":	{"JJ"},
"civic-lunch":	{"JJ"},
"civics":	{"NN"},
"civies":	{"NN"},
"civil":	{"JJ"},
"civil-investigative":	{"JJ"},
"civil-libertarian":	{"JJ"},
"civil-liberties":	{"NNS"},
"civil-rights":	{"NNS","JJ","NN"},
"civil-service":	{"JJ","NN"},
"civilian":	{"JJ","NN"},
"civilian-aircraft":	{"NN"},
"civilians":	{"NNS"},
"civilisation":	{"NN"},
"civilise":	{"VB","VBP"},
"civilised":	{"JJ","VBD","VBN"},
"civilises":	{"VBZ"},
"civilising":	{"VBG"},
"civilities":	{"NNS"},
"civility":	{"NN"},
"civilization":	{"NN"},
"civilizational":	{"JJ"},
"civilizations":	{"NNS"},
"civilize":	{"VB","VBP"},
"civilized":	{"JJ","VBD","VBN"},
"civilizes":	{"VBZ"},
"civilizing":	{"VBG"},
"civilly":	{"RB"},
"civvies":	{"NNS"},
"cjd":	{"NN"},
"cl":	{"NN","NNS"},
"clabber":	{"VB","VBP"},
"clabbered":	{"VBD","VBN"},
"clabbering":	{"VBG"},
"clabbers":	{"VBZ"},
"clack":	{"NN","VB","VBP"},
"clacked":	{"VBD","VBN"},
"clacking":	{"VBG"},
"clacks":	{"VBZ"},
"clad":	{"JJ","VB","VBD","VBN"},
"cladding":	{"NN"},
"clade":	{"NN"},
"cladistics":	{"NN"},
"cladode":	{"NN"},
"cladogram":	{"NN"},
"cladonia":	{"NN"},
"cladoniaceae":	{"NN"},
"cladophyll":	{"NN"},
"cladorhyncus":	{"NNS"},
"cladrastis":	{"NN"},
"claforan":	{"NN"},
"claim":	{"NN","VBP","VB"},
"claimant":	{"NN"},
"claimants":	{"NNS"},
"claimed":	{"VBD","VBN"},
"claiming":	{"VBG"},
"claims":	{"NNS","VBZ"},
"claims-processing":	{"NN"},
"clair":	{"NN"},
"clairaudiently":	{"RB"},
"clairvoyance":	{"NN"},
"clairvoyant":	{"NN","JJ"},
"clairvoyants":	{"NNS"},
"clam":	{"VB","VBP","NN"},
"clamant":	{"JJ"},
"clamatores":	{"NNS"},
"clamatorial":	{"JJ"},
"clambake":	{"NN"},
"clamber":	{"VB","VBP","NN"},
"clambered":	{"VBD","VBN"},
"clambering":	{"VBG"},
"clambers":	{"VBZ"},
"clammed":	{"VBD","VBN"},
"clammily":	{"RB"},
"clamminess":	{"NN"},
"clamming":	{"VBG"},
"clammy":	{"JJ"},
"clammyweed":	{"NN"},
"clamor":	{"VB","VBP","NN"},
"clamored":	{"VBD","VBN"},
"clamoring":	{"VBG","NN"},
"clamorous":	{"JJ"},
"clamorously":	{"RB"},
"clamors":	{"VBZ"},
"clamour":	{"NN","VBP","VB"},
"clamoured":	{"VBD","VBN"},
"clamouring":	{"VBG","NN"},
"clamours":	{"VBZ"},
"clamp":	{"VB","VBP","NN"},
"clampdown":	{"NN"},
"clampdowns":	{"NNS"},
"clamped":	{"VBD","VBN"},
"clamping":	{"VBG"},
"clamps":	{"NNS","VBZ"},
"clams":	{"VBZ","NNS"},
"clamshell":	{"NN"},
"clamshells":	{"NNS"},
"clan":	{"NN"},
"clancy":	{"NN"},
"clandestine":	{"JJ","NN"},
"clang":	{"NN","VB","VBP"},
"clanged":	{"VBD","VBN"},
"clanger":	{"NN"},
"clanging":	{"NN","VBG"},
"clangor":	{"NN","VB","VBP"},
"clangored":	{"VBD","VBN"},
"clangoring":	{"VBG"},
"clangorous":	{"JJ"},
"clangorously":	{"RB"},
"clangors":	{"VBZ"},
"clangour":	{"NN","VB","VBP"},
"clangoured":	{"VBD","VBN"},
"clangouring":	{"VBG"},
"clangours":	{"NNS","VBZ"},
"clangs":	{"NNS","VBZ"},
"clangula":	{"NN"},
"clank":	{"VB","VBP","NN"},
"clanked":	{"VBD","VBN"},
"clanking":	{"VBG"},
"clanks":	{"VBZ"},
"clannish":	{"JJ"},
"clannishly":	{"RB"},
"clannishness":	{"NN"},
"clans":	{"NNS","VBZ"},
"clansman":	{"NN"},
"clanswoman":	{"NN"},
"clap":	{"VB","VBP","NN"},
"clapboard":	{"NN"},
"clapped":	{"VBD","VBN"},
"clapper":	{"NN"},
"clapperboard":	{"NN"},
"clapperclaw":	{"VB","VBP"},
"clapperclawed":	{"VBD","VBN"},
"clapperclawing":	{"VBG"},
"clapperclaws":	{"VBZ"},
"clappers":	{"NNS"},
"clapping":	{"NN","VBG"},
"claps":	{"NNS","VBZ"},
"claptrap":	{"NN"},
"claque":	{"NN"},
"clare":	{"NN"},
"clarence":	{"NN"},
"claret":	{"NN","JJ"},
"clarets":	{"NNS"},
"clarification":	{"NN"},
"clarifications":	{"NNS"},
"clarified":	{"VBD","VBN"},
"clarifies":	{"VBZ","NNS"},
"clarify":	{"VB","NN","VBP"},
"clarifying":	{"VBG","NN"},
"clarinet":	{"NN"},
"clarinetist":	{"NN"},
"clarinettist":	{"NN"},
"clarion":	{"NN"},
"clarity":	{"NN"},
"clark":	{"NN"},
"clarks":	{"NNS"},
"clarksburg":	{"NN"},
"clarkson":	{"NN"},
"claro":	{"NN"},
"clary":	{"NN"},
"clash":	{"NN","VB","VBP"},
"clashed":	{"VBD","VBN"},
"clashes":	{"NNS","VBZ"},
"clashing":	{"VBG"},
"clasp":	{"NN","VB","VBP"},
"clasped":	{"VBD","VBN"},
"clasping":	{"VBG"},
"clasps":	{"NNS","VBZ"},
"class":	{"NN","VB","VBP"},
"class-action":	{"JJ","NN"},
"class-based":	{"JJ"},
"class-biased":	{"JJ"},
"class-conscious":	{"JJ"},
"class-warfare":	{"JJ","NN"},
"class-warrior":	{"NN"},
"classed":	{"VBD","VBN"},
"classes":	{"NNS","VBZ"},
"classic":	{"JJ","NN"},
"classical":	{"JJ"},
"classical-music":	{"JJ"},
"classicalism":	{"NN"},
"classically":	{"RB"},
"classicise":	{"VB","VBP"},
"classicised":	{"VBD","VBN"},
"classicises":	{"VBZ"},
"classicising":	{"VBG"},
"classicism":	{"NN"},
"classicist":	{"NN"},
"classicistic":	{"JJ"},
"classicize":	{"VB","VBP"},
"classicized":	{"VBD","VBN"},
"classicizes":	{"VBZ"},
"classicizing":	{"VBG"},
"classics":	{"NNS"},
"classier":	{"JJR"},
"classiest":	{"JJS"},
"classifiable":	{"JJ"},
"classifiably":	{"RB"},
"classification":	{"NN"},
"classification-angle":	{"JJ"},
"classifications":	{"NNS"},
"classificatory":	{"JJ"},
"classified":	{"JJ","VBD","VBN"},
"classified-ad":	{"NN"},
"classifier":	{"NN"},
"classifiers":	{"NNS"},
"classifies":	{"VBZ"},
"classify":	{"VB","VBP"},
"classifying":	{"VBG"},
"classing":	{"VBG"},
"classless":	{"JJ"},
"classmate":	{"NN"},
"classmates":	{"NNS"},
"classroom":	{"NN"},
"classrooms":	{"NNS"},
"classwork":	{"NN"},
"classy":	{"JJ"},
"clast":	{"NN"},
"clastic":	{"JJ"},
"clathraceae":	{"NN"},
"clathrate":	{"JJ"},
"clathrus":	{"NN"},
"clatter":	{"VB","VBP","NN"},
"clattered":	{"VBD","VBN"},
"clattering":	{"VBG"},
"clatters":	{"VBZ"},
"clattery":	{"JJ"},
"claudia":	{"NN"},
"claudication":	{"NN"},
"claudius":	{"NNS"},
"claus":	{"NN"},
"clausal":	{"JJ"},
"clause":	{"NN"},
"clauses":	{"NNS"},
"clausewitz":	{"NN"},
"claustrophobe":	{"NN"},
"claustrophobia":	{"NN"},
"claustrophobic":	{"JJ"},
"claustrum":	{"NN"},
"clavariaceae":	{"NN"},
"claver":	{"VB"},
"claviceps":	{"NNS"},
"clavichord":	{"NN"},
"clavicipitaceae":	{"NN"},
"clavicle":	{"NN"},
"clavier":	{"NN"},
"clavus":	{"NN"},
"claw":	{"NN","VB","VBP"},
"claw-back":	{"NN"},
"claw-hammer":	{"NN"},
"claw-shaped":	{"JJ"},
"clawback":	{"NN"},
"clawbacks":	{"NNS"},
"clawed":	{"VBD","VBN"},
"clawfoot":	{"NN"},
"clawhammer":	{"NN"},
"clawhammers":	{"NNS"},
"clawing":	{"VBG"},
"clawlike":	{"JJ"},
"claws":	{"NNS","VBZ"},
"claxon":	{"NN","VB"},
"clay":	{"NN"},
"clay-like":	{"JJ"},
"clay-mining":	{"NN"},
"clayey":	{"JJ"},
"claymore":	{"NN"},
"clays":	{"NNS"},
"claystone":	{"NN"},
"claytonia":	{"NN"},
"clayware":	{"NN"},
"clean":	{"JJ","VB","NN","RB","VBP"},
"clean-air":	{"JJ","NN"},
"clean-bank":	{"JJ"},
"clean-burning":	{"JJ"},
"clean-cut":	{"JJ"},
"clean-fuels":	{"NNS"},
"clean-handed":	{"JJ"},
"clean-limbed":	{"JJ"},
"clean-living":	{"JJ"},
"clean-shaven":	{"JJ"},
"clean-top":	{"JJ"},
"clean-up":	{"JJ","NN"},
"clean-water":	{"NN"},
"cleanable":	{"JJ"},
"cleaned":	{"VBD","VBN","JJ"},
"cleaned-up":	{"JJ"},
"cleaner":	{"NN","JJR"},
"cleaner-burning":	{"JJ"},
"cleaners":	{"NNS"},
"cleanest":	{"JJS"},
"cleaning":	{"VBG","NN"},
"cleaning-fluid":	{"NN"},
"cleanliness":	{"NN"},
"cleanly":	{"RB","JJ"},
"cleanness":	{"NN"},
"cleans":	{"VBZ"},
"cleanse":	{"VB","VBP"},
"cleansed":	{"VBD","VBN"},
"cleanser":	{"NN"},
"cleansers":	{"NNS"},
"cleanses":	{"VBZ"},
"cleansing":	{"VBG","JJ","NN"},
"cleanthes":	{"NNS"},
"cleanup":	{"NN"},
"cleanups":	{"NNS"},
"clear":	{"JJ","VB","RB","VBP","NN"},
"clear-channel":	{"JJ","NN"},
"clear-cut":	{"JJ","NN","VB","VBP"},
"clear-cutting":	{"JJ","NN"},
"clear-eyed":	{"JJ"},
"clear-headed":	{"JJ"},
"clear-it-out":	{"JJ"},
"clear-sighted":	{"JJ"},
"clear-thinking":	{"JJ"},
"clearance":	{"NN"},
"clearances":	{"NNS"},
"clearcutness":	{"NN"},
"cleared":	{"VBN","VBD"},
"clearer":	{"JJR"},
"clearest":	{"JJS"},
"clearheaded":	{"JJ"},
"clearing":	{"VBG","NN"},
"clearing-firm":	{"JJ"},
"clearinghouse":	{"NN"},
"clearly":	{"RB"},
"clearnace":	{"NN"},
"clearness":	{"NN"},
"clears":	{"VBZ"},
"clearstory":	{"NN"},
"clearwater":	{"NN"},
"clearway":	{"NN"},
"clearweed":	{"NN"},
"cleary":	{"NN"},
"cleat":	{"NN"},
"cleated":	{"VBD","VBN"},
"cleating":	{"VBG"},
"cleats":	{"NNS","VBZ"},
"cleavable":	{"JJ"},
"cleavage":	{"NN"},
"cleave":	{"VB","VBP"},
"cleaved":	{"VBD","VBN"},
"cleaver":	{"NN"},
"cleavers":	{"NNS"},
"cleaves":	{"VBZ"},
"cleaving":	{"VBG"},
"clef":	{"NN"},
"cleft":	{"NN","JJ","VBD","VBN"},
"clefts":	{"NNS"},
"cleg":	{"NN"},
"clegg":	{"NN"},
"cleistes":	{"NNS"},
"cleistocarp":	{"NN"},
"cleistogamic":	{"JJ"},
"cleistogamous":	{"JJ"},
"cleistogamy":	{"NN"},
"cleistothecium":	{"NN"},
"clematis":	{"NN"},
"clemence":	{"NN"},
"clemenceau":	{"NN"},
"clemency":	{"NN"},
"clemens":	{"NNS"},
"clement":	{"JJ"},
"clementine":	{"NN"},
"clements":	{"NNS"},
"clench":	{"VB","VBP"},
"clenched":	{"VBD","VBN"},
"clenches":	{"VBZ"},
"clenching":	{"VBG"},
"cleome":	{"NN"},
"cleopatra":	{"NN"},
"clepsydra":	{"NN"},
"clerestory":	{"NN"},
"clergy":	{"NNS"},
"clergyman":	{"NN"},
"clergymen":	{"NNS"},
"cleric":	{"NN","JJ"},
"clerical":	{"JJ","NN"},
"clerical-lay":	{"JJ"},
"clericalism":	{"NN"},
"clericalist":	{"NN"},
"clerics":	{"NNS"},
"clerid":	{"NN"},
"cleridae":	{"NN"},
"clerihew":	{"NN"},
"clerisy":	{"NN"},
"clerk":	{"NN","VBP","VB"},
"clerk-turned":	{"JJ"},
"clerked":	{"VBD","VBN"},
"clerking":	{"NN","VBG"},
"clerks":	{"NNS","VBZ"},
"clerkship":	{"NN"},
"clethra":	{"NN"},
"clethraceae":	{"NN"},
"clethrionomys":	{"NNS"},
"cleveland":	{"NN"},
"cleveland-based":	{"JJ"},
"clever":	{"JJ"},
"cleverly":	{"RB"},
"cleverness":	{"NN"},
"clevis":	{"NN"},
"clew":	{"NN","VB","VBP"},
"clewed":	{"VBD","VBN"},
"clewing":	{"VBG"},
"clews":	{"NNS","VBZ"},
"cli":	{"NN"},
"clianthus":	{"NN"},
"cliche":	{"NN"},
"cliched":	{"JJ"},
"cliches":	{"NNS"},
"clichy":	{"NN"},
"clichy-la-garenne":	{"NN"},
"click":	{"NN","VB","VBP"},
"click-clack":	{"NN"},
"click-through":	{"NN"},
"click-throughs":	{"NNS"},
"clickbait":	{"NN"},
"clicked":	{"VBD","VBN"},
"clickety-clack":	{"NN"},
"clickety-click":	{"NN"},
"clicking":	{"NN","VBG"},
"clicks":	{"NNS","VBZ"},
"client":	{"NN"},
"client-server":	{"JJ"},
"client-service":	{"JJ","NN"},
"clientage":	{"NN"},
"clientele":	{"NN","NNS"},
"clients":	{"NNS"},
"clientslose":	{"JJ"},
"cliff":	{"NN"},
"cliff-brake":	{"NN"},
"cliff-hanging":	{"JJ"},
"cliffhanger":	{"NN"},
"cliffhangers":	{"NNS"},
"cliffhanging":	{"JJ"},
"cliffs":	{"NNS"},
"clifton":	{"NN"},
"cliftonia":	{"NN"},
"climacteric":	{"JJ","NN"},
"climactic":	{"JJ"},
"climate":	{"NN"},
"climates":	{"NNS"},
"climatic":	{"JJ","NN"},
"climatical":	{"JJ"},
"climatically":	{"RB"},
"climatologist":	{"NN"},
"climatology":	{"NN"},
"climax":	{"NN","VB","VBP"},
"climaxed":	{"VBD","VBN"},
"climaxes":	{"NNS","VBZ"},
"climaxing":	{"VBG"},
"climb":	{"VB","NN","VBP"},
"climb-down":	{"NN"},
"climb-downs":	{"NN"},
"climbable":	{"JJ"},
"climbdown":	{"NN"},
"climbdowns":	{"NNS"},
"climbed":	{"VBD","VBN"},
"climber":	{"NN"},
"climbers":	{"NNS"},
"climbing":	{"VBG","NN"},
"climbs":	{"VBZ","NNS"},
"clime":	{"NN"},
"climes":	{"NNS"},
"clinch":	{"VB","VBP","NN"},
"clinched":	{"VBD","VBN"},
"clincher":	{"NN"},
"clincher-built":	{"JJ"},
"clinchers":	{"NNS"},
"clinches":	{"VBZ","NNS"},
"clinching":	{"VBG"},
"cline":	{"NN"},
"cling":	{"VBP","VB"},
"clingfilm":	{"NN"},
"clingfish":	{"NN"},
"clinging":	{"VBG"},
"clings":	{"VBZ"},
"clingstone":	{"NN"},
"clingy":	{"JJ"},
"clinic":	{"NN"},
"clinical":	{"JJ"},
"clinical-products":	{"NNS"},
"clinically":	{"RB"},
"clinician":	{"NN"},
"clinics":	{"NNS"},
"clinid":	{"NN"},
"clinidae":	{"NN"},
"clink":	{"VB","VBP","NN"},
"clinked":	{"VBD","VBN"},
"clinker":	{"NN","VB","VBP"},
"clinker-built":	{"JJ"},
"clinkered":	{"VBD","VBN"},
"clinkering":	{"VBG"},
"clinkers":	{"NNS","VBZ"},
"clinking":	{"JJ","VBG"},
"clinks":	{"VBZ"},
"clinocephalism":	{"NN"},
"clinocephaly":	{"NN"},
"clinodactyly":	{"NN"},
"clinometer":	{"NN"},
"clinopodium":	{"NN"},
"clinoril":	{"NN"},
"clinquant":	{"JJ"},
"clint":	{"NN"},
"clinton":	{"NN"},
"clintonia":	{"NN"},
"clio":	{"NN"},
"clioquinol":	{"NN"},
"clip":	{"NN","VB","VBP"},
"clip-clop":	{"NN","VB","VBP"},
"clip-clopped":	{"VBD","VBN"},
"clip-clopping":	{"VBG"},
"clip-clops":	{"VBZ"},
"clip-on":	{"JJ","NN"},
"clipboard":	{"NN"},
"clipboard-size":	{"JJ"},
"clipboard-sized":	{"JJ"},
"clipboards":	{"NNS"},
"clipped":	{"JJ","VBD","VBN"},
"clipper":	{"NN"},
"clippety-clop":	{"NN"},
"clipping":	{"NN","VBG"},
"clippings":	{"NNS"},
"clips":	{"NNS","VBZ"},
"clique":	{"NN"},
"cliqued":	{"VBD","VBN"},
"cliques":	{"NNS","VBZ"},
"cliquing":	{"VBG"},
"cliquish":	{"JJ"},
"cliquishly":	{"RB"},
"cliquishness":	{"NN"},
"clit":	{"NN"},
"clitocybe":	{"NN"},
"clitoral":	{"JJ"},
"clitoria":	{"NN"},
"clitoric":	{"JJ"},
"clitoridectomy":	{"NN"},
"clitoris":	{"NN"},
"clitter":	{"VB"},
"clive":	{"NN"},
"clivers":	{"NNS"},
"cloaca":	{"NN"},
"cloak":	{"NN","VB","VBP"},
"cloak-and-dagger":	{"JJ"},
"cloaked":	{"VBD","VBN","JJ"},
"cloaking":	{"VBG"},
"cloakmaker":	{"NN"},
"cloakroom":	{"NN"},
"cloakrooms":	{"NNS"},
"cloaks":	{"NNS","VBZ"},
"clobber":	{"VBP","NN","VB"},
"clobbered":	{"VBD","VBN"},
"clobbering":	{"VBG"},
"clobbers":	{"VBZ"},
"cloche":	{"NN"},
"clock":	{"NN","VBP","VB"},
"clock-stopped":	{"VBN"},
"clock-watching":	{"NN"},
"clocked":	{"VBD","VBN"},
"clocking":	{"NN","VBG"},
"clockmaker":	{"NN"},
"clocks":	{"NNS","VBZ"},
"clocksmith":	{"NN"},
"clockwise":	{"RB","JJ"},
"clockwork":	{"NN"},
"clod":	{"NN"},
"cloddish":	{"JJ","NN"},
"cloddishness":	{"NN"},
"clodhopper":	{"NN"},
"clodhoppers":	{"NNS"},
"clods":	{"NNS"},
"clofibrate":	{"NN"},
"clog":	{"VB","VBP","NN"},
"clogged":	{"JJ","VBD","VBN"},
"clogging":	{"VBG"},
"cloggy":	{"JJ"},
"clogs":	{"VBZ","NNS"},
"cloisonne":	{"JJ","NN"},
"cloister":	{"NN","VB","VBP"},
"cloistered":	{"JJ","VBD","VBN"},
"cloistering":	{"VBG"},
"cloisters":	{"NNS","VBZ"},
"cloistral":	{"JJ"},
"clomid":	{"NN"},
"clomiphene":	{"NN"},
"clomipramine":	{"NN"},
"clomp":	{"VB","VBP","NN"},
"clomped":	{"VBD","VBN"},
"clomping":	{"VBG"},
"clomps":	{"VBZ","NNS"},
"clonal":	{"JJ"},
"clonazepam":	{"NN"},
"clone":	{"NN","VB","VBP"},
"cloned":	{"VBD","VBN"},
"clones":	{"NNS","VBZ"},
"clonic":	{"JJ"},
"clonidine":	{"NN"},
"cloning":	{"VBG","NN"},
"clonus":	{"NN"},
"clop":	{"NN","VB","VBP"},
"clopped":	{"VBD","VBN"},
"clopping":	{"VBG"},
"clops":	{"VBZ"},
"clorox":	{"NN"},
"close":	{"RB","JJ","VB","NN","VBP"},
"close-fitting":	{"JJ"},
"close-grained":	{"JJ"},
"close-hauled":	{"JJ"},
"close-in":	{"JJ"},
"close-knit":	{"JJ"},
"close-minded":	{"JJ"},
"close-mouthed":	{"JJ"},
"close-packed":	{"JJ"},
"close-set":	{"JJ"},
"close-up":	{"NN","JJ"},
"close-ups":	{"NNS"},
"closed":	{"VBD","VBN","JJ"},
"closed-captioned":	{"NN"},
"closed-chain":	{"JJ"},
"closed-circuit":	{"JJ"},
"closed-door":	{"JJ"},
"closed-end":	{"JJ"},
"closed-minded":	{"JJ"},
"closed-ring":	{"JJ"},
"closedown":	{"NN"},
"closedowns":	{"NNS"},
"closefisted":	{"JJ"},
"closelipped":	{"JJ"},
"closely":	{"RB"},
"closely-held":	{"JJ"},
"closely-packed":	{"JJ"},
"closemouthed":	{"JJ"},
"closeness":	{"NN"},
"closeout":	{"NN","JJ"},
"closer":	{"JJR"},
"closes":	{"VBZ","NNS"},
"closest":	{"JJS"},
"closestool":	{"NN"},
"closet":	{"NN","VB","VBP","JJ"},
"closet-sized":	{"JJ"},
"closeted":	{"VBD","VBN","JJ"},
"closeting":	{"VBG"},
"closets":	{"VBZ","NNS"},
"closeup":	{"NN"},
"closeups":	{"NNS"},
"closing":	{"VBG","NN","JJ"},
"closings":	{"NNS"},
"clostridia":	{"NN"},
"clostridium":	{"NN"},
"closure":	{"NN","VB","VBP"},
"closured":	{"VBD","VBN"},
"closures":	{"NNS","VBZ"},
"closuring":	{"VBG"},
"clot":	{"NN","VB","VBP"},
"clot-reducing":	{"JJ"},
"clotbur":	{"NN"},
"cloth":	{"NN"},
"cloth-of-gold":	{"NN"},
"clothbound":	{"JJ"},
"clothe":	{"VB","VBP"},
"clothed":	{"VBD","VBN"},
"clothes":	{"NNS","VBZ"},
"clothesbrush":	{"NN"},
"clotheshorse":	{"NN"},
"clothesless":	{"JJ"},
"clothesline":	{"NN","VB","VBP"},
"clotheslined":	{"VBD","VBN"},
"clotheslines":	{"NNS","VBZ"},
"clotheslining":	{"VBG"},
"clothespin":	{"NN"},
"clothespress":	{"NN"},
"clothier":	{"NN"},
"clothiers":	{"NNS"},
"clothing":	{"NN","VBG"},
"clothing-store":	{"NN"},
"clotho":	{"NN"},
"clots":	{"NNS","VBZ"},
"clotted":	{"JJ","VBD","VBN"},
"clotting":	{"NN","VBG"},
"clottings":	{"NNS"},
"cloture":	{"VB","NN"},
"cloud":	{"NN","VB","VBP"},
"cloud-based":	{"JJ"},
"cloud-covered":	{"JJ"},
"cloud-cuckoo-land":	{"NN"},
"cloud-flecked":	{"JJ"},
"cloudberry":	{"NN"},
"cloudburst":	{"NN"},
"clouded":	{"JJ","VBD","VBN"},
"cloudiness":	{"NN"},
"clouding":	{"NN","VBG"},
"cloudless":	{"JJ"},
"cloudlessness":	{"NN"},
"cloudlike":	{"JJ"},
"clouds":	{"NNS","VBZ"},
"cloudy":	{"JJ","NN"},
"clout":	{"NN","VBP","VB"},
"clouted":	{"VBD","VBN"},
"clouting":	{"VBG"},
"clouts":	{"VBZ","NNS"},
"clove":	{"NN","VBD"},
"clove-scented":	{"JJ"},
"cloven":	{"JJ","NN","VBN"},
"cloven-footed":	{"JJ"},
"cloven-hoofed":	{"JJ"},
"clover":	{"NN"},
"clover-root":	{"NN"},
"cloverleaf":	{"NN"},
"cloveroot":	{"NN"},
"cloves":	{"NNS"},
"clovis":	{"NN"},
"clowder":	{"NN"},
"clown":	{"NN","VB","VBP"},
"clowned":	{"VBD","VBN"},
"clowning":	{"VBG"},
"clownish":	{"JJ"},
"clownlike":	{"JJ"},
"clowns":	{"NNS","VBZ"},
"cloy":	{"VB","VBP"},
"cloyed":	{"VBD","VBN"},
"cloying":	{"JJ","VBG"},
"cloyingly":	{"RB"},
"cloys":	{"VBZ"},
"clozapine":	{"NN"},
"clozaril":	{"NN"},
"cloze":	{"JJ","NN"},
"cls":	{"NNS"},
"club":	{"NN","VB","VBP"},
"club-head":	{"NN"},
"club-moss":	{"NN"},
"club-root":	{"NN"},
"club-shaped":	{"JJ"},
"clubable":	{"JJ"},
"clubbable":	{"JJ"},
"clubbed":	{"VBD","VBN"},
"clubber":	{"NN"},
"clubbers":	{"NNS"},
"clubbing":	{"VBG","NN"},
"clubbish":	{"JJ"},
"clubby":	{"JJ"},
"clubfoot":	{"NN"},
"clubfooted":	{"JJ"},
"clubgoer":	{"NN"},
"clubgoers":	{"NNS"},
"clubhead":	{"NN"},
"clubhouse":	{"NN"},
"clubhouses":	{"NNS"},
"clubroom":	{"NN"},
"clubrooms":	{"NNS"},
"clubs":	{"NNS","VBZ"},
"cluck":	{"NN","VB","VBP"},
"clucked":	{"VBD","VBN"},
"clucking":	{"JJ","VBG"},
"clucks":	{"NNS","VBZ"},
"clue":	{"NN","VB","VBP"},
"clued":	{"VBD","VBN"},
"clueless":	{"JJ","NN"},
"cluelessness":	{"NN"},
"clues":	{"NNS","VBZ"},
"cluing":	{"VBG"},
"clumber":	{"NN"},
"clump":	{"NN","VB","VBP"},
"clumped":	{"VBD","VBN"},
"clumping":	{"VBG"},
"clumps":	{"NNS","VBZ"},
"clumsily":	{"RB"},
"clumsiness":	{"NN"},
"clumsy":	{"JJ"},
"clunch":	{"NN"},
"clung":	{"NN","VBD","VBN"},
"clunk":	{"NN","VB","VBP"},
"clunked":	{"VBD","VBN"},
"clunker":	{"NN"},
"clunkers":	{"NNS"},
"clunking":	{"VBG"},
"clunks":	{"NNS","VBZ"},
"clunky":	{"JJ"},
"clupea":	{"NN"},
"clupeid":	{"NN"},
"clupeidae":	{"NN"},
"clusia":	{"NN"},
"clusiaceae":	{"NN"},
"cluster":	{"NN","VB","VBP"},
"clustered":	{"VBD","VBN"},
"clustering":	{"VBG"},
"clusters":	{"NNS","VBZ"},
"clutch":	{"VB","VBP","NN"},
"clutched":	{"VBD","VBN"},
"clutches":	{"VBZ","NNS"},
"clutching":	{"VBG"},
"clutter":	{"NN","VB","VBP"},
"cluttered":	{"VBD","VBN","JJ"},
"cluttering":	{"VBG"},
"clutters":	{"VBZ"},
"clv":	{"JJ"},
"clx":	{"JJ"},
"clxv":	{"JJ"},
"clxx":	{"JJ"},
"clxxv":	{"JJ"},
"clxxx":	{"JJ"},
"clyde":	{"NN"},
"clydesdale":	{"NN"},
"clypeus":	{"NNS"},
"clyster":	{"NN"},
"clytemnestra":	{"NN"},
"cm":	{"NN"},
"cm.":	{"NN"},
"cmb":	{"NN"},
"cmbr":	{"NN"},
"cmv":	{"NN"},
"cnemidophorus":	{"NN"},
"cnicus":	{"NNS"},
"cnidaria":	{"NN"},
"cnidarian":	{"NN"},
"cnidoscolus":	{"NNS"},
"cnidosporidia":	{"NN"},
"cnossos":	{"NN"},
"cnossus":	{"NN"},
"cnpz":	{"NN"},
"cns":	{"NNS"},
"cnut":	{"NN"},
"co-anchor":	{"NN","JJ"},
"co-anchored":	{"VBN"},
"co-author":	{"NN","VB","VBP"},
"co-authored":	{"VBN","VBD"},
"co-authoring":	{"VBG"},
"co-authors":	{"NNS","VBZ"},
"co-beneficiary":	{"NN"},
"co-chair":	{"NN","VB","VBP"},
"co-chaired":	{"VBD","VBN"},
"co-chairing":	{"VBG"},
"co-chairman":	{"NN"},
"co-chairmen":	{"NNS"},
"co-chairperson":	{"NN"},
"co-chairpersons":	{"NNS"},
"co-chairs":	{"NNS","VBZ"},
"co-chief":	{"JJ","NN"},
"co-conspirators":	{"NNS"},
"co-defendant":	{"NN"},
"co-defendants":	{"NNS"},
"co-develop":	{"VB","VBP"},
"co-developed":	{"VBD","VBN"},
"co-developer":	{"NN"},
"co-developers":	{"NNS"},
"co-developing":	{"VBG"},
"co-develops":	{"VBZ"},
"co-director":	{"NN"},
"co-discover":	{"VB","VBP"},
"co-discovered":	{"VBD","VBN"},
"co-discoverer":	{"NN"},
"co-discoverers":	{"NNS"},
"co-discovering":	{"VBG"},
"co-discovers":	{"VBZ"},
"co-ed":	{"JJ","NN"},
"co-edited":	{"JJ"},
"co-editor":	{"NN"},
"co-edits":	{"VBZ"},
"co-eds":	{"NNS"},
"co-educate":	{"VB"},
"co-educational":	{"JJ"},
"co-exist":	{"VB","VBP"},
"co-existed":	{"VBD","VBN"},
"co-existence":	{"NN"},
"co-existing":	{"VBG"},
"co-exists":	{"VBZ"},
"co-extinction":	{"NN"},
"co-financing":	{"NN"},
"co-founder":	{"NN"},
"co-founders":	{"NNS"},
"co-head":	{"NN"},
"co-heads":	{"NNS"},
"co-hero":	{"NN"},
"co-host":	{"VB","NN","JJ"},
"co-insurance":	{"JJ","NN"},
"co-inventors":	{"NNS"},
"co-lead":	{"JJ"},
"co-leader":	{"NN"},
"co-leaders":	{"NNS"},
"co-major":	{"NN"},
"co-managed":	{"VBN","JJ","VBD"},
"co-manager":	{"NN"},
"co-managers":	{"NNS"},
"co-managing":	{"JJ","VBG"},
"co-marketing":	{"JJ"},
"co-obligation":	{"NN"},
"co-occur":	{"VB","VBP"},
"co-occurred":	{"VBD","VBN"},
"co-occurrence":	{"NN"},
"co-occurrent":	{"JJ"},
"co-occurring":	{"VBG"},
"co-occurs":	{"VBZ"},
"co-op":	{"NN","JJ"},
"co-operate":	{"VB","VBP"},
"co-operated":	{"VBD","VBN"},
"co-operates":	{"VBZ"},
"co-operating":	{"VBG"},
"co-operation":	{"NN"},
"co-operative":	{"JJ","NN"},
"co-operatively":	{"RB"},
"co-operatives":	{"NNS"},
"co-operator":	{"NN"},
"co-ops":	{"NNS"},
"co-opt":	{"VB","VBP"},
"co-optation":	{"NN"},
"co-opted":	{"VBD","VBN"},
"co-opting":	{"VBG"},
"co-option":	{"NN"},
"co-opts":	{"VBZ"},
"co-ordinate":	{"NN","VB","VBP","JJ"},
"co-ordinated":	{"VBD","VBN","JJ"},
"co-ordinates":	{"VBZ","NNS"},
"co-ordinating":	{"VBG"},
"co-ordination":	{"NN"},
"co-ordinator":	{"NN"},
"co-ordinators":	{"NNS"},
"co-own":	{"VB","VBP"},
"co-owned":	{"VBD","VBN"},
"co-owner":	{"NN"},
"co-ownership":	{"NN"},
"co-owning":	{"VBG"},
"co-owns":	{"VBZ"},
"co-parent":	{"NN","VB","VBP"},
"co-parented":	{"VBD","VBN"},
"co-parenting":	{"VBG"},
"co-parents":	{"NNS","VBZ"},
"co-pay":	{"NN"},
"co-payment":	{"NN"},
"co-payments":	{"NNS"},
"co-pilot":	{"NN"},
"co-pilots":	{"NNS"},
"co-plaintiff":	{"NN"},
"co-presidents":	{"NNS"},
"co-produce":	{"VB","VBP"},
"co-produced":	{"VBD","VBN","JJ"},
"co-producer":	{"NN","RB","JJ"},
"co-produces":	{"VBZ"},
"co-producing":	{"VBG"},
"co-production":	{"NN","JJ"},
"co-publisher":	{"NN"},
"co-referent":	{"JJ"},
"co-respondent":	{"NN"},
"co-star":	{"VB","VBP","NN"},
"co-starred":	{"VBD","VBN"},
"co-starring":	{"VBG"},
"co-stars":	{"NNS","VBZ"},
"co-vary":	{"VB"},
"co-venture":	{"NN"},
"co-worker":	{"JJ","NN"},
"co-workers":	{"NNS"},
"co-writer":	{"NN"},
"co-writers":	{"NNS"},
"co-written":	{"VBN"},
"co-wrote":	{"VBD"},
"co2":	{"NN"},
"coNterviews":	{"NNS"},
"coach":	{"NN","VBP","VB"},
"coach-and-four":	{"NN"},
"coachbuilder":	{"NN"},
"coached":	{"VBD","VBN"},
"coaches":	{"NNS","VBZ"},
"coaching":	{"NN","VBG"},
"coachman":	{"NN"},
"coachmen":	{"NNS"},
"coachwhip":	{"NN"},
"coachwork":	{"NN"},
"coact":	{"VB"},
"coaction":	{"NN"},
"coadjutor":	{"NN"},
"coagulable":	{"JJ"},
"coagulant":	{"NN"},
"coagulase":	{"NN"},
"coagulate":	{"VB","VBP"},
"coagulated":	{"VBD","VBN"},
"coagulates":	{"VBZ"},
"coagulating":	{"VBG"},
"coagulation":	{"NN"},
"coagulator":	{"NN"},
"coagulum":	{"NN"},
"coahse":	{"NN"},
"coahuila":	{"NN"},
"coal":	{"NN","VB","VBP"},
"coal-black":	{"JJ"},
"coal-burning":	{"JJ"},
"coal-fire":	{"JJ"},
"coal-fired":	{"VBD","VBN","JJ"},
"coal-like":	{"JJ"},
"coal-mining":	{"JJ"},
"coal-preparation":	{"JJ"},
"coal-railroad":	{"NN"},
"coal-seam-gas":	{"JJ"},
"coalbin":	{"NN"},
"coaled":	{"VBD","VBN"},
"coalesce":	{"VB","VBP"},
"coalesced":	{"VBD","VBN"},
"coalescence":	{"NN"},
"coalescency":	{"NN"},
"coalescent":	{"JJ"},
"coalesces":	{"VBZ"},
"coalescing":	{"VBG"},
"coalface":	{"NN"},
"coalfield":	{"NN"},
"coalfields":	{"NNS"},
"coalhole":	{"NN"},
"coaling":	{"VBG"},
"coalition":	{"NN"},
"coalitions":	{"NNS"},
"coalman":	{"NN"},
"coalmine":	{"NN"},
"coalminer":	{"NN"},
"coalminers":	{"NNS"},
"coalmines":	{"NNS"},
"coalpit":	{"NN"},
"coals":	{"NNS","VBZ"},
"coals-to-Newcastle":	{"JJ"},
"coals-to-newcastle":	{"JJ"},
"coaming":	{"NN"},
"coapt":	{"VB"},
"coarctate":	{"JJ"},
"coarctation":	{"NN"},
"coarse":	{"JJ"},
"coarse-furred":	{"JJ"},
"coarse-grained":	{"JJ"},
"coarse-haired":	{"JJ"},
"coarse-textured":	{"JJ"},
"coarsely":	{"RB"},
"coarsen":	{"VB","VBP"},
"coarsened":	{"VBD","VBN"},
"coarseness":	{"NN"},
"coarsening":	{"VBG"},
"coarsens":	{"VBZ"},
"coast":	{"NN","VB","VBP"},
"coast-based":	{"JJ"},
"coast-to-coast":	{"JJ"},
"coastal":	{"JJ"},
"coasted":	{"VBD","VBN"},
"coaster":	{"NN"},
"coasters":	{"NNS"},
"coastguard":	{"NN"},
"coastguards":	{"NNS"},
"coastguardsman":	{"NN"},
"coasting":	{"VBG"},
"coastland":	{"NN"},
"coastline":	{"NN"},
"coastlines":	{"NNS"},
"coasts":	{"NNS","VBZ"},
"coastward":	{"RB"},
"coastwise":	{"JJ","RB"},
"coat":	{"NN","VB","VBP"},
"coat-hanger":	{"NN"},
"coat-tails":	{"NNS"},
"coatdress":	{"NN"},
"coated":	{"VBD","VBN","JJ"},
"coated-magnetic":	{"JJ"},
"coatee":	{"NN"},
"coati":	{"NN"},
"coati-mondi":	{"NN"},
"coati-mundi":	{"NN"},
"coating":	{"NN","VBG"},
"coatings":	{"NNS"},
"coatrack":	{"NN"},
"coatroom":	{"NN"},
"coats":	{"NNS","VBZ"},
"coattail":	{"NN"},
"coattails":	{"NNS"},
"coauthor":	{"NN","VB","VBP"},
"coauthored":	{"VBD","VBN"},
"coauthoring":	{"VBG"},
"coauthors":	{"NNS","VBZ"},
"coax":	{"VB","VBP"},
"coaxal":	{"JJ"},
"coaxed":	{"VBD","VBN"},
"coaxer":	{"NN"},
"coaxes":	{"VBZ"},
"coaxial":	{"JJ"},
"coaxing":	{"NN","VBG"},
"coaxingly":	{"RB"},
"cob":	{"NN"},
"cobalamin":	{"NN"},
"cobalt":	{"NN","JJ"},
"cobalt-60":	{"NN"},
"cobaltite":	{"NN"},
"cobber":	{"NN"},
"cobble":	{"VB","VBP","NN"},
"cobbled":	{"VBD","VBN","JJ"},
"cobbler":	{"NN"},
"cobblers":	{"NNS"},
"cobbles":	{"VBZ","NNS"},
"cobblestone":	{"NN"},
"cobblestones":	{"NNS"},
"cobbling":	{"VBG"},
"cobbs":	{"NNS"},
"cobia":	{"NN"},
"cobitidae":	{"NN"},
"cobnut":	{"NN"},
"cobol":	{"NN"},
"cobra":	{"NN"},
"cobweb":	{"NN","VB","VBP"},
"cobwebbed":	{"VBD","VBN","JJ"},
"cobwebbing":	{"VBG"},
"cobwebby":	{"JJ"},
"cobwebs":	{"NNS","VBZ"},
"coca":	{"NN"},
"cocain":	{"NN"},
"cocaine":	{"NN"},
"cocaine-processing":	{"NN"},
"cocainise":	{"VB"},
"cocainize":	{"VB"},
"cocao":	{"NN"},
"cocarboxylase":	{"NN"},
"coccal":	{"JJ"},
"cocci":	{"NN"},
"coccidae":	{"NN"},
"coccidia":	{"NN"},
"coccidioidomycosis":	{"NN"},
"coccidiomycosis":	{"NN"},
"coccidiosis":	{"NN"},
"coccidium":	{"NN"},
"coccinellidae":	{"NN"},
"coccobacillus":	{"NN"},
"coccoid":	{"JJ"},
"coccoidea":	{"NN"},
"coccothraustes":	{"NNS"},
"cocculus":	{"NN"},
"coccus":	{"NN"},
"coccygeal":	{"JJ"},
"coccyx":	{"NN"},
"coccyzus":	{"NNS"},
"cochair":	{"NN","VB","VBP"},
"cochaired":	{"VBD","VBN"},
"cochairing":	{"VBG"},
"cochairman":	{"NN"},
"cochairmen":	{"NNS"},
"cochairperson":	{"NN"},
"cochairpersons":	{"NNS"},
"cochairs":	{"NNS","VBZ"},
"cochannel":	{"JJ","NN"},
"cochimi":	{"NN"},
"cochin":	{"NN"},
"cochineal":	{"NN"},
"cochise":	{"NN"},
"cochlea":	{"NN"},
"cochlear":	{"JJ","NN"},
"cochlearia":	{"NN"},
"cochlearius":	{"NN"},
"cochran":	{"NN"},
"cock":	{"NN","VB","VBP"},
"cock-a-doodle-doo":	{"NN"},
"cock-a-hoop":	{"JJ"},
"cock-a-leekie":	{"NN"},
"cockade":	{"NN"},
"cockaigne":	{"NN"},
"cockamamie":	{"JJ"},
"cockamamy":	{"JJ"},
"cockateel":	{"NN"},
"cockatiel":	{"NN"},
"cockatoo":	{"NN"},
"cockatoos":	{"NNS"},
"cockatrice":	{"NN"},
"cockchafer":	{"NN"},
"cockcroft":	{"NN"},
"cockcrow":	{"NN"},
"cocked":	{"VBD","VBN"},
"cocker":	{"NN"},
"cockered":	{"VBD","VBN"},
"cockerel":	{"NN"},
"cockering":	{"VBG"},
"cockers":	{"VBZ"},
"cockeyed":	{"JJ"},
"cockfight":	{"VB","NN"},
"cockfighting":	{"NN"},
"cockhorse":	{"NN"},
"cockier":	{"JJR"},
"cockiest":	{"JJS"},
"cockiness":	{"NN"},
"cocking":	{"VBG"},
"cockle":	{"NN","VB","VBP"},
"cockle-bur":	{"NN"},
"cockle-burr":	{"NN"},
"cocklebur":	{"NN"},
"cockleburr":	{"NN"},
"cockled":	{"VBD","VBN"},
"cockles":	{"NNS","VBZ"},
"cockleshell":	{"NN"},
"cockling":	{"VBG"},
"cockloft":	{"NN"},
"cockney":	{"NN","JJ"},
"cockneys":	{"NNS"},
"cockpit":	{"NN"},
"cockpits":	{"NNS"},
"cockroach":	{"NN"},
"cockroaches":	{"NNS"},
"cocks":	{"NNS","VBZ"},
"cockscomb":	{"NN"},
"cocksfoot":	{"NN"},
"cocksman":	{"NN"},
"cocksmen":	{"NNS"},
"cockspur":	{"NN"},
"cocksucker":	{"NN"},
"cocksure":	{"JJ"},
"cocksureness":	{"NN"},
"cocktail":	{"NN"},
"cocktails":	{"NNS"},
"cockup":	{"NN"},
"cocky":	{"JJ"},
"cocky-leeky":	{"NN"},
"coco":	{"NN"},
"cocoa":	{"NN"},
"cocoa-trading":	{"JJ"},
"cocoanut":	{"NN"},
"cocobolo":	{"NN"},
"coconspirator":	{"NN"},
"coconspire":	{"VB"},
"coconut":	{"NN"},
"coconut-containing":	{"JJ"},
"coconut-lime":	{"JJ"},
"coconuts":	{"NNS"},
"cocoon":	{"NN","VB","VBP"},
"cocooned":	{"VBD","VBN","JJ"},
"cocooning":	{"VBG"},
"cocoons":	{"NNS","VBZ"},
"cocopa":	{"NN"},
"cocopah":	{"NN"},
"cocopalm":	{"NN"},
"cocos":	{"NNS"},
"cocoswood":	{"NN"},
"cocotte":	{"NN"},
"cocoyam":	{"NN"},
"cocozelle":	{"NN"},
"cocteau":	{"NN"},
"cocu":	{"NN"},
"cocus":	{"NN"},
"cocuswood":	{"NN"},
"cocytus":	{"NNS"},
"cod":	{"NN","NNS","JJ"},
"cod-liver":	{"NN"},
"coda":	{"NN"},
"codariocalyx":	{"NN"},
"codded":	{"VBD","VBN"},
"codding":	{"VBG"},
"coddle":	{"VB","VBP"},
"coddled":	{"VBD","VBN"},
"coddler":	{"NN"},
"coddles":	{"VBZ"},
"coddling":	{"VBG"},
"code":	{"NN","VB","VBP"},
"code-name":	{"VB","VBP"},
"code-named":	{"VBN","VBD"},
"code-names":	{"VBZ"},
"code-naming":	{"VBG"},
"code-related":	{"JJ"},
"code-sharing":	{"NN"},
"coded":	{"JJ","VBD","VBN"},
"codefendant":	{"NN"},
"codeine":	{"NN"},
"codependencies":	{"NNS"},
"codependency":	{"NN"},
"codependent":	{"NN"},
"coder":	{"NN"},
"codes":	{"NNS","VBZ"},
"codetalker":	{"NN"},
"codetermines":	{"VBZ"},
"codevelop":	{"VB","VBP"},
"codeveloped":	{"VBD","VBN"},
"codeveloper":	{"NN"},
"codevelopers":	{"NNS"},
"codeveloping":	{"VBG"},
"codevelops":	{"VBZ"},
"codeword":	{"NN"},
"codewords":	{"NNS"},
"codex":	{"NN"},
"codfish":	{"NN"},
"codger":	{"NN"},
"codgers":	{"NNS"},
"codiaeum":	{"NN"},
"codicil":	{"NN"},
"codicils":	{"NNS"},
"codification":	{"NN"},
"codified":	{"VBD","VBN"},
"codifies":	{"VBZ"},
"codify":	{"VB","VBP"},
"codifying":	{"VBG"},
"coding":	{"NN","VBG"},
"codirect":	{"VB","VBP"},
"codirected":	{"VBD","VBN"},
"codirecting":	{"VBG"},
"codirection":	{"NN"},
"codirectional":	{"JJ"},
"codirectionally":	{"RB"},
"codirections":	{"NNS"},
"codirector":	{"NN"},
"codirectors":	{"NNS"},
"codirects":	{"VBZ"},
"codiscover":	{"VB","VBP"},
"codiscovered":	{"VBD","VBN"},
"codiscoverer":	{"NN"},
"codiscoverers":	{"NNS"},
"codiscovering":	{"VBG"},
"codiscovers":	{"VBZ"},
"codling":	{"NN"},
"codlins-and-cream":	{"NN"},
"codon":	{"NN"},
"codpiece":	{"NN"},
"codpieces":	{"NNS"},
"cods":	{"VBZ"},
"codswallop":	{"NN"},
"coed":	{"NN","JJ"},
"coeditor":	{"NN"},
"coeditors":	{"NNS"},
"coedna":	{"NN"},
"coeds":	{"NNS"},
"coeducate":	{"VB"},
"coeducation":	{"NN"},
"coeducational":	{"JJ"},
"coefficient":	{"NN"},
"coefficients":	{"NNS"},
"coelacanth":	{"NN"},
"coelenterata":	{"NN"},
"coelenterate":	{"NN"},
"coelenteron":	{"NN"},
"coeliac":	{"JJ"},
"coeloglossum":	{"NN"},
"coelogyne":	{"NN"},
"coelom":	{"NN"},
"coelophysis":	{"NN"},
"coelostat":	{"NN"},
"coenobite":	{"NN"},
"coenobitic":	{"JJ"},
"coenobitical":	{"JJ"},
"coenzyme":	{"NN"},
"coequal":	{"JJ","NN"},
"coerce":	{"VB","VBP"},
"coerced":	{"VBD","VBN"},
"coerces":	{"VBZ"},
"coercing":	{"VBG"},
"coercion":	{"NN"},
"coercive":	{"JJ"},
"coercively":	{"RB"},
"coereba":	{"NN"},
"coerebidae":	{"NN"},
"coetaneous":	{"JJ"},
"coeur":	{"NN"},
"coeval":	{"JJ","NN"},
"coevals":	{"NNS"},
"coexist":	{"VB","NN","VBP"},
"coexisted":	{"VBD","VBN"},
"coexistence":	{"NN"},
"coexistent":	{"JJ"},
"coexisting":	{"VBG"},
"coexists":	{"VBZ"},
"coextension":	{"NN"},
"coextensive":	{"JJ"},
"coextrude":	{"VBP","VB"},
"cofactor":	{"NN"},
"cofactors":	{"NNS"},
"coffea":	{"NN"},
"coffee":	{"NN"},
"coffee-house":	{"NN"},
"coffee-roasting":	{"JJ"},
"coffee-shop":	{"NN"},
"coffeeberry":	{"NN"},
"coffeecake":	{"NN"},
"coffeecup":	{"NN"},
"coffeehouse":	{"NN"},
"coffeepot":	{"NN"},
"coffees":	{"NNS"},
"coffer":	{"NN"},
"cofferdam":	{"NN"},
"coffered":	{"VBD","VBN"},
"coffering":	{"VBG"},
"coffers":	{"NNS","VBZ"},
"coffey":	{"NN"},
"coffin":	{"NN"},
"coffin-sized":	{"JJ"},
"coffined":	{"VBD","VBN"},
"coffining":	{"VBG"},
"coffins":	{"NNS","VBZ"},
"cofinance":	{"VB","VBP"},
"cofinanced":	{"VBD","VBN"},
"cofinances":	{"VBZ"},
"cofinancing":	{"VBG","NN"},
"cofound":	{"VB","VBP"},
"cofounded":	{"VBD","VBN"},
"cofounder":	{"NN"},
"cofounders":	{"NNS"},
"cofounding":	{"VBG"},
"cofounds":	{"VBZ"},
"cog":	{"NN"},
"cog-railway":	{"NN"},
"cogency":	{"NN"},
"cogeneration":	{"NN"},
"cogeneration-plant":	{"NN"},
"cogent":	{"JJ","NN"},
"cogently":	{"RB"},
"cogged":	{"JJ","VBD","VBN"},
"cogging":	{"VBG"},
"coggle":	{"VB"},
"cogitable":	{"JJ"},
"cogitate":	{"VB","VBP"},
"cogitated":	{"VBD","VBN"},
"cogitates":	{"VBZ"},
"cogitating":	{"VBG"},
"cogitation":	{"NN"},
"cogitative":	{"JJ"},
"cognac":	{"NN"},
"cognate":	{"NN","JJ"},
"cognation":	{"NN"},
"cognisable":	{"JJ"},
"cognisance":	{"NN"},
"cognisant":	{"JJ"},
"cognise":	{"VB"},
"cognition":	{"NN"},
"cognitive":	{"JJ","NN"},
"cognitively":	{"RB"},
"cognizable":	{"JJ"},
"cognizance":	{"NN"},
"cognizant":	{"JJ","NN"},
"cognize":	{"VB"},
"cognomen":	{"NN"},
"cognoscente":	{"NN"},
"cognoscenti":	{"NNS"},
"cognoscible":	{"JJ"},
"cogs":	{"NNS","VBZ"},
"cogwheel":	{"NN"},
"cohabit":	{"VB","VBP"},
"cohabitation":	{"NN"},
"cohabited":	{"VBD","VBN"},
"cohabiting":	{"VBG"},
"cohabits":	{"VBZ"},
"cohan":	{"NN"},
"cohere":	{"VB","VBP"},
"cohered":	{"VBD","VBN"},
"coherence":	{"NN"},
"coherency":	{"NN"},
"coherent":	{"JJ"},
"coherently":	{"RB"},
"coheres":	{"VBZ"},
"cohering":	{"VBG"},
"cohesion":	{"NN"},
"cohesive":	{"JJ"},
"cohesively":	{"RB"},
"cohesiveness":	{"NN"},
"cohn":	{"NN"},
"cohnfidunt":	{"NN"},
"coho":	{"NN","NNS"},
"cohoe":	{"NN"},
"cohort":	{"NN"},
"cohorts":	{"NNS"},
"cohosh":	{"NN"},
"cohune":	{"NN"},
"coif":	{"NN","VB","VBP"},
"coifed":	{"VBD","VBN"},
"coiffe":	{"VB"},
"coiffed":	{"JJ","VBD","VBN"},
"coiffeur":	{"NN"},
"coiffeuse":	{"NN"},
"coiffing":	{"VBG"},
"coiffure":	{"NN"},
"coifing":	{"VBG"},
"coifs":	{"VBZ","NNS"},
"coign":	{"NN"},
"coigne":	{"NN"},
"coigue":	{"NN"},
"coil":	{"NN","VB","VBP"},
"coiled":	{"VBD","VBN","JJ"},
"coiling":	{"VBG"},
"coils":	{"NNS","VBZ"},
"coily":	{"RB"},
"coin":	{"NN","VBP","VB"},
"coin-cleaning":	{"JJ"},
"coin-operated":	{"JJ"},
"coinage":	{"NN"},
"coincide":	{"VB","VBP"},
"coincided":	{"VBD","VBN"},
"coincidence":	{"NN"},
"coincidences":	{"NNS"},
"coincident":	{"JJ"},
"coincidental":	{"JJ"},
"coincidentally":	{"RB"},
"coincidently":	{"RB"},
"coincides":	{"VBZ"},
"coinciding":	{"VBG"},
"coined":	{"VBD","VBN"},
"coiner":	{"NN"},
"coining":	{"VBG"},
"coins":	{"NNS","VBZ"},
"coinsurance":	{"NN"},
"coinsure":	{"VB"},
"coir":	{"NN"},
"coital":	{"JJ"},
"coition":	{"NN"},
"coitus":	{"NN"},
"coke":	{"NN","VB","VBP"},
"coked":	{"VBD","VBN"},
"cokes":	{"NNS","VBZ"},
"coking":	{"VBG"},
"col":	{"NN"},
"cola":	{"NN"},
"colander":	{"NN"},
"colaptes":	{"NNS"},
"colas":	{"NNS"},
"colbert":	{"NN"},
"colchicaceae":	{"NN"},
"colchicine":	{"NN"},
"colchicum":	{"NN"},
"colchis":	{"NN"},
"cold":	{"JJ","NN","RB"},
"cold-blooded":	{"JJ"},
"cold-bloodedly":	{"RB"},
"cold-cereal":	{"JJ"},
"cold-cream":	{"VB"},
"cold-cuts":	{"NNS"},
"cold-eyed":	{"JJ"},
"cold-rolled":	{"JJ"},
"cold-shoulder":	{"VB","VBP","NN"},
"cold-shouldered":	{"VBD","VBN"},
"cold-shouldering":	{"VBG"},
"cold-shoulders":	{"VBZ"},
"cold-storage":	{"JJ"},
"cold-temperate":	{"JJ"},
"cold-war":	{"JJ"},
"cold-weather":	{"JJ"},
"coldblooded":	{"JJ"},
"coldbloodedly":	{"RB"},
"coldbloodedness":	{"NN"},
"coldcock":	{"VB"},
"coldcream":	{"NN"},
"colde":	{"MD"},
"colder":	{"JJR"},
"coldest":	{"JJS"},
"coldhearted":	{"JJ"},
"coldheartedness":	{"NN"},
"coldly":	{"RB"},
"coldness":	{"NN"},
"colds":	{"NNS"},
"coldwork":	{"VB"},
"coleonyx":	{"NN"},
"coleoptera":	{"NN"},
"coleridgean":	{"JJ"},
"coleridgian":	{"JJ"},
"coleslaw":	{"NN"},
"coleus":	{"NN"},
"coleuses":	{"NNS"},
"colewort":	{"NN"},
"colic":	{"NN"},
"colicky":	{"JJ"},
"colicroot":	{"NN"},
"colima":	{"NN"},
"colinus":	{"NN"},
"coliphage":	{"NN"},
"coliseum":	{"NN"},
"colitis":	{"NN"},
"collaborate":	{"VB","VBP"},
"collaborated":	{"VBD","VBN"},
"collaborates":	{"VBZ"},
"collaborating":	{"VBG"},
"collaboration":	{"NN"},
"collaborationism":	{"NN"},
"collaborationist":	{"JJ"},
"collaborations":	{"NNS"},
"collaborative":	{"JJ"},
"collaboratively":	{"RB"},
"collaborator":	{"NN"},
"collaborators":	{"NNS"},
"collage":	{"NN","VB","VBP"},
"collaged":	{"VBD","VBN","JJ"},
"collagen":	{"NN"},
"collagenase":	{"NN"},
"collagenic":	{"JJ"},
"collagenous":	{"JJ"},
"collages":	{"NNS","VBZ"},
"collaging":	{"VBG"},
"collagist":	{"NN"},
"collagists":	{"NNS"},
"collapsable":	{"JJ"},
"collapse":	{"NN","VB","VBP"},
"collapsed":	{"VBD","VBN"},
"collapses":	{"VBZ"},
"collapsible":	{"JJ"},
"collapsing":	{"VBG"},
"collar":	{"NN","VB","VBP"},
"collar-to-collar":	{"JJ"},
"collarbone":	{"NN"},
"collarbones":	{"NNS"},
"collard":	{"NN"},
"collards":	{"NNS"},
"collared":	{"VBN","VBD"},
"collaring":	{"VBG"},
"collarless":	{"JJ"},
"collars":	{"NNS","VBZ"},
"collate":	{"VB","VBP"},
"collated":	{"VBD","VBN"},
"collateral":	{"NN","JJ"},
"collateralize":	{"VB","VBP"},
"collateralized":	{"VBN","VBD"},
"collateralizes":	{"VBZ"},
"collateralizing":	{"VBG"},
"collates":	{"VBZ"},
"collating":	{"VBG"},
"collation":	{"NN"},
"colleague":	{"NN"},
"colleagues":	{"NNS"},
"collect":	{"VB","RB","JJ","VBP","NN"},
"collectability":	{"NN"},
"collectable":	{"JJ","NN"},
"collected":	{"VBN","VBD","JJ"},
"collectedly":	{"RB"},
"collectible":	{"JJ","NN"},
"collectibles":	{"NNS"},
"collecting":	{"VBG","JJ","NN"},
"collection":	{"NN"},
"collections":	{"NNS"},
"collective":	{"JJ","NN"},
"collective-bargaining":	{"NN"},
"collectively":	{"RB"},
"collectives":	{"NNS"},
"collectivisation":	{"NN"},
"collectivise":	{"VB","VBP"},
"collectivised":	{"VBD","VBN"},
"collectivises":	{"VBZ"},
"collectivising":	{"VBG"},
"collectivism":	{"NN"},
"collectivist":	{"JJ"},
"collectivistic":	{"JJ"},
"collectivization":	{"NN"},
"collectivize":	{"VB","VBP"},
"collectivized":	{"VBD","VBN"},
"collectivizers":	{"NNS"},
"collectivizes":	{"VBZ"},
"collectivizing":	{"VBG"},
"collector":	{"NN"},
"collectors":	{"NNS"},
"collects":	{"VBZ","NNS"},
"colleen":	{"NN"},
"college":	{"NN"},
"college-bound":	{"JJ"},
"college-bowl":	{"NN"},
"college-completion":	{"JJ"},
"college-educated":	{"JJ"},
"college-oriented":	{"JJ"},
"college-sports":	{"NNS","JJ"},
"collegers":	{"NNS"},
"colleges":	{"NNS"},
"collegial":	{"JJ"},
"collegian":	{"NN","JJ"},
"collegians":	{"NNS"},
"collegiate":	{"JJ"},
"colleging":	{"NN"},
"collembola":	{"NN"},
"collembolan":	{"NN"},
"colles":	{"FW"},
"collet":	{"NN"},
"collide":	{"VB","NN","VBP"},
"collided":	{"VBD","VBN"},
"collider":	{"NN"},
"collides":	{"VBZ"},
"colliding":	{"VBG"},
"collie":	{"NN"},
"collied":	{"VBD","VBN"},
"collier":	{"NN"},
"colliery":	{"NN"},
"collies":	{"NNS","VBZ"},
"colligate":	{"VB"},
"colligation":	{"NN"},
"collimate":	{"VB"},
"collimated":	{"VBN"},
"collimation":	{"NN"},
"collimator":	{"NN"},
"collinear":	{"JJ"},
"collinsia":	{"NN"},
"collinsonia":	{"NN"},
"collision":	{"NN"},
"collision-damage":	{"NN"},
"collisions":	{"NNS"},
"collocalia":	{"NN"},
"collocate":	{"VB","VBP","NN"},
"collocated":	{"VBD","VBN"},
"collocates":	{"VBZ","NNS"},
"collocating":	{"VBG"},
"collocation":	{"NN"},
"collocations":	{"NNS"},
"collodion":	{"NN"},
"collogue":	{"VB"},
"colloid":	{"NN","JJ"},
"colloidal":	{"JJ"},
"colloidally":	{"RB"},
"colloquial":	{"JJ","NN"},
"colloquialism":	{"NN"},
"colloquially":	{"RB"},
"colloquies":	{"NNS"},
"colloquium":	{"NN"},
"colloquy":	{"NN"},
"collosal":	{"JJ"},
"collotype":	{"NN"},
"collude":	{"VB","VBP"},
"colluded":	{"VBD","VBN"},
"colludes":	{"VBZ"},
"colluding":	{"VBG"},
"collusion":	{"NN"},
"collusive":	{"JJ"},
"colly":	{"NN","VB","VBP"},
"collying":	{"VBG"},
"collyrium":	{"NN"},
"collywobbles":	{"NNS"},
"colo-rectal":	{"JJ"},
"colobus":	{"NN"},
"colocasia":	{"NN"},
"cologne":	{"NN"},
"colognes":	{"NNS"},
"colombo":	{"NN"},
"colon":	{"NN"},
"colon-cancer":	{"NN"},
"colonel":	{"NN"},
"colonels":	{"NNS"},
"colonial":	{"JJ","NN"},
"colonialism":	{"NN"},
"colonialist":	{"NN","JJ"},
"colonialists":	{"NNS"},
"colonials":	{"NNS"},
"colonic":	{"JJ","NN"},
"colonies":	{"NNS"},
"colonisation":	{"NN"},
"colonise":	{"VB","VBP"},
"colonised":	{"VBD","VBN"},
"coloniser":	{"NN"},
"colonises":	{"VBZ"},
"colonising":	{"VBG"},
"colonist":	{"NN"},
"colonists":	{"NNS"},
"colonization":	{"NN"},
"colonize":	{"VB","VBP"},
"colonized":	{"VBD","VBN"},
"colonizer":	{"NN"},
"colonizes":	{"VBZ"},
"colonizing":	{"VBG"},
"colonnade":	{"NN"},
"colonnaded":	{"JJ"},
"colonography":	{"NN"},
"colonoscope":	{"NN"},
"colonoscopy":	{"NN"},
"colony":	{"NN"},
"colophon":	{"NN"},
"colophony":	{"NN"},
"color":	{"NN","VB","VBP","JJ"},
"color-TV":	{"NN"},
"color-blind":	{"JJ"},
"color-coded":	{"VBD","VBN"},
"color-coding":	{"VBG"},
"color-field":	{"JJ"},
"color-glutted":	{"JJ"},
"color-printing":	{"JJ"},
"color-television":	{"NN"},
"color-tv":	{"NN"},
"coloradan":	{"NN"},
"coloradillo":	{"NN"},
"colorado":	{"NN"},
"colorado-based":	{"JJ"},
"colorama":	{"NN"},
"coloration":	{"NN"},
"coloratura":	{"NN"},
"colorblind":	{"NN","JJ"},
"colorblindness":	{"NN"},
"colorcast":	{"NN","VB","VBP","VBD","VBN"},
"colorcasted":	{"VBD","VBN"},
"colorcasting":	{"VBG"},
"colorcasts":	{"NNS","VBZ"},
"colorectal":	{"JJ","NN"},
"colorectum":	{"NN"},
"colored":	{"JJ","VBN","VBD","NN"},
"coloreds":	{"NNS"},
"colorfast":	{"JJ"},
"colorful":	{"JJ"},
"colorimeter":	{"NN"},
"colorimetric":	{"JJ"},
"colorimetrical":	{"JJ"},
"colorimetry":	{"NN"},
"coloring":	{"NN","VBG"},
"colorist":	{"NN"},
"colorization":	{"NN"},
"colorize":	{"VB","VBP"},
"colorized":	{"VBD","VBN"},
"colorizes":	{"VBZ"},
"colorizing":	{"VBG"},
"colorless":	{"JJ"},
"colorlessly":	{"RB"},
"colorlessness":	{"NN"},
"colors":	{"NNS","VBZ"},
"colossae":	{"NN"},
"colossal":	{"JJ","NN"},
"colosseum":	{"NN"},
"colossian":	{"NN"},
"colossians":	{"NNS"},
"colossus":	{"NN"},
"colostomy":	{"NN"},
"colostrum":	{"NN"},
"colour":	{"NN","VB","VBP","JJ"},
"colour-blind":	{"JJ"},
"colour-blindness":	{"NN"},
"colour-prints":	{"NNS"},
"colouration":	{"NN"},
"colourcast":	{"NN"},
"coloured":	{"JJ","VBD","VBN","NN"},
"coloureds":	{"NNS"},
"colourful":	{"JJ"},
"colourfully":	{"RB"},
"colouring":	{"NN","VBG"},
"colourize":	{"VB","VBP"},
"colourized":	{"VBD","VBN"},
"colourizes":	{"VBZ"},
"colourizing":	{"VBG"},
"colourless":	{"JJ"},
"colourlessly":	{"RB"},
"colourlessness":	{"NN"},
"colours":	{"NNS","VBZ"},
"colpitis":	{"NNS"},
"colpocele":	{"NN"},
"colpocystitis":	{"NNS"},
"colpocystocele":	{"NN"},
"colpoxerosis":	{"NN"},
"colt":	{"NN"},
"coltan":	{"NN"},
"colter":	{"NN"},
"coltish":	{"NN","JJ"},
"colts":	{"NNS"},
"coltsfoot":	{"NN"},
"coltsman":	{"NN"},
"coluber":	{"NN"},
"colubrid":	{"NN"},
"colubridae":	{"NN"},
"colubrina":	{"NN"},
"colugo":	{"NN"},
"columba":	{"NN"},
"columbarium":	{"NN"},
"columbary":	{"NN"},
"columbia":	{"NN"},
"columbian":	{"JJ"},
"columbidae":	{"NN"},
"columbiformes":	{"NNS"},
"columbine":	{"NN"},
"columbines":	{"NNS"},
"columbite":	{"NN"},
"columbite-tantalite":	{"NN"},
"columbium":	{"NN"},
"columbo":	{"NN"},
"columbus":	{"NN"},
"columella":	{"NN"},
"column":	{"NN"},
"column-shaped":	{"JJ"},
"columnar":	{"JJ"},
"columnea":	{"NN"},
"columned":	{"JJ"},
"columniation":	{"NN"},
"columniform":	{"JJ"},
"columnist":	{"NN"},
"columnists":	{"NNS"},
"columnlike":	{"JJ"},
"columns":	{"NNS"},
"colutea":	{"NN"},
"colymbiformes":	{"NNS"},
"colza":	{"NN"},
"com":	{"NN"},
"coma":	{"NN"},
"comal":	{"JJ"},
"comanche":	{"NN"},
"comandancia":	{"FW"},
"comandra":	{"NN"},
"comas":	{"NNS"},
"comate":	{"JJ"},
"comatose":	{"JJ","NN"},
"comatoseness":	{"NN"},
"comatula":	{"NN"},
"comatulid":	{"NN"},
"comatulidae":	{"NN"},
"comb":	{"NN","VB","VBP"},
"comb-like":	{"JJ"},
"comb-out":	{"NN"},
"comb-plate":	{"NN"},
"combat":	{"NN","VB","VBP"},
"combat-inflicted":	{"JJ"},
"combat-ready":	{"JJ"},
"combat-tested":	{"JJ"},
"combat-trained":	{"JJ"},
"combatant":	{"NN"},
"combatants":	{"NNS"},
"combated":	{"VBD","VBN"},
"combating":	{"VBG"},
"combative":	{"JJ","NN"},
"combatively":	{"RB"},
"combativeness":	{"NN"},
"combats":	{"VBZ","NNS"},
"combatted":	{"VBD","VBN"},
"combatting":	{"VBG"},
"combed":	{"VBD","VBN"},
"comber":	{"NN"},
"combinable":	{"JJ"},
"combination":	{"NN"},
"combinational":	{"JJ"},
"combinations":	{"NNS"},
"combinative":	{"JJ"},
"combinatorial":	{"JJ"},
"combinatory":	{"JJ"},
"combine":	{"VB","NN","VBP"},
"combined":	{"VBN","JJ","VBD"},
"combines":	{"VBZ","NNS"},
"combing":	{"NN","VBG"},
"combining":	{"VBG"},
"combo":	{"NN"},
"combos":	{"NNS"},
"combretaceae":	{"NN"},
"combretum":	{"NN"},
"combs":	{"VBZ","NNS"},
"comburant":	{"JJ"},
"comburent":	{"JJ"},
"combust":	{"JJ","VB","VBP"},
"combusted":	{"VBD","VBN"},
"combustibility":	{"NN"},
"combustible":	{"JJ","NN"},
"combustibleness":	{"NN"},
"combustibles":	{"NNS"},
"combusting":	{"VBG"},
"combustion":	{"NN"},
"combustive":	{"JJ"},
"combusts":	{"VBZ"},
"come":	{"VB","VBN","VBP"},
"come-at-able":	{"JJ"},
"come-on":	{"NN"},
"come-uppance":	{"NN"},
"comeback":	{"NN"},
"comebacks":	{"NNS","VBZ"},
"comedian":	{"NN"},
"comedians":	{"NNS"},
"comedic":	{"JJ"},
"comedie":	{"NN"},
"comedienne":	{"NN"},
"comedies":	{"NNS"},
"comedo":	{"NN"},
"comedown":	{"NN"},
"comedy":	{"NN"},
"comedy-oriented":	{"JJ"},
"comeliness":	{"NN"},
"comely":	{"JJ","RB"},
"comend":	{"VB"},
"comenius":	{"NNS"},
"comer":	{"NN"},
"comers":	{"NNS"},
"comes":	{"VBZ"},
"comest":	{"VBP","VB"},
"comestible":	{"JJ","NN"},
"comestibles":	{"NNS"},
"comet":	{"NN"},
"comet-like":	{"JJ"},
"cometary":	{"JJ"},
"cometh":	{"VBZ"},
"cometic":	{"JJ"},
"comets":	{"NNS"},
"comeupance":	{"NN"},
"comeuppance":	{"NN"},
"comfit":	{"NN","VB"},
"comfort":	{"NN","VB","VBP"},
"comfortable":	{"JJ"},
"comfortableness":	{"NN"},
"comfortably":	{"RB"},
"comforted":	{"VBD","VBN"},
"comforter":	{"NN"},
"comforting":	{"JJ","VBG"},
"comfortingly":	{"RB"},
"comfortless":	{"JJ"},
"comforts":	{"VBZ","NNS"},
"comfrey":	{"NN"},
"comfy":	{"JJ","NN"},
"comic":	{"JJ","NN"},
"comical":	{"JJ","NN"},
"comicality":	{"NN"},
"comically":	{"RB"},
"comico-romantico":	{"JJ"},
"comics":	{"NNS"},
"coming":	{"VBG","JJ","NN"},
"coming-of-age":	{"JJ"},
"coming-out":	{"JJ"},
"comings":	{"NNS"},
"comint":	{"NN"},
"comiskey":	{"NN"},
"comity":	{"NN"},
"comma":	{"NN"},
"command":	{"NN","VB","VBP"},
"command-and-control":	{"JJ"},
"commandant":	{"NN"},
"commanded":	{"VBD","VBN"},
"commandeer":	{"VB","VBP"},
"commandeered":	{"VBD","VBN"},
"commandeering":	{"VBG"},
"commandeers":	{"VBZ"},
"commander":	{"NN"},
"commander-in-chief":	{"JJ","NN"},
"commanders":	{"NNS"},
"commandership":	{"NN"},
"commandery":	{"NN"},
"commanding":	{"JJ","NN","VBG"},
"commandment":	{"NN"},
"commandments":	{"NNS"},
"commando":	{"NN"},
"commando-trained":	{"VBD","VBN"},
"commandos":	{"NNS"},
"commands":	{"NNS","VBZ"},
"commas":	{"NNS"},
"commelina":	{"NN"},
"commelinaceae":	{"NN"},
"commelinales":	{"NNS"},
"commelinidae":	{"NN"},
"commemorate":	{"VB","VBP"},
"commemorated":	{"VBD","VBN"},
"commemorates":	{"VBZ"},
"commemorating":	{"VBG"},
"commemoration":	{"NN"},
"commemorative":	{"JJ"},
"commence":	{"VB","NN","VBP"},
"commenced":	{"VBD","VBN"},
"commencement":	{"NN"},
"commencements":	{"NNS"},
"commences":	{"VBZ","NNS"},
"commencing":	{"VBG","NN"},
"commend":	{"VB","VBP"},
"commendable":	{"JJ"},
"commendably":	{"RB"},
"commendation":	{"NN"},
"commendations":	{"NNS"},
"commended":	{"VBD","VBN"},
"commending":	{"VBG"},
"commends":	{"VBZ"},
"commensal":	{"JJ","NN"},
"commensalism":	{"NN"},
"commensally":	{"RB"},
"commensurable":	{"JJ"},
"commensurate":	{"JJ"},
"commensurateness":	{"NN"},
"comment":	{"VB","VBP","NN"},
"commentaries":	{"NNS"},
"commentary":	{"NN"},
"commentate":	{"VB","VBP"},
"commentated":	{"VBD","VBN"},
"commentates":	{"VBZ"},
"commentating":	{"VBG"},
"commentator":	{"NN"},
"commentators":	{"NNS"},
"commented":	{"VBD","VBN"},
"commenting":	{"VBG"},
"comments":	{"NNS","VBZ"},
"commerce":	{"NN"},
"commercial":	{"JJ","NN"},
"commercial-bank":	{"JJ","NN"},
"commercial-banking":	{"NN","JJ"},
"commercial-credit":	{"NN"},
"commercial-free":	{"JJ"},
"commercial-goods":	{"NNS"},
"commercial-grade":	{"JJ"},
"commercial-industrial":	{"JJ"},
"commercial-jetliner":	{"JJ"},
"commercial-litigation":	{"NN"},
"commercial-loan":	{"JJ","NN"},
"commercial-products":	{"JJ"},
"commercial-property":	{"NN"},
"commercial-satellite-launching":	{"JJ"},
"commercial-switch":	{"JJ"},
"commercialisation":	{"NN"},
"commercialise":	{"VB","VBP"},
"commercialised":	{"VBD","VBN"},
"commercialises":	{"VBZ"},
"commercialising":	{"VBG"},
"commercialism":	{"NN"},
"commercialization":	{"NN"},
"commercialize":	{"VB","VBP"},
"commercialized":	{"VBD","VBN"},
"commercializes":	{"VBZ"},
"commercializing":	{"VBG"},
"commercially":	{"RB"},
"commercials":	{"NNS"},
"commerical":	{"JJ"},
"commie":	{"NN"},
"comminate":	{"VB"},
"commination":	{"NN"},
"comminatory":	{"JJ"},
"comminge":	{"VBG"},
"commingle":	{"VB","VBP"},
"commingled":	{"VBD","VBN"},
"commingles":	{"VBZ"},
"commingling":	{"VBG","NN"},
"comminute":	{"VB"},
"commiphora":	{"NN"},
"commiserate":	{"VB","VBP"},
"commiserated":	{"VBD","VBN"},
"commiserates":	{"VBZ"},
"commiserating":	{"VBG"},
"commiseration":	{"NN"},
"commiserations":	{"NNS"},
"commiserative":	{"JJ"},
"commissar":	{"NN"},
"commissariat":	{"NN"},
"commissaries":	{"NNS"},
"commissary":	{"NN"},
"commission":	{"NN","VBP","VB"},
"commission-controlled":	{"JJ"},
"commission-driven":	{"JJ"},
"commissionaire":	{"NN"},
"commissionaires":	{"NNS"},
"commissioned":	{"VBN","VBD"},
"commissioner":	{"NN"},
"commissioners":	{"NNS"},
"commissioning":	{"NN","VBG"},
"commissions":	{"NNS","VBZ"},
"commissure":	{"NN"},
"commit":	{"VB","VBP"},
"commitment":	{"NN"},
"commitments":	{"NNS"},
"commits":	{"VBZ"},
"committal":	{"NN"},
"committals":	{"NNS"},
"committed":	{"VBN","VBD","JJ"},
"committedness":	{"NN"},
"committee":	{"NN"},
"committeeman":	{"NN"},
"committeemen":	{"NNS"},
"committees":	{"NNS"},
"committeewoman":	{"NN"},
"committeewomen":	{"NNS"},
"committing":	{"VBG"},
"committment":	{"NN"},
"commix":	{"VB","VBP"},
"commixed":	{"VBD","VBN"},
"commixes":	{"VBZ"},
"commixing":	{"VBG"},
"commixture":	{"NN"},
"commmercial":	{"JJ"},
"commmon":	{"JJ"},
"commmuter":	{"NN"},
"commode":	{"NN"},
"commodious":	{"JJ"},
"commodiousness":	{"NN"},
"commodities":	{"NNS"},
"commodities-related":	{"JJ"},
"commoditisation":	{"NN"},
"commoditise":	{"VB","VBP"},
"commoditised":	{"VBD","VBN"},
"commoditises":	{"VBZ"},
"commoditising":	{"VBG"},
"commoditization":	{"NN"},
"commoditize":	{"VB","VBP"},
"commoditized":	{"VBD","VBN"},
"commoditizes":	{"VBZ"},
"commoditizing":	{"VBG"},
"commodity":	{"NN"},
"commodity-chemical":	{"JJ"},
"commodity-market":	{"NN"},
"commodity-options":	{"NNS"},
"commodity-oriented":	{"JJ"},
"commodity-price":	{"JJ"},
"commodity-swap":	{"NN"},
"commodity-trading":	{"NN"},
"commodore":	{"NN"},
"common":	{"JJ","NN"},
"common-carrier":	{"NN"},
"common-law":	{"NN","JJ"},
"common-law-marriage":	{"NN"},
"common-position":	{"JJ"},
"common-sense":	{"JJ","NN"},
"common-sensical":	{"JJ"},
"common-share":	{"JJ"},
"common-stock":	{"JJ","NN"},
"commonage":	{"NN"},
"commonality":	{"NN"},
"commonalty":	{"NN"},
"commoner":	{"NN","JJR"},
"commoners":	{"NNS"},
"commonest":	{"JJS"},
"commonly":	{"RB"},
"commonness":	{"NN"},
"commonplace":	{"JJ","NN"},
"commonplaceness":	{"NN"},
"commonplaces":	{"NNS"},
"commons":	{"NNS"},
"commonsense":	{"JJ","NN"},
"commonsensible":	{"JJ"},
"commonsensical":	{"JJ"},
"commonstock":	{"NN"},
"commonweal":	{"NN"},
"commonwealth":	{"NN"},
"commonwealths":	{"NNS"},
"commotio":	{"NN"},
"commotion":	{"NN"},
"commove":	{"VB"},
"commoved":	{"VBD","VBN"},
"commoves":	{"VBZ"},
"commoving":	{"VBG"},
"communal":	{"JJ"},
"communalise":	{"VB"},
"communalism":	{"NN"},
"communalize":	{"VB"},
"communally":	{"RB"},
"commune":	{"NN","VB","VBP"},
"communed":	{"VBD","VBN"},
"communes":	{"NNS","VBZ"},
"communicable":	{"JJ"},
"communicant":	{"NN"},
"communicants":	{"NNS"},
"communicate":	{"VB","VBP"},
"communicated":	{"VBN","VBD"},
"communicates":	{"VBZ"},
"communicating":	{"VBG"},
"communication":	{"NN"},
"communication-cluttered":	{"JJ"},
"communication-service":	{"JJ"},
"communicational":	{"JJ"},
"communications":	{"NNS","NN"},
"communications-equipment":	{"NN"},
"communications-network":	{"JJ"},
"communications-technology":	{"NN"},
"communicative":	{"JJ"},
"communicativeness":	{"NN"},
"communicator":	{"NN"},
"communicators":	{"NNS"},
"communicatory":	{"JJ"},
"communing":	{"VBG"},
"communion":	{"NN"},
"communique":	{"NN"},
"communiques":	{"NNS"},
"communisation":	{"NN"},
"communise":	{"VB"},
"communism":	{"NN"},
"communisn":	{"NN"},
"communist":	{"NN","JJ"},
"communist-designed":	{"JJ"},
"communist-inspired":	{"JJ"},
"communist-led":	{"JJ"},
"communist-type":	{"JJ"},
"communistic":	{"JJ"},
"communists":	{"NNS"},
"communitarians":	{"NNS"},
"communities":	{"NNS"},
"community":	{"NN"},
"community-based":	{"JJ"},
"community-development":	{"NN"},
"community-oriented":	{"JJ"},
"community-service":	{"NN"},
"communization":	{"NN"},
"communize":	{"VB"},
"commutability":	{"NN"},
"commutable":	{"JJ"},
"commutate":	{"VB"},
"commutation":	{"NN"},
"commutative":	{"JJ"},
"commutator":	{"NN"},
"commutator-like":	{"JJ"},
"commute":	{"VB","VBP","NN"},
"commuted":	{"VBD","VBN"},
"commuter":	{"NN"},
"commuter-airline":	{"NN"},
"commuters":	{"NNS"},
"commutes":	{"VBZ","NNS"},
"commuting":	{"VBG"},
"comoros":	{"NN"},
"comose":	{"JJ"},
"comp":	{"NN","VB","VBP"},
"compact":	{"JJ","NN","VB","VBP"},
"compact-car":	{"NN"},
"compact-disk":	{"NN"},
"compacted":	{"VBN","VBD","JJ"},
"compacting":	{"VBG"},
"compaction":	{"NN"},
"compactly":	{"RB"},
"compactness":	{"NN"},
"compacts":	{"VBZ","NNS"},
"compania":	{"NN"},
"companied":	{"VBD","VBN"},
"companies":	{"NNS","VBZ"},
"companion":	{"NN","VB","VBP"},
"companionability":	{"NN"},
"companionable":	{"JJ"},
"companionableness":	{"NN"},
"companionably":	{"RB"},
"companionate":	{"JJ"},
"companioned":	{"VBD","VBN"},
"companioning":	{"VBG"},
"companions":	{"NNS","VBZ"},
"companionship":	{"NN"},
"companionway":	{"NN"},
"companionways":	{"NNS"},
"company":	{"NN","VB","VBP"},
"company-arranged":	{"JJ"},
"company-managed":	{"JJ"},
"company-operated":	{"JJ"},
"company-owned":	{"JJ"},
"company-paid":	{"JJ"},
"company-run":	{"JJ"},
"company-sponsored":	{"JJ"},
"company-wide":	{"JJ"},
"companying":	{"VBG"},
"companywide":	{"JJ","RB"},
"comparability":	{"NN"},
"comparable":	{"JJ"},
"comparable-store":	{"JJ"},
"comparably":	{"RB"},
"comparative":	{"JJ","NN"},
"comparatively":	{"RB"},
"compare":	{"VB","VBP","NN"},
"compared":	{"VBN","VBD"},
"compares":	{"VBZ","NNS"},
"comparing":	{"VBG"},
"comparison":	{"NN"},
"comparison-shop":	{"VB","VBP"},
"comparisons":	{"NNS"},
"compart":	{"VB","VBP"},
"comparted":	{"VBD","VBN"},
"comparting":	{"VBG"},
"compartment":	{"NN","VB","VBP"},
"compartmental":	{"JJ"},
"compartmentalisation":	{"NN"},
"compartmentalise":	{"VB","VBP"},
"compartmentalised":	{"JJ","VBD","VBN"},
"compartmentalises":	{"VBZ"},
"compartmentalising":	{"VBG"},
"compartmentalization":	{"NN"},
"compartmentalize":	{"VB","VBP"},
"compartmentalized":	{"VBD","VBN","JJ"},
"compartmentalizes":	{"VBZ"},
"compartmentalizing":	{"VBG"},
"compartmented":	{"VBD","VBN"},
"compartmenting":	{"VBG"},
"compartments":	{"NNS","VBZ"},
"comparts":	{"VBZ"},
"compass":	{"NN","VB","VBP"},
"compassed":	{"VBD","VBN"},
"compasses":	{"NNS","VBZ"},
"compassing":	{"VBG"},
"compassion":	{"NN"},
"compassionate":	{"JJ","VB","VBP"},
"compassionated":	{"VBD","VBN"},
"compassionately":	{"RB"},
"compassionateness":	{"NN"},
"compassionates":	{"VBZ"},
"compassionating":	{"VBG"},
"compatability":	{"NN"},
"compatibility":	{"NN"},
"compatible":	{"JJ","NN"},
"compatiblizers":	{"NNS"},
"compatibly":	{"RB"},
"compatriot":	{"NN"},
"compatriots":	{"NNS"},
"comped":	{"VBD","VBN"},
"compeer":	{"NN"},
"compeers":	{"NNS"},
"compel":	{"VB","VBP"},
"compelled":	{"VBN","VBD"},
"compelling":	{"JJ","VBG"},
"compellingly":	{"RB"},
"compels":	{"VBZ"},
"compendia":	{"NNS"},
"compendious":	{"JJ"},
"compendium":	{"NN"},
"compendiums":	{"NNS"},
"compensable":	{"JJ"},
"compensate":	{"VB","VBP"},
"compensated":	{"VBD","VBN"},
"compensates":	{"VBZ"},
"compensating":	{"VBG"},
"compensation":	{"NN"},
"compensations":	{"NNS"},
"compensatory":	{"JJ"},
"compere":	{"NN","VB","VBP"},
"compered":	{"VBD","VBN"},
"comperes":	{"NNS","VBZ"},
"compering":	{"VBG"},
"compete":	{"VB","VBP"},
"competed":	{"VBD","VBN"},
"competence":	{"NN"},
"competences":	{"NNS"},
"competencies":	{"NNS"},
"competency":	{"NN"},
"competent":	{"JJ"},
"competently":	{"RB"},
"competes":	{"VBZ"},
"competing":	{"VBG","JJ"},
"competition":	{"NN"},
"competition-enhancers":	{"NNS"},
"competitions":	{"NNS"},
"competitive":	{"JJ"},
"competitive-analysis":	{"JJ"},
"competitively":	{"RB"},
"competitiveness":	{"NN"},
"competitor":	{"NN"},
"competitors":	{"NNS"},
"competitory":	{"JJ"},
"competitve":	{"JJ"},
"competitveness":	{"NN"},
"compilation":	{"NN"},
"compilations":	{"NNS"},
"compile":	{"VB","VBP"},
"compiled":	{"VBN","VBD"},
"compiler":	{"NN"},
"compilers":	{"NNS"},
"compiles":	{"VBZ"},
"compiling":	{"VBG"},
"comping":	{"VBG"},
"complacence":	{"NN"},
"complacency":	{"NN"},
"complacent":	{"JJ"},
"complacently":	{"RB"},
"complain":	{"VB","VBP"},
"complainant":	{"NN"},
"complainants":	{"NNS"},
"complained":	{"VBD","VBN"},
"complainer":	{"NN"},
"complaining":	{"VBG"},
"complainingly":	{"RB"},
"complains":	{"VBZ"},
"complaint":	{"NN"},
"complaint-resolution":	{"NN"},
"complaintive":	{"JJ"},
"complaints":	{"NNS"},
"complaisance":	{"NN"},
"complaisant":	{"JJ"},
"complaisantly":	{"RB"},
"compleated":	{"VBN"},
"complect":	{"VB","VBP"},
"complected":	{"VBD","VBN"},
"complecting":	{"VBG"},
"complection":	{"NN"},
"complects":	{"VBZ"},
"complement":	{"NN","VB","VBP"},
"complemental":	{"JJ"},
"complementarity":	{"NN"},
"complementary":	{"JJ"},
"complementation":	{"NN"},
"complemented":	{"VBD","VBN"},
"complementing":	{"VBG"},
"complements":	{"VBZ","NNS"},
"complete":	{"JJ","VB","VBP"},
"completed":	{"VBN","VBD"},
"completed-contract":	{"JJ"},
"completely":	{"RB"},
"completely-restored":	{"JJ"},
"completeness":	{"NN"},
"completes":	{"VBZ"},
"completing":	{"VBG"},
"completion":	{"NN"},
"completions":	{"NNS"},
"complex":	{"JJ","NN"},
"complex-valued":	{"JJ"},
"complexes":	{"NNS"},
"complexified":	{"VBD","VBN"},
"complexifier":	{"NN"},
"complexifies":	{"VBZ"},
"complexify":	{"VB","VBP"},
"complexifying":	{"VBG"},
"complexion":	{"NN"},
"complexions":	{"NNS"},
"complexities":	{"NNS"},
"complexity":	{"NN"},
"complexly":	{"RB"},
"complexness":	{"NN"},
"compliance":	{"NN"},
"compliancy":	{"NN"},
"compliant":	{"JJ"},
"complicate":	{"VB","VBP"},
"complicated":	{"JJ","VBN","VBD"},
"complicatedness":	{"NN"},
"complicates":	{"VBZ"},
"complicating":	{"VBG"},
"complication":	{"NN"},
"complications":	{"NNS"},
"complicity":	{"NN"},
"complied":	{"VBN","VBD"},
"complies":	{"VBZ","NNS"},
"compliment":	{"NN","VB","VBP"},
"complimentary":	{"JJ"},
"complimented":	{"VBD","VBN"},
"complimenting":	{"VBG"},
"compliments":	{"NNS","VBZ"},
"compline":	{"NN"},
"complot":	{"NN","VB","VBP"},
"complots":	{"NNS","VBZ"},
"complotted":	{"VBD","VBN"},
"complotting":	{"VBG"},
"comply":	{"VB","VBP"},
"complying":	{"VBG"},
"component":	{"NN","JJ"},
"components":	{"NNS"},
"comport":	{"VB","VBP"},
"comported":	{"VBD","VBN"},
"comporting":	{"VBG"},
"comportment":	{"NN"},
"comports":	{"VBZ"},
"compose":	{"VB","VBP"},
"composed":	{"JJ","VBN","VBD"},
"composedly":	{"RB"},
"composer":	{"NN"},
"composer-in-residence":	{"NN"},
"composer-pianist-conductor":	{"NN"},
"composers":	{"NNS"},
"composes":	{"VBZ"},
"composing":	{"NN","VBG"},
"compositae":	{"NN"},
"composite":	{"JJ","NN"},
"compositeness":	{"NN"},
"composites":	{"NNS"},
"composition":	{"NN"},
"compositional":	{"JJ"},
"compositions":	{"NNS"},
"compositor":	{"NN"},
"compositors":	{"NNS"},
"compost":	{"NN","VB","VBP"},
"composted":	{"VBD","VBN"},
"composting":	{"VBG","NN"},
"composts":	{"NNS","VBZ"},
"composure":	{"NN"},
"compote":	{"NN"},
"compotes":	{"NNS"},
"compound":	{"NN","VB","JJ","VBP"},
"compound-engine":	{"JJ"},
"compounded":	{"VBD","VBN"},
"compounding":	{"VBG","NN"},
"compounds":	{"NNS","VBZ"},
"comprehend":	{"VB","VBP"},
"comprehended":	{"VBD","VBN"},
"comprehendible":	{"JJ"},
"comprehending":	{"VBG"},
"comprehends":	{"VBZ"},
"comprehensibility":	{"NN"},
"comprehensible":	{"JJ"},
"comprehension":	{"NN"},
"comprehensions":	{"NNS"},
"comprehensive":	{"JJ"},
"comprehensively":	{"RB"},
"comprehensiveness":	{"NN"},
"compress":	{"VB","VBP","NN"},
"compressed":	{"VBD","VBN"},
"compresses":	{"NNS","VBZ"},
"compressibility":	{"NN"},
"compressible":	{"JJ"},
"compressing":	{"VBG"},
"compression":	{"NN"},
"compressive":	{"JJ"},
"compressor":	{"NN"},
"compressor-manufacturing":	{"JJ"},
"compressors":	{"NNS"},
"comprise":	{"VB","VBP"},
"comprised":	{"VBN","VBD"},
"comprises":	{"VBZ"},
"comprising":	{"VBG"},
"compromise":	{"NN","VB","VBP"},
"compromised":	{"VBD","VBN"},
"compromiser":	{"NN"},
"compromises":	{"NNS","VBZ"},
"compromising":	{"JJ","VBG"},
"comps":	{"VBZ"},
"compsognathus":	{"NN"},
"compton":	{"NN"},
"comptonia":	{"NN"},
"comptroller":	{"NN"},
"comptrollers":	{"NNS"},
"comptrollership":	{"NN"},
"compulsion":	{"NN"},
"compulsions":	{"NNS"},
"compulsive":	{"JJ","NN"},
"compulsively":	{"RB"},
"compulsiveness":	{"NN"},
"compulsives":	{"NNS"},
"compulsivity":	{"NN"},
"compulsorily":	{"RB"},
"compulsoriness":	{"NN"},
"compulsory":	{"JJ"},
"compunction":	{"NN"},
"computable":	{"JJ"},
"computation":	{"NN"},
"computational":	{"JJ"},
"computationally":	{"RB"},
"computations":	{"NNS"},
"compute":	{"VB","VBP"},
"computed":	{"VBD","VBN"},
"computer":	{"NN"},
"computer-accessory":	{"JJ","NN"},
"computer-activated":	{"JJ"},
"computer-age":	{"JJ"},
"computer-aided":	{"JJ"},
"computer-aided-design":	{"NN"},
"computer-aided-software-engineering":	{"NN"},
"computer-and-semiconductor":	{"JJ"},
"computer-assembly":	{"NN"},
"computer-assisted":	{"JJ"},
"computer-based":	{"JJ"},
"computer-chip":	{"NN","JJ"},
"computer-controlled":	{"JJ"},
"computer-data-storage":	{"JJ"},
"computer-dependent":	{"JJ"},
"computer-distributed":	{"JJ"},
"computer-driven":	{"JJ"},
"computer-edited":	{"JJ"},
"computer-game":	{"NN"},
"computer-generated":	{"JJ"},
"computer-guided":	{"JJ"},
"computer-hardware":	{"NN"},
"computer-industry":	{"NN","JJ"},
"computer-integrated":	{"JJ"},
"computer-integrated-manufacturing":	{"JJ"},
"computer-literate":	{"JJ"},
"computer-magazine":	{"JJ"},
"computer-maintenance":	{"NN","JJ"},
"computer-maker":	{"NN"},
"computer-making":	{"JJ"},
"computer-market":	{"JJ"},
"computer-marketing":	{"NN"},
"computer-matching":	{"JJ"},
"computer-network":	{"NN"},
"computer-operated":	{"JJ"},
"computer-oriented":	{"JJ"},
"computer-peripherals":	{"NNS"},
"computer-power-supply":	{"NN"},
"computer-printer":	{"NN"},
"computer-products":	{"NNS","JJ"},
"computer-related":	{"JJ"},
"computer-reservation":	{"JJ","NN"},
"computer-room":	{"JJ"},
"computer-science":	{"NN"},
"computer-security":	{"JJ"},
"computer-service":	{"JJ"},
"computer-services":	{"NNS"},
"computer-servicing":	{"JJ","NN"},
"computer-software":	{"NN"},
"computer-stock":	{"NN"},
"computer-store":	{"NN"},
"computer-system-design":	{"JJ"},
"computer-systems":	{"NNS"},
"computer-trading":	{"NN"},
"computer-unit":	{"JJ"},
"computerise":	{"VB","VBP"},
"computerised":	{"VBD","VBN","JJ"},
"computerises":	{"VBZ"},
"computerising":	{"VBG"},
"computerization":	{"NN"},
"computerize":	{"VB","VBP"},
"computerized":	{"VBD","VBN","JJ"},
"computerizes":	{"VBZ"},
"computerizing":	{"VBG"},
"computerrelated":	{"JJ"},
"computers":	{"NNS"},
"computes":	{"VBZ"},
"computing":	{"NN","VBG"},
"computing-services":	{"JJ"},
"comrade":	{"NN"},
"comrade-in-arms":	{"NN"},
"comradeliness":	{"NN"},
"comradely":	{"JJ"},
"comradery":	{"NN"},
"comrades":	{"NNS"},
"comrades-in-arms":	{"NNS"},
"comradeship":	{"NN"},
"comstock":	{"NN"},
"comstockery":	{"NN"},
"comte":	{"NN"},
"comtism":	{"NN"},
"con":	{"NN","VBP","RB","JJ","IN","VB"},
"conacaste":	{"NN"},
"conakry":	{"NN"},
"conan":	{"NN"},
"concatenate":	{"VB"},
"concatenation":	{"NN"},
"concave":	{"JJ","NN"},
"concaved":	{"VBD","VBN"},
"concavely":	{"RB"},
"concaveness":	{"NN"},
"concaves":	{"VBZ"},
"concaving":	{"VBG"},
"concavity":	{"NN"},
"concavo-concave":	{"JJ"},
"concavo-convex":	{"JJ"},
"conceal":	{"VB","VBP"},
"concealed":	{"VBD","VBN"},
"concealing":	{"VBG"},
"concealment":	{"NN"},
"conceals":	{"VBZ"},
"concede":	{"VB","NN","VBP"},
"conceded":	{"VBD","VBN"},
"concededly":	{"RB"},
"concedes":	{"VBZ"},
"conceding":	{"VBG","NN"},
"conceit":	{"NN"},
"conceited":	{"JJ","VBD","VBN"},
"conceitedly":	{"RB"},
"conceitedness":	{"NN"},
"conceiting":	{"VBG"},
"conceits":	{"NNS","VBZ"},
"conceivability":	{"NN"},
"conceivable":	{"JJ"},
"conceivableness":	{"NN"},
"conceivably":	{"RB"},
"conceive":	{"VB","VBP"},
"conceived":	{"VBD","VBN"},
"conceiver":	{"NN"},
"conceives":	{"VBZ"},
"conceiving":	{"VBG"},
"concenter":	{"VB"},
"concentrate":	{"VB","NN","VBP"},
"concentrated":	{"VBD","VBN","JJ"},
"concentrates":	{"VBZ","NNS"},
"concentrating":	{"VBG"},
"concentration":	{"NN"},
"concentration-camp":	{"NN"},
"concentrations":	{"NNS"},
"concentre":	{"VB","VBP"},
"concentred":	{"VBD","VBN"},
"concentres":	{"VBZ"},
"concentric":	{"JJ"},
"concentrical":	{"JJ"},
"concentricity":	{"NN"},
"concentring":	{"VBG"},
"concepcion":	{"NN"},
"concept":	{"NN"},
"conception":	{"NN"},
"conceptional":	{"JJ"},
"conceptions":	{"NNS"},
"conceptive":	{"JJ"},
"concepts":	{"NNS"},
"conceptual":	{"JJ"},
"conceptualisation":	{"NN"},
"conceptualise":	{"VB","VBP"},
"conceptualised":	{"VBD","VBN"},
"conceptualises":	{"VBZ"},
"conceptualising":	{"VBG"},
"conceptualism":	{"NN"},
"conceptualistic":	{"JJ"},
"conceptuality":	{"NN"},
"conceptualization":	{"NN"},
"conceptualize":	{"VB","VBP"},
"conceptualized":	{"VBD","VBN"},
"conceptualizes":	{"VBZ"},
"conceptualizing":	{"VBG"},
"conceptually":	{"RB"},
"conceptus":	{"NN"},
"concern":	{"NN","VB","VBP"},
"concerned":	{"VBN","JJ","VBD"},
"concernedly":	{"RB"},
"concerning":	{"IN","VBG"},
"concerns":	{"NNS","VBZ"},
"concert":	{"NN"},
"concert-goer":	{"JJ","NN"},
"concerted":	{"JJ","NN","VBD","VBN"},
"concerti":	{"NNS"},
"concertina":	{"NN","VB","VBP"},
"concertinaed":	{"VBD","VBN"},
"concertinaing":	{"VBG"},
"concertinas":	{"NNS","VBZ"},
"concerting":	{"VBG"},
"concertise":	{"VB"},
"concertize":	{"VB"},
"concertmaster":	{"NN"},
"concerto":	{"NN"},
"concertos":	{"NNS"},
"concerts":	{"NNS","VBZ"},
"concession":	{"NN"},
"concessionaire":	{"NN"},
"concessionaires":	{"NNS"},
"concessioner":	{"NN"},
"concessions":	{"NNS"},
"concessive":	{"JJ"},
"conch":	{"NN"},
"concha":	{"NN"},
"conchfish":	{"NN"},
"conchologist":	{"NN"},
"conchology":	{"NN"},
"concierge":	{"NN"},
"conciliable":	{"JJ"},
"conciliate":	{"VB","VBP"},
"conciliated":	{"VBD","VBN"},
"conciliates":	{"VBZ"},
"conciliating":	{"VBG"},
"conciliation":	{"NN"},
"conciliative":	{"JJ"},
"conciliator":	{"NN"},
"conciliators":	{"NNS"},
"conciliatory":	{"JJ"},
"concise":	{"JJ","NN"},
"concisely":	{"RB"},
"conciseness":	{"NN"},
"concision":	{"NN"},
"conclave":	{"NN"},
"conclaves":	{"NNS"},
"conclude":	{"VB","VBP"},
"concluded":	{"VBD","VBN"},
"concludes":	{"VBZ"},
"concluding":	{"JJ","VBG"},
"conclusion":	{"NN"},
"conclusions":	{"NNS"},
"conclusive":	{"JJ","NN"},
"conclusively":	{"RB"},
"conclusiveness":	{"NN"},
"concoct":	{"VB","VBP"},
"concocted":	{"VBD","VBN"},
"concocting":	{"VBG"},
"concoction":	{"NN"},
"concoctions":	{"NNS"},
"concocts":	{"VBZ"},
"concomitance":	{"NN"},
"concomitant":	{"JJ","NN"},
"concomitantly":	{"RB"},
"concord":	{"NN"},
"concordance":	{"NN"},
"concordant":	{"JJ"},
"concordat":	{"NN"},
"concorde":	{"NN"},
"concourse":	{"NN"},
"concrete":	{"JJ","NN","VB","VBP"},
"concrete-product-making":	{"NN"},
"concreted":	{"VBD","VBN"},
"concretely":	{"RB"},
"concreteness":	{"NN"},
"concretes":	{"VBZ"},
"concreting":	{"VBG"},
"concretion":	{"NN"},
"concretisable":	{"JJ"},
"concretisation":	{"NN"},
"concretise":	{"VB","VBP"},
"concretised":	{"VBD","VBN"},
"concretises":	{"VBZ"},
"concretising":	{"VBG"},
"concretism":	{"NN"},
"concretistic":	{"JJ"},
"concretistic-seeming":	{"JJ"},
"concretizable":	{"JJ"},
"concretization":	{"NN"},
"concretize":	{"VB","VBP"},
"concretized":	{"VBD","VBN"},
"concretizes":	{"VBZ"},
"concretizing":	{"VBG"},
"concubinage":	{"NN"},
"concubine":	{"NN"},
"concupiscence":	{"NN"},
"concupiscent":	{"JJ"},
"concur":	{"VB","VBP"},
"concurred":	{"VBD","VBN"},
"concurrence":	{"NN"},
"concurrency":	{"NN"},
"concurrent":	{"JJ"},
"concurrently":	{"RB"},
"concurring":	{"VBG"},
"concurs":	{"VBZ"},
"concuss":	{"VB","VBP"},
"concussed":	{"VBD","VBN"},
"concusses":	{"VBZ"},
"concussing":	{"VBG"},
"concussion":	{"NN"},
"concussions":	{"NNS"},
"conde":	{"NN"},
"condemn":	{"VB","VBP"},
"condemnable":	{"JJ"},
"condemnation":	{"NN"},
"condemnations":	{"NNS"},
"condemnatory":	{"JJ"},
"condemned":	{"JJ","VBD","VBN"},
"condemning":	{"VBG"},
"condemns":	{"VBZ"},
"condensate":	{"NN"},
"condensation":	{"NN"},
"condensations":	{"NNS"},
"condense":	{"VB","VBP"},
"condensed":	{"VBD","VBN","JJ"},
"condenser":	{"NN"},
"condensers":	{"NNS"},
"condenses":	{"VBZ"},
"condensing":	{"VBG"},
"condescend":	{"VB","VBP"},
"condescended":	{"VBD","VBN"},
"condescending":	{"JJ","VBG"},
"condescendingly":	{"RB"},
"condescendingness":	{"NN"},
"condescends":	{"VBZ"},
"condescension":	{"NN"},
"condicions":	{"NNS"},
"condign":	{"JJ"},
"condiment":	{"NN"},
"condiments":	{"NNS"},
"condition":	{"NN","VBP","VB"},
"conditional":	{"JJ","NN"},
"conditionality":	{"NN"},
"conditionally":	{"RB"},
"conditioned":	{"JJ","VBD","VBN"},
"conditioner":	{"NN"},
"conditioners":	{"NNS"},
"conditioning":	{"NN","VBG"},
"conditions":	{"NNS","VBZ"},
"condo":	{"NN"},
"condole":	{"VB"},
"condoled":	{"VBD","VBN"},
"condolence":	{"NN"},
"condolences":	{"NNS"},
"condolent":	{"JJ"},
"condoles":	{"VBZ"},
"condoling":	{"VBG"},
"condom":	{"NN"},
"condominium":	{"NN"},
"condominiums":	{"NNS"},
"condoms":	{"NNS"},
"condonation":	{"NN"},
"condone":	{"VB","VBP"},
"condoned":	{"VBD","VBN"},
"condones":	{"VBZ"},
"condoning":	{"VBG"},
"condor":	{"NN"},
"condorcet":	{"NN"},
"condos":	{"NNS"},
"conduce":	{"VB","VBP"},
"conduced":	{"VBD","VBN"},
"conduces":	{"VBZ"},
"conducing":	{"VBG"},
"conducive":	{"JJ"},
"conduct":	{"NN","VB","VBP"},
"conductance":	{"NN"},
"conducted":	{"VBN","VBD"},
"conducting":	{"VBG","NN"},
"conduction":	{"NN"},
"conductive":	{"JJ"},
"conductivity":	{"NN"},
"conductor":	{"NN"},
"conductors":	{"NNS"},
"conductorship":	{"NN"},
"conductress":	{"NN"},
"conducts":	{"VBZ","NNS"},
"conduit":	{"NN"},
"conduits":	{"NNS"},
"condylar":	{"JJ"},
"condyle":	{"NN"},
"condylion":	{"NN"},
"condylura":	{"NN"},
"cone":	{"VB","VBP","NN"},
"cone-bearing":	{"JJ"},
"cone-shaped":	{"JJ"},
"cone-sphere":	{"JJ"},
"coned":	{"VBD","VBN"},
"coneflower":	{"NN"},
"coneheads":	{"NNS"},
"conelike":	{"JJ"},
"conenose":	{"NN"},
"conepatus":	{"NNS"},
"cones":	{"NNS","VBZ"},
"conessi":	{"NN"},
"conestoga":	{"NN"},
"coney":	{"NN"},
"coneys":	{"NNS"},
"confab":	{"VB","NN"},
"confabulate":	{"VB"},
"confabulated":	{"VBN"},
"confabulation":	{"NN"},
"confabulations":	{"NNS"},
"confect":	{"NN","VB","VBP"},
"confected":	{"VBD","VBN"},
"confecting":	{"VBG"},
"confection":	{"NN"},
"confectionary":	{"NN"},
"confectioner":	{"NN"},
"confectioners":	{"NNS"},
"confectionery":	{"NN"},
"confections":	{"NNS"},
"confects":	{"NNS","VBZ"},
"confederacy":	{"NN"},
"confederate":	{"JJ","NN","VB","VBP"},
"confederated":	{"VBD","VBN"},
"confederates":	{"NNS","VBZ"},
"confederating":	{"VBG"},
"confederation":	{"NN"},
"confederations":	{"NNS"},
"confederative":	{"JJ"},
"confer":	{"VB","VBP"},
"conferee":	{"NN"},
"conferees":	{"NNS"},
"conference":	{"NN"},
"conferences":	{"NNS"},
"conferment":	{"NN"},
"conferral":	{"NN"},
"conferred":	{"VBD","VBN"},
"conferrer":	{"NN"},
"conferring":	{"VBG"},
"confers":	{"VBZ"},
"conferva":	{"NN"},
"confess":	{"VB","VBP"},
"confessed":	{"VBD","VBN","JJ"},
"confessedly":	{"RB"},
"confesses":	{"VBZ"},
"confessing":	{"VBG"},
"confession":	{"NN"},
"confessional":	{"NN","JJ"},
"confessionals":	{"NNS"},
"confessions":	{"NNS"},
"confessor":	{"NN"},
"confessors":	{"NNS"},
"confetti":	{"NN"},
"confict":	{"NN"},
"confidant":	{"NN"},
"confidante":	{"NN"},
"confidants":	{"NNS"},
"confide":	{"VB","VBP"},
"confided":	{"VBD","VBN"},
"confidence":	{"NN"},
"confidence-crusher":	{"NN"},
"confidence-shattering":	{"JJ"},
"confidences":	{"NNS"},
"confident":	{"JJ"},
"confidential":	{"JJ"},
"confidentiality":	{"NN"},
"confidentially":	{"RB"},
"confidently":	{"RB"},
"confides":	{"VBZ","NNS"},
"confiding":	{"JJ","VBG"},
"confidingly":	{"RB"},
"configuration":	{"NN"},
"configuration-data":	{"JJ"},
"configurational":	{"JJ"},
"configurationism":	{"NN"},
"configurations":	{"NNS"},
"configure":	{"VB","VBP"},
"configured":	{"VBD","VBN"},
"configures":	{"VBZ"},
"configuring":	{"VBG"},
"confine":	{"VB","VBP","NN"},
"confined":	{"VBN","JJ","VBD"},
"confinement":	{"NN"},
"confinements":	{"NNS"},
"confines":	{"VBZ","NNS"},
"confining":	{"VBG"},
"confirm":	{"VB","VBP"},
"confirmable":	{"JJ"},
"confirmation":	{"NN"},
"confirmations":	{"NNS"},
"confirmative":	{"JJ"},
"confirmatory":	{"JJ"},
"confirmed":	{"JJ","VBD","VBN"},
"confirming":	{"VBG"},
"confirms":	{"VBZ"},
"confiscate":	{"VB","VBP"},
"confiscated":	{"VBD","VBN"},
"confiscates":	{"VBZ"},
"confiscating":	{"VBG"},
"confiscation":	{"NN"},
"confiscatory":	{"JJ"},
"confit":	{"NN"},
"confiture":	{"NN"},
"conflagrate":	{"VB"},
"conflagration":	{"NN"},
"conflate":	{"VB","VBP"},
"conflated":	{"VBD","VBN"},
"conflates":	{"VBZ"},
"conflating":	{"VBG"},
"conflation":	{"NN"},
"conflations":	{"NNS"},
"conflict":	{"NN","VB","VBP"},
"conflict-of-interest":	{"NN","JJ"},
"conflict-ridden":	{"JJ"},
"conflicted":	{"JJ","VBD","VBN"},
"conflicting":	{"JJ","NN","VBG"},
"conflicts":	{"NNS","VBZ"},
"confluence":	{"NN"},
"confluent":	{"NN","JJ"},
"conflux":	{"NN"},
"conform":	{"VB","VBP"},
"conformable":	{"JJ"},
"conformably":	{"RB"},
"conformance":	{"NN"},
"conformation":	{"NN"},
"conformational":	{"JJ"},
"conformations":	{"NNS"},
"conformed":	{"VBD","VBN"},
"conforming":	{"VBG"},
"conformism":	{"NN"},
"conformist":	{"JJ","NN"},
"conformists":	{"NNS"},
"conformitarianism":	{"NN"},
"conformity":	{"NN"},
"conforms":	{"VBZ"},
"confound":	{"VB","VBP"},
"confounded":	{"JJ","VBD","VBN"},
"confoundedly":	{"RB"},
"confounding":	{"VBG"},
"confounds":	{"VBZ"},
"confrere":	{"NN"},
"confreres":	{"FW","NNS"},
"confront":	{"VB","VBP"},
"confrontation":	{"NN"},
"confrontational":	{"JJ"},
"confrontations":	{"NNS"},
"confronted":	{"VBN","VBD"},
"confronting":	{"VBG"},
"confronts":	{"VBZ"},
"confucianism":	{"NN"},
"confucianist":	{"NN"},
"confucius":	{"NN"},
"confusable":	{"JJ"},
"confuse":	{"VB","VBP"},
"confused":	{"VBN","JJ","VBD"},
"confusedly":	{"RB"},
"confusedness":	{"NN"},
"confuses":	{"VBZ"},
"confusing":	{"JJ","VBG"},
"confusingly":	{"RB"},
"confusion":	{"NN"},
"confusions":	{"NNS"},
"confutable":	{"JJ"},
"confutation":	{"NN"},
"confutative":	{"JJ"},
"confute":	{"VB","VBP"},
"confuted":	{"VBD","VBN"},
"confuter":	{"NN"},
"confutes":	{"VBZ"},
"confuting":	{"VBG"},
"conga":	{"NN","VB","VBP"},
"congaed":	{"VBD","VBN"},
"congaing":	{"VBG"},
"congas":	{"NNS","VBZ"},
"conge":	{"NN","VB"},
"congeal":	{"VB","VBP"},
"congealed":	{"VBD","VBN"},
"congealing":	{"VBG"},
"congealment":	{"NN"},
"congeals":	{"VBZ"},
"congee":	{"NN","VB","VBP"},
"congeed":	{"VBD","VBN"},
"congeeing":	{"VBG"},
"congees":	{"NNS","VBZ"},
"congelation":	{"NN"},
"congenator":	{"NN"},
"congener":	{"NN"},
"congeneric":	{"JJ","NN"},
"congenerical":	{"JJ"},
"congenerous":	{"JJ"},
"congenial":	{"JJ","NN"},
"congeniality":	{"NN"},
"congenially":	{"RB"},
"congenialness":	{"NN"},
"congenital":	{"JJ","NN"},
"conger":	{"NN"},
"congeries":	{"NN"},
"congest":	{"VB","VBP"},
"congested":	{"JJ","VBD","VBN"},
"congesting":	{"VBG"},
"congestion":	{"NN"},
"congestive":	{"JJ"},
"congests":	{"VBZ"},
"congius":	{"NN"},
"conglobate":	{"VB"},
"conglobation":	{"NN"},
"conglobe":	{"VB"},
"conglomerate":	{"NN","JJ"},
"conglomerated":	{"VBD","VBN"},
"conglomerates":	{"VBZ","NNS"},
"conglomerating":	{"VBG"},
"conglomeration":	{"NN"},
"conglutinate":	{"VB"},
"conglutination":	{"NN"},
"congo":	{"NN"},
"congolese":	{"JJ","NN"},
"congou":	{"NN"},
"congrats":	{"NNS"},
"congratulate":	{"VB","VBP"},
"congratulated":	{"VBD","VBN"},
"congratulates":	{"VBZ"},
"congratulating":	{"VBG"},
"congratulation":	{"NN"},
"congratulations":	{"NNS"},
"congratulatory":	{"JJ"},
"congregant":	{"NN"},
"congregate":	{"VB","VBP"},
"congregated":	{"VBD","VBN"},
"congregates":	{"VBZ"},
"congregating":	{"VBG"},
"congregation":	{"NN"},
"congregational":	{"JJ"},
"congregationalism":	{"NN"},
"congregationalists":	{"NNS"},
"congregations":	{"NNS"},
"congress":	{"NN"},
"congresses":	{"NNS"},
"congressional":	{"JJ"},
"congressional-item":	{"JJ"},
"congressionally":	{"RB"},
"congressman":	{"NN"},
"congressmen":	{"NNS"},
"congressonal":	{"JJ"},
"congresssional":	{"JJ"},
"congresswoman":	{"NN"},
"congreve":	{"NN"},
"congridae":	{"NN"},
"congruence":	{"NN"},
"congruent":	{"JJ","NN"},
"congruity":	{"NN"},
"congruous":	{"JJ"},
"congruousness":	{"NN"},
"conic":	{"JJ","NN"},
"conical":	{"JJ"},
"conically":	{"RB"},
"conidiophore":	{"NN"},
"conidiospore":	{"NN"},
"conidium":	{"NN"},
"conies":	{"NNS"},
"conifer":	{"NN"},
"coniferales":	{"NNS"},
"coniferophyta":	{"NN"},
"coniferophytina":	{"NN"},
"coniferopsida":	{"NN"},
"coniferous":	{"JJ"},
"conilurus":	{"NN"},
"conima":	{"NN"},
"coning":	{"VBG"},
"coniogramme":	{"NN"},
"coniston":	{"NN"},
"conium":	{"NN"},
"conjectural":	{"JJ"},
"conjecturally":	{"RB"},
"conjecture":	{"NN","VB","VBP"},
"conjectured":	{"VBD","VBN"},
"conjectures":	{"NNS","VBZ"},
"conjecturing":	{"VBG"},
"conjee":	{"NN"},
"conjoin":	{"VB","VBP"},
"conjoined":	{"VBD","VBN"},
"conjoining":	{"VBG"},
"conjoins":	{"VBZ"},
"conjoint":	{"JJ"},
"conjointly":	{"RB"},
"conjugal":	{"JJ"},
"conjugally":	{"RB"},
"conjugate":	{"VB","VBP"},
"conjugated":	{"VBD","VBN"},
"conjugates":	{"VBZ"},
"conjugating":	{"VBG"},
"conjugation":	{"NN"},
"conjugations":	{"NNS"},
"conjunct":	{"JJ","NN"},
"conjunction":	{"NN"},
"conjunctions":	{"NNS"},
"conjunctiva":	{"NN"},
"conjunctival":	{"JJ"},
"conjunctive":	{"JJ","NN"},
"conjunctivitis":	{"NN"},
"conjuncture":	{"NN"},
"conjur":	{"NN"},
"conjuration":	{"NN"},
"conjure":	{"VB","VBP"},
"conjured":	{"VBD","VBN"},
"conjurer":	{"NN"},
"conjurers":	{"NNS"},
"conjures":	{"VBZ"},
"conjuring":	{"NN","VBG"},
"conjuror":	{"NN"},
"conjury":	{"NN"},
"conk":	{"NN","VB","VBP"},
"conked":	{"VBD","VBN"},
"conker":	{"NN"},
"conkers":	{"NNS"},
"conking":	{"VBG"},
"conks":	{"NNS","VBZ"},
"conn":	{"NN","VB","VBP"},
"connally":	{"NN"},
"connaraceae":	{"NN"},
"connarus":	{"NN"},
"connate":	{"JJ"},
"connatural":	{"JJ"},
"connect":	{"VB","VBP"},
"connected":	{"VBN","VBD","JJ"},
"connectedness":	{"NN"},
"connecter":	{"NN"},
"connecticuter":	{"NN"},
"connecting":	{"VBG"},
"connection":	{"NN"},
"connections":	{"NNS"},
"connective":	{"JJ","NN"},
"connectives":	{"NNS"},
"connectivity":	{"NN"},
"connector":	{"NN"},
"connectors":	{"NNS"},
"connects":	{"VBZ"},
"conned":	{"VBD","VBN"},
"connexion":	{"NN"},
"conning":	{"VBG"},
"conniption":	{"NN"},
"connivance":	{"NN"},
"connive":	{"VB","VBP"},
"connived":	{"VBD","VBN"},
"conniver":	{"NN"},
"connives":	{"VBZ"},
"conniving":	{"VBG","JJ"},
"connochaetes":	{"NNS"},
"connoisseur":	{"NN"},
"connoisseurs":	{"NNS"},
"connoisseurship":	{"NN"},
"connolly":	{"NN"},
"connor":	{"NN"},
"connors":	{"NNS"},
"connotation":	{"NN"},
"connotational":	{"JJ"},
"connotations":	{"NNS"},
"connotative":	{"JJ"},
"connote":	{"VB","VBP"},
"connoted":	{"VBD","VBN"},
"connotes":	{"VBZ"},
"connoting":	{"VBG"},
"conns":	{"NNS","VBZ"},
"connubial":	{"JJ","NN"},
"conocarpus":	{"NNS"},
"conoclinium":	{"NN"},
"conodont":	{"NN"},
"conodonta":	{"NN"},
"conodontophorida":	{"NN"},
"conoid":	{"NN"},
"conopodium":	{"NN"},
"conospermum":	{"NN"},
"conoy":	{"NN"},
"conpired":	{"VBN"},
"conquer":	{"VB","VBP"},
"conquerable":	{"JJ"},
"conquered":	{"VBD","VBN"},
"conquering":	{"VBG","JJ"},
"conqueror":	{"NN"},
"conquerors":	{"NNS"},
"conquers":	{"VBZ"},
"conquest":	{"NN"},
"conquests":	{"NNS"},
"conquete":	{"FW"},
"conquistador":	{"NN"},
"conrad":	{"NN"},
"conradically":	{"RB"},
"conradina":	{"NN"},
"cons":	{"VB","JJ","NN","VBZ","NNS"},
"consanguine":	{"JJ"},
"consanguineal":	{"JJ"},
"consanguineous":	{"JJ"},
"consanguineously":	{"RB"},
"consanguinity":	{"NN"},
"conscience":	{"NN"},
"conscience-smitten":	{"JJ"},
"conscienceless":	{"JJ"},
"consciences":	{"NNS"},
"conscientious":	{"JJ"},
"conscientiously":	{"RB"},
"conscientiousness":	{"NN"},
"conscionable":	{"JJ"},
"conscious":	{"JJ"},
"consciously":	{"RB"},
"consciousness":	{"NN"},
"consciousness-raising":	{"NN"},
"conscript":	{"VB","VBP","NN"},
"conscripted":	{"VBD","VBN"},
"conscripting":	{"VBG"},
"conscription":	{"NN"},
"conscripts":	{"NNS","VBZ"},
"consderations":	{"NNS"},
"consecrate":	{"VB","VBP"},
"consecrated":	{"VBD","VBN"},
"consecrates":	{"VBZ"},
"consecrating":	{"VBG"},
"consecration":	{"NN"},
"consecutive":	{"JJ"},
"consecutively":	{"RB"},
"consensual":	{"JJ","NN"},
"consensus":	{"NN"},
"consensus-seeker":	{"NN"},
"consent":	{"NN","VB","VBP"},
"consent-decree":	{"JJ"},
"consentaneous":	{"JJ"},
"consented":	{"VBD","VBN"},
"consentient":	{"JJ"},
"consenting":	{"JJ","VBG"},
"consents":	{"NNS","VBZ"},
"consentual":	{"JJ"},
"consequence":	{"NN"},
"consequences":	{"NNS"},
"consequent":	{"JJ","NN"},
"consequential":	{"JJ","NN"},
"consequentially":	{"RB"},
"consequently":	{"RB"},
"conservancy":	{"NN"},
"conservation":	{"NN"},
"conservationist":	{"NN"},
"conservationists":	{"NNS"},
"conservatism":	{"NN"},
"conservative":	{"JJ","NN"},
"conservative-communist":	{"JJ"},
"conservative-led":	{"JJ"},
"conservative-liberal":	{"JJ"},
"conservatively":	{"RB"},
"conservatively-cravated":	{"JJ"},
"conservatives":	{"NNS"},
"conservativism":	{"NN"},
"conservativist":	{"NN"},
"conservatoire":	{"NN"},
"conservator":	{"NN"},
"conservatories":	{"NNS"},
"conservators":	{"NNS"},
"conservatorship":	{"NN"},
"conservatory":	{"NN"},
"conserve":	{"VB","VBP","NN"},
"conserved":	{"VBD","VBN"},
"conserves":	{"VBZ","NNS"},
"conserving":	{"VBG"},
"consider":	{"VB","VBP"},
"considerable":	{"JJ"},
"considerably":	{"RB"},
"considerate":	{"JJ"},
"considerately":	{"RB"},
"considerateness":	{"NN"},
"consideration":	{"NN"},
"considerations":	{"NNS"},
"considered":	{"VBN","VBD","JJ"},
"considering":	{"IN","CC","VBG","RB"},
"considers":	{"VBZ"},
"consign":	{"VB","VBP"},
"consigned":	{"VBD","VBN"},
"consignee":	{"NN"},
"consignees":	{"NNS"},
"consigner":	{"NN"},
"consigning":	{"VBG"},
"consignment":	{"NN"},
"consignments":	{"NNS"},
"consignor":	{"NN"},
"consignors":	{"NNS"},
"consigns":	{"VBZ"},
"consisently":	{"RB"},
"consist":	{"VB","VBP"},
"consisted":	{"VBD","VBN"},
"consistence":	{"NN"},
"consistencies":	{"NNS"},
"consistency":	{"NN"},
"consistent":	{"JJ"},
"consistently":	{"RB"},
"consisting":	{"VBG"},
"consistory":	{"NN"},
"consists":	{"VBZ"},
"consitutional":	{"JJ"},
"consociate":	{"VB","VBP","NN","JJ"},
"consociated":	{"VBD","VBN"},
"consociates":	{"VBZ","NNS"},
"consociating":	{"VBG"},
"consociation":	{"NN"},
"consociational":	{"JJ"},
"consolable":	{"JJ"},
"consolation":	{"NN"},
"consolatory":	{"JJ"},
"console":	{"VB","VBP","NN"},
"consoled":	{"VBD","VBN"},
"consoles":	{"VBZ","NNS"},
"consolida":	{"NN"},
"consolidate":	{"VB","VBP"},
"consolidated":	{"JJ","VBD","VBN"},
"consolidated-pretax":	{"JJ"},
"consolidates":	{"VBZ"},
"consolidating":	{"VBG"},
"consolidation":	{"NN"},
"consolidations":	{"NNS"},
"consolidative":	{"JJ"},
"consoling":	{"VBG"},
"consolingly":	{"RB"},
"consomme":	{"NN"},
"consonance":	{"NN"},
"consonant":	{"JJ","NN"},
"consonantal":	{"JJ"},
"consonants":	{"NNS"},
"consonate":	{"VB"},
"consort":	{"NN","VB","VBP"},
"consorted":	{"VBD","VBN"},
"consortia":	{"NNS"},
"consorting":	{"VBG"},
"consortium":	{"NN"},
"consortium-ownership":	{"NN"},
"consortiums":	{"NNS"},
"consorts":	{"VBZ","NNS"},
"conspecific":	{"JJ","NN"},
"conspectus":	{"NN"},
"conspicuous":	{"JJ"},
"conspicuously":	{"RB"},
"conspicuousness":	{"NN"},
"conspiracies":	{"NNS"},
"conspiracy":	{"NN"},
"conspirative":	{"JJ"},
"conspirator":	{"NN"},
"conspiratorial":	{"JJ"},
"conspiratorially":	{"RB"},
"conspirators":	{"NNS"},
"conspire":	{"VB","VBP"},
"conspired":	{"VBD","VBN"},
"conspires":	{"VBZ"},
"conspiring":	{"VBG"},
"constable":	{"NN"},
"constables":	{"NNS"},
"constabulary":	{"NN","JJ"},
"constance":	{"NN"},
"constancy":	{"NN"},
"constant":	{"JJ","NN"},
"constant-temperature":	{"NN"},
"constantan":	{"NN"},
"constantina":	{"NN"},
"constantine":	{"NN"},
"constantinople":	{"NN"},
"constantly":	{"RB"},
"constants":	{"NNS"},
"constatation":	{"NN"},
"constellate":	{"VB","VBP"},
"constellated":	{"VBD","VBN"},
"constellates":	{"VBZ"},
"constellating":	{"VBG"},
"constellation":	{"NN"},
"constellations":	{"NNS"},
"consternate":	{"VB"},
"consternation":	{"NN"},
"constipate":	{"VB","VBP"},
"constipated":	{"JJ","VBD","VBN"},
"constipates":	{"VBZ"},
"constipating":	{"VBG"},
"constipation":	{"NN"},
"constituencies":	{"NNS"},
"constituency":	{"NN"},
"constituent":	{"NN","JJ"},
"constituents":	{"NNS"},
"constitute":	{"VB","NN","VBP"},
"constituted":	{"VBD","VBN"},
"constitutes":	{"VBZ"},
"constituting":	{"VBG","NN"},
"constitution":	{"NN"},
"constitutional":	{"JJ","NN"},
"constitutional-law":	{"JJ","NN"},
"constitutionalise":	{"VB"},
"constitutionalism":	{"NN"},
"constitutionalist":	{"NN"},
"constitutionality":	{"NN"},
"constitutionalize":	{"VB"},
"constitutionally":	{"RB"},
"constitutions":	{"NNS"},
"constitutive":	{"JJ","NN"},
"constrain":	{"VB","VBP"},
"constrained":	{"JJ","VBD","VBN"},
"constrainedly":	{"RB"},
"constraining":	{"VBG"},
"constrains":	{"VBZ"},
"constraint":	{"NN"},
"constraints":	{"NNS"},
"constrict":	{"VB","VBP"},
"constricted":	{"JJ","VBD","VBN"},
"constricting":	{"JJ","VBG"},
"constriction":	{"NN"},
"constrictions":	{"NNS"},
"constrictive":	{"JJ"},
"constrictor":	{"NN"},
"constrictors":	{"NNS"},
"constricts":	{"VBZ"},
"constringe":	{"VB"},
"construal":	{"NN"},
"construct":	{"VB","NN","VBP"},
"constructed":	{"VBD","VBN"},
"constructing":	{"NN","VBG"},
"construction":	{"NN"},
"construction-industry":	{"NN"},
"construction-management":	{"JJ"},
"construction-oriented":	{"JJ"},
"construction-related":	{"JJ"},
"constructional":	{"JJ"},
"constructions":	{"NNS"},
"constructive":	{"JJ"},
"constructive-metabolic":	{"JJ"},
"constructively":	{"RB"},
"constructiveness":	{"NN"},
"constructivism":	{"NN"},
"constructivist":	{"NN"},
"constructon":	{"NN"},
"constructor":	{"NN"},
"constructors":	{"NNS"},
"constructs":	{"VBZ","NNS"},
"construe":	{"VB","VBP"},
"construed":	{"VBD","VBN"},
"construes":	{"VBZ"},
"construing":	{"VBG"},
"consubstantial":	{"JJ"},
"consubstantiate":	{"VB"},
"consubstantiation":	{"NN"},
"consuetude":	{"NN"},
"consuetudinal":	{"NN"},
"consuetudinary":	{"NN"},
"consul":	{"NN"},
"consular":	{"JJ","NN"},
"consulate":	{"NN"},
"consulates":	{"NNS"},
"consulship":	{"NN"},
"consult":	{"VB","VBP"},
"consultancies":	{"NNS"},
"consultancy":	{"NN"},
"consultant":	{"NN"},
"consultants":	{"NNS"},
"consultation":	{"NN"},
"consultations":	{"NNS"},
"consultative":	{"JJ"},
"consultatory":	{"JJ"},
"consulted":	{"VBD","VBN"},
"consulting":	{"VBG","NN"},
"consulting-firm":	{"NN"},
"consultive":	{"JJ"},
"consults":	{"VBZ"},
"consumable":	{"JJ","NN"},
"consumables":	{"NNS"},
"consume":	{"VB","VBP"},
"consumed":	{"VBN","VBD"},
"consumer":	{"NN"},
"consumer-advocacy":	{"JJ"},
"consumer-analgesic":	{"JJ"},
"consumer-credit":	{"JJ","NN"},
"consumer-driven":	{"JJ"},
"consumer-electronics":	{"NNS","JJ"},
"consumer-finance":	{"JJ"},
"consumer-goods":	{"NNS"},
"consumer-led":	{"JJ"},
"consumer-minded":	{"JJ"},
"consumer-oriented":	{"JJ"},
"consumer-paint":	{"JJ"},
"consumer-price":	{"JJ","NN"},
"consumer-price-index":	{"JJ"},
"consumer-product":	{"JJ","NN"},
"consumer-products":	{"NNS","JJ"},
"consumer-protection":	{"NN"},
"consumer-telephone":	{"JJ"},
"consumer-warning":	{"NN"},
"consumerism":	{"NN"},
"consumerist":	{"JJ"},
"consumers":	{"NNS"},
"consumes":	{"VBZ"},
"consuming":	{"JJ","VBG"},
"consummate":	{"JJ","VB","VBP"},
"consummated":	{"VBD","VBN"},
"consummately":	{"RB"},
"consummates":	{"VBZ"},
"consummating":	{"VBG"},
"consummation":	{"NN"},
"consumption":	{"NN"},
"consumption-tax":	{"NN"},
"consumptive":	{"JJ","NN"},
"consumptives":	{"NNS"},
"cont":	{"VBN"},
"contact":	{"NN","VB","VBP","JJ"},
"contact-lens":	{"NN"},
"contacted":	{"VBN","VBD"},
"contacting":	{"VBG"},
"contaction":	{"NN"},
"contacts":	{"NNS","VBZ"},
"contadini":	{"NNS"},
"contadino":	{"NN"},
"contagion":	{"NN"},
"contagious":	{"JJ"},
"contagiously":	{"RB"},
"contain":	{"VB","VBP"},
"containable":	{"JJ"},
"contained":	{"VBD","VBN"},
"container":	{"NN"},
"container-ship":	{"NN"},
"containerboard":	{"NN"},
"containerful":	{"NN"},
"containerisation":	{"NN"},
"containerise":	{"VB","VBP"},
"containerised":	{"VBD","VBN"},
"containerises":	{"VBZ"},
"containerising":	{"VBG"},
"containerization":	{"NN"},
"containerize":	{"VB"},
"containerized":	{"VBD","VBN"},
"containerized-cargo":	{"NN"},
"containerizes":	{"VBZ"},
"containerizing":	{"VBG"},
"containers":	{"NNS"},
"containership":	{"NN"},
"containing":	{"VBG"},
"containment":	{"NN"},
"contains":	{"VBZ"},
"contaminant":	{"NN"},
"contaminants":	{"NNS"},
"contaminate":	{"VB","VBP"},
"contaminated":	{"JJ","VBD","VBN"},
"contaminates":	{"VBZ"},
"contaminating":	{"VBG"},
"contamination":	{"NN"},
"contaminative":	{"JJ"},
"contemn":	{"VB"},
"contemned":	{"VBD","VBN"},
"contemning":	{"VBG"},
"contemns":	{"VBZ"},
"contemplate":	{"VB","VBP"},
"contemplated":	{"VBN","VBD"},
"contemplates":	{"VBZ"},
"contemplating":	{"VBG"},
"contemplation":	{"NN"},
"contemplative":	{"JJ","NN"},
"contemplativeness":	{"NN"},
"contemplatives":	{"NNS"},
"contemporaneity":	{"NN"},
"contemporaneous":	{"JJ"},
"contemporaneously":	{"RB"},
"contemporaneousness":	{"NN"},
"contemporaries":	{"NNS"},
"contemporary":	{"JJ","NN"},
"contemporise":	{"VB"},
"contemporize":	{"VB"},
"contempt":	{"NN"},
"contempt-of-court":	{"NN"},
"contemptibility":	{"NN"},
"contemptible":	{"JJ","NN"},
"contemptibly":	{"RB"},
"contemptuous":	{"JJ"},
"contemptuously":	{"RB"},
"contemptuousness":	{"NN"},
"contend":	{"VB","VBP"},
"contended":	{"VBD","VBN"},
"contender":	{"NN"},
"contenders":	{"NNS"},
"contending":	{"VBG"},
"contends":	{"VBZ"},
"content":	{"NN","JJ","VB","VBP"},
"contented":	{"JJ","VBD","VBN"},
"contentedly":	{"RB"},
"contentedness":	{"NN"},
"contenting":	{"VBG"},
"contention":	{"NN"},
"contentions":	{"NNS"},
"contentious":	{"JJ"},
"contentiously":	{"RB"},
"contentiousness":	{"NN"},
"contentment":	{"NN"},
"contents":	{"NNS","VBZ"},
"conterminous":	{"JJ"},
"contest":	{"NN","VB"},
"contestable":	{"JJ"},
"contestant":	{"NN"},
"contestants":	{"NNS"},
"contestation":	{"NN"},
"contested":	{"VBD","VBN"},
"contestee":	{"NN"},
"contester":	{"NN"},
"contesting":	{"VBG","NN"},
"contests":	{"NNS","VBZ"},
"context":	{"NN"},
"contexts":	{"NNS"},
"contextual":	{"JJ"},
"contextualism":	{"NN"},
"contextually":	{"RB"},
"contiguity":	{"NN"},
"contiguous":	{"JJ","NN"},
"contiguousness":	{"NN"},
"continence":	{"NN"},
"continency":	{"NN"},
"continent":	{"NN","JJ"},
"continent-wide":	{"JJ"},
"continental":	{"JJ"},
"continentally":	{"RB"},
"continentals":	{"NNS"},
"continents":	{"NNS"},
"contingence":	{"NN"},
"contingencies":	{"NNS"},
"contingency":	{"NN"},
"contingency-fee":	{"JJ"},
"contingent":	{"NN","JJ"},
"contingent-fee":	{"JJ"},
"contingents":	{"NNS"},
"continously":	{"RB"},
"continua":	{"NNS"},
"continual":	{"JJ"},
"continually":	{"RB"},
"continuance":	{"NN"},
"continuant":	{"JJ","NN"},
"continuation":	{"NN"},
"continuations":	{"NNS"},
"continuative":	{"NN"},
"continue":	{"VB","VBP"},
"continued":	{"VBD","VBN","JJ"},
"continues":	{"VBZ"},
"continuing":	{"VBG","JJ"},
"continuing-education":	{"JJ"},
"continuingly":	{"RB"},
"continuities":	{"NNS"},
"continuity":	{"NN"},
"continuo":	{"NN"},
"continuos":	{"NNS"},
"continuous":	{"JJ"},
"continuously":	{"RB"},
"continuousness":	{"NN"},
"continuum":	{"NN"},
"continuums":	{"NNS"},
"conto":	{"NN"},
"contopus":	{"NNS"},
"contort":	{"VB","VBP"},
"contorted":	{"VBD","VBN"},
"contorting":	{"VBG"},
"contortion":	{"NN"},
"contortionist":	{"NN"},
"contortionists":	{"NNS"},
"contortions":	{"NNS"},
"contorts":	{"VBZ"},
"contour":	{"NN","VB","VBP"},
"contour-obliterating":	{"JJ"},
"contoured":	{"VBD","VBN"},
"contouring":	{"VBG"},
"contours":	{"NNS","VBZ"},
"contra":	{"NN"},
"contraband":	{"NN","JJ"},
"contrabandist":	{"NN"},
"contrabandists":	{"NNS"},
"contrabass":	{"JJ","NN"},
"contrabassoon":	{"NN"},
"contracept":	{"VB"},
"contraception":	{"NN"},
"contraceptive":	{"JJ","NN"},
"contraceptives":	{"NNS"},
"contraclockwise":	{"JJ"},
"contract":	{"NN","VB","VBP"},
"contract-drilling":	{"NN","VBG"},
"contract-food":	{"NN"},
"contract-negotiation":	{"NN"},
"contract-services":	{"NNS"},
"contract-steering":	{"JJ"},
"contractable":	{"JJ"},
"contracted":	{"VBD","VBN"},
"contracted-for":	{"JJ"},
"contractile":	{"JJ"},
"contractility":	{"NN"},
"contracting":	{"VBG","JJ"},
"contraction":	{"NN"},
"contraction-extension":	{"JJ"},
"contractions":	{"NNS"},
"contractor":	{"NN"},
"contractors":	{"NNS"},
"contracts":	{"NNS","VBZ"},
"contractual":	{"JJ","NN"},
"contractually":	{"RB"},
"contracture":	{"NN"},
"contradance":	{"NN","VB"},
"contradict":	{"VB","NN","VBP"},
"contradicted":	{"VBD","VBN"},
"contradicting":	{"VBG","NN"},
"contradiction":	{"NN"},
"contradictions":	{"NNS"},
"contradictorily":	{"RB"},
"contradictoriness":	{"NN"},
"contradictory":	{"JJ","NN"},
"contradicts":	{"VBZ","NNS"},
"contradistinction":	{"NN"},
"contradistinguish":	{"VB"},
"contrafagotto":	{"NN"},
"contrail":	{"NN"},
"contraindicate":	{"VB"},
"contraindication":	{"NN"},
"contralateral":	{"JJ"},
"contralto":	{"NN"},
"contraption":	{"NN"},
"contraptions":	{"NNS"},
"contrapuntal":	{"JJ"},
"contrapuntist":	{"NN"},
"contrarian":	{"NN"},
"contrarians":	{"NNS"},
"contrarieties":	{"NNS"},
"contrariety":	{"NN"},
"contrarily":	{"RB"},
"contrariness":	{"NN"},
"contrarious":	{"JJ"},
"contrariwise":	{"RB"},
"contrary":	{"NN","JJ"},
"contrary-to-reality":	{"JJ"},
"contras":	{"NNS"},
"contrast":	{"NN","VB","VBP"},
"contrasted":	{"VBD","VBN"},
"contrasting":	{"VBG","JJ"},
"contrastingly":	{"RB"},
"contrastive":	{"JJ"},
"contrasts":	{"NNS","VBZ"},
"contrasty":	{"JJ"},
"contravene":	{"VB","VBP"},
"contravened":	{"VBD","VBN"},
"contravenes":	{"VBZ"},
"contravening":	{"VBG"},
"contravention":	{"NN"},
"contraventions":	{"NNS"},
"contredanse":	{"NN","VB"},
"contretemps":	{"NN","NNS"},
"contribs":	{"NNS"},
"contribute":	{"VB","VBP"},
"contributed":	{"VBD","VBN"},
"contributes":	{"VBZ"},
"contributing":	{"VBG"},
"contribution":	{"NN"},
"contributions":	{"NNS"},
"contributive":	{"JJ"},
"contributor":	{"NN"},
"contributors":	{"NNS"},
"contributory":	{"JJ"},
"contrite":	{"JJ","NN"},
"contritely":	{"RB"},
"contriteness":	{"NN"},
"contrition":	{"NN"},
"contrivance":	{"NN"},
"contrivances":	{"NNS"},
"contrive":	{"VB","VBP"},
"contrived":	{"JJ","VBD","VBN"},
"contriver":	{"NN"},
"contrives":	{"VBZ"},
"contriving":	{"VBG"},
"control":	{"NN","VB","VBP"},
"control-room":	{"NN"},
"controllable":	{"JJ","NN"},
"controlled":	{"VBN","VBD","JJ"},
"controlled-circulation":	{"JJ"},
"controller":	{"NN"},
"controllers":	{"NNS"},
"controllership":	{"NN"},
"controlling":	{"VBG"},
"controls":	{"NNS","VBZ"},
"controversial":	{"JJ"},
"controversialist":	{"NN"},
"controversialists":	{"NNS"},
"controversially":	{"RB"},
"controversies":	{"NNS"},
"controversy":	{"NN"},
"controversy-prone":	{"JJ"},
"controvert":	{"VB","VBP"},
"controverted":	{"VBD","VBN"},
"controverting":	{"VBG"},
"controverts":	{"VBZ"},
"contumacious":	{"JJ"},
"contumaciously":	{"RB"},
"contumacy":	{"NN"},
"contumelious":	{"JJ"},
"contumeliously":	{"RB"},
"contumely":	{"NN"},
"contuse":	{"VB"},
"contusion":	{"NN"},
"contusions":	{"NNS"},
"conundrum":	{"NN"},
"conurbation":	{"NN"},
"conuropsis":	{"NN"},
"convalesce":	{"VB","VBP"},
"convalesced":	{"VBD","VBN"},
"convalescence":	{"NN"},
"convalescent":	{"JJ","NN"},
"convalescents":	{"NNS"},
"convalesces":	{"VBZ"},
"convalescing":	{"VBG"},
"convallaria":	{"NN"},
"convallariaceae":	{"NN"},
"convect":	{"VB","VBP"},
"convected":	{"VBD","VBN"},
"convecting":	{"VBG"},
"convection":	{"NN"},
"convector":	{"NN"},
"convectors":	{"NNS"},
"convects":	{"VBZ"},
"convenants":	{"NNS"},
"convene":	{"VB","VBP"},
"convened":	{"VBD","VBN"},
"convener":	{"NN"},
"conveners":	{"NNS"},
"convenes":	{"VBZ"},
"convenience":	{"NN"},
"convenience-food":	{"NN"},
"convenience-store":	{"NN"},
"conveniences":	{"NNS"},
"convenient":	{"JJ"},
"convenient-type":	{"JJ"},
"conveniently":	{"RB"},
"convening":	{"VBG"},
"convent":	{"NN"},
"conventicle":	{"NN"},
"convention":	{"NN"},
"convention-goers":	{"NNS"},
"conventional":	{"JJ"},
"conventional-arms":	{"NNS","JJ"},
"conventional-type":	{"JJ"},
"conventionalisation":	{"NN"},
"conventionalise":	{"VB","VBP"},
"conventionalised":	{"VBD","VBN"},
"conventionalises":	{"VBZ"},
"conventionalising":	{"VBG"},
"conventionalism":	{"NN"},
"conventionality":	{"NN"},
"conventionalization":	{"NN"},
"conventionalize":	{"VB","VBP"},
"conventionalized":	{"VBD","VBN"},
"conventionalizes":	{"VBZ"},
"conventionalizing":	{"VBG"},
"conventionally":	{"RB"},
"conventioneer":	{"NN"},
"conventioneers":	{"NNS"},
"conventioners":	{"NNS"},
"conventions":	{"NNS"},
"convents":	{"NNS"},
"conventual":	{"JJ"},
"converage":	{"NN"},
"converge":	{"VB","NN","VBP"},
"converged":	{"VBD","VBN"},
"convergence":	{"NN"},
"convergency":	{"NN"},
"convergent":	{"JJ","NN"},
"converges":	{"VBZ"},
"converging":	{"NN","VBG"},
"conversance":	{"NN"},
"conversancy":	{"NN"},
"conversant":	{"JJ","NN"},
"conversation":	{"NN"},
"conversational":	{"JJ"},
"conversationalist":	{"NN"},
"conversationally":	{"RB"},
"conversationist":	{"NN"},
"conversations":	{"NNS"},
"converse":	{"VB","JJ","NN"},
"conversed":	{"VBD","VBN"},
"conversely":	{"RB"},
"converses":	{"VBZ"},
"conversing":	{"VBG","NN"},
"conversion":	{"NN"},
"conversion-by-renovation":	{"JJ"},
"conversions":	{"NNS"},
"converso":	{"NN"},
"convert":	{"VB","VBP","NN"},
"converted":	{"VBN","VBD","JJ"},
"converter":	{"NN"},
"converters":	{"NNS"},
"convertibility":	{"NN"},
"convertible":	{"JJ","NN"},
"convertible-bond":	{"JJ"},
"convertibles":	{"NNS"},
"converting":	{"VBG"},
"convertor":	{"NN"},
"converts":	{"VBZ","NNS"},
"convex":	{"JJ","NN"},
"convexity":	{"NN"},
"convexly":	{"RB"},
"convexness":	{"NN"},
"convexo-concave":	{"JJ"},
"convexo-convex":	{"JJ"},
"convey":	{"VB","VBP"},
"conveyable":	{"JJ"},
"conveyance":	{"NN"},
"conveyancer":	{"NN"},
"conveyancers":	{"NNS"},
"conveyancing":	{"NN"},
"conveyed":	{"VBD","VBN"},
"conveyer":	{"NN"},
"conveyers":	{"NNS"},
"conveying":	{"VBG"},
"conveyor":	{"NN"},
"conveyors":	{"NNS"},
"conveys":	{"VBZ"},
"convict":	{"VB","VBP","NN"},
"convicted":	{"VBN","VBD"},
"convictfish":	{"NN"},
"convicting":	{"VBG"},
"conviction":	{"NN"},
"convictions":	{"NNS"},
"convicts":	{"VBZ","NNS"},
"convince":	{"VB","VBP"},
"convinced":	{"VBN","VBD","JJ"},
"convinces":	{"VBZ"},
"convincible":	{"JJ"},
"convincing":	{"JJ","VBG"},
"convincingly":	{"RB"},
"convincingness":	{"NN"},
"convivial":	{"JJ","NN"},
"conviviality":	{"NN"},
"convivially":	{"RB"},
"convocation":	{"NN"},
"convocations":	{"NNS"},
"convoke":	{"VB","VBP"},
"convoked":	{"VBD","VBN"},
"convokes":	{"VBZ"},
"convoking":	{"VBG"},
"convolute":	{"VB","VBP","JJ"},
"convoluted":	{"JJ","VBN","VBD"},
"convolutedness":	{"NN"},
"convolutely":	{"RB"},
"convolutes":	{"VBZ"},
"convoluting":	{"VBG"},
"convolution":	{"NN"},
"convolutions":	{"NNS"},
"convolve":	{"VB"},
"convolvulaceae":	{"NN"},
"convolvulus":	{"NN"},
"convoy":	{"NN","VB","VBP"},
"convoyed":	{"VBD","VBN"},
"convoying":	{"VBG"},
"convoys":	{"NNS","VBZ"},
"convulse":	{"VB","VBP"},
"convulsed":	{"VBD","VBN"},
"convulses":	{"VBZ"},
"convulsing":	{"VBG"},
"convulsion":	{"NN"},
"convulsions":	{"NNS"},
"convulsive":	{"JJ"},
"convulsively":	{"RB"},
"cony":	{"NN"},
"conyza":	{"NN"},
"coo":	{"NN","VB","VBP","UH"},
"cooccur":	{"VB"},
"cooccurring":	{"JJ"},
"cooed":	{"VBD","VBN"},
"cooing":	{"VBG"},
"cook":	{"VB","NN","VBP"},
"cookbook":	{"NN"},
"cookbooks":	{"NNS"},
"cooke":	{"NN"},
"cooked":	{"VBN","VBD","JJ"},
"cooked-over":	{"JJ"},
"cooker":	{"NN"},
"cookers":	{"NNS"},
"cookery":	{"NN"},
"cookfire":	{"NN"},
"cookhouse":	{"NN"},
"cookie":	{"NN"},
"cookie-and-cracker":	{"JJ"},
"cookie-cutter":	{"JJ"},
"cookie-sized":	{"JJ"},
"cookies":	{"NNS"},
"cooking":	{"NN","VBG","JJ"},
"cookout":	{"NN"},
"cooks":	{"NNS","VBZ"},
"cookstove":	{"NN"},
"cookware":	{"NN"},
"cooky":	{"NN"},
"cool":	{"JJ","VB","NN","VBP","RB"},
"cool-down":	{"NN"},
"cool-downs":	{"NNS"},
"cool-headed":	{"JJ"},
"cool-white":	{"JJ"},
"coolant":	{"NN"},
"coolants":	{"NNS"},
"cooldown":	{"NN"},
"cooldowns":	{"NNS"},
"cooled":	{"VBD","VBN"},
"cooler":	{"NN","JJR"},
"coolers":	{"NNS"},
"coolest":	{"JJS"},
"coolheaded":	{"JJ"},
"coolie":	{"NN"},
"coolies":	{"NNS"},
"cooling":	{"NN","VBG"},
"cooling-heating":	{"JJ"},
"cooling-off":	{"JJ","NN"},
"coolly":	{"RB"},
"coolness":	{"NN"},
"coolnesses":	{"NNS"},
"cools":	{"VBZ"},
"coolwart":	{"NN"},
"cooly":	{"NN"},
"coon":	{"NN"},
"coondog":	{"NN"},
"coonhound":	{"NN"},
"coonskin":	{"NN","JJ"},
"coontie":	{"NN"},
"coop":	{"NN","VB","VBP"},
"cooped":	{"VBD","VBN"},
"cooper":	{"NN","VB","VBP"},
"cooperate":	{"VB","VBP"},
"cooperated":	{"VBD","VBN"},
"cooperates":	{"VBZ"},
"cooperating":	{"VBG"},
"cooperation":	{"NN"},
"cooperative":	{"JJ","NN"},
"cooperative-care":	{"JJ"},
"cooperatively":	{"RB"},
"cooperativeness":	{"NN"},
"cooperatives":	{"NNS"},
"cooperator":	{"NN"},
"coopered":	{"VBD","VBN"},
"coopering":	{"VBG"},
"coopers":	{"NNS","VBZ"},
"cooperstown":	{"NN"},
"cooping":	{"VBG"},
"coops":	{"NNS","VBZ"},
"coopt":	{"VB","VBP"},
"coopted":	{"VBD","VBN"},
"coopting":	{"VBG"},
"coopts":	{"VBZ"},
"coordinate":	{"VB","VBP","NN","JJ"},
"coordinated":	{"VBD","VBN","JJ"},
"coordinately":	{"RB"},
"coordinates":	{"NNS","VBZ"},
"coordinating":	{"VBG"},
"coordination":	{"NN"},
"coordinative":	{"JJ"},
"coordinator":	{"NN"},
"coordinators":	{"NNS"},
"coos":	{"VBZ","NNS"},
"coosa":	{"NN"},
"coosie":	{"NN"},
"coot":	{"NN"},
"cooter":	{"NN"},
"cootie":	{"NN"},
"cop":	{"NN","VBP","VB"},
"cop-killer":	{"JJ"},
"cop-out":	{"NN"},
"copacetic":	{"JJ"},
"copaiba":	{"NN"},
"copal":	{"NN"},
"copaline":	{"NN"},
"copalite":	{"NN"},
"copartner":	{"NN"},
"copartnership":	{"NN"},
"copasetic":	{"JJ"},
"copay":	{"NN"},
"copayment":	{"NN"},
"copayments":	{"NNS"},
"cope":	{"VB","NN","VBP"},
"copeck":	{"NN"},
"coped":	{"VBD","VBN"},
"copehan":	{"NN"},
"copenhagen":	{"NN"},
"copepod":	{"NN"},
"copepoda":	{"NN"},
"copernican":	{"JJ"},
"copernicia":	{"NN"},
"copernicus":	{"NN"},
"copernicus-the-astronomer":	{"NN"},
"copes":	{"VBZ","NNS"},
"copesetic":	{"JJ"},
"copesettic":	{"JJ"},
"copestone":	{"NN"},
"copied":	{"VBN","VBD"},
"copier":	{"NN"},
"copiers":	{"NNS"},
"copies":	{"NNS","VBZ"},
"copilot":	{"NN"},
"coping":	{"VBG","NN"},
"copings":	{"NNS"},
"copious":	{"JJ"},
"copiously":	{"RB"},
"copiousness":	{"NN"},
"coplanar":	{"JJ"},
"copland":	{"NN"},
"coplandesque":	{"JJ"},
"copley":	{"NN"},
"copolymer":	{"NN"},
"copolymerise":	{"VB"},
"copolymerize":	{"VB"},
"copolymers":	{"NNS"},
"copout":	{"NN"},
"copped":	{"VBD","VBN"},
"copper":	{"NN","VB","VBP"},
"copper-based":	{"JJ"},
"copper-bottom":	{"VB"},
"copper-bottomed":	{"JJ"},
"copper-producing":	{"JJ"},
"copper-rich":	{"JJ"},
"coppered":	{"VBD","VBN"},
"copperhead":	{"NN"},
"coppering":	{"VBG"},
"copperplate":	{"NN"},
"coppers":	{"NNS","VBZ"},
"coppersmith":	{"NN"},
"copperware":	{"NN"},
"coppery":	{"JJ"},
"coppice":	{"NN","VB","VBP"},
"coppiced":	{"VBD","VBN"},
"coppices":	{"NNS","VBZ"},
"coppicing":	{"VBG"},
"copping":	{"VBG"},
"coppola":	{"NN"},
"copra":	{"NN"},
"coprinaceae":	{"NN"},
"coprinus":	{"NN"},
"coproduce":	{"VB","VBP"},
"coproduced":	{"VBD","VBN"},
"coproducer":	{"NN"},
"coproduces":	{"VBZ"},
"coproducing":	{"VBG"},
"coproductions":	{"NNS"},
"coprolalia":	{"NN"},
"coprolite":	{"NN"},
"coprolith":	{"NN"},
"coprophagia":	{"NN"},
"coprophagy":	{"NN"},
"cops":	{"NNS","VBZ"},
"copse":	{"NN"},
"copt":	{"NN"},
"coptic":	{"JJ","NN"},
"coptis":	{"NN"},
"copula":	{"NN"},
"copular":	{"JJ"},
"copulate":	{"VB","VBP"},
"copulated":	{"VBD","VBN"},
"copulates":	{"VBZ"},
"copulating":	{"VBG"},
"copulation":	{"NN"},
"copulations":	{"NNS"},
"copulative":	{"JJ"},
"copulatory":	{"JJ"},
"copy":	{"NN","VB","VBP"},
"copy-cat":	{"JJ"},
"copybook":	{"NN","JJ"},
"copybooks":	{"NNS"},
"copycat":	{"NN","JJ","VB","VBP"},
"copycats":	{"NNS","VBZ"},
"copycatted":	{"VBD","VBN"},
"copycatting":	{"VBG"},
"copyedit":	{"VB"},
"copyhold":	{"NN"},
"copyholder":	{"NN"},
"copying":	{"VBG","NN"},
"copyist":	{"NN"},
"copyread":	{"VB"},
"copyreader":	{"NN"},
"copyright":	{"NN","JJ","VB","VBP"},
"copyright-infringement":	{"NN"},
"copyrighted":	{"VBD","VBN"},
"copyrighting":	{"VBG"},
"copyrights":	{"NNS","VBZ"},
"copywriter":	{"NN"},
"coquet":	{"VB"},
"coquetry":	{"NN"},
"coquette":	{"NN"},
"coquettish":	{"JJ","NN"},
"coquettishly":	{"RB"},
"coquille":	{"NN"},
"cora":	{"NN"},
"coracan":	{"NN"},
"coracias":	{"NNS"},
"coraciidae":	{"NN"},
"coraciiformes":	{"NNS"},
"coracle":	{"NN"},
"coragyps":	{"NNS"},
"corakan":	{"NN"},
"coral":	{"NN","JJ"},
"coral-colored":	{"JJ"},
"coral-red":	{"JJ"},
"coral-wood":	{"NN"},
"coralbells":	{"NNS"},
"coralberry":	{"NN"},
"corallorhiza":	{"NN"},
"coralroot":	{"NN"},
"coralwood":	{"NN"},
"coralwort":	{"NN"},
"corbel":	{"NN"},
"corbeled":	{"VBD","VBN"},
"corbeling":	{"VBG"},
"corbelled":	{"JJ","VBD","VBN"},
"corbelling":	{"VBG"},
"corbels":	{"VBZ"},
"corbett":	{"NN"},
"corbie-step":	{"NN"},
"corbiestep":	{"NN"},
"corbin":	{"NN"},
"corbina":	{"NN"},
"corby":	{"NN"},
"corchorus":	{"NN"},
"corcoran":	{"NN"},
"cord":	{"NN","VBP","VB","JJ"},
"cordage":	{"NN"},
"cordaitaceae":	{"NN"},
"cordaitales":	{"NNS"},
"cordaites":	{"NNS"},
"cordarone":	{"NN"},
"cordate":	{"JJ"},
"corday":	{"NN"},
"corded":	{"VBD","VBN"},
"cordgrass":	{"NN"},
"cordia":	{"NN"},
"cordial":	{"JJ","NN"},
"cordiality":	{"NN"},
"cordially":	{"RB"},
"cordials":	{"NNS"},
"cordierite":	{"NN"},
"cordiform":	{"JJ"},
"cording":	{"VBG"},
"cordite":	{"NN"},
"corditis":	{"NN"},
"cordless":	{"JJ"},
"cordoba":	{"NN"},
"cordon":	{"NN","VB","VBP"},
"cordoned":	{"VBD","VBN"},
"cordoning":	{"VBG"},
"cordons":	{"NNS","VBZ"},
"cordova":	{"NN"},
"cords":	{"NNS","VBZ"},
"corduroy":	{"NN","VB","VBP"},
"corduroyed":	{"VBD","VBN"},
"corduroying":	{"VBG"},
"corduroys":	{"NNS","VBZ"},
"cordwood":	{"NN"},
"cordylidae":	{"NN"},
"cordyline":	{"NN"},
"cordylus":	{"NN"},
"core":	{"NN","JJ","VB","VBP"},
"core-jacket":	{"JJ"},
"cored":	{"VBD","VBN"},
"coreference":	{"NN"},
"coreferent":	{"JJ"},
"coreferential":	{"JJ"},
"coregonidae":	{"NN"},
"coregonus":	{"NN"},
"coreid":	{"NN"},
"coreidae":	{"NN"},
"coreligionist":	{"NN"},
"corelli":	{"NN"},
"coreopsis":	{"NN"},
"corer":	{"NN"},
"cores":	{"NNS","VBZ"},
"corespondent":	{"NN"},
"corgard":	{"NN"},
"corgi":	{"NN"},
"coriaceous":	{"JJ"},
"coriander":	{"NN"},
"coriandrum":	{"NN"},
"coricidin":	{"NN"},
"coring":	{"VBG"},
"corinne":	{"NN"},
"corinth":	{"NN"},
"corium":	{"NN"},
"corixa":	{"NN"},
"corixidae":	{"NN"},
"cork":	{"NN","VBP","VB"},
"corkage":	{"NN"},
"corkboard":	{"NN"},
"corked":	{"JJ","VBD","VBN"},
"corker":	{"NN"},
"corkers":	{"NNS"},
"corking":	{"JJ","VBG"},
"corks":	{"NNS","VBZ"},
"corkscrew":	{"NN","VBP","JJ","VB"},
"corkscrewed":	{"VBD","VBN"},
"corkscrewing":	{"VBG"},
"corkscrews":	{"NNS","VBZ"},
"corkwood":	{"NN"},
"corky":	{"JJ"},
"corm":	{"NN"},
"cormorant":	{"NN"},
"cormose":	{"JJ"},
"cormous":	{"JJ"},
"corn":	{"NN","VB","VBP"},
"corn-based":	{"JJ"},
"corn-belt":	{"NN"},
"corn-buying":	{"JJ"},
"corn-farmers":	{"NNS"},
"corn-fed":	{"JJ"},
"corn-producing":	{"JJ"},
"corn-seed":	{"NN"},
"cornaceae":	{"NN"},
"cornball":	{"NN","JJ"},
"cornbread":	{"NN"},
"corncob":	{"NN"},
"corncrake":	{"NN"},
"corncrib":	{"NN"},
"corne":	{"NN"},
"cornea":	{"NN"},
"corneal":	{"JJ","NN"},
"corned":	{"JJ","VBD","VBN"},
"corneille":	{"NN"},
"cornel":	{"NN"},
"cornelian":	{"NN"},
"cornell":	{"NN"},
"corneous":	{"JJ"},
"corner":	{"NN","VB","VBP"},
"corner-posts":	{"NNS"},
"cornerback":	{"NN"},
"cornerbacks":	{"NNS"},
"cornered":	{"VBD","VBN","JJ"},
"cornering":	{"VBG"},
"corners":	{"NNS","VBZ"},
"cornerstone":	{"NN"},
"cornerstones":	{"NNS"},
"cornet":	{"NN"},
"cornetfish":	{"NN"},
"cornetist":	{"NN"},
"corneum":	{"NN"},
"cornfield":	{"NN"},
"cornfields":	{"NNS"},
"cornflake-size":	{"JJ"},
"cornflour":	{"NN"},
"cornflower":	{"NN"},
"cornflowers":	{"NNS"},
"cornhusk":	{"NN"},
"cornhusker":	{"NN"},
"cornhusking":	{"NN"},
"cornice":	{"NN","VB","VBP"},
"corniced":	{"VBD","VBN"},
"cornices":	{"NNS","VBZ"},
"cornicing":	{"VBG"},
"cornier":	{"JJR"},
"corniest":	{"JJS"},
"corning":	{"VBG"},
"cornishman":	{"NN"},
"cornishwoman":	{"NN"},
"cornmeal":	{"NN"},
"cornmeal-price":	{"NN"},
"cornpone":	{"NN"},
"corns":	{"NNS","VBZ"},
"cornsilk":	{"NN"},
"cornsmut":	{"NN"},
"cornstalk":	{"NN"},
"cornstarch":	{"NN"},
"cornu":	{"NN"},
"cornucopia":	{"NN"},
"cornus":	{"NN"},
"cornwall":	{"NN"},
"cornwallis":	{"NN"},
"corny":	{"JJ"},
"corokia":	{"NN"},
"corolla":	{"NN"},
"corollaries":	{"NNS"},
"corollary":	{"NN","JJ"},
"corona":	{"NN"},
"coronach":	{"NN"},
"coronal":	{"JJ","NN"},
"coronaries":	{"NNS"},
"coronary":	{"JJ","NN"},
"coronate":	{"VB","VBP","JJ"},
"coronated":	{"VBD","VBN"},
"coronates":	{"VBZ"},
"coronating":	{"VBG"},
"coronation":	{"NN"},
"coroner":	{"NN"},
"coronet":	{"NN"},
"coroneted":	{"JJ"},
"coronilla":	{"NN"},
"coronion":	{"NN"},
"coropuna":	{"NN"},
"corot":	{"NN"},
"corozo":	{"NN"},
"corpocrat":	{"NN"},
"corporal":	{"NN","JJ"},
"corporality":	{"NN"},
"corporate":	{"JJ"},
"corporate-bond":	{"JJ"},
"corporate-coverage":	{"JJ"},
"corporate-development":	{"NN"},
"corporate-earnings":	{"NNS"},
"corporate-entertainment":	{"JJ"},
"corporate-finance":	{"JJ","NN"},
"corporate-identity":	{"JJ"},
"corporate-image":	{"JJ"},
"corporate-law":	{"NN"},
"corporate-lending":	{"JJ"},
"corporate-owned":	{"JJ"},
"corporate-pension":	{"JJ"},
"corporate-raider":	{"JJ"},
"corporate-related":	{"JJ"},
"corporate-securities":	{"JJ"},
"corporate-settlement":	{"NN"},
"corporate-tax":	{"JJ"},
"corporate-wide":	{"JJ"},
"corporates":	{"NNS"},
"corporatewide":	{"JJ"},
"corporation":	{"NN"},
"corporation-socialist":	{"JJ"},
"corporations":	{"NNS"},
"corporatism":	{"NN"},
"corporatist":	{"JJ","NN"},
"corporativism":	{"NN"},
"corporativists":	{"NNS"},
"corporeal":	{"JJ"},
"corporeality":	{"NN"},
"corporis":	{"FW"},
"corposant":	{"NN"},
"corps":	{"NNS","NN"},
"corpse":	{"NN"},
"corpses":	{"NNS"},
"corpsman":	{"NN"},
"corpulence":	{"NN"},
"corpulency":	{"NN"},
"corpulent":	{"JJ"},
"corpus":	{"NN"},
"corpuscle":	{"NN"},
"corpuscular":	{"JJ"},
"corpuscular-radiation":	{"NN"},
"corrade":	{"VB"},
"corral":	{"NN","VB","VBP"},
"corraled":	{"VBD","VBN"},
"corraling":	{"VBG"},
"corralled":	{"VBD","VBN"},
"corralling":	{"VBG","NN"},
"corrals":	{"VBZ","NNS"},
"corrasion":	{"NN"},
"correct":	{"JJ","VB","VBP"},
"correctable":	{"JJ"},
"corrected":	{"VBD","VBN"},
"correcting":	{"JJ","VBG","NN"},
"correction":	{"NN"},
"correctional":	{"JJ"},
"corrections":	{"NNS"},
"correctitude":	{"NN"},
"corrective":	{"JJ","NN"},
"correctly":	{"RB"},
"correctness":	{"NN"},
"corrects":	{"JJ","VBZ","NN"},
"correggio":	{"NN"},
"corregidor":	{"NN"},
"correlate":	{"VB","VBP"},
"correlated":	{"VBD","VBN"},
"correlates":	{"VBZ"},
"correlating":	{"VBG"},
"correlation":	{"NN"},
"correlational":	{"JJ"},
"correlations":	{"NNS"},
"correlative":	{"NN","JJ"},
"correlatively":	{"RB"},
"correlatives":	{"NNS"},
"correlativity":	{"NN"},
"correspond":	{"VB","VBP"},
"corresponded":	{"VBD","VBN"},
"correspondence":	{"NN"},
"correspondent":	{"NN"},
"correspondents":	{"NNS"},
"corresponding":	{"JJ","VBG"},
"correspondingly":	{"RB"},
"corresponds":	{"VBZ"},
"corrida":	{"NN"},
"corridor":	{"NN"},
"corridors":	{"NNS"},
"corrie":	{"NN"},
"corrigenda":	{"NNS"},
"corrigendum":	{"NN"},
"corrigible":	{"JJ"},
"corroborant":	{"JJ"},
"corroborate":	{"VB","VBP"},
"corroborated":	{"VBD","VBN"},
"corroborates":	{"VBZ"},
"corroborating":	{"VBG"},
"corroboration":	{"NN"},
"corroborative":	{"JJ"},
"corroboratory":	{"JJ"},
"corroborees":	{"NNS"},
"corrode":	{"VB","VBP"},
"corroded":	{"VBD","VBN","JJ"},
"corrodentia":	{"NN"},
"corrodes":	{"VBZ"},
"corroding":	{"VBG"},
"corrosion":	{"NN"},
"corrosion-protection":	{"JJ","NN"},
"corrosion-resistant":	{"JJ"},
"corrosive":	{"JJ","NN"},
"corrugate":	{"VB"},
"corrugated":	{"JJ","VBD","VBN"},
"corrugates":	{"VBZ"},
"corrugating":	{"VBG"},
"corrugation":	{"NN"},
"corrugations":	{"NNS"},
"corrupt":	{"JJ","VB","VBP"},
"corrupted":	{"VBD","VBN"},
"corruptedly":	{"RB"},
"corrupter":	{"NN"},
"corruptibility":	{"NN"},
"corruptible":	{"JJ"},
"corrupting":	{"VBG","NN"},
"corruption":	{"NN"},
"corruptions":	{"NNS"},
"corruptive":	{"JJ"},
"corruptly":	{"RB"},
"corruptness":	{"NN"},
"corrupts":	{"VBZ"},
"corsage":	{"NN"},
"corsair":	{"NN"},
"corse":	{"NN"},
"corselet":	{"NN"},
"corset":	{"NN","VB","VBP"},
"corseted":	{"VBD","VBN","JJ"},
"corseting":	{"VBG"},
"corsets":	{"NNS","VBZ"},
"corsica":	{"NN"},
"corsican":	{"JJ"},
"corsicas":	{"NNS"},
"corslet":	{"NN"},
"cortaderia":	{"NN"},
"cortef":	{"NN"},
"cortege":	{"NN"},
"corteggiamento":	{"FW"},
"cortex":	{"NN"},
"cortez":	{"NN"},
"cortical":	{"JJ"},
"cortically":	{"RB"},
"corticifugal":	{"JJ"},
"corticipetal":	{"JJ"},
"corticium":	{"NN"},
"cortico-fugal":	{"JJ","NN"},
"cortico-hypothalamic":	{"JJ"},
"corticoafferent":	{"JJ"},
"corticoefferent":	{"JJ"},
"corticofugal":	{"JJ"},
"corticoid":	{"NN"},
"corticosteroid":	{"NN"},
"corticosteroids":	{"NNS"},
"corticosterone":	{"NN"},
"corticotrophin":	{"NN"},
"corticotropin":	{"NN"},
"cortina":	{"NN"},
"cortinariaceae":	{"NN"},
"cortinarius":	{"NNS"},
"cortisol":	{"NN"},
"cortisone":	{"NN"},
"cortland":	{"NN"},
"corundom":	{"NN"},
"corundum":	{"NN"},
"coruscant":	{"JJ"},
"coruscate":	{"VB","VBP"},
"coruscated":	{"VBD","VBN"},
"coruscates":	{"VBZ"},
"coruscating":	{"VBG"},
"coruscation":	{"NN"},
"corvee":	{"NN"},
"corvette":	{"NN"},
"corvettes":	{"NNS"},
"corvidae":	{"NN"},
"corvine":	{"JJ"},
"corvus":	{"NN"},
"coryanthes":	{"NNS"},
"corydalidae":	{"NN"},
"corydalis":	{"NN"},
"corydalus":	{"NN"},
"corylaceae":	{"NN"},
"corylopsis":	{"NN"},
"corylus":	{"NN"},
"corymb":	{"NN"},
"corymbose":	{"JJ"},
"corynebacteriaceae":	{"NN"},
"corynebacterium":	{"NN"},
"corypha":	{"NN"},
"coryphaenidae":	{"NN"},
"coryphantha":	{"NN"},
"corythosaur":	{"NN"},
"corythosaurus":	{"NN"},
"coryza":	{"NN"},
"cos":	{"NN"},
"coscoroba":	{"NN"},
"cosec":	{"NN"},
"cosecant":	{"NN"},
"coseismal":	{"JJ"},
"coseismic":	{"JJ"},
"cosh":	{"NN","VB","VBP"},
"coshed":	{"VBD","VBN"},
"cosher":	{"JJ"},
"coshes":	{"NNS","VBZ"},
"coshing":	{"VBG"},
"cosied":	{"VBD","VBN"},
"cosier":	{"JJR"},
"cosies":	{"NNS","VBZ"},
"cosiest":	{"JJS"},
"cosign":	{"VB","VBP"},
"cosignatory":	{"JJ","NN"},
"cosigned":	{"VBD","VBN"},
"cosigner":	{"NN"},
"cosigners":	{"NNS"},
"cosigning":	{"VBG"},
"cosigns":	{"VBZ"},
"cosily":	{"RB"},
"cosine":	{"NN"},
"cosiness":	{"NN"},
"cosmea":	{"NN"},
"cosmetic":	{"JJ","NN"},
"cosmetically":	{"RB"},
"cosmetician":	{"NN"},
"cosmetics":	{"NNS"},
"cosmetics-industry":	{"NN"},
"cosmetologist":	{"NN"},
"cosmetology":	{"NN"},
"cosmic":	{"JJ"},
"cosmical":	{"JJ"},
"cosmid":	{"NN"},
"cosmocampus":	{"NN"},
"cosmogenic":	{"JJ"},
"cosmogeny":	{"NN"},
"cosmogonic":	{"JJ"},
"cosmogonical":	{"JJ"},
"cosmogony":	{"NN"},
"cosmographer":	{"NN"},
"cosmographist":	{"NN"},
"cosmography":	{"NN"},
"cosmolatry":	{"NN"},
"cosmologic":	{"JJ"},
"cosmological":	{"JJ"},
"cosmologies":	{"NNS"},
"cosmologist":	{"NN"},
"cosmologists":	{"NNS"},
"cosmology":	{"NN"},
"cosmonaut":	{"NN"},
"cosmopolitan":	{"JJ","NN"},
"cosmopolitanism":	{"NN"},
"cosmopolitans":	{"NNS"},
"cosmopolite":	{"NN"},
"cosmos":	{"NN"},
"cosmotron":	{"NN"},
"cosplay":	{"NN","VB","VBP"},
"cosplayed":	{"VBD","VBN"},
"cosplayer":	{"NN"},
"cosplayers":	{"NNS"},
"cosplaying":	{"VBG"},
"cosplays":	{"NNS","VBZ"},
"cosponsor":	{"VB","VBP","NN"},
"cosponsored":	{"VBD","VBN"},
"cosponsoring":	{"VBG"},
"cosponsors":	{"VBZ","NNS"},
"coss":	{"NN"},
"cossack":	{"NN"},
"cosset":	{"VB","VBP"},
"cosseted":	{"VBD","VBN","JJ"},
"cosseting":	{"VBG"},
"cossets":	{"VBZ"},
"cost":	{"NN","VB","VBD","VBP","VBN"},
"cost-accounting":	{"JJ"},
"cost-benefit":	{"JJ","NN"},
"cost-billing":	{"JJ"},
"cost-conscious":	{"JJ"},
"cost-consciousness":	{"NN"},
"cost-containment":	{"NN","JJ"},
"cost-control":	{"JJ"},
"cost-cutters":	{"NNS"},
"cost-cutting":	{"JJ","NN"},
"cost-data":	{"JJ"},
"cost-effective":	{"JJ"},
"cost-effectiveness":	{"JJ","NN"},
"cost-efficiency":	{"NN"},
"cost-efficient":	{"JJ"},
"cost-finding":	{"JJ"},
"cost-of-living":	{"JJ","NN"},
"cost-plus":	{"JJ"},
"cost-prohibitive":	{"JJ"},
"cost-push":	{"JJ"},
"cost-raising":	{"JJ"},
"cost-recovery":	{"JJ"},
"cost-reduction":	{"JJ","NN"},
"cost-saving":	{"JJ"},
"cost-savings":	{"JJ","NNS"},
"cost-sharing":	{"NN","JJ"},
"cost-shifting":	{"NN"},
"cost-to-benefit":	{"JJ"},
"cost-transfer":	{"NN"},
"costa":	{"NN","JJ"},
"costal":	{"JJ"},
"costalgia":	{"NN"},
"costanoan":	{"NN"},
"costate":	{"JJ"},
"costcutting":	{"NN"},
"costello":	{"NN"},
"costermonger":	{"NN"},
"costia":	{"NN"},
"costiasis":	{"NN"},
"costing":	{"VBG","NN"},
"costive":	{"JJ"},
"costless":	{"JJ"},
"costlier":	{"JJR"},
"costliest":	{"JJS"},
"costliness":	{"NN"},
"costly":	{"JJ"},
"costmary":	{"NN"},
"costochondritis":	{"NN"},
"costs":	{"NNS","VBZ"},
"costume":	{"NN","VB","VBP","JJ"},
"costume-jewelry":	{"NN"},
"costumed":	{"VBD","VBN"},
"costumer":	{"NN"},
"costumers":	{"NNS"},
"costumes":	{"NNS","VBZ"},
"costumier":	{"NN"},
"costumiers":	{"NNS"},
"costuming":	{"NN","VBG"},
"costusroot":	{"NN"},
"cosy":	{"JJ","NN","VB","VBP"},
"cosying":	{"VBG"},
"cot":	{"NN"},
"cotacachi":	{"NN"},
"cotan":	{"NN"},
"cotangent":	{"NN"},
"cote":	{"NN"},
"cotenant":	{"NN"},
"coterie":	{"NN"},
"coterminous":	{"JJ"},
"coterminously":	{"RB"},
"cothromboplastin":	{"NN"},
"cotilion":	{"NN"},
"cotillion":	{"NN"},
"cotinga":	{"NN"},
"cotingidae":	{"NN"},
"cotinus":	{"NN"},
"cotoneaster":	{"NN"},
"cotonou":	{"NN"},
"cotopaxi":	{"NN"},
"cots":	{"NNS"},
"cotswold":	{"NN"},
"cotswolds":	{"NNS"},
"cottage":	{"NN"},
"cottager":	{"NN"},
"cottages":	{"NNS"},
"cottar":	{"NN"},
"cotter":	{"NN"},
"cottidae":	{"NN"},
"cottier":	{"NN"},
"cotton":	{"NN","VB","VBP"},
"cotton-ginning":	{"JJ"},
"cotton-growing":	{"JJ"},
"cottoned":	{"VBD","VBN"},
"cottoning":	{"VBG"},
"cottonmouth":	{"NN"},
"cottons":	{"VBZ"},
"cottonseed":	{"NN"},
"cottontail":	{"NN"},
"cottonweed":	{"NN"},
"cottonwick":	{"NN"},
"cottonwood":	{"NN"},
"cottonwoods":	{"NNS"},
"cottony":	{"JJ","NN"},
"cottony-white":	{"JJ"},
"cottus":	{"NN"},
"cotula":	{"NN"},
"coturnix":	{"NN"},
"cotyledon":	{"NN"},
"cotyloid":	{"JJ"},
"cotyloidal":	{"JJ"},
"coucal":	{"NN"},
"couch":	{"NN","VB","VBP"},
"couch-potato":	{"NN"},
"couchant":	{"JJ"},
"couched":	{"VBD","VBN"},
"couches":	{"VBZ","NNS"},
"couchette":	{"NN"},
"couchettes":	{"NNS"},
"couching":	{"VBG"},
"coudn":	{"MD"},
"coue":	{"NN"},
"cougar":	{"NN"},
"cougars":	{"NNS"},
"cough":	{"NN","VB","VBP"},
"coughed":	{"VBD","VBN"},
"coughing":	{"NN","VBG"},
"coughs":	{"NNS","VBZ"},
"could":	{"MD"},
"coulda":	{"NN"},
"coulisse":	{"NN"},
"coulomb":	{"NN"},
"coulter":	{"NN"},
"coumadin":	{"NN"},
"coumarone":	{"NN"},
"coumarouna":	{"NN"},
"council":	{"NN"},
"councillor":	{"NN"},
"councillorship":	{"NN"},
"councilman":	{"NN"},
"councilor":	{"NN"},
"councilors":	{"NNS"},
"councilorship":	{"NN"},
"councils":	{"NNS"},
"councilwoman":	{"NN"},
"counsel":	{"NN","VB","VBP"},
"counseled":	{"VBD","VBN"},
"counseling":	{"NN","VBG"},
"counselled":	{"VBD","VBN"},
"counselling":	{"NN","VBG"},
"counsellor":	{"NN"},
"counsellorship":	{"NN"},
"counselor":	{"NN"},
"counselor-at-law":	{"NN"},
"counselors":	{"NNS"},
"counselorship":	{"NN"},
"counsels":	{"NNS","VBZ"},
"count":	{"NN","VB","VBP"},
"countable":	{"JJ"},
"countdown":	{"NN"},
"counted":	{"VBN","VBD"},
"countenance":	{"NN","VB","VBP"},
"countenanced":	{"VBD","VBN"},
"countenances":	{"NNS","VBZ"},
"countenancing":	{"VBG"},
"counter":	{"NN","VB","VBP","JJ","RB"},
"counter-apparatus":	{"NN"},
"counter-argument":	{"NN"},
"counter-arguments":	{"NNS"},
"counter-attack":	{"NN","VB","VBP"},
"counter-attacked":	{"VBD","VBN"},
"counter-attacking":	{"VBG"},
"counter-attacks":	{"NNS","VBZ"},
"counter-balanced":	{"JJ"},
"counter-claims":	{"NNS"},
"counter-culture":	{"NN"},
"counter-cultures":	{"NNS"},
"counter-cyclical":	{"JJ"},
"counter-demand":	{"NN"},
"counter-drill":	{"VB"},
"counter-efforts":	{"NNS"},
"counter-escalation":	{"NN"},
"counter-evidence":	{"NN"},
"counter-evidences":	{"NNS"},
"counter-intelligence":	{"NN"},
"counter-measures":	{"NNS"},
"counter-moves":	{"NNS"},
"counter-offensive":	{"NN"},
"counter-productive":	{"JJ"},
"counter-revolutionary":	{"JJ"},
"counter-revolutionist":	{"NN"},
"counter-sabotage":	{"NN"},
"counter-successes":	{"NNS"},
"counter-tenor":	{"NN"},
"counter-trade":	{"JJ"},
"counter-trend":	{"JJ"},
"counteract":	{"VB","VBP"},
"counteracted":	{"VBN","VBD"},
"counteracting":	{"VBG"},
"counteraction":	{"NN"},
"counteractive":	{"JJ"},
"counteractively":	{"RB"},
"counteracts":	{"VBZ"},
"counterargument":	{"NN"},
"counterarguments":	{"NNS"},
"counterattack":	{"NN","VB","VBP"},
"counterattacked":	{"VBD","VBN"},
"counterattacking":	{"VBG"},
"counterattacks":	{"NNS","VBZ"},
"counterattraction":	{"NN"},
"counterbalance":	{"NN","VB","VBP"},
"counterbalanced":	{"VBD","VBN"},
"counterbalances":	{"VBZ","NNS"},
"counterbalancing":	{"VBG"},
"counterbid":	{"NN"},
"counterbidder":	{"NN"},
"counterbidders":	{"NNS"},
"counterbids":	{"NNS"},
"counterblast":	{"NN"},
"counterblasts":	{"NNS"},
"counterblow":	{"NN"},
"counterbombardment":	{"NN"},
"counterbore":	{"NN"},
"counterchange":	{"VB","VBP"},
"counterchanged":	{"VBD","VBN"},
"counterchanges":	{"VBZ"},
"counterchanging":	{"VBG"},
"countercharge":	{"NN","VB","VBP"},
"countercharged":	{"VBD","VBN"},
"countercharges":	{"NNS","VBZ"},
"countercharging":	{"VBG"},
"countercheck":	{"NN","VB","VBP"},
"counterchecked":	{"VBD","VBN"},
"counterchecking":	{"VBG"},
"counterchecks":	{"VBZ"},
"counterclaim":	{"NN","VB","VBP"},
"counterclaimed":	{"VBD","VBN"},
"counterclaiming":	{"VBG"},
"counterclaims":	{"NNS","VBZ"},
"counterclockwise":	{"RB"},
"countercoup":	{"NN"},
"countercultural":	{"JJ"},
"counterculture":	{"NN"},
"countercurrent":	{"NN"},
"counterdemonstration":	{"NN"},
"counterdemonstrator":	{"NN"},
"countered":	{"VBD","VBN"},
"counterespionage":	{"NN"},
"counterevidence":	{"NN"},
"counterevidences":	{"NNS"},
"counterexample":	{"NN"},
"counterfactual":	{"JJ","NN"},
"counterfactuality":	{"NN"},
"counterfeit":	{"NN","VB","VBP","JJ"},
"counterfeited":	{"VBD","VBN"},
"counterfeiter":	{"NN"},
"counterfeiters":	{"NNS"},
"counterfeiting":	{"VBG","NN"},
"counterfeits":	{"VBZ"},
"counterfire":	{"NN"},
"counterflow":	{"NN"},
"counterfoil":	{"NN"},
"counterfoils":	{"NNS"},
"counterforce":	{"NN"},
"counterglow":	{"NN"},
"counterguarantee":	{"NN"},
"countering":	{"VBG"},
"counterinsurgency":	{"NN"},
"counterinsurgent":	{"JJ"},
"counterintelligence":	{"NN"},
"counterintuitive":	{"JJ","NN"},
"counterintuitively":	{"RB"},
"counterirritant":	{"NN"},
"counterman":	{"NN"},
"countermand":	{"VB","VBP"},
"countermanded":	{"VBD","VBN"},
"countermanding":	{"VBG"},
"countermands":	{"VBZ"},
"countermarch":	{"NN","VB","VBP"},
"countermarched":	{"VBD","VBN"},
"countermarches":	{"NNS","VBZ"},
"countermarching":	{"VBG"},
"countermeasure":	{"NN"},
"countermeasures":	{"NNS"},
"countermine":	{"NN","VB","VBP"},
"countermined":	{"VBD","VBN"},
"countermines":	{"NNS","VBZ"},
"countermining":	{"VBG"},
"countermove":	{"NN","VB","VBP"},
"countermoved":	{"VBD","VBN"},
"countermoves":	{"VBZ"},
"countermoving":	{"VBG"},
"counternarrative":	{"NN"},
"counternarratives":	{"NNS"},
"counteroffensive":	{"NN"},
"counteroffer":	{"NN"},
"counterpane":	{"NN"},
"counterpanes":	{"NNS"},
"counterpart":	{"NN"},
"counterparts":	{"NNS"},
"counterperson":	{"NN"},
"counterplan":	{"NN"},
"counterplay":	{"NN"},
"counterplea":	{"NN"},
"counterplot":	{"NN","VB","VBP"},
"counterplots":	{"NNS","VBZ"},
"counterplotted":	{"VBD","VBN"},
"counterplotting":	{"VBG"},
"counterpoint":	{"NN"},
"counterpointed":	{"VBD","VBN"},
"counterpointing":	{"VBG"},
"counterpoints":	{"NNS","VBZ"},
"counterpoise":	{"NN","VB","VBP"},
"counterpoised":	{"VBD","VBN"},
"counterpoises":	{"VBZ"},
"counterpoising":	{"VBG"},
"counterpoison":	{"NN"},
"counterpose":	{"VB","VBP"},
"counterposed":	{"VBD","VBN"},
"counterposes":	{"VBZ"},
"counterposing":	{"VBG"},
"counterproductive":	{"JJ"},
"counterprogram":	{"VB","VBP"},
"counterprogrammed":	{"VBD","VBN"},
"counterprogramming":	{"NN","VBG"},
"counterprograms":	{"VBZ"},
"counterproliferation":	{"NN"},
"counterproposal":	{"NN"},
"counterproposals":	{"NNS"},
"counterpunch":	{"NN","VB","VBP"},
"counterpunched":	{"VBD","VBN"},
"counterpuncher":	{"NN"},
"counterpunchers":	{"NNS"},
"counterpunches":	{"NNS","VBZ"},
"counterpunching":	{"VBG"},
"counterreformation":	{"NN"},
"counterrevolution":	{"NN"},
"counterrevolutionaries":	{"NNS"},
"counterrevolutionary":	{"JJ"},
"counterrevolutionist":	{"NN"},
"counters":	{"NNS","VBZ"},
"countersank":	{"VBD"},
"countershot":	{"NN"},
"countersign":	{"VB","VBP"},
"countersignature":	{"NN"},
"countersigned":	{"VBD","VBN"},
"countersigning":	{"VBG"},
"countersigns":	{"VBZ"},
"countersink":	{"VB","VBP"},
"countersinking":	{"VBG"},
"countersinks":	{"VBZ"},
"counterspy":	{"NN"},
"counterstain":	{"NN"},
"counterstrike":	{"NN","VB","VBP"},
"counterstriked":	{"VBD","VBN"},
"counterstrikes":	{"NNS","VBZ"},
"counterstriking":	{"VBG"},
"countersubversion":	{"NN"},
"countersued":	{"VBD","VBN"},
"countersuing":	{"VBG"},
"countersuit":	{"NN"},
"countersunk":	{"VBN"},
"countertenor":	{"NN"},
"countertenors":	{"NNS"},
"counterterror":	{"NN"},
"counterterrorism":	{"NN"},
"counterterrorist":	{"JJ"},
"countertop":	{"NN"},
"countertops":	{"NNS"},
"countertransference":	{"NN"},
"countervail":	{"VB","VBP"},
"countervailed":	{"VBD","VBN"},
"countervailing":	{"VBG","JJ"},
"countervails":	{"VBZ"},
"counterweight":	{"NN"},
"counterweights":	{"NNS"},
"counterwoman":	{"NN"},
"countess":	{"NN"},
"countian":	{"NN"},
"counties":	{"NNS"},
"counting":	{"VBG","NN"},
"countinghouse":	{"NN"},
"countless":	{"JJ"},
"countlessness":	{"NN"},
"countries":	{"NNS"},
"countrified":	{"JJ"},
"countriman":	{"NN"},
"country":	{"NN","JJ"},
"country-and-Western":	{"JJ"},
"country-and-western":	{"JJ"},
"country-bred":	{"JJ"},
"country-club":	{"NN"},
"country-dance":	{"NN","VB"},
"country-development":	{"NN"},
"country-life":	{"JJ"},
"country-squirehood":	{"NN"},
"country-style":	{"JJ"},
"countryfied":	{"JJ"},
"countryfolk":	{"NN"},
"countryman":	{"NN"},
"countrymen":	{"NNS"},
"countrypolitan":	{"NN","JJ"},
"countryseat":	{"NN"},
"countryside":	{"NN"},
"countrysides":	{"NNS"},
"countrywide":	{"JJ","RB"},
"countrywoman":	{"NN"},
"countrywomen":	{"NNS"},
"counts":	{"NNS","VBZ"},
"county":	{"NN"},
"county-wide":	{"JJ"},
"countywide":	{"JJ","NN"},
"coup":	{"NN","FW"},
"coup-makers":	{"NNS"},
"coup-planning":	{"NN"},
"coup-proof":	{"JJ"},
"coupe":	{"NN"},
"couperin":	{"NN"},
"coupes":	{"NNS"},
"couple":	{"NN","VB","VBP"},
"coupled":	{"VBN","VBD"},
"coupler":	{"NN"},
"couplers":	{"NNS"},
"couples":	{"NNS","VBZ"},
"couplet":	{"NN"},
"couplets":	{"NNS"},
"coupling":	{"NN","VBG"},
"coupon":	{"NN"},
"coupon-distribution":	{"JJ"},
"coupon-equivalent":	{"JJ"},
"couponing":	{"NN","VBG","NN","VBG"},
"coupons":	{"NNS"},
"coups":	{"NNS"},
"courage":	{"NN"},
"courageous":	{"JJ","NN"},
"courageously":	{"RB"},
"courageousness":	{"NN"},
"courant":	{"NN"},
"courante":	{"NN"},
"courbaril":	{"NN"},
"courbet":	{"NN"},
"coureurs":	{"FW"},
"courgette":	{"NN"},
"courier":	{"NN","VB","VBP"},
"couriered":	{"VBD","VBN"},
"couriering":	{"VBG"},
"couriers":	{"NNS","VBZ"},
"courlan":	{"NN"},
"course":	{"NN","VBP","VB"},
"course-correction":	{"NN"},
"coursed":	{"VBD","VBN"},
"courser":	{"NN"},
"courses":	{"NNS","VBZ"},
"coursework":	{"NN"},
"coursing":	{"VBG","NN"},
"court":	{"NN","VBP","VB"},
"court-appointed":	{"JJ"},
"court-approved":	{"JJ"},
"court-awarded":	{"JJ"},
"court-length":	{"JJ"},
"court-martial":	{"NN","VB","VBP"},
"court-martialed":	{"VBD","VBN"},
"court-martialing":	{"VBG"},
"court-martialled":	{"VBD","VBN"},
"court-martialling":	{"VBG"},
"court-martials":	{"NNS","VBZ"},
"court-ordered":	{"JJ"},
"court-packing":	{"JJ"},
"court-reporting":	{"JJ"},
"court-supervised":	{"JJ"},
"courted":	{"VBD","VBN"},
"courtelle":	{"NN"},
"courteous":	{"JJ","NN"},
"courteously":	{"RB"},
"courtesan":	{"NN"},
"courtesies":	{"NNS"},
"courtesy":	{"NN","JJ"},
"courthouse":	{"NN"},
"courthouses":	{"NNS"},
"courtier":	{"NN"},
"courtiers":	{"NNS"},
"courting":	{"NN","VBG"},
"courtlier":	{"JJR","RBR"},
"courtliest":	{"JJS","RBR"},
"courtliness":	{"NN"},
"courtly":	{"JJ","RB"},
"courtroom":	{"NN"},
"courtrooms":	{"NNS"},
"courts":	{"NNS","VBZ"},
"courts-martial":	{"NNS"},
"courtship":	{"NN"},
"courtside":	{"NN","IN","JJ","VBN","RB"},
"courtyard":	{"NN"},
"courtyards":	{"NNS"},
"couscous":	{"NN","JJ"},
"cousin":	{"NN"},
"cousin-german":	{"NN"},
"cousin-wife":	{"NN"},
"cousinly":	{"RB"},
"cousins":	{"NNS"},
"cousteau":	{"NN"},
"couth":	{"NN"},
"couthie":	{"JJ"},
"couthy":	{"JJ"},
"couture":	{"NN"},
"couturier":	{"NN"},
"couvade":	{"NN"},
"couverture":	{"NN"},
"covalence":	{"NN"},
"covalency":	{"NN"},
"covalent":	{"JJ"},
"covariance":	{"NN"},
"covariant":	{"JJ"},
"covariates":	{"NNS"},
"covariation":	{"NN"},
"cove":	{"NN"},
"coved":	{"VBD","VBN"},
"coven":	{"NN"},
"covenant":	{"NN","VB","VBP"},
"covenanted":	{"VBD","VBN"},
"covenanting":	{"VBG"},
"covenants":	{"NNS","VBZ"},
"covent":	{"NN"},
"cover":	{"VB","NN","VBP"},
"cover-up":	{"NN","JJ"},
"coverage":	{"NN"},
"coverages":	{"NNS"},
"coverall":	{"NN"},
"covered":	{"VBN","VBD","JJ"},
"covering":	{"VBG","NN"},
"coverings":	{"NNS"},
"coverlet":	{"NN"},
"covers":	{"VBZ","NNS"},
"covert":	{"JJ","NN"},
"covert-operations":	{"NNS"},
"covertly":	{"RB"},
"covertness":	{"NN"},
"coverts":	{"NNS"},
"coverup":	{"NN","JJ"},
"coves":	{"NNS","VBZ"},
"covet":	{"VB","VBP"},
"coveted":	{"VBD","VBN","JJ"},
"coveting":	{"VBG"},
"covetous":	{"JJ"},
"covetously":	{"RB"},
"covetousness":	{"NN"},
"covets":	{"VBZ"},
"covey":	{"NN"},
"coville":	{"NN"},
"coving":	{"VBG"},
"cow":	{"NN","VB","VBP"},
"cow-blood":	{"NN"},
"cow-man":	{"NN"},
"cow-pat":	{"NN"},
"cow-people":	{"NN"},
"cowage":	{"NN"},
"cowan":	{"NN"},
"coward":	{"NN"},
"cowardice":	{"NN"},
"cowardliness":	{"NN"},
"cowardly":	{"JJ"},
"cowards":	{"NNS"},
"cowbarn":	{"NN"},
"cowbell":	{"NN"},
"cowbells":	{"NNS"},
"cowberry":	{"NN"},
"cowbird":	{"NN"},
"cowbirds":	{"NNS"},
"cowboy":	{"NN"},
"cowboys":	{"NNS"},
"cowboys-owned":	{"JJ"},
"cowcatcher":	{"NN"},
"cowcatchers":	{"NNS"},
"cowed":	{"VBN","VBD","JJ"},
"cower":	{"VB","VBP"},
"cowered":	{"VBD","VBN"},
"cowering":	{"VBG"},
"cowers":	{"VBZ"},
"cowfish":	{"NN"},
"cowgirl":	{"NN"},
"cowgirls":	{"NNS"},
"cowhand":	{"NN"},
"cowhands":	{"NNS"},
"cowherb":	{"NN"},
"cowherd":	{"NN"},
"cowhide":	{"NN","VB","VBP"},
"cowhided":	{"VBD","VBN"},
"cowhides":	{"NNS","VBZ"},
"cowhiding":	{"VBG"},
"cowhouse":	{"NN"},
"cowing":	{"VBG"},
"cowl":	{"NN","VB","VBP"},
"cowl-shaped":	{"JJ"},
"cowled":	{"VBD","VBN"},
"cowlick":	{"NN"},
"cowling":	{"NN","VBG"},
"cowls":	{"NNS","VBZ"},
"cowman":	{"NN"},
"coworker":	{"NN"},
"coworkers":	{"NNS"},
"cowpea":	{"NN"},
"cowpens":	{"NNS"},
"cowper":	{"NN"},
"cowpie":	{"NN"},
"cowpoke":	{"NN"},
"cowpony":	{"NN"},
"cowpox":	{"NN"},
"cowpuncher":	{"NN"},
"cowrie":	{"NN"},
"cowries":	{"NNS"},
"cowrtiers":	{"NNS"},
"cowry":	{"NN"},
"cows":	{"NNS","VBZ"},
"cowshed":	{"NN"},
"cowsheds":	{"NNS"},
"cowskin":	{"NN"},
"cowslip":	{"NN"},
"cowslips":	{"NNS"},
"cowtown":	{"NN"},
"cox":	{"NN","VB","VBP"},
"cox-1":	{"NN"},
"cox-2":	{"NN"},
"coxa":	{"NN"},
"coxcomb":	{"NN"},
"coxcombs":	{"NNS"},
"coxed":	{"VBD","VBN"},
"coxes":	{"NNS","VBZ"},
"coxing":	{"VBG"},
"coxsackievirus":	{"NN"},
"coxswain":	{"NN"},
"coxswains":	{"NNS"},
"coy":	{"JJ"},
"coydog":	{"NN"},
"coyly":	{"RB"},
"coyness":	{"NN"},
"coyol":	{"NN"},
"coyote":	{"NN"},
"coyotes":	{"NNS"},
"coypu":	{"NN"},
"coze":	{"NN","VB"},
"cozen":	{"VB","VBP"},
"cozenage":	{"NN"},
"cozened":	{"VBD","VBN"},
"cozening":	{"VBG"},
"cozens":	{"VBZ"},
"cozied":	{"VBD","VBN"},
"cozier":	{"JJR"},
"cozies":	{"NNS","VBZ"},
"coziest":	{"JJS"},
"cozily":	{"RB"},
"coziness":	{"NN"},
"cozy":	{"JJ","VB","VBP","NN"},
"cozying":	{"VBG"},
"cpa":	{"NN"},
"cpi":	{"NN"},
"cpr":	{"NN"},
"cps":	{"NN"},
"cpt":	{"NN"},
"cpts":	{"NNS"},
"cpu":	{"NN"},
"cr":	{"NN"},
"crab":	{"NN","VB","VBP"},
"crab-louse":	{"NN"},
"crabapple":	{"NN"},
"crabbed":	{"JJ","VBD","VBN"},
"crabbedness":	{"NN"},
"crabbier":	{"JJR"},
"crabbiest":	{"JJS"},
"crabbiness":	{"NN"},
"crabbing":	{"VBG"},
"crabby":	{"JJ"},
"crabgrass":	{"NN"},
"crabmeat":	{"NN"},
"crabs":	{"NNS","VBZ"},
"crabwise":	{"RB"},
"cracidae":	{"NN"},
"crack":	{"NN","VB","VBP","JJ"},
"crack-addicted":	{"JJ"},
"crack-cocaine":	{"NN"},
"crack-induced":	{"JJ"},
"crack-ridden":	{"JJ"},
"crack-up":	{"NN","JJ"},
"crack-user":	{"NN"},
"crack-using":	{"JJ"},
"crackbrained":	{"JJ"},
"crackdown":	{"NN"},
"crackdowns":	{"NNS"},
"cracked":	{"VBD","VBN","JJ"},
"cracker":	{"NN"},
"cracker-barrel":	{"JJ"},
"cracker-box":	{"JJ"},
"crackerberry":	{"NN"},
"crackerjack":	{"NN"},
"crackers":	{"NNS","JJ"},
"cracking":	{"JJ","NN","RB","VBG"},
"crackle":	{"VB","VBP","NN"},
"crackle-ware":	{"NN"},
"crackled":	{"VBD","VBN"},
"crackles":	{"VBZ","NNS"},
"crackleware":	{"NN"},
"crackling":	{"NN","VBG"},
"cracklings":	{"NNS"},
"crackly":	{"JJ"},
"crackpot":	{"NN","JJ"},
"crackpots":	{"NNS"},
"cracks":	{"VBZ","NNS"},
"cracksman":	{"NN"},
"cracow":	{"NN"},
"cracticidae":	{"NN"},
"cracticus":	{"NN"},
"cradle":	{"NN","VB","VBP"},
"cradle-to-grave":	{"JJ"},
"cradled":	{"VBD","VBN"},
"cradles":	{"NNS","VBZ"},
"cradlesong":	{"NN"},
"cradling":	{"VBG"},
"craft":	{"NN","VB","VBP","NNS"},
"craft-industrial":	{"JJ"},
"crafted":	{"VBD","VBN"},
"crafter":	{"VB","NN"},
"craftier":	{"JJR"},
"craftiest":	{"JJS"},
"craftily":	{"RB"},
"craftiness":	{"NN"},
"crafting":	{"VBG"},
"crafts":	{"VBZ","NNS"},
"craftsman":	{"NN"},
"craftsman-in-residence":	{"JJ"},
"craftsmanship":	{"NN"},
"craftsmen":	{"NNS"},
"crafty":	{"JJ"},
"crag":	{"NN"},
"cragfast":	{"JJ"},
"cragged":	{"JJ"},
"craggy":	{"JJ","NN"},
"crags":	{"NNS"},
"cragsman":	{"NN"},
"craigie":	{"NN"},
"crake":	{"NN"},
"cram":	{"VB","VBP"},
"crambe":	{"NN"},
"crammed":	{"VBN","VBD","JJ"},
"crammer":	{"NN"},
"crammers":	{"NNS"},
"cramming":	{"VBG"},
"cramp":	{"NN","VB","VBP"},
"crampbark":	{"NN"},
"cramped":	{"JJ","VBN","VBD"},
"crampfish":	{"NN"},
"cramping":	{"VBG"},
"crampon":	{"NN"},
"crampons":	{"NNS"},
"crampoon":	{"NN"},
"cramps":	{"NNS","VBZ"},
"crams":	{"VBZ"},
"cran":	{"NN"},
"cranberries":	{"NNS"},
"cranberry":	{"NN"},
"cranberry-and-gray":	{"JJ"},
"cranch":	{"VB"},
"crane":	{"NN","VB","VBP"},
"crane-safety":	{"NN"},
"craned":	{"VBD","VBN"},
"cranelike":	{"JJ"},
"cranes":	{"NNS","VBZ"},
"cranesbill":	{"NN"},
"crangon":	{"NN"},
"crangonidae":	{"NN"},
"crania":	{"NNS"},
"cranial":	{"JJ"},
"craniata":	{"NN"},
"craniate":	{"JJ"},
"craning":	{"VBG"},
"craniologist":	{"NN"},
"craniology":	{"NN"},
"craniometer":	{"NN"},
"craniometric":	{"JJ"},
"craniometrical":	{"JJ"},
"craniometry":	{"NN"},
"craniotomy":	{"NN"},
"cranium":	{"NN"},
"craniums":	{"NNS"},
"crank":	{"NN","VB","VBP"},
"crankcase":	{"NN"},
"cranked":	{"VBD","VBN"},
"crankier":	{"JJR"},
"crankiest":	{"JJS"},
"crankiness":	{"NN"},
"cranking":	{"VBG"},
"cranks":	{"NNS","VBZ"},
"crankshaft":	{"NN"},
"crankshafts":	{"NNS"},
"cranky":	{"JJ"},
"crannied":	{"JJ"},
"crannies":	{"NNS"},
"cranny":	{"NN"},
"crap":	{"NN","VB","VBP","JJ"},
"crap-shooter":	{"NN"},
"crapaud":	{"NN"},
"crape":	{"NN","VB","VBP"},
"craped":	{"VBD","VBN"},
"crapes":	{"VBZ"},
"crapette":	{"NN"},
"craping":	{"VBG"},
"crapped":	{"VBD","VBN"},
"crapper":	{"NN"},
"crappie":	{"NN"},
"crappier":	{"JJR"},
"crappiest":	{"JJS"},
"crapping":	{"VBG"},
"crappy":	{"JJ"},
"craps":	{"NNS","VBZ"},
"crapshoot":	{"NN"},
"crapshooter":	{"NN"},
"craptacular":	{"JJ"},
"crapulence":	{"NN"},
"crapulent":	{"JJ"},
"crapulous":	{"JJ"},
"crash":	{"NN","JJ","RB","VB","VBP"},
"crash-dive":	{"NN","VB","VBP"},
"crash-dived":	{"VBD","VBN"},
"crash-dives":	{"NNS","VBZ"},
"crash-diving":	{"VBG"},
"crash-land":	{"VB","VBP"},
"crash-landed":	{"VBD","VBN"},
"crash-landing":	{"VBG","NN"},
"crash-lands":	{"VBZ"},
"crash-scarred":	{"JJ"},
"crash-wary":	{"JJ"},
"crashed":	{"VBD","VBN"},
"crasher":	{"NN"},
"crashes":	{"NNS","VBZ"},
"crashing":	{"VBG"},
"crashlet":	{"NN"},
"craspedia":	{"NN"},
"crass":	{"JJ"},
"crasser":	{"JJR"},
"crassest":	{"JJS"},
"crassitude":	{"NN"},
"crassness":	{"NN"},
"crassostrea":	{"NN"},
"crassula":	{"NN"},
"crassulaceae":	{"NN"},
"crataegus":	{"NN"},
"crate":	{"NN","VBP","VB"},
"crated":	{"VBD","VBN"},
"crateful":	{"NN"},
"crater":	{"NN","VB","VBP"},
"cratered":	{"VBN","VBD","JJ"},
"cratering":	{"VBG"},
"craters":	{"NNS","VBZ"},
"crates":	{"NNS","VBZ"},
"crateva":	{"NN"},
"crating":	{"VBG"},
"craton":	{"NN"},
"craunch":	{"VB"},
"cravat":	{"NN"},
"cravats":	{"NNS"},
"crave":	{"VB","VBP"},
"craved":	{"VBD","VBN"},
"craven":	{"JJ"},
"cravenly":	{"RB"},
"cravenness":	{"NN"},
"craves":	{"VBZ"},
"craving":	{"NN","VBG"},
"cravings":	{"NNS"},
"craw":	{"NN"},
"crawdad":	{"NN"},
"crawdaddy":	{"NN"},
"crawfish":	{"NN","NNS"},
"crawford":	{"NN"},
"crawl":	{"VB","VBP","NN"},
"crawled":	{"VBD","VBN"},
"crawler":	{"NN"},
"crawlers":	{"NNS"},
"crawling":	{"NN","VBG"},
"crawls":	{"VBZ","NNS"},
"crawlspace":	{"NN"},
"crax":	{"NN"},
"crayfish":	{"NN","NNS"},
"crayon":	{"NN","VB","VBP"},
"crayoned":	{"VBD","VBN"},
"crayoning":	{"VBG"},
"crayons":	{"NNS","VBZ"},
"craze":	{"NN"},
"crazed":	{"JJ","VBD","VBN"},
"crazee":	{"JJ"},
"crazes":	{"NNS","VBZ"},
"crazies":	{"NNS"},
"crazily":	{"RB"},
"craziness":	{"NN"},
"crazing":	{"VBG"},
"crazy":	{"JJ","NN"},
"crazy-wonderful":	{"JJ"},
"crazyweed":	{"NN"},
"creak":	{"VB","VBP","NN"},
"creaked":	{"VBD","VBN"},
"creakier":	{"JJR"},
"creakiest":	{"JJS"},
"creakily":	{"RB"},
"creakiness":	{"NN"},
"creaking":	{"VBG"},
"creakingly":	{"RB"},
"creaks":	{"VBZ","NNS"},
"creaky":	{"JJ"},
"cream":	{"NN","VB","VBP"},
"cream-colored":	{"JJ"},
"cream-of-the-crop":	{"NN"},
"creamcups":	{"NNS"},
"creamed":	{"VBD","VBN"},
"creamer":	{"NN"},
"creamerier":	{"NNS"},
"creamers":	{"NNS"},
"creamery":	{"NN"},
"creamier":	{"JJR"},
"creamiest":	{"JJS"},
"creaminess":	{"NN"},
"creaming":	{"VBG"},
"creams":	{"NNS","VBZ"},
"creamy":	{"JJ"},
"creamy-colored":	{"JJ"},
"creamy-white":	{"JJ"},
"creamy-yellow":	{"JJ"},
"crease":	{"NN","VB","VBP"},
"crease-resistant":	{"JJ"},
"creased":	{"VBN","VBD","JJ"},
"creaseless":	{"JJ"},
"creaseproof":	{"JJ"},
"creases":	{"NNS","VBZ"},
"creashak":	{"NN"},
"creasing":	{"VBG"},
"creasingly":	{"RB"},
"create":	{"VB","VBP"},
"created":	{"VBN","VBD"},
"creates":	{"VBZ"},
"creatine":	{"NN"},
"creating":	{"VBG"},
"creation":	{"NN"},
"creationism":	{"NN"},
"creationist":	{"NN","JJ"},
"creationists":	{"NNS"},
"creations":	{"NNS"},
"creative":	{"JJ","NN"},
"creatively":	{"RB"},
"creativeness":	{"NN"},
"creativity":	{"NN"},
"creativity-oriented":	{"JJ"},
"creator":	{"NN"},
"creators":	{"NNS"},
"creature":	{"NN"},
"creatures":	{"NNS"},
"creche":	{"NN"},
"crecy":	{"NN"},
"cred":	{"NN"},
"credal":	{"JJ"},
"credence":	{"NN"},
"credendum":	{"NN"},
"credential":	{"NN","JJ","VB","VBP"},
"credentialed":	{"JJ","VBD","VBN"},
"credentialing":	{"VBG","NN"},
"credentialism":	{"NN"},
"credentialized":	{"JJ"},
"credentialled":	{"JJ","VBD","VBN"},
"credentialling":	{"VBG","NN"},
"credentials":	{"NNS","VBZ"},
"credenza":	{"NN"},
"credibility":	{"NN"},
"credible":	{"JJ"},
"credibleness":	{"NN"},
"credibly":	{"RB"},
"credit":	{"NN","VB","VBP"},
"credit-backing":	{"NN"},
"credit-card":	{"NN","JJ"},
"credit-data":	{"NN","NNS"},
"credit-discrimination":	{"NN"},
"credit-easing":	{"JJ","NN"},
"credit-enhancement":	{"NN"},
"credit-financed":	{"JJ"},
"credit-information":	{"NN"},
"credit-line":	{"NN"},
"credit-market":	{"JJ"},
"credit-policy":	{"NN"},
"credit-quality":	{"JJ"},
"credit-rating":	{"NN"},
"credit-ratings":	{"NNS"},
"credit-reporting":	{"JJ","NN"},
"credit-services":	{"NNS"},
"credit-side":	{"NN"},
"credit-softening":	{"NN"},
"credit-tightening":	{"NN"},
"credit-worthiness":	{"NN"},
"credit-worthy":	{"JJ"},
"creditable":	{"JJ"},
"creditably":	{"RB"},
"creditcard":	{"NN"},
"credited":	{"VBN","VBD"},
"crediting":	{"VBG"},
"creditor":	{"NN"},
"creditors":	{"NNS"},
"credits":	{"NNS","VBZ"},
"creditworthiness":	{"NN"},
"creditworthy":	{"JJ"},
"credo":	{"NN"},
"creds":	{"NNS"},
"credulity":	{"NN"},
"credulous":	{"JJ"},
"credulously":	{"RB"},
"credulousness":	{"NN"},
"creed":	{"NN"},
"creedal":	{"JJ"},
"creeds":	{"NNS"},
"creek":	{"NN"},
"creek-filled":	{"JJ"},
"creek-turn":	{"JJ"},
"creeks":	{"NNS"},
"creel":	{"NN"},
"creep":	{"VB","VBP","NN"},
"creeper":	{"NN"},
"creepers":	{"NNS"},
"creepier":	{"JJR"},
"creepiest":	{"JJS"},
"creepiness":	{"NN"},
"creeping":	{"NN","JJ","VBG"},
"creeps":	{"VBZ","NNS"},
"creepy":	{"JJ"},
"creepy-crawlies":	{"NNS"},
"creepy-crawly":	{"NN"},
"creese":	{"NN"},
"cremains":	{"NNS"},
"cremate":	{"VB","VBP"},
"cremated":	{"VBD","VBN"},
"cremates":	{"VBZ"},
"cremating":	{"VBG"},
"cremation":	{"NN"},
"cremations":	{"NNS"},
"crematoria":	{"NNS"},
"crematories":	{"NNS"},
"crematorium":	{"NN"},
"crematoriums":	{"NNS"},
"crematory":	{"NN"},
"creme":	{"FW"},
"cremini":	{"NN"},
"creminis":	{"NNS"},
"cremona":	{"NN"},
"crenate":	{"JJ"},
"crenated":	{"JJ"},
"crenation":	{"NN"},
"crenature":	{"NN"},
"crenel":	{"NN","VB"},
"crenelate":	{"VB"},
"crenelation":	{"NN"},
"crenellate":	{"VB"},
"crenellation":	{"NN"},
"crenelle":	{"NN"},
"crenulate":	{"JJ"},
"crenulated":	{"JJ"},
"creole":	{"NN","JJ"},
"creole-fish":	{"NN"},
"creoles":	{"NNS"},
"creolization":	{"NN"},
"creolize":	{"VB","VBP"},
"creolized":	{"VBD","VBN"},
"creolizes":	{"VBZ"},
"creolizing":	{"VBG"},
"creon":	{"NN"},
"creosol":	{"NN"},
"creosote":	{"NN","VB","VBP"},
"creosoted":	{"VBD","VBN"},
"creosotes":	{"VBZ"},
"creosoting":	{"VBG"},
"crepe":	{"NN"},
"crepis":	{"NN"},
"crepitate":	{"VB","VBP"},
"crepitated":	{"VBD","VBN"},
"crepitates":	{"VBZ"},
"crepitating":	{"VBG"},
"crepitation":	{"NN"},
"crept":	{"VBD","VBN"},
"crepuscle":	{"NN"},
"crepuscular":	{"JJ"},
"crepuscule":	{"NN"},
"crescendo":	{"NN"},
"crescendoed":	{"VBD","VBN"},
"crescendoes":	{"VBZ"},
"crescendoing":	{"VBG"},
"crescent":	{"NN"},
"crescent-shaped":	{"JJ"},
"crescentia":	{"NN"},
"cresol":	{"NN"},
"cress":	{"NN"},
"cresson":	{"JJ"},
"crest":	{"NN","VB","VBP"},
"crest-colgate":	{"JJ"},
"crested":	{"JJ","VBD","VBN"},
"crestfallen":	{"JJ"},
"cresting":	{"VBG"},
"crests":	{"NNS","VBZ"},
"cretaceous":	{"JJ","NN"},
"crete":	{"NN"},
"cretin":	{"NN"},
"cretinism":	{"NN"},
"cretinous":	{"JJ"},
"cretonne":	{"NN"},
"crevasse":	{"NN"},
"crevassed":	{"VBD","VBN"},
"crevasses":	{"NNS","VBZ"},
"crevassing":	{"VBG"},
"crevice":	{"NN"},
"crevices":	{"NNS"},
"crew":	{"NN","VBP","VB","VBD"},
"crew-pairing":	{"JJ"},
"crew-rest":	{"NN"},
"crewcut":	{"NN"},
"crewed":	{"VBD","VBN"},
"crewel":	{"NN"},
"crewelwork":	{"NN"},
"crewet":	{"NN"},
"crewing":	{"VBG"},
"crewman":	{"NN"},
"crewmen":	{"NNS"},
"crewneck":	{"NN"},
"crewnecks":	{"NNS"},
"crews":	{"NNS","VBZ"},
"crex":	{"NN"},
"crib":	{"NN","VB","VBP"},
"cribbage":	{"NN"},
"cribbed":	{"VBD","VBN"},
"cribbing":	{"VBG"},
"cribs":	{"NNS","VBZ"},
"cricetidae":	{"NN"},
"cricetus":	{"NNS"},
"crichton":	{"NN"},
"crick":	{"NN","VBP","VB"},
"cricked":	{"VBD","VBN"},
"cricket":	{"NN","VB","VBP"},
"cricketed":	{"VBD","VBN"},
"cricketer":	{"NN"},
"cricketers":	{"NNS"},
"cricketing":	{"VBG","JJ"},
"crickets":	{"NNS","VBZ"},
"cricking":	{"VBG"},
"cricks":	{"NNS","VBZ"},
"cried":	{"VBD","VBN"},
"crier":	{"NN"},
"cries":	{"NNS","VBZ"},
"crime":	{"NN"},
"crime-busting":	{"JJ"},
"crime-fighting":	{"JJ"},
"crime-infested":	{"JJ"},
"crime-ridden":	{"JJ"},
"crimea":	{"NN"},
"crimes":	{"NNS"},
"criminal":	{"JJ","NN"},
"criminal-abortion":	{"JJ"},
"criminal-defense":	{"JJ","NN"},
"criminal-justice":	{"NN"},
"criminal-law":	{"NN"},
"criminalisation":	{"NN"},
"criminalise":	{"VB","VBP"},
"criminalised":	{"VBD","VBN"},
"criminalises":	{"VBZ"},
"criminalising":	{"VBG"},
"criminalism":	{"NN"},
"criminality":	{"NN"},
"criminalization":	{"NN"},
"criminalize":	{"VB","VBP"},
"criminalized":	{"VBD","VBN"},
"criminalizes":	{"VBZ"},
"criminalizing":	{"VBG"},
"criminally":	{"RB"},
"criminalness":	{"NN"},
"criminals":	{"NNS"},
"criminate":	{"VB"},
"criminative":	{"JJ"},
"criminatory":	{"JJ"},
"crimini":	{"NN"},
"criminis":	{"NNS"},
"criminological":	{"JJ"},
"criminologist":	{"NN"},
"criminologists":	{"NNS"},
"criminology":	{"NN"},
"crimp":	{"VB","VBP"},
"crimped":	{"VBN","VBD"},
"crimper":	{"NN"},
"crimping":	{"VBG"},
"crimps":	{"VBZ"},
"crimson":	{"NN","JJ","VBP","VB"},
"crimson-magenta":	{"JJ"},
"crimson-purple":	{"JJ"},
"crimson-yellow":	{"JJ"},
"crimsoned":	{"VBD","VBN"},
"crimsoning":	{"VBG"},
"crimsons":	{"VBZ"},
"cringe":	{"VB","VBP"},
"cringed":	{"VBD","VBN"},
"cringes":	{"VBZ"},
"cringing":	{"VBG"},
"cringle":	{"NN"},
"crinion":	{"NN"},
"crinkle":	{"NN","VB","VBP"},
"crinkle-root":	{"NN"},
"crinkled":	{"VBD","VBN","JJ"},
"crinkleroot":	{"NN"},
"crinkles":	{"NNS","VBZ"},
"crinklier":	{"JJR"},
"crinkliest":	{"JJS"},
"crinkling":	{"VBG"},
"crinkly":	{"JJ"},
"crinoid":	{"NN","JJ"},
"crinoidea":	{"NN"},
"crinoline":	{"NN"},
"criollo":	{"NN"},
"cripple":	{"NN","VB","VBP"},
"cripple-maker":	{"NN"},
"crippled":	{"JJ","VBD","VBN"},
"cripples":	{"VBZ","NNS"},
"crippling":	{"JJ","VBG"},
"cripplingly":	{"RB"},
"crises":	{"NNS"},
"crisis":	{"NN"},
"crisis-management":	{"JJ","NN"},
"crisis-oriented":	{"JJ"},
"crisis-response":	{"JJ"},
"crisis-to-crisis":	{"JJ"},
"crisp":	{"JJ","NN","VB","VBP"},
"crispate":	{"JJ"},
"crisped":	{"VBD","VBN"},
"crispen":	{"VB","VBP"},
"crispened":	{"VBD","VBN"},
"crispening":	{"VBG"},
"crispens":	{"VBZ"},
"crisper":	{"JJR"},
"crispest":	{"JJS"},
"crispier":	{"JJR"},
"crispiest":	{"JJS"},
"crispiness":	{"NN"},
"crisping":	{"VBG"},
"crisply":	{"RB"},
"crispness":	{"NN"},
"crisps":	{"NNS","VBZ"},
"crispy":	{"JJ"},
"criss-cross":	{"VBP","JJ","VB"},
"criss-crossed":	{"VBD","VBN"},
"criss-crosses":	{"VBZ"},
"criss-crossing":	{"VBG"},
"crisscross":	{"VB","VBP","NN","JJ","RB"},
"crisscrossed":	{"VBD","VBN"},
"crisscrosses":	{"VBZ"},
"crisscrossing":	{"VBG"},
"cristal":	{"NN"},
"cristata":	{"FW"},
"cristobalite":	{"NN"},
"critcism":	{"NN"},
"criteria":	{"NNS"},
"criterial":	{"JJ"},
"criterion":	{"NN"},
"criterional":	{"JJ"},
"crith":	{"NN"},
"critic":	{"NN"},
"critical":	{"JJ"},
"critical-intellectual":	{"JJ"},
"criticality":	{"NN"},
"critically":	{"RB"},
"criticalness":	{"NN"},
"criticise":	{"VB","VBP"},
"criticised":	{"VBD","VBN"},
"criticises":	{"VBZ"},
"criticising":	{"VBG"},
"criticism":	{"NN"},
"criticisms":	{"NNS"},
"criticize":	{"VB","VBP"},
"criticized":	{"VBN","VBD"},
"criticizes":	{"VBZ"},
"criticizing":	{"VBG"},
"critics":	{"NNS"},
"critique":	{"NN","VB","VBP"},
"critiqued":	{"VBD","VBN"},
"critiques":	{"NNS","VBZ"},
"critiquing":	{"VBG"},
"critter":	{"NN"},
"critters":	{"NNS"},
"crius":	{"NN"},
"crixivan":	{"NN"},
"cro":	{"NN"},
"cro-magnon":	{"NN"},
"croak":	{"VB","VBP","NN"},
"croaked":	{"VBD","VBN"},
"croaker":	{"NN"},
"croaking":	{"VBG"},
"croaks":	{"VBZ","NNS"},
"croaky":	{"JJ"},
"croat":	{"NN"},
"croatia":	{"NN"},
"crocethia":	{"NN"},
"crochet":	{"NN","VB","VBP"},
"crocheted":	{"VBD","VBN"},
"crocheting":	{"NN","VBG"},
"crochets":	{"VBZ"},
"crocidolite":	{"NN"},
"crock":	{"NN","VB","VBP"},
"crocked":	{"JJ","VBD","VBN"},
"crockery":	{"NN"},
"crocket":	{"NN"},
"crocketed":	{"JJ"},
"crocking":	{"VBG"},
"crocks":	{"NNS","VBZ"},
"crocodile":	{"NN"},
"crocodilia":	{"NN"},
"crocodilian":	{"JJ","NN"},
"crocodilus":	{"NN"},
"crocodylia":	{"NN"},
"crocodylidae":	{"NN"},
"crocodylus":	{"NN"},
"crocolite":	{"NN"},
"crocus":	{"NN"},
"crocuses":	{"NNS"},
"crocuta":	{"NN"},
"croesus":	{"NNS"},
"croft":	{"NN"},
"crofter":	{"NN"},
"crofters":	{"NNS"},
"croissant":	{"NN"},
"croissants":	{"NNS"},
"cromlech":	{"NN"},
"cromorne":	{"NN"},
"cromwell":	{"NN"},
"cromwellian":	{"JJ"},
"cronartium":	{"NN"},
"crone":	{"NN"},
"cronies":	{"NNS"},
"cronk":	{"VB"},
"cronkite":	{"NN"},
"cronus":	{"NN"},
"cronut":	{"NN"},
"cronuts":	{"NNS"},
"crony":	{"NN"},
"cronyism":	{"NN"},
"cronyn":	{"NN"},
"crook":	{"NN","VB","VBP","JJ"},
"crook-back":	{"NN","JJ"},
"crook-backed":	{"JJ"},
"crookback":	{"NN"},
"crookbacked":	{"JJ"},
"crooked":	{"JJ","VBD","VBN"},
"crookedly":	{"RB"},
"crookedness":	{"NN"},
"crookery":	{"NN"},
"crooking":	{"VBG"},
"crookneck":	{"NN"},
"crooks":	{"VBZ","NNS"},
"croon":	{"VB","VBP"},
"crooned":	{"VBD","VBN"},
"crooner":	{"NN"},
"crooners":	{"NNS"},
"crooning":	{"VBG"},
"croons":	{"VBZ"},
"crop":	{"NN","VB","VBP"},
"crop-dusting":	{"NN"},
"crop-spraying":	{"NN"},
"cropped":	{"JJ","VBD","VBN"},
"cropper":	{"NN"},
"cropping":	{"NN","VBG"},
"crops":	{"NNS","VBZ"},
"croquet":	{"NN"},
"croqueted":	{"VBD","VBN"},
"croqueting":	{"VBG"},
"croquets":	{"VBZ"},
"croquette":	{"NN"},
"crore":	{"NN"},
"crosby":	{"NN"},
"crosier":	{"NN"},
"cross":	{"NN","VB","JJ","VBP"},
"cross-banded":	{"JJ"},
"cross-bay":	{"JJ"},
"cross-blending":	{"JJ"},
"cross-border":	{"JJ"},
"cross-bred":	{"JJ"},
"cross-buying":	{"NN"},
"cross-check":	{"VB","VBP","NN"},
"cross-checked":	{"VBD","VBN"},
"cross-checking":	{"VBG"},
"cross-checks":	{"VBZ","NNS"},
"cross-classification":	{"NN"},
"cross-connect":	{"JJ"},
"cross-countries":	{"NNS"},
"cross-country":	{"JJ","NN","RB"},
"cross-cultural":	{"JJ"},
"cross-currency":	{"JJ"},
"cross-currents":	{"NNS"},
"cross-division":	{"NN"},
"cross-dress":	{"VB","VBP"},
"cross-dressed":	{"VBD","VBN"},
"cross-dresser":	{"NN"},
"cross-dressers":	{"NNS"},
"cross-dresses":	{"VBZ"},
"cross-dressing":	{"VBG","NN"},
"cross-examination":	{"JJ","NN"},
"cross-examined":	{"VBD","VBN"},
"cross-examiner":	{"NN"},
"cross-examines":	{"VBZ"},
"cross-eye":	{"NN"},
"cross-eyed":	{"JJ"},
"cross-fertilisation":	{"NN"},
"cross-fertilise":	{"VB","VBP"},
"cross-fertilised":	{"VBD","VBN"},
"cross-fertilises":	{"VBZ"},
"cross-fertilising":	{"VBG"},
"cross-fertilization":	{"NN"},
"cross-fertilize":	{"VB","VBP"},
"cross-fertilized":	{"VBD","VBN"},
"cross-fertilizes":	{"VBZ"},
"cross-fertilizing":	{"VBG"},
"cross-file":	{"VB"},
"cross-functional":	{"JJ"},
"cross-grained":	{"JJ"},
"cross-index":	{"NN","VB","VBP"},
"cross-indexed":	{"VBD","VBN"},
"cross-indexes":	{"NNS","VBZ"},
"cross-indexing":	{"VBG"},
"cross-investing":	{"JJ","NN"},
"cross-investment":	{"JJ","NN"},
"cross-legged":	{"RB","JJ"},
"cross-licensing":	{"NN","JJ"},
"cross-linguistic":	{"JJ"},
"cross-linguistically":	{"RB"},
"cross-link":	{"NN","VB"},
"cross-linkage":	{"NN"},
"cross-margining":	{"JJ","NN"},
"cross-market":	{"JJ"},
"cross-marketing":	{"JJ","VBG"},
"cross-modal":	{"JJ"},
"cross-ownership":	{"NN"},
"cross-party":	{"JJ"},
"cross-ply":	{"JJ"},
"cross-pollinate":	{"VB","VBP"},
"cross-pollinated":	{"VBD","VBN"},
"cross-pollinates":	{"VBZ"},
"cross-pollinating":	{"VBG"},
"cross-pollination":	{"NN"},
"cross-promotion":	{"NN"},
"cross-purchase":	{"JJ"},
"cross-purpose":	{"NN"},
"cross-purposes":	{"NN"},
"cross-question":	{"NN"},
"cross-questioner":	{"NN"},
"cross-react":	{"VBP","VB"},
"cross-refer":	{"VB","VBP"},
"cross-reference":	{"NN","VB","VBP"},
"cross-referenced":	{"VBD","VBN"},
"cross-references":	{"NNS","VBZ"},
"cross-referencing":	{"VBG"},
"cross-referred":	{"VBD","VBN"},
"cross-referring":	{"VBG"},
"cross-refers":	{"VBZ"},
"cross-section":	{"NN","JJ"},
"cross-sectional":	{"JJ","NN"},
"cross-selling":	{"NN"},
"cross-sentential":	{"JJ"},
"cross-shaped":	{"JJ"},
"cross-shareholding":	{"NN"},
"cross-shareholdings":	{"NNS"},
"cross-state":	{"JJ"},
"cross-stitch":	{"NN","VB","VBP"},
"cross-stitched":	{"VBD","VBN"},
"cross-stitches":	{"NNS","VBZ"},
"cross-stitching":	{"VBG"},
"cross-striations":	{"NNS"},
"cross-subsidies":	{"NNS"},
"cross-top":	{"JJ"},
"cross-town":	{"JJ"},
"cross-trading":	{"NN"},
"cross-train":	{"VB","VBP"},
"cross-trained":	{"VBD","VBN"},
"cross-trainer":	{"NN"},
"cross-trainers":	{"NNS"},
"cross-training":	{"VBG"},
"cross-trains":	{"VBZ"},
"cross-writing":	{"NN"},
"crossbar":	{"NN"},
"crossbars":	{"NNS"},
"crossbeam":	{"NN"},
"crossbench":	{"NN"},
"crossbencher":	{"NN"},
"crossbill":	{"NN"},
"crossbones":	{"NNS"},
"crossborder":	{"JJ"},
"crossbow":	{"NN"},
"crossbred":	{"JJ","VBD","VBN"},
"crossbreed":	{"VB","VBP","NN"},
"crossbreeding":	{"VBG"},
"crossbreeds":	{"VBZ"},
"crosscheck":	{"VB","VBP","NN"},
"crosschecked":	{"VBD","VBN"},
"crosschecking":	{"VBG"},
"crosschecks":	{"VBZ"},
"crosscurrent":	{"NN"},
"crosscurrents":	{"NNS"},
"crosscut":	{"JJ","NN","VB","VBP","VBD","VBN"},
"crosscuting":	{"VBG"},
"crosscuts":	{"VBZ","NNS"},
"crosse":	{"NN"},
"crossed":	{"JJ","VBD","VBN"},
"crosses":	{"NNS","VBZ"},
"crossexamining":	{"VBG"},
"crossfertilizing":	{"VBG"},
"crossfire":	{"NN"},
"crosshairs":	{"NNS"},
"crosshatch":	{"NN","VB","VBP"},
"crosshatched":	{"VBD","VBN"},
"crosshatches":	{"NNS","VBZ"},
"crosshatching":	{"VBG","NN"},
"crosshead":	{"NN"},
"crossheading":	{"NN"},
"crossing":	{"VBG","NN"},
"crossings":	{"NNS"},
"crossjack":	{"NN"},
"crossly":	{"RB"},
"crossness":	{"NN"},
"crossopterygian":	{"NN"},
"crossopterygii":	{"NN"},
"crossover":	{"NN"},
"crosspatch":	{"NN"},
"crosspiece":	{"NN"},
"crossroad":	{"NN"},
"crossroads":	{"NN","NNS"},
"crossruff":	{"VB"},
"crosstalk":	{"NN"},
"crosstie":	{"NN"},
"crosstown":	{"JJ","NN"},
"crosswalk":	{"NN"},
"crossway":	{"NN"},
"crossways":	{"RB"},
"crosswind":	{"NN"},
"crosswise":	{"RB"},
"crossword":	{"NN"},
"crotal":	{"NN"},
"crotalaria":	{"NN"},
"crotale":	{"JJ"},
"crotalidae":	{"NN"},
"crotalus":	{"NN"},
"crotaphion":	{"NN"},
"crotaphytus":	{"NNS"},
"crotch":	{"NN"},
"crotchet":	{"NN"},
"crotchetiness":	{"NN"},
"crotchety":	{"JJ","NN"},
"croton":	{"NN"},
"crotonbug":	{"NN"},
"crotophaga":	{"NN"},
"crottal":	{"NN"},
"crottle":	{"NN"},
"crouch":	{"VB","VBP","NN"},
"crouched":	{"VBD","VBN"},
"crouches":	{"VBZ"},
"crouching":	{"VBG"},
"croup":	{"NN"},
"croupe":	{"NN"},
"croupier":	{"NN"},
"croupy":	{"JJ"},
"crouse":	{"NN"},
"crouton":	{"NN"},
"crow":	{"NN","VB","VBP"},
"crow-bait":	{"NN"},
"crow-sized":	{"JJ"},
"crowbait":	{"NN"},
"crowbar":	{"NN","VB","VBP"},
"crowbarred":	{"VBD","VBN"},
"crowbarring":	{"VBG"},
"crowbars":	{"NNS","VBZ"},
"crowberry":	{"NN"},
"crowd":	{"NN","VBP","VB"},
"crowded":	{"JJ","VBN","VBD"},
"crowdfund":	{"VB","VBP"},
"crowdfunded":	{"VBD","VBN"},
"crowdfunding":	{"VBG","NN"},
"crowdfunds":	{"VBZ"},
"crowding":	{"VBG"},
"crowds":	{"NNS","VBZ"},
"crowed":	{"VBD","VBN"},
"crowfoot":	{"NN"},
"crowing":	{"VBG"},
"crown":	{"NN","VB","VBP"},
"crown-beard":	{"NN"},
"crown-of-the-field":	{"NN"},
"crownbeard":	{"NN"},
"crowned":	{"VBD","VBN"},
"crowning":	{"JJ","VBG"},
"crownless":	{"JJ"},
"crowns":	{"VBZ","NNS"},
"crownwork":	{"NN"},
"crows":	{"NNS","VBZ"},
"crozier":	{"NN"},
"crp":	{"NN"},
"crs":	{"NNS"},
"crt":	{"NN"},
"cru":	{"NN"},
"crucial":	{"JJ"},
"cruciality":	{"NN"},
"crucially":	{"RB"},
"cruciate":	{"JJ","NN"},
"crucible":	{"NN"},
"crucifer":	{"NN"},
"cruciferae":	{"NN"},
"cruciferous":	{"JJ"},
"crucified":	{"VBD","VBN"},
"crucifies":	{"VBZ"},
"crucifix":	{"NN"},
"crucifixes":	{"NNS"},
"crucifixion":	{"NN"},
"crucifixions":	{"NNS"},
"cruciform":	{"JJ"},
"crucify":	{"VB","VBP"},
"crucifying":	{"VBG"},
"crud":	{"NN"},
"cruddy":	{"JJ"},
"crude":	{"JJ","NN"},
"crude-goods":	{"NNS"},
"crude-oil":	{"NN","JJ"},
"crude-steel":	{"NN"},
"crudely":	{"RB"},
"crudeness":	{"NN"},
"cruder":	{"JJR"},
"crudes":	{"NNS"},
"crudest":	{"JJS"},
"crudites":	{"NNS"},
"crudities":	{"NNS"},
"crudity":	{"NN"},
"cruel":	{"JJ"},
"crueller":	{"JJR"},
"cruellest":	{"JJS"},
"cruelly":	{"RB"},
"cruelness":	{"NN"},
"cruelty":	{"NN"},
"cruet":	{"NN"},
"cruet-stand":	{"NN"},
"cruise":	{"NN","VBP","VB"},
"cruise-ship":	{"NN","JJ"},
"cruised":	{"VBD","VBN"},
"cruiser":	{"NN"},
"cruisers":	{"NNS"},
"cruiserweight":	{"NN"},
"cruises":	{"NNS","VBZ"},
"cruising":	{"NN","VBG"},
"cruller":	{"NN"},
"crumb":	{"NN"},
"crumbed":	{"VBD","VBN"},
"crumbing":	{"VBG"},
"crumble":	{"VB","VBP","NN"},
"crumbled":	{"VBD","VBN"},
"crumbles":	{"VBZ","NNS"},
"crumblier":	{"JJR"},
"crumbliest":	{"JJS"},
"crumbliness":	{"NN"},
"crumbling":	{"VBG"},
"crumbly":	{"JJ"},
"crumbs":	{"NNS","VBZ","UH"},
"crumhorn":	{"NN"},
"crumminess":	{"NN"},
"crummy":	{"JJ","NN"},
"crump":	{"NN","VB","VBP"},
"crumped":	{"VBD","VBN"},
"crumpet":	{"NN"},
"crumping":	{"VBG"},
"crumple":	{"VB","VBP"},
"crumpled":	{"JJ","VBD","VBN"},
"crumples":	{"VBZ"},
"crumpling":	{"VBG"},
"crumps":	{"VBZ"},
"crunch":	{"NN","VB","VBP"},
"crunched":	{"VBD","VBN"},
"crunches":	{"NNS","VBZ"},
"crunchier":	{"JJR"},
"crunchiest":	{"JJS"},
"crunching":	{"VBG"},
"crunchy":	{"JJ"},
"crupper":	{"NN"},
"crural":	{"JJ"},
"crus":	{"NN","JJ"},
"crusade":	{"NN","VBP","VB"},
"crusaded":	{"VBD","VBN"},
"crusader":	{"NN"},
"crusaders":	{"NNS"},
"crusades":	{"NNS","VBZ"},
"crusading":	{"NN","VBG"},
"cruse":	{"NN"},
"crush":	{"NN","VB","VBP"},
"crushed":	{"VBN","VBD"},
"crusher":	{"NN"},
"crushers":	{"NNS"},
"crushes":	{"VBZ","NNS"},
"crushing":	{"JJ","VBG"},
"crushingly":	{"RB"},
"crust":	{"NN","VB","VBP"},
"crustacea":	{"NNS"},
"crustacean":	{"NN","JJ"},
"crustaceans":	{"NNS"},
"crustaceous":	{"JJ"},
"crustal":	{"JJ","NN"},
"crusted":	{"JJ","VBD","VBN"},
"crustier":	{"JJR"},
"crustiest":	{"JJS"},
"crusting":	{"VBG"},
"crustlike":	{"JJ"},
"crustose":	{"JJ"},
"crusts":	{"VBZ","NNS"},
"crusty":	{"JJ"},
"crutch":	{"NN"},
"crutched":	{"VBD","VBN"},
"crutches":	{"NNS","VBZ"},
"crutching":	{"VBG"},
"crux":	{"NN"},
"cruzado":	{"NN"},
"cruzados":	{"NNS"},
"cry":	{"NN","VB","VBP"},
"cryaesthesia":	{"NN"},
"crybaby":	{"NN"},
"cryesthesia":	{"NN"},
"crying":	{"VBG","JJ","NN"},
"cryoanaesthesia":	{"NN"},
"cryoanesthesia":	{"NN"},
"cryobiology":	{"NN"},
"cryocautery":	{"NN"},
"cryogen":	{"NN"},
"cryogenic":	{"JJ"},
"cryogenics":	{"NN"},
"cryogeny":	{"NN"},
"cryolite":	{"NN"},
"cryometer":	{"NN"},
"cryonic":	{"JJ"},
"cryonics":	{"NN"},
"cryopathy":	{"NN"},
"cryophobia":	{"NN"},
"cryoscope":	{"NN"},
"cryostat":	{"NN"},
"cryosurgery":	{"NN"},
"crypt":	{"NN"},
"cryptacanthodes":	{"NNS"},
"cryptanalysis":	{"NN"},
"cryptanalyst":	{"NN"},
"cryptanalytic":	{"JJ"},
"cryptanalytics":	{"NN"},
"cryptex":	{"NN"},
"cryptic":	{"JJ","NN"},
"cryptical":	{"JJ"},
"cryptically":	{"RB"},
"cryptobiosis":	{"NN"},
"cryptobiotic":	{"JJ"},
"cryptobranchidae":	{"NN"},
"cryptobranchus":	{"NNS"},
"cryptocercidae":	{"NN"},
"cryptocercus":	{"NNS"},
"cryptococcosis":	{"NN"},
"cryptocoryne":	{"NN"},
"cryptogam":	{"NN"},
"cryptogamia":	{"NN"},
"cryptogamic":	{"JJ"},
"cryptogamous":	{"JJ"},
"cryptogram":	{"NN"},
"cryptogramma":	{"NN"},
"cryptogrammataceae":	{"NN"},
"cryptograph":	{"NN"},
"cryptographer":	{"NN"},
"cryptographers":	{"NNS"},
"cryptographic":	{"JJ"},
"cryptographical":	{"JJ"},
"cryptographically":	{"RB"},
"cryptography":	{"NN"},
"cryptologic":	{"JJ"},
"cryptological":	{"JJ"},
"cryptologist":	{"NN"},
"cryptology":	{"NN"},
"cryptomeria":	{"NN"},
"cryptomonad":	{"NN"},
"cryptophyceae":	{"NN"},
"cryptophyta":	{"NN"},
"cryptophyte":	{"NN"},
"cryptoprocta":	{"NN"},
"cryptorchidism":	{"NN"},
"cryptorchidy":	{"NN"},
"cryptorchism":	{"NN"},
"cryptotermes":	{"NNS"},
"cryptotis":	{"NN"},
"crysanthemum":	{"NN"},
"crystal":	{"NN","JJ"},
"crystal-lattice":	{"JJ","NN"},
"crystalisability":	{"NN"},
"crystalisable":	{"JJ"},
"crystalisation":	{"NN"},
"crystalise":	{"VB","VBP"},
"crystalised":	{"JJ","VBD","VBN"},
"crystaliser":	{"NN"},
"crystalises":	{"VBZ"},
"crystalising":	{"VBG"},
"crystalizability":	{"NN"},
"crystalizable":	{"JJ"},
"crystalization":	{"NN"},
"crystalize":	{"VB","VBP"},
"crystalized":	{"VBD","VBN","JJ"},
"crystalizer":	{"NN"},
"crystalizes":	{"VBZ"},
"crystalizing":	{"VBG"},
"crystalline":	{"JJ","NN"},
"crystallisability":	{"NN"},
"crystallisable":	{"JJ"},
"crystallisation":	{"NN"},
"crystallise":	{"VB","VBP"},
"crystallised":	{"JJ","VBD","VBN"},
"crystalliser":	{"NN"},
"crystallises":	{"VBZ"},
"crystallising":	{"VBG"},
"crystallite":	{"NN"},
"crystallites":	{"NNS"},
"crystallizability":	{"NN"},
"crystallizable":	{"JJ"},
"crystallization":	{"NN"},
"crystallize":	{"VB","VBP"},
"crystallized":	{"JJ","VBD","VBN"},
"crystallizer":	{"NN"},
"crystallizes":	{"VBZ"},
"crystallizing":	{"VBG"},
"crystallographer":	{"NN"},
"crystallographers":	{"NNS"},
"crystallographic":	{"JJ"},
"crystallography":	{"NN"},
"crystals":	{"NNS"},
"cs":	{"NN"},
"cse":	{"NN"},
"csis":	{"NN"},
"cst":	{"NN"},
"ct":	{"NN"},
"ctas":	{"NNS"},
"ctc":	{"NN"},
"ctene":	{"NN"},
"ctenidium":	{"NN"},
"ctenizidae":	{"NN"},
"ctenocephalides":	{"NNS"},
"ctenocephalus":	{"NNS"},
"ctenoid":	{"JJ"},
"ctenophora":	{"NN"},
"ctenophore":	{"NN"},
"cts":	{"NN"},
"cu":	{"NN"},
"cu.":	{"NN"},
"cub":	{"NN"},
"cuba":	{"NN"},
"cuban-assisted":	{"JJ"},
"cubby":	{"NN"},
"cubbyhole":	{"NN"},
"cubbyholes":	{"NNS"},
"cube":	{"NN","VB","VBP"},
"cube-shaped":	{"JJ"},
"cubeb":	{"NN"},
"cubed":	{"VBD","VBN"},
"cubelike":	{"JJ"},
"cubes":	{"NNS","VBZ"},
"cubic":	{"JJ"},
"cubical":	{"JJ"},
"cubicity":	{"NN"},
"cubicle":	{"NN"},
"cubiform":	{"JJ"},
"cubing":	{"VBG"},
"cubism":	{"NN"},
"cubist":	{"NN","JJ"},
"cubistic":	{"JJ"},
"cubists":	{"NNS"},
"cubit":	{"NN"},
"cubital":	{"JJ"},
"cubitiere":	{"NN"},
"cubitus":	{"NN"},
"cuboid":	{"NN","JJ"},
"cuboidal":	{"JJ"},
"cubs":	{"NNS"},
"cuckold":	{"NN","VBP","VB"},
"cuckolded":	{"VBD","VBN"},
"cuckolding":	{"VBG"},
"cuckoldom":	{"NN"},
"cuckoldry":	{"NN"},
"cuckolds":	{"NNS","VBZ"},
"cuckoo":	{"NN","JJ","VBP","VB"},
"cuckoo-bumblebee":	{"NN"},
"cuckooed":	{"VBD","VBN"},
"cuckooflower":	{"NN"},
"cuckooing":	{"VBG"},
"cuckoopint":	{"NN"},
"cuckoos":	{"NNS","VBZ"},
"cuculidae":	{"NN"},
"cuculiformes":	{"NNS"},
"cuculus":	{"NNS"},
"cucumber":	{"NN"},
"cucumber-shaped":	{"JJ"},
"cucumbers":	{"NNS"},
"cucumis":	{"NN"},
"cucurbit":	{"NN"},
"cucurbita":	{"NN"},
"cucurbitaceae":	{"NN"},
"cucurbitaceous":	{"JJ"},
"cud":	{"NN"},
"cudbear":	{"NN"},
"cuddle":	{"VB","VBP","NN"},
"cuddled":	{"VBD","VBN"},
"cuddles":	{"VBZ"},
"cuddlesome":	{"JJ"},
"cuddlier":	{"JJR"},
"cuddliest":	{"JJS"},
"cuddling":	{"VBG"},
"cuddly":	{"JJ"},
"cuddy":	{"NN"},
"cudgel":	{"NN","VB","VBP"},
"cudgeled":	{"VBD","VBN"},
"cudgeling":	{"VBG"},
"cudgelled":	{"VBD","VBN"},
"cudgelling":	{"VBG"},
"cudgels":	{"NNS","VBZ"},
"cudweed":	{"NN"},
"cue":	{"NN","VB","VBP"},
"cue-phrase":	{"NN"},
"cued":	{"VBD","VBN"},
"cueing":	{"VBG"},
"cues":	{"VBZ","NNS"},
"cuff":	{"NN","VB","VBP"},
"cuff-like":	{"JJ"},
"cuff-link":	{"NN"},
"cuff-links":	{"NNS"},
"cuffed":	{"VBD","VBN"},
"cuffing":	{"VBG"},
"cufflink":	{"NN"},
"cufflinks":	{"NNS"},
"cuffs":	{"NNS","VBZ"},
"cuirass":	{"NN"},
"cuirassier":	{"NN"},
"cuirassiers":	{"NNS"},
"cuisine":	{"NN"},
"cuisse":	{"NN"},
"cuk":	{"JJ"},
"cuke":	{"NN"},
"cul":	{"NN"},
"culbertson":	{"NN"},
"culcita":	{"NN"},
"culdoscope":	{"NN"},
"culdoscopy":	{"NN"},
"culebra":	{"NN"},
"culex":	{"NN"},
"culiacan":	{"NN"},
"culicidae":	{"NN"},
"culinary":	{"JJ","NN"},
"cull":	{"VB","VBP","NN"},
"culled":	{"VBD","VBN"},
"cullender":	{"NN"},
"culling":	{"VBG"},
"cullis":	{"NN"},
"culls":	{"VBZ","NNS"},
"culm":	{"NN"},
"culminate":	{"VB","VBP"},
"culminated":	{"VBD","VBN"},
"culminates":	{"VBZ"},
"culminating":	{"VBG"},
"culmination":	{"NN"},
"culotte":	{"NN"},
"culpa":	{"NN"},
"culpability":	{"NN"},
"culpable":	{"JJ"},
"culpableness":	{"NN"},
"culpably":	{"RB"},
"culpas":	{"FW"},
"culprit":	{"NN"},
"culprits":	{"NNS"},
"cult":	{"NN","JJ"},
"culte":	{"FW"},
"cultism":	{"NN"},
"cultist":	{"NN"},
"cultivable":	{"JJ"},
"cultivar":	{"NN"},
"cultivars":	{"NNS"},
"cultivatable":	{"JJ"},
"cultivate":	{"VB","VBP"},
"cultivated":	{"VBN","JJ","VBD"},
"cultivates":	{"VBZ"},
"cultivating":	{"VBG"},
"cultivation":	{"NN"},
"cultivator":	{"NN"},
"cultivators":	{"NNS"},
"cults":	{"NNS"},
"cultura":	{"NN"},
"cultural":	{"JJ"},
"cultural-reform":	{"NN"},
"culturally":	{"RB"},
"culturati":	{"NN"},
"culture":	{"NN","VB","VBP"},
"culture-Protestantism":	{"NN"},
"culture-protestantism":	{"NN"},
"cultured":	{"JJ","VBD","VBN"},
"cultures":	{"NNS","VBZ"},
"culturing":	{"VBG"},
"cultus":	{"NN"},
"culverin":	{"NN"},
"culvert":	{"NN"},
"cum":	{"IN"},
"cumana":	{"NN"},
"cumara":	{"NN"},
"cumarone":	{"NN"},
"cumber":	{"VB","VBP"},
"cumbered":	{"VBD","VBN"},
"cumbering":	{"VBG"},
"cumberland":	{"NN"},
"cumbers":	{"VBZ"},
"cumbersome":	{"JJ"},
"cumbersomeness":	{"NN"},
"cumbria":	{"NN"},
"cumbrous":	{"JJ"},
"cumfrey":	{"NN"},
"cumin":	{"NN"},
"cuminum":	{"NN"},
"cummerbund":	{"NN"},
"cummins":	{"NNS"},
"cumquat":	{"NN"},
"cumulate":	{"VB","VBP"},
"cumulated":	{"VBD","VBN"},
"cumulates":	{"VBZ"},
"cumulating":	{"VBG"},
"cumulation":	{"NN"},
"cumulative":	{"JJ"},
"cumulatively":	{"RB"},
"cumuli":	{"NNS"},
"cumuliform":	{"JJ"},
"cumulonimbus":	{"NN"},
"cumulous":	{"JJ"},
"cumulus":	{"NN"},
"cunaxa":	{"NN"},
"cunctation":	{"NN"},
"cunctator":	{"NN"},
"cuneal":	{"JJ"},
"cuneate":	{"JJ"},
"cuneiform":	{"NN","JJ"},
"cuneiforms":	{"NNS"},
"cuneus":	{"NNS"},
"cuniculus":	{"NNS"},
"cunner":	{"NN"},
"cunnilinctus":	{"NNS"},
"cunnilingus":	{"NN"},
"cunning":	{"JJ","NN"},
"cunningham":	{"NN"},
"cunningly":	{"RB"},
"cunoniaceae":	{"NN"},
"cunt":	{"NN"},
"cuon":	{"NN"},
"cup":	{"NN","VB","VBP"},
"cupbearer":	{"NN"},
"cupboard":	{"NN"},
"cupboards":	{"NNS"},
"cupcake":	{"NN"},
"cupcakes":	{"NNS"},
"cupel":	{"NN"},
"cupflower":	{"NN"},
"cupful":	{"NN"},
"cupfuls":	{"NNS"},
"cupid":	{"NN"},
"cupidity":	{"NN"},
"cupids":	{"NNS"},
"cuplike":	{"JJ"},
"cupola":	{"NN"},
"cupolas":	{"NNS"},
"cuppa":	{"NN"},
"cuppas":	{"NNS"},
"cupped":	{"VBD","VBN"},
"cupper":	{"NN"},
"cupping":	{"NN","VBG"},
"cupressaceae":	{"NN"},
"cupressus":	{"NN","NNS"},
"cupric":	{"JJ"},
"cuprimine":	{"NN"},
"cuprite":	{"NN"},
"cupronickel":	{"NN"},
"cuprous":	{"JJ"},
"cups":	{"NNS","VBZ"},
"cupular":	{"JJ"},
"cupulate":	{"JJ"},
"cupule":	{"NN"},
"cuquenan":	{"NN"},
"cur":	{"NN"},
"curability":	{"NN"},
"curable":	{"JJ"},
"curableness":	{"NN"},
"curacao":	{"NN"},
"curacoa":	{"NN"},
"curacy":	{"NN"},
"curandera":	{"NN"},
"curandero":	{"NN"},
"curanderos":	{"NNS"},
"curare":	{"NN"},
"curassow":	{"NN"},
"curate":	{"NN","VB","VBP"},
"curated":	{"VBD","VBN"},
"curates":	{"NNS","VBZ"},
"curating":	{"VBG"},
"curation":	{"NN"},
"curations":	{"NNS"},
"curative":	{"JJ","NN"},
"curator":	{"NN"},
"curatorial":	{"JJ","NN"},
"curators":	{"NNS"},
"curatorship":	{"NN"},
"curb":	{"VB","VBP","NN"},
"curbed":	{"VBD","VBN"},
"curbing":	{"VBG"},
"curbs":	{"NNS","VBZ"},
"curbside":	{"NN"},
"curbstone":	{"NN"},
"curculionidae":	{"NN"},
"curcuma":	{"NN"},
"curd":	{"NN"},
"curded":	{"VBD","VBN"},
"curding":	{"VBG"},
"curdle":	{"VB","VBP"},
"curdled":	{"VBD","VBN"},
"curdles":	{"VBZ"},
"curdling":	{"VBG"},
"curds":	{"NNS","VBZ"},
"cure":	{"VB","VBP","NN"},
"cure-all":	{"NN"},
"cure-alls":	{"NNS"},
"cured":	{"VBD","VBN"},
"cures":	{"NNS","VBZ"},
"curet":	{"NN"},
"curettage":	{"NN"},
"curette":	{"NN"},
"curettement":	{"NN"},
"curfew":	{"NN"},
"curia":	{"NN"},
"curiae":	{"NNS"},
"curial":	{"JJ"},
"curie":	{"NN"},
"curietherapy":	{"NN"},
"curing":	{"NN","JJ","VBG"},
"curio":	{"NN"},
"curiosa":	{"NN"},
"curiosities":	{"NNS"},
"curiosity":	{"NN"},
"curious":	{"JJ"},
"curiously":	{"RB"},
"curiousness":	{"NN"},
"curitiba":	{"NN"},
"curium":	{"NN"},
"curl":	{"NN","VB","VBP"},
"curled":	{"VBD","VBN"},
"curler":	{"NN"},
"curlers":	{"NNS"},
"curlew":	{"NN"},
"curlews":	{"NNS"},
"curlicue":	{"NN"},
"curlicues":	{"NNS"},
"curlier":	{"JJR"},
"curliest":	{"JJS"},
"curliness":	{"NN"},
"curling":	{"NN","VBG"},
"curls":	{"VBZ","NNS"},
"curly":	{"JJ"},
"curly-coated":	{"JJ"},
"curly-grained":	{"JJ"},
"curly-haired":	{"JJ"},
"curly-heads":	{"NNS"},
"curly-leafed":	{"JJ"},
"curly-leaved":	{"JJ"},
"curmudgeon":	{"NN"},
"curmudgeonly":	{"JJ"},
"currajong":	{"NN"},
"currant":	{"NN"},
"currants":	{"NNS"},
"currawong":	{"NN"},
"currencies":	{"NNS"},
"currencny":	{"NN"},
"currency":	{"NN"},
"currency-exchange":	{"JJ"},
"currency-market":	{"JJ"},
"currency-options":	{"NNS"},
"current":	{"JJ","NN"},
"current-account":	{"JJ","NN"},
"current-carrying":	{"JJ"},
"current-coupon":	{"JJ"},
"current-delivery":	{"NN"},
"current-generation":	{"JJ","NN"},
"current-year":	{"JJ"},
"currently":	{"RB","JJ"},
"currentness":	{"NN"},
"currents":	{"NNS"},
"curricula":	{"NNS"},
"curricular":	{"JJ"},
"curriculum":	{"NN"},
"curriculums":	{"NNS"},
"curried":	{"VBD","VBN","JJ"},
"currier":	{"NN"},
"curries":	{"VBZ","NNS"},
"currish":	{"JJ"},
"currishly":	{"RB"},
"curry":	{"NN","VB","VBP"},
"curry-comb":	{"NN"},
"currycomb":	{"NN","VB","VBP"},
"currycombed":	{"VBD","VBN"},
"currycombing":	{"VBG"},
"currycombs":	{"VBZ"},
"currying":	{"VBG"},
"curse":	{"NN","VB","VBP"},
"cursed":	{"VBD","VBN","JJ"},
"cursedly":	{"RB"},
"curses":	{"VBZ","NNS"},
"cursing":	{"VBG"},
"cursive":	{"JJ"},
"cursively":	{"RB"},
"cursor":	{"NN"},
"cursorial":	{"JJ"},
"cursorily":	{"RB"},
"cursorius":	{"NN"},
"cursors":	{"NNS"},
"cursory":	{"JJ"},
"curst":	{"JJ","VBD","VBN"},
"curt":	{"JJ","NN"},
"curtail":	{"VB","VBP"},
"curtailed":	{"VBD","VBN"},
"curtailing":	{"VBG"},
"curtailment":	{"NN"},
"curtails":	{"VBZ"},
"curtain":	{"NN","VB","VBP"},
"curtain-raiser":	{"NN"},
"curtain-raisers":	{"NNS"},
"curtained":	{"JJ","VBD","VBN"},
"curtaining":	{"VBG"},
"curtainless":	{"JJ"},
"curtains":	{"NNS","VBZ"},
"curtal":	{"JJ"},
"curtilage":	{"NN"},
"curtisia":	{"NN"},
"curtiss":	{"NNS"},
"curtly":	{"RB"},
"curtness":	{"NN"},
"curtsey":	{"NN","VB","VBP"},
"curtseyed":	{"VBD","VBN"},
"curtseying":	{"VBG","VBG"},
"curtseys":	{"VBZ","VBZ"},
"curtsied":	{"VBD","VBN"},
"curtsies":	{"VBZ"},
"curtsy":	{"NN","VB","VBP"},
"curtsying":	{"VBG"},
"curvaceous":	{"JJ"},
"curvaceously":	{"RB"},
"curvaceousness":	{"NN"},
"curvature":	{"NN"},
"curve":	{"NN","VB","VBP"},
"curveball":	{"NN","RB"},
"curved":	{"JJ","VBD","VBN"},
"curves":	{"NNS","VBZ"},
"curvet":	{"NN","VB","VBP"},
"curveted":	{"VBD","VBN"},
"curveting":	{"VBG"},
"curvets":	{"VBZ"},
"curvetted":	{"VBD","VBN"},
"curvetting":	{"VBG"},
"curvey":	{"JJ"},
"curvier":	{"JJR"},
"curviest":	{"JJS"},
"curvilineal":	{"JJ"},
"curvilinear":	{"JJ","NN"},
"curving":	{"VBG"},
"curvy":	{"JJ"},
"cusco":	{"NN"},
"cuscus":	{"NN"},
"cuscuta":	{"NN"},
"cush-cush":	{"NN"},
"cushat":	{"NN"},
"cushaw":	{"NN"},
"cushing":	{"NN"},
"cushion":	{"NN","VB","VBP"},
"cushioned":	{"VBD","VBN"},
"cushioning":	{"NN","VBG"},
"cushions":	{"VBZ","NNS"},
"cushiony":	{"JJ"},
"cushitic":	{"NN"},
"cushy":	{"JJ"},
"cusk":	{"NN"},
"cusk-eel":	{"NN"},
"cusp":	{"NN"},
"cuspate":	{"JJ"},
"cuspated":	{"JJ"},
"cusped":	{"JJ"},
"cuspid":	{"NN"},
"cuspidal":	{"JJ"},
"cuspidate":	{"JJ"},
"cuspidated":	{"JJ"},
"cuspidation":	{"NN"},
"cuspidor":	{"NN"},
"cuss":	{"NN","VB","VBP"},
"cussed":	{"JJ","VBD","VBN"},
"cussedly":	{"RB"},
"cussedness":	{"NN"},
"cusses":	{"VBZ"},
"cussing":	{"VBG"},
"custard":	{"NN"},
"custard-like":	{"JJ"},
"custer":	{"NN"},
"custodial":	{"JJ","NN"},
"custodian":	{"NN"},
"custodianship":	{"NN"},
"custody":	{"NN"},
"custom":	{"NN","JJ"},
"custom-built":	{"JJ","NN"},
"custom-chip":	{"JJ"},
"custom-design":	{"JJ"},
"custom-designed":	{"JJ"},
"custom-die":	{"NN"},
"custom-made":	{"JJ","VBD","VBN"},
"custom-make":	{"VB","VBP"},
"custom-makes":	{"VBZ"},
"custom-making":	{"VBG"},
"custom-tailored":	{"JJ"},
"customarily":	{"RB"},
"customary":	{"JJ"},
"customer":	{"NN"},
"customer-access":	{"NN"},
"customer-account":	{"NN"},
"customer-cost":	{"NN"},
"customer-driven":	{"JJ"},
"customer-inventory":	{"JJ"},
"customer-oriented":	{"JJ"},
"customer-service":	{"JJ","NN"},
"customers":	{"NNS"},
"customhouse":	{"NN"},
"customise":	{"VB","VBP"},
"customised":	{"VBD","VBN"},
"customises":	{"VBZ"},
"customising":	{"VBG"},
"customization":	{"NN"},
"customize":	{"VB","VBP"},
"customized":	{"VBN","VBD","JJ"},
"customizes":	{"VBZ"},
"customizing":	{"VBG"},
"customs":	{"NN","NNS"},
"customs-clearance":	{"NN"},
"customs-cleared":	{"JJ"},
"customshouse":	{"NN"},
"cut":	{"VB","NN","VBD","VBN","VBP"},
"cut-and-dried":	{"JJ"},
"cut-and-dry":	{"JJ"},
"cut-and-paste":	{"JJ"},
"cut-and-thrust":	{"NN"},
"cut-down":	{"JJ"},
"cut-glass":	{"JJ"},
"cut-in":	{"NN"},
"cut-off":	{"NN"},
"cut-price":	{"JJ"},
"cut-rate":	{"JJ","NN"},
"cut-throat":	{"JJ"},
"cut-to-a-familiar-pattern":	{"JJ"},
"cut-up":	{"NN"},
"cutaneal":	{"JJ"},
"cutaneous":	{"JJ"},
"cutaway":	{"JJ","NN"},
"cutback":	{"NN"},
"cutbacks":	{"NNS"},
"cutch":	{"NN"},
"cute":	{"JJ"},
"cutely":	{"RB"},
"cuteness":	{"NN"},
"cuter":	{"JJR"},
"cuterebra":	{"NN"},
"cuterebridae":	{"NN"},
"cutest":	{"JJS"},
"cutglass":	{"JJ"},
"cuticle":	{"NN"},
"cuticula":	{"NN"},
"cuticular":	{"JJ"},
"cutin":	{"NN"},
"cutinize":	{"VB"},
"cutis":	{"NN"},
"cutlas":	{"NN"},
"cutlass":	{"NN"},
"cutlassfish":	{"NN"},
"cutler":	{"NN"},
"cutlery":	{"NN"},
"cutlet":	{"NN"},
"cutlets":	{"NNS"},
"cutoff":	{"NN"},
"cutout":	{"NN"},
"cutouts":	{"NNS"},
"cutpurse":	{"NN"},
"cuts":	{"NNS","VBZ"},
"cutsie":	{"JJ"},
"cuttable":	{"JJ"},
"cutter":	{"NN"},
"cutters":	{"NNS"},
"cutthroat":	{"JJ","NN"},
"cutting":	{"VBG","NN","JJ"},
"cutting-and-pasting":	{"NN"},
"cutting-edge":	{"JJ"},
"cutting-tools":	{"NNS"},
"cuttingly":	{"RB"},
"cuttings":	{"NNS"},
"cuttle":	{"NN"},
"cuttlefish":	{"NN","NNS"},
"cutwork":	{"NN"},
"cutworm":	{"NN"},
"cuvees":	{"NNS"},
"cuvier":	{"NN"},
"cuzco":	{"NN"},
"cv":	{"JJ","NN"},
"cva":	{"NN"},
"cw-capable":	{"JJ"},
"cwm":	{"NN"},
"cwt":	{"NN"},
"cx":	{"JJ"},
"cxl":	{"JJ"},
"cxlv":	{"JJ"},
"cxv":	{"JJ"},
"cxx":	{"JJ"},
"cxxv":	{"JJ"},
"cxxx":	{"JJ"},
"cxxxv":	{"JJ"},
"cyamopsis":	{"NN"},
"cyamus":	{"NN"},
"cyan":	{"JJ","NN"},
"cyanamid":	{"NN"},
"cyanamide":	{"NN"},
"cyanide":	{"NN"},
"cyanide-laced":	{"JJ"},
"cyanided":	{"VBD","VBN"},
"cyanides":	{"VBZ"},
"cyaniding":	{"VBG"},
"cyanite":	{"NN"},
"cyanobacteria":	{"NNS"},
"cyanobacterial":	{"JJ"},
"cyanobacterium":	{"NN"},
"cyanocitta":	{"NN"},
"cyanocobalamin":	{"NN"},
"cyanogen":	{"NN"},
"cyanogenetic":	{"JJ"},
"cyanogenic":	{"JJ"},
"cyanohydrin":	{"NN"},
"cyanophyceae":	{"NN"},
"cyanophyta":	{"NN"},
"cyanophyte":	{"JJ"},
"cyanosis":	{"NN"},
"cyanuramide":	{"NN"},
"cyathea":	{"NN"},
"cyatheaceae":	{"NN"},
"cybele":	{"NN"},
"cyber":	{"JJ","VB","VBP"},
"cyber-terrorism":	{"NN"},
"cyber-terrorist":	{"NN"},
"cyberactivism":	{"NN"},
"cyberactivist":	{"NN"},
"cyberactivists":	{"NNS"},
"cyberactivities":	{"NNS"},
"cyberactivity":	{"NN"},
"cyberart":	{"NN"},
"cyberathlete":	{"NN"},
"cyberathletes":	{"NNS"},
"cyberathletics":	{"NN"},
"cyberattack":	{"NN","VB","VBP"},
"cyberattacked":	{"VBD","VBN"},
"cyberattacking":	{"VBG"},
"cyberattacks":	{"NNS","VBZ"},
"cyberbullied":	{"VBD","VBN"},
"cyberbullies":	{"NNS","VBZ"},
"cyberbully":	{"NN","VB","VBP"},
"cyberbullying":	{"VBG","NN"},
"cybercafe":	{"NN"},
"cyberchondria":	{"NN"},
"cyberchondriac":	{"JJ","NN"},
"cyberchondriacs":	{"NNS"},
"cybercrime":	{"NN"},
"cyberculture":	{"NN"},
"cyberheist":	{"NN"},
"cyberheists":	{"NNS"},
"cyberlove":	{"NN"},
"cybernate":	{"VB","VBP"},
"cybernated":	{"VBD","VBN"},
"cybernates":	{"VBZ"},
"cybernating":	{"VBG"},
"cybernation":	{"NN"},
"cybernaut":	{"NN"},
"cybernetic":	{"JJ"},
"cybernetical":	{"JJ"},
"cybernetically":	{"RB"},
"cybernetician":	{"NN"},
"cyberneticians":	{"NNS"},
"cyberneticist":	{"NN"},
"cyberneticists":	{"NNS"},
"cybernetics":	{"NN"},
"cyberpet":	{"NN"},
"cyberpets":	{"NNS"},
"cyberphobia":	{"NN"},
"cyberporn":	{"NN"},
"cyberpunk":	{"NN","JJ"},
"cybersecurity":	{"NN"},
"cybersex":	{"NN"},
"cyberspace":	{"NN"},
"cybersquatter":	{"NN"},
"cybersquatters":	{"NNS"},
"cybersquatting":	{"NN"},
"cyberstalker":	{"NN"},
"cyberstalkers":	{"NNS"},
"cyberstalking":	{"NN"},
"cyberterrorism":	{"NN"},
"cyberwar":	{"NN"},
"cyberwarfare":	{"NN"},
"cyberweapon":	{"NN"},
"cyberweapons":	{"NNS"},
"cyborg":	{"NN"},
"cycad":	{"NN"},
"cycadaceae":	{"NN"},
"cycadaceous":	{"JJ"},
"cycadales":	{"NNS"},
"cycadofilicales":	{"NNS"},
"cycadophyta":	{"NN"},
"cycadophytina":	{"NN"},
"cycadopsida":	{"NN"},
"cycads":	{"NNS"},
"cycas":	{"NN"},
"cyclamen":	{"NN","NNS"},
"cycle":	{"NN","VB","VBP"},
"cycled":	{"VBD","VBN"},
"cycles":	{"NNS","VBZ"},
"cyclic":	{"JJ"},
"cyclical":	{"JJ"},
"cyclicality":	{"NN"},
"cyclically":	{"RB"},
"cyclicity":	{"NN"},
"cycling":	{"NN","VBG"},
"cycliophora":	{"NN"},
"cyclist":	{"NN"},
"cyclists":	{"NNS"},
"cyclobenzaprine":	{"NN"},
"cyclohexanol":	{"NN"},
"cycloid":	{"JJ","NN"},
"cycloidal":	{"JJ"},
"cycloloma":	{"NN"},
"cyclonal":	{"JJ"},
"cyclone":	{"NN"},
"cyclones":	{"NNS"},
"cyclonic":	{"JJ"},
"cyclonical":	{"JJ"},
"cyclooxygenase":	{"NN"},
"cyclooxygenase-1":	{"NN"},
"cyclooxygenase-2":	{"NN"},
"cyclopaedia":	{"NN"},
"cyclopedia":	{"NN"},
"cyclophorus":	{"NN"},
"cyclopia":	{"NN"},
"cyclopropane":	{"NN"},
"cyclopteridae":	{"NN"},
"cyclopterus":	{"NN"},
"cyclorama":	{"NN"},
"cycloserine":	{"NN"},
"cyclosis":	{"NN"},
"cyclosorus":	{"NN"},
"cyclosporeae":	{"NN"},
"cyclosporine":	{"NN","JJ"},
"cyclostomata":	{"NN"},
"cyclostome":	{"NN"},
"cyclostyle":	{"NN","VB","VBP"},
"cyclostyled":	{"VBD","VBN"},
"cyclostyles":	{"NNS","VBZ"},
"cyclostyling":	{"VBG"},
"cyclothymia":	{"NN"},
"cyclothymic":	{"JJ"},
"cyclotron":	{"NN"},
"cycnoches":	{"NNS"},
"cyder":	{"NN"},
"cydippea":	{"NN"},
"cydippida":	{"NN"},
"cydippidea":	{"NN"},
"cydonia":	{"NN"},
"cygnet":	{"NN"},
"cygnus":	{"NN"},
"cylinder":	{"NN"},
"cylinders":	{"NNS"},
"cylindric":	{"JJ"},
"cylindrical":	{"JJ"},
"cylindrical-stemmed":	{"JJ"},
"cylindricality":	{"NN"},
"cylindricalness":	{"NN"},
"cylix":	{"NN"},
"cyma":	{"NN"},
"cymatiidae":	{"NN"},
"cymatium":	{"NN"},
"cymbal":	{"NN"},
"cymbalist":	{"NN"},
"cymbid":	{"NN"},
"cymbidium":	{"NN"},
"cyme":	{"NN"},
"cymene":	{"NN"},
"cymling":	{"NN"},
"cymograph":	{"NN"},
"cymose":	{"JJ"},
"cymric":	{"NN"},
"cymru":	{"NN"},
"cymry":	{"NN"},
"cymule":	{"NN"},
"cynancum":	{"NN"},
"cynara":	{"NN"},
"cynewulf":	{"NN"},
"cynic":	{"NN","JJ"},
"cynical":	{"JJ"},
"cynically":	{"RB"},
"cynicism":	{"NN"},
"cynics":	{"NNS"},
"cynipidae":	{"NN"},
"cynips":	{"NNS"},
"cynocephalidae":	{"NN"},
"cynocephalus":	{"NNS"},
"cynodon":	{"NN"},
"cynodont":	{"NN"},
"cynodontia":	{"NN"},
"cynoglossidae":	{"NN"},
"cynoglossum":	{"NN"},
"cynomys":	{"NNS"},
"cynophobia":	{"NN"},
"cynopterus":	{"NN"},
"cynoscephalae":	{"NN"},
"cynoscion":	{"NN"},
"cynosure":	{"NN"},
"cynthia":	{"NN"},
"cynwulf":	{"NN"},
"cyon":	{"NN"},
"cyperaceae":	{"NN"},
"cyperus":	{"NN"},
"cypher":	{"NN"},
"cyphered":	{"VBD","VBN"},
"cyphering":	{"VBG"},
"cyphers":	{"VBZ"},
"cyphomandra":	{"NN"},
"cypraea":	{"NN"},
"cypraeidae":	{"NN"},
"cypre":	{"NN"},
"cypress":	{"NN"},
"cypress-like":	{"JJ"},
"cyprian":	{"JJ","NN"},
"cyprinid":	{"JJ","NN"},
"cyprinidae":	{"NN"},
"cypriniformes":	{"NNS"},
"cyprinodont":	{"NN"},
"cyprinodontidae":	{"NN"},
"cyprinoid":	{"JJ"},
"cyprinus":	{"NN"},
"cypriote":	{"JJ","NN"},
"cypripedia":	{"NN"},
"cypripedium":	{"NN"},
"cyproheptadine":	{"NN"},
"cyril":	{"NN"},
"cyrilla":	{"NN"},
"cyrilliaceae":	{"NN"},
"cyrillic":	{"NN"},
"cyrtomium":	{"NN"},
"cyrus":	{"NN"},
"cyst":	{"NN"},
"cysteine":	{"NN"},
"cystic":	{"JJ","NN"},
"cystine":	{"NN"},
"cystitis":	{"NN"},
"cystocele":	{"NN"},
"cystolith":	{"NN"},
"cystoparalysis":	{"NN"},
"cystophora":	{"NN"},
"cystoplegia":	{"NN"},
"cystopteris":	{"NNS"},
"cysts":	{"NNS"},
"cytherea":	{"NN"},
"cytidine":	{"NN"},
"cytisus":	{"NN"},
"cytisuses":	{"NNS"},
"cytoarchitectonic":	{"JJ"},
"cytoarchitectonics":	{"NN"},
"cytoarchitectural":	{"JJ"},
"cytoarchitecture":	{"NN"},
"cytochrome":	{"NN"},
"cytogenesis":	{"NN"},
"cytogenetic":	{"JJ"},
"cytogenetical":	{"JJ"},
"cytogeneticist":	{"NN"},
"cytogenetics":	{"NN"},
"cytogeny":	{"NN"},
"cytokine":	{"NN"},
"cytokines":	{"NNS"},
"cytokinesis":	{"NN"},
"cytokinetic":	{"JJ"},
"cytokinin":	{"NN"},
"cytol":	{"NN"},
"cytologic":	{"JJ"},
"cytological":	{"JJ"},
"cytologist":	{"NN"},
"cytology":	{"NN"},
"cytolysin":	{"NN"},
"cytolysis":	{"NN"},
"cytolytic":	{"JJ"},
"cytomegalic":	{"JJ"},
"cytomegalovirus":	{"NN","JJ"},
"cytomembrane":	{"NN"},
"cytopathogenic":	{"JJ"},
"cytopenia":	{"NN"},
"cytophotometer":	{"NN"},
"cytophotometric":	{"JJ"},
"cytophotometrically":	{"RB"},
"cytophotometry":	{"NN"},
"cytoplasm":	{"NN"},
"cytoplasmatic":	{"JJ"},
"cytoplasmic":	{"JJ"},
"cytoplasmically":	{"RB"},
"cytoplast":	{"NN"},
"cytoplastic":	{"JJ"},
"cytosine":	{"NN"},
"cytoskeleton":	{"NN"},
"cytosmear":	{"NN"},
"cytosol":	{"NN"},
"cytostome":	{"NN"},
"cytotoxic":	{"JJ"},
"cytotoxicity":	{"NN"},
"cytotoxin":	{"NN"},
"czar":	{"NN"},
"czarina":	{"NN"},
"czarist":	{"JJ","NN"},
"czaristic":	{"JJ"},
"czaritza":	{"NN"},
"czars":	{"NNS"},
"czechoslovak":	{"NN"},
"czechoslovak-made":	{"JJ"},
"czechoslovakia":	{"NN"},
"czechoslovakian":	{"JJ","NN"},
"czerny":	{"NN"},
"czestochowa":	{"NN"},
"d":	{"NN","SYM","LS"},
"d-Percentage":	{"NN"},
"d-c":	{"NN"},
"d-day":	{"NN"},
"d-layer":	{"NN"},
"d-marks":	{"NNS"},
"d-night":	{"NN"},
"d-percentage":	{"NN"},
"d.a.":	{"NN"},
"d.c.":	{"NN"},
"d.o.a.":	{"JJ"},
"d.p.r.k.":	{"NN"},
"da'wah":	{"NN"},
"da-da-da-dum":	{"JJ"},
"dab":	{"NN","VB","VBP"},
"daba":	{"NN"},
"dabbed":	{"VBD","VBN"},
"dabbing":	{"VBG"},
"dabble":	{"VB","VBP"},
"dabbled":	{"VBD","VBN"},
"dabbler":	{"NN"},
"dabblers":	{"NNS"},
"dabbles":	{"VBZ"},
"dabbling":	{"VBG"},
"dabchick":	{"NN"},
"daboecia":	{"NN"},
"dabs":	{"VBZ","NNS"},
"dacca":	{"NN"},
"dace":	{"NN","NNS"},
"dacelo":	{"NN"},
"dacha":	{"NN"},
"dachau":	{"NN"},
"dachshounds":	{"NNS"},
"dachshund":	{"NN"},
"dachsie":	{"NN"},
"dacite":	{"NN"},
"dacitic":	{"JJ"},
"dack-rihs":	{"NNS"},
"dacninae":	{"NN"},
"dacoit":	{"NN"},
"dacoity":	{"NN"},
"dacron":	{"NN"},
"dacrycarpus":	{"NNS"},
"dacrydium":	{"NN"},
"dacrymyces":	{"NN"},
"dacrymycetaceae":	{"NN"},
"dacryocyst":	{"NN"},
"dacryocystitis":	{"NNS"},
"dacryon":	{"NN"},
"dactyl":	{"NN"},
"dactylic":	{"JJ"},
"dactylis":	{"NN"},
"dactyloctenium":	{"NN"},
"dactylomegaly":	{"NN"},
"dactylopiidae":	{"NN"},
"dactylopius":	{"NNS"},
"dactylopteridae":	{"NN"},
"dactylopterus":	{"NN"},
"dactylorhiza":	{"NN"},
"dactyloscopidae":	{"NN"},
"dactyls":	{"NNS"},
"dad":	{"NN"},
"dada":	{"NN"},
"dadaism":	{"NN"},
"daddy":	{"NN"},
"dado":	{"NN"},
"dads":	{"NNS","VBZ"},
"dae-han-min-gook":	{"NN"},
"daedal":	{"JJ","NN"},
"daedalus":	{"NNS"},
"daemon":	{"NN"},
"daffo":	{"NN"},
"daffodil":	{"NN"},
"daffodils":	{"NNS"},
"dafla":	{"NN"},
"daft":	{"JJ","NN"},
"daftly":	{"RB"},
"daftness":	{"NN"},
"dag":	{"NN"},
"dagame":	{"NN"},
"dagan":	{"NN"},
"dagda":	{"NN"},
"dagers":	{"NNS"},
"dagestani":	{"NN"},
"dagga":	{"NN"},
"dagger":	{"NN"},
"dagger-like":	{"JJ"},
"daggerboard":	{"NN"},
"daggerman":	{"NN"},
"dago":	{"NN"},
"dagon":	{"NN"},
"daguerre":	{"NN"},
"daguerreotype":	{"NN"},
"daguerreotypes":	{"NNS"},
"dah":	{"NN"},
"dahl":	{"NN"},
"dahlia":	{"NN"},
"dahna":	{"NN"},
"dahomey":	{"NN"},
"daikon":	{"NN"},
"dail":	{"NN"},
"dailies":	{"NNS"},
"daily":	{"JJ","RB","NN"},
"daily-wear":	{"JJ"},
"daimler":	{"NN"},
"daimon":	{"NN"},
"dain-sponsored":	{"JJ"},
"daintily":	{"RB"},
"daintiness":	{"NN"},
"dainty":	{"JJ","NN"},
"dainty-legged":	{"JJ"},
"daiquiri":	{"NN"},
"dairen":	{"NN"},
"dairies":	{"NNS"},
"dairy":	{"NN"},
"dairy-oh":	{"NN"},
"dairying":	{"NN"},
"dairyland":	{"NN"},
"dairymaid":	{"NN"},
"dairyman":	{"NN"},
"dairymen":	{"NNS"},
"dais":	{"NN"},
"daises":	{"NNS"},
"daishiki":	{"NN"},
"daisies":	{"NNS"},
"daisy":	{"NN"},
"daisy-bush":	{"NN"},
"daisy-chain":	{"NN","VB","VBP"},
"daisy-chained":	{"VBD","VBN"},
"daisy-chaining":	{"VBG"},
"daisy-chains":	{"NNS","VBZ"},
"daisybush":	{"NN"},
"daisylike":	{"JJ"},
"dak":	{"NN"},
"dakar":	{"NN"},
"dakoit":	{"NN"},
"dakoity":	{"NN"},
"dakota":	{"NN"},
"dakotas":	{"NNS"},
"dal":	{"NN"},
"dalasi":	{"NN"},
"dalbergia":	{"NN"},
"dale":	{"NN"},
"dalea":	{"NN"},
"dales":	{"NNS"},
"dalesman":	{"NN"},
"daleth":	{"NN"},
"dali":	{"NN"},
"dali-esque":	{"JJ"},
"dalian":	{"NN"},
"dallas":	{"NNS"},
"dallas-based":	{"JJ"},
"dallas-headquartered":	{"JJ"},
"dalliance":	{"NN"},
"dalliances":	{"NNS"},
"dallied":	{"VBD","VBN"},
"dallier":	{"NN"},
"dallies":	{"VBZ"},
"dallisgrass":	{"NN"},
"dally":	{"VB","VBP"},
"dallying":	{"VBG"},
"dalmane":	{"NN"},
"dalmatia":	{"NN"},
"dalmatian":	{"JJ","NN"},
"dalo":	{"NN"},
"dalton":	{"NN"},
"daltonism":	{"NN"},
"dam":	{"NN","VBP","VB"},
"dama":	{"NN"},
"damage":	{"NN","VBP","VB"},
"damaged":	{"VBN","JJ","VBD"},
"damages":	{"NNS","VBZ"},
"damaging":	{"JJ","VBG"},
"damaliscus":	{"NNS"},
"damar":	{"NN"},
"damascene":	{"VB","VBP"},
"damascened":	{"VBD","VBN"},
"damascenes":	{"VBZ"},
"damascening":	{"VBG"},
"damascus":	{"NNS"},
"damask":	{"NN"},
"dame":	{"NN"},
"damed":	{"VBD","VBN"},
"damgalnunna":	{"NN"},
"daminozide":	{"NN"},
"damkina":	{"NN"},
"dammar":	{"NN"},
"dammed":	{"VBD","VBN"},
"dammed-up":	{"VBN"},
"damming":	{"VBG"},
"dammit":	{"UH"},
"damn":	{"VB","VBP","RB","JJ","NN","UH"},
"damn-the-torpedoes":	{"JJ"},
"damnable":	{"JJ"},
"damnably":	{"RB"},
"damnation":	{"NN","UH"},
"damnatory":	{"JJ"},
"damned":	{"RB","VBD","VBN","JJ","NNS"},
"damning":	{"JJ","VBG"},
"damnit":	{"UH"},
"damns":	{"VBZ"},
"damocles":	{"NNS"},
"damoiselle":	{"NN"},
"damon":	{"NN"},
"damosel":	{"NN"},
"damourite":	{"NN"},
"damozel":	{"NN"},
"damp":	{"JJ","VB","VBP","NN"},
"damped":	{"VBN","VBD"},
"dampen":	{"VB","VBP"},
"dampened":	{"VBD","VBN"},
"dampener":	{"NN"},
"dampening":	{"VBG"},
"dampens":	{"VBZ"},
"damper":	{"NN","JJR"},
"dampers":	{"NNS"},
"dampest":	{"JJS"},
"damping":	{"VBG"},
"dampish":	{"NN"},
"damply":	{"RB"},
"dampness":	{"NN"},
"damps":	{"VBZ"},
"dams":	{"NNS","VBZ"},
"damsel":	{"NN"},
"damselfish":	{"NN"},
"damselfly":	{"NN"},
"damson":	{"NN"},
"danaea":	{"NN"},
"danaid":	{"NN"},
"danaidae":	{"NN"},
"danau":	{"NN"},
"danaus":	{"NN"},
"dance":	{"NN","VB","VBP"},
"dance-committee":	{"JJ"},
"dance-theatre":	{"JJ"},
"danceable":	{"JJ"},
"danced":	{"VBD","VBN"},
"dancelike":	{"JJ"},
"dancer":	{"NN"},
"dancers":	{"NNS"},
"dances":	{"NNS","VBZ"},
"dancing":	{"NN","VBG"},
"dancing-master":	{"NN"},
"dandelion":	{"NN"},
"dander":	{"NN"},
"dandified":	{"JJ"},
"dandify":	{"VB"},
"dandily":	{"RB"},
"dandle":	{"VB","VBP"},
"dandled":	{"VBD","VBN"},
"dandles":	{"VBZ"},
"dandling":	{"VBG"},
"dandruff":	{"NN"},
"dandy":	{"NN","JJ"},
"dandyish":	{"JJ"},
"dandyism":	{"NN"},
"dane":	{"NN"},
"danewort":	{"NN"},
"dang":	{"UH","JJ","RB","VB","VBP"},
"dangaleat":	{"NN"},
"danged":	{"VBD","VBN"},
"danger":	{"NN"},
"dangerous":	{"JJ"},
"dangerously":	{"RB"},
"dangerousness":	{"NN"},
"dangers":	{"NNS"},
"danging":	{"VBG"},
"dangla":	{"NN"},
"dangle":	{"VB","VBP"},
"dangle-berry":	{"NN"},
"dangleberry":	{"NN"},
"dangled":	{"VBD","VBN"},
"dangles":	{"VBZ"},
"dangling":	{"VBG"},
"dangs":	{"VBZ"},
"daniel":	{"NN"},
"dank":	{"JJ","NN"},
"dankness":	{"NN"},
"danmark":	{"NN"},
"dano-norwegian":	{"NN"},
"dans":	{"FW"},
"danseur":	{"NN"},
"danseuse":	{"NN"},
"dante":	{"NN"},
"dantean":	{"JJ"},
"dantesque":	{"JJ"},
"danton":	{"NN"},
"danu":	{"NN"},
"danube":	{"NN"},
"danubian":	{"JJ"},
"danzig":	{"NN"},
"daoism":	{"NN"},
"daphnia":	{"NN"},
"dapped":	{"VBD","VBN"},
"dapper":	{"JJ"},
"dapperness":	{"NN"},
"dapping":	{"VBG"},
"dapple":	{"VB","VBP"},
"dapple-gray":	{"NN"},
"dapple-grey":	{"NN","JJ"},
"dappled":	{"JJ","VBD","VBN"},
"dappled-gray":	{"NN"},
"dappled-grey":	{"NN"},
"dapples":	{"VBZ"},
"dappling":	{"VBG"},
"daps":	{"VBZ"},
"dapsang":	{"NN"},
"dapsone":	{"NN"},
"daraf":	{"NN"},
"darbuka":	{"NN"},
"darby":	{"NN"},
"darcy":	{"NN"},
"dard":	{"NN"},
"dardan":	{"NN"},
"dardanelles":	{"NNS"},
"dardanian":	{"NN"},
"dardanus":	{"NN"},
"dardic":	{"NN"},
"dare":	{"VB","VBP","NN","MD"},
"dared":	{"VBD","VBN"},
"daredevil":	{"NN","JJ"},
"daredevilry":	{"NN"},
"daredevils":	{"NNS"},
"daredeviltry":	{"NN"},
"dares":	{"VBZ","NNS"},
"daresay":	{"VB","VBP"},
"darfur":	{"NN"},
"dari":	{"NN"},
"daricon":	{"NN"},
"daring":	{"JJ","NN","VBG"},
"daringly":	{"RB"},
"darius":	{"NN"},
"darjeeling":	{"NN"},
"dark":	{"JJ","NN"},
"dark-blue":	{"JJ"},
"dark-brown":	{"JJ"},
"dark-coated":	{"JJ"},
"dark-colored":	{"JJ"},
"dark-coloured":	{"JJ"},
"dark-fruited":	{"JJ"},
"dark-gray":	{"JJ"},
"dark-green":	{"JJ"},
"dark-grey":	{"JJ"},
"dark-haired":	{"JJ"},
"dark-skinned":	{"JJ"},
"dark-spotted":	{"JJ"},
"dark-squared":	{"JJ"},
"darken":	{"VB","VBP"},
"darkened":	{"JJ","VBD","VBN"},
"darkening":	{"VBG"},
"darkens":	{"VBZ"},
"darker":	{"JJR"},
"darkest":	{"JJS"},
"darkey":	{"NN"},
"darkhaired":	{"JJ"},
"darkie":	{"NN"},
"darkish":	{"JJ"},
"darkling":	{"JJ","RB"},
"darkly":	{"RB"},
"darkness":	{"NN"},
"darkroom":	{"NN"},
"darky":	{"NN"},
"darling":	{"NN","JJ"},
"darlings":	{"NNS"},
"darlingtonia":	{"NN"},
"darmera":	{"NN"},
"darmstadtium":	{"NN"},
"darn":	{"UH","JJ","RB","VB","VBP","NN"},
"darned":	{"JJ","RB","VBD","VBN"},
"darnel":	{"NN"},
"darner":	{"NN"},
"darning":	{"NN","VBG"},
"darning-needle":	{"NN"},
"darns":	{"NNS","VBZ"},
"darpa":	{"NN"},
"darrell":	{"NN"},
"darrow":	{"NN"},
"darsana":	{"NN"},
"dart":	{"VB","VBP","NN"},
"dart-throwing":	{"NN"},
"dartboard":	{"NN"},
"dartboards":	{"NNS"},
"darted":	{"VBD","VBN"},
"darter":	{"NN"},
"darting":	{"VBG"},
"darts":	{"NNS","VBZ","NN"},
"darvon":	{"NN"},
"darwin":	{"NN"},
"darwinian":	{"JJ","NN"},
"darwinism":	{"NN"},
"das":	{"NN"},
"dash":	{"NN","VB"},
"dash-pot":	{"NN"},
"dashboard":	{"NN"},
"dashboards":	{"NNS"},
"dashcam":	{"NN"},
"dashcams":	{"NNS"},
"dashed":	{"JJ","VBD","VBN"},
"dasheen":	{"NN"},
"dashes":	{"NNS","VBZ"},
"dashiki":	{"NN"},
"dashing":	{"JJ","VBG"},
"dashingly":	{"RB"},
"dasht-e-kavir":	{"NN"},
"dasht-e-lut":	{"NN"},
"dassie":	{"NN"},
"dastard":	{"NN"},
"dastardliness":	{"NN"},
"dastardly":	{"JJ","RB"},
"dasyatidae":	{"NN"},
"dasyatis":	{"NNS"},
"dasymeter":	{"NN"},
"dasypodidae":	{"NN"},
"dasyprocta":	{"NN"},
"dasyproctidae":	{"NN"},
"dasypus":	{"NNS"},
"dasyure":	{"NN"},
"dasyurid":	{"NN"},
"dasyuridae":	{"NN"},
"dasyurus":	{"NN"},
"dat":	{"NN"},
"data":	{"NNS","NN"},
"data-base":	{"JJ","NN"},
"data-based":	{"JJ"},
"data-capture":	{"JJ"},
"data-collection":	{"NN"},
"data-communications":	{"NNS"},
"data-destroying":	{"JJ"},
"data-gathering":	{"JJ"},
"data-handling":	{"NN"},
"data-processing":	{"NN"},
"data-recording":	{"NN"},
"data-service":	{"JJ"},
"data-storage":	{"JJ","NN"},
"data-storing":	{"JJ"},
"data-transmission":	{"JJ","NN"},
"database":	{"NN"},
"databased":	{"VBD","VBN"},
"databases":	{"NNS","VBZ"},
"databasing":	{"VBG"},
"datable":	{"JJ"},
"datadex":	{"NN"},
"datasets":	{"NNS"},
"date":	{"NN","VBP","VB"},
"date-mark":	{"VB"},
"dateable":	{"JJ"},
"dated":	{"VBN","JJ","VBD"},
"dateless":	{"JJ"},
"dateline":	{"NN"},
"datelined":	{"VBN","VBD"},
"datemark":	{"VB"},
"dates":	{"NNS","VBZ"},
"dating":	{"VBG","NN"},
"dative":	{"NN","JJ"},
"datril":	{"NN"},
"datum":	{"NN"},
"datura":	{"NN"},
"daub":	{"VB","VBP","NN"},
"daubed":	{"VBD","VBN"},
"daubentonia":	{"NN"},
"daubentoniidae":	{"NN"},
"dauber":	{"NN"},
"daubers":	{"NNS"},
"daubing":	{"VBG"},
"daubs":	{"VBZ","NNS"},
"daucus":	{"NNS"},
"daugavpils":	{"NNS"},
"daughter":	{"NN"},
"daughter-in-law":	{"NN"},
"daughterly":	{"JJ"},
"daughters":	{"NNS"},
"daumier":	{"NN"},
"daunt":	{"VB","VBP"},
"daunted":	{"VBD","VBN"},
"daunting":	{"JJ","VBG"},
"dauntingly":	{"RB"},
"dauntless":	{"JJ"},
"dauntlessly":	{"RB"},
"dauntlessness":	{"NN"},
"daunts":	{"VBZ"},
"dauphin":	{"NN"},
"davallia":	{"NN"},
"davalliaceae":	{"NN"},
"davenport":	{"NN"},
"davies":	{"NN"},
"daviesia":	{"NN"},
"davis":	{"NNS"},
"davit":	{"NN"},
"davits":	{"NNS"},
"davy":	{"NN"},
"davys":	{"NNS"},
"daw":	{"NN"},
"dawah":	{"NN"},
"dawdle":	{"VB","VBP"},
"dawdled":	{"VBD","VBN"},
"dawdler":	{"NN"},
"dawdlers":	{"NNS"},
"dawdles":	{"VBZ"},
"dawdling":	{"VBG"},
"dawes":	{"NNS"},
"dawn":	{"NN","VB","VBP"},
"dawned":	{"VBD","VBN"},
"dawning":	{"VBG","NN"},
"dawns":	{"VBZ","NNS"},
"dawson":	{"NN"},
"day":	{"NN"},
"day-after-day":	{"JJ"},
"day-and-night":	{"JJ"},
"day-by-day":	{"JJ"},
"day-care":	{"JJ"},
"day-even":	{"NN"},
"day-long":	{"JJ"},
"day-old":	{"JJ"},
"day-to-day":	{"JJ"},
"day-today":	{"JJ"},
"day-tripper":	{"NN"},
"day-trippers":	{"NNS"},
"day-watch":	{"NN"},
"dayan":	{"NN"},
"daybed":	{"NN"},
"daybook":	{"NN"},
"dayboy":	{"NN"},
"daybreak":	{"NN"},
"daycare":	{"NN"},
"daydream":	{"VB","VBP","NN"},
"daydreamed":	{"VBD","VBN"},
"daydreamer":	{"NN"},
"daydreamers":	{"NNS"},
"daydreaming":	{"VBG"},
"daydreams":	{"VBZ","NNS"},
"dayflower":	{"NN"},
"dayfly":	{"NN"},
"daygirl":	{"NN"},
"daylight":	{"NN"},
"daylights":	{"NNS"},
"daylily":	{"RB"},
"daylong":	{"JJ","NN"},
"daypro":	{"NN"},
"days":	{"NNS"},
"dayspring":	{"NN"},
"daystar":	{"NN"},
"daytime":	{"JJ","NN"},
"dayton":	{"NN"},
"daze":	{"VB","NN"},
"dazed":	{"JJ","VBD","VBN"},
"dazedly":	{"RB"},
"dazes":	{"VBZ"},
"dazing":	{"VBG"},
"dazzle":	{"VB","VBP","NN"},
"dazzled":	{"VBD","VBN"},
"dazzler":	{"NN"},
"dazzles":	{"VBZ"},
"dazzling":	{"JJ","VBG"},
"dazzlingly":	{"RB"},
"db":	{"NN"},
"dba":	{"NN"},
"dbms":	{"NNS"},
"dc":	{"NN"},
"dccp":	{"NN"},
"dci":	{"NN"},
"dd":	{"NN"},
"ddc":	{"NN"},
"ddi":	{"NN"},
"dds":	{"NN"},
"ddt":	{"NN"},
"de-Americanization":	{"NN"},
"de-access":	{"VB"},
"de-aerate":	{"VB"},
"de-americanization":	{"NN"},
"de-emphases":	{"NNS"},
"de-emphasis":	{"NN"},
"de-emphasise":	{"VB","VBP"},
"de-emphasised":	{"VBD","VBN"},
"de-emphasises":	{"VBZ"},
"de-emphasising":	{"VBG"},
"de-emphasize":	{"VB","VBP"},
"de-emphasized":	{"VBD","VBN"},
"de-emphasizes":	{"VBZ"},
"de-emphasizing":	{"VBG"},
"de-energise":	{"VB"},
"de-energize":	{"VB"},
"de-escalate":	{"VB","VBP"},
"de-escalated":	{"VBD","VBN"},
"de-escalates":	{"VBZ"},
"de-escalating":	{"VBG"},
"de-escalation":	{"NN"},
"de-facto":	{"JJ"},
"de-ice":	{"VB","VBP","NN"},
"de-iced":	{"VBD","VBN"},
"de-ices":	{"VBZ"},
"de-icing":	{"VBG"},
"de-inking":	{"JJ"},
"de-iodinase":	{"NN"},
"de-iodinate":	{"VB"},
"de-iodinated":	{"VBN"},
"de-iodinating":	{"JJ"},
"de-iodination":	{"NN"},
"de-ionate":	{"VB"},
"de-linkage":	{"NN"},
"de-listed":	{"VBN"},
"de-nazification":	{"NN"},
"de-stalinisation":	{"NN"},
"de-stalinization":	{"NN"},
"de-stocking":	{"NN"},
"de-stress":	{"VB","VBP"},
"de-stressed":	{"VBD","VBN"},
"de-stresser":	{"NN"},
"de-stressers":	{"NNS"},
"de-stresses":	{"VBZ"},
"de-stressing":	{"VBG"},
"de-worse-ification":	{"NN"},
"dea":	{"NN"},
"deaccession":	{"VB","VBP"},
"deaccessioned":	{"VBD","VBN"},
"deaccessioning":	{"VBG"},
"deaccessions":	{"VBZ"},
"deacon":	{"NN"},
"deaconess":	{"NN"},
"deacons":	{"NNS"},
"deactivate":	{"VB","VBP"},
"deactivated":	{"VBN","VBD"},
"deactivates":	{"VBZ"},
"deactivating":	{"VBG"},
"deactivation":	{"NN"},
"dead":	{"JJ","NNS","RB"},
"dead-end":	{"VB","JJ"},
"dead-eyed":	{"JJ"},
"dead-man's-fingers":	{"NNS"},
"dead-men's-fingers":	{"NNS"},
"dead-on":	{"JJ"},
"dead-weight":	{"NN"},
"deadbeat":	{"NN","JJ"},
"deadbeats":	{"NNS"},
"deadbolt":	{"NN"},
"deaden":	{"VB","VBP"},
"deadened":	{"VBD","VBN"},
"deadening":	{"JJ","NN","VBG"},
"deadens":	{"VBZ"},
"deadeye":	{"NN"},
"deadhead":	{"NN","VB","VBP"},
"deadheaded":	{"VBD","VBN"},
"deadheading":	{"VBG"},
"deadheads":	{"NNS","VBZ"},
"deadlier":	{"JJR"},
"deadliest":	{"JJS"},
"deadlight":	{"NN"},
"deadline":	{"NN"},
"deadlines":	{"NNS"},
"deadliness":	{"NN"},
"deadlock":	{"NN","VB","VBP"},
"deadlocked":	{"VBD","VBN","JJ"},
"deadlocking":	{"VBG"},
"deadlocks":	{"VBZ"},
"deadly":	{"JJ","RB"},
"deadness":	{"NN"},
"deadpan":	{"JJ","RB","NN","VB","VBP"},
"deadpanned":	{"VBD","VBN"},
"deadpanning":	{"VBG"},
"deadpans":	{"VBZ","NNS"},
"deadweight":	{"NN"},
"deadwood":	{"NN"},
"deae-cellulose-treated":	{"NN"},
"deaerate":	{"VB"},
"deaf":	{"JJ","NN"},
"deaf-aid":	{"NN"},
"deaf-and-dumb":	{"JJ"},
"deaf-mute":	{"JJ","NN"},
"deaf-muteness":	{"NN"},
"deaf-mutism":	{"NN"},
"deafen":	{"VB","VBP"},
"deafened":	{"VBD","VBN"},
"deafening":	{"JJ","VBG"},
"deafeningly":	{"RB"},
"deafens":	{"VBZ"},
"deafness":	{"NN"},
"deal":	{"NN","VB","VBP"},
"deal-blocker":	{"NN"},
"deal-making":	{"NN"},
"dealer":	{"NN"},
"dealer-community":	{"JJ"},
"dealer-led":	{"JJ"},
"dealer-manager":	{"NN"},
"dealer-managers":	{"NNS"},
"dealer-related":	{"JJ"},
"dealer-to-dealer":	{"JJ","NN"},
"dealers":	{"NNS"},
"dealership":	{"NN"},
"dealerships":	{"NNS"},
"dealfish":	{"NN"},
"dealignment":	{"NN"},
"dealing":	{"VBG","NN"},
"dealings":	{"NNS"},
"dealmaker":	{"NN"},
"dealmakers":	{"NNS"},
"dealmaking":	{"NN"},
"deals":	{"NNS","VBZ"},
"dealt":	{"VBN","VBD"},
"deaminate":	{"VB"},
"deamination":	{"NN"},
"deaminization":	{"NN"},
"deaminize":	{"VB"},
"dean":	{"NN"},
"deanery":	{"NN"},
"deans":	{"NNS"},
"deanship":	{"NN"},
"dear":	{"JJ","NN","UH","RB"},
"dearer":	{"JJR"},
"dearest":	{"JJS","NN"},
"dearie":	{"NN"},
"dearly":	{"RB"},
"dearly-won":	{"JJ"},
"dearness":	{"NN"},
"dearth":	{"NN"},
"deary":	{"NN"},
"death":	{"NN"},
"death-backed":	{"JJ"},
"death-benefit":	{"JJ"},
"death-blow":	{"NN"},
"death-like":	{"JJ"},
"death-locked":	{"JJ"},
"death-mask":	{"NN"},
"death-masks":	{"NNS"},
"death-penalty":	{"NN"},
"death-rattle":	{"NN"},
"death-roll":	{"NN"},
"death-row":	{"NN"},
"death-sentence":	{"NN"},
"death-trap":	{"NN"},
"death-warrant":	{"NN"},
"death-wish":	{"NN"},
"deathbed":	{"NN"},
"deathbeds":	{"NNS"},
"deathblow":	{"NN"},
"deathday":	{"NN"},
"deathless":	{"JJ"},
"deathlier":	{"JJR"},
"deathliest":	{"JJS"},
"deathlike":	{"JJ"},
"deathly":	{"JJ","RB"},
"deathrate":	{"NN"},
"deaths":	{"NNS"},
"deathtrap":	{"NN"},
"deathward":	{"RB"},
"deathwatch":	{"NN"},
"deb":	{"NN"},
"debacle":	{"NN"},
"debacles":	{"NNS"},
"debar":	{"VB","VBP"},
"debark":	{"VB","VBP"},
"debarkation":	{"NN"},
"debarked":	{"VBD","VBN"},
"debarking":	{"VBG"},
"debarks":	{"VBZ"},
"debarment":	{"NN"},
"debarred":	{"VBD","VBN"},
"debarring":	{"VBG"},
"debars":	{"VBZ"},
"debase":	{"VB","VBP"},
"debased":	{"JJ","VBD","VBN"},
"debasement":	{"NN"},
"debaser":	{"NN"},
"debases":	{"VBZ"},
"debasing":	{"VBG"},
"debatable":	{"JJ"},
"debate":	{"NN","VB","VBP"},
"debated":	{"VBD","VBN"},
"debater":	{"NN"},
"debates":	{"NNS","VBZ"},
"debating":	{"NN","VBG"},
"debauch":	{"VB","VBP","NN"},
"debauched":	{"JJ","VBD","VBN"},
"debauchee":	{"NN"},
"debaucher":	{"NN"},
"debauchery":	{"NN"},
"debauches":	{"VBZ","NNS"},
"debauching":	{"VBG"},
"debbie":	{"NN"},
"debenture":	{"NN"},
"debentures":	{"NNS"},
"debile":	{"JJ"},
"debilitate":	{"VB","VBP"},
"debilitated":	{"JJ","VBD","VBN"},
"debilitates":	{"VBZ"},
"debilitating":	{"JJ","VBG"},
"debilitatingly":	{"RB"},
"debilitation":	{"NN"},
"debilitative":	{"JJ"},
"debility":	{"NN"},
"debit":	{"VB","VBP","NN"},
"debited":	{"VBD","VBN"},
"debiting":	{"VBG"},
"debitor":	{"NN"},
"debits":	{"VBZ","NNS"},
"debonair":	{"JJ"},
"debonaire":	{"JJ"},
"debone":	{"VB","NN"},
"deboned":	{"VBD","VBN"},
"debonnaire":	{"JJ"},
"debouch":	{"VB","VBP"},
"debouched":	{"VBD","VBN"},
"debouches":	{"VBZ"},
"debouching":	{"VBG"},
"debra":	{"NN"},
"debridement":	{"NN"},
"debrief":	{"VB","VBP"},
"debriefed":	{"VBD","VBN"},
"debriefing":	{"NN","VBG"},
"debriefings":	{"NNS"},
"debriefs":	{"VBZ"},
"debris":	{"NN"},
"debs":	{"NNS"},
"debt":	{"NN"},
"debt-burdened":	{"JJ"},
"debt-ceiling":	{"JJ","NN"},
"debt-coverage":	{"JJ"},
"debt-equity":	{"JJ","NN"},
"debt-financed":	{"JJ"},
"debt-financing":	{"JJ"},
"debt-for-environment":	{"NN"},
"debt-free":	{"JJ"},
"debt-futures":	{"NNS"},
"debt-happy":	{"JJ"},
"debt-heavy":	{"JJ"},
"debt-induced":	{"JJ"},
"debt-laden":	{"JJ"},
"debt-limit":	{"NN"},
"debt-payment":	{"JJ","NN"},
"debt-portfolio":	{"NN"},
"debt-rating":	{"JJ"},
"debt-reduction":	{"NN","JJ"},
"debt-relief":	{"NN"},
"debt-repayment":	{"NN"},
"debt-restructuring":	{"JJ"},
"debt-ridden":	{"JJ"},
"debt-riddled":	{"JJ"},
"debt-service":	{"JJ","NN"},
"debt-servicing":	{"NN"},
"debt-to-assets":	{"JJ"},
"debt-to-equity":	{"JJ","NN"},
"debtholder":	{"NN"},
"debtholders":	{"NNS"},
"debtor":	{"NN"},
"debtor-in-possession":	{"NN"},
"debtor-nation":	{"NN"},
"debtors":	{"NNS"},
"debts":	{"NNS"},
"debug":	{"VB","VBP"},
"debugged":	{"VBD","VBN"},
"debugger":	{"NN"},
"debugging":	{"VBG","NN"},
"debugs":	{"VBZ"},
"debunk":	{"VB","VBP"},
"debunked":	{"VBD","VBN"},
"debunker":	{"NN"},
"debunkers":	{"NNS"},
"debunking":	{"VBG"},
"debunks":	{"VBZ"},
"debussy":	{"NN"},
"debut":	{"NN","VB","VBP"},
"debutante":	{"NN"},
"debuted":	{"VBD","VBN"},
"debuting":	{"VBG"},
"debuts":	{"NNS","VBZ"},
"dec":	{"NN"},
"decade":	{"NN"},
"decade-long":	{"JJ"},
"decade-old":	{"JJ"},
"decadelong":	{"JJ"},
"decadence":	{"NN"},
"decadency":	{"NN"},
"decadent":	{"JJ","NN"},
"decades":	{"NNS"},
"decades-old":	{"JJ"},
"decadron":	{"NN"},
"decaf":	{"NN"},
"decaffeinate":	{"VB","VBP"},
"decaffeinated":	{"JJ","NN","VBD","VBN"},
"decaffeinates":	{"VBZ"},
"decaffeinating":	{"VBG"},
"decagon":	{"NN"},
"decagram":	{"NN"},
"decahedron":	{"NN"},
"decal":	{"NN"},
"decalcification":	{"NN"},
"decalcify":	{"VB"},
"decalcomania":	{"NN"},
"decalescence":	{"NN"},
"decalescent":	{"JJ"},
"decaliter":	{"NN"},
"decalitre":	{"NN"},
"decalogue":	{"NN"},
"decameter":	{"NN"},
"decametre":	{"NN"},
"decametrina":	{"NN"},
"decamp":	{"VB","VBP"},
"decamped":	{"VBD","VBN"},
"decamping":	{"VBG"},
"decampment":	{"NN"},
"decamps":	{"VBZ"},
"decant":	{"VB","VBP"},
"decantation":	{"NN"},
"decanted":	{"VBD","VBN"},
"decanter":	{"NN"},
"decanters":	{"NNS"},
"decanting":	{"VBG"},
"decants":	{"VBZ"},
"decapitalize":	{"VBP","VB"},
"decapitalized":	{"JJ"},
"decapitate":	{"VB","VBP"},
"decapitated":	{"VBD","VBN"},
"decapitates":	{"VBZ"},
"decapitating":	{"VBG"},
"decapitation":	{"NN"},
"decapitations":	{"NNS"},
"decapod":	{"NN"},
"decapoda":	{"NN"},
"decapterus":	{"NN"},
"decarbonate":	{"VB"},
"decarbonise":	{"VB"},
"decarbonize":	{"VB"},
"decarboxylase":	{"NN"},
"decarboxylate":	{"VB"},
"decarboxylation":	{"NN"},
"decarburise":	{"VB"},
"decarburize":	{"VB"},
"decarceration":	{"NN"},
"decasyllabic":	{"JJ"},
"decasyllable":	{"NN"},
"decathlon":	{"NN"},
"decatur":	{"NN"},
"decay":	{"VB","VBP","NN"},
"decayable":	{"JJ"},
"decayed":	{"JJ","VBD","VBN"},
"decaying":	{"VBG"},
"decays":	{"VBZ"},
"decease":	{"NN","VB","VBP"},
"deceased":	{"JJ","VBD","VBN","NN","NNS"},
"deceases":	{"VBZ"},
"deceasing":	{"VBG"},
"decedent":	{"NN"},
"deceit":	{"NN"},
"deceitful":	{"JJ"},
"deceitfully":	{"RB"},
"deceitfulness":	{"NN"},
"deceive":	{"VB","VBP"},
"deceived":	{"VBD","VBN"},
"deceiver":	{"NN"},
"deceivers":	{"NNS"},
"deceives":	{"VBZ"},
"deceiving":	{"VBG"},
"deceivingly":	{"RB"},
"decelerate":	{"VB","VBP"},
"decelerated":	{"VBD","VBN"},
"decelerates":	{"VBZ"},
"decelerating":	{"VBG"},
"deceleration":	{"NN"},
"december":	{"NN"},
"decencies":	{"NNS"},
"decency":	{"NN"},
"decennary":	{"NN"},
"decennium":	{"NN"},
"decent":	{"JJ"},
"decentalisation":	{"NN"},
"decently":	{"RB"},
"decentralisation":	{"NN"},
"decentralise":	{"VB","VBP"},
"decentralised":	{"JJ","VBD","VBN"},
"decentralises":	{"VBZ"},
"decentralising":	{"VBG"},
"decentralization":	{"NN"},
"decentralize":	{"VB","VBP"},
"decentralized":	{"JJ","VBD","VBN"},
"decentralizes":	{"VBZ"},
"decentralizing":	{"VBG"},
"deception":	{"NN"},
"deceptive":	{"JJ"},
"deceptively":	{"RB"},
"deceptiveness":	{"NN"},
"decerebrate":	{"VB","VBP","JJ","NN"},
"decerebrated":	{"VBD","VBN"},
"decerebrates":	{"VBZ","NNS"},
"decerebrating":	{"VBG"},
"decerebration":	{"NN"},
"decertification":	{"NN"},
"decertified":	{"VBD","VBN"},
"decertifies":	{"VBZ"},
"decertify":	{"VB","VBP"},
"decertifying":	{"VBG"},
"dechlorinate":	{"VB"},
"decibel":	{"NN"},
"decide":	{"VB","VBP"},
"decided":	{"VBD","VBN","JJ"},
"decidedly":	{"RB"},
"decidely":	{"RB"},
"decides":	{"VBZ"},
"deciding":	{"VBG","JJ"},
"decidua":	{"NN"},
"deciduous":	{"JJ"},
"decigram":	{"NN"},
"decile":	{"NN"},
"deciliter":	{"NN"},
"decilitre":	{"NN"},
"decimal":	{"JJ","NN"},
"decimalisation":	{"NN"},
"decimalise":	{"VB"},
"decimalization":	{"NN"},
"decimalize":	{"VB"},
"decimalized":	{"VBD","VBN"},
"decimalizes":	{"VBZ"},
"decimalizing":	{"VBG"},
"decimals":	{"NNS"},
"decimate":	{"VB","VBP"},
"decimated":	{"VBD","VBN"},
"decimates":	{"VBZ"},
"decimating":	{"VBG"},
"decimation":	{"NN"},
"decimeter":	{"NN"},
"decimeter-wave-length":	{"NN"},
"decimetre":	{"NN"},
"decions":	{"NNS"},
"decipher":	{"VB","VBP"},
"decipherable":	{"JJ"},
"decipherably":	{"RB"},
"deciphered":	{"VBD","VBN"},
"decipherer":	{"NN"},
"deciphering":	{"VBG"},
"decipherment":	{"NN"},
"deciphers":	{"VBZ"},
"decision":	{"NN"},
"decision-maker":	{"NN"},
"decision-makers":	{"NNS"},
"decision-making":	{"NN","JJ"},
"decisional":	{"JJ"},
"decisioned":	{"VBD","VBN"},
"decisioning":	{"VBG"},
"decisionmaking":	{"NN"},
"decisions":	{"NNS","VBZ"},
"decisis":	{"FW"},
"decisive":	{"JJ"},
"decisively":	{"RB"},
"decisiveness":	{"NN"},
"decius":	{"NNS"},
"deck":	{"NN","VB","VBP"},
"deck-chair":	{"NN"},
"deck-chairs":	{"NNS"},
"deck-hand":	{"NN"},
"deck-hands":	{"NNS"},
"deck-house":	{"NN"},
"decked":	{"VBN","VBD"},
"decker":	{"NN"},
"deckhand":	{"NN"},
"deckhands":	{"NNS"},
"decking":	{"NN","VBG"},
"deckle":	{"NN"},
"deckle-edged":	{"JJ"},
"decks":	{"NNS","VBZ"},
"declaim":	{"VB","VBP"},
"declaimed":	{"VBD","VBN"},
"declaiming":	{"VBG"},
"declaims":	{"VBZ"},
"declamation":	{"NN"},
"declamatory":	{"JJ"},
"declarable":	{"JJ"},
"declaration":	{"NN"},
"declarations":	{"NNS"},
"declarative":	{"JJ"},
"declaratory":	{"JJ"},
"declare":	{"VB","VBP"},
"declared":	{"VBD","VBN","JJ"},
"declarer":	{"NN"},
"declares":	{"VBZ"},
"declaring":	{"VBG"},
"declasse":	{"JJ"},
"declassed":	{"VBD","VBN"},
"declasses":	{"VBZ"},
"declassification":	{"NN"},
"declassified":	{"VBD","VBN","JJ"},
"declassifies":	{"VBZ"},
"declassify":	{"VB","VBP"},
"declassifying":	{"VBG"},
"declassing":	{"VBG"},
"declaw":	{"VB"},
"declension":	{"NN"},
"declination":	{"NN"},
"declinations":	{"NNS"},
"decline":	{"NN","VB","VBP"},
"declined":	{"VBD","VBN"},
"decliners":	{"NNS"},
"declines":	{"NNS","VBZ"},
"declining":	{"VBG","JJ"},
"declinometer":	{"NN"},
"declivitous":	{"JJ"},
"declivity":	{"NN"},
"declomycin":	{"NN"},
"declutch":	{"VB","VBP"},
"declutched":	{"VBD","VBN"},
"declutches":	{"VBZ"},
"declutching":	{"VBG"},
"declutter":	{"VB","VBP"},
"decluttered":	{"VBD","VBN"},
"decluttering":	{"VBG"},
"declutters":	{"VBZ"},
"deco":	{"NN"},
"decoagulant":	{"NN"},
"decoct":	{"VB"},
"decocted":	{"VBD","VBN"},
"decocting":	{"VBG"},
"decoction":	{"NN"},
"decocts":	{"VBZ"},
"decode":	{"VB","VBP"},
"decoded":	{"VBD","VBN"},
"decoder":	{"NN"},
"decoders":	{"NNS"},
"decodes":	{"VBZ"},
"decoding":	{"VBG"},
"decoke":	{"VB"},
"decollate":	{"VB"},
"decolletage":	{"NN"},
"decollete":	{"JJ"},
"decolonisation":	{"NN"},
"decolonise":	{"VB","VBP"},
"decolonised":	{"VBD","VBN"},
"decolonises":	{"VBZ"},
"decolonising":	{"VBG"},
"decolonization":	{"NN"},
"decolonize":	{"VB","VBP"},
"decolonized":	{"VBD","VBN"},
"decolonizes":	{"VBZ"},
"decolonizing":	{"VBG"},
"decolor":	{"VB"},
"decolored":	{"VBD","VBN"},
"decoloring":	{"VBG"},
"decolorise":	{"VB"},
"decolorize":	{"VB"},
"decolors":	{"VBZ"},
"decolour":	{"VB"},
"decolourise":	{"VB"},
"decolourize":	{"VB"},
"decommission":	{"VB","VBP"},
"decommissioned":	{"VBD","VBN"},
"decommissioning":	{"VBG"},
"decommissions":	{"VBZ"},
"decommissoned":	{"JJ"},
"decomposable":	{"JJ"},
"decompose":	{"VB","VBP"},
"decomposed":	{"JJ","VBD","VBN"},
"decomposes":	{"VBZ"},
"decomposing":	{"VBG"},
"decomposition":	{"NN"},
"decompositional":	{"JJ"},
"decompound":	{"JJ"},
"decompress":	{"VB","VBP"},
"decompressed":	{"VBD","VBN"},
"decompresses":	{"VBZ"},
"decompressing":	{"VBG"},
"decompression":	{"NN"},
"deconcentrate":	{"VB","VBP"},
"deconcentrated":	{"VBD","VBN"},
"deconcentrates":	{"VBZ"},
"deconcentrating":	{"VBG"},
"deconfliction":	{"NN"},
"decongestant":	{"NN"},
"deconsecrate":	{"VB","VBP"},
"deconsecrated":	{"VBD","VBN"},
"deconsecrates":	{"VBZ"},
"deconsecrating":	{"VBG"},
"deconstruct":	{"VB","VBP"},
"deconstructed":	{"VBD","VBN","JJ"},
"deconstructing":	{"VBG"},
"deconstruction":	{"NN"},
"deconstructionism":	{"NN"},
"deconstructionist":	{"NN"},
"deconstructivism":	{"NN"},
"deconstructs":	{"VBZ"},
"decontaminate":	{"VB","VBP"},
"decontaminated":	{"VBD","VBN"},
"decontaminates":	{"VBZ"},
"decontaminating":	{"VBG"},
"decontamination":	{"NN"},
"decontrol":	{"VB","VBP","NN"},
"decontrolled":	{"VBD","VBN"},
"decontrolling":	{"VBG"},
"decontrols":	{"VBZ","NNS"},
"decor":	{"NN"},
"decorate":	{"VB","VBP"},
"decorated":	{"VBN","VBD"},
"decorates":	{"VBZ"},
"decorating":	{"NN","VBG"},
"decoration":	{"NN"},
"decorations":	{"NNS"},
"decorative":	{"JJ"},
"decoratively":	{"RB"},
"decorativeness":	{"NN"},
"decorator":	{"NN"},
"decorators":	{"NNS"},
"decorous":	{"JJ"},
"decorously":	{"RB"},
"decorousness":	{"NN"},
"decorticate":	{"VB","VBP"},
"decorticated":	{"VBN","VBD"},
"decorticates":	{"VBZ"},
"decorticating":	{"VBG"},
"decortication":	{"NN"},
"decorticator":	{"NN"},
"decorum":	{"NN"},
"decoupage":	{"NN"},
"decouple":	{"VB","VBP"},
"decoupled":	{"VBD","VBN"},
"decouples":	{"VBZ"},
"decoupling":	{"VBG"},
"decoy":	{"NN","VB","VBP"},
"decoyed":	{"VBD","VBN"},
"decoying":	{"VBG"},
"decoys":	{"NNS","VBZ"},
"decrease":	{"VB","VBP","NN"},
"decreased":	{"VBD","VBN"},
"decreases":	{"NNS","VBZ"},
"decreasing":	{"JJ","VBG"},
"decree":	{"NN","VB","VBP"},
"decreed":	{"VBD","VBN"},
"decreeing":	{"NN","VBG"},
"decrees":	{"NNS","VBZ"},
"decrement":	{"NN"},
"decrepit":	{"JJ","NN"},
"decrepitate":	{"VB"},
"decrepitation":	{"NN"},
"decrepitude":	{"NN"},
"decrescendo":	{"NN"},
"decried":	{"VBD","VBN"},
"decries":	{"VBZ","NNS"},
"decriminalisation":	{"NN"},
"decriminalise":	{"VB","VBP"},
"decriminalised":	{"VBD","VBN"},
"decriminalises":	{"VBZ"},
"decriminalising":	{"VBG"},
"decriminalization":	{"NN"},
"decriminalize":	{"VB","VBP"},
"decriminalized":	{"VBD","VBN"},
"decriminalizes":	{"VBZ"},
"decriminalizing":	{"VBG"},
"decry":	{"VB","VBP"},
"decrying":	{"VBG"},
"decrypt":	{"VB","VBP"},
"decrypted":	{"VBD","VBN"},
"decrypting":	{"VBG"},
"decryption":	{"NN"},
"decrypts":	{"VBZ"},
"decubitus":	{"NN"},
"decumaria":	{"NN"},
"decumary":	{"NN"},
"decumbent":	{"JJ"},
"decurved":	{"JJ"},
"decussate":	{"JJ","VB"},
"decussation":	{"NN"},
"ded":	{"NN"},
"dedicate":	{"VB","VBP"},
"dedicated":	{"VBN","JJ","VBD"},
"dedicates":	{"VBZ"},
"dedicating":	{"VBG"},
"dedication":	{"NN"},
"dedications":	{"NNS"},
"dedifferentiate":	{"VB"},
"dedifferentiated":	{"JJ"},
"dedifferentiation":	{"NN"},
"deduce":	{"VB","VBP"},
"deduced":	{"VBD","VBN"},
"deduces":	{"VBZ"},
"deducible":	{"JJ"},
"deducing":	{"VBG"},
"deduct":	{"VB","VBP"},
"deducted":	{"VBD","VBN"},
"deductibility":	{"NN"},
"deductible":	{"JJ"},
"deducting":	{"VBG"},
"deduction":	{"NN"},
"deductions":	{"NNS"},
"deductive":	{"JJ"},
"deducts":	{"VBZ"},
"deed":	{"VB","NN"},
"deedbox":	{"NN"},
"deeded":	{"VBD","VBN"},
"deeding":	{"VBG"},
"deeds":	{"VB","JJ","NN","VBZ","NNS"},
"deem":	{"VB","VBP"},
"deemed":	{"VBN","VBD"},
"deeming":	{"VBG"},
"deems":	{"VBZ"},
"deep":	{"JJ","RB","NN"},
"deep-chested":	{"JJ"},
"deep-discount":	{"JJ"},
"deep-dye":	{"VB"},
"deep-eyed":	{"JJ"},
"deep-fat-fry":	{"VB"},
"deep-freeze":	{"NN"},
"deep-fried":	{"VBD","VBN"},
"deep-fries":	{"VBZ"},
"deep-fry":	{"VB","VBP"},
"deep-frying":	{"VBG"},
"deep-laid":	{"JJ"},
"deep-lobed":	{"JJ"},
"deep-mined":	{"JJ"},
"deep-pink":	{"JJ"},
"deep-pocket":	{"JJ"},
"deep-pocketed":	{"JJ"},
"deep-rooted":	{"JJ"},
"deep-sea":	{"JJ"},
"deep-seated":	{"JJ"},
"deep-set":	{"JJ"},
"deep-six":	{"VB","VBP"},
"deep-sixed":	{"VBD","VBN"},
"deep-sixes":	{"VBZ"},
"deep-sixing":	{"VBG"},
"deep-sounding":	{"JJ"},
"deep-space":	{"JJ"},
"deep-tendon":	{"NN"},
"deep-water":	{"JJ"},
"deep-yellow":	{"JJ"},
"deepen":	{"VB","VBP"},
"deepened":	{"VBD","VBN"},
"deepening":	{"VBG"},
"deepens":	{"VBZ"},
"deeper":	{"JJR","RBR"},
"deepest":	{"JJS","RBS"},
"deepfreeze":	{"NN"},
"deeply":	{"RB"},
"deepness":	{"NN"},
"deer":	{"NN","NNS"},
"deer's-ear":	{"NN"},
"deer's-ears":	{"NNS"},
"deer-are-long-legged-rats-with-big-ears":	{"JJ"},
"deer-handling":	{"NN"},
"deer-killing":	{"NN"},
"deerberry":	{"NN"},
"deere":	{"NN","JJ"},
"deerfield":	{"NN"},
"deerhound":	{"NN"},
"deerskin":	{"NN"},
"deerskins":	{"NNS"},
"deerstalker":	{"NN"},
"deerstalkers":	{"NNS"},
"deerstalking":	{"NN"},
"deets":	{"NNS"},
"deface":	{"VB","VBP"},
"defaced":	{"VBD","VBN"},
"defacement":	{"NN"},
"defaces":	{"VBZ"},
"defacing":	{"VBG"},
"defalcate":	{"VB"},
"defalcation":	{"NN"},
"defalcator":	{"NN"},
"defamation":	{"NN"},
"defamatory":	{"JJ"},
"defame":	{"VB","VBP"},
"defamed":	{"VBD","VBN"},
"defamer":	{"NN"},
"defames":	{"VBZ"},
"defaming":	{"VBG"},
"defang":	{"VB","NN"},
"defat":	{"VB","VBP"},
"defats":	{"VBZ"},
"defatted":	{"VBD","VBN"},
"defatting":	{"VBG"},
"default":	{"NN","VB","VBP"},
"defaulted":	{"VBD","VBN"},
"defaulter":	{"NN"},
"defaulters":	{"NNS"},
"defaulting":	{"VBG"},
"defaults":	{"NNS","VBZ"},
"defeasible":	{"JJ"},
"defeat":	{"NN","VB","VBP"},
"defeatable":	{"JJ"},
"defeated":	{"VBD","VBN","JJ"},
"defeating":	{"VBG"},
"defeatism":	{"NN"},
"defeatist":	{"NN","JJ"},
"defeatists":	{"NNS"},
"defeats":	{"VBZ","NNS"},
"defecate":	{"VB","NN","VBP"},
"defecated":	{"VBD","VBN"},
"defecates":	{"VBZ"},
"defecating":	{"VBG"},
"defecation":	{"NN"},
"defecator":	{"NN"},
"defect":	{"NN","VB","VBP"},
"defected":	{"VBD","VBN"},
"defecting":	{"VBG"},
"defection":	{"NN"},
"defections":	{"NNS"},
"defective":	{"JJ"},
"defectively":	{"RB"},
"defectiveness":	{"NN"},
"defector":	{"NN"},
"defectors":	{"NNS"},
"defects":	{"NNS","VBZ"},
"defects-office":	{"NN"},
"defeminise":	{"VB"},
"defeminize":	{"VB"},
"defence":	{"NN"},
"defenceless":	{"JJ","RB"},
"defencelessly":	{"RB"},
"defencelessness":	{"NN"},
"defend":	{"VB","VBP"},
"defendable":	{"JJ"},
"defendant":	{"NN"},
"defendants":	{"NNS"},
"defended":	{"VBD","VBN"},
"defender":	{"NN"},
"defenders":	{"NNS"},
"defending":	{"VBG"},
"defends":	{"VBZ"},
"defenestrate":	{"VB"},
"defenestration":	{"NN"},
"defense":	{"NN"},
"defense-appropriations":	{"JJ"},
"defense-authorization":	{"NN"},
"defense-budget":	{"NN"},
"defense-contract":	{"NN"},
"defense-electronics":	{"NNS","JJ"},
"defense-equipment":	{"JJ"},
"defense-industry":	{"JJ","NN"},
"defense-oriented":	{"JJ"},
"defense-procurement":	{"NN"},
"defense-products":	{"NNS"},
"defense-related":	{"JJ"},
"defense-suppression":	{"NN"},
"defensed":	{"VBD","VBN"},
"defenseless":	{"JJ","NN"},
"defenselessly":	{"RB"},
"defenselessness":	{"NN"},
"defenseman":	{"NN"},
"defensemen":	{"NNS"},
"defenses":	{"NNS","VBZ"},
"defensibility":	{"NN"},
"defensible":	{"JJ"},
"defensing":	{"VBG"},
"defensive":	{"JJ","NN"},
"defensively":	{"RB"},
"defensiveness":	{"NN"},
"defer":	{"VB","VBP"},
"deference":	{"NN"},
"deferent":	{"JJ"},
"deferential":	{"JJ"},
"deferentially":	{"RB"},
"deferment":	{"NN"},
"deferments":	{"NNS"},
"deferral":	{"NN"},
"deferrals":	{"NNS"},
"deferred":	{"JJ","VBD","VBN"},
"deferred-maintenance":	{"JJ"},
"deferring":	{"VBG"},
"defers":	{"VBZ"},
"defervesce":	{"VB","VBP"},
"defervesced":	{"VBD","VBN"},
"defervescence":	{"NN"},
"defervescent":	{"JJ"},
"defervesces":	{"VBZ"},
"defervescing":	{"VBG"},
"defiance":	{"NN"},
"defiant":	{"JJ","NN"},
"defiantly":	{"RB"},
"defibrillate":	{"VB","VBP"},
"defibrillated":	{"VBD","VBN"},
"defibrillates":	{"VBZ"},
"defibrillating":	{"VBG"},
"defibrillation":	{"NN"},
"defibrillative":	{"JJ"},
"defibrillator":	{"NN"},
"defibrillatory":	{"JJ"},
"defibrinate":	{"VB"},
"deficiencies":	{"NNS"},
"deficiency":	{"NN"},
"deficient":	{"JJ","NN"},
"deficit":	{"NN"},
"deficit-cutting":	{"JJ","NN"},
"deficit-debt":	{"NN"},
"deficit-inflation-capital-flight":	{"JJ"},
"deficit-racked":	{"JJ"},
"deficit-reduction":	{"NN","JJ"},
"deficit-ridden":	{"JJ"},
"deficitcutting":	{"NN"},
"deficits":	{"NNS"},
"defied":	{"VBD","VBN"},
"defies":	{"VBZ"},
"defilade":	{"NN"},
"defile":	{"VB","VBP","NN"},
"defiled":	{"VBD","VBN"},
"defilement":	{"NN"},
"defiler":	{"NN"},
"defiles":	{"VBZ","NNS"},
"defiling":	{"VBG"},
"definable":	{"JJ"},
"define":	{"VB","VBP"},
"defined":	{"VBN","VBD","JJ"},
"defined-benefit":	{"JJ"},
"defined-contribution":	{"NN"},
"defines":	{"VBZ"},
"defining":	{"VBG"},
"definite":	{"JJ"},
"definitely":	{"RB"},
"definiteness":	{"NN"},
"definition":	{"NN"},
"definition-specialization":	{"JJ","NN"},
"definitional":	{"JJ"},
"definitions":	{"NNS"},
"definitive":	{"JJ"},
"definitively":	{"RB"},
"deflagrate":	{"VB"},
"deflagration":	{"NN"},
"deflate":	{"VB","VBP"},
"deflated":	{"VBD","VBN","JJ"},
"deflates":	{"VBZ"},
"deflating":	{"VBG"},
"deflation":	{"NN"},
"deflationary":	{"JJ"},
"deflationist":	{"NN"},
"deflator":	{"NN"},
"deflators":	{"NNS"},
"deflect":	{"VB","VBP"},
"deflected":	{"VBD","VBN"},
"deflecting":	{"VBG"},
"deflection":	{"NN"},
"deflections":	{"NNS"},
"deflective":	{"JJ"},
"deflector":	{"NN"},
"deflects":	{"VBZ"},
"deflexion":	{"NN"},
"defloration":	{"NN"},
"deflower":	{"VB","VBP"},
"deflowered":	{"VBD","VBN"},
"deflowering":	{"VBG"},
"deflowers":	{"VBZ"},
"defocusing":	{"VBG"},
"defoe":	{"NN"},
"defog":	{"VB","VBP"},
"defogged":	{"VBD","VBN"},
"defogging":	{"VBG"},
"defogs":	{"VBZ"},
"defoliant":	{"NN"},
"defoliate":	{"VB","VBP","NN"},
"defoliated":	{"VBD","VBN"},
"defoliates":	{"VBZ"},
"defoliating":	{"VBG"},
"defoliation":	{"NN"},
"defoliator":	{"NN"},
"deforest":	{"VB","VBP"},
"deforestation":	{"NN"},
"deforested":	{"VBD","VBN"},
"deforesting":	{"VBG"},
"deforests":	{"VBZ"},
"deform":	{"VB","VBP"},
"deformation":	{"NN"},
"deformational":	{"JJ"},
"deformed":	{"JJ","VBD","VBN"},
"deforming":	{"VBG"},
"deformities":	{"NNS"},
"deformity":	{"NN"},
"deforms":	{"VBZ"},
"defraud":	{"VB","VBP"},
"defrauded":	{"VBD","VBN"},
"defrauder":	{"NN"},
"defrauding":	{"VBG"},
"defrauds":	{"VBZ"},
"defray":	{"VB","VBP"},
"defrayal":	{"NN"},
"defrayed":	{"VBD","VBN"},
"defraying":	{"VBG"},
"defrayment":	{"NN"},
"defrays":	{"VBZ"},
"defriend":	{"VB","VBP"},
"defriended":	{"VBD","VBN"},
"defriending":	{"VBG"},
"defriends":	{"VBZ"},
"defrock":	{"VB","VBP"},
"defrocked":	{"VBD","VBN","JJ"},
"defrocking":	{"VBG"},
"defrocks":	{"VBZ"},
"defrost":	{"VB","VBP"},
"defrosted":	{"VBD","VBN"},
"defroster":	{"NN"},
"defrosting":	{"VBG"},
"defrosts":	{"VBZ"},
"deft":	{"JJ","NN"},
"deftly":	{"RB"},
"deftness":	{"NN"},
"defunct":	{"JJ","NN"},
"defunctness":	{"NN"},
"defunded":	{"VBN"},
"defuse":	{"VB","VBP"},
"defused":	{"VBD","VBN"},
"defuses":	{"VBZ"},
"defusing":	{"VBG"},
"defy":	{"VB","VBP"},
"defying":	{"VBG"},
"degage":	{"JJ"},
"degas":	{"NNS","VB"},
"degases":	{"VBZ"},
"degassed":	{"VBN","VBD"},
"degasses":	{"VBZ"},
"degassing":	{"VBG"},
"degauss":	{"VB"},
"degaussing":	{"NN"},
"degeneracy":	{"NN"},
"degenerate":	{"VB","VBP","JJ","NN"},
"degenerated":	{"VBD","VBN"},
"degenerates":	{"VBZ","NNS"},
"degenerating":	{"VBG"},
"degeneration":	{"NN"},
"degenerative":	{"JJ"},
"deglaze":	{"VB","VBP"},
"deglazed":	{"VBD","VBN"},
"deglazes":	{"VBZ"},
"deglazing":	{"VBG"},
"deglutition":	{"NN"},
"deglycerolise":	{"VB"},
"deglycerolize":	{"VB"},
"deglycerolized":	{"VBN"},
"degradable":	{"JJ"},
"degradation":	{"NN"},
"degradations":	{"NNS"},
"degrade":	{"VB","VBP"},
"degraded":	{"VBD","VBN","JJ"},
"degrader":	{"NN"},
"degrades":	{"VBZ"},
"degrading":	{"JJ","VBG"},
"degrease":	{"VB","VBP"},
"degreased":	{"VBD","VBN"},
"degreaser":	{"NN"},
"degreases":	{"VBZ"},
"degreasing":	{"VBG"},
"degree":	{"NN"},
"degree-granting":	{"JJ"},
"degrees":	{"NNS"},
"degressive":	{"JJ"},
"degust":	{"VB"},
"degustation":	{"NN"},
"dehisce":	{"VB"},
"dehiscence":	{"NN"},
"dehiscent":	{"JJ"},
"dehorn":	{"VB"},
"dehumanisation":	{"NN"},
"dehumanise":	{"VB","VBP"},
"dehumanised":	{"VBD","VBN"},
"dehumanises":	{"VBZ"},
"dehumanising":	{"VBG"},
"dehumanization":	{"NN"},
"dehumanize":	{"VB","VBP"},
"dehumanized":	{"VBD","VBN"},
"dehumanizes":	{"VBZ"},
"dehumanizing":	{"VBG","JJ"},
"dehumidified":	{"VBD","VBN","JJ"},
"dehumidify":	{"VB"},
"dehydrate":	{"VB","VBP"},
"dehydrated":	{"JJ","VBD","VBN"},
"dehydrates":	{"VBZ"},
"dehydrating":	{"VBG"},
"dehydration":	{"NN"},
"dehydrogenate":	{"VB"},
"dehydroretinol":	{"NN"},
"dei":	{"NNP","FW"},
"deice":	{"VB"},
"deicer":	{"NN"},
"deictic":	{"JJ","NN"},
"deific":	{"JJ"},
"deification":	{"NN"},
"deified":	{"VBD","VBN"},
"deifies":	{"VBZ"},
"deify":	{"VB","VBP"},
"deifying":	{"VBG"},
"deign":	{"VB","VBP"},
"deigned":	{"VBD","VBN"},
"deigning":	{"VBG"},
"deigns":	{"VBZ"},
"deimos":	{"NNS"},
"deinocheirus":	{"NN"},
"deinonychus":	{"NNS"},
"deinstitutionalization":	{"NN"},
"deionize":	{"VB"},
"deipnosophist":	{"NN"},
"deism":	{"NN"},
"deist":	{"NN"},
"deistic":	{"JJ"},
"deities":	{"NNS"},
"deity":	{"NN"},
"deixis":	{"NNS"},
"deja":	{"NN"},
"deject":	{"VB"},
"dejected":	{"JJ","VBD","VBN"},
"dejectedly":	{"RB"},
"dejectedness":	{"NN"},
"dejecting":	{"VBG"},
"dejection":	{"NN"},
"dejects":	{"VBZ"},
"dejeuner":	{"NN"},
"dejeuners":	{"FW"},
"dekagram":	{"NN"},
"dekaliter":	{"NN"},
"dekalitre":	{"NN"},
"dekameter":	{"NN"},
"dekametre":	{"NN"},
"dekker":	{"NN"},
"dekko":	{"NN"},
"del":	{"NNP","FW"},
"delacroix":	{"NN"},
"delairea":	{"NN"},
"delavirdine":	{"NN"},
"delaware":	{"NN"},
"delaware-based":	{"JJ"},
"delawarean":	{"NN"},
"delawares":	{"NNS"},
"delawarian":	{"NN"},
"delay":	{"NN","VB","VBP"},
"delayed":	{"VBN","VBD","JJ"},
"delayed-action":	{"JJ"},
"delayer":	{"NN"},
"delaying":	{"VBG","NN"},
"delays":	{"NNS","VBZ"},
"delbruck":	{"NN"},
"delectability":	{"NN"},
"delectable":	{"JJ"},
"delectably":	{"RB"},
"delectation":	{"NN"},
"delegacy":	{"NN"},
"delegate":	{"NN","VB","VBP"},
"delegated":	{"VBD","VBN"},
"delegates":	{"NNS","VBZ"},
"delegating":	{"VBG"},
"delegation":	{"NN"},
"delegations":	{"NNS"},
"delegee":	{"NN"},
"delegees":	{"NNS"},
"delenda":	{"FW"},
"delete":	{"VB","VBP"},
"deleted":	{"VBD","VBN"},
"deleterious":	{"JJ"},
"deleteriously":	{"RB"},
"deletes":	{"VBZ"},
"deleting":	{"VBG"},
"deletion":	{"NN"},
"deletions":	{"NNS"},
"deleverage":	{"VB","VBP"},
"deleveraged":	{"VBD","VBN"},
"deleverages":	{"VBZ"},
"deleveraging":	{"VBG","NN"},
"delf":	{"NN"},
"delft":	{"NN"},
"delhi":	{"NN"},
"deli":	{"NN"},
"deliberate":	{"JJ","VB","VBP"},
"deliberated":	{"VBD","VBN"},
"deliberately":	{"RB"},
"deliberateness":	{"NN"},
"deliberates":	{"VBZ"},
"deliberating":	{"VBG"},
"deliberation":	{"NN"},
"deliberations":	{"NNS"},
"deliberative":	{"JJ","NN"},
"delibes":	{"NNS"},
"delible":	{"JJ"},
"delicacies":	{"NNS"},
"delicacy":	{"NN"},
"delicate":	{"JJ"},
"delicate-beyond-description":	{"JJ"},
"delicately":	{"RB"},
"delicately-textured":	{"JJ"},
"delicatessen":	{"NN"},
"delichon":	{"NN"},
"delicious":	{"JJ"},
"deliciously":	{"RB"},
"deliciousness":	{"NN"},
"delicti":	{"FW"},
"delicto":	{"FW"},
"delight":	{"NN","VB","VBP"},
"delighted":	{"JJ","VBD","VBN"},
"delightedly":	{"RB"},
"delightful":	{"JJ"},
"delightfully":	{"RB"},
"delighting":	{"VBG"},
"delights":	{"NNS","VBZ"},
"delilah":	{"NN"},
"delimit":	{"VB","VBP"},
"delimitate":	{"VB","VBP"},
"delimitated":	{"VBD","VBN"},
"delimitates":	{"VBZ"},
"delimitating":	{"VBG"},
"delimitation":	{"NN"},
"delimited":	{"VBD","VBN"},
"delimiting":	{"VBG"},
"delimits":	{"VBZ"},
"delineaments":	{"NNS"},
"delineate":	{"VB","VBP"},
"delineated":	{"VBD","VBN"},
"delineates":	{"VBZ"},
"delineating":	{"VBG"},
"delineation":	{"NN"},
"delineative":	{"JJ"},
"delinking":	{"NN"},
"delinquencies":	{"NNS"},
"delinquency":	{"NN"},
"delinquent":	{"JJ","NN"},
"delinquents":	{"NNS"},
"deliquesce":	{"VB"},
"deliquescent":	{"JJ"},
"deliquium":	{"NN"},
"delirious":	{"JJ"},
"deliriously":	{"RB"},
"delirium":	{"NN"},
"delis":	{"NNS"},
"delist":	{"VB","VBP"},
"delisted":	{"VBD","VBN"},
"delisting":	{"NN","VBG"},
"delistings":	{"NNS"},
"delists":	{"VBZ"},
"delius":	{"NNS"},
"deliver":	{"VB","VBP"},
"deliverable":	{"JJ","NN"},
"deliverance":	{"NN"},
"delivered":	{"VBN","VBD"},
"deliverer":	{"NN"},
"deliverers":	{"NNS"},
"deliveries":	{"NNS"},
"delivering":	{"VBG"},
"delivers":	{"VBZ"},
"delivery":	{"NN"},
"deliveryman":	{"NN"},
"dell":	{"NN"},
"delle":	{"NN"},
"delocalize":	{"VB"},
"delonix":	{"NN"},
"delorme":	{"NN"},
"delouse":	{"VB","VBP"},
"deloused":	{"VBN","VBD"},
"delouses":	{"VBZ"},
"delousing":	{"VBG"},
"delphi":	{"NN"},
"delphian":	{"JJ"},
"delphic":	{"JJ"},
"delphinapterus":	{"NN"},
"delphinidae":	{"NN"},
"delphinium":	{"NN"},
"delphinus":	{"NN"},
"delta":	{"NN"},
"deltas":	{"NNS"},
"deltasone":	{"NN"},
"deltoid":	{"JJ","NN"},
"deltoids":	{"NNS"},
"delude":	{"VB","VBP"},
"deluded":	{"VBD","VBN"},
"deludes":	{"VBZ"},
"deluding":	{"VBG"},
"deluge":	{"NN","VB","VBP"},
"deluged":	{"VBD","VBN"},
"deluges":	{"VBZ","NNS"},
"deluging":	{"VBG"},
"delusion":	{"NN"},
"delusional":	{"JJ"},
"delusions":	{"NNS"},
"delusive":	{"JJ"},
"delusively":	{"RB"},
"delusory":	{"JJ"},
"deluxe":	{"JJ","NN"},
"deluxer":	{"NN"},
"delve":	{"VB","VBP"},
"delved":	{"VBD","VBN"},
"delver":	{"NN"},
"delves":	{"VBZ"},
"delving":	{"VBG"},
"demage":	{"NN"},
"demagnetisation":	{"NN"},
"demagnetise":	{"VB","VBP"},
"demagnetised":	{"VBD","VBN"},
"demagnetises":	{"VBZ"},
"demagnetising":	{"VBG"},
"demagnetization":	{"NN"},
"demagnetize":	{"VB","VBP"},
"demagnetized":	{"VBD","VBN"},
"demagnetizes":	{"VBZ"},
"demagnetizing":	{"VBG"},
"demagnification":	{"NN"},
"demagog":	{"NN"},
"demagogic":	{"JJ"},
"demagogical":	{"JJ"},
"demagogue":	{"NN"},
"demagoguery":	{"NN"},
"demagogues":	{"NNS"},
"demagogy":	{"NN"},
"demand":	{"NN","VB","VBP"},
"demand-related":	{"JJ"},
"demand-supply":	{"JJ"},
"demanded":	{"VBD","VBN"},
"demander":	{"NN"},
"demanding":	{"VBG","JJ"},
"demandingly":	{"RB"},
"demands":	{"NNS","VBZ"},
"demantoid":	{"NN"},
"demarcate":	{"VB","VBP"},
"demarcated":	{"VBD","VBN"},
"demarcates":	{"VBZ"},
"demarcating":	{"VBG"},
"demarcation":	{"NN"},
"demarche":	{"NN"},
"demasculinise":	{"VB"},
"demasculinize":	{"VB"},
"dematerialise":	{"VB"},
"dematerialize":	{"VB"},
"dematerialized":	{"VBD","VBN"},
"dematerializes":	{"VBZ"},
"dematerializing":	{"VBG"},
"dematiaceae":	{"NN"},
"demavend":	{"NN"},
"demean":	{"VB","VBP"},
"demeaned":	{"VBD","VBN"},
"demeaning":	{"JJ","VBG"},
"demeaningly":	{"RB"},
"demeanor":	{"NN"},
"demeanors":	{"NNS"},
"demeanour":	{"NN"},
"demeans":	{"VBZ"},
"demented":	{"JJ","VBD","VBN"},
"dementedly":	{"RB"},
"dementedness":	{"NN"},
"dementia":	{"NN"},
"dementing":	{"VBG"},
"dements":	{"VBZ"},
"demerara":	{"NN"},
"demerit":	{"NN"},
"demerol":	{"NN"},
"demesne":	{"NN"},
"demeter":	{"NN"},
"demetrius":	{"NNS"},
"demi-glaze":	{"NN"},
"demi-monde":	{"FW"},
"demiglace":	{"NN"},
"demigod":	{"NN"},
"demijohn":	{"NN"},
"demilitarisation":	{"NN"},
"demilitarise":	{"VB","VBP"},
"demilitarised":	{"VBD","VBN"},
"demilitarises":	{"VBZ"},
"demilitarising":	{"VBG"},
"demilitarization":	{"NN"},
"demilitarize":	{"VB","VBP"},
"demilitarized":	{"VBD","VBN"},
"demilitarizes":	{"VBZ"},
"demilitarizing":	{"VBG"},
"demille":	{"NN"},
"demimondaine":	{"NN"},
"demimonde":	{"NN"},
"demineralisation":	{"NN"},
"demineralise":	{"VB"},
"demineralization":	{"NN"},
"demineralize":	{"VB"},
"demise":	{"NN","VB","VBP"},
"demised":	{"VBD","VBN"},
"demisemiquaver":	{"NN"},
"demises":	{"VBZ"},
"demising":	{"VBG"},
"demist":	{"VB","VBP"},
"demisted":	{"VBD","VBN"},
"demister":	{"NN"},
"demisters":	{"NNS"},
"demisting":	{"VBG"},
"demists":	{"VBZ"},
"demitasse":	{"NN"},
"demiurge":	{"NN"},
"demo":	{"NN","VB","VBP"},
"demob":	{"VB","VBP"},
"demobbed":	{"VBD","VBN"},
"demobbing":	{"VBG"},
"demobilisation":	{"NN"},
"demobilise":	{"VB","VBP"},
"demobilised":	{"VBD","VBN"},
"demobilises":	{"VBZ"},
"demobilising":	{"VBG"},
"demobilization":	{"NN"},
"demobilize":	{"VB","VBP"},
"demobilized":	{"VBD","VBN"},
"demobilizes":	{"VBZ"},
"demobilizing":	{"VBG"},
"demobs":	{"VBZ"},
"democracies":	{"NNS"},
"democracy":	{"NN"},
"democracy-free":	{"JJ"},
"democrat":	{"NN"},
"democratic":	{"JJ"},
"democratic-controlled":	{"JJ"},
"democratic-endorsed":	{"JJ"},
"democratic-led":	{"JJ"},
"democratic-sounding":	{"JJ"},
"democratic-sponsored":	{"JJ"},
"democratic-style":	{"JJ"},
"democratically":	{"RB"},
"democratisation":	{"NN"},
"democratise":	{"VB","VBP"},
"democratised":	{"VBD","VBN"},
"democratises":	{"VBZ"},
"democratising":	{"VBG"},
"democratization":	{"NN"},
"democratize":	{"VB","VBP"},
"democratized":	{"VBD","VBN"},
"democratizes":	{"VBZ"},
"democratizing":	{"VBG"},
"democrats":	{"NNS"},
"democritus":	{"NNS"},
"demode":	{"JJ"},
"demodulate":	{"VB","VBP"},
"demodulated":	{"VBD","VBN"},
"demodulates":	{"VBZ"},
"demodulating":	{"VBG"},
"demodulation":	{"NN"},
"demodulator":	{"NN"},
"demoed":	{"VBD","VBN"},
"demogorgon":	{"NN"},
"demographer":	{"NN"},
"demographic":	{"JJ","NN"},
"demographically":	{"RB"},
"demographics":	{"NNS"},
"demographiques":	{"FW"},
"demographist":	{"NN"},
"demography":	{"NN"},
"demoing":	{"VBG"},
"demoiselle":	{"NN"},
"demolish":	{"VB","VBP"},
"demolished":	{"VBD","VBN"},
"demolishes":	{"VBZ"},
"demolishing":	{"VBG"},
"demolition":	{"NN"},
"demolitions":	{"NNS"},
"demon":	{"NN"},
"demon-ridden":	{"JJ"},
"demonetisation":	{"NN"},
"demonetise":	{"VB","VBP"},
"demonetised":	{"VBD","VBN"},
"demonetises":	{"VBZ"},
"demonetising":	{"VBG"},
"demonetization":	{"NN"},
"demonetize":	{"VB","VBP"},
"demonetized":	{"VBD","VBN"},
"demonetizes":	{"VBZ"},
"demonetizing":	{"VBG"},
"demoniac":	{"NN","JJ"},
"demoniacal":	{"JJ"},
"demoniacally":	{"RB"},
"demonic":	{"JJ"},
"demonically":	{"RB"},
"demonisation":	{"NN"},
"demonise":	{"VB","VBP"},
"demonised":	{"VBD","VBN"},
"demonises":	{"VBZ"},
"demonising":	{"VBG"},
"demonism":	{"NN"},
"demonization":	{"NN"},
"demonize":	{"VB","VBP"},
"demonized":	{"VBD","VBN"},
"demonizes":	{"VBZ"},
"demonizing":	{"VBG"},
"demonolatry":	{"NN"},
"demonologist":	{"NN"},
"demons":	{"NNS"},
"demonstators":	{"NNS"},
"demonstrability":	{"NN"},
"demonstrable":	{"JJ"},
"demonstrably":	{"RB"},
"demonstrate":	{"VB","VBP"},
"demonstrated":	{"VBD","VBN"},
"demonstrates":	{"VBZ"},
"demonstrating":	{"VBG"},
"demonstration":	{"NN"},
"demonstrations":	{"NNS"},
"demonstrative":	{"JJ"},
"demonstratively":	{"RB"},
"demonstrativeness":	{"NN"},
"demonstratives":	{"NNS"},
"demonstrator":	{"NN"},
"demonstrators":	{"NNS"},
"demoralisation":	{"NN"},
"demoralise":	{"VB","VBP"},
"demoralised":	{"JJ","VBD","VBN"},
"demoralises":	{"VBZ"},
"demoralising":	{"JJ","VBG"},
"demoralization":	{"NN"},
"demoralize":	{"VB","VBP"},
"demoralized":	{"JJ","VBD","VBN"},
"demoralizes":	{"VBZ"},
"demoralizing":	{"JJ","VBG"},
"demos":	{"NNS","VBZ"},
"demosthenes":	{"NNS"},
"demosthenic":	{"JJ"},
"demote":	{"VB","VBP"},
"demoted":	{"VBD","VBN"},
"demotes":	{"VBZ"},
"demotic":	{"JJ","NN"},
"demoting":	{"VBG"},
"demotion":	{"NN"},
"demotions":	{"NNS"},
"demotivate":	{"VB","VBP"},
"demotivated":	{"JJ","VBD","VBN"},
"demotivates":	{"VBZ"},
"demotivating":	{"VBG"},
"dempsey":	{"NN"},
"demulcent":	{"JJ","NN"},
"demulen":	{"NN"},
"demulsify":	{"VB"},
"demur":	{"VB","VBP","NN"},
"demure":	{"JJ"},
"demurely":	{"RB"},
"demureness":	{"NN"},
"demurrage":	{"NN"},
"demurral":	{"NN"},
"demurred":	{"VBD","VBN"},
"demurrer":	{"NN"},
"demurring":	{"VBG"},
"demurs":	{"VBZ"},
"demyelinate":	{"VB"},
"demyelination":	{"NN"},
"demystification":	{"NN"},
"demystified":	{"VBD","VBN"},
"demystifies":	{"VBZ"},
"demystify":	{"VB","VBP"},
"demystifying":	{"VBG"},
"demythologisation":	{"NN"},
"demythologise":	{"VB","VBP"},
"demythologised":	{"VBD","VBN"},
"demythologises":	{"VBZ"},
"demythologising":	{"VBG"},
"demythologization":	{"NN"},
"demythologize":	{"VB","VBP"},
"demythologized":	{"VBD","VBN"},
"demythologizes":	{"VBZ"},
"demythologizing":	{"VBG"},
"den":	{"NN","VB","VBP"},
"denali":	{"NN"},
"denary":	{"JJ"},
"denationalisation":	{"NN"},
"denationalise":	{"VB","VBP"},
"denationalised":	{"VBD","VBN"},
"denationalises":	{"VBZ"},
"denationalising":	{"VBG"},
"denationalization":	{"NN"},
"denationalizations":	{"NNS"},
"denationalize":	{"VB","VBP"},
"denationalized":	{"VBD","VBN"},
"denationalizes":	{"VBZ"},
"denationalizing":	{"VBG"},
"denaturalise":	{"VB","VBP"},
"denaturalises":	{"VBZ"},
"denaturalising":	{"VBG"},
"denaturalize":	{"VB","VBP"},
"denaturalizes":	{"VBZ"},
"denaturalizing":	{"VBG"},
"denaturant":	{"NN"},
"denature":	{"VB","VBP"},
"denatured":	{"JJ","VBD","VBN"},
"denatures":	{"VBZ"},
"denaturing":	{"VBG"},
"denaturised":	{"JJ","VBD","VBN"},
"denaturized":	{"JJ","VBD","VBN"},
"denazification":	{"NN"},
"denazified":	{"VBD","VBN"},
"denazifies":	{"VBZ"},
"denazify":	{"VB","VBP"},
"denazifying":	{"VBG"},
"dendranthema":	{"NN"},
"dendraspis":	{"NNS"},
"dendriform":	{"JJ"},
"dendrite":	{"NN"},
"dendritic":	{"JJ","NN"},
"dendroaspis":	{"NNS"},
"dendrobium":	{"NN"},
"dendrocalamus":	{"NNS"},
"dendrocolaptes":	{"NNS"},
"dendrocolaptidae":	{"NN"},
"dendroctonus":	{"NN"},
"dendroica":	{"NN"},
"dendroid":	{"JJ"},
"dendroidal":	{"JJ"},
"dendrolagus":	{"NNS"},
"dendromecon":	{"NN"},
"deneb":	{"NN"},
"denebola":	{"NN"},
"dengue":	{"NN"},
"deniable":	{"JJ"},
"denial":	{"NN"},
"denialism":	{"NN"},
"denials":	{"NNS"},
"denied":	{"VBD","VBN"},
"denier":	{"NN"},
"denies":	{"VBZ"},
"denigrate":	{"VB","VBP"},
"denigrated":	{"VBD","VBN"},
"denigrates":	{"VBZ"},
"denigrating":	{"VBG"},
"denigration":	{"NN"},
"denigrative":	{"JJ"},
"denigratory":	{"JJ"},
"denim":	{"NN"},
"denims":	{"NNS"},
"denis":	{"NN"},
"denisonia":	{"NN"},
"denitrify":	{"VB"},
"denizen":	{"NN"},
"denizens":	{"NNS"},
"denmark":	{"NN"},
"denned":	{"VBD","VBN"},
"denning":	{"VBG"},
"dennstaedtia":	{"NN"},
"dennstaedtiaceae":	{"NN"},
"denominate":	{"VB","VBP"},
"denominated":	{"VBD","VBN"},
"denominates":	{"VBZ"},
"denominating":	{"VBG"},
"denomination":	{"NN"},
"denominational":	{"JJ"},
"denominationalism":	{"NN"},
"denominationally":	{"RB"},
"denominations":	{"NNS"},
"denominator":	{"NN"},
"denominators":	{"NNS"},
"denotation":	{"NN"},
"denotative":	{"JJ"},
"denotatum":	{"NN"},
"denote":	{"VB","NN","VBP"},
"denoted":	{"VBD","VBN"},
"denotes":	{"VBZ","NNS"},
"denoting":	{"VBG","NN"},
"denotive":	{"JJ"},
"denouement":	{"NN"},
"denounce":	{"VB","VBP"},
"denounced":	{"VBD","VBN"},
"denouncement":	{"NN"},
"denounces":	{"VBZ"},
"denouncing":	{"VBG"},
"dens":	{"NNS","VBZ"},
"dense":	{"JJ"},
"densely":	{"RB"},
"denseness":	{"NN"},
"denser":	{"JJR"},
"densest":	{"JJS"},
"densification":	{"NN"},
"densimeter":	{"NN"},
"densimeters":	{"NNS"},
"densities":	{"NNS"},
"densitometer":	{"NN"},
"densitometry":	{"NN"},
"density":	{"NN"},
"dent":	{"NN","VB","VBP"},
"dental":	{"JJ"},
"dental-products":	{"NNS"},
"dentaria":	{"NN"},
"dentate":	{"JJ"},
"dented":	{"VBD","VBN"},
"denticle":	{"NN"},
"denticulate":	{"JJ"},
"dentifrice":	{"NN"},
"dentin":	{"NN"},
"dentine":	{"NN"},
"denting":	{"VBG"},
"dentist":	{"NN"},
"dentistry":	{"NN"},
"dentists":	{"NNS"},
"dentition":	{"NN"},
"dents":	{"NNS","VBZ"},
"denture":	{"NN"},
"dentures":	{"NNS"},
"denturist":	{"NN"},
"dentuso":	{"FW"},
"denuclearized":	{"VBN"},
"denudate":	{"JJ","VB","VBP"},
"denudated":	{"VBD","VBN"},
"denudates":	{"VBZ"},
"denudating":	{"VBG"},
"denudation":	{"NN"},
"denude":	{"VB","VBP"},
"denuded":	{"VBD","VBN"},
"denudes":	{"VBZ"},
"denuding":	{"VBG"},
"denumerable":	{"JJ"},
"denunciation":	{"NN"},
"denunciations":	{"NNS"},
"denunciative":	{"JJ"},
"denunciatory":	{"JJ"},
"denver":	{"NN"},
"denver-area":	{"NN"},
"deny":	{"VB","VBP"},
"denying":	{"VBG"},
"deodar":	{"NN"},
"deodorant":	{"NN","JJ"},
"deodorise":	{"VB","VBP"},
"deodorised":	{"VBD","VBN"},
"deodorises":	{"VBZ"},
"deodorising":	{"VBG"},
"deodorize":	{"VB","VBP"},
"deodorized":	{"VBD","VBN"},
"deodorizes":	{"VBZ"},
"deodorizing":	{"VBG"},
"deodourant":	{"NN"},
"deodourise":	{"VB"},
"deossification":	{"NN"},
"deoxidise":	{"VB"},
"deoxidize":	{"VB"},
"deoxyadenosine":	{"NN"},
"deoxycytidine":	{"NN"},
"deoxyephedrine":	{"NN"},
"deoxygenate":	{"VB"},
"deoxyguanosine":	{"NN"},
"deoxyribonucleic":	{"JJ"},
"deoxyribose":	{"NN"},
"deoxythymidine":	{"NN"},
"depardieu":	{"NN"},
"deparia":	{"NN"},
"depart":	{"VB","JJ","VBP"},
"departed":	{"VBN","JJ","VBD"},
"departee":	{"NN"},
"departees":	{"NNS"},
"departer":	{"NN"},
"departing":	{"VBG"},
"department":	{"NN"},
"department-sponsored":	{"JJ"},
"department-store":	{"NN","JJ"},
"departmental":	{"JJ","NN"},
"departmentalizing":	{"VBG"},
"departmentally":	{"RB"},
"departments":	{"NNS"},
"departs":	{"VBZ","NNS"},
"departure":	{"NN"},
"departures":	{"NNS"},
"depcreciation":	{"NN"},
"depend":	{"VB","VBP"},
"dependability":	{"NN"},
"dependable":	{"JJ"},
"dependableness":	{"NN"},
"dependably":	{"RB"},
"dependance":	{"NN"},
"dependant":	{"NN"},
"dependants":	{"NNS"},
"depended":	{"VBD","VBN"},
"dependence":	{"NN"},
"dependencies":	{"NNS"},
"dependency":	{"NN"},
"dependent":	{"JJ","NN"},
"dependent-care":	{"JJ"},
"dependents":	{"NNS"},
"depending":	{"VBG"},
"depends":	{"VBZ"},
"depersonalisation":	{"NN"},
"depersonalise":	{"VB","VBP"},
"depersonalised":	{"VBD","VBN"},
"depersonalises":	{"VBZ"},
"depersonalising":	{"VBG"},
"depersonalization":	{"NN"},
"depersonalize":	{"VB","VBP"},
"depersonalized":	{"VBD","VBN"},
"depersonalizes":	{"VBZ"},
"depersonalizing":	{"VBG"},
"depict":	{"VB","NN","VBP"},
"depicted":	{"VBD","VBN"},
"depicting":	{"VBG","NN"},
"depiction":	{"NN"},
"depictions":	{"NNS"},
"depictive":	{"JJ"},
"depicts":	{"VBZ","NNS"},
"depigmentation":	{"NN"},
"depilate":	{"VB","VBP"},
"depilated":	{"VBD","VBN"},
"depilates":	{"VBZ"},
"depilating":	{"VBG"},
"depilation":	{"NN"},
"depilator":	{"NN"},
"depilatories":	{"NNS"},
"depilatory":	{"NN","JJ"},
"depilous":	{"JJ"},
"deplane":	{"VB","VBP"},
"deplaned":	{"VBD","VBN"},
"deplanes":	{"VBZ"},
"deplaning":	{"VBG"},
"depletable":	{"JJ"},
"deplete":	{"VB","VBP"},
"depleted":	{"VBN","VBD","JJ"},
"depletes":	{"VBZ"},
"depleting":	{"VBG"},
"depletion":	{"NN"},
"deplorable":	{"JJ"},
"deplorably":	{"RB"},
"deplore":	{"VB","VBP"},
"deplored":	{"VBD","VBN"},
"deplores":	{"VBZ"},
"deploring":	{"VBG"},
"deploy":	{"VB","VBP"},
"deployable":	{"JJ"},
"deployed":	{"VBD","VBN"},
"deploying":	{"VBG"},
"deployment":	{"NN"},
"deployments":	{"NNS"},
"deploys":	{"VBZ"},
"deplumate":	{"VB"},
"deplume":	{"VB"},
"depokene":	{"NN"},
"depolarisation":	{"NN"},
"depolarise":	{"VB"},
"depolarization":	{"NN"},
"depolarize":	{"VB"},
"depone":	{"VB"},
"deponent":	{"NN"},
"depopulate":	{"VB","VBP"},
"depopulated":	{"VBD","VBN","JJ"},
"depopulates":	{"VBZ"},
"depopulating":	{"VBG"},
"depopulation":	{"NN"},
"deport":	{"VB","VBP"},
"deportation":	{"NN"},
"deportations":	{"NNS"},
"deported":	{"VBD","VBN"},
"deportee":	{"NN"},
"deportees":	{"NNS"},
"deporting":	{"VBG"},
"deportment":	{"NN"},
"deports":	{"VBZ"},
"depose":	{"VB","VBP"},
"deposed":	{"VBD","VBN"},
"deposer":	{"NN"},
"deposes":	{"VBZ"},
"deposing":	{"VBG"},
"deposit":	{"NN","VB","VBP"},
"deposit-transfer":	{"NN"},
"depositary":	{"NN"},
"deposited":	{"VBN","VBD"},
"depositing":	{"VBG"},
"deposition":	{"NN"},
"depositions":	{"NNS"},
"depositor":	{"NN"},
"depositories":	{"NNS"},
"depositors":	{"NNS"},
"depository":	{"NN","JJ"},
"deposits":	{"NNS","VBZ"},
"depot":	{"NN"},
"depots":	{"NNS"},
"depravation":	{"NN"},
"deprave":	{"VB","VBP"},
"depraved":	{"JJ","VBD","VBN"},
"depraves":	{"VBZ"},
"depraving":	{"VBG"},
"depravities":	{"NNS"},
"depravity":	{"NN"},
"deprecate":	{"VB","VBP"},
"deprecated":	{"VBD","VBN"},
"deprecates":	{"VBZ"},
"deprecating":	{"JJ","VBG"},
"deprecatingly":	{"RB"},
"deprecation":	{"NN"},
"deprecative":	{"JJ"},
"deprecatively":	{"RB"},
"deprecatory":	{"JJ"},
"depreciable":	{"JJ"},
"depreciate":	{"VB","VBP"},
"depreciated":	{"VBD","VBN"},
"depreciates":	{"VBZ"},
"depreciating":	{"VBG"},
"depreciation":	{"NN"},
"depreciation-induced":	{"JJ"},
"depreciations":	{"NNS"},
"depreciative":	{"JJ"},
"depreciator":	{"NN"},
"depreciatory":	{"JJ"},
"depredation":	{"NN"},
"depredations":	{"NNS"},
"depress":	{"VB","VBP"},
"depressant":	{"NN","JJ"},
"depressants":	{"NNS"},
"depressed":	{"JJ","VBN","VBD"},
"depresses":	{"VBZ"},
"depressing":	{"JJ","VBG"},
"depressingly":	{"RB"},
"depression":	{"NN"},
"depression-era":	{"JJ"},
"depressions":	{"NNS"},
"depressive":	{"JJ","NN"},
"depressives":	{"NNS"},
"depressor":	{"NN"},
"depressors":	{"NNS"},
"depressurisation":	{"NN"},
"depressurise":	{"VB","VBP"},
"depressurised":	{"VBD","VBN"},
"depressurises":	{"VBZ"},
"depressurising":	{"VBG"},
"depressurization":	{"NN"},
"depressurize":	{"VB","VBP"},
"depressurized":	{"VBD","VBN"},
"depressurizes":	{"VBZ"},
"depressurizing":	{"VBG"},
"deprivation":	{"NN"},
"deprivations":	{"NNS"},
"deprive":	{"VB","VBP"},
"deprived":	{"VBD","VBN","JJ"},
"deprives":	{"VBZ"},
"depriving":	{"VBG"},
"deprogrammings":	{"NNS"},
"dept.":	{"NN"},
"depth":	{"NN"},
"depths":	{"NNS"},
"deputation":	{"NN"},
"deputations":	{"NNS"},
"depute":	{"VB","VBP"},
"deputed":	{"VBD","VBN"},
"deputes":	{"VBZ"},
"deputies":	{"NNS"},
"deputing":	{"VBG"},
"deputise":	{"VB","VBP"},
"deputised":	{"VBD","VBN"},
"deputises":	{"VBZ"},
"deputising":	{"VBG"},
"deputize":	{"VB","VBP"},
"deputized":	{"VBD","VBN"},
"deputizes":	{"VBZ"},
"deputizing":	{"VBG"},
"deputy":	{"NN"},
"der":	{"NN"},
"deracinate":	{"VB"},
"deracination":	{"NN"},
"derail":	{"VB","VBP"},
"derailed":	{"VBD","VBN"},
"derailing":	{"VBG"},
"derailment":	{"NN"},
"derailments":	{"NNS"},
"derails":	{"VBZ"},
"derain":	{"NN"},
"derange":	{"VB","VBP"},
"deranged":	{"JJ","VBD","VBN"},
"derangement":	{"NN"},
"deranges":	{"VBZ"},
"deranging":	{"VBG"},
"deras":	{"FW"},
"derate":	{"VB"},
"derby":	{"NN"},
"dere":	{"NN"},
"derecognise":	{"VB"},
"derecognize":	{"VB"},
"deregister":	{"VB","VBP"},
"deregistered":	{"VBD","VBN"},
"deregistering":	{"VBG"},
"deregisters":	{"VBZ"},
"deregulate":	{"VB","VBP"},
"deregulated":	{"VBD","VBN"},
"deregulates":	{"VBZ"},
"deregulating":	{"VBG"},
"deregulation":	{"NN"},
"derelict":	{"JJ","NN"},
"dereliction":	{"NN"},
"derelicts":	{"NNS"},
"derequisition":	{"VB"},
"derestrict":	{"VB"},
"deride":	{"VB","VBP"},
"derided":	{"VBD","VBN"},
"derides":	{"VBZ"},
"deriding":	{"VBG"},
"derision":	{"NN"},
"derisive":	{"JJ"},
"derisively":	{"RB"},
"derisorily":	{"RB"},
"derisory":	{"JJ"},
"derivable":	{"JJ"},
"derivation":	{"NN"},
"derivational":	{"JJ"},
"derivationally":	{"RB"},
"derivations":	{"NNS"},
"derivative":	{"JJ","NN"},
"derivatives":	{"NNS"},
"derive":	{"VB","NN","VBP"},
"derived":	{"VBD","VBN"},
"derives":	{"VBZ","NNS"},
"deriving":	{"VBG","NN"},
"derma":	{"NN"},
"dermabrasion":	{"NN"},
"dermacentor":	{"NN"},
"dermal":	{"JJ"},
"dermaptera":	{"NN"},
"dermatitis":	{"NN"},
"dermatobia":	{"NN"},
"dermatoglyphic":	{"NN"},
"dermatoglyphics":	{"NN"},
"dermatologic":	{"JJ"},
"dermatological":	{"JJ"},
"dermatologist":	{"NN"},
"dermatologists":	{"NNS"},
"dermatology":	{"NN"},
"dermatome":	{"NN"},
"dermatomycosis":	{"NN"},
"dermatomyositis":	{"NNS"},
"dermatophytosis":	{"NN"},
"dermatosclerosis":	{"NN"},
"dermatosis":	{"NN"},
"dermestidae":	{"NN"},
"dermic":	{"JJ"},
"dermis":	{"NN"},
"dermochelyidae":	{"NN"},
"dermochelys":	{"NNS"},
"dermoptera":	{"NN"},
"derogate":	{"VB","VBP"},
"derogated":	{"VBD","VBN"},
"derogates":	{"VBZ"},
"derogating":	{"VBG"},
"derogation":	{"NN"},
"derogative":	{"JJ"},
"derogatory":	{"JJ"},
"derrick":	{"NN"},
"derrida":	{"NN"},
"derriere":	{"NN"},
"derring":	{"NN"},
"derring-do":	{"NN"},
"derringer":	{"NN"},
"derris":	{"NN"},
"derv":	{"NN"},
"dervish":	{"NN"},
"dervish-like":	{"JJ"},
"dervishes":	{"NNS"},
"desacralize":	{"VB"},
"desalinate":	{"VB"},
"desalination":	{"NN"},
"desalinisation":	{"NN"},
"desalinise":	{"VB"},
"desalinization":	{"NN"},
"desalinize":	{"VB"},
"desalt":	{"VB"},
"desalted":	{"VBD","VBN"},
"desalting":	{"VBG"},
"desalts":	{"VBZ"},
"descale":	{"VB","VBP"},
"descaled":	{"VBD","VBN"},
"descales":	{"VBZ"},
"descaling":	{"VBG"},
"descant":	{"NN","VB","VBP"},
"descanted":	{"VBD","VBN"},
"descanting":	{"VBG"},
"descants":	{"NNS","VBZ"},
"descartes":	{"NNS"},
"descend":	{"VB","VBP"},
"descendant":	{"NN","JJ"},
"descendants":	{"NNS"},
"descended":	{"VBD","VBN","JJ"},
"descendent":	{"NN","JJ"},
"descendents":	{"NNS"},
"descender":	{"NN"},
"descending":	{"JJ","VBG"},
"descends":	{"VBZ"},
"descensus":	{"NNS"},
"descent":	{"NN"},
"descents":	{"NNS"},
"describable":	{"JJ"},
"describe":	{"VB","VBP"},
"described":	{"VBN","VBD"},
"describes":	{"VBZ"},
"describing":	{"VBG"},
"descried":	{"VBD","VBN"},
"descries":	{"VBZ"},
"description":	{"NN"},
"descriptions":	{"NNS"},
"descriptive":	{"JJ","NN"},
"descriptively":	{"RB"},
"descriptivism":	{"NN"},
"descriptor":	{"NN"},
"descry":	{"VB","VBP"},
"descrying":	{"VBG"},
"descurainia":	{"NN"},
"desecrate":	{"VB","VBP"},
"desecrated":	{"VBD","VBN"},
"desecrates":	{"VBZ"},
"desecrating":	{"VBG"},
"desecration":	{"NN"},
"desegrated":	{"JJ"},
"desegregate":	{"VB","VBP"},
"desegregated":	{"VBD","VBN"},
"desegregates":	{"VBZ"},
"desegregating":	{"VBG"},
"desegregation":	{"NN"},
"desegregation-from-court-order":	{"NN"},
"desensitisation":	{"NN"},
"desensitise":	{"VB","VBP"},
"desensitised":	{"VBD","VBN"},
"desensitises":	{"VBZ"},
"desensitising":	{"VBG"},
"desensitization":	{"NN"},
"desensitize":	{"VB","VBP"},
"desensitized":	{"VBD","VBN"},
"desensitizes":	{"VBZ"},
"desensitizing":	{"VBG"},
"desert":	{"NN","VB","VBP"},
"desert-battle":	{"JJ"},
"desert-bound":	{"JJ"},
"deserted":	{"JJ","VBD","VBN"},
"deserter":	{"NN"},
"desertification":	{"NN"},
"desertified":	{"VBD","VBN"},
"desertifies":	{"VBZ"},
"desertify":	{"VB","VBP"},
"desertifying":	{"VBG"},
"deserting":	{"VBG"},
"desertion":	{"NN"},
"deserts":	{"NNS","VBZ"},
"deserve":	{"VB","VBP"},
"deserved":	{"JJ","VBD","VBN"},
"deservedly":	{"RB"},
"deserves":	{"VBZ"},
"deserving":	{"JJ","VBG"},
"deservingness":	{"NN"},
"desex":	{"VB"},
"desexualise":	{"VB"},
"desexualize":	{"VB"},
"deshabille":	{"NN"},
"desiccant":	{"NN","JJ"},
"desiccate":	{"VB","VBP"},
"desiccated":	{"JJ","VBD","VBN"},
"desiccates":	{"VBZ"},
"desiccating":	{"VBG"},
"desiccation":	{"NN"},
"desideratum":	{"NN"},
"design":	{"NN","VB","VBP"},
"design-conscious":	{"JJ"},
"design-side":	{"JJ"},
"designate":	{"VB","VBP","JJ"},
"designated":	{"VBN","VBD","JJ"},
"designates":	{"VBZ"},
"designating":	{"VBG"},
"designation":	{"NN"},
"designations":	{"NNS"},
"designative":	{"JJ"},
"designator":	{"NN"},
"designatum":	{"NN"},
"designed":	{"VBN","VBD"},
"designedly":	{"RB"},
"designees":	{"NNS"},
"designer":	{"NN","JJ"},
"designers":	{"NNS"},
"designing":	{"VBG"},
"designs":	{"NNS","VBZ"},
"desipramine":	{"NN"},
"desirability":	{"NN"},
"desirable":	{"JJ"},
"desirableness":	{"NN"},
"desire":	{"NN","VBP","VB"},
"desired":	{"VBN","VBD","JJ"},
"desires":	{"NNS","VBZ"},
"desiring":	{"NN","VBG"},
"desirous":	{"JJ"},
"desist":	{"VB","VBP"},
"desisted":	{"VBD","VBN"},
"desisting":	{"VBG"},
"desists":	{"VBZ"},
"desk":	{"NN"},
"desk-bound":	{"JJ"},
"desk-legs":	{"NNS"},
"desk-top":	{"JJ"},
"deskbound":	{"JJ"},
"desklegs":	{"NNS"},
"deskman":	{"NN"},
"desks":	{"NNS"},
"desktop":	{"NN","JJ"},
"desktop-computer":	{"NN"},
"desktop-presentation":	{"JJ"},
"desktop-publishing":	{"NN"},
"desktops":	{"NNS"},
"desmanthus":	{"NNS"},
"desmid":	{"NN"},
"desmidiaceae":	{"NN"},
"desmidium":	{"NN"},
"desmodium":	{"NN"},
"desmodontidae":	{"NN"},
"desmodus":	{"NNS"},
"desmograthus":	{"NNS"},
"desmond":	{"NN"},
"desolate":	{"JJ","VB","VBP"},
"desolated":	{"VBD","VBN","JJ"},
"desolately":	{"RB"},
"desolates":	{"VBZ"},
"desolating":	{"VBG","JJ"},
"desolation":	{"NN"},
"desolations":	{"NNS"},
"desorb":	{"VB"},
"desorption":	{"NN"},
"despair":	{"NN","VBP","VB"},
"despaired":	{"VBD","VBN","JJ"},
"despairing":	{"VBG","JJ"},
"despairingly":	{"RB"},
"despairs":	{"VBZ","NNS"},
"despatch":	{"NN","VB","VBP"},
"despatched":	{"VBD","VBN"},
"despatches":	{"NNS","VBZ"},
"despatching":	{"VBG"},
"desperado":	{"NN"},
"desperadoes":	{"NNS"},
"desperate":	{"JJ"},
"desperately":	{"RB"},
"desperation":	{"NN"},
"despicability":	{"NN"},
"despicable":	{"JJ","NN"},
"despicableness":	{"NN"},
"despicably":	{"RB"},
"despisal":	{"NN"},
"despise":	{"VB","VBP"},
"despised":	{"VBD","VBN"},
"despises":	{"VBZ"},
"despising":	{"VBG"},
"despite":	{"IN"},
"despiteful":	{"JJ"},
"despitefully":	{"RB"},
"despoil":	{"VB","VBP"},
"despoilation":	{"NN"},
"despoiled":	{"VBD","VBN"},
"despoiler":	{"NN"},
"despoilers":	{"NNS"},
"despoiling":	{"VBG"},
"despoilment":	{"NN"},
"despoils":	{"VBZ"},
"despoina":	{"NN"},
"despoliation":	{"NN"},
"despond":	{"NN","VB","VBP"},
"desponded":	{"VBD","VBN"},
"despondence":	{"NN"},
"despondency":	{"NN"},
"despondent":	{"JJ"},
"despondently":	{"RB"},
"desponding":	{"VBG"},
"desponds":	{"VBZ"},
"despot":	{"NN"},
"despotic":	{"JJ"},
"despotical":	{"JJ"},
"despotism":	{"NN"},
"despots":	{"NNS"},
"despues":	{"FW"},
"desquamate":	{"VB"},
"desquamation":	{"NN"},
"dessert":	{"NN"},
"dessert-menu":	{"NN"},
"desserts":	{"NNS"},
"dessertspoon":	{"NN"},
"dessertspoonful":	{"NN"},
"dessiatine":	{"NN"},
"destabilisation":	{"NN"},
"destabilise":	{"VB","VBP"},
"destabilised":	{"VBD","VBN"},
"destabilises":	{"VBZ"},
"destabilising":	{"VBG"},
"destabilization":	{"NN"},
"destabilize":	{"VB","VBP"},
"destabilized":	{"VBD","VBN"},
"destabilizes":	{"VBZ"},
"destabilizing":	{"VBG"},
"destain":	{"VB"},
"destalinisation":	{"NN"},
"destalinise":	{"VB"},
"destalinization":	{"NN"},
"destalinize":	{"VB"},
"destigmatization":	{"NN"},
"destination":	{"NN"},
"destinations":	{"NNS"},
"destine":	{"VB","VBP"},
"destined":	{"JJ","VBD","VBN"},
"destines":	{"VBZ"},
"destinies":	{"NNS"},
"destining":	{"VBG"},
"destiny":	{"NN"},
"destitute":	{"JJ"},
"destitution":	{"NN"},
"destock":	{"VB","VBP"},
"destocked":	{"VBD","VBN"},
"destocking":	{"VBG"},
"destocks":	{"VBZ"},
"destress":	{"VB","VBP"},
"destressed":	{"VBD","VBN"},
"destresser":	{"NN"},
"destressers":	{"NNS"},
"destresses":	{"VBZ"},
"destressing":	{"VBG"},
"destroy":	{"VB","VBP"},
"destroyable":	{"JJ"},
"destroyed":	{"VBN","VBD"},
"destroyer":	{"NN"},
"destroyers":	{"NNS"},
"destroying":	{"VBG"},
"destroys":	{"VBZ"},
"destruct":	{"VB","NN"},
"destructibility":	{"NN"},
"destructible":	{"JJ"},
"destruction":	{"NN"},
"destructive":	{"JJ"},
"destructive-metabolic":	{"JJ"},
"destructively":	{"RB"},
"destructiveness":	{"NN"},
"desuetude":	{"NN"},
"desulfurization":	{"NN"},
"desulfurize":	{"VB"},
"desulphurize":	{"VB"},
"desultory":	{"JJ"},
"desynchronisation":	{"NN"},
"desynchronise":	{"VB"},
"desynchronization":	{"NN"},
"desynchronize":	{"VB"},
"desynchronizing":	{"NN"},
"desyrel":	{"NN"},
"detach":	{"VB","VBP"},
"detachable":	{"JJ"},
"detached":	{"JJ","VBD","VBN"},
"detaches":	{"VBZ"},
"detaching":	{"VBG"},
"detachment":	{"NN"},
"detachments":	{"NNS"},
"detail":	{"NN","VB","VBP"},
"detailed":	{"JJ","VBN","VBD"},
"detailing":	{"NN","VBG"},
"details":	{"NNS","VBZ"},
"detailsman":	{"NN"},
"detain":	{"VB","VBP"},
"detained":	{"VBN","VBD"},
"detainee":	{"NN"},
"detainees":	{"NNS"},
"detaining":	{"VBG"},
"detainment":	{"NN"},
"detains":	{"VBZ"},
"detect":	{"VB","VBP"},
"detectable":	{"JJ"},
"detected":	{"VBN","VBD"},
"detecting":	{"VBG"},
"detection":	{"NN"},
"detective":	{"NN"},
"detective-story":	{"NN"},
"detectives":	{"NNS"},
"detector":	{"NN"},
"detectors":	{"NNS"},
"detects":	{"VBZ"},
"detent":	{"NN"},
"detente":	{"NN"},
"detention":	{"NN"},
"deter":	{"VB","VBP"},
"deterence":	{"NN"},
"deterge":	{"VB","VBP"},
"deterged":	{"VBD","VBN"},
"detergence":	{"NN"},
"detergency":	{"NN"},
"detergent":	{"NN","JJ"},
"detergents":	{"NNS"},
"deterges":	{"VBZ"},
"deterging":	{"VBG"},
"deteriorate":	{"VB","VBP"},
"deteriorated":	{"VBD","VBN"},
"deteriorates":	{"VBZ"},
"deteriorating":	{"VBG"},
"deterioration":	{"NN"},
"determent":	{"NN"},
"determinability":	{"NN"},
"determinable":	{"JJ"},
"determinant":	{"NN"},
"determinants":	{"NNS"},
"determinate":	{"JJ"},
"determinateness":	{"NN"},
"determination":	{"NN"},
"determinations":	{"NNS"},
"determinative":	{"JJ","NN"},
"determine":	{"VB","VBP"},
"determined":	{"VBN","VBD","JJ"},
"determinedly":	{"RB"},
"determiner":	{"NN"},
"determiners":	{"NNS"},
"determines":	{"VBZ"},
"determining":	{"VBG"},
"determinism":	{"NN"},
"determinist":	{"NN","JJ"},
"deterministic":	{"JJ"},
"determinists":	{"NNS"},
"deterrant":	{"JJ"},
"deterred":	{"VBD","VBN"},
"deterrence":	{"NN"},
"deterrent":	{"NN","JJ"},
"deterrents":	{"NNS"},
"deterring":	{"VBG"},
"deters":	{"VBZ"},
"detersive":	{"JJ"},
"detest":	{"VB","NN","VBP"},
"detestable":	{"JJ"},
"detestably":	{"RB"},
"detestation":	{"NN"},
"detested":	{"VBD","VBN"},
"detesting":	{"VBG"},
"detests":	{"VBZ","NNS"},
"dethaw":	{"VB"},
"dethrone":	{"VB","VBP"},
"dethroned":	{"VBD","VBN"},
"dethronement":	{"NN"},
"dethrones":	{"VBZ"},
"dethroning":	{"VBG"},
"detick":	{"VB"},
"detonate":	{"VB","VBP"},
"detonated":	{"VBD","VBN"},
"detonates":	{"VBZ"},
"detonating":	{"VBG"},
"detonation":	{"NN"},
"detonations":	{"NNS"},
"detonative":	{"JJ"},
"detonator":	{"NN"},
"detonators":	{"NNS"},
"detour":	{"NN","VBP","VB"},
"detoured":	{"VBD","VBN"},
"detouring":	{"VBG"},
"detours":	{"NNS","VBZ"},
"detox":	{"NN","VB","VBP"},
"detoxed":	{"VBD","VBN"},
"detoxes":	{"NNS","VBZ"},
"detoxicate":	{"VB","VBP"},
"detoxicated":	{"VBD","VBN"},
"detoxicates":	{"VBZ"},
"detoxicationg":	{"VBG"},
"detoxification":	{"NN"},
"detoxified":	{"VBD","VBN"},
"detoxifies":	{"VBZ"},
"detoxify":	{"VB","VBP"},
"detoxifying":	{"VBG"},
"detoxing":	{"VBG"},
"detract":	{"VB","VBP"},
"detracted":	{"VBD","VBN"},
"detracting":	{"VBG"},
"detraction":	{"NN"},
"detractive":	{"JJ"},
"detractor":	{"NN"},
"detractors":	{"NNS"},
"detracts":	{"VBZ"},
"detrain":	{"VB","VBP"},
"detrained":	{"VBD","VBN"},
"detraining":	{"VBG"},
"detrains":	{"VBZ"},
"detransitivise":	{"VB"},
"detransitivize":	{"VB"},
"detribalisation":	{"NN"},
"detribalise":	{"VB"},
"detribalization":	{"NN"},
"detribalize":	{"VB"},
"detriment":	{"NN"},
"detrimental":	{"JJ"},
"detrimentally":	{"RB"},
"detriments":	{"NNS"},
"detrition":	{"NN"},
"detritus":	{"NN"},
"detroit":	{"NN"},
"detroit-area":	{"JJ"},
"detroit-based":	{"JJ"},
"detroit-over-san":	{"JJ"},
"detroit-to-tokyo":	{"JJ"},
"detroiters":	{"NNS"},
"detumescence":	{"NN"},
"detusk":	{"VB"},
"deuce":	{"NN"},
"deuce-ace":	{"NN"},
"deuced":	{"JJ"},
"deucedly":	{"RB"},
"deuteranopia":	{"NN"},
"deuteranopic":	{"JJ"},
"deuterated":	{"VBD","VBN"},
"deuterium":	{"NN"},
"deuteromycetes":	{"NNS"},
"deuteromycota":	{"NN"},
"deuteromycotina":	{"NN"},
"deuteron":	{"NN"},
"deuteronomy":	{"NN"},
"deutsche":	{"NN","FW"},
"deutschland":	{"NN"},
"deutschmark":	{"NN"},
"deutzia":	{"NN"},
"deux":	{"FW"},
"devaluate":	{"VB","VBP"},
"devaluated":	{"VBD","VBN"},
"devaluates":	{"VBZ"},
"devaluating":	{"VBG"},
"devaluation":	{"NN"},
"devaluations":	{"NNS"},
"devalue":	{"VB","VBP"},
"devalued":	{"VBD","VBN"},
"devalues":	{"VBZ"},
"devaluing":	{"VBG"},
"devanagari":	{"NN"},
"devastate":	{"VB","VBP"},
"devastated":	{"VBD","VBN","JJ"},
"devastates":	{"VBZ"},
"devastating":	{"JJ","VBG"},
"devastatingly":	{"RB"},
"devastation":	{"NN"},
"devein":	{"VB","VBP"},
"deveined":	{"VBD","VBN"},
"deveining":	{"VBG"},
"deveins":	{"VBZ"},
"develop":	{"VB","VBP"},
"developed":	{"VBN","VBD","JJ"},
"developer":	{"NN"},
"developers":	{"NNS"},
"developing":	{"VBG","JJ"},
"developing-country":	{"JJ"},
"developing-nation":	{"JJ"},
"development":	{"NN"},
"development-aid":	{"NN"},
"developmental":	{"JJ"},
"developmentally":	{"RB"},
"developments":	{"NNS"},
"develops":	{"VBZ"},
"devi":	{"NN"},
"deviance":	{"NN"},
"deviant":	{"JJ","NN"},
"deviants":	{"NNS"},
"deviate":	{"VB","VBP"},
"deviated":	{"VBD","VBN"},
"deviates":	{"VBZ"},
"deviating":	{"VBG"},
"deviation":	{"NN"},
"deviationism":	{"NN"},
"deviationist":	{"JJ","NN"},
"deviations":	{"NNS"},
"device":	{"NN"},
"devices":	{"NNS"},
"devil":	{"VB","NN"},
"devil-may-care":	{"JJ"},
"devil-worship":	{"NN"},
"deviled":	{"VBD","VBN"},
"devilfish":	{"NN"},
"deviling":	{"VBG"},
"devilise":	{"VB"},
"devilish":	{"JJ","NN"},
"devilishly":	{"RB"},
"devilize":	{"VB"},
"devilled":	{"VBD","VBN"},
"devilling":	{"VBG"},
"devilment":	{"NN"},
"devilry":	{"NN"},
"devils":	{"NNS","VBZ"},
"deviltry":	{"NN"},
"devilwood":	{"NN"},
"devine":	{"NN"},
"devious":	{"JJ"},
"deviously":	{"RB"},
"deviousness":	{"NN"},
"devisal":	{"NN"},
"devise":	{"VB","NN","VBP"},
"devised":	{"VBD","VBN"},
"devisee":	{"NN"},
"deviser":	{"NN"},
"devises":	{"VBZ","NNS"},
"devising":	{"VBG","NN"},
"devisor":	{"NN"},
"devitalisation":	{"NN"},
"devitalise":	{"VB"},
"devitalization":	{"NN"},
"devitalize":	{"VB"},
"devitrify":	{"VB"},
"devlopments":	{"NNS"},
"devoice":	{"VB"},
"devoid":	{"JJ"},
"devoir":	{"NN"},
"devolution":	{"NN"},
"devolve":	{"VB","VBP"},
"devolved":	{"VBD","VBN"},
"devolvement":	{"NN"},
"devolves":	{"VBZ"},
"devolving":	{"VBG"},
"devon":	{"NN"},
"devonian":	{"NN"},
"devonshire":	{"NN"},
"devote":	{"VB","VBP"},
"devoted":	{"VBN","VBD","JJ"},
"devotedly":	{"RB"},
"devotedness":	{"NN"},
"devotee":	{"NN"},
"devotees":	{"NNS"},
"devotes":	{"VBZ"},
"devoting":	{"VBG"},
"devotion":	{"NN"},
"devotional":	{"JJ","NN"},
"devotions":	{"NNS"},
"devour":	{"VB","VBP"},
"devoured":	{"VBD","VBN"},
"devourer":	{"NN"},
"devouring":	{"VBG"},
"devours":	{"VBZ"},
"devout":	{"JJ"},
"devoutly":	{"RB"},
"devoutness":	{"NN"},
"devries":	{"NN"},
"dew":	{"NN"},
"dew-sodden":	{"JJ"},
"dewar":	{"NN"},
"dewars":	{"NNS"},
"dewater":	{"VB","VBP"},
"dewatered":	{"VBD","VBN"},
"dewatering":	{"NN","VBG"},
"dewaters":	{"VBZ"},
"dewberry":	{"NN"},
"dewdrop":	{"NN"},
"dewdrops":	{"NNS"},
"dewed":	{"VBD","VBN"},
"deweyan":	{"JJ"},
"dewing":	{"VBG"},
"dewlap":	{"NN"},
"deworm":	{"VB","VBP"},
"dewormed":	{"VBD","VBN"},
"dewormer":	{"NN"},
"dewormers":	{"NNS"},
"deworming":	{"VBG"},
"deworms":	{"VBZ"},
"dews":	{"VBZ"},
"dewy":	{"JJ"},
"dewy-eyed":	{"JJ"},
"dexamethasone":	{"NN"},
"dexedrine":	{"NN"},
"dexone":	{"NN"},
"dexter":	{"JJ"},
"dexterity":	{"NN"},
"dexterous":	{"JJ"},
"dexterously":	{"RB"},
"dextral":	{"JJ"},
"dextrality":	{"NN"},
"dextrin":	{"NN"},
"dextrocardia":	{"NN"},
"dextroglucose":	{"NN"},
"dextrorotary":	{"JJ"},
"dextrorotation":	{"NN"},
"dextrorotatory":	{"JJ"},
"dextrorsal":	{"JJ"},
"dextrorse":	{"JJ"},
"dextrose":	{"NN"},
"dextrous":	{"JJ"},
"dextrous-fingered":	{"JJ"},
"dextrously":	{"RB"},
"dey":	{"NN"},
"dflp":	{"NN"},
"dg":	{"NN"},
"dhahran":	{"NN"},
"dhak":	{"NN"},
"dhaka":	{"NN"},
"dhal":	{"NN"},
"dharma":	{"NN"},
"dhaulagiri":	{"NN"},
"dhava":	{"NN"},
"dhawa":	{"NN"},
"dhegiha":	{"NN"},
"dhodhekanisos":	{"NNS"},
"dhole":	{"NN"},
"dhoti":	{"NN"},
"dhow":	{"NN"},
"di":	{"NN"},
"dia":	{"NN"},
"dia.":	{"NN","JJ"},
"diabatic":	{"JJ"},
"diabetes":	{"NN"},
"diabetic":	{"JJ","NN"},
"diabetics":	{"NNS"},
"diabolatry":	{"NN"},
"diabolic":	{"JJ"},
"diabolical":	{"JJ","NN"},
"diabolically":	{"RB"},
"diabolise":	{"VB"},
"diabolism":	{"NN"},
"diabolist":	{"NN"},
"diabolize":	{"VB"},
"diacalpa":	{"NN"},
"diacetylmorphine":	{"NN"},
"diachronic":	{"JJ"},
"diachrony":	{"NN"},
"diacritic":	{"JJ","NN"},
"diacritical":	{"JJ"},
"diadem":	{"NN","VB","VBP"},
"diademed":	{"VBD","VBN"},
"diademing":	{"VBG"},
"diadems":	{"NNS","VBZ"},
"diadophis":	{"NNS"},
"diadromous":	{"JJ"},
"diaeresis":	{"NN"},
"diaghilev":	{"NN"},
"diaglyph":	{"NN"},
"diagnometer":	{"NN"},
"diagnosable":	{"JJ"},
"diagnose":	{"VB","VBP"},
"diagnosed":	{"VBN","VBD"},
"diagnoses":	{"VBZ","NNS"},
"diagnosing":	{"VBG"},
"diagnosis":	{"NN"},
"diagnostic":	{"JJ"},
"diagnostician":	{"NN"},
"diagnosticians":	{"NNS"},
"diagnostics":	{"NN"},
"diagonal":	{"NN","JJ"},
"diagonalisation":	{"NN"},
"diagonalise":	{"VB"},
"diagonalizable":	{"JJ"},
"diagonalization":	{"NN"},
"diagonalize":	{"VB"},
"diagonally":	{"RB"},
"diagonals":	{"NNS"},
"diagram":	{"NN","VB","VBP"},
"diagrammatic":	{"JJ"},
"diagrammatical":	{"JJ"},
"diagrammatically":	{"RB"},
"diagrammed":	{"VBD","VBN"},
"diagramming":	{"VBG"},
"diagrams":	{"NNS","VBZ"},
"diakinesis":	{"NN"},
"dial":	{"NN","VB","VBP"},
"dial-a-banker":	{"JJ"},
"dial-tone":	{"NN"},
"dial-up":	{"NN","JJ"},
"dialect":	{"NN"},
"dialectal":	{"JJ","NN"},
"dialectic":	{"NN"},
"dialectical":	{"JJ"},
"dialectically":	{"RB"},
"dialectician":	{"NN"},
"dialectics":	{"NN"},
"dialectology":	{"NN"},
"dialects":	{"NNS"},
"dialed":	{"VBD","VBN"},
"dialeurodes":	{"NNS"},
"dialing":	{"VBG"},
"dialled":	{"VBD","VBN"},
"dialling":	{"VBG"},
"dialog":	{"NN","VB","VBP"},
"dialoged":	{"VBD","VBN"},
"dialoging":	{"VBG"},
"dialogs":	{"NNS","VBZ"},
"dialogue":	{"NN","VB","VBP"},
"dialogued":	{"VBD","VBN"},
"dialogues":	{"NNS","VBZ"},
"dialoguing":	{"VBG"},
"dials":	{"NNS","VBZ"},
"dialysability":	{"NN"},
"dialysable":	{"JJ"},
"dialysation":	{"NN"},
"dialyse":	{"VB","VBP"},
"dialysed":	{"VBD","VBN"},
"dialyses":	{"VBZ"},
"dialysing":	{"VBG"},
"dialysis":	{"NN"},
"dialyzability":	{"NN"},
"dialyzable":	{"JJ"},
"dialyzation":	{"NN"},
"dialyze":	{"VB","VBP"},
"dialyzed":	{"VBD","VBN"},
"dialyzer":	{"NN"},
"dialyzes":	{"VBZ"},
"dialyzing":	{"VBG"},
"diam":	{"NN"},
"diamagnet":	{"NN"},
"diamagnetic":	{"JJ"},
"diamagnetism":	{"NN"},
"diamante":	{"JJ"},
"diamantine":	{"JJ"},
"diameter":	{"NN"},
"diameters":	{"NNS"},
"diametral":	{"JJ"},
"diametric":	{"JJ"},
"diametrical":	{"JJ"},
"diametrically":	{"RB"},
"diamine":	{"NN"},
"diamond":	{"NN"},
"diamond-polishing":	{"NN"},
"diamond-shaped":	{"JJ"},
"diamond-studded":	{"VBD","VBN"},
"diamondback":	{"NN"},
"diamonded":	{"VBD","VBN"},
"diamonding":	{"VBG"},
"diamonds":	{"NNS","VBZ"},
"diana":	{"NN"},
"dianoetic":	{"JJ"},
"dianthus":	{"NN"},
"diapason":	{"NN"},
"diapedesis":	{"NN"},
"diapensia":	{"NN"},
"diapensiaceae":	{"NN"},
"diapensiales":	{"NNS"},
"diaper":	{"VB","NN"},
"diaper-changing":	{"JJ"},
"diapered":	{"VBD","VBN"},
"diapering":	{"VBG"},
"diapers":	{"VBZ","NNS"},
"diaphanous":	{"JJ"},
"diapheromera":	{"NN"},
"diaphone":	{"NN"},
"diaphoresis":	{"NN"},
"diaphoretic":	{"JJ","NN"},
"diaphragm":	{"NN"},
"diaphragmic":	{"JJ"},
"diaphragms":	{"NNS"},
"diaphyseal":	{"JJ"},
"diaphysial":	{"JJ"},
"diaphysis":	{"NN"},
"diapiace":	{"FW"},
"diapir":	{"NN"},
"diapsid":	{"NN"},
"diapsida":	{"NN"},
"diarchy":	{"NN"},
"diaries":	{"NNS"},
"diarist":	{"NN"},
"diarrhea":	{"NN"},
"diarrheal":	{"JJ","NN"},
"diarrheic":	{"JJ"},
"diarrhetic":	{"JJ"},
"diarrhoea":	{"NN"},
"diarrhoeal":	{"JJ"},
"diarrhoeic":	{"JJ"},
"diarrhoetic":	{"JJ"},
"diarthrosis":	{"NN"},
"diary":	{"NN"},
"diaspididae":	{"NN"},
"diaspora":	{"NN"},
"diastasis":	{"NN"},
"diastema":	{"NN"},
"diastole":	{"NN"},
"diastolic":	{"JJ"},
"diastrophism":	{"NN"},
"diathermy":	{"NN"},
"diathesis":	{"NN"},
"diatom":	{"NN"},
"diatomic":	{"JJ"},
"diatomite":	{"NN"},
"diatomophyceae":	{"NN"},
"diatoms":	{"NNS"},
"diatonic":	{"JJ"},
"diatribe":	{"NN"},
"diaz":	{"NN"},
"diazepam":	{"NN"},
"diazo":	{"JJ"},
"diazonium":	{"NN"},
"diazotize":	{"VB"},
"diazoxide":	{"NN"},
"dibber":	{"NN"},
"dibble":	{"VB","VBP","NN"},
"dibbled":	{"VBD","VBN"},
"dibbles":	{"VBZ","NNS"},
"dibbling":	{"VBG"},
"dibbuk":	{"NN"},
"dibenzofurans":	{"NNS"},
"dibrach":	{"NN"},
"dibranch":	{"NN"},
"dibranchia":	{"NN"},
"dibranchiata":	{"NN"},
"dibranchiate":	{"NN"},
"dibs":	{"NNS"},
"dibucaine":	{"NN"},
"dicamptodon":	{"NN"},
"dicamptodontid":	{"NN"},
"dicamptodontidae":	{"NN"},
"dicarban":	{"NN"},
"dicarboxylic":	{"JJ"},
"dicate":	{"VBP","VB"},
"dice":	{"NNS","NN","VBP","VB"},
"diced":	{"VBD","VBN","JJ"},
"dicendi":	{"FW"},
"dicentra":	{"NN"},
"dicer":	{"NN"},
"diceros":	{"NNS"},
"dices":	{"VBZ"},
"dicey":	{"JJ","NN"},
"dichloride":	{"NN"},
"dichlorodiphenyltrichloroethane":	{"NN"},
"dichloromethane":	{"NN"},
"dichondra":	{"NN"},
"dichotomisation":	{"NN"},
"dichotomise":	{"VB"},
"dichotomization":	{"NN"},
"dichotomize":	{"VB"},
"dichotomous":	{"JJ"},
"dichotomously":	{"RB"},
"dichotomy":	{"NN"},
"dichroism":	{"NN"},
"dichromacy":	{"NN"},
"dichromasy":	{"NN"},
"dichromat":	{"NN"},
"dichromate":	{"NN"},
"dichromatic":	{"JJ"},
"dichromatism":	{"NN"},
"dichromatopsia":	{"NN"},
"dichromia":	{"NN"},
"dicing":	{"VBG"},
"dick":	{"NN","VBP","VB"},
"dicked":	{"VBD","VBN"},
"dickens":	{"NN"},
"dicker":	{"VB","VBP"},
"dickered":	{"VBD","VBN"},
"dickering":	{"VBG"},
"dickers":	{"VBZ"},
"dickey":	{"NN"},
"dickey-bird":	{"NN"},
"dickey-seat":	{"NN"},
"dickeybird":	{"NN"},
"dickhead":	{"NN"},
"dickie":	{"NN"},
"dickie-seat":	{"NN"},
"dickier":	{"JJR"},
"dickiest":	{"JJS"},
"dicking":	{"VBG"},
"dickinson":	{"NN"},
"dickless":	{"JJ"},
"dicks":	{"NNS","VBZ"},
"dicksonia":	{"NN"},
"dicksoniaceae":	{"NN"},
"dicky":	{"JJ","NN"},
"dicky-bird":	{"NN"},
"dicky-seat":	{"NN"},
"dickybird":	{"NN"},
"diclinous":	{"JJ"},
"diclosed":	{"VBN"},
"dicloxacillin":	{"NN"},
"dicot":	{"NN"},
"dicotyledon":	{"NN"},
"dicotyledonae":	{"NN"},
"dicotyledones":	{"NNS"},
"dicotyledonous":	{"JJ"},
"dicoumarol":	{"NN"},
"dicranaceae":	{"NN"},
"dicranales":	{"NNS"},
"dicranopteris":	{"NNS"},
"dicranum":	{"NN"},
"dicrostonyx":	{"NN"},
"dictamnus":	{"NN"},
"dictaphone":	{"NN"},
"dictate":	{"VB","VBP","NN"},
"dictated":	{"VBD","VBN"},
"dictates":	{"VBZ","NNS"},
"dictating":	{"VBG"},
"dictation":	{"NN"},
"dictator":	{"NN"},
"dictatorial":	{"JJ"},
"dictatorially":	{"RB"},
"dictators":	{"NNS"},
"dictatorship":	{"NN"},
"dictatorships":	{"NNS"},
"diction":	{"NN"},
"dictionaries":	{"NNS"},
"dictionary":	{"NN"},
"dictostylium":	{"NN"},
"dictum":	{"NN"},
"dictyophera":	{"NN"},
"dictyoptera":	{"NN"},
"dictyopteran":	{"JJ"},
"dictyosome":	{"NN"},
"dicumarol":	{"NN"},
"dicynodont":	{"NN"},
"dicynodontia":	{"NN"},
"did":	{"VBD"},
"didactic":	{"JJ"},
"didactical":	{"JJ"},
"didactically":	{"RB"},
"didacticism":	{"NN"},
"didactics":	{"NN"},
"didanosine":	{"NN"},
"didder":	{"VB"},
"diddle":	{"VB","VBP"},
"diddled":	{"VBD","VBN"},
"diddles":	{"VBZ"},
"diddley":	{"NN"},
"diddling":	{"VBG"},
"diddly":	{"NN"},
"diddly-shit":	{"NN"},
"diddly-squat":	{"NN"},
"diddlyshit":	{"NN"},
"diddlysquat":	{"NN"},
"didelphidae":	{"NN"},
"didelphis":	{"NNS"},
"dideoxycytosine":	{"NN"},
"dideoxyinosine":	{"NN"},
"diderot":	{"NN"},
"didion":	{"NN"},
"dido":	{"NN"},
"didrikson":	{"NN"},
"die":	{"VB","VBP","NN"},
"die-cast":	{"JJ"},
"die-dead":	{"NN"},
"die-hard":	{"JJ","NN"},
"die-hards":	{"NNS"},
"die-sinker":	{"NN"},
"die-up":	{"NN"},
"dieback":	{"NN"},
"died":	{"VBD","VBN"},
"dieffenbachia":	{"NN"},
"diego-area":	{"JJ"},
"diegueno":	{"NN"},
"diehard":	{"JJ","NN"},
"diehards":	{"NNS"},
"dielectric":	{"JJ","NN"},
"dielectrolysis":	{"NN"},
"diem":	{"NN"},
"diemaker":	{"NN"},
"diencephalon":	{"NN"},
"dieresis":	{"NN"},
"diervilla":	{"NN"},
"dies":	{"VBZ","NNS"},
"diesel":	{"NN","JJ"},
"diesel-electric":	{"NN"},
"diesel-hydraulic":	{"NN"},
"diesels":	{"NNS"},
"diesinker":	{"NN"},
"diesis":	{"NN"},
"diestock":	{"NN"},
"diestrous":	{"JJ"},
"diestrual":	{"JJ"},
"diestrum":	{"NN"},
"diestrus":	{"NN"},
"diet":	{"NN","VB","VBP","JJ"},
"dietary":	{"JJ","NN"},
"dieted":	{"VBD","VBN"},
"dieter":	{"NN"},
"dieters":	{"NNS"},
"dietetic":	{"JJ"},
"dietetical":	{"JJ"},
"dietetics":	{"NN"},
"diethylaminoethyl":	{"NN"},
"diethylmalonylurea":	{"NN"},
"diethylstilbesterol":	{"NN"},
"diethylstilbestrol":	{"NN"},
"diethylstilboestrol":	{"NN"},
"dietician":	{"NN"},
"dieticians":	{"NNS"},
"dieting":	{"VBG","NN"},
"dietitian":	{"NN"},
"dietitians":	{"NNS"},
"diets":	{"NNS","VBZ"},
"diety":	{"NN"},
"diff":	{"NN"},
"differ":	{"VB","VBP"},
"differed":	{"VBD","VBN"},
"difference":	{"NN","VB","VBP"},
"differenced":	{"VBD","VBN"},
"differences":	{"NNS","VBZ"},
"differencing":	{"VBG"},
"different":	{"JJ"},
"different-color":	{"JJ"},
"differentia":	{"NN"},
"differentiability":	{"NN"},
"differentiable":	{"JJ"},
"differential":	{"NN","JJ"},
"differentially":	{"RB"},
"differentials":	{"NNS"},
"differentiate":	{"VB","VBP"},
"differentiated":	{"VBD","VBN"},
"differentiates":	{"VBZ"},
"differentiating":	{"VBG"},
"differentiation":	{"NN"},
"differentiator":	{"NN"},
"differently":	{"RB"},
"differing":	{"VBG"},
"differs":	{"VBZ"},
"difficile":	{"JJ","NN"},
"difficult":	{"JJ"},
"difficulties":	{"NNS"},
"difficultness":	{"NN"},
"difficulty":	{"NN"},
"diffidence":	{"NN"},
"diffident":	{"JJ","NN"},
"diffidently":	{"RB"},
"difflugia":	{"NN"},
"diffract":	{"VB","VBP"},
"diffracted":	{"VBD","VBN"},
"diffracting":	{"VBG"},
"diffraction":	{"NN"},
"diffracts":	{"VBZ"},
"diffrunce":	{"NN"},
"diffuse":	{"VB","VBP","JJ"},
"diffused":	{"VBD","VBN"},
"diffusely":	{"RB"},
"diffuseness":	{"NN"},
"diffuser":	{"NN"},
"diffusers":	{"NNS"},
"diffuses":	{"VBZ"},
"diffusing":	{"VBG"},
"diffusion":	{"NN"},
"diffusive":	{"JJ"},
"diffusor":	{"NN"},
"diflunisal":	{"NN"},
"dig":	{"VB","VBP","NN"},
"digenesis":	{"NN"},
"digest":	{"VB","VBP","NN"},
"digest-size":	{"JJ"},
"digested":	{"VBD","VBN"},
"digester":	{"NN"},
"digestibility":	{"NN"},
"digestible":	{"JJ"},
"digestibleness":	{"NN"},
"digesting":	{"VBG"},
"digestion":	{"NN"},
"digestions":	{"NNS"},
"digestive":	{"JJ","NN"},
"digestives":	{"NNS"},
"digests":	{"VBZ","NNS"},
"digge":	{"VB"},
"digger":	{"NN"},
"diggers":	{"NNS"},
"digging":	{"NN","VBG"},
"diggings":	{"NNS"},
"dighted":	{"JJ"},
"digit":	{"NN"},
"digital":	{"JJ"},
"digitalin":	{"NN"},
"digitalis":	{"NN"},
"digitalisation":	{"NN"},
"digitalise":	{"VB","VBP"},
"digitalised":	{"VBD","VBN"},
"digitalises":	{"VBZ"},
"digitalising":	{"VBG"},
"digitalization":	{"NN"},
"digitalize":	{"VB","VBP"},
"digitalized":	{"VBD","VBN"},
"digitalizes":	{"VBZ"},
"digitalizing":	{"VBG"},
"digitally":	{"RB"},
"digitaria":	{"NN"},
"digitate":	{"JJ"},
"digitately":	{"RB"},
"digitigrade":	{"JJ"},
"digitisation":	{"NN"},
"digitise":	{"VB","VBP"},
"digitised":	{"VBD","VBN"},
"digitiser":	{"NN"},
"digitises":	{"VBZ"},
"digitising":	{"VBG"},
"digitization":	{"NN"},
"digitize":	{"VB","VBP"},
"digitized":	{"VBN","VBD"},
"digitizer":	{"NN"},
"digitizes":	{"VBZ"},
"digitizing":	{"VBG"},
"digitoxin":	{"NN"},
"digits":	{"NNS"},
"dignified":	{"JJ","VBD","VBN"},
"dignifies":	{"VBZ"},
"dignify":	{"VB","VBP"},
"dignifying":	{"VBG"},
"dignitaries":	{"NNS"},
"dignitary":	{"NN","JJ"},
"dignity":	{"NN"},
"digoxin":	{"NN"},
"digram":	{"NN"},
"digraph":	{"NN"},
"digress":	{"VB","VBP"},
"digressed":	{"VBD","VBN"},
"digresses":	{"VBZ"},
"digressing":	{"VBG"},
"digression":	{"NN"},
"digressions":	{"NNS"},
"digressive":	{"JJ"},
"digs":	{"NNS","VBZ"},
"dihybrid":	{"NN"},
"dihydrostreptomycin":	{"NN"},
"dihydroxyphenylalanine":	{"NN"},
"diisocyanate":	{"NN"},
"dik-dik":	{"NN"},
"dika":	{"NN"},
"dike":	{"NN"},
"diked":	{"VBD","VBN"},
"dikes":	{"VBZ"},
"diking":	{"VBG"},
"diktat":	{"NN"},
"dilantin":	{"NN"},
"dilapidate":	{"VB"},
"dilapidated":	{"JJ"},
"dilapidation":	{"NN"},
"dilatation":	{"NN"},
"dilate":	{"VB","VBP"},
"dilated":	{"VBD","VBN","JJ"},
"dilater":	{"NN"},
"dilates":	{"VBZ"},
"dilating":	{"VBG"},
"dilation":	{"NN"},
"dilator":	{"NN"},
"dilatorily":	{"RB"},
"dilatoriness":	{"NN"},
"dilatory":	{"JJ"},
"dilaudid":	{"NN"},
"dildo":	{"NN"},
"dilemma":	{"NN"},
"dilemmas":	{"NNS"},
"dilettante":	{"NN","JJ"},
"dilettanteish":	{"JJ"},
"dilettantish":	{"JJ"},
"diligence":	{"NN"},
"diligent":	{"JJ"},
"diligently":	{"RB"},
"dill":	{"NN"},
"dillenia":	{"NN"},
"dilleniaceae":	{"NN"},
"dilleniidae":	{"NN"},
"dilly-dallied":	{"VBD","VBN"},
"dilly-dallier":	{"NN"},
"dilly-dallies":	{"VBZ"},
"dilly-dally":	{"VB","VBP"},
"dilly-dallying":	{"VBG"},
"dillydallied":	{"VBD","VBN"},
"dillydallier":	{"NN"},
"dillydallies":	{"VBZ"},
"dillydally":	{"VB","VBP"},
"dillydallying":	{"VBG"},
"diltiazem":	{"NN"},
"diluent":	{"NN","JJ"},
"diluents":	{"NNS"},
"dilutant":	{"NN"},
"dilute":	{"VB","VBP","JJ"},
"diluted":	{"VBD","VBN"},
"dilutes":	{"VBZ"},
"diluting":	{"VBG"},
"dilution":	{"NN"},
"dilutions":	{"NNS"},
"dilutive":	{"JJ"},
"diluvial":	{"JJ"},
"diluvian":	{"JJ"},
"dim":	{"JJ","VBP","NN","VB"},
"dim-sighted":	{"JJ"},
"dim-witted":	{"JJ"},
"dimaggio":	{"NN"},
"dimash":	{"NN"},
"dime":	{"NN"},
"dimenhydrinate":	{"NN"},
"dimension":	{"NN"},
"dimensional":	{"JJ"},
"dimensionality":	{"NN"},
"dimensionally":	{"RB"},
"dimensioned":	{"VBD","VBN"},
"dimensioning":	{"JJ","VBG"},
"dimensions":	{"NNS","VBZ"},
"dimer":	{"NN"},
"dimers":	{"NNS"},
"dimes":	{"NNS"},
"dimesize":	{"JJ"},
"dimetane":	{"NN"},
"dimetapp":	{"NN"},
"dimethylglyoxime":	{"NN"},
"dimetrodon":	{"NN"},
"diming":	{"VBG","NN"},
"diminish":	{"VB","VBP"},
"diminished":	{"VBD","VBN","JJ"},
"diminishes":	{"VBZ"},
"diminishing":	{"VBG"},
"diminuendo":	{"NN","JJ","RB"},
"diminuendos":	{"NNS"},
"diminution":	{"NN"},
"diminutive":	{"JJ","NN"},
"diminutiveness":	{"NN"},
"dimitri":	{"NN"},
"dimity":	{"NN"},
"dimly":	{"RB"},
"dimly-outlined":	{"JJ"},
"dimmed":	{"JJ","VBD","VBN"},
"dimmer":	{"NN","JJR"},
"dimmest":	{"JJS"},
"dimming":	{"NN","VBG"},
"dimness":	{"NN"},
"dimocarpus":	{"NNS"},
"dimorphic":	{"JJ"},
"dimorphism":	{"NN"},
"dimorphotheca":	{"NN"},
"dimorphous":	{"JJ"},
"dimout":	{"NN"},
"dimple":	{"NN","VB","VBP"},
"dimpled":	{"VBD","VBN","JJ"},
"dimples":	{"NNS","VBZ"},
"dimpling":	{"VBG"},
"dims":	{"VBZ"},
"dimwit":	{"NN"},
"dimwits":	{"NNS"},
"dimwitted":	{"JJ"},
"din":	{"NN","VBP","VB"},
"dinar":	{"NN"},
"dindymene":	{"NN"},
"dine":	{"VB","VBP"},
"dined":	{"VBD","VBN"},
"diner":	{"NN"},
"dinero":	{"NN"},
"diners":	{"NNS"},
"dines":	{"VBZ"},
"dinette":	{"NN"},
"dinettes":	{"NNS"},
"ding":	{"NN","VB","VBP"},
"ding-dong":	{"NN","RB"},
"dingbat":	{"NN"},
"dinge":	{"NN"},
"dinged":	{"VBD","VBN"},
"dinghies":	{"NNS"},
"dinghy":	{"NN"},
"dingier":	{"JJR"},
"dingiest":	{"JJS"},
"dingily":	{"RB"},
"dinginess":	{"NN"},
"dinging":	{"VBG"},
"dingle":	{"NN"},
"dingo":	{"NN"},
"dingoes":	{"NNS"},
"dings":	{"NNS","VBZ"},
"dingy":	{"JJ"},
"dingy-looking":	{"JJ"},
"dining":	{"NN","VBG"},
"dining-car":	{"NN"},
"dining-cars":	{"NNS"},
"dining-hall":	{"NN"},
"dining-room":	{"NN"},
"dining-table":	{"NN"},
"dining-tables":	{"NNS"},
"dink":	{"NN","VB","VBP"},
"dinka":	{"NN"},
"dinked":	{"VBD","VBN"},
"dinkey":	{"NN"},
"dinkier":	{"JJR"},
"dinkiest":	{"JJS"},
"dinking":	{"VBG"},
"dinks":	{"NNS","VBZ"},
"dinky":	{"JJ"},
"dinna":	{"VB","VBP"},
"dinnae":	{"VB","VBP"},
"dinned":	{"VBD","VBN"},
"dinner":	{"NN"},
"dinner-hour":	{"JJ"},
"dinner-jacket":	{"NN"},
"dinner-jackets":	{"NNS"},
"dinner-parties":	{"NNS"},
"dinner-party":	{"NN"},
"dinners":	{"NNS"},
"dinnertime":	{"NN"},
"dinnerware":	{"NN"},
"dinning":	{"VBG"},
"dino":	{"NN"},
"dinoceras":	{"NNS"},
"dinocerata":	{"NN"},
"dinocerate":	{"NN"},
"dinoflagellata":	{"NN"},
"dinoflagellate":	{"NN"},
"dinornis":	{"NNS"},
"dinornithidae":	{"NN"},
"dinornithiformes":	{"NNS"},
"dinosaur":	{"NN"},
"dinosaurs":	{"NNS"},
"dins":	{"VBZ"},
"dint":	{"NN","VB","VBP"},
"dinted":	{"VBD","VBN"},
"dinting":	{"VBG"},
"dints":	{"VBZ"},
"diocesan":	{"NN","JJ"},
"diocese":	{"NN"},
"dioceses":	{"NNS"},
"diocletian":	{"NN"},
"diocs":	{"NNS"},
"diode":	{"NN"},
"diodon":	{"NN"},
"diodontidae":	{"NN"},
"dioecian":	{"JJ"},
"dioecious":	{"JJ"},
"dioestrous":	{"JJ"},
"dioestrual":	{"JJ"},
"diol":	{"NN"},
"diomedeidae":	{"NN"},
"dionaea":	{"NN"},
"dionysia":	{"NN"},
"dionysian":	{"JJ"},
"dionysius":	{"NNS"},
"dionysus":	{"NNS"},
"dioon":	{"NN"},
"diophantus":	{"NNS"},
"diopter":	{"NN"},
"dioptre":	{"NN"},
"dior":	{"NN"},
"diorah":	{"NN"},
"diorama":	{"NN"},
"dioramas":	{"NNS"},
"diorite":	{"NN"},
"dioscorea":	{"NN"},
"dioscoreaceae":	{"NN"},
"diospyros":	{"NNS"},
"diovan":	{"NN"},
"dioxalate":	{"NN"},
"dioxide":	{"NN"},
"dioxin":	{"NN"},
"dioxins":	{"NNS"},
"dip":	{"NN","VB","VBP"},
"diphenhydramine":	{"NN"},
"diphenylhydantoin":	{"NN"},
"diphosphopyridine":	{"JJ"},
"diphtheria":	{"NN"},
"diphthong":	{"NN"},
"diphthongisation":	{"NN"},
"diphthongise":	{"VB","VBP"},
"diphthongised":	{"VBD","VBN"},
"diphthongises":	{"VBZ"},
"diphthongising":	{"VBG"},
"diphthongization":	{"NN"},
"diphthongize":	{"VB","VBP"},
"diphthongized":	{"VBD","VBN"},
"diphthongizes":	{"VBZ"},
"diphthongizing":	{"VBG"},
"diphthongs":	{"NNS"},
"diphylla":	{"NN"},
"dipladenia":	{"NN"},
"diplegia":	{"NN"},
"diplococcus":	{"NN"},
"diplodocus":	{"NN"},
"diploid":	{"NN"},
"diploidy":	{"NN"},
"diploma":	{"NN"},
"diplomacy":	{"NN"},
"diplomas":	{"NNS"},
"diplomat":	{"NN"},
"diplomate":	{"NN"},
"diplomatic":	{"JJ"},
"diplomatical":	{"JJ"},
"diplomatically":	{"RB"},
"diplomatist":	{"NN"},
"diplomats":	{"NNS"},
"diplopia":	{"NN"},
"diplopoda":	{"NN"},
"diplopterygium":	{"NN"},
"diplotaxis":	{"NNS"},
"diplotene":	{"NN"},
"dipnoi":	{"NN"},
"dipodidae":	{"NN"},
"dipodomys":	{"NNS"},
"dipogon":	{"NN"},
"dipolar":	{"JJ"},
"dipole":	{"NN"},
"dipoles":	{"NNS"},
"dipotassium":	{"NN"},
"dipped":	{"VBD","VBN"},
"dipper":	{"NN"},
"dippers":	{"NNS"},
"dipping":	{"NN","VBG"},
"dippy":	{"JJ"},
"dips":	{"NNS","VBZ"},
"dipsacaceae":	{"NN"},
"dipsacus":	{"NNS"},
"dipsomania":	{"NN"},
"dipsomaniac":	{"NN"},
"dipsosaurus":	{"NN"},
"dipstick":	{"NN"},
"dipsticks":	{"NNS"},
"diptera":	{"NN"},
"dipteran":	{"NN"},
"dipterocarp":	{"NN"},
"dipterocarpaceae":	{"NN"},
"dipteron":	{"NN"},
"dipteronia":	{"NN"},
"dipterous":	{"JJ"},
"dipteryx":	{"NN"},
"diptych":	{"NN"},
"dipus":	{"NNS"},
"dipylon":	{"JJ","NN"},
"dirac":	{"NN"},
"dirca":	{"NN"},
"dire":	{"JJ","FW"},
"direct":	{"JJ","VBP","RB","VB"},
"direct-investment":	{"JJ"},
"direct-line":	{"JJ"},
"direct-mail":	{"NN"},
"direct-mail-mogul":	{"NN"},
"direct-marketed":	{"JJ"},
"direct-marketing":	{"NN"},
"direct-seller":	{"NN"},
"direct-selling":	{"JJ"},
"direct-steelmaking":	{"NN"},
"direct-sum":	{"NN"},
"directed":	{"VBN","VBD"},
"directing":	{"VBG","NN"},
"direction":	{"NN"},
"directional":	{"JJ"},
"directionality":	{"NN"},
"directionally":	{"RB"},
"directionless":	{"JJ"},
"directionlessness":	{"NN"},
"directions":	{"NNS"},
"directive":	{"NN","JJ"},
"directiveness":	{"NN"},
"directives":	{"NNS"},
"directivity":	{"NN"},
"directly":	{"RB","IN"},
"directmail":	{"NN"},
"directness":	{"NN"},
"director":	{"NN"},
"director-general":	{"NN"},
"directorate":	{"NN"},
"directorial":	{"JJ"},
"directories":	{"NNS"},
"directors":	{"NNS"},
"directorship":	{"NN"},
"directory":	{"NN","JJ"},
"directrices":	{"NNS"},
"directs":	{"VBZ"},
"direful":	{"JJ"},
"direfully":	{"RB"},
"dirge":	{"NN"},
"dirham":	{"NN"},
"dirhams":	{"NNS"},
"dirigible":	{"JJ","NN"},
"dirk":	{"NN"},
"dirndl":	{"NN"},
"dirt":	{"NN"},
"dirt-catcher":	{"NN"},
"dirtied":	{"VBD","VBN"},
"dirtier":	{"JJR"},
"dirtier-running":	{"JJ"},
"dirties":	{"VBZ"},
"dirtiest":	{"JJS"},
"dirtily":	{"RB"},
"dirtiness":	{"NN"},
"dirty":	{"JJ","VBP","VB","RB"},
"dirty-faced":	{"JJ"},
"dirty-minded":	{"JJ"},
"dirtying":	{"VBG"},
"dis":	{"NN"},
"disa":	{"NN"},
"disabilities":	{"NNS"},
"disability":	{"NN"},
"disable":	{"VB","VBP"},
"disabled":	{"JJ","VBN","NNS","VBD"},
"disabled-workers":	{"NNS"},
"disablement":	{"NN"},
"disables":	{"VBZ"},
"disabling":	{"VBG","JJ"},
"disabuse":	{"VB","VBP"},
"disabused":	{"VBD","VBN"},
"disabuses":	{"VBZ"},
"disabusing":	{"VBG"},
"disaccharidase":	{"NN"},
"disaccharide":	{"NN"},
"disaccord":	{"VB","VBP","NN"},
"disaccorded":	{"VBD","VBN"},
"disaccording":	{"VBG"},
"disaccords":	{"VBZ"},
"disacquaintance":	{"NN"},
"disadvantage":	{"NN","VB","VBP"},
"disadvantaged":	{"VBD","VBN","JJ","NNS"},
"disadvantageous":	{"JJ"},
"disadvantageously":	{"RB"},
"disadvantages":	{"NNS","VBZ"},
"disadvantaging":	{"VBG"},
"disaffect":	{"VB","VBP"},
"disaffected":	{"JJ","VBD","VBN"},
"disaffecting":	{"VBG"},
"disaffection":	{"NN"},
"disaffects":	{"VBZ"},
"disaffiliate":	{"VBP","VB"},
"disaffiliated":	{"VBD","VBN"},
"disaffiliation":	{"NN"},
"disaffirmation":	{"NN"},
"disafforest":	{"VB"},
"disagree":	{"VB","VBP"},
"disagreeable":	{"JJ"},
"disagreeableness":	{"NN"},
"disagreeably":	{"RB"},
"disagreed":	{"VBD","VBN"},
"disagreeing":	{"VBG"},
"disagreement":	{"NN"},
"disagreements":	{"NNS"},
"disagrees":	{"VBZ"},
"disallow":	{"VB","VBP"},
"disallowance":	{"NN"},
"disallowed":	{"VBD","VBN"},
"disallowing":	{"VBG"},
"disallows":	{"VBZ"},
"disambiguate":	{"VB"},
"disambiguation":	{"NN"},
"disambiguator":	{"NN"},
"disappear":	{"VB","VBP"},
"disappearance":	{"NN"},
"disappearances":	{"NN"},
"disappeared":	{"VBD","VBN"},
"disappearing":	{"VBG"},
"disappears":	{"VBZ"},
"disappoint":	{"VB","VBP"},
"disappointed":	{"VBN","JJ","VBD"},
"disappointedly":	{"RB"},
"disappointing":	{"JJ","VBG"},
"disappointingly":	{"RB"},
"disappointment":	{"NN"},
"disappointments":	{"NNS"},
"disappoints":	{"VBZ"},
"disapprobation":	{"NN"},
"disapproval":	{"NN"},
"disapprove":	{"VB","VBP"},
"disapproved":	{"VBD","VBN"},
"disapproves":	{"VBZ"},
"disapproving":	{"VBG","JJ"},
"disapprovingly":	{"RB"},
"disarm":	{"VB","VBP"},
"disarmament":	{"NN"},
"disarmed":	{"VBN","VBD"},
"disarmer":	{"NN"},
"disarming":	{"JJ","VBG"},
"disarmingly":	{"RB"},
"disarms":	{"VBZ"},
"disarrange":	{"VB","VBP"},
"disarranged":	{"VBD","VBN"},
"disarrangement":	{"NN"},
"disarranges":	{"VBZ"},
"disarranging":	{"VBG"},
"disarray":	{"NN"},
"disarrayed":	{"JJ","VBD","VBN"},
"disarraying":	{"VBG"},
"disarrays":	{"VBZ"},
"disarticulate":	{"VB","VBP"},
"disarticulated":	{"VBD","VBN"},
"disarticulates":	{"VBZ"},
"disarticulating":	{"VBG"},
"disarticulation":	{"NN"},
"disarticulator":	{"NN"},
"disassemble":	{"VB","VBP"},
"disassembled":	{"VBD","VBN"},
"disassembles":	{"VBZ"},
"disassembling":	{"VBG"},
"disassembly":	{"NN"},
"disassociate":	{"VB","VBP"},
"disassociated":	{"VBD","VBN"},
"disassociates":	{"VBZ"},
"disassociating":	{"VBG"},
"disassociation":	{"NN"},
"disaster":	{"NN"},
"disaster-assistance":	{"JJ"},
"disaster-contingency":	{"NN"},
"disaster-prone":	{"JJ"},
"disaster-recovery":	{"JJ","NN"},
"disaster-subsidy":	{"JJ"},
"disasters":	{"NNS"},
"disastrous":	{"JJ"},
"disastrously":	{"RB"},
"disavow":	{"VB","VBP"},
"disavowable":	{"JJ"},
"disavowal":	{"NN"},
"disavowals":	{"NNS"},
"disavowed":	{"VBD","VBN"},
"disavowing":	{"VBG"},
"disavows":	{"VBZ"},
"disband":	{"VB","VBP"},
"disbanded":	{"VBN","VBD"},
"disbanding":	{"VBG"},
"disbandment":	{"NN"},
"disbands":	{"VBZ"},
"disbar":	{"VB","VBP"},
"disbarment":	{"NN"},
"disbarred":	{"VBD","VBN"},
"disbarring":	{"VBG"},
"disbars":	{"VBZ"},
"disbelief":	{"NN"},
"disbelieve":	{"VB","VBP"},
"disbelieved":	{"VBD","VBN"},
"disbeliever":	{"NN"},
"disbelieves":	{"VBZ"},
"disbelieving":	{"JJ","VBG"},
"disbelievingly":	{"RB"},
"disbud":	{"VB"},
"disburden":	{"VB","VBP"},
"disburdened":	{"VBD","VBN"},
"disburdening":	{"VBG"},
"disburdens":	{"VBZ"},
"disbursal":	{"NN"},
"disburse":	{"VB","VBP"},
"disbursed":	{"VBN","VBD"},
"disbursement":	{"NN"},
"disbursements":	{"NNS"},
"disburser":	{"NN"},
"disburses":	{"VBZ"},
"disbursing":	{"VBG"},
"disc":	{"NN"},
"disc-jockey":	{"NN"},
"disc-jockeys":	{"NNS"},
"disc-shaped":	{"JJ"},
"discalceate":	{"JJ"},
"discalced":	{"JJ"},
"discant":	{"NN"},
"discard":	{"VB","NN","VBP"},
"discarded":	{"VBD","VBN"},
"discarding":	{"VBG"},
"discards":	{"VBZ","NNS"},
"discase":	{"VB"},
"disced":	{"VBD","VBN"},
"disceptation":	{"NN"},
"discern":	{"VB","VBP"},
"discernability":	{"NN"},
"discernable":	{"JJ"},
"discerned":	{"VBD","VBN"},
"discernible":	{"JJ"},
"discernibly":	{"RB"},
"discerning":	{"JJ","VBG"},
"discernment":	{"NN"},
"discerns":	{"VBZ"},
"discerp":	{"VB"},
"discharge":	{"NN","VB","VBP"},
"discharged":	{"JJ","VBD","VBN"},
"discharges":	{"NNS","VBZ"},
"discharging":	{"NN","VBG"},
"disciform":	{"JJ"},
"discimination":	{"NN"},
"discina":	{"NN"},
"discing":	{"VBG"},
"disciple":	{"NN"},
"disciples":	{"NNS"},
"discipleship":	{"NN"},
"disciplinal":	{"JJ"},
"disciplinarian":	{"NN"},
"disciplinarians":	{"NNS"},
"disciplinary":	{"JJ"},
"discipline":	{"NN","VB","VBP"},
"disciplined":	{"JJ","VBN","VBD"},
"disciplines":	{"NNS","VBZ"},
"disciplining":	{"VBG"},
"disclaim":	{"VB","VBP"},
"disclaimed":	{"VBD","VBN"},
"disclaimer":	{"NN"},
"disclaimers":	{"NNS"},
"disclaiming":	{"VBG"},
"disclaims":	{"VBZ"},
"disclike":	{"JJ"},
"disclose":	{"VB","VBP"},
"disclosed":	{"VBN","VBD"},
"discloses":	{"VBZ"},
"disclosing":	{"VBG"},
"disclosure":	{"NN"},
"disclosures":	{"NNS"},
"disco":	{"VB","NN"},
"discocephali":	{"NN"},
"discoed":	{"VBD","VBN"},
"discoglossidae":	{"NN"},
"discography":	{"NN"},
"discoid":	{"JJ"},
"discoidal":	{"JJ"},
"discoing":	{"VBG"},
"discolor":	{"VB","VBP"},
"discoloration":	{"NN"},
"discolored":	{"VBN","VBD"},
"discoloring":	{"VBG"},
"discolors":	{"VBZ"},
"discolour":	{"VB","VBP"},
"discolouration":	{"NN"},
"discoloured":	{"VBD","VBN"},
"discolouring":	{"VBG"},
"discolours":	{"VBZ"},
"discombobulate":	{"VB","VBP"},
"discombobulated":	{"VBD","VBN","JJ"},
"discombobulates":	{"VBZ"},
"discombobulating":	{"VBG"},
"discombobulation":	{"NN"},
"discomfit":	{"VB","VBP"},
"discomfited":	{"VBD","VBN"},
"discomfiting":	{"VBG"},
"discomfits":	{"VBZ"},
"discomfiture":	{"NN"},
"discomfort":	{"NN","VB","VBP"},
"discomforted":	{"VBD","VBN"},
"discomforting":	{"VBG"},
"discomforts":	{"VBZ","NNS"},
"discommode":	{"VB","VBP"},
"discommoded":	{"VBD","VBN"},
"discommodes":	{"VBZ"},
"discommoding":	{"VBG"},
"discompose":	{"VB","VBP"},
"discomposed":	{"VBD","VBN"},
"discomposes":	{"VBZ"},
"discomposing":	{"VBG"},
"discomposure":	{"NN"},
"discomycete":	{"NN"},
"discomycetes":	{"NNS"},
"discomycetous":	{"JJ"},
"disconcert":	{"VB","VBP"},
"disconcerted":	{"JJ","VBD","VBN"},
"disconcerting":	{"JJ","VBG"},
"disconcertingly":	{"RB"},
"disconcertion":	{"NN"},
"disconcertment":	{"NN"},
"disconcerts":	{"VBZ"},
"disconfirming":	{"JJ"},
"disconnect":	{"VB","VBP"},
"disconnected":	{"JJ","VBD","VBN"},
"disconnectedly":	{"RB"},
"disconnectedness":	{"NN"},
"disconnecting":	{"VBG"},
"disconnection":	{"NN"},
"disconnections":	{"NNS"},
"disconnects":	{"VBZ"},
"disconsolate":	{"JJ","NN"},
"disconsolately":	{"RB"},
"disconsolateness":	{"NN"},
"discontent":	{"NN","VB","VBP"},
"discontented":	{"JJ","VBD","VBN"},
"discontentedly":	{"RB"},
"discontentedness":	{"NN"},
"discontenting":	{"VBG"},
"discontentment":	{"NN"},
"discontents":	{"NNS","VBZ"},
"discontinuance":	{"NN"},
"discontinuation":	{"NN"},
"discontinue":	{"VB","VBP"},
"discontinued":	{"VBD","VBN"},
"discontinues":	{"VBZ"},
"discontinuing":	{"VBG"},
"discontinuities":	{"NNS"},
"discontinuity":	{"NN"},
"discontinuous":	{"JJ"},
"discontinuously":	{"RB"},
"discord":	{"NN","VB","VBP"},
"discordance":	{"NN"},
"discordant":	{"JJ"},
"discordantly":	{"RB"},
"discorded":	{"VBD","VBN"},
"discording":	{"VBG"},
"discords":	{"NNS","VBZ"},
"discorporate":	{"JJ"},
"discorporated":	{"VBN"},
"discos":	{"NNS","VBZ"},
"discotheque":	{"NN"},
"discotheques":	{"NNS"},
"discount":	{"NN","VB","VBP"},
"discount-borrowing":	{"NN"},
"discount-brokerage":	{"NN"},
"discount-coupon":	{"NN"},
"discount-movie":	{"JJ"},
"discount-rate":	{"JJ"},
"discount-retailing":	{"NN"},
"discount-store":	{"NN"},
"discount-toy":	{"JJ"},
"discounted":	{"VBD","VBN"},
"discountenance":	{"VB","VBP"},
"discountenanced":	{"VBD","VBN"},
"discountenances":	{"VBZ"},
"discountenancing":	{"VBG"},
"discounter":	{"NN"},
"discounters":	{"NNS"},
"discounting":	{"VBG"},
"discounts":	{"NNS","VBZ"},
"discourage":	{"VB","VBP"},
"discouraged":	{"JJ","VBD","VBN"},
"discouragement":	{"NN"},
"discouragements":	{"NNS"},
"discourages":	{"VBZ"},
"discouraging":	{"JJ","VBG"},
"discouragingly":	{"RB"},
"discourse":	{"NN","VB","VBP"},
"discoursed":	{"VBD","VBN"},
"discourses":	{"VBZ","NNS"},
"discoursing":	{"VBG"},
"discourteous":	{"JJ"},
"discourteously":	{"RB"},
"discourtesy":	{"NN"},
"discover":	{"VB","VBP"},
"discoverable":	{"JJ"},
"discovered":	{"VBD","VBN"},
"discoverer":	{"NN"},
"discoverers":	{"NNS"},
"discoveries":	{"NNS"},
"discovering":	{"VBG"},
"discovers":	{"VBZ"},
"discovery":	{"NN"},
"discredit":	{"VB","VBP","NN"},
"discreditable":	{"JJ"},
"discreditably":	{"RB"},
"discredited":	{"VBD","VBN","JJ"},
"discrediting":	{"VBG"},
"discredits":	{"VBZ"},
"discreet":	{"JJ","NN"},
"discreetly":	{"RB"},
"discreetness":	{"NN"},
"discrepancies":	{"NNS"},
"discrepancy":	{"NN"},
"discrepant":	{"JJ","NN"},
"discrepencies":	{"NNS"},
"discrepency":	{"NN"},
"discrete":	{"JJ","NN"},
"discreteness":	{"NN"},
"discretion":	{"NN"},
"discretional":	{"JJ"},
"discretionary":	{"JJ"},
"discriminable":	{"JJ"},
"discriminate":	{"VB","VBP"},
"discriminated":	{"VBD","VBN"},
"discriminates":	{"VBZ"},
"discriminating":	{"JJ","VBG"},
"discrimination":	{"NN"},
"discriminative":	{"JJ"},
"discriminatively":	{"RB"},
"discriminator":	{"NN"},
"discriminators":	{"NNS"},
"discriminatory":	{"JJ"},
"discs":	{"NNS","NN","VB","VBZ"},
"discursive":	{"JJ"},
"discursively":	{"RB"},
"discursiveness":	{"NN"},
"discus":	{"NN"},
"discuses":	{"NNS"},
"discuss":	{"VB","VBP"},
"discussant":	{"NN"},
"discussed":	{"VBN","VBD"},
"discusses":	{"VBZ"},
"discussing":	{"VBG"},
"discussion":	{"NN","JJ"},
"discussions":	{"NNS"},
"disdain":	{"NN","VB","VBP"},
"disdained":	{"VBD","VBN"},
"disdainful":	{"JJ"},
"disdainfully":	{"RB"},
"disdainfulness":	{"NN"},
"disdaining":	{"VBG"},
"disdains":	{"VBZ"},
"disease":	{"NN"},
"disease-fighting":	{"JJ"},
"disease-resistance":	{"JJ"},
"disease-resistant":	{"JJ"},
"diseased":	{"JJ"},
"diseases":	{"NNS"},
"disembark":	{"VB","VBP"},
"disembarkation":	{"NN"},
"disembarked":	{"VBD","VBN"},
"disembarking":	{"VBG"},
"disembarkment":	{"NN"},
"disembarks":	{"VBZ"},
"disembarrass":	{"VB"},
"disembarrassment":	{"NN"},
"disembodied":	{"JJ","VBD","VBN"},
"disembodies":	{"VBZ"},
"disembody":	{"VB","VBP"},
"disembodying":	{"VBG"},
"disembowel":	{"VB","VBP"},
"disemboweled":	{"VBD","VBN"},
"disemboweling":	{"VBG"},
"disembowelled":	{"VBD","VBN"},
"disembowelling":	{"VBG"},
"disembowelment":	{"NN"},
"disembowels":	{"VBZ"},
"disembroil":	{"VB"},
"disenable":	{"VB"},
"disenchant":	{"VB","VBP"},
"disenchanted":	{"JJ","VBD","VBN"},
"disenchanting":	{"VBG"},
"disenchantment":	{"NN"},
"disenchants":	{"VBZ"},
"disencumber":	{"VB"},
"disencumbered":	{"VBD","VBN"},
"disencumbering":	{"VBG"},
"disencumbers":	{"VBZ"},
"disenfranchise":	{"VB","VBP"},
"disenfranchised":	{"JJ","VBD","VBN"},
"disenfranchisement":	{"NN"},
"disenfranchises":	{"VBZ"},
"disenfranchising":	{"VBG"},
"disengage":	{"VB","VBP"},
"disengaged":	{"VBN","JJ","VBD"},
"disengagement":	{"NN"},
"disengages":	{"VBZ"},
"disengaging":	{"VBG"},
"disentangle":	{"VB","VBP"},
"disentangled":	{"VBD","VBN"},
"disentanglement":	{"NN"},
"disentangler":	{"NN"},
"disentangles":	{"VBZ"},
"disentangling":	{"VBG"},
"disequilibrium":	{"NN"},
"disestablish":	{"VB","VBP"},
"disestablished":	{"VBD","VBN"},
"disestablishes":	{"VBZ"},
"disestablishing":	{"VBG"},
"disestablishment":	{"NN"},
"disesteem":	{"VB","VBP","NN"},
"disesteemed":	{"VBD","VBN"},
"disesteeming":	{"VBG"},
"disesteems":	{"VBZ"},
"disfavor":	{"VB","NN"},
"disfavored":	{"VBD","VBN"},
"disfavoring":	{"VBG"},
"disfavors":	{"VBZ"},
"disfavour":	{"NN","VB"},
"disfiguration":	{"NN"},
"disfigure":	{"VB","VBP"},
"disfigured":	{"JJ","VBD","VBN"},
"disfigurement":	{"NN"},
"disfigurements":	{"NNS"},
"disfigures":	{"VBZ"},
"disfiguring":	{"VBG","JJ"},
"disfluencies":	{"NNS"},
"disfluency":	{"NN"},
"disforest":	{"VB"},
"disforestation":	{"NN"},
"disfranchise":	{"VB","VBP"},
"disfranchised":	{"VBD","VBN"},
"disfranchisement":	{"NN"},
"disfranchises":	{"VBZ"},
"disfranchising":	{"VBG"},
"disfunction":	{"NN"},
"disgorge":	{"VB","VBP"},
"disgorged":	{"VBD","VBN"},
"disgorgement":	{"NN"},
"disgorges":	{"VBZ"},
"disgorging":	{"VBG"},
"disgrace":	{"NN","VB","VBP"},
"disgraced":	{"VBD","VBN"},
"disgraceful":	{"JJ"},
"disgracefully":	{"RB"},
"disgracefulness":	{"NN"},
"disgraces":	{"VBZ"},
"disgracing":	{"VBG"},
"disgruntle":	{"VB","VBP"},
"disgruntled":	{"JJ","VBD","VBN"},
"disgruntlement":	{"NN"},
"disgruntles":	{"VBZ"},
"disgruntling":	{"VBG"},
"disguise":	{"VB","NN","VBP"},
"disguised":	{"VBD","VBN","JJ"},
"disguises":	{"VBZ"},
"disguising":	{"VBG"},
"disgust":	{"NN","VB","VBP"},
"disgusted":	{"JJ","VBD","VBN"},
"disgustedly":	{"RB"},
"disgustful":	{"JJ"},
"disgusting":	{"JJ","VBG"},
"disgustingly":	{"RB"},
"disgustingness":	{"NN"},
"disgusts":	{"VBZ"},
"dish":	{"NN","VB","VBP"},
"dish-shaped":	{"JJ"},
"dishabille":	{"NN"},
"disharmonious":	{"JJ"},
"disharmonize":	{"VB"},
"disharmony":	{"NN"},
"dishcloth":	{"NN"},
"dishcloths":	{"NNS"},
"dishearten":	{"VB","VBP"},
"disheartened":	{"JJ","VBD","VBN"},
"disheartening":	{"JJ","VBG"},
"dishearteningly":	{"RB"},
"disheartenment":	{"NN"},
"disheartens":	{"VBZ"},
"dished":	{"VBD","VBN"},
"dishes":	{"NNS","VBZ"},
"dishevel":	{"VB","VBP"},
"disheveled":	{"JJ","VBD","VBN"},
"disheveling":	{"VBG"},
"dishevelled":	{"JJ","VBD","VBN"},
"dishevelling":	{"VBG"},
"dishevels":	{"VBZ"},
"dishful":	{"NN"},
"dishier":	{"JJR"},
"dishiest":	{"JJS"},
"dishing":	{"VBG"},
"dishonest":	{"JJ"},
"dishonestly":	{"RB"},
"dishonesty":	{"NN"},
"dishonor":	{"NN","VB","VBP"},
"dishonorable":	{"JJ"},
"dishonorableness":	{"NN"},
"dishonorably":	{"RB"},
"dishonored":	{"VBD","VBN"},
"dishonoring":	{"VBG"},
"dishonors":	{"VBZ"},
"dishonour":	{"NN","VB","VBP"},
"dishonourable":	{"JJ"},
"dishonourableness":	{"NN"},
"dishonourably":	{"RB"},
"dishonoured":	{"VBD","VBN"},
"dishonouring":	{"VBG"},
"dishonours":	{"VBZ"},
"dishpan":	{"NN"},
"dishrag":	{"NN"},
"dishtowel":	{"NN"},
"dishware":	{"NN"},
"dishwasher":	{"NN"},
"dishwashers":	{"NNS"},
"dishwashing":	{"NN"},
"dishwater":	{"NN"},
"dishy":	{"JJ"},
"disillusion":	{"VB","VBP","NN"},
"disillusioned":	{"JJ","VBD","VBN"},
"disillusioning":	{"VBG"},
"disillusionment":	{"NN"},
"disillusions":	{"VBZ"},
"disincarnate":	{"VB"},
"disincentive":	{"NN","JJ"},
"disincentives":	{"NNS"},
"disinclination":	{"NN"},
"disincline":	{"VB","VBP"},
"disinclined":	{"JJ","VBD","VBN"},
"disinclines":	{"VBZ"},
"disinclining":	{"VBG"},
"disinfect":	{"VB","VBP"},
"disinfectant":	{"NN"},
"disinfectants":	{"NNS"},
"disinfected":	{"VBN","VBD"},
"disinfecting":	{"VBG"},
"disinfection":	{"NN"},
"disinfects":	{"VBZ"},
"disinfest":	{"VB"},
"disinfestation":	{"NN"},
"disinflation":	{"NN"},
"disinflationary":	{"JJ"},
"disinformation":	{"NN"},
"disingenuous":	{"JJ"},
"disingenuously":	{"RB"},
"disingenuousness":	{"NN"},
"disinherit":	{"VB","VBP"},
"disinheritance":	{"NN"},
"disinherited":	{"VBD","VBN"},
"disinheriting":	{"VBG"},
"disinherits":	{"VBZ"},
"disinhibit":	{"VB","VBP"},
"disinhibited":	{"VBD","VBN"},
"disinhibiting":	{"VBG"},
"disinhibition":	{"NN"},
"disinhibitions":	{"NNS"},
"disinhibitor":	{"NN"},
"disinhibitors":	{"NNS"},
"disinhibits":	{"VBZ"},
"disintegrable":	{"JJ"},
"disintegrate":	{"VB","VBP"},
"disintegrated":	{"VBD","VBN"},
"disintegrates":	{"VBZ"},
"disintegrating":	{"VBG"},
"disintegration":	{"NN"},
"disintegrative":	{"JJ"},
"disinter":	{"VB","VBP"},
"disinterest":	{"NN","VB","VBP"},
"disinterested":	{"JJ","VBD","VBN"},
"disinterestedly":	{"RB"},
"disinterestedness":	{"NN"},
"disinteresting":	{"VBG"},
"disinterests":	{"VBZ"},
"disinterment":	{"NN"},
"disinterred":	{"VBD","VBN"},
"disinterring":	{"VBG"},
"disinters":	{"VBZ"},
"disinvest":	{"VB","VBP"},
"disinvested":	{"VBD","VBN"},
"disinvesting":	{"VBG"},
"disinvestment":	{"NN"},
"disinvests":	{"VBZ"},
"disinvolve":	{"VB","VBP"},
"disinvolved":	{"VBD","VBN"},
"disinvolves":	{"VBZ"},
"disinvolving":	{"VBG"},
"disjoin":	{"VB","VBP"},
"disjoined":	{"VBD","VBN"},
"disjoining":	{"VBG"},
"disjoins":	{"VBZ"},
"disjoint":	{"VB","VBP"},
"disjointed":	{"JJ","VBD","VBN"},
"disjointedly":	{"RB"},
"disjointedness":	{"NN"},
"disjointing":	{"VBG"},
"disjoints":	{"VBZ"},
"disjunct":	{"JJ","NN"},
"disjunction":	{"NN"},
"disjunctive":	{"JJ"},
"disjuncture":	{"NN"},
"disk":	{"NN"},
"disk-drive":	{"NN","JJ"},
"disk-read":	{"JJ"},
"disk-shaped":	{"JJ"},
"disked":	{"VBD","VBN"},
"diskette":	{"NN"},
"diskettes":	{"NNS"},
"disking":	{"VBG"},
"disklike":	{"JJ"},
"disks":	{"NNS","VBZ"},
"dislikable":	{"JJ"},
"dislike":	{"VB","NN","VBP"},
"disliked":	{"VBD","VBN"},
"dislikes":	{"VBZ","NNS"},
"disliking":	{"VBG"},
"dislocate":	{"VB","VBP"},
"dislocated":	{"VBD","VBN","JJ"},
"dislocates":	{"VBZ"},
"dislocating":	{"VBG"},
"dislocation":	{"NN"},
"dislocations":	{"NNS"},
"dislodge":	{"VB","VBP"},
"dislodged":	{"VBD","VBN"},
"dislodgement":	{"NN"},
"dislodges":	{"VBZ"},
"dislodging":	{"VBG"},
"dislodgment":	{"NN"},
"dislogistic":	{"JJ"},
"disloyal":	{"JJ"},
"disloyally":	{"RB"},
"disloyalty":	{"NN"},
"dismal":	{"JJ"},
"dismally":	{"RB"},
"dismantle":	{"VB","VBP"},
"dismantled":	{"VBD","VBN"},
"dismantlement":	{"NN"},
"dismantles":	{"VBZ"},
"dismantling":	{"VBG"},
"dismay":	{"NN","VB","VBP"},
"dismayed":	{"JJ","VBD","VBN"},
"dismaying":	{"VBG"},
"dismays":	{"VBZ"},
"dismember":	{"VB","VBP"},
"dismembered":	{"VBD","VBN"},
"dismembering":	{"VBG"},
"dismemberment":	{"NN"},
"dismembers":	{"VBZ"},
"dismiss":	{"VB","VBP"},
"dismissal":	{"NN"},
"dismissals":	{"NNS"},
"dismissed":	{"VBN","VBD"},
"dismisses":	{"VBZ"},
"dismissible":	{"JJ"},
"dismissing":	{"VBG"},
"dismission":	{"NN"},
"dismissive":	{"JJ"},
"dismissively":	{"RB"},
"dismount":	{"VB","VBP"},
"dismounted":	{"VBD","VBN"},
"dismounting":	{"VBG"},
"dismounts":	{"VBZ"},
"disney":	{"NN"},
"disneyland":	{"NN"},
"disobedience":	{"NN"},
"disobedient":	{"JJ"},
"disobediently":	{"RB"},
"disobey":	{"VB","VBP"},
"disobeyed":	{"VBD","VBN"},
"disobeying":	{"VBG"},
"disobeys":	{"VBZ"},
"disoblige":	{"VB","VBP"},
"disobliged":	{"VBD","VBN"},
"disobliges":	{"VBZ"},
"disobliging":	{"JJ","VBG"},
"disobligingly":	{"RB"},
"disorder":	{"NN","VB","VBP"},
"disordered":	{"JJ","VBD","VBN"},
"disordering":	{"VBG"},
"disorderliness":	{"NN"},
"disorderly":	{"JJ"},
"disorders":	{"NNS","VBZ"},
"disorganisation":	{"NN"},
"disorganise":	{"VB","VBP"},
"disorganised":	{"JJ","VBD","VBN"},
"disorganises":	{"VBZ"},
"disorganising":	{"VBG"},
"disorganization":	{"NN"},
"disorganize":	{"VB","VBP"},
"disorganized":	{"JJ","VBD","VBN"},
"disorganizes":	{"VBZ"},
"disorganizing":	{"VBG"},
"disorient":	{"VB","VBP"},
"disorientate":	{"VB","VBP"},
"disorientated":	{"VBD","VBN"},
"disorientates":	{"VBZ"},
"disorientating":	{"VBG"},
"disorientation":	{"NN"},
"disoriented":	{"JJ","VBD","VBN"},
"disorienting":	{"VBG","JJ"},
"disorients":	{"VBZ"},
"disown":	{"VB","VBP"},
"disowned":	{"VBD","VBN"},
"disowning":	{"VBG"},
"disownment":	{"NN"},
"disowns":	{"VBZ"},
"disparage":	{"VB","VBP"},
"disparaged":	{"VBD","VBN"},
"disparagement":	{"NN"},
"disparager":	{"NN"},
"disparages":	{"VBZ"},
"disparaging":	{"JJ","VBG"},
"disparagingly":	{"RB"},
"disparate":	{"JJ"},
"disparately":	{"RB"},
"disparateness":	{"NN"},
"disparities":	{"NNS"},
"disparity":	{"NN"},
"dispassion":	{"NN"},
"dispassionate":	{"JJ"},
"dispassionately":	{"RB"},
"dispassionateness":	{"NN"},
"dispatch":	{"VB","VBP","NN"},
"dispatch-box":	{"NN"},
"dispatch-boxes":	{"NNS"},
"dispatch-rider":	{"NN"},
"dispatch-riders":	{"NNS"},
"dispatched":	{"VBD","VBN"},
"dispatcher":	{"NN"},
"dispatchers":	{"NNS"},
"dispatches":	{"NNS","VBZ"},
"dispatching":	{"VBG"},
"dispel":	{"VB","VBP"},
"dispelled":	{"VBN","VBD"},
"dispelling":	{"VBG"},
"dispels":	{"VBZ"},
"dispensability":	{"NN"},
"dispensable":	{"JJ"},
"dispensableness":	{"NN"},
"dispensaries":	{"NNS"},
"dispensary":	{"NN"},
"dispensation":	{"NN"},
"dispensations":	{"NNS"},
"dispense":	{"VB","VBP"},
"dispensed":	{"VBD","VBN"},
"dispenser":	{"NN"},
"dispensers":	{"NNS"},
"dispenses":	{"VBZ"},
"dispensing":	{"VBG"},
"dispersal":	{"NN"},
"dispersals":	{"NNS"},
"dispersant":	{"NN"},
"dispersants":	{"NNS"},
"disperse":	{"VB","VBP"},
"dispersed":	{"JJ","VBD","VBN"},
"dispersement":	{"NN"},
"disperses":	{"VBZ"},
"dispersing":	{"VBG"},
"dispersion":	{"NN"},
"dispersive":	{"JJ"},
"dispirit":	{"VB","VBP"},
"dispirited":	{"JJ","VBD","VBN"},
"dispiritedly":	{"RB"},
"dispiritedness":	{"NN"},
"dispiriting":	{"VBG","JJ"},
"dispirits":	{"VBZ"},
"displace":	{"VB","VBP"},
"displaced":	{"VBN","VBD","JJ"},
"displacement":	{"NN"},
"displaces":	{"VBZ"},
"displacing":	{"VBG"},
"display":	{"NN","VB","VBP"},
"displayed":	{"VBN","VBD"},
"displaying":	{"VBG"},
"displays":	{"NNS","VBZ"},
"displease":	{"VB","VBP"},
"displeased":	{"JJ","VBD","VBN"},
"displeases":	{"VBZ"},
"displeasing":	{"JJ","VBG"},
"displeasingly":	{"RB"},
"displeasure":	{"NN"},
"displume":	{"VB","VBP"},
"displumed":	{"VBD","VBN"},
"displumes":	{"VBZ"},
"displuming":	{"VBG"},
"disport":	{"VB","VBP"},
"disported":	{"VBD","VBN"},
"disporting":	{"VBG"},
"disports":	{"VBZ"},
"disposable":	{"JJ","NN"},
"disposables":	{"NNS"},
"disposal":	{"NN"},
"disposals":	{"NNS"},
"dispose":	{"VB","VBP"},
"disposed":	{"JJ","VBD","VBN"},
"disposes":	{"VBZ"},
"disposing":	{"VBG"},
"disposition":	{"NN"},
"dispositions":	{"NNS"},
"dispossess":	{"VB","VBP"},
"dispossessed":	{"JJ","VBD","VBN","NNS"},
"dispossesses":	{"VBZ"},
"dispossessing":	{"VBG"},
"dispossession":	{"NN"},
"dispraise":	{"NN"},
"dispread":	{"VB","VBP"},
"dispreaded":	{"VBD","VBN"},
"dispreading":	{"VBG"},
"dispreads":	{"VBZ"},
"disproof":	{"NN"},
"disproportion":	{"NN"},
"disproportional":	{"JJ"},
"disproportionality":	{"NN"},
"disproportionally":	{"RB"},
"disproportionate":	{"JJ"},
"disproportionately":	{"RB"},
"disproportions":	{"NNS"},
"disprove":	{"VB","VBP"},
"disproved":	{"VBD","VBN"},
"disprover":	{"NN"},
"disproves":	{"VBZ"},
"disproving":	{"VBG"},
"disputable":	{"JJ"},
"disputably":	{"RB"},
"disputant":	{"NN"},
"disputation":	{"NN"},
"disputations":	{"NNS"},
"disputatious":	{"JJ"},
"disputatiously":	{"RB"},
"disputative":	{"JJ"},
"dispute":	{"NN","VB","VBP"},
"dispute-settlement":	{"JJ","NN"},
"disputed":	{"VBD","VBN","JJ"},
"disputes":	{"NNS","VBZ"},
"disputing":	{"VBG"},
"disqualification":	{"NN"},
"disqualified":	{"VBD","VBN"},
"disqualifies":	{"VBZ"},
"disqualify":	{"VB","VBP"},
"disqualifying":	{"VBG"},
"disquiet":	{"NN","VB","VBP"},
"disquieted":	{"VBD","VBN"},
"disquieting":	{"JJ","VBG"},
"disquietingly":	{"RB"},
"disquiets":	{"VBZ"},
"disquietude":	{"NN"},
"disquisition":	{"NN"},
"disquisitions":	{"NNS"},
"disregard":	{"VB","VBP","NN"},
"disregarded":	{"VBD","VBN"},
"disregarding":	{"VBG"},
"disregardless":	{"RB"},
"disregards":	{"VBZ"},
"disregulation":	{"NN"},
"disrepair":	{"NN"},
"disreputability":	{"NN"},
"disreputable":	{"JJ"},
"disreputableness":	{"NN"},
"disreputably":	{"RB"},
"disrepute":	{"NN"},
"disrespect":	{"NN","VB","VBP"},
"disrespected":	{"VBD","VBN"},
"disrespectful":	{"JJ"},
"disrespectfully":	{"RB"},
"disrespecting":	{"VBG"},
"disrespects":	{"VBZ"},
"disrobe":	{"VB","VBP"},
"disrobed":	{"VBD","VBN"},
"disrobes":	{"VBZ"},
"disrobing":	{"VBG"},
"disrupt":	{"VB","VBP"},
"disrupted":	{"VBD","VBN"},
"disrupting":	{"VBG"},
"disruption":	{"NN"},
"disruptions":	{"NNS"},
"disruptive":	{"JJ"},
"disruptively":	{"RB"},
"disrupts":	{"VBZ"},
"diss":	{"VB","VBP"},
"dissatisfaction":	{"NN"},
"dissatisfactions":	{"NNS"},
"dissatisfactory":	{"JJ"},
"dissatisfied":	{"JJ","VBD","VBN"},
"dissatisfies":	{"VBZ"},
"dissatisfy":	{"VB"},
"dissatisfying":	{"VBG"},
"dissect":	{"VB","VBP"},
"dissected":	{"VBD","VBN"},
"dissecting":	{"VBG"},
"dissection":	{"NN"},
"dissections":	{"NNS"},
"dissects":	{"VBZ"},
"dissed":	{"VBD","VBN"},
"dissemble":	{"VB","VBP"},
"dissembled":	{"VBD","VBN"},
"dissembler":	{"NN"},
"dissembles":	{"VBZ"},
"dissembling":	{"VBG"},
"disseminate":	{"VB","VBP"},
"disseminated":	{"VBD","VBN"},
"disseminates":	{"VBZ"},
"disseminating":	{"VBG"},
"dissemination":	{"NN"},
"disseminative":	{"JJ"},
"disseminator":	{"NN"},
"dissension":	{"NN"},
"dissensions":	{"NNS"},
"dissent":	{"NN","VBP","VB"},
"dissented":	{"VBD","VBN"},
"dissenter":	{"NN"},
"dissenters":	{"NNS"},
"dissentient":	{"JJ","NN"},
"dissenting":	{"JJ","VBG"},
"dissentious":	{"JJ"},
"dissents":	{"VBZ"},
"disseration":	{"NN"},
"dissertate":	{"VB","VBP"},
"dissertated":	{"VBD","VBN"},
"dissertates":	{"VBZ"},
"dissertating":	{"VBG"},
"dissertation":	{"NN"},
"dissertations":	{"NNS"},
"disservice":	{"NN"},
"disses":	{"VBZ"},
"dissever":	{"VB","VBP"},
"dissevered":	{"VBD","VBN"},
"dissevering":	{"VBG"},
"dissevers":	{"VBZ"},
"dissidence":	{"NN"},
"dissident":	{"JJ","NN"},
"dissident-shareholder":	{"NN"},
"dissidents":	{"NNS"},
"dissilience":	{"NN"},
"dissilient":	{"JJ"},
"dissimilar":	{"JJ"},
"dissimilarities":	{"NNS"},
"dissimilarity":	{"NN"},
"dissimilarly":	{"RB"},
"dissimilate":	{"VB","VBP"},
"dissimilated":	{"VBD","VBN"},
"dissimilates":	{"VBZ"},
"dissimilating":	{"VBG"},
"dissimilation":	{"NN"},
"dissimiliar":	{"JJ"},
"dissimilitude":	{"NN"},
"dissimulate":	{"VB","VBP"},
"dissimulated":	{"VBD","VBN"},
"dissimulates":	{"VBZ"},
"dissimulating":	{"VBG"},
"dissimulation":	{"NN"},
"dissimulative":	{"JJ"},
"dissimulator":	{"NN"},
"dissing":	{"VBG"},
"dissipate":	{"VB","VBP"},
"dissipated":	{"VBD","VBN","JJ"},
"dissipates":	{"VBZ"},
"dissipating":	{"VBG"},
"dissipation":	{"NN"},
"dissociable":	{"JJ"},
"dissociate":	{"VB","VBP"},
"dissociated":	{"VBD","VBN"},
"dissociates":	{"VBZ"},
"dissociating":	{"VBG"},
"dissociation":	{"NN"},
"dissociative":	{"JJ"},
"dissolubility":	{"NN"},
"dissoluble":	{"JJ"},
"dissolute":	{"JJ"},
"dissolutely":	{"RB"},
"dissoluteness":	{"NN"},
"dissolution":	{"NN"},
"dissolutions":	{"NNS"},
"dissolvable":	{"JJ"},
"dissolve":	{"VB","VBP"},
"dissolved":	{"VBD","VBN"},
"dissolvent":	{"NN","JJ"},
"dissolver":	{"NN"},
"dissolves":	{"VBZ"},
"dissolving":	{"JJ","VBG"},
"dissonance":	{"NN"},
"dissonances":	{"NNS"},
"dissonant":	{"JJ"},
"dissonantly":	{"RB"},
"dissuade":	{"VB","VBP"},
"dissuaded":	{"VBD","VBN"},
"dissuades":	{"VBZ"},
"dissuading":	{"VBG"},
"dissuasion":	{"NN"},
"dissuasive":	{"JJ"},
"dissyllable":	{"NN"},
"dissymmetry":	{"NN"},
"dist":	{"NN"},
"distaff":	{"NN"},
"distaffs":	{"NNS"},
"distal":	{"JJ"},
"distally":	{"RB"},
"distance":	{"NN","VB","VBP"},
"distanced":	{"VBD","VBN"},
"distances":	{"NNS","VBZ"},
"distancing":	{"VBG"},
"distant":	{"JJ"},
"distantly":	{"RB"},
"distaste":	{"NN","VB","VBP"},
"distasted":	{"VBD","VBN"},
"distasteful":	{"JJ"},
"distastefully":	{"RB"},
"distastefulness":	{"NN"},
"distastes":	{"VBZ"},
"distasting":	{"VBG"},
"distemper":	{"NN","VB","VBP"},
"distempered":	{"VBD","VBN"},
"distempering":	{"VBG"},
"distempers":	{"VBZ"},
"distend":	{"VB","VBP"},
"distended":	{"VBD","VBN","JJ"},
"distending":	{"VBG"},
"distends":	{"VBZ"},
"distensible":	{"JJ"},
"distension":	{"NN"},
"distention":	{"NN"},
"distich":	{"NN"},
"distichiasis":	{"NN"},
"distil":	{"VB","VBP"},
"distill":	{"VB","VBP"},
"distillate":	{"NN"},
"distillates":	{"NNS"},
"distillation":	{"NN"},
"distilled":	{"VBD","VBN","JJ"},
"distiller":	{"NN"},
"distilleries":	{"NNS"},
"distillers":	{"NNS"},
"distillery":	{"NN"},
"distilling":	{"VBG"},
"distillment":	{"NN"},
"distills":	{"VBZ"},
"distinct":	{"JJ"},
"distinction":	{"NN"},
"distinctions":	{"NNS"},
"distinctive":	{"JJ"},
"distinctively":	{"RB"},
"distinctiveness":	{"NN"},
"distinctly":	{"RB"},
"distinctness":	{"NN"},
"distinguish":	{"VB","VBP"},
"distinguishable":	{"JJ"},
"distinguished":	{"JJ","VBD","VBN"},
"distinguishes":	{"VBZ"},
"distinguishing":	{"VBG","JJ"},
"distort":	{"VB","VBP"},
"distortable":	{"JJ"},
"distorted":	{"JJ","VBD","VBN"},
"distorting":	{"VBG"},
"distortion":	{"NN"},
"distortionist":	{"NN"},
"distortions":	{"NNS"},
"distorts":	{"VBZ"},
"distract":	{"VB","VBP"},
"distracted":	{"JJ","VBD","VBN"},
"distractedly":	{"RB"},
"distracting":	{"VBG","JJ"},
"distractingly":	{"RB"},
"distraction":	{"NN"},
"distractions":	{"NNS"},
"distractors":	{"NNS"},
"distracts":	{"VBZ"},
"distrain":	{"VB","VBP","NN"},
"distrained":	{"VBD","VBN"},
"distraining":	{"VBG"},
"distrains":	{"VBZ"},
"distraint":	{"NN"},
"distrait":	{"JJ"},
"distraught":	{"JJ"},
"distress":	{"NN","VB","VBP"},
"distressed":	{"JJ","VBD","VBN"},
"distresses":	{"VBZ"},
"distressful":	{"JJ"},
"distressfully":	{"RB"},
"distressfulness":	{"NN"},
"distressing":	{"JJ","VBG"},
"distressingly":	{"RB"},
"distressingness":	{"NN"},
"distributable":	{"JJ"},
"distributary":	{"NN"},
"distribute":	{"VB","VBP"},
"distributed":	{"VBN","VBD","JJ"},
"distributes":	{"VBZ"},
"distributing":	{"VBG"},
"distribution":	{"NN"},
"distributional":	{"JJ"},
"distributions":	{"NNS"},
"distributive":	{"JJ"},
"distributively":	{"RB"},
"distributor":	{"NN"},
"distributors":	{"NNS"},
"distributorship":	{"NN"},
"distributorships":	{"NNS"},
"district":	{"NN","VB","VBP"},
"district-by-district":	{"RB"},
"district-court":	{"NN"},
"districted":	{"VBD","VBN"},
"districting":	{"VBG"},
"districts":	{"NNS","VBZ"},
"distrubition":	{"NN"},
"distrust":	{"VB","NN","VBP"},
"distrusted":	{"VBD","VBN"},
"distrustful":	{"JJ"},
"distrustfully":	{"RB"},
"distrustfulness":	{"NN"},
"distrusting":	{"VBG"},
"distrusts":	{"VBZ"},
"disturb":	{"VB","VBP"},
"disturbance":	{"NN"},
"disturbances":	{"NNS"},
"disturbed":	{"JJ","VBD","VBN"},
"disturber":	{"NN"},
"disturbing":	{"JJ","VBG"},
"disturbingly":	{"RB"},
"disturbs":	{"VBZ"},
"disulfide":	{"NN"},
"disulfiram":	{"NN"},
"disunion":	{"NN"},
"disunite":	{"VB","VBP"},
"disunited":	{"JJ","VBD","VBN"},
"disunites":	{"VBZ"},
"disuniting":	{"VBG"},
"disunity":	{"NN"},
"disuse":	{"NN"},
"disused":	{"JJ"},
"disyllabic":	{"JJ"},
"disyllable":	{"NN"},
"dit":	{"NN"},
"dita":	{"NN"},
"ditch":	{"NN","VB","VBP"},
"ditched":	{"VBD","VBN"},
"ditcher":	{"NN"},
"ditches":	{"VBZ","NNS"},
"ditching":	{"VBG"},
"ditchmoss":	{"NN"},
"dites":	{"FW"},
"dither":	{"VB","VBP","NN"},
"dithered":	{"VBD","VBN"},
"ditherer":	{"NN"},
"ditherers":	{"NNS"},
"dithering":	{"NN","VBG"},
"dithers":	{"VBZ","NNS"},
"dithyramb":	{"NN"},
"dithyrambic":	{"JJ"},
"dittany":	{"NN"},
"ditties":	{"NNS"},
"ditto":	{"NN","VBP","RB","VB"},
"dittoed":	{"VBD","VBN"},
"dittoing":	{"VBG"},
"dittos":	{"VBZ","NNS"},
"ditty":	{"NN"},
"diuresis":	{"NN"},
"diuretic":	{"NN","JJ"},
"diuretics":	{"NNS"},
"diuril":	{"NN"},
"diurnal":	{"JJ"},
"diva":	{"NN"},
"divagate":	{"VB","VBP"},
"divagated":	{"VBD","VBN"},
"divagates":	{"VBZ"},
"divagating":	{"VBG"},
"divagation":	{"NN"},
"divalent":	{"JJ"},
"divan":	{"NN"},
"divan-like":	{"JJ"},
"divans":	{"NNS"},
"divaricate":	{"VB","VBP","JJ"},
"divaricated":	{"VBD","VBN"},
"divaricately":	{"RB"},
"divaricates":	{"VBZ"},
"divaricating":	{"VBG"},
"divaricatingly":	{"RB"},
"divarication":	{"NN"},
"divas":	{"NNS"},
"dive":	{"NN","VB","VBP"},
"dive-bomb":	{"VB","VBP"},
"dive-bombed":	{"VBD","VBN"},
"dive-bomber":	{"NN"},
"dive-bombers":	{"NNS"},
"dive-bombing":	{"VBG"},
"dive-bombs":	{"VBZ"},
"dived":	{"VBD","VBN"},
"diver":	{"NN"},
"diverge":	{"VB","VBP"},
"diverged":	{"VBD","VBN"},
"divergence":	{"NN"},
"divergences":	{"NNS"},
"divergency":	{"NN"},
"divergent":	{"JJ"},
"diverges":	{"VBZ"},
"diverging":	{"VBG"},
"divers":	{"NNS","JJ"},
"diverse":	{"JJ"},
"diversely":	{"RB"},
"diverseness":	{"NN"},
"diversifed":	{"VBN"},
"diversification":	{"NN"},
"diversifications":	{"NNS"},
"diversified":	{"VBD","VBN","JJ"},
"diversifies":	{"VBZ"},
"diversify":	{"VB","VBP"},
"diversifying":	{"VBG"},
"diversion":	{"NN"},
"diversionary":	{"JJ"},
"diversionist":	{"NN"},
"diversions":	{"NNS"},
"diversities":	{"NNS"},
"diversity":	{"NN"},
"divert":	{"VB","VBP"},
"diverted":	{"VBD","VBN"},
"diverticulitis":	{"NN"},
"diverticulosis":	{"NN"},
"diverticulum":	{"NN"},
"divertimento":	{"NN"},
"diverting":	{"JJ","VBG"},
"divertingly":	{"RB"},
"diverts":	{"VBZ"},
"dives":	{"NNS","VBZ"},
"divest":	{"VB","VBP"},
"divested":	{"VBD","VBN"},
"divesting":	{"VBG"},
"divestiture":	{"NN"},
"divestiture-related":	{"JJ"},
"divestitures":	{"NNS"},
"divestment":	{"NN"},
"divests":	{"VBZ"},
"divi-divi":	{"NN"},
"dividable":	{"JJ"},
"divide":	{"VB","NN","VBP"},
"divided":	{"VBN","VBD","JJ"},
"dividend":	{"NN"},
"dividend-capture":	{"NN"},
"dividend-related":	{"JJ"},
"dividends":	{"NNS"},
"divider":	{"NN"},
"dividers":	{"NNS"},
"divides":	{"VBZ","NNS"},
"dividing":	{"JJ","VBG"},
"divination":	{"NN"},
"divinatory":	{"JJ"},
"divine":	{"VB","VBP","JJ","NN"},
"divined":	{"VBD","VBN"},
"divinely":	{"RB"},
"diviner":	{"NN"},
"diviners":	{"NNS"},
"divines":	{"VBZ","NNS"},
"diving":	{"NN","VBG"},
"divining":	{"VBG"},
"divinities":	{"NNS"},
"divinity":	{"NN"},
"divisibility":	{"NN"},
"divisible":	{"JJ"},
"division":	{"NN"},
"division-bell":	{"NN"},
"divisional":	{"JJ"},
"divisions":	{"NNS"},
"divisive":	{"JJ"},
"divisively":	{"RB"},
"divisiveness":	{"NN"},
"divisor":	{"NN"},
"divisors":	{"NNS"},
"divorce":	{"NN","VB","VBP"},
"divorced":	{"VBN","VBD","JJ"},
"divorcee":	{"NN"},
"divorcees":	{"NNS"},
"divorcement":	{"NN"},
"divorces":	{"VBZ","NNS"},
"divorcing":	{"VBG"},
"divot":	{"NN"},
"divots":	{"NNS"},
"divulge":	{"VB","VBP"},
"divulged":	{"VBD","VBN"},
"divulgement":	{"NN"},
"divulgence":	{"NN"},
"divulges":	{"VBZ"},
"divulging":	{"VBG"},
"divvied":	{"VBD","VBN"},
"divvies":	{"NNS","VBZ"},
"divvy":	{"NN","VB","VBP"},
"divvying":	{"VBG"},
"diwan":	{"NN"},
"dix":	{"NN"},
"dixie":	{"NN"},
"dixiecrats":	{"NNS"},
"dixieland":	{"NN"},
"dizen":	{"VB","VBP"},
"dizened":	{"VBD","VBN"},
"dizening":	{"VBG"},
"dizens":	{"VBZ"},
"dizygotic":	{"JJ"},
"dizygous":	{"JJ"},
"dizzied":	{"VBD","VBN"},
"dizzies":	{"VBZ"},
"dizzily":	{"RB"},
"dizziness":	{"NN"},
"dizzy":	{"JJ","VB","NN"},
"dizzying":	{"JJ","VBG"},
"dj":	{"NN"},
"djakarta":	{"NN"},
"djanet":	{"NN"},
"djibouti":	{"NN"},
"djiboutian":	{"JJ","NN"},
"djinn":	{"NN"},
"djinni":	{"NN"},
"djinny":	{"NN"},
"dkg":	{"NN"},
"dkl":	{"NN"},
"dkm":	{"NN"},
"dl":	{"NN"},
"dle":	{"NN"},
"dline":	{"NN"},
"dm":	{"NN"},
"dmd":	{"NN"},
"dmitri":	{"NN"},
"dmus":	{"NNS"},
"dmz":	{"NN"},
"dna":	{"NN"},
"dneprodzerzhinsk":	{"NN"},
"dnieper":	{"NN"},
"dnipropetrovsk":	{"NN"},
"do":	{"VBP","VB","NN"},
"do-everything":	{"JJ"},
"do-good":	{"JJ"},
"do-gooder":	{"NN"},
"do-gooders":	{"NNS"},
"do-it-yourself":	{"JJ","NN"},
"do-nothing":	{"JJ","NN"},
"do-or-die":	{"JJ"},
"do-si-do":	{"NN","VB","VBP"},
"do-si-doed":	{"VBD","VBN"},
"do-si-doing":	{"VBG"},
"do-si-dos":	{"NNS","VBZ"},
"doable":	{"JJ"},
"doan":	{"VBP","VB"},
"dobbin":	{"NN"},
"doberman":	{"NN"},
"doble":	{"NN","JJ"},
"dobra":	{"NN"},
"dobrich":	{"NN"},
"dobson":	{"NN"},
"dobsonfly":	{"NN"},
"doc":	{"NN"},
"docent":	{"NN"},
"docents":	{"NNS"},
"docetism":	{"NN"},
"docile":	{"JJ"},
"docilely":	{"RB"},
"docility":	{"NN"},
"dock":	{"NN","VB","VBP"},
"dock-siders":	{"NNS"},
"dock-walloper":	{"NN"},
"dockage":	{"NN"},
"docked":	{"VBD","VBN"},
"docker":	{"NN"},
"dockers":	{"NNS"},
"docket":	{"NN","VB","VBP"},
"docketed":	{"VBN","VBD"},
"docketing":	{"VBG"},
"dockets":	{"NNS","VBZ"},
"dockhand":	{"NN"},
"docking":	{"NN","VBG"},
"dockland":	{"NN"},
"docklands":	{"NN"},
"docks":	{"NNS","VBZ"},
"dockside":	{"NN"},
"dockworker":	{"NN"},
"dockworkers":	{"NNS"},
"dockyard":	{"NN"},
"dockyards":	{"NNS"},
"doctor":	{"NN","VB","VBP"},
"doctor-fish":	{"NN"},
"doctor-oriented":	{"JJ"},
"doctor-originated":	{"JJ"},
"doctor-patient":	{"JJ"},
"doctoral":	{"JJ"},
"doctorate":	{"NN"},
"doctorates":	{"NNS"},
"doctored":	{"VBN","VBD"},
"doctorfish":	{"NN"},
"doctorial":	{"JJ"},
"doctoring":	{"VBG","NN"},
"doctorow":	{"NN"},
"doctors":	{"NNS","VBZ"},
"doctorspeak":	{"NN"},
"doctrinaire":	{"JJ","NN"},
"doctrinal":	{"JJ"},
"doctrinally":	{"RB"},
"doctrine":	{"NN"},
"doctrines":	{"NNS"},
"docudrama":	{"NN"},
"docudramas":	{"NNS"},
"document":	{"NN","VB","VBP"},
"documental":	{"JJ"},
"documentaries":	{"NNS"},
"documentary":	{"NN","JJ"},
"documentary-type":	{"JJ"},
"documentation":	{"NN"},
"documented":	{"VBN","VBD"},
"documenting":	{"VBG"},
"documents":	{"NNS","VBZ"},
"docutainment":	{"NN"},
"dodder":	{"NN","VB","VBP"},
"doddered":	{"VBD","VBN"},
"dodderer":	{"NN"},
"doddering":	{"JJ","VBG"},
"dodders":	{"VBZ"},
"doddery":	{"JJ"},
"doddle":	{"NN"},
"dodecagon":	{"NN"},
"dodecahedron":	{"NN"},
"dodecanese":	{"NN"},
"dodge":	{"VB","VBP","NN"},
"dodgeball":	{"NN"},
"dodged":	{"VBD","VBN"},
"dodgem":	{"NN"},
"dodgems":	{"NNS"},
"dodger":	{"NN"},
"dodgers":	{"NNS"},
"dodges":	{"VBZ","NNS"},
"dodgier":	{"JJR"},
"dodgiest":	{"JJS"},
"dodging":	{"VBG"},
"dodgson":	{"NN"},
"dodgy":	{"JJ"},
"dodo":	{"NN"},
"dodoes":	{"NNS"},
"dodonaea":	{"NN"},
"dodos":	{"NNS"},
"doe":	{"NN"},
"doe-site":	{"NN"},
"doei":	{"NN"},
"doer":	{"NN"},
"doers":	{"NNS"},
"does":	{"VBZ","NNS"},
"doeskin":	{"NN"},
"doff":	{"VB","VBP"},
"doffed":	{"VBD","VBN"},
"doffing":	{"VBG"},
"doffs":	{"VBZ"},
"dog":	{"NN","VBP","VB"},
"dog-and-pony":	{"NN"},
"dog-biscuit":	{"NN"},
"dog-biscuits":	{"NNS"},
"dog-collar":	{"NN"},
"dog-collars":	{"NNS"},
"dog-ear":	{"NN"},
"dog-eared":	{"JJ"},
"dog-eat-dog":	{"JJ"},
"dog-iron":	{"NN"},
"dog-leg":	{"NN"},
"dog-legs":	{"NNS"},
"dog-like":	{"JJ"},
"dog-meat":	{"NN"},
"dog-paddle":	{"NN","VB","VBP"},
"dog-paddled":	{"VBD","VBN"},
"dog-paddles":	{"VBZ"},
"dog-paddling":	{"VBG"},
"dog-pin":	{"JJ"},
"dog-powered":	{"JJ"},
"dog-rose":	{"NN"},
"dog-sized":	{"JJ"},
"dog-star":	{"NN"},
"dog-tired":	{"JJ"},
"dog-tooth":	{"NN"},
"dog-trot":	{"NN"},
"dogbane":	{"NN"},
"dogcart":	{"NN"},
"dogcarts":	{"NNS"},
"dogcatcher":	{"NN"},
"doge":	{"NN"},
"dogfight":	{"NN"},
"dogfighter":	{"NN"},
"dogfish":	{"NN"},
"dogged":	{"JJ","VBD","VBN"},
"doggedly":	{"RB"},
"doggedness":	{"NN"},
"doggerel":	{"NN"},
"doggie":	{"NN"},
"doggies":	{"NNS"},
"dogging":	{"VBG"},
"doggo":	{"RB"},
"doggone":	{"JJ","RB"},
"doggy":	{"NN","JJ"},
"doghouse":	{"NN"},
"doghouses":	{"NNS"},
"dogie":	{"NN"},
"dogleg":	{"NN"},
"doglegs":	{"NNS"},
"doglike":	{"JJ"},
"dogma":	{"NN"},
"dogmas":	{"NNS"},
"dogmatic":	{"JJ"},
"dogmatical":	{"JJ"},
"dogmatically":	{"RB"},
"dogmatise":	{"VB","VBP"},
"dogmatised":	{"VBD","VBN"},
"dogmatises":	{"VBZ"},
"dogmatising":	{"VBG"},
"dogmatism":	{"NN"},
"dogmatist":	{"NN"},
"dogmatize":	{"VB","VBP"},
"dogmatized":	{"VBD","VBN"},
"dogmatizes":	{"VBZ"},
"dogmatizing":	{"VBG"},
"dogs":	{"NNS","VBZ"},
"dogsbodies":	{"NNS"},
"dogsbody":	{"NN"},
"dogshit":	{"NN"},
"dogsled":	{"NN"},
"dogtooth":	{"NN"},
"dogtrot":	{"NN"},
"dogwatch":	{"NN"},
"dogwood":	{"NN"},
"dogwoods":	{"NNS"},
"dogy":	{"NN"},
"doh":	{"NN"},
"doi":	{"NN"},
"doilies":	{"NNS"},
"doily":	{"NN"},
"doing":	{"VBG","NN"},
"doings":	{"NNS"},
"dojc":	{"NN"},
"dol":	{"NN"},
"dolabrate":	{"JJ"},
"dolabriform":	{"JJ"},
"dolce":	{"JJ"},
"doldrums":	{"NNS"},
"dole":	{"NN","VB","VBP"},
"doled":	{"VBD","VBN"},
"doleful":	{"JJ"},
"dolefully":	{"RB"},
"dolefulness":	{"NN"},
"doles":	{"VBZ"},
"dolichocephalic":	{"JJ"},
"dolichocephalism":	{"NN"},
"dolichocephaly":	{"NN"},
"dolichocranial":	{"JJ"},
"dolichocranic":	{"JJ"},
"dolichonyx":	{"NN"},
"dolichos":	{"NNS"},
"dolichotis":	{"NNS"},
"doling":	{"VBG"},
"doliolidae":	{"NN"},
"doliolum":	{"NN"},
"doll":	{"NN","VB","VBP"},
"doll-like":	{"JJ"},
"doll-sized":	{"JJ"},
"dollar":	{"NN"},
"dollar-and-cents":	{"JJ"},
"dollar-convertible":	{"JJ"},
"dollar-cost":	{"JJ","NN"},
"dollar-denominated":	{"JJ"},
"dollar-mark":	{"NN"},
"dollar-priced":	{"JJ"},
"dollar-profits":	{"JJ"},
"dollar-related":	{"JJ"},
"dollar-sellers":	{"NNS"},
"dollar-selling":	{"NN"},
"dollar-sign":	{"NN"},
"dollar-yen":	{"JJ"},
"dollarette":	{"JJ"},
"dollarfish":	{"NN"},
"dollars":	{"NNS"},
"dollars-and-cents":	{"JJ"},
"dolled":	{"VBD","VBN"},
"dolledup":	{"JJ"},
"dollhouse":	{"NN"},
"dollied":	{"VBD","VBN"},
"dollies":	{"NNS","VBZ"},
"dolling":	{"VBG"},
"dollop":	{"NN","VB","VBP"},
"dollopped":	{"VBD","VBN"},
"dollopping":	{"VBG"},
"dollops":	{"NNS","VBZ"},
"dolls":	{"NNS","VBZ"},
"dolly":	{"NN","VB","VBP"},
"dollying":	{"VBG"},
"dolman":	{"NN"},
"dolmas":	{"NNS"},
"dolmen":	{"NN"},
"dolobid":	{"NN"},
"dolomite":	{"NN"},
"dolomitic":	{"JJ"},
"dolor":	{"NN"},
"dolorous":	{"JJ"},
"dolour":	{"NN"},
"dolourous":	{"JJ"},
"dolphin":	{"NN"},
"dolphinfish":	{"NN"},
"dolphins":	{"NNS"},
"dolt":	{"NN"},
"doltish":	{"JJ"},
"doltishly":	{"RB"},
"dolts":	{"NNS"},
"dom":	{"NN"},
"domain":	{"NN"},
"domains":	{"NNS"},
"domatium":	{"NN"},
"dombeya":	{"NN"},
"dome":	{"NN","VB","VBP"},
"dome-shaped":	{"JJ"},
"domed":	{"JJ","VBD","VBN"},
"domelike":	{"JJ"},
"domes":	{"NNS","VBZ"},
"domestic":	{"JJ","NN"},
"domestic-airline":	{"NN"},
"domestic-credit":	{"NN"},
"domestic-demand":	{"JJ"},
"domestic-inflation":	{"NN"},
"domestic-made":	{"JJ"},
"domestic-policy":	{"JJ","NN"},
"domestic-production":	{"NN"},
"domestically":	{"RB"},
"domesticate":	{"VB","VBP"},
"domesticated":	{"JJ","VBD","VBN"},
"domesticates":	{"VBZ"},
"domesticating":	{"VBG"},
"domestication":	{"NN"},
"domesticise":	{"VB","VBP"},
"domesticity":	{"NN"},
"domesticize":	{"VB","VBP"},
"domestics":	{"NNS"},
"domi":	{"FW"},
"domical":	{"JJ"},
"domicile":	{"NN"},
"domiciled":	{"JJ"},
"domiciles":	{"NNS"},
"domiciliary":	{"JJ"},
"domiciliate":	{"VB","VBP"},
"domiciliated":	{"VBD","VBN"},
"domiciliates":	{"VBZ"},
"domiciliating":	{"VBG"},
"domiciliation":	{"NN"},
"dominance":	{"NN"},
"dominant":	{"JJ","NN"},
"dominantly":	{"RB"},
"dominate":	{"VB","VBP"},
"dominated":	{"VBN","VBD"},
"dominates":	{"VBZ"},
"dominating":	{"JJ","VBG"},
"domination":	{"NN"},
"dominatrix":	{"NN"},
"domine":	{"NN"},
"dominee":	{"NN"},
"domineer":	{"VB","VBP"},
"domineered":	{"VBD","VBN"},
"domineering":	{"JJ","VBG"},
"domineeringly":	{"RB"},
"domineeringness":	{"NN"},
"domineers":	{"VBZ"},
"doming":	{"VBG"},
"dominic":	{"NN"},
"dominical":	{"JJ"},
"dominick":	{"NN"},
"dominicus":	{"NNS"},
"dominie":	{"NN"},
"dominion":	{"NN"},
"dominions":	{"NNS"},
"dominique":	{"NN"},
"domino":	{"NN"},
"dominoes":	{"NNS","NN"},
"dominus":	{"NN"},
"domitian":	{"NN"},
"don":	{"VB","NN","VBP"},
"don't-know":	{"NN"},
"dona":	{"NN"},
"donar":	{"NN"},
"donate":	{"VB","VBP"},
"donated":	{"VBN","VBD"},
"donates":	{"VBZ"},
"donating":	{"VBG"},
"donation":	{"NN"},
"donations":	{"NNS"},
"donatism":	{"NN"},
"donatist":	{"JJ","NN"},
"donator":	{"NN"},
"donators":	{"NNS"},
"donatus":	{"NNS"},
"donbas":	{"NNS"},
"donbass":	{"NN"},
"done":	{"VBN","JJ","UH"},
"done-and":	{"CC"},
"done-unto":	{"JJ"},
"donee":	{"NN"},
"donetsk":	{"NN"},
"donetske":	{"NN"},
"dong":	{"NN"},
"dongle":	{"NN"},
"donizetti":	{"NN"},
"donjon":	{"NN"},
"donkey":	{"NN"},
"donkeys":	{"NNS"},
"donkeywork":	{"NN"},
"donna":	{"NN"},
"donnean":	{"JJ"},
"donned":	{"VBD","VBN"},
"donnian":	{"JJ"},
"donning":	{"VBG"},
"donnish":	{"JJ"},
"donnybrook":	{"NN"},
"donor":	{"NN"},
"donors":	{"NNS"},
"dons":	{"VBZ","NNS"},
"donut":	{"NN"},
"donut-sales":	{"JJ"},
"donuts":	{"NNS"},
"doo":	{"NN"},
"doo-wop":	{"NN"},
"doob":	{"NN"},
"doodad":	{"NN"},
"doodads":	{"NNS"},
"doodia":	{"NN"},
"doodle":	{"VB","VBP","NN"},
"doodlebug":	{"NN"},
"doodled":	{"VBD","VBN"},
"doodles":	{"VBZ","NNS"},
"doodling":	{"VBG","NN"},
"doodlings":	{"NNS"},
"doodly-squat":	{"NN"},
"doofus":	{"JJ","NN"},
"doohickey":	{"NN"},
"doojigger":	{"NN"},
"doom":	{"VB","VBP","NN"},
"doomed":	{"VBN","JJ","VBD"},
"dooming":	{"VBG"},
"dooms":	{"VBZ"},
"doomsaid":	{"VBD","VBN"},
"doomsay":	{"VB","VBP"},
"doomsayer":	{"NN"},
"doomsayers":	{"NNS"},
"doomsaying":	{"VBG","NN"},
"doomsayings":	{"NNS"},
"doomsays":	{"VBZ"},
"doomsday":	{"NN"},
"doomster":	{"NN"},
"doomsters":	{"NNS"},
"door":	{"NN"},
"door-frame":	{"NN"},
"door-fronted":	{"JJ"},
"door-to-door":	{"JJ"},
"doorbell":	{"NN"},
"doorbells":	{"NNS"},
"doorcase":	{"NN"},
"doorframe":	{"NN"},
"doorhandle":	{"NN"},
"doorjamb":	{"NN"},
"doorkeeper":	{"NN"},
"doorkeepers":	{"NNS"},
"doorknob":	{"NN"},
"doorknobs":	{"NNS"},
"doorknocker":	{"NN"},
"doorknockers":	{"NNS"},
"doorlock":	{"NN"},
"doorman":	{"NN"},
"doormat":	{"NN"},
"doormats":	{"NNS"},
"doormen":	{"NNS"},
"doornail":	{"NN"},
"doorplate":	{"NN"},
"doorpost":	{"NN"},
"doorposts":	{"NNS"},
"doors":	{"NNS"},
"doorsill":	{"NN"},
"doorstep":	{"NN","VB","VBP"},
"doorstepped":	{"VBD","VBN"},
"doorstepping":	{"VBG"},
"doorsteps":	{"NNS","VBZ"},
"doorstop":	{"NN"},
"doorstopper":	{"NN"},
"doorstops":	{"NNS"},
"doorway":	{"NN"},
"doorways":	{"NNS"},
"dooryard":	{"NN"},
"dopa":	{"NN"},
"dopamine":	{"NN"},
"dopastat":	{"NN"},
"dope":	{"NN","VB","VBP"},
"dope-ridden":	{"JJ"},
"doped":	{"VBD","VBN"},
"dopeier":	{"JJR"},
"dopeiest":	{"JJS"},
"doper":	{"NN"},
"dopes":	{"VBZ","NNS"},
"dopey":	{"JJ"},
"doping":	{"VBG"},
"doppelganger":	{"NN"},
"doppelzentner":	{"NN"},
"dopy":	{"JJ"},
"dorbeetle":	{"NN"},
"doriden":	{"NN"},
"dories":	{"NNS"},
"doritos":	{"NNS"},
"dork":	{"NN"},
"dorking":	{"NN"},
"dorks":	{"NNS"},
"dorky":	{"JJ"},
"dorm":	{"NN"},
"dormancy":	{"NN"},
"dormant":	{"JJ"},
"dormer":	{"NN"},
"dormers":	{"NNS"},
"dormice":	{"NNS"},
"dormie":	{"JJ"},
"dormition":	{"NN"},
"dormitories":	{"NNS"},
"dormitory":	{"NN"},
"dormouse":	{"NN"},
"dorms":	{"NNS"},
"dormy":	{"JJ"},
"doronicum":	{"NN"},
"dorotheanthus":	{"NN"},
"dorsal":	{"JJ"},
"dorsally":	{"RB"},
"dorsey":	{"NN"},
"dorsiflexion":	{"NN"},
"dorsoventral":	{"JJ"},
"dorsoventrally":	{"RB"},
"dorsum":	{"NN"},
"dory":	{"NN"},
"dorylinae":	{"NN"},
"doryopteris":	{"NNS"},
"dos":	{"NNS"},
"dosage":	{"NN"},
"dosages":	{"NNS"},
"dose":	{"NN","VBP","VB"},
"dosed":	{"VBD","VBN"},
"dosemeter":	{"NN"},
"doses":	{"NNS","VBZ"},
"dosimeter":	{"NN"},
"dosimetry":	{"NN"},
"dosing":	{"VBG"},
"doss":	{"VB","VBP","NN"},
"doss-house":	{"NN"},
"doss-houses":	{"NNS"},
"dossal":	{"NN"},
"dossed":	{"VBD","VBN"},
"dossel":	{"NN"},
"dosser":	{"NN"},
"dossers":	{"NNS"},
"dosses":	{"VBZ"},
"dosshouse":	{"NN"},
"dossier":	{"NN"},
"dossiers":	{"NNS"},
"dossing":	{"VBG"},
"dost":	{"VBP"},
"dostoevski":	{"NN"},
"dostoevskian":	{"JJ"},
"dostoyevskian":	{"JJ"},
"dot":	{"NN","VB","VBP"},
"dot-com":	{"JJ","NN"},
"dot-coms":	{"NNS"},
"dot-matrix":	{"NN"},
"dotage":	{"NN"},
"dotard":	{"NN"},
"dote":	{"VB","NN","VBP"},
"doted":	{"VBD","VBN"},
"dotes":	{"VBZ"},
"doth":	{"VBZ"},
"doting":	{"JJ","VBG"},
"dotingly":	{"RB"},
"dotrel":	{"NN"},
"dots":	{"NNS","VBZ"},
"dotted":	{"JJ","VBD","VBN"},
"dotterel":	{"NN"},
"dottier":	{"JJR"},
"dottiest":	{"JJS"},
"dottily":	{"RB"},
"dotting":	{"VBG"},
"dottle":	{"NN"},
"dotty":	{"JJ"},
"douala":	{"NN"},
"double":	{"JJ","VBP","NN","RB","VB","PDT"},
"double-A-rated":	{"JJ"},
"double-B-minus":	{"NN"},
"double-a-rated":	{"JJ"},
"double-b-minus":	{"NN"},
"double-barreled":	{"JJ"},
"double-barrelled":	{"JJ"},
"double-bass":	{"JJ"},
"double-bedded":	{"JJ"},
"double-billing":	{"VBG"},
"double-bladed":	{"JJ"},
"double-bogey":	{"NN"},
"double-bogeyed":	{"JJ"},
"double-breasted":	{"JJ"},
"double-check":	{"VB","VBP"},
"double-checked":	{"VBD","VBN"},
"double-checking":	{"VBG"},
"double-checks":	{"VBZ"},
"double-chinned":	{"JJ"},
"double-coupon":	{"NN"},
"double-cross":	{"VB","VBP","NN"},
"double-crossed":	{"VBD","VBN"},
"double-crosser":	{"NN"},
"double-crossers":	{"NNS"},
"double-crosses":	{"VBZ","NNS"},
"double-crossing":	{"VBG"},
"double-date":	{"VB","VBP"},
"double-dated":	{"VBD","VBN"},
"double-dates":	{"VBZ"},
"double-dating":	{"VBG"},
"double-dealer":	{"NN"},
"double-dealing":	{"NN"},
"double-deck":	{"JJ"},
"double-decked":	{"JJ"},
"double-decker":	{"NN","JJ"},
"double-deckers":	{"NNS"},
"double-decking":	{"NN"},
"double-digit":	{"JJ"},
"double-double":	{"NN"},
"double-doubles":	{"NNS"},
"double-dyed":	{"JJ"},
"double-edged":	{"JJ"},
"double-entendre":	{"NN"},
"double-faced":	{"JJ"},
"double-geared":	{"JJ"},
"double-glaze":	{"VB","VBP"},
"double-glazed":	{"JJ","VBD","VBN"},
"double-glazes":	{"VBZ"},
"double-glazing":	{"VBG"},
"double-hamburger":	{"NN"},
"double-header":	{"NN"},
"double-headers":	{"NNS"},
"double-helix":	{"JJ"},
"double-humped":	{"JJ"},
"double-jeopardy":	{"NN"},
"double-jointed":	{"JJ"},
"double-magnum":	{"NN"},
"double-married":	{"JJ"},
"double-meaning":	{"NN"},
"double-park":	{"VB","VBP"},
"double-parked":	{"VBD","VBN"},
"double-parking":	{"VBG"},
"double-parks":	{"VBZ"},
"double-prop":	{"NN"},
"double-quick":	{"JJ"},
"double-room":	{"NN"},
"double-space":	{"VB","VBP"},
"double-spaced":	{"JJ","VBD","VBN"},
"double-spaces":	{"VBZ"},
"double-spacing":	{"NN","VBG"},
"double-stage":	{"JJ"},
"double-step":	{"JJ"},
"double-talk":	{"NN"},
"double-team":	{"VB","VBP","NN"},
"double-teamed":	{"VBD","VBN"},
"double-teaming":	{"VBG"},
"double-teams":	{"VBZ","NNS"},
"double-tongue":	{"VB","VBP"},
"double-tongued":	{"JJ","VBD","VBN"},
"double-tongues":	{"VBZ"},
"double-tonguing":	{"VBG"},
"double-valued":	{"JJ"},
"double-wall":	{"JJ"},
"double-whammy":	{"NN"},
"double-wing":	{"JJ"},
"doubleA-2":	{"JJ"},
"doubled":	{"VBD","VBN"},
"doubled-edged":	{"JJ"},
"doubleheader":	{"NN"},
"doubler":	{"NN"},
"doubles":	{"NNS","VBZ"},
"doublespeak":	{"NN"},
"doublet":	{"NN"},
"doublethink":	{"NN"},
"doubleton":	{"NN"},
"doubletree":	{"NN"},
"doublets":	{"NNS"},
"doubling":	{"NN","VBG"},
"doubloon":	{"NN"},
"doubly":	{"RB"},
"doubt":	{"NN","VB","VBP"},
"doubte":	{"NN"},
"doubted":	{"VBD","VBN"},
"doubter":	{"NN"},
"doubters":	{"NNS"},
"doubtful":	{"JJ"},
"doubtfully":	{"RB"},
"doubtfulness":	{"NN"},
"doubting":	{"VBG"},
"doubtingly":	{"RB"},
"doubtless":	{"RB"},
"doubtlessly":	{"RB"},
"doubts":	{"NNS","VBZ"},
"douche":	{"NN","VB","VBP"},
"douchebag":	{"NN"},
"douchebags":	{"NNS"},
"douched":	{"VBD","VBN"},
"douches":	{"VBZ","NNS"},
"douchey":	{"JJ"},
"douching":	{"VBG"},
"dough":	{"NN"},
"doughboy":	{"NN"},
"dougherty":	{"NN"},
"doughnut":	{"NN"},
"doughnut-shaped":	{"JJ"},
"doughnuts":	{"NNS"},
"doughnuttery":	{"NN"},
"doughs":	{"NNS"},
"doughty":	{"JJ"},
"doughy":	{"JJ"},
"doula":	{"NN"},
"dour":	{"JJ"},
"doura":	{"NN"},
"dourah":	{"NN"},
"dourly":	{"RB"},
"douroucouli":	{"NN"},
"douse":	{"VB","VBP"},
"doused":	{"VBD","VBN"},
"douses":	{"VBZ"},
"dousing":	{"VBG"},
"dove":	{"NN","VBD"},
"dovecote":	{"NN"},
"dovecotes":	{"NNS"},
"dovekie":	{"NN"},
"doves":	{"NNS"},
"dovetail":	{"VB","VBP","NN"},
"dovetailed":	{"VBD","VBN"},
"dovetailing":	{"VBG"},
"dovetails":	{"VBZ","NNS"},
"dovish":	{"JJ"},
"dovishness":	{"NN"},
"dovyalis":	{"NN"},
"dowager":	{"NN","JJ"},
"dowagers":	{"NNS"},
"dowdier":	{"JJR"},
"dowdiest":	{"JJS"},
"dowdily":	{"RB"},
"dowdiness":	{"NN"},
"dowding":	{"NN"},
"dowdy":	{"JJ"},
"dowdy-looking":	{"JJ"},
"dowel":	{"NN"},
"doweling":	{"NN"},
"dowels":	{"NNS"},
"dower":	{"NN","VB","VBP"},
"dowered":	{"VBD","VBN"},
"dowering":	{"VBG"},
"dowerless":	{"JJ"},
"dowers":	{"VBZ"},
"dowery":	{"NN"},
"dowitcher":	{"NN"},
"dowland":	{"NN"},
"dowling":	{"NN"},
"down":	{"RB","IN","NN","VBP","VB","RP","JJ"},
"down-and-out":	{"JJ","NN"},
"down-and-outer":	{"NN"},
"down-and-outers":	{"NNS"},
"down-and-outs":	{"NNS"},
"down-bow":	{"NN"},
"down-down":	{"JJ"},
"down-home":	{"JJ"},
"down-payment":	{"NN"},
"down-payments":	{"NNS"},
"down-the-line":	{"JJ"},
"down-to-earth":	{"JJ"},
"downbeat":	{"NN","JJ"},
"downbeats":	{"NNS"},
"downbound":	{"JJ"},
"downcast":	{"JJ"},
"downdraft":	{"NN"},
"downdrift":	{"NN"},
"downed":	{"VBD","VBN"},
"downer":	{"NN"},
"downers":	{"NNS"},
"downfall":	{"NN"},
"downfield":	{"JJ","RB"},
"downgrade":	{"NN","VB","VBP"},
"downgraded":	{"VBN","VBD"},
"downgrades":	{"NNS","VBZ"},
"downgrading":	{"VBG","NN"},
"downhearted":	{"JJ"},
"downheartedness":	{"NN"},
"downhill":	{"RB","JJ"},
"downier":	{"JJR"},
"downiest":	{"JJS"},
"downiness":	{"NN"},
"downing":	{"VBG"},
"downlike":	{"JJ"},
"download":	{"NN","VBP","VB"},
"downloaded":	{"VBD","VBN"},
"downloading":	{"VBG","NN"},
"downloads":	{"NNS","VBZ"},
"downmarket":	{"JJ","RB"},
"downpayment":	{"NN"},
"downpayments":	{"NNS"},
"downplay":	{"VB","VBP"},
"downplayed":	{"VBD","VBN"},
"downplaying":	{"VBG"},
"downplays":	{"VBZ"},
"downpour":	{"NN"},
"downpours":	{"NNS"},
"downright":	{"RB","JJ"},
"downrightness":	{"NN"},
"downriver":	{"RB"},
"downs":	{"NNS","VBZ"},
"downscale":	{"JJ","VBP","VB"},
"downscaled":	{"VBD","VBN"},
"downscales":	{"VBZ"},
"downscaling":	{"VBG"},
"downshift":	{"VB","VBP"},
"downshifted":	{"VBD","VBN"},
"downshifting":	{"VBG"},
"downshifts":	{"VBZ"},
"downshoot":	{"NN"},
"downside":	{"NN"},
"downsides":	{"NNS"},
"downsize":	{"VB","VBP"},
"downsized":	{"VBD","VBN"},
"downsizes":	{"VBZ"},
"downsizing":	{"NN","VBG"},
"downslope":	{"JJ","NN"},
"downspin":	{"NN"},
"downstage":	{"RB","JJ"},
"downstairs":	{"RB","JJ","NN"},
"downstream":	{"RB","JJ"},
"downstroke":	{"NN"},
"downswing":	{"NN"},
"downswings":	{"NNS"},
"downtalking":	{"JJ"},
"downtick":	{"NN"},
"downtime":	{"NN","JJ"},
"downtown":	{"RB","JJ","NN"},
"downtrend":	{"NN"},
"downtrodden":	{"JJ","NN"},
"downturn":	{"NN"},
"downturns":	{"NNS"},
"downward":	{"JJ","RB"},
"downward-arching":	{"JJ"},
"downward-sloping":	{"JJ"},
"downwardly":	{"RB"},
"downwards":	{"RB"},
"downwind":	{"RB"},
"downy":	{"JJ"},
"dowries":	{"NNS"},
"dowry":	{"NN"},
"dowse":	{"VBP","VB"},
"dowsed":	{"VBD","VBN"},
"dowser":	{"NN"},
"dowsers":	{"NNS"},
"dowses":	{"VBZ"},
"dowsing":	{"VBG"},
"dox":	{"NN","VB","VBP"},
"doxazosin":	{"NN"},
"doxed":	{"VBD","VBN"},
"doxepin":	{"NN"},
"doxes":	{"NNS","VBZ"},
"doxing":	{"VBG"},
"doxology":	{"NN"},
"doxorubicin":	{"NN"},
"doxy":	{"NN"},
"doxycycline":	{"NN"},
"doyen":	{"NN"},
"doyenne":	{"NN"},
"doyennes":	{"NNS"},
"doyens":	{"NNS"},
"doyley":	{"NN"},
"doyly":	{"NN"},
"doze":	{"VB","VBP","NN"},
"dozed":	{"VBD","VBN"},
"dozen":	{"NN","NNS","CD"},
"dozens":	{"NNS"},
"dozer":	{"NN"},
"dozes":	{"VBZ"},
"dozing":	{"VBG"},
"dozy":	{"JJ","NN"},
"dp":	{"NN"},
"dph":	{"NN"},
"dphil":	{"NN"},
"dprk":	{"NN"},
"dr.":	{"NN"},
"drab":	{"JJ","NN"},
"drab-haired":	{"JJ"},
"draba":	{"NN"},
"drabbed":	{"VBD","VBN"},
"drabbing":	{"VBG"},
"drably":	{"RB"},
"drabness":	{"NN"},
"drabs":	{"VBZ"},
"dracaena":	{"NN"},
"dracaenaceae":	{"NN"},
"dracenaceae":	{"NN"},
"drachm":	{"NN"},
"drachma":	{"NN"},
"drachmas":	{"NNS"},
"draco":	{"NN"},
"dracocephalum":	{"NN"},
"draconian":	{"JJ"},
"dracontium":	{"NN"},
"dracula":	{"NN"},
"dracunculiasis":	{"NN"},
"dracunculidae":	{"NN"},
"dracunculus":	{"NN"},
"draft":	{"NN","JJ","VB","VBP"},
"draft-avoidance":	{"NN"},
"draft-resistance":	{"NN"},
"drafted":	{"VBN","VBD"},
"draftee":	{"NN"},
"draftees":	{"NNS"},
"drafter":	{"NN"},
"drafters":	{"NNS"},
"drafting":	{"VBG"},
"drafts":	{"NNS","VBZ"},
"draftsman":	{"NN"},
"draftsmanship":	{"NN"},
"draftsmen":	{"NNS"},
"draftsperson":	{"NN"},
"drafty":	{"JJ"},
"drag":	{"NN","VB","VBP"},
"drag-down":	{"JJ"},
"drag-hunt":	{"NN"},
"drag-net":	{"NN"},
"dragee":	{"NN"},
"dragged":	{"VBD","VBN"},
"dragger":	{"NN"},
"dragging":	{"VBG"},
"draggingly":	{"RB"},
"draggle":	{"VB","VBP"},
"draggled":	{"JJ","VBD","VBN"},
"draggles":	{"VBZ"},
"draggling":	{"VBG"},
"dragnet":	{"NN"},
"dragoman":	{"NN"},
"dragomans":	{"NNS"},
"dragon":	{"NN"},
"dragonet":	{"NN"},
"dragonflies":	{"NNS"},
"dragonfly":	{"NN"},
"dragonhead":	{"NN"},
"dragons":	{"NNS"},
"dragoon":	{"NN","VB","VBP"},
"dragooned":	{"VBD","VBN"},
"dragooning":	{"VBG"},
"dragoons":	{"NNS","VBZ"},
"drags":	{"NNS","VBZ"},
"dragster":	{"NN"},
"dragsters":	{"NNS"},
"dragunov":	{"NN"},
"drain":	{"NN","VB","VBP"},
"drainage":	{"NN"},
"drainboard":	{"NN"},
"drainboards":	{"NNS"},
"drained":	{"VBD","VBN","JJ"},
"draining":	{"VBG"},
"drainpipe":	{"NN"},
"drainpipes":	{"NNS"},
"drainplug":	{"NN"},
"drains":	{"NNS","VBZ"},
"drake":	{"NN"},
"dram":	{"NN"},
"drama":	{"NN"},
"drama-filled":	{"JJ"},
"dramamine":	{"NN"},
"dramas":	{"NNS"},
"dramatic":	{"JJ"},
"dramatical":	{"JJ"},
"dramatically":	{"RB"},
"dramatics":	{"NN"},
"dramatisation":	{"NN"},
"dramatisations":	{"NNS"},
"dramatise":	{"VB","VBP"},
"dramatised":	{"VBD","VBN"},
"dramatises":	{"VBZ"},
"dramatising":	{"VBG"},
"dramatist":	{"NN"},
"dramatists":	{"NNS"},
"dramatization":	{"NN"},
"dramatizations":	{"NNS"},
"dramatize":	{"VB","VBP"},
"dramatized":	{"VBD","VBN"},
"dramatizes":	{"VBZ"},
"dramatizing":	{"VBG"},
"dramaturgic":	{"JJ"},
"dramaturgical":	{"JJ"},
"dramaturgy":	{"NN"},
"drams":	{"NNS"},
"drank":	{"VBD"},
"drape":	{"VB","VBP","NN"},
"draped":	{"VBD","VBN"},
"draper":	{"NN"},
"draperies":	{"NNS"},
"drapers":	{"NNS"},
"drapery":	{"NN"},
"drapes":	{"VBZ","NNS"},
"draping":	{"VBG"},
"drastic":	{"JJ"},
"drastically":	{"RB"},
"draught":	{"NN","VBP","JJ","VB"},
"draughted":	{"VBD","VBN"},
"draughting":	{"VBG"},
"draughts":	{"NNS","VBZ"},
"draughtsman":	{"NN"},
"draughty":	{"JJ"},
"dravidian":	{"NN"},
"dravidic":	{"NN"},
"draw":	{"VB","NN","VBP"},
"draw-down":	{"NN"},
"drawback":	{"NN"},
"drawbacks":	{"NNS"},
"drawbar":	{"NN"},
"drawbridge":	{"NN"},
"drawdown":	{"NN"},
"drawee":	{"NN"},
"drawer":	{"NN"},
"drawers":	{"NNS"},
"drawing":	{"VBG","NN"},
"drawing-board":	{"NN"},
"drawing-boards":	{"NNS"},
"drawing-pin":	{"NN"},
"drawing-pins":	{"NNS"},
"drawing-room":	{"NN"},
"drawing-rooms":	{"NNS"},
"drawings":	{"NNS"},
"drawknife":	{"NN"},
"drawl":	{"NN","VB","VBP"},
"drawled":	{"VBD","VBN"},
"drawler":	{"NN"},
"drawling":	{"VBG"},
"drawls":	{"VBZ"},
"drawn":	{"VBN","JJ"},
"drawn-back":	{"NN"},
"drawn-out":	{"JJ"},
"drawnwork":	{"NN"},
"draws":	{"VBZ","NNS"},
"drawshave":	{"NN"},
"drawstring":	{"NN"},
"drawstrings":	{"NNS"},
"dray":	{"NN"},
"drayhorse":	{"NN"},
"drdw":	{"NN"},
"dread":	{"NN","VB","VBP","JJ"},
"dreaded":	{"JJ","VBD","VBN"},
"dreadful":	{"JJ"},
"dreadfully":	{"RB"},
"dreadfulness":	{"NN"},
"dreading":	{"VBG"},
"dreadlock":	{"NN"},
"dreadnaught":	{"NN"},
"dreadnought":	{"NN"},
"dreads":	{"VBZ"},
"dream":	{"NN","VB","VBP"},
"dream-ridden":	{"JJ"},
"dreamboat":	{"NN"},
"dreamcatcher":	{"NN"},
"dreamcatchers":	{"NNS"},
"dreamed":	{"VBD","VBN"},
"dreamer":	{"NN"},
"dreamers":	{"NNS"},
"dreamfully":	{"RB"},
"dreamier":	{"JJR"},
"dreamiest":	{"JJS"},
"dreamily":	{"RB"},
"dreamin":	{"NN"},
"dreaminess":	{"NN"},
"dreaming":	{"VBG"},
"dreamland":	{"NN"},
"dreamless":	{"JJ"},
"dreamlessly":	{"RB"},
"dreamlike":	{"JJ"},
"dreams":	{"NNS","VBZ"},
"dreamt":	{"VBD","VBN"},
"dreamworld":	{"NN"},
"dreamy":	{"JJ"},
"drear":	{"JJ"},
"drearier":	{"JJR"},
"dreariest":	{"JJS"},
"drearily":	{"RB"},
"dreariness":	{"NN"},
"dreary":	{"JJ"},
"dreck":	{"NN"},
"dredge":	{"VB","VBP","NN"},
"dredged":	{"VBD","VBN"},
"dredger":	{"NN"},
"dredgers":	{"NNS"},
"dredges":	{"VBZ","NNS"},
"dredging":	{"VBG"},
"dreg":	{"NN"},
"dregs":	{"NNS"},
"dreissena":	{"NN"},
"drench":	{"VB","VBP"},
"drenched":	{"JJ","VBD","VBN"},
"drenches":	{"VBZ"},
"drenching":	{"NN","VBG","JJ"},
"drepanididae":	{"NN"},
"drepanis":	{"NNS"},
"dress":	{"NN","VB","VBP"},
"dress-circle":	{"NN"},
"dress-shirt":	{"NN"},
"dressage":	{"NN"},
"dressed":	{"VBN","VBD","JJ"},
"dressed-up":	{"JJ"},
"dresser":	{"NN"},
"dressers":	{"NNS"},
"dresses":	{"NNS","VBZ"},
"dressier":	{"JJR"},
"dressiest":	{"JJS"},
"dressing":	{"NN","VBG"},
"dressings":	{"NNS"},
"dressmaker":	{"NN"},
"dressmakers":	{"NNS"},
"dressmaking":	{"NN"},
"dressy":	{"JJ"},
"drew":	{"VBD"},
"drexel-managed":	{"JJ"},
"drexel-underwritten":	{"JJ"},
"drexler":	{"NN"},
"drey":	{"NN"},
"dreyfus":	{"NNS"},
"drib":	{"NN"},
"drib-drool":	{"NN"},
"dribble":	{"VB","VBP","NN"},
"dribbled":	{"VBD","VBN"},
"dribbler":	{"NN"},
"dribbles":	{"VBZ","NNS"},
"dribbling":	{"VBG"},
"driblet":	{"NN"},
"driblets":	{"NNS"},
"dried":	{"JJ","VBD","VBN"},
"dried-out":	{"JJ"},
"dried-up":	{"JJ"},
"drier":	{"NN","JJR"},
"driers":	{"NNS"},
"dries":	{"VBZ"},
"driest":	{"JJS"},
"drift":	{"VB","VBP","NN"},
"drift-ice":	{"NN"},
"drift-net":	{"NN"},
"drift-wood":	{"NN"},
"driftage":	{"NN"},
"drifted":	{"VBD","VBN"},
"drifter":	{"NN"},
"drifters":	{"NNS"},
"driftfish":	{"NN"},
"drifting":	{"VBG"},
"driftnet":	{"NN"},
"driftnets":	{"NNS"},
"drifts":	{"VBZ","NNS"},
"driftwood":	{"NN"},
"drill":	{"NN","VB","VBP"},
"drill-bit":	{"NN"},
"drill-like":	{"JJ"},
"drilled":	{"VBD","VBN"},
"driller":	{"NN"},
"drillers":	{"NNS"},
"drilling":	{"NN","VBG"},
"drills":	{"NNS","VBZ"},
"drily":	{"RB"},
"drink":	{"NN","VB","VBP"},
"drinkable":	{"JJ"},
"drinker":	{"NN"},
"drinkers":	{"NNS"},
"drinking":	{"NN","JJ","VBG"},
"drinking-water":	{"NN"},
"drinks":	{"NNS","VBZ"},
"drip":	{"NN","VB","VBP"},
"drip-dried":	{"VBD","VBN"},
"drip-dries":	{"VBZ"},
"drip-dry":	{"JJ","VB","VBP"},
"drip-drying":	{"VBG"},
"dripless":	{"JJ"},
"drippage":	{"NN"},
"dripped":	{"VBD","VBN"},
"drippily":	{"RB"},
"drippiness":	{"NN"},
"dripping":	{"JJ","NN","VBG"},
"drippings":	{"NNS"},
"drippy":	{"JJ"},
"drips":	{"NNS","VBZ"},
"dripstone":	{"NN"},
"drive":	{"NN","VB","VBP"},
"drive-by":	{"NN","JJ"},
"drive-bys":	{"NNS"},
"drive-in":	{"NN"},
"drive-ins":	{"NNS"},
"drive-through":	{"JJ","NN"},
"drive-train":	{"NN"},
"drive-yourself":	{"JJ"},
"drivel":	{"NN","VB","VBP"},
"driveled":	{"VBD","VBN"},
"driveling":	{"VBG"},
"drivelled":	{"VBD","VBN"},
"driveller":	{"NN"},
"drivelling":	{"VBG"},
"drivels":	{"VBZ","VBZ"},
"driven":	{"VBN","JJ"},
"driver":	{"NN"},
"driverless":	{"JJ"},
"drivers":	{"NNS"},
"drives":	{"NNS","VBZ"},
"driveshaft":	{"NN"},
"driveway":	{"NN"},
"driveways":	{"NNS"},
"driving":	{"VBG","JJ","NN"},
"driving-belt":	{"NN"},
"driving-licence":	{"NN"},
"driving-licences":	{"NNS"},
"driving-test":	{"NN"},
"driving-tests":	{"NNS"},
"driving-wheel":	{"NN"},
"driving-wheels":	{"NNS"},
"drixoral":	{"NN"},
"drizzle":	{"VB","VBP","NN"},
"drizzled":	{"VBD","VBN"},
"drizzles":	{"VBZ"},
"drizzling":	{"VBG"},
"drizzly":	{"JJ"},
"drms":	{"NNS"},
"drogheda":	{"NN"},
"drogue":	{"NN"},
"droid":	{"NN"},
"droids":	{"NNS"},
"droll":	{"JJ"},
"drollery":	{"NN"},
"dromaeosaur":	{"NN"},
"dromaeosauridae":	{"NN"},
"dromaius":	{"NNS"},
"drome":	{"NN"},
"dromedaries":	{"NNS"},
"dromedary":	{"NN","JJ"},
"dromozoa":	{"NNS"},
"dromozootic":	{"JJ"},
"dronabinol":	{"NN"},
"drone":	{"VB","VBP","NN"},
"droned":	{"VBD","VBN"},
"drones":	{"VBZ","NNS"},
"droning":	{"VBG"},
"drool":	{"VB","VBP"},
"drooled":	{"VBD","VBN"},
"drooler":	{"NN"},
"drooling":	{"VBG"},
"drools":	{"VBZ"},
"droop":	{"VB","VBP"},
"drooped":	{"VBD","VBN"},
"droopier":	{"JJR"},
"droopiest":	{"JJS"},
"drooping":	{"VBG"},
"droopingly":	{"RB"},
"droops":	{"VBZ"},
"droopy":	{"JJ"},
"droopy-eyed":	{"JJ"},
"drop":	{"NN","VB","VBP"},
"drop-block":	{"NN"},
"drop-dead":	{"RB","JJ"},
"drop-down":	{"JJ","NN"},
"drop-downs":	{"NNS"},
"drop-in":	{"JJ"},
"drop-kick":	{"VB","VBP"},
"drop-kicked":	{"VBD","VBN"},
"drop-kicking":	{"VBG"},
"drop-kicks":	{"VBZ"},
"drop-leaf":	{"NN"},
"drop-off":	{"NN"},
"drop-out":	{"JJ"},
"drop-seed":	{"NN"},
"dropdown":	{"JJ","NN"},
"dropdowns":	{"NNS"},
"dropforge":	{"VB"},
"dropkick":	{"NN"},
"dropkicker":	{"NN"},
"droplet":	{"NN"},
"droplets":	{"NNS"},
"dropline":	{"NN"},
"dropoff":	{"NN"},
"dropoffs":	{"NNS"},
"dropout":	{"NN"},
"dropouts":	{"NNS"},
"droppable":	{"JJ"},
"dropped":	{"VBD","VBN"},
"dropper":	{"NN"},
"droppers":	{"NNS"},
"dropping":	{"VBG","NN"},
"droppings":	{"NNS"},
"drops":	{"NNS","VBZ"},
"dropseed":	{"NN"},
"dropsical":	{"JJ"},
"dropsy":	{"NN"},
"drosera":	{"NN"},
"droseraceae":	{"NN"},
"droshky":	{"NN"},
"drosky":	{"NN"},
"drosophila":	{"NN"},
"drosophilidae":	{"NN"},
"drosophyllum":	{"NN"},
"dross":	{"NN"},
"drought":	{"NN"},
"drought-induced":	{"JJ"},
"drought-inspired":	{"JJ"},
"drought-ravaged":	{"JJ"},
"drought-related":	{"JJ"},
"drought-seared":	{"JJ"},
"drought-shriveled":	{"JJ"},
"drought-stricken":	{"JJ"},
"drought-stunted":	{"JJ"},
"droughts":	{"NNS"},
"drouth":	{"NN"},
"drove":	{"VBD","NN"},
"drover":	{"NN"},
"drovers":	{"NNS"},
"droves":	{"NNS"},
"drown":	{"VB","VBP"},
"drowned":	{"VBD","VBN"},
"drowning":	{"VBG"},
"drownings":	{"NNS"},
"drowns":	{"VBZ"},
"drowse":	{"VB","VBP","NN"},
"drowsed":	{"VBD","VBN"},
"drowses":	{"VBZ"},
"drowsier":	{"JJR"},
"drowsiest":	{"JJS"},
"drowsily":	{"RB"},
"drowsiness":	{"NN"},
"drowsing":	{"VBG"},
"drowsy":	{"JJ"},
"drub":	{"VB","VBP"},
"drubbed":	{"VBD","VBN"},
"drubbing":	{"VBG","NN"},
"drubbings":	{"NNS"},
"drubs":	{"VBZ"},
"drudge":	{"NN","VB","VBP"},
"drudged":	{"VBD","VBN"},
"drudgery":	{"NN"},
"drudges":	{"NNS","VBZ"},
"drudging":	{"VBG"},
"drug":	{"NN","VBP","VB"},
"drug-abuse":	{"JJ","NN"},
"drug-addicted":	{"JJ"},
"drug-addled":	{"JJ"},
"drug-approval":	{"JJ"},
"drug-bill":	{"NN"},
"drug-cartel":	{"JJ"},
"drug-consuming":	{"JJ"},
"drug-dealing":	{"JJ","NN"},
"drug-delivery":	{"JJ"},
"drug-education":	{"NN"},
"drug-enforcement":	{"JJ"},
"drug-fighting":	{"JJ"},
"drug-financed":	{"JJ"},
"drug-free":	{"JJ","NN"},
"drug-funding":	{"NN"},
"drug-industry":	{"NN"},
"drug-infested":	{"JJ"},
"drug-interdiction":	{"NN","JJ"},
"drug-laden":	{"JJ"},
"drug-law":	{"NN"},
"drug-making":	{"JJ"},
"drug-policy":	{"NN"},
"drug-pricing":	{"NN"},
"drug-pushing":	{"JJ"},
"drug-related":	{"JJ"},
"drug-sales":	{"NNS"},
"drug-seeking":	{"JJ"},
"drug-sensing":	{"JJ"},
"drug-smuggling":	{"JJ"},
"drug-store":	{"NN"},
"drug-supply":	{"JJ"},
"drug-traffickers":	{"NNS"},
"drug-trafficking":	{"JJ","VBG","NN"},
"drug-treatment":	{"NN","JJ"},
"drugged":	{"JJ","VBD","VBN"},
"druggers":	{"NNS"},
"drugget":	{"NN"},
"druggies":	{"NNS"},
"drugging":	{"NN","VBG"},
"druggist":	{"NN"},
"druggists":	{"NNS"},
"drugless":	{"JJ"},
"drugmaker":	{"NN"},
"drugmakers":	{"NNS"},
"drugs":	{"NNS","VBZ"},
"drugstore":	{"NN"},
"drugstores":	{"NNS"},
"drugtrafficking":	{"NN"},
"druid":	{"NN"},
"druidism":	{"NN"},
"drum":	{"NN","VB","VBP"},
"drum-kit":	{"NN"},
"drum-kits":	{"NNS"},
"drum-like":	{"JJ"},
"drum-shaped":	{"JJ"},
"drumbeat":	{"NN"},
"drumbeater":	{"NN"},
"drumbeating":	{"NN"},
"drumbeats":	{"NNS"},
"drumfire":	{"NN"},
"drumfish":	{"NN"},
"drumhead":	{"NN"},
"drumless":	{"JJ"},
"drumlin":	{"NN"},
"drummed":	{"VBD","VBN"},
"drummer":	{"NN"},
"drummers":	{"NNS"},
"drumming":	{"NN","VBG"},
"drumroll":	{"NN"},
"drums":	{"NNS","VBZ"},
"drumstick":	{"NN"},
"drumsticks":	{"NNS"},
"drunk":	{"JJ","NN","VBN"},
"drunk-and-disorderlies":	{"NNS"},
"drunk-and-disorderly":	{"NN"},
"drunk-driving":	{"NN"},
"drunkard":	{"NN"},
"drunkards":	{"NNS"},
"drunken":	{"JJ"},
"drunkenly":	{"RB"},
"drunkenness":	{"NN"},
"drunks":	{"NNS"},
"drupaceous":	{"JJ"},
"drupe":	{"NN"},
"drupelet":	{"NN"},
"drusen":	{"NN"},
"druther":	{"NN"},
"druthers":	{"NNS"},
"dry":	{"JJ","VB","VBP"},
"dry-clean":	{"VB","VBP"},
"dry-cleaned":	{"VBD","VBN"},
"dry-cleaning":	{"VBG"},
"dry-cleans":	{"VBZ"},
"dry-dock":	{"NN"},
"dry-eyed":	{"JJ"},
"dry-farm":	{"VB","VBP"},
"dry-farmed":	{"VBD","VBN"},
"dry-farming":	{"VBG"},
"dry-farms":	{"VBZ"},
"dry-gulchin":	{"NN"},
"dry-gulching":	{"NN"},
"dry-ice":	{"NN"},
"dry-nurse":	{"NN"},
"dry-rot":	{"NN"},
"dry-shod":	{"JJ","RB"},
"dry-wall":	{"NN","VB","VBP"},
"dry-walled":	{"VBD","VBN"},
"dry-walling":	{"VBG"},
"dry-walls":	{"VBZ"},
"dryad":	{"NN"},
"dryadella":	{"NN"},
"dryas":	{"NNS"},
"drydock":	{"NN"},
"dryer":	{"NN"},
"dryers":	{"NNS"},
"drygoods":	{"NNS"},
"drying":	{"VBG"},
"dryland":	{"JJ"},
"dryly":	{"RB"},
"drymarchon":	{"NN"},
"drymoglossum":	{"NN"},
"drynaria":	{"NN"},
"dryness":	{"NN"},
"dryopithecine":	{"NN"},
"dryopithecus":	{"NNS"},
"dryopteridaceae":	{"NN"},
"dryopteris":	{"NNS"},
"drypis":	{"NN"},
"drywall":	{"NN"},
"ds":	{"NN"},
"dscdna":	{"NN"},
"dsl":	{"NN"},
"dsw":	{"NN"},
"dtf":	{"NN"},
"dthat":	{"IN"},
"dtic":	{"NN"},
"dts":	{"NNS"},
"duad":	{"NN"},
"dual":	{"JJ"},
"dual-career":	{"JJ"},
"dual-channel":	{"JJ"},
"dual-ladder":	{"JJ"},
"dual-lane":	{"JJ"},
"dual-purpose":	{"JJ"},
"dual-road-up":	{"NN"},
"dual-trading":	{"NN"},
"dualism":	{"NN"},
"dualist":	{"NN"},
"dualistic":	{"JJ"},
"dualities":	{"NNS"},
"duality":	{"NN"},
"duang":	{"NN"},
"dub":	{"VB","VBP","NN"},
"dubbed":	{"VBN","VBD"},
"dubbin":	{"NN","VB","VBP"},
"dubbined":	{"VBD","VBN"},
"dubbing":	{"NN","VBG"},
"dubbining":	{"VBG"},
"dubbins":	{"VBZ"},
"dubiety":	{"NN"},
"dubious":	{"JJ"},
"dubiously":	{"RB"},
"dubiousness":	{"NN"},
"dubitable":	{"JJ"},
"dubliner":	{"NN"},
"dubnium":	{"NN"},
"dubonnet":	{"NN"},
"dubrovnik":	{"NN"},
"dubs":	{"VBZ"},
"dubuque":	{"NN"},
"dubyuh":	{"NN"},
"ducal":	{"JJ"},
"ducat":	{"NN"},
"ducats":	{"NNS"},
"duce":	{"NN"},
"duces":	{"NNS"},
"duchess":	{"NN"},
"duchesses":	{"NNS"},
"duchies":	{"NNS"},
"duchy":	{"NN"},
"duck":	{"NN","NNS","VB","VBP"},
"duck-billed":	{"JJ"},
"duckbill":	{"NN"},
"duckboard":	{"NN"},
"duckboards":	{"NNS"},
"ducked":	{"VBD","VBN"},
"ducking":	{"NN","VBG"},
"duckling":	{"NN"},
"ducklings":	{"NNS"},
"duckpin":	{"NN"},
"duckpins":	{"NNS"},
"ducks":	{"NNS","VBZ"},
"duckweed":	{"NN"},
"ducky":	{"NN","JJ"},
"duct":	{"NN","VB","VBP"},
"ducted":	{"VBD","VBN"},
"ductile":	{"JJ"},
"ductileness":	{"NN"},
"ductility":	{"NN"},
"ducting":	{"VBG"},
"ductless":	{"JJ"},
"ducts":	{"VBZ","NNS"},
"ductule":	{"NN"},
"ductulus":	{"NNS"},
"ductus":	{"NN"},
"ductwork":	{"NN"},
"dud":	{"NN","JJ"},
"dude":	{"NN","VB","VBP"},
"duded":	{"VBD","VBN"},
"dudeen":	{"NN"},
"dudes":	{"NNS","VBZ"},
"dudgeon":	{"NN"},
"duding":	{"VBG"},
"duds":	{"NNS"},
"due":	{"JJ","RB","NN"},
"due-diligence":	{"JJ"},
"due-process":	{"NN"},
"duel":	{"NN","VB","VBP"},
"dueled":	{"VBD","VBN"},
"dueler":	{"NN"},
"dueling":	{"VBG"},
"duelist":	{"NN"},
"duelled":	{"VBD","VBN"},
"dueller":	{"NN"},
"duelling":	{"VBG"},
"duellist":	{"NN"},
"duels":	{"NNS","VBZ"},
"duenna":	{"NN"},
"dues":	{"NNS"},
"duet":	{"NN","VB","VBP"},
"duets":	{"NNS","VBZ"},
"duetted":	{"VBD","VBN"},
"duetting":	{"VBG"},
"duf":	{"NN"},
"duff":	{"JJ","NN","VB","VBP"},
"duffed":	{"VBD","VBN"},
"duffel":	{"NN"},
"duffels":	{"NNS"},
"duffer":	{"NN"},
"duffers":	{"NNS"},
"duffing":	{"VBG"},
"duffle":	{"NN"},
"duffle-coat":	{"NN"},
"duffle-coats":	{"NNS"},
"duffs":	{"NNS","VBZ"},
"duffy":	{"NN"},
"dug":	{"NN","VBD","VBN"},
"dugong":	{"NN"},
"dugongidae":	{"NN"},
"dugout":	{"NN"},
"dugouts":	{"NNS"},
"dukas":	{"NNS"},
"duke":	{"NN","VB","VBP"},
"duke-epa":	{"JJ"},
"duked":	{"VBD","VBN"},
"dukedom":	{"NN"},
"dukedoms":	{"NNS"},
"dukes":	{"NNS","VBZ"},
"duking":	{"VBG"},
"dulcet":	{"JJ"},
"dulciana":	{"NN"},
"dulcification":	{"NN"},
"dulcified":	{"VBD","VBN"},
"dulcifies":	{"VBZ"},
"dulcify":	{"VB","VBP"},
"dulcifying":	{"VBG"},
"dulcimer":	{"NN"},
"dulcimers":	{"NNS"},
"dulcinea":	{"NN"},
"dulcorate":	{"VB","VBP"},
"dull":	{"JJ","VB","VBP"},
"dull-gray":	{"JJ"},
"dull-purple":	{"JJ"},
"dull-white":	{"JJ"},
"dullard":	{"NN"},
"dullards":	{"NNS"},
"dulled":	{"VBD","VBN"},
"duller":	{"JJR"},
"dullest":	{"JJS"},
"dulling":	{"VBG"},
"dullish":	{"JJ"},
"dullness":	{"NN"},
"dulls":	{"VBZ"},
"dully":	{"RB"},
"dulse":	{"NN"},
"duluth":	{"NN"},
"duly":	{"RB"},
"duma":	{"NN"},
"dumas":	{"NNS"},
"dumb":	{"JJ","VB","VBP"},
"dumbass":	{"NN"},
"dumbbell":	{"NN"},
"dumbbells":	{"NNS"},
"dumbed":	{"VBD","VBN"},
"dumber":	{"JJR"},
"dumbest":	{"JJS"},
"dumbfound":	{"VB","VBP"},
"dumbfounded":	{"JJ","VBD","VBN"},
"dumbfounding":	{"VBG"},
"dumbfounds":	{"VBZ"},
"dumbing":	{"VBG"},
"dumbly":	{"RB"},
"dumbness":	{"NN"},
"dumbphone":	{"NN"},
"dumbphones":	{"NNS"},
"dumbs":	{"VBZ"},
"dumbstricken":	{"JJ"},
"dumbstruck":	{"JJ"},
"dumbwaiter":	{"NN"},
"dumdum":	{"NN"},
"dumetella":	{"NN"},
"dummied":	{"VBD","VBN"},
"dummies":	{"NNS","VBZ"},
"dummy":	{"NN","JJ","VB","VBP"},
"dummying":	{"VBG"},
"dump":	{"VB","VBP","NN"},
"dumpcart":	{"NN"},
"dumped":	{"VBD","VBN"},
"dumper":	{"NN"},
"dumpiness":	{"NN"},
"dumping":	{"VBG","NN"},
"dumpling":	{"NN"},
"dumplings":	{"NNS"},
"dumps":	{"NNS","VBZ"},
"dumpsite":	{"NN"},
"dumpsters":	{"NNS"},
"dumpy":	{"JJ"},
"dumuzi":	{"NN"},
"dun":	{"VB","VBP","NN","JJ"},
"dun-colored":	{"JJ"},
"dun-coloured":	{"JJ"},
"dunbar":	{"NN"},
"dunce":	{"NN"},
"dunces":	{"NNS"},
"duncical":	{"JJ"},
"duncish":	{"JJ"},
"dunderhead":	{"NN"},
"dunderheads":	{"NNS"},
"dune":	{"NN"},
"dune-grass":	{"NN"},
"dunes":	{"NNS"},
"dung":	{"NN","VB","VBP"},
"dungaree":	{"NN"},
"dungarees":	{"NNS"},
"dunged":	{"VBD","VBN"},
"dungeon":	{"NN"},
"dungeons":	{"NNS"},
"dunghill":	{"NN"},
"dunging":	{"VBG"},
"dungs":	{"VBZ"},
"dungy":	{"JJ"},
"dunk":	{"VB","VBP","NN"},
"dunkard":	{"NN"},
"dunked":	{"VBD","VBN"},
"dunker":	{"NN"},
"dunkerque":	{"NN"},
"dunkers":	{"NNS"},
"dunking":	{"VBG"},
"dunks":	{"VBZ","NNS"},
"dunlin":	{"NN"},
"dunne":	{"NN"},
"dunned":	{"VBD","VBN"},
"dunning":	{"VBG"},
"dunnock":	{"NN"},
"duns":	{"VBZ"},
"duo":	{"NN"},
"duodecimal":	{"JJ"},
"duodenal":	{"JJ"},
"duodenum":	{"NN"},
"duodenums":	{"NNS"},
"duologue":	{"NN"},
"duomo":	{"NN"},
"duopolies":	{"NNS"},
"duopoly":	{"NN"},
"duos":	{"NNS"},
"dupe":	{"VB","VBP","NN"},
"duped":	{"VBD","VBN"},
"dupery":	{"NN"},
"dupes":	{"VBZ","NNS"},
"duping":	{"VBG"},
"duple":	{"JJ"},
"duplex":	{"NN","JJ"},
"duplexes":	{"NNS"},
"duplicability":	{"NN"},
"duplicable":	{"JJ"},
"duplicatable":	{"JJ"},
"duplicate":	{"VB","NN","JJ","VBP"},
"duplicated":	{"VBD","VBN"},
"duplicates":	{"VBZ","NNS"},
"duplicating":	{"VBG"},
"duplication":	{"NN"},
"duplications":	{"NNS"},
"duplicative":	{"JJ"},
"duplicator":	{"NN"},
"duplicidentata":	{"NN"},
"duplicitous":	{"JJ"},
"dupont":	{"NN"},
"dura":	{"NN"},
"durability":	{"NN"},
"durable":	{"JJ"},
"durable-goods":	{"NNS"},
"durables":	{"NNS"},
"durabolin":	{"NN"},
"dural":	{"JJ"},
"duralumin":	{"NN"},
"duramen":	{"NN"},
"durance":	{"NN"},
"durango":	{"NN"},
"durant":	{"NN"},
"duration":	{"NN"},
"durations":	{"NNS"},
"durative":	{"NN"},
"durazzo":	{"NN"},
"durban":	{"NN"},
"durbar":	{"NN"},
"durer":	{"NN"},
"duress":	{"NN"},
"durga":	{"NN"},
"durian":	{"NN"},
"durin":	{"NN"},
"during":	{"IN"},
"durio":	{"NN"},
"durion":	{"NN"},
"durkheim":	{"NN"},
"durmast":	{"NN"},
"durn":	{"NN"},
"durra":	{"NN"},
"durrell":	{"NN"},
"durres":	{"NNS"},
"durum":	{"NN"},
"dusanbe":	{"NN"},
"duse":	{"NN"},
"dusicyon":	{"NN"},
"dusk":	{"NN","VB","VBP"},
"dusked":	{"VBD","VBN"},
"duskier":	{"JJR"},
"duskiest":	{"JJS"},
"duskiness":	{"NN"},
"dusking":	{"VBG"},
"dusks":	{"VBZ"},
"dusky":	{"JJ"},
"dusky-colored":	{"JJ"},
"dusky-coloured":	{"JJ"},
"dusseldorf":	{"NN"},
"dust":	{"NN","VB","VBP"},
"dust-cover":	{"NN"},
"dust-covered":	{"JJ"},
"dust-covers":	{"NNS"},
"dust-jacket":	{"NN"},
"dust-jackets":	{"NNS"},
"dust-settling":	{"JJ"},
"dust-sheet":	{"NN"},
"dust-sheets":	{"NNS"},
"dust-swirling":	{"JJ"},
"dust-thick":	{"JJ"},
"dust-up":	{"NN"},
"dust-ups":	{"NNS"},
"dustbin":	{"NN"},
"dustbins":	{"NNS"},
"dustbowl":	{"NN"},
"dustcart":	{"NN"},
"dustcarts":	{"NNS"},
"dustcloth":	{"NN"},
"dusted":	{"VBD","VBN"},
"duster":	{"NN"},
"dusters":	{"NNS"},
"dustiness":	{"NN"},
"dusting":	{"VBG"},
"dustjacket":	{"NN"},
"dustlike":	{"JJ"},
"dustman":	{"NN"},
"dustmen":	{"NNS"},
"dustmop":	{"NN"},
"dustpan":	{"NN"},
"dustpanful":	{"NN"},
"dustpans":	{"NNS"},
"dustrag":	{"NN"},
"dusts":	{"VBZ","NNS"},
"dustup":	{"NN"},
"dusty":	{"JJ"},
"dusty-green":	{"JJ"},
"dusty-slippered":	{"JJ"},
"dutch-based":	{"JJ"},
"dutch-descended":	{"JJ"},
"dutch-elm-disease":	{"NN"},
"dutchman's-pipe":	{"NN"},
"duteous":	{"JJ"},
"dutiable":	{"JJ"},
"duties":	{"NNS"},
"dutiful":	{"JJ"},
"dutifully":	{"RB"},
"dutifulness":	{"NN"},
"dutton":	{"NN"},
"duty":	{"NN"},
"duty-bound":	{"JJ"},
"duty-free":	{"JJ","RB","NN"},
"duty-frees":	{"NNS"},
"duvet":	{"NN"},
"duvets":	{"NNS"},
"dwarf":	{"NN","VB","VBP","JJ"},
"dwarfed":	{"VBD","VBN"},
"dwarfing":	{"VBG"},
"dwarfish":	{"JJ"},
"dwarfishness":	{"NN"},
"dwarfism":	{"NN"},
"dwarfs":	{"VBZ","NNS"},
"dweeb":	{"NN"},
"dweebs":	{"NNS"},
"dwell":	{"VB","VBP"},
"dwelled":	{"VBD","VBN"},
"dweller":	{"NN"},
"dwellers":	{"NNS"},
"dwelling":	{"NN","VBG"},
"dwelling-house":	{"NN"},
"dwelling-houses":	{"NNS"},
"dwellings":	{"NNS"},
"dwells":	{"VBZ"},
"dwelt":	{"VBD","VBN"},
"dwight":	{"NN"},
"dwindle":	{"VB","VBP"},
"dwindled":	{"VBD","VBN"},
"dwindles":	{"VBZ"},
"dwindling":	{"VBG","JJ"},
"dwindling-sales":	{"JJ"},
"dwyer":	{"NN"},
"dx":	{"NN"},
"dy":	{"NN"},
"dyad":	{"NN"},
"dyadic":	{"JJ"},
"dyarchy":	{"NN"},
"dyaus":	{"NNS"},
"dyaus-pitar":	{"NN"},
"dybbuk":	{"NN"},
"dye":	{"NN","VB","VBP"},
"dye-works":	{"NNS"},
"dyed":	{"VBD","VBN","JJ"},
"dyed-in-the-wool":	{"JJ"},
"dyeing":	{"NN","VBG"},
"dyer":	{"NN"},
"dyer's-broom":	{"NN"},
"dyes":	{"NNS","VBZ"},
"dyestuff":	{"NN"},
"dyeweed":	{"NN"},
"dyewood":	{"NN"},
"dying":	{"VBG","NNS","JJ"},
"dyirbal":	{"NN"},
"dyke":	{"NN","VB","VBP"},
"dyked":	{"VBD","VBN"},
"dykes":	{"NNS","VBZ"},
"dyking":	{"VBG"},
"dylan-influenced":	{"JJ"},
"dynamic":	{"JJ","NN"},
"dynamical":	{"JJ"},
"dynamically":	{"RB"},
"dynamics":	{"NN","NNS"},
"dynamise":	{"VB","VBP"},
"dynamised":	{"VBD","VBN"},
"dynamises":	{"VBZ"},
"dynamising":	{"VBG"},
"dynamism":	{"NN"},
"dynamite":	{"NN","VB","VBP"},
"dynamited":	{"VBD","VBN"},
"dynamiter":	{"NN"},
"dynamites":	{"VBZ"},
"dynamiting":	{"VBG"},
"dynamitist":	{"NN"},
"dynamize":	{"VB","VBP"},
"dynamized":	{"VBD","VBN"},
"dynamizes":	{"VBZ"},
"dynamizing":	{"VBG"},
"dynamo":	{"NN"},
"dynamometer":	{"NN"},
"dynamos":	{"NNS"},
"dynapen":	{"NN"},
"dynast":	{"NN"},
"dynastic":	{"JJ"},
"dynasties":	{"NNS"},
"dynasty":	{"NN"},
"dyne":	{"NN"},
"dynodes":	{"NNS"},
"dysaphia":	{"NN"},
"dysarthria":	{"NN"},
"dyscalculia":	{"NN"},
"dyschezia":	{"NN"},
"dyscrasia":	{"NN"},
"dysdercus":	{"NNS"},
"dysentery":	{"NN"},
"dysfunction":	{"NN"},
"dysfunctional":	{"JJ"},
"dysfunctions":	{"NNS"},
"dysgenesis":	{"NN"},
"dysgenic":	{"JJ"},
"dysgenics":	{"NN"},
"dysgraphia":	{"NN"},
"dyskinesia":	{"NN"},
"dyslectic":	{"JJ","NN"},
"dyslexia":	{"NN"},
"dyslexic":	{"JJ","NN"},
"dyslipidemia":	{"NN"},
"dyslogia":	{"NN"},
"dyslogistic":	{"JJ"},
"dysmenorrhea":	{"NN"},
"dysomia":	{"NN"},
"dyson":	{"NN"},
"dysosmia":	{"NN"},
"dyspepsia":	{"NN"},
"dyspeptic":	{"JJ","NN"},
"dysphagia":	{"NN"},
"dysphasia":	{"NN"},
"dysphemism":	{"NN"},
"dysphemistic":	{"JJ"},
"dysphonia":	{"NN"},
"dysphoria":	{"NN"},
"dysphoric":	{"JJ"},
"dysplasia":	{"NN"},
"dysplastic":	{"JJ"},
"dyspnea":	{"NN"},
"dyspneal":	{"JJ"},
"dyspneic":	{"JJ"},
"dyspnoea":	{"NN"},
"dyspnoeal":	{"JJ"},
"dyspnoeic":	{"JJ"},
"dysprosium":	{"NN"},
"dyssynergia":	{"NN"},
"dysthymia":	{"NN"},
"dystopia":	{"NN"},
"dystopian":	{"JJ"},
"dystopias":	{"NNS"},
"dystopic":	{"JJ"},
"dystopically":	{"RB"},
"dystrophy":	{"NN"},
"dysuria":	{"NN"},
"dytiscidae":	{"NN"},
"dyushambe":	{"NN"},
"dziggetai":	{"NN"},
"e-Estimated":	{"VBN"},
"e-In":	{"IN"},
"e-bomb":	{"NN"},
"e-book":	{"NN"},
"e-books":	{"NNS"},
"e-commence":	{"NN"},
"e-commerce":	{"JJ","NN"},
"e-estimated":	{"VBN"},
"e-mail":	{"NN","VB","VBP"},
"e-mailed":	{"JJ","VBD","VBN"},
"e-mails":	{"NNS","VBZ"},
"e-mycin":	{"NN"},
"e-reader":	{"NN"},
"e-readers":	{"NNS"},
"e-sports":	{"NN"},
"e-z":	{"JJ"},
"e.g":	{"NN","FW"},
"e.g.":	{"RB"},
"e.s.p.":	{"NN"},
"eSports":	{"NN"},
"ea":	{"NN"},
"each":	{"DT","RB"},
"eadwig":	{"NN"},
"eager":	{"JJ"},
"eagerly":	{"RB"},
"eagerness":	{"NN"},
"eagle":	{"NN","VB","VBP"},
"eagle-eyed":	{"JJ"},
"eagled":	{"VBD","VBN"},
"eagles":	{"NNS","VBZ"},
"eaglet":	{"NN"},
"eaglets":	{"NNS"},
"eagling":	{"VBG"},
"eagre":	{"NN"},
"ear":	{"NN","VB","VBP"},
"ear-like":	{"JJ"},
"ear-piercing":	{"JJ"},
"ear-shaped":	{"JJ"},
"ear-shell":	{"NN"},
"ear-splitting":	{"JJ"},
"earache":	{"NN"},
"earbud":	{"NN"},
"earbuds":	{"NNS"},
"eardrop":	{"NN"},
"eardrum":	{"NN"},
"eardrums":	{"NNS"},
"eared":	{"JJ","VBD","VBN"},
"earflap":	{"NN"},
"earful":	{"NN"},
"earing":	{"VBG"},
"earl":	{"NN"},
"earlap":	{"NN"},
"earldom":	{"NN"},
"earldoms":	{"NNS"},
"earle":	{"NN"},
"earless":	{"JJ"},
"earlier":	{"RBR","JJR"},
"earlier-announced":	{"JJ"},
"earlier-expressed":	{"JJ"},
"earlier-period":	{"NN"},
"earlier-reported":	{"JJ"},
"earlier-than-expected":	{"JJ"},
"earlier-the":	{"IN"},
"earliest":	{"JJS","RBS","NN"},
"earliness":	{"NN"},
"earlobe":	{"NN"},
"earlobes":	{"NNS"},
"earls":	{"NNS"},
"early":	{"JJ","RB"},
"early-blooming":	{"JJ"},
"early-childhood":	{"NN"},
"early-departure":	{"NN"},
"early-flowering":	{"JJ"},
"early-morning":	{"JJ","NN"},
"early-retirement":	{"NN","JJ"},
"early-season":	{"JJ"},
"early-warning":	{"JJ"},
"earlyish":	{"JJ"},
"earmark":	{"VB","VBP"},
"earmarked":	{"VBD","VBN"},
"earmarking":	{"VBG"},
"earmarks":	{"VBZ"},
"earmuff":	{"NN"},
"earn":	{"VB","VBP"},
"earned":	{"VBD","VBN"},
"earned-income":	{"NN"},
"earned-run":	{"JJ"},
"earner":	{"NN"},
"earners":	{"NNS"},
"earnest":	{"NN","JJ"},
"earnestly":	{"RB"},
"earnestness":	{"NN"},
"earning":	{"VBG","NN"},
"earnings":	{"NNS"},
"earnings-driven":	{"JJ"},
"earnings-forecast":	{"JJ"},
"earnings-growth":	{"NN","JJ"},
"earnings-limit":	{"JJ"},
"earnings-per-share":	{"JJ"},
"earnings-related":	{"JJ"},
"earns":	{"VBZ"},
"earphone":	{"NN"},
"earphones":	{"NNS"},
"earpiece":	{"NN"},
"earpieces":	{"NNS"},
"earplug":	{"NN"},
"earplugs":	{"NNS"},
"earreach":	{"NN"},
"earring":	{"NN"},
"earrings":	{"NNS"},
"ears":	{"NNS","VBZ"},
"earshot":	{"NN"},
"earsplitting":	{"JJ"},
"earth":	{"NN","VB","VBP"},
"earth-ball":	{"NN"},
"earth-bound":	{"JJ"},
"earth-closet":	{"NN"},
"earth-colored":	{"JJ"},
"earth-god":	{"NN"},
"earth-goddess":	{"NN"},
"earth-moving":	{"JJ"},
"earth-orbiting":	{"JJ"},
"earth-quake":	{"NN"},
"earth-shattering":	{"JJ"},
"earth-tone":	{"NN"},
"earth-toned":	{"JJ"},
"earth-tongue":	{"NN"},
"earth-touching":	{"JJ"},
"earth-week":	{"NN"},
"earth-weeks":	{"NNS"},
"earthball":	{"NN"},
"earthborn":	{"JJ"},
"earthbound":	{"JJ"},
"earthed":	{"VBD","VBN"},
"earthen":	{"JJ"},
"earthenware":	{"JJ","NN"},
"earthier":	{"JJR"},
"earthiest":	{"JJS"},
"earthiness":	{"NN"},
"earthing":	{"VBG"},
"earthlike":	{"JJ"},
"earthling":	{"NN"},
"earthlings":	{"NNS"},
"earthly":	{"JJ"},
"earthman":	{"NN"},
"earthmoving":	{"JJ","NN"},
"earthnut":	{"NN"},
"earthquake":	{"NN"},
"earthquake-proof":	{"JJ"},
"earthquake-ravaged":	{"JJ"},
"earthquake-related":	{"JJ"},
"earthquake-resistant":	{"JJ"},
"earthquake-stricken":	{"JJ"},
"earthquake-trained":	{"JJ"},
"earthquake-triggered":	{"JJ"},
"earthquakes":	{"NNS"},
"earths":	{"VBZ"},
"earthshaking":	{"JJ"},
"earthstar":	{"NN"},
"earthtongue":	{"NN"},
"earthwork":	{"NN"},
"earthworks":	{"NNS"},
"earthworm":	{"NN"},
"earthworms":	{"NNS"},
"earthy":	{"JJ"},
"earwax":	{"NN"},
"earwig":	{"NN","VB","VBP"},
"earwigged":	{"VBD","VBN"},
"earwigging":	{"VBG"},
"earwigs":	{"NNS","VBZ"},
"earworm":	{"NN"},
"eas":	{"NN"},
"ease":	{"VB","NN","VBP"},
"eased":	{"VBD","VBN"},
"easel":	{"NN"},
"easels":	{"NNS"},
"easement":	{"NN"},
"easements":	{"NNS"},
"eases":	{"VBZ"},
"easier":	{"JJR","RBR"},
"easier-to-read":	{"JJ"},
"easiest":	{"JJS","RBS"},
"easily":	{"RB"},
"easiness":	{"NN"},
"easing":	{"VBG","NN"},
"east":	{"JJ","RB","NN"},
"east-central":	{"JJ"},
"east-northeast":	{"NN","JJ","RB"},
"east-sider":	{"NN"},
"east-southeast":	{"NN","JJ","RB"},
"east-to-west":	{"RB"},
"east-west":	{"JJ"},
"eastbound":	{"JJ"},
"easterlies":	{"NNS"},
"easterly":	{"JJ","RB","NN"},
"eastern":	{"JJ"},
"easterner":	{"NN"},
"easterners":	{"NNS"},
"easternmost":	{"JJ"},
"eastertide":	{"NN"},
"eastmost":	{"JJ"},
"eastside":	{"NN"},
"eastward":	{"RB","JJ"},
"eastwards":	{"RB"},
"easy":	{"JJ","RB"},
"easy-going":	{"JJ"},
"easy-to-film":	{"JJ"},
"easy-to-operate":	{"JJ"},
"easy-to-reach":	{"JJ"},
"easy-to-read":	{"JJ"},
"easy-to-spot":	{"JJ"},
"easy-to-turn":	{"JJ"},
"easy-to-use":	{"JJ"},
"easygoing":	{"JJ"},
"easygoingness":	{"NN"},
"eat":	{"VB","VBP"},
"eatable":	{"JJ"},
"eatage":	{"NN"},
"eaten":	{"VBN"},
"eater":	{"NN"},
"eateries":	{"NNS"},
"eaters":	{"NNS"},
"eatery":	{"NN"},
"eating":	{"VBG","NN"},
"eating-house":	{"NN"},
"eating-houses":	{"NNS"},
"eating-place":	{"NN"},
"eating-places":	{"NNS"},
"eatings":	{"NNS"},
"eats":	{"VBZ","NNS"},
"eave":	{"NN"},
"eaves":	{"NNS"},
"eavesdrop":	{"VB","VBP"},
"eavesdropped":	{"VBD","VBN"},
"eavesdropper":	{"NN"},
"eavesdroppers":	{"NNS"},
"eavesdropping":	{"VBG","NN"},
"eavesdrops":	{"VBZ"},
"eb":	{"NN"},
"ebb":	{"NN","VB","VBP"},
"ebb-and-flow":	{"NN"},
"ebbed":	{"VBD","VBN"},
"ebbing":	{"VBG"},
"ebbs":	{"VBZ","NNS"},
"ebbtide":	{"NN"},
"ebenaceae":	{"NN"},
"ebenales":	{"NNS"},
"ebionite":	{"JJ","NN"},
"ebit":	{"NN"},
"ebitda":	{"NN"},
"eblis":	{"NNS"},
"ebn":	{"NN"},
"ebon":	{"NN","JJ"},
"ebonics":	{"NN"},
"ebonise":	{"VB","VBP"},
"ebonised":	{"VBD","VBN"},
"ebonises":	{"VBZ"},
"ebonising":	{"VBG"},
"ebonite":	{"NN"},
"ebonize":	{"VB","VBP"},
"ebonized":	{"VBD","VBN"},
"ebonizes":	{"VBZ"},
"ebonizing":	{"VBG"},
"ebony":	{"NN","JJ"},
"ebracteate":	{"JJ"},
"ebrahim":	{"NN"},
"ebro":	{"NN"},
"ebs":	{"NNS"},
"ebullience":	{"NN"},
"ebullient":	{"JJ"},
"ebulliently":	{"RB"},
"ebullition":	{"NN"},
"eburnation":	{"NN"},
"eburophyton":	{"NN"},
"ebv":	{"NN"},
"ec":	{"NN"},
"ec-made":	{"JJ"},
"ec-wide":	{"JJ"},
"ecarte":	{"NN"},
"ecballium":	{"NN"},
"ecc":	{"NN"},
"eccentric":	{"JJ","NN"},
"eccentrically":	{"RB"},
"eccentricities":	{"NNS"},
"eccentricity":	{"NN"},
"eccentrics":	{"NNS"},
"ecchymosis":	{"NN"},
"eccles":	{"NNS"},
"ecclesiastic":	{"NN","JJ"},
"ecclesiastical":	{"JJ"},
"ecclesiastically":	{"RB"},
"ecclesiasticism":	{"NN"},
"ecclesiasticus":	{"NNS"},
"ecclesiology":	{"NN"},
"eccm":	{"NN"},
"eccrine":	{"JJ"},
"eccyesis":	{"NN"},
"ecdemic":	{"JJ"},
"ecdysiast":	{"NN"},
"ecdysis":	{"NN"},
"ecesis":	{"NN"},
"ecf":	{"NN"},
"echelon":	{"NN"},
"echelons":	{"NNS"},
"echeneididae":	{"NN"},
"echeneis":	{"NNS"},
"echidna":	{"NN"},
"echidnophaga":	{"NN"},
"echinacea":	{"NN"},
"echinocactus":	{"NNS"},
"echinocereus":	{"NNS"},
"echinochloa":	{"NN"},
"echinococcosis":	{"NN"},
"echinococcus":	{"NN"},
"echinoderm":	{"NN"},
"echinodermata":	{"NN"},
"echinoidea":	{"NN"},
"echinops":	{"NNS"},
"echinus":	{"NN"},
"echium":	{"NN"},
"echo":	{"VB","VBP","NN"},
"echocardiogram":	{"NN"},
"echocardiograph":	{"NN"},
"echocardiography":	{"NN"},
"echoed":	{"VBD","VBN"},
"echoencephalogram":	{"NN"},
"echoencephalograph":	{"NN"},
"echoencephalography":	{"NN"},
"echoes":	{"VBZ","NNS"},
"echogram":	{"NN"},
"echography":	{"NN"},
"echoic":	{"JJ"},
"echoing":	{"VBG"},
"echolalia":	{"NN"},
"echoless":	{"JJ"},
"echolike":	{"JJ"},
"echolocation":	{"NN"},
"echovirus":	{"NN"},
"echt":	{"NN","JJ"},
"eck":	{"NN"},
"eckhart":	{"NN"},
"eclair":	{"NN"},
"eclairs":	{"NNS"},
"eclampsia":	{"NN"},
"eclat":	{"NN"},
"eclectic":	{"JJ","NN"},
"eclectically":	{"RB"},
"eclecticism":	{"NN"},
"eclecticist":	{"NN"},
"eclipse":	{"NN","VB","VBP"},
"eclipsed":	{"VBD","VBN"},
"eclipses":	{"VBZ","NNS"},
"eclipsing":	{"VBG"},
"eclipsis":	{"NN"},
"ecliptic":	{"NN","JJ"},
"eclogue":	{"NN"},
"ecm":	{"NN"},
"eco-evangelists":	{"NNS"},
"eco-warfare":	{"NN"},
"ecobabble":	{"NN"},
"ecocertification":	{"NN"},
"ecologic":	{"JJ","NN"},
"ecological":	{"JJ"},
"ecologically":	{"RB"},
"ecologies":	{"NNS"},
"ecologist":	{"NN"},
"ecologists":	{"NNS"},
"ecology":	{"NN"},
"econobox":	{"NN"},
"econometric":	{"JJ"},
"econometrician":	{"NN"},
"econometricians":	{"NNS"},
"econometrics":	{"NN"},
"econometrist":	{"NN"},
"economia":	{"NN"},
"economic":	{"JJ"},
"economic-cooperation":	{"NN"},
"economic-crime":	{"JJ"},
"economic-development":	{"NN"},
"economic-efficiency":	{"NN"},
"economic-forecasting":	{"JJ"},
"economic-policy":	{"NN"},
"economic-reform":	{"JJ","NN"},
"economic-restructuring":	{"JJ"},
"economical":	{"JJ"},
"economically":	{"RB"},
"economics":	{"NN","NNS"},
"economies":	{"NNS"},
"economise":	{"VB","VBP"},
"economised":	{"VBD","VBN"},
"economiser":	{"NN"},
"economises":	{"VBZ"},
"economising":	{"VBG"},
"economist":	{"NN"},
"economists":	{"NNS"},
"economize":	{"VB","VBP"},
"economized":	{"VBD","VBN"},
"economizer":	{"NN"},
"economizers":	{"NNS"},
"economizes":	{"VBZ"},
"economizing":	{"VBG"},
"economy":	{"NN","JJ"},
"economy-lodging":	{"JJ"},
"ecosoc":	{"NN"},
"ecosystem":	{"NN"},
"ecosystems":	{"NNS"},
"ecoterrorism":	{"NN"},
"ecoterrorist":	{"NN"},
"ecoterrorists":	{"NNS"},
"ecotourism":	{"NN"},
"ecotourist":	{"NN"},
"ecotourists":	{"NNS"},
"ecphonesis":	{"NN"},
"ecrevisse":	{"NN"},
"ecru":	{"NN","JJ"},
"ecstasies":	{"NNS"},
"ecstasy":	{"NN"},
"ecstatic":	{"JJ"},
"ecstatically":	{"RB"},
"ect":	{"NN"},
"ectasia":	{"NN"},
"ectasis":	{"NN"},
"ectoblast":	{"NN"},
"ectoderm":	{"NN"},
"ectodermal":	{"JJ"},
"ectodermic":	{"JJ"},
"ectomorph":	{"NN"},
"ectomorphic":	{"JJ"},
"ectomorphy":	{"NN"},
"ectoparasite":	{"NN"},
"ectopia":	{"NN"},
"ectopic":	{"JJ"},
"ectopistes":	{"NNS"},
"ectoplasm":	{"NN"},
"ectoplasmic":	{"JJ"},
"ectoproct":	{"NN"},
"ectoprocta":	{"NN"},
"ectotherm":	{"NN"},
"ectothermic":	{"JJ"},
"ectozoan":	{"JJ","NN"},
"ectozoon":	{"NN"},
"ectrodactyly":	{"NN"},
"ecu-based":	{"JJ"},
"ecu-denominated":	{"JJ"},
"ecuadoran":	{"NN"},
"ecumenic":	{"JJ"},
"ecumenical":	{"JJ"},
"ecumenicalism":	{"NN"},
"ecumenically":	{"RB"},
"ecumenicism":	{"NN"},
"ecumenicists":	{"NNS"},
"ecumenism":	{"NN"},
"ecumenist":	{"NN"},
"ecumenists":	{"NNS"},
"ecus":	{"NNS"},
"eczema":	{"NN"},
"ed":	{"NN"},
"ed.":	{"NN"},
"edacious":	{"JJ"},
"edacity":	{"NN"},
"edaphosauridae":	{"NN"},
"edaphosaurus":	{"NN"},
"edbiz":	{"NN"},
"edd":	{"NN"},
"edda":	{"NN"},
"eddied":	{"VBD","VBN"},
"eddies":	{"NNS","VBZ"},
"eddington":	{"NN"},
"eddo":	{"NN"},
"eddy":	{"NN","VB","VBP"},
"eddying":	{"VBG"},
"edecrin":	{"NN"},
"edelweiss":	{"NN","NNS"},
"edema":	{"NN"},
"edematous":	{"JJ"},
"edental":	{"JJ"},
"edentata":	{"NN"},
"edentate":	{"JJ","NN"},
"edentulate":	{"JJ"},
"edentulous":	{"JJ"},
"ederle":	{"NN"},
"edgardo":	{"NN"},
"edge":	{"NN","VB","VBP"},
"edged":	{"JJ","VBD","VBN"},
"edgeless":	{"JJ"},
"edger":	{"NN"},
"edges":	{"NNS","VBZ"},
"edgeways":	{"RB"},
"edgewise":	{"RB"},
"edgier":	{"JJR"},
"edgiest":	{"JJS"},
"edgily":	{"RB"},
"edginess":	{"NN"},
"edging":	{"NN","VBG"},
"edging-shears":	{"NNS"},
"edgings":	{"NNS"},
"edgy":	{"JJ"},
"edibility":	{"NN"},
"edible":	{"JJ"},
"edibleness":	{"NN"},
"edict":	{"NN"},
"edicts":	{"NNS"},
"edification":	{"NN"},
"edifice":	{"NN"},
"edifices":	{"NNS"},
"edified":	{"VBD","VBN"},
"edifies":	{"VBZ"},
"edify":	{"VB","VBP"},
"edifying":	{"JJ","VBG"},
"edirne":	{"NN"},
"edit":	{"VB","VBP","NN"},
"edited":	{"VBN","VBD"},
"editing":	{"NN","VBG"},
"edition":	{"NN"},
"editions":	{"NNS"},
"editor":	{"NN"},
"editor-in-chief":	{"NN"},
"editorial":	{"NN","JJ"},
"editorial-page":	{"NN","JJ"},
"editorialise":	{"VB","VBP"},
"editorialised":	{"VBD","VBN"},
"editorialises":	{"VBZ"},
"editorialising":	{"VBG"},
"editorialist":	{"NN"},
"editorialists":	{"NNS"},
"editorialize":	{"VB","VBP"},
"editorialized":	{"VBD","VBN"},
"editorializes":	{"VBZ"},
"editorializing":	{"VBG"},
"editorially":	{"RB"},
"editorials":	{"NNS"},
"editors":	{"NNS"},
"editorship":	{"NN"},
"editorships":	{"NNS"},
"edits":	{"VBZ","NNS"},
"edmonia":	{"NN"},
"edmontonia":	{"NN"},
"edmontosaurus":	{"NN"},
"edmov":	{"NN"},
"edmund":	{"NN"},
"ednedayose":	{"NN"},
"edo":	{"NN"},
"edp":	{"NN"},
"edronax":	{"NN"},
"eds":	{"NN"},
"edta":	{"NN"},
"educare":	{"FW"},
"educate":	{"VB","VBP"},
"educated":	{"JJ","VBD","VBN"},
"educatee":	{"NN"},
"educates":	{"VBZ"},
"educating":	{"VBG"},
"education":	{"NN"},
"educational":	{"JJ"},
"educationalist":	{"NN"},
"educationalists":	{"NNS"},
"educationally":	{"RB"},
"educationist":	{"NN"},
"educations":	{"NNS"},
"educative":	{"JJ"},
"educator":	{"NN"},
"educators":	{"NNS"},
"educe":	{"VB","VBP"},
"educed":	{"VBD","VBN"},
"educes":	{"VBZ"},
"educing":	{"VBG"},
"educrats":	{"NNS"},
"eduction":	{"NN"},
"edulcorate":	{"VB"},
"edutainment":	{"NN"},
"edwin":	{"NN"},
"edwy":	{"NN"},
"ee":	{"NN"},
"ee-faket":	{"NN"},
"eeae-cellulose":	{"NN"},
"eec":	{"NN"},
"eeg":	{"NN"},
"eel":	{"NN"},
"eel-shaped":	{"JJ"},
"eelam":	{"NN"},
"eelblenny":	{"NN"},
"eelgrass":	{"NN"},
"eellike":	{"JJ"},
"eelpout":	{"NN"},
"eelworm":	{"NN"},
"eep":	{"UH","NN","VB","VBP"},
"eeped":	{"VBD","VBN"},
"eeping":	{"VBG"},
"eeps":	{"NNS","VBZ"},
"eerie":	{"JJ"},
"eerily":	{"RB"},
"eeriness":	{"NN"},
"eery":	{"JJ"},
"eff":	{"VB","VBP"},
"efface":	{"VB","VBP"},
"effaceable":	{"JJ"},
"effaced":	{"VBD","VBN"},
"effacement":	{"NN"},
"effaces":	{"VBZ"},
"effacing":	{"VBG"},
"effect":	{"NN","VB","VBP"},
"effected":	{"VBD","VBN"},
"effecter":	{"NN"},
"effecting":	{"VBG"},
"effective":	{"JJ"},
"effectively":	{"RB"},
"effectiveness":	{"NN"},
"effectivity":	{"NN"},
"effector":	{"NN"},
"effects":	{"NNS","VBZ"},
"effectual":	{"JJ"},
"effectuality":	{"NN"},
"effectually":	{"RB"},
"effectualness":	{"NN"},
"effectuate":	{"VB","VBP"},
"effectuated":	{"VBD","VBN"},
"effectuates":	{"VBZ"},
"effectuating":	{"VBG"},
"effectuation":	{"NN"},
"effed":	{"VBD","VBN"},
"effeminacy":	{"NN"},
"effeminate":	{"JJ"},
"effeminately":	{"RB"},
"effeminateness":	{"NN"},
"effeminise":	{"VB","VBP"},
"effeminised":	{"VBD","VBN"},
"effeminises":	{"VBZ"},
"effeminising":	{"VBG"},
"effeminize":	{"VB","VBP"},
"effeminized":	{"VBD","VBN"},
"effeminizes":	{"VBZ"},
"effeminizing":	{"VBG"},
"effendi":	{"NN"},
"efferent":	{"JJ"},
"effervesce":	{"VB","VBP"},
"effervesced":	{"VBD","VBN"},
"effervescence":	{"NN"},
"effervescent":	{"JJ"},
"effervesces":	{"VBZ"},
"effervescing":	{"VBG"},
"effete":	{"JJ"},
"effeteness":	{"NN"},
"efficacious":	{"JJ"},
"efficaciously":	{"RB"},
"efficaciousness":	{"NN"},
"efficacy":	{"NN"},
"efficiencies":	{"NNS"},
"efficiency":	{"NN"},
"efficient":	{"JJ"},
"efficient-in":	{"JJ","IN"},
"efficient-market":	{"NN"},
"efficiently":	{"RB"},
"effigies":	{"NNS"},
"effigy":	{"NN"},
"effing":	{"VBG","JJ"},
"effleurage":	{"NN","VB","VBP"},
"effleuraged":	{"VBD","VBN"},
"effleurages":	{"VBZ"},
"effleuraging":	{"VBG"},
"effloresce":	{"VB","VBP"},
"effloresced":	{"VBD","VBN"},
"efflorescence":	{"NN"},
"efflorescent":	{"JJ"},
"effloresces":	{"VBZ"},
"efflorescing":	{"VBG"},
"effluence":	{"NN"},
"effluent":	{"NN","JJ"},
"effluents":	{"NNS"},
"effluvium":	{"NN"},
"efflux":	{"NN"},
"effort":	{"NN"},
"effortful":	{"JJ"},
"effortfulness":	{"NN"},
"effortless":	{"JJ"},
"effortlessly":	{"RB"},
"effortlessness":	{"NN"},
"efforts":	{"NNS"},
"effrontery":	{"NN"},
"effs":	{"VBZ"},
"effulgence":	{"NN"},
"effulgent":	{"JJ"},
"effuse":	{"VB","VBP"},
"effused":	{"VBD","VBN"},
"effuses":	{"VBZ"},
"effusing":	{"VBG"},
"effusion":	{"NN"},
"effusions":	{"NNS"},
"effusive":	{"JJ"},
"effusively":	{"RB"},
"effusiveness":	{"NN"},
"efps":	{"NNS"},
"eft":	{"NN"},
"ega-vga":	{"JJ"},
"egalitarian":	{"NN","JJ"},
"egalitarianism":	{"NN"},
"egalite":	{"NN"},
"egality":	{"NN"},
"egbert":	{"NN"},
"egeria":	{"NN"},
"egest":	{"VB","VBP"},
"egested":	{"VBD","VBN"},
"egesting":	{"VBG"},
"egests":	{"VBZ"},
"egg":	{"NN","VBP","VB"},
"egg-and-anchor":	{"NN"},
"egg-and-dart":	{"NN"},
"egg-and-tongue":	{"NN"},
"egg-beater":	{"NN"},
"egg-breaking":	{"NN"},
"egg-cup":	{"NN"},
"egg-cups":	{"NNS"},
"egg-filled":	{"JJ"},
"egg-hatching":	{"JJ"},
"egg-industry":	{"NN"},
"egg-on-the-face":	{"JJ"},
"egg-plant":	{"NN"},
"egg-plants":	{"NNS"},
"egg-processing":	{"JJ"},
"egg-producing":	{"JJ"},
"egg-shaped":	{"JJ"},
"egg-sized":	{"JJ"},
"egg-throwing":	{"JJ"},
"egg-timer":	{"NN"},
"egg-timers":	{"NNS"},
"egg-whisk":	{"NN"},
"egg-whisks":	{"NNS"},
"eggar":	{"NN"},
"eggbeater":	{"NN"},
"eggcup":	{"NN"},
"egged":	{"VBN","VBD"},
"egger":	{"NN"},
"eggfruit":	{"NN"},
"egghead":	{"NN"},
"eggheaded":	{"JJ"},
"eggheadedness":	{"NN"},
"eggheads":	{"NNS"},
"egging":	{"VBG"},
"eggnog":	{"NN"},
"eggplant":	{"NN"},
"eggplants":	{"NNS"},
"eggs":	{"NNS","VBZ"},
"eggshake":	{"NN"},
"eggshell":	{"NN","JJ"},
"eggshells":	{"NNS"},
"eggwhisk":	{"NN"},
"egis":	{"NNS"},
"eglantine":	{"NN"},
"eglevsky":	{"NN"},
"ego":	{"NN"},
"ego-adaptive":	{"JJ"},
"egocentric":	{"JJ"},
"egocentricity":	{"NN"},
"egocentrism":	{"NN"},
"egoism":	{"NN"},
"egoist":	{"NN"},
"egoistic":	{"JJ"},
"egoistical":	{"JJ"},
"egoists":	{"NNS"},
"egomania":	{"NN"},
"egomaniac":	{"NN"},
"egos":	{"NNS"},
"egotism":	{"NN"},
"egotist":	{"NN"},
"egotistic":	{"JJ"},
"egotistical":	{"JJ"},
"egotistically":	{"RB"},
"egotrip":	{"VB","VBP"},
"egotripped":	{"VBD","VBN"},
"egotripping":	{"VBG"},
"egotrips":	{"VBZ"},
"egregious":	{"JJ"},
"egregiously":	{"RB"},
"egress":	{"NN","VB","VBP"},
"egressed":	{"VBD","VBN"},
"egresses":	{"VBZ"},
"egressing":	{"VBG"},
"egression":	{"NN"},
"egret":	{"NN"},
"egrets":	{"NNS"},
"egretta":	{"NN"},
"egtk":	{"NN"},
"egyptologist":	{"NN"},
"egyptology":	{"NN"},
"eh":	{"UH"},
"ehadhamen":	{"NN"},
"ehf":	{"NN"},
"ehrenberg":	{"NN"},
"ehrlichman":	{"NN"},
"eib":	{"NN"},
"eibit":	{"NN"},
"eichhornia":	{"NN"},
"eider":	{"NN"},
"eiderdown":	{"NN"},
"eiderdowns":	{"NNS"},
"eidetic":	{"JJ"},
"eidos":	{"NN"},
"eies":	{"NNS"},
"eiffel":	{"NN"},
"eigen":	{"NN"},
"eigenvalue":	{"NN"},
"eigenvectors":	{"NNS"},
"eight":	{"CD","LS"},
"eight-acre":	{"JJ"},
"eight-and-a-half-foot":	{"JJ"},
"eight-bar":	{"JJ"},
"eight-bit":	{"JJ"},
"eight-by-ten":	{"JJ"},
"eight-cent":	{"JJ"},
"eight-count":	{"JJ"},
"eight-day":	{"JJ"},
"eight-fold":	{"JJ"},
"eight-foot":	{"JJ"},
"eight-foot-high":	{"JJ"},
"eight-foot-tall":	{"JJ"},
"eight-hour":	{"JJ"},
"eight-inch":	{"JJ"},
"eight-member":	{"JJ"},
"eight-membered":	{"JJ"},
"eight-mile":	{"JJ"},
"eight-mile-long":	{"JJ"},
"eight-month":	{"JJ"},
"eight-month-old":	{"JJ"},
"eight-page":	{"JJ"},
"eight-page-a-minute":	{"JJ"},
"eight-partner":	{"JJ"},
"eight-person":	{"JJ"},
"eight-piece":	{"JJ"},
"eight-sided":	{"JJ"},
"eight-spot":	{"NN"},
"eight-team":	{"JJ"},
"eight-thirty":	{"JJ"},
"eight-time":	{"JJ"},
"eight-times":	{"JJ"},
"eight-week":	{"JJ"},
"eight-year-old":	{"JJ","NN"},
"eightball":	{"NN"},
"eighteen":	{"NN","CD"},
"eighteen-year-old":	{"JJ"},
"eighteenth":	{"JJ","NN"},
"eighteenth-century":	{"JJ"},
"eighter":	{"NN"},
"eightfold":	{"NN"},
"eighth":	{"JJ","NN"},
"eighth-floor":	{"JJ"},
"eighties":	{"NNS"},
"eightieth":	{"JJ","NN"},
"eightpence":	{"NN"},
"eightpenny":	{"JJ"},
"eightsome":	{"NN"},
"eightvo":	{"NN"},
"eighty":	{"NN","CD"},
"eighty-eight":	{"JJ"},
"eighty-fifth":	{"JJ"},
"eighty-five":	{"CD"},
"eighty-four":	{"JJ"},
"eighty-nine":	{"NN"},
"eighty-one":	{"NN","JJ"},
"eighty-seven":	{"JJ","NN"},
"eighty-six":	{"JJ","NN"},
"eighty-sixth":	{"JJ"},
"eighty-three":	{"CD"},
"eighty-two":	{"NN","JJ"},
"eighty-year-old":	{"JJ"},
"eijkman":	{"NN"},
"eimeria":	{"NN"},
"eimeriidae":	{"NN"},
"ein":	{"NN"},
"eindhoven":	{"NN"},
"eine":	{"FW"},
"einsteinian":	{"JJ"},
"einsteinium":	{"NN"},
"einthoven":	{"NN"},
"eira":	{"NN"},
"eire":	{"NN"},
"eisegesis":	{"NN"},
"eisenstaedt":	{"NN"},
"eisteddfod":	{"NN"},
"eisteddfods":	{"NNS"},
"either":	{"DT","CC","RB"},
"either-or":	{"JJ"},
"ejaculate":	{"VB","VBP"},
"ejaculated":	{"VBD","VBN"},
"ejaculates":	{"VBZ"},
"ejaculating":	{"VBG"},
"ejaculation":	{"NN"},
"ejaculations":	{"NNS"},
"ejaculator":	{"NN"},
"eject":	{"VB","VBP"},
"ejected":	{"VBD","VBN"},
"ejecting":	{"VBG"},
"ejection":	{"NN"},
"ejections":	{"NNS"},
"ejector":	{"NN"},
"ejects":	{"VBZ"},
"ek":	{"NN"},
"eke":	{"VB","VBP"},
"eked":	{"VBD","VBN"},
"ekes":	{"VBZ"},
"ekg":	{"NN"},
"eking":	{"VBG"},
"ekman":	{"NN"},
"el":	{"NN"},
"el-aksur":	{"NN"},
"ela":	{"NN"},
"elaborate":	{"JJ","VB","VBP"},
"elaborated":	{"VBD","VBN"},
"elaborately":	{"RB"},
"elaborateness":	{"NN"},
"elaborates":	{"VBZ"},
"elaborating":	{"VBG"},
"elaboration":	{"NN"},
"elaeagnaceae":	{"NN"},
"elaeagnus":	{"NN"},
"elaeis":	{"NNS"},
"elaeocarpaceae":	{"NN"},
"elaeocarpus":	{"NNS"},
"elagatis":	{"NNS"},
"elam":	{"NN"},
"elamite":	{"NN"},
"elamitic":	{"NN"},
"elan":	{"NN"},
"eland":	{"NN"},
"elanoides":	{"NNS"},
"elanus":	{"NN"},
"elaphe":	{"NN"},
"elaphure":	{"NN"},
"elaphurus":	{"NN"},
"elapid":	{"NN"},
"elapidae":	{"NN"},
"elapse":	{"VB","VBP"},
"elapsed":	{"VBD","VBN"},
"elapses":	{"VBZ"},
"elapsing":	{"VBG"},
"elasmobranch":	{"NN"},
"elasmobranchii":	{"NN"},
"elastance":	{"NN"},
"elastase":	{"NN"},
"elastic":	{"JJ","NN"},
"elasticate":	{"VB","VBP"},
"elasticated":	{"VBD","VBN","JJ"},
"elasticates":	{"VBZ"},
"elasticating":	{"VBG"},
"elasticised":	{"JJ"},
"elasticity":	{"NN"},
"elasticized":	{"JJ"},
"elastin":	{"NN"},
"elastomer":	{"NN"},
"elastomers":	{"NNS"},
"elastoplast":	{"NN","JJ"},
"elastosis":	{"NN"},
"elate":	{"VB","VBP"},
"elated":	{"JJ","VBD","VBN"},
"elatedly":	{"RB"},
"elater":	{"NN"},
"elaterid":	{"NN"},
"elateridae":	{"NN"},
"elates":	{"VBZ"},
"elating":	{"VBG"},
"elation":	{"NN"},
"elavil":	{"NN"},
"elbe":	{"NN"},
"elbow":	{"NN","VB","VBP"},
"elbow-grease":	{"NN"},
"elbow-room":	{"NN"},
"elbowed":	{"VBD","VBN"},
"elbowing":	{"VBG"},
"elbows":	{"NNS","VBZ"},
"eld":	{"NN"},
"elder":	{"NN","JJ"},
"elderberries":	{"NNS"},
"elderberry":	{"NN"},
"elderly":	{"JJ"},
"elders":	{"NNS"},
"eldership":	{"NN"},
"eldest":	{"JJ","NN"},
"eldorado":	{"NN"},
"eldorados":	{"NNS"},
"eldritch":	{"JJ"},
"elecampane":	{"NN"},
"elect":	{"VB","VBP","NNS","JJ"},
"elected":	{"VBN","VBD","JJ"},
"electing":	{"VBG"},
"election":	{"NN"},
"electioneer":	{"VB","VBP"},
"electioneered":	{"VBD","VBN"},
"electioneering":	{"NN","VBG"},
"electioneers":	{"VBZ"},
"elections":	{"NNS"},
"elective":	{"JJ","NN"},
"electives":	{"NNS"},
"elector":	{"NN"},
"electoral":	{"JJ"},
"electorally":	{"RB"},
"electorate":	{"NN","JJ"},
"electors":	{"NNS"},
"electric":	{"JJ"},
"electric-power":	{"JJ"},
"electrical":	{"JJ"},
"electrical-engineering":	{"NN"},
"electrical-safety":	{"JJ"},
"electrically":	{"RB"},
"electrician":	{"NN"},
"electricians":	{"NNS"},
"electricity":	{"NN"},
"electrification":	{"NN"},
"electrified":	{"VBN","VBD","JJ"},
"electrifies":	{"VBZ"},
"electrify":	{"VB","VBP"},
"electrifying":	{"JJ","VBG"},
"electriques":	{"FW"},
"electrocardiogram":	{"NN"},
"electrocardiograms":	{"NNS"},
"electrocardiograph":	{"NN"},
"electrocardiographic":	{"JJ"},
"electrocardiographs":	{"NNS"},
"electrocardiography":	{"NN"},
"electrocautery":	{"NN"},
"electrochemical":	{"JJ"},
"electrochemistry":	{"NN"},
"electrocute":	{"VB","VBP"},
"electrocuted":	{"VBD","VBN"},
"electrocutes":	{"VBZ"},
"electrocuting":	{"VBG"},
"electrocution":	{"NN"},
"electrocutioner":	{"NN"},
"electrode":	{"NN"},
"electrodeposition":	{"NN"},
"electrodes":	{"NNS"},
"electrodynamics":	{"NN"},
"electrodynamometer":	{"NN"},
"electroencephalogram":	{"NN"},
"electroencephalograms":	{"NNS"},
"electroencephalograph":	{"NN"},
"electroencephalographic":	{"JJ"},
"electroencephalographs":	{"NNS"},
"electrograph":	{"NN"},
"electrologist":	{"NN"},
"electroluminescence":	{"NN"},
"electrolysis":	{"NN"},
"electrolyte":	{"NN"},
"electrolytes":	{"NNS"},
"electrolytic":	{"JJ"},
"electromagnet":	{"NN"},
"electromagnetic":	{"JJ"},
"electromagnetism":	{"NN"},
"electromagnets":	{"NNS"},
"electromechanical":	{"JJ"},
"electrometer":	{"NN"},
"electromotive":	{"JJ"},
"electromyogram":	{"NN"},
"electromyograph":	{"NN"},
"electromyography":	{"NN"},
"electron":	{"NN"},
"electronegative":	{"JJ"},
"electronegativity":	{"NN"},
"electroneutral":	{"JJ"},
"electronic":	{"JJ"},
"electronic-publishing":	{"NN"},
"electronic-trading":	{"JJ","NN"},
"electronic-warfare":	{"NN"},
"electronically":	{"RB"},
"electronics":	{"NNS","NN"},
"electronography":	{"NN"},
"electrons":	{"NNS"},
"electrophoresis":	{"NN"},
"electrophoretic":	{"JJ"},
"electrophoridae":	{"NN"},
"electrophorus":	{"NN"},
"electroplate":	{"VB","VBP"},
"electroplated":	{"VBD","VBN"},
"electroplater":	{"NN"},
"electroplates":	{"VBZ"},
"electroplating":	{"VBG"},
"electropositive":	{"JJ"},
"electroreality":	{"NN"},
"electroretinogram":	{"NN"},
"electroscope":	{"NN"},
"electroshock":	{"NN"},
"electroshocks":	{"NNS"},
"electrosleep":	{"NN"},
"electrostatic":	{"JJ"},
"electrostatically":	{"RB"},
"electrostatics":	{"NN"},
"electrosurgery":	{"NN"},
"electrosurgical":	{"JJ"},
"electrotherapist":	{"NN"},
"electrotherapy":	{"NN"},
"electrum":	{"NN"},
"elects":	{"VBZ"},
"eleemosynary":	{"JJ"},
"elegance":	{"NN"},
"elegances":	{"NNS"},
"elegancy":	{"NN"},
"elegant":	{"JJ"},
"elegantly":	{"RB"},
"elegent":	{"FW"},
"elegiac":	{"JJ","NN"},
"elegies":	{"NNS"},
"elegise":	{"VB","VBP"},
"elegised":	{"VBD","VBN"},
"elegises":	{"VBZ"},
"elegising":	{"VBG"},
"elegist":	{"NN"},
"elegize":	{"VB","VBP"},
"elegized":	{"VBD","VBN"},
"elegizes":	{"VBZ"},
"elegizing":	{"VBG"},
"elegy":	{"NN"},
"element":	{"NN"},
"elemental":	{"JJ","NN"},
"elementarily":	{"RB"},
"elementary":	{"JJ"},
"elementary-grade":	{"JJ"},
"elementary-school":	{"NN"},
"elementary-schools":	{"NNS"},
"elements":	{"NNS"},
"elemi":	{"NN"},
"eleocharis":	{"NNS"},
"eleotridae":	{"NN"},
"elephant":	{"NN"},
"elephant's-foot":	{"NN"},
"elephant-like":	{"JJ"},
"elephant-tusk":	{"NN"},
"elephantiasis":	{"NN"},
"elephantidae":	{"NN"},
"elephantine":	{"JJ"},
"elephantopus":	{"NN"},
"elephants":	{"NNS"},
"elephas":	{"NNS"},
"elettaria":	{"NN"},
"eleusine":	{"NN"},
"eleutherodactylus":	{"NNS"},
"elevate":	{"VB","VBP"},
"elevated":	{"JJ","VBD","VBN"},
"elevates":	{"VBZ"},
"elevating":	{"JJ","VBG"},
"elevation":	{"NN"},
"elevations":	{"NNS"},
"elevator":	{"NN"},
"elevators":	{"NNS"},
"eleven":	{"CD","NN"},
"eleven-plus":	{"NN"},
"eleven-sided":	{"JJ"},
"eleventh":	{"NN","JJ"},
"eleventh-floor":	{"JJ"},
"eleventh-hour":	{"NN"},
"elf":	{"NN"},
"elfin":	{"JJ","NN"},
"elfish":	{"JJ"},
"elflike":	{"JJ"},
"elgin":	{"NN"},
"elia":	{"NN"},
"elicit":	{"VB","VBP"},
"elicitation":	{"NN"},
"elicited":	{"VBD","VBN"},
"eliciting":	{"VBG"},
"elicits":	{"VBZ"},
"elide":	{"VB","VBP"},
"elided":	{"VBD","VBN"},
"elides":	{"VBZ"},
"eliding":	{"VBG"},
"eligibility":	{"NN"},
"eligible":	{"JJ"},
"eliminate":	{"VB","VBP"},
"eliminated":	{"VBN","VBD"},
"eliminates":	{"VBZ"},
"eliminating":	{"VBG"},
"elimination":	{"NN"},
"eliminations":	{"NNS"},
"eliminator":	{"NN"},
"eliminators":	{"NNS"},
"elint":	{"NN"},
"elinvar":	{"NN"},
"eliomys":	{"NNS"},
"elisa":	{"NN"},
"elisabethville":	{"NN"},
"elision":	{"NN"},
"elisions":	{"NNS"},
"elite":	{"NN","JJ"},
"elites":	{"NNS"},
"elitism":	{"NN"},
"elitist":	{"NN"},
"elitists":	{"NNS"},
"elixir":	{"NN"},
"elixirs":	{"NNS"},
"elixophyllin":	{"NN"},
"elk":	{"NN","NNS"},
"elk-wood":	{"NN"},
"elkhound":	{"NN"},
"elks":	{"NNS"},
"elkwood":	{"NN"},
"ell":	{"NN"},
"elli":	{"NN"},
"ellipse":	{"NN"},
"ellipses":	{"NNS"},
"ellipsis":	{"NN"},
"ellipsoid":	{"NN"},
"ellipsoidal":	{"JJ"},
"ellipsoids":	{"NNS"},
"elliptic":	{"JJ"},
"elliptical":	{"JJ"},
"ellipticity":	{"NN"},
"ellison":	{"NN"},
"ellsworth":	{"NN"},
"ellul":	{"NN"},
"elm":	{"NN"},
"elmer":	{"NN"},
"elmont":	{"NN"},
"elms":	{"NNS"},
"elmwood":	{"NN"},
"eln":	{"NN"},
"elocute":	{"VB","VBP"},
"elocuted":	{"VBD","VBN"},
"elocutes":	{"VBZ"},
"elocuting":	{"VBG"},
"elocution":	{"NN"},
"elocutionary":	{"JJ"},
"elocutionist":	{"NN"},
"elocutionists":	{"NNS"},
"elodea":	{"NN"},
"elongate":	{"VB","VBP"},
"elongated":	{"JJ","VBD","VBN"},
"elongates":	{"VBZ"},
"elongating":	{"VBG"},
"elongation":	{"NN"},
"elope":	{"VB","VBP"},
"eloped":	{"VBD","VBN"},
"elopement":	{"NN"},
"elopements":	{"NNS"},
"elopes":	{"VBZ"},
"elopidae":	{"NN"},
"eloping":	{"VBG"},
"elops":	{"NNS"},
"eloquence":	{"NN"},
"eloquent":	{"JJ"},
"eloquently":	{"RB"},
"elsass":	{"NN"},
"else":	{"RB","JJ"},
"elsewhere":	{"RB"},
"elsholtzia":	{"NN"},
"elspar":	{"NN"},
"eluate":	{"NN"},
"eluates":	{"NNS"},
"elucidate":	{"VB","VBP"},
"elucidated":	{"VBD","VBN"},
"elucidates":	{"VBZ"},
"elucidating":	{"VBG"},
"elucidation":	{"NN"},
"elucidations":	{"NNS"},
"elucidative":	{"JJ"},
"elude":	{"VB","VBP"},
"eluded":	{"VBD","VBN"},
"eludes":	{"VBZ"},
"eluding":	{"VBG"},
"elul":	{"NN"},
"elusion":	{"NN"},
"elusive":	{"JJ"},
"elusively":	{"RB"},
"elusiveness":	{"NN"},
"elute":	{"VB","VBP"},
"eluted":	{"VBD","VBN"},
"elutes":	{"VBZ"},
"eluting":	{"VBG"},
"elution":	{"NN"},
"elver":	{"NN"},
"elves":	{"NNS"},
"elvish":	{"JJ"},
"elymus":	{"NNS"},
"elysian":	{"JJ"},
"elysium":	{"NN"},
"elytron":	{"NN"},
"em":	{"NN"},
"emaciate":	{"VB","VBP"},
"emaciated":	{"JJ","VBD","VBN"},
"emaciates":	{"VBZ"},
"emaciating":	{"VBG"},
"emaciation":	{"NN"},
"email":	{"NN","VB","VBP"},
"emailed":	{"VBD","VBN"},
"emailing":	{"VBG"},
"emails":	{"NNS","VBZ"},
"emanate":	{"VB","VBP"},
"emanated":	{"VBD","VBN"},
"emanates":	{"VBZ"},
"emanating":	{"VBG"},
"emanation":	{"NN"},
"emanations":	{"NNS"},
"emancipate":	{"VB","VBP"},
"emancipated":	{"JJ","VBD","VBN"},
"emancipates":	{"VBZ"},
"emancipating":	{"VBG"},
"emancipation":	{"NN"},
"emancipationist":	{"NN"},
"emancipative":	{"JJ"},
"emancipator":	{"NN"},
"emarginate":	{"JJ"},
"emasculate":	{"VB","VBP"},
"emasculated":	{"VBD","VBN"},
"emasculates":	{"VBZ"},
"emasculating":	{"VBG"},
"emasculation":	{"NN"},
"embalm":	{"VB","VBP"},
"embalmed":	{"VBD","VBN"},
"embalmer":	{"NN"},
"embalmers":	{"NNS"},
"embalming":	{"VBG"},
"embalmment":	{"NN"},
"embalms":	{"VBZ"},
"embank":	{"VB","VBP"},
"embanked":	{"VBD","VBN"},
"embanking":	{"VBG"},
"embankment":	{"NN"},
"embankments":	{"NNS"},
"embanks":	{"VBZ"},
"embargo":	{"NN","VB","VBP"},
"embargoed":	{"VBD","VBN"},
"embargoes":	{"NNS","VBZ"},
"embargoing":	{"VBG"},
"embargos":	{"NNS"},
"embark":	{"VB","VBP"},
"embarkation":	{"NN"},
"embarkations":	{"NNS"},
"embarked":	{"VBD","VBN"},
"embarking":	{"VBG"},
"embarkment":	{"NN"},
"embarks":	{"VBZ"},
"embarrass":	{"VB","VBP"},
"embarrassed":	{"JJ","VBD","VBN"},
"embarrassedly":	{"RB"},
"embarrasses":	{"VBZ"},
"embarrassing":	{"JJ","VBG"},
"embarrassingly":	{"RB"},
"embarrassment":	{"NN"},
"embarrassments":	{"NNS"},
"embassador":	{"NN"},
"embassadors":	{"NNS"},
"embassies":	{"NNS"},
"embassy":	{"NN"},
"embattle":	{"VB","VBP"},
"embattled":	{"JJ","VBD","VBN"},
"embattles":	{"VBZ"},
"embattling":	{"VBG"},
"embayment":	{"NN"},
"embed":	{"VB","VBP"},
"embedded":	{"JJ","VBD","VBN"},
"embedding":	{"VBG","NN"},
"embeds":	{"VBZ"},
"embellish":	{"VB","VBP"},
"embellished":	{"VBD","VBN"},
"embellishes":	{"VBZ"},
"embellishing":	{"VBG"},
"embellishment":	{"NN"},
"embellishments":	{"NNS"},
"ember":	{"NN"},
"emberiza":	{"NN"},
"emberizidae":	{"NN"},
"embers":	{"NNS"},
"embezzle":	{"VB","VBP"},
"embezzled":	{"VBD","VBN"},
"embezzlement":	{"NN"},
"embezzler":	{"NN"},
"embezzlers":	{"NNS"},
"embezzles":	{"VBZ"},
"embezzling":	{"VBG"},
"embiodea":	{"NN"},
"embioptera":	{"NN"},
"embiotocidae":	{"NN"},
"embitter":	{"VB","VBP"},
"embittered":	{"VBD","VBN","JJ"},
"embittering":	{"VBG"},
"embitterment":	{"NN"},
"embitters":	{"VBZ"},
"emblazon":	{"VB","VBP"},
"emblazoned":	{"VBD","VBN","JJ"},
"emblazoning":	{"VBG"},
"emblazons":	{"VBZ"},
"emblem":	{"NN"},
"emblematic":	{"JJ"},
"emblematical":	{"JJ"},
"emblems":	{"NNS"},
"embodied":	{"VBD","VBN"},
"embodies":	{"VBZ"},
"embodiment":	{"NN"},
"embodiments":	{"NNS"},
"embody":	{"VB","VBP"},
"embodying":	{"VBG"},
"embolden":	{"VB","VBP"},
"emboldened":	{"VBD","VBN"},
"emboldening":	{"VBG"},
"emboldens":	{"VBZ"},
"embolectomy":	{"NN"},
"embolic":	{"JJ"},
"embolism":	{"NN"},
"embolisms":	{"NNS"},
"embolus":	{"NN"},
"embonpoint":	{"NN"},
"embosom":	{"VB","VBP"},
"embosomed":	{"VBD","VBN"},
"embosoming":	{"VBG"},
"embosoms":	{"VBZ"},
"emboss":	{"VB","VBP"},
"embossed":	{"JJ","VBD","VBN"},
"embosses":	{"VBZ"},
"embossing":	{"VBG"},
"embossment":	{"NN"},
"embothrium":	{"NN"},
"embouchure":	{"NN"},
"embower":	{"VB","VBP"},
"embowered":	{"VBD","VBN"},
"embowering":	{"VBG"},
"embowers":	{"VBZ"},
"embrace":	{"VB","NN","VBP"},
"embraced":	{"VBN","VBD"},
"embracement":	{"NN"},
"embraces":	{"VBZ","NNS"},
"embracing":	{"VBG"},
"embrangle":	{"VB","VBP"},
"embrangled":	{"VBD","VBN"},
"embranglement":	{"NN"},
"embrangles":	{"VBZ"},
"embrangling":	{"VBG"},
"embrasure":	{"NN"},
"embrasures":	{"NNS"},
"embrittle":	{"VB","VBP"},
"embrocate":	{"VB","VBP"},
"embrocated":	{"VBD","VBN"},
"embrocates":	{"VBZ"},
"embrocating":	{"VBG"},
"embrocation":	{"NN"},
"embroider":	{"VB","VBP"},
"embroidered":	{"VBD","VBN"},
"embroiderer":	{"NN"},
"embroideress":	{"NN"},
"embroideries":	{"NNS"},
"embroidering":	{"VBG"},
"embroiders":	{"VBZ"},
"embroidery":	{"NN"},
"embroil":	{"VB","VBP"},
"embroiled":	{"VBD","VBN"},
"embroiling":	{"VBG"},
"embroilment":	{"NN"},
"embroils":	{"VBZ"},
"embrown":	{"VB","VBP"},
"embrowned":	{"VBD","VBN"},
"embrowning":	{"VBG"},
"embrowns":	{"VBZ"},
"embryo":	{"NN"},
"embryologic":	{"JJ"},
"embryological":	{"JJ"},
"embryologically":	{"RB"},
"embryologist":	{"NN"},
"embryologists":	{"NNS"},
"embryology":	{"NN"},
"embryonal":	{"JJ"},
"embryonic":	{"JJ"},
"embryos":	{"NNS"},
"embryotic":	{"JJ"},
"emcee":	{"VB","VBP","NN"},
"emceed":	{"VBD","VBN"},
"emceeing":	{"VBG"},
"emcees":	{"VBZ","NNS"},
"emda":	{"NN"},
"emeer":	{"NN"},
"emend":	{"VB","VBP"},
"emendation":	{"NN"},
"emended":	{"VBD","VBN"},
"emending":	{"VBG"},
"emends":	{"VBZ"},
"emerald":	{"NN","JJ"},
"emeralds":	{"NNS"},
"emerge":	{"VB","VBP"},
"emerged":	{"VBD","VBN"},
"emergence":	{"NN"},
"emergencies":	{"NNS"},
"emergency":	{"NN"},
"emergency-cash":	{"NN"},
"emergency-claims":	{"NNS"},
"emergency-medical":	{"JJ"},
"emergency-relief":	{"NN"},
"emergency-room":	{"NN"},
"emergent":	{"JJ"},
"emerges":	{"VBZ"},
"emerging":	{"VBG","JJ"},
"emerging-growth":	{"NN"},
"emeriti":	{"NN"},
"emeritus":	{"JJ"},
"emersion":	{"NN"},
"emery":	{"NN"},
"emery-board":	{"NN"},
"emery-boards":	{"NNS"},
"emery-paper":	{"NN"},
"emeside":	{"NN"},
"emesis":	{"NN"},
"emetic":	{"NN","JJ"},
"emetics":	{"NNS"},
"emetrol":	{"NN"},
"emf":	{"NN"},
"emg":	{"NN"},
"emigrant":	{"NN"},
"emigrants":	{"NNS"},
"emigrate":	{"VB","VBP"},
"emigrated":	{"VBD","VBN"},
"emigrates":	{"VBZ"},
"emigrating":	{"VBG"},
"emigration":	{"NN"},
"emigration-related":	{"JJ"},
"emigrations":	{"NNS"},
"emigre":	{"NN"},
"emigree":	{"NN"},
"emigres":	{"NNS"},
"emile":	{"NN"},
"emilia":	{"NN"},
"emilia-romagna":	{"NN"},
"eminence":	{"NN"},
"eminences":	{"NNS"},
"eminent":	{"JJ"},
"eminently":	{"RB"},
"emir":	{"NN"},
"emirate":	{"NN"},
"emirates":	{"NNS"},
"emirs":	{"NNS"},
"emissaries":	{"NNS"},
"emissary":	{"NN"},
"emission":	{"NN"},
"emission-control":	{"JJ"},
"emissions":	{"NNS"},
"emit":	{"VB","VBP"},
"emits":	{"VBZ"},
"emitted":	{"VBN","VBD"},
"emitter":	{"NN"},
"emitting":	{"VBG"},
"emmanthe":	{"NN"},
"emmenagogue":	{"NN"},
"emmer":	{"NN"},
"emmet":	{"NN"},
"emmetropia":	{"NN"},
"emmetropic":	{"JJ"},
"emojis":	{"NNS"},
"emollient":	{"JJ","NN"},
"emollients":	{"NNS"},
"emolument":	{"NN"},
"emoluments":	{"NNS"},
"emory":	{"NN"},
"emote":	{"VB","VBP"},
"emoted":	{"VBD","VBN"},
"emotes":	{"VBZ"},
"emoticon":	{"NN"},
"emoting":	{"VBG"},
"emotion":	{"NN"},
"emotional":	{"JJ"},
"emotionalism":	{"NN"},
"emotionality":	{"NN"},
"emotionally":	{"RB"},
"emotionless":	{"JJ"},
"emotionlessness":	{"NN"},
"emotions":	{"NNS"},
"emotive":	{"JJ"},
"emotively":	{"RB"},
"empale":	{"VB","VBP"},
"empaled":	{"VBD","VBN"},
"empalement":	{"NN"},
"empaler":	{"NN"},
"empales":	{"VBZ"},
"empaling":	{"VBG"},
"empanel":	{"VB","VBP"},
"empaneled":	{"VBD","VBN"},
"empaneling":	{"VBG"},
"empanelled":	{"VBD","VBN"},
"empanelling":	{"VBG"},
"empanels":	{"VBZ"},
"empathetic":	{"JJ"},
"empathetically":	{"RB"},
"empathic":	{"JJ"},
"empathise":	{"VB","VBP"},
"empathised":	{"VBD","VBN"},
"empathises":	{"VBZ"},
"empathising":	{"VBG"},
"empathize":	{"VB","VBP"},
"empathized":	{"VBD","VBN"},
"empathizes":	{"VBZ"},
"empathizing":	{"VBG"},
"empathy":	{"NN"},
"empedocles":	{"NNS"},
"empennage":	{"NN"},
"emperor":	{"NN"},
"emperors":	{"NNS"},
"empetraceae":	{"NN"},
"empetrum":	{"NN"},
"emphases":	{"NNS"},
"emphasis":	{"NN"},
"emphasise":	{"VB","VBP"},
"emphasised":	{"VBD","VBN"},
"emphasises":	{"VBZ"},
"emphasising":	{"VBG"},
"emphasize":	{"VB","VBP"},
"emphasized":	{"VBD","VBN"},
"emphasizes":	{"VBZ"},
"emphasizing":	{"VBG"},
"emphatic":	{"JJ"},
"emphatically":	{"RB"},
"emphysema":	{"NN"},
"emphysematous":	{"JJ"},
"empire":	{"NN"},
"empire-building":	{"NN"},
"empires":	{"NNS"},
"empiric":	{"JJ"},
"empirical":	{"JJ"},
"empirically":	{"RB"},
"empiricism":	{"NN"},
"empiricist":	{"NN"},
"empiricists":	{"NNS"},
"empirin":	{"NN"},
"emplace":	{"VB","VBP"},
"emplaced":	{"VBD","VBN"},
"emplacement":	{"NN"},
"emplaces":	{"VBZ"},
"emplacing":	{"VBG"},
"emplane":	{"VB","VBP"},
"emplaned":	{"VBD","VBN"},
"emplanes":	{"VBZ"},
"emplaning":	{"VBG"},
"employ":	{"VB","NN","VBP"},
"employable":	{"JJ"},
"employe":	{"NN"},
"employed":	{"VBN","VBD"},
"employee":	{"NN"},
"employee-benefit":	{"JJ","NN"},
"employee-benefits":	{"JJ","NNS"},
"employee-bonus":	{"JJ","NN"},
"employee-contributed":	{"JJ"},
"employee-health":	{"NN"},
"employee-incentive":	{"NN"},
"employee-management":	{"JJ","NN"},
"employee-owned":	{"JJ"},
"employee-ownership":	{"JJ","NN"},
"employee-stock":	{"JJ"},
"employees":	{"NNS"},
"employer":	{"NN"},
"employer-offered":	{"JJ"},
"employer-paid":	{"JJ"},
"employer-provided":	{"JJ"},
"employer-sponsored":	{"JJ"},
"employerpaid":	{"JJ"},
"employers":	{"NNS"},
"employing":	{"VBG"},
"employment":	{"NN"},
"employment-services":	{"JJ"},
"employment-tax":	{"JJ"},
"employments":	{"NNS"},
"employs":	{"VBZ"},
"emporia":	{"NNS"},
"emporium":	{"NN"},
"emporiums":	{"NNS"},
"empower":	{"VB","VBP"},
"empowered":	{"VBD","VBN"},
"empowering":	{"VBG"},
"empowerment":	{"NN"},
"empowers":	{"VBZ"},
"empress":	{"NN"},
"emptied":	{"VBN","VBD"},
"emptier":	{"JJR"},
"empties":	{"NNS","VBZ"},
"emptiest":	{"JJS"},
"emptiness":	{"NN"},
"emptor":	{"NN"},
"empty":	{"JJ","VB","VBP"},
"empty-bellied":	{"JJ"},
"empty-handed":	{"JJ"},
"empty-headed":	{"JJ"},
"empty-shelved":	{"JJ"},
"emptying":	{"VBG"},
"empurple":	{"VB","VBP"},
"empurpled":	{"VBD","VBN"},
"empurples":	{"VBZ"},
"empurpling":	{"VBG"},
"empyema":	{"NN"},
"empyreal":	{"JJ"},
"empyrean":	{"JJ","NN"},
"emu":	{"NN","NNS"},
"emulate":	{"VB","VBP"},
"emulated":	{"VBD","VBN"},
"emulates":	{"VBZ"},
"emulating":	{"VBG"},
"emulation":	{"NN"},
"emulator":	{"NN"},
"emulous":	{"JJ"},
"emulously":	{"RB"},
"emulsified":	{"VBD","VBN"},
"emulsifier":	{"NN"},
"emulsifiers":	{"NNS"},
"emulsifies":	{"VBZ"},
"emulsify":	{"VB","VBP"},
"emulsifying":	{"VBG"},
"emulsion":	{"NN"},
"emulsions":	{"NNS"},
"emus":	{"NNS"},
"emydidae":	{"NN"},
"en":	{"FW"},
"en-lil":	{"NN"},
"enable":	{"VB","VBP"},
"enabled":	{"VBD","VBN"},
"enables":	{"VBZ"},
"enabling":	{"JJ","VBG"},
"enact":	{"VB","VBP"},
"enacted":	{"VBN","VBD"},
"enacting":	{"VBG"},
"enactment":	{"NN"},
"enactments":	{"NNS"},
"enacts":	{"VBZ"},
"enalapril":	{"NN"},
"enallage":	{"NN"},
"enamel":	{"NN","VB","VBP","JJ"},
"enameled":	{"JJ","VBD","VBN"},
"enameling":	{"NN","VBG"},
"enamelled":	{"JJ","VBD","VBN"},
"enamelling":	{"NN","VBG"},
"enamels":	{"NNS","VBZ"},
"enamelware":	{"NN"},
"enamine":	{"NN"},
"enamor":	{"VB","VBP"},
"enamored":	{"JJ","VBD","VBN"},
"enamoredness":	{"NN"},
"enamoring":	{"VBG"},
"enamors":	{"VBZ"},
"enamour":	{"VB","VBP"},
"enamoured":	{"JJ","VBD","VBN"},
"enamouring":	{"VBG"},
"enamours":	{"VBZ"},
"enanthem":	{"NN"},
"enanthema":	{"NN"},
"enantiomer":	{"NN"},
"enantiomorph":	{"NN"},
"enantiomorphism":	{"NN"},
"enarthrosis":	{"NN"},
"enate":	{"JJ","NN"},
"enatic":	{"JJ"},
"enation":	{"NN"},
"enbrel":	{"NN"},
"encainide":	{"NN"},
"encamp":	{"VB","VBP"},
"encamped":	{"VBD","VBN"},
"encamping":	{"VBG"},
"encampment":	{"NN"},
"encampments":	{"NNS"},
"encamps":	{"VBZ"},
"encapsulate":	{"VB","VBP"},
"encapsulated":	{"VBD","VBN"},
"encapsulates":	{"VBZ"},
"encapsulating":	{"VBG"},
"encapsulation":	{"NN"},
"encase":	{"VB","VBP"},
"encased":	{"VBD","VBN"},
"encasement":	{"NN"},
"encases":	{"VBZ"},
"encasing":	{"VBG"},
"encaustic":	{"JJ","NN"},
"enceinte":	{"JJ","NN"},
"encelia":	{"NN"},
"enceliopsis":	{"NN"},
"encephalartos":	{"NNS"},
"encephalitis":	{"NN"},
"encephalocele":	{"NN"},
"encephalogram":	{"NN"},
"encephalographic":	{"JJ"},
"encephalography":	{"NN"},
"encephalomeningitis":	{"NNS"},
"encephalomyelitis":	{"NN"},
"encephalon":	{"NN"},
"encephalopathy":	{"NN"},
"enchain":	{"VB","VBP"},
"enchained":	{"VBD","VBN"},
"enchaining":	{"VBG"},
"enchains":	{"VBZ"},
"enchant":	{"VB","VBP"},
"enchanted":	{"JJ","VBD","VBN"},
"enchanter":	{"NN"},
"enchanters":	{"NNS"},
"enchanting":	{"JJ","VBG"},
"enchantingly":	{"RB"},
"enchantment":	{"NN"},
"enchantments":	{"NNS"},
"enchantress":	{"NN"},
"enchantresses":	{"NNS"},
"enchants":	{"VBZ"},
"enchilada":	{"NN"},
"enchiladas":	{"NNS"},
"enchiridion":	{"NN"},
"enchondroma":	{"NN"},
"encipher":	{"VB","VBP"},
"enciphered":	{"VBN","VBD"},
"enciphering":	{"VBG"},
"enciphers":	{"VBZ"},
"encircle":	{"VB","VBP"},
"encircled":	{"VBD","VBN"},
"encirclement":	{"NN"},
"encircles":	{"VBZ"},
"encircling":	{"VBG","NN"},
"enclave":	{"NN"},
"enclaves":	{"NNS"},
"enclose":	{"VB","VBP"},
"enclosed":	{"VBD","VBN","JJ"},
"encloses":	{"VBZ"},
"enclosing":	{"VBG"},
"enclosure":	{"NN"},
"enclosures":	{"NNS"},
"enclothe":	{"VB","VBP"},
"enclothed":	{"VBD","VBN"},
"enclothes":	{"VBZ"},
"enclothing":	{"VBG"},
"encode":	{"VB","VBP"},
"encoded":	{"VBN","VBD"},
"encoder":	{"NN"},
"encodes":	{"VBZ"},
"encoding":	{"NN","VBG"},
"encolure":	{"NN"},
"encomia":	{"NNS"},
"encomiastic":	{"JJ"},
"encomium":	{"NN"},
"encomiums":	{"NNS"},
"encompass":	{"VB","VBP"},
"encompassed":	{"VBD","VBN"},
"encompasses":	{"VBZ"},
"encompassing":	{"VBG"},
"encompassment":	{"NN"},
"encopresis":	{"NN"},
"encore":	{"NN","UH","VB","VBP"},
"encored":	{"VBD","VBN"},
"encores":	{"NNS","VBZ"},
"encoring":	{"VBG"},
"encounter":	{"NN","VB","VBP"},
"encountered":	{"VBN","VBD"},
"encountering":	{"VBG"},
"encounters":	{"NNS","VBZ"},
"encourage":	{"VB","VBP"},
"encouraged":	{"VBN","VBD","JJ"},
"encouragement":	{"NN"},
"encouragements":	{"NNS"},
"encourages":	{"VBZ"},
"encouraging":	{"VBG","JJ"},
"encouragingly":	{"RB"},
"encrimson":	{"VB","VBP"},
"encrimsoned":	{"VBD","VBN"},
"encrimsoning":	{"VBG"},
"encrimsons":	{"VBZ"},
"encroach":	{"VB","VBP"},
"encroached":	{"VBD","VBN"},
"encroacher":	{"NN"},
"encroaches":	{"VBZ"},
"encroaching":	{"VBG"},
"encroachment":	{"NN"},
"encroachments":	{"NNS"},
"encrust":	{"VB","VBP"},
"encrustation":	{"NN"},
"encrustations":	{"NNS"},
"encrusted":	{"VBD","VBN","JJ"},
"encrusting":	{"VBG"},
"encrusts":	{"VBZ"},
"encrypt":	{"VB","VBP"},
"encrypted":	{"VBD","VBN","JJ"},
"encrypting":	{"VBG"},
"encryption":	{"NN"},
"encrypts":	{"VBZ"},
"enculturate":	{"VB","VBP"},
"enculturated":	{"VBD","VBN"},
"enculturates":	{"VBZ"},
"enculturating":	{"VBG"},
"enculturation":	{"NN"},
"enculturative":	{"JJ"},
"encumber":	{"VB","VBP"},
"encumbered":	{"VBD","VBN","JJ"},
"encumbering":	{"VBG"},
"encumbers":	{"VBZ"},
"encumbrance":	{"NN"},
"encumbrances":	{"NNS"},
"encyclia":	{"NN"},
"encyclical":	{"NN"},
"encyclicals":	{"NNS"},
"encyclopaedia":	{"NN"},
"encyclopaedias":	{"NNS"},
"encyclopaedic":	{"JJ"},
"encyclopaedism":	{"NN"},
"encyclopaedist":	{"NN"},
"encyclopedia":	{"NN"},
"encyclopedias":	{"NNS"},
"encyclopedic":	{"JJ"},
"encyclopedism":	{"NN"},
"encyclopedist":	{"NN"},
"encylopedia":	{"NN"},
"encysted":	{"JJ"},
"end":	{"NN","VB","VBP"},
"end-all":	{"NN"},
"end-of-model-year":	{"JJ"},
"end-of-school":	{"JJ"},
"end-of-season":	{"JJ"},
"end-of-the-quarter":	{"JJ"},
"end-of-the-season":	{"JJ"},
"end-of-the-year":	{"JJ"},
"end-of-year":	{"JJ"},
"end-plate":	{"NN"},
"end-product":	{"NN"},
"end-products":	{"NNS"},
"end-rhymed":	{"JJ"},
"end-run":	{"NN"},
"end-stopped":	{"JJ"},
"end-to-end":	{"JJ","RB"},
"end-use":	{"NN"},
"end-user":	{"NN"},
"end-users":	{"NNS"},
"end-zone":	{"NN"},
"endaemonism":	{"NN"},
"endameba":	{"NN"},
"endamoeba":	{"NN"},
"endamoebidae":	{"NN"},
"endanger":	{"VB","VBP"},
"endangered":	{"VBN","JJ","VBD"},
"endangered-species":	{"NNS"},
"endangering":	{"VBG"},
"endangerment":	{"NN"},
"endangers":	{"VBZ"},
"endarterectomy":	{"NN"},
"endarteritis":	{"NN"},
"endcap":	{"NN"},
"endcaps":	{"NNS"},
"endear":	{"VB","VBP"},
"endeared":	{"VBD","VBN"},
"endearing":	{"JJ","VBG"},
"endearingly":	{"RB"},
"endearment":	{"NN"},
"endearments":	{"NNS"},
"endears":	{"VBZ"},
"endeavor":	{"NN","VB","VBP"},
"endeavored":	{"VBD","VBN"},
"endeavoring":	{"VBG"},
"endeavors":	{"NNS","VBZ"},
"endeavour":	{"NN","VB","VBP"},
"endeavoured":	{"VBD","VBN"},
"endeavouring":	{"VBG"},
"endeavours":	{"NNS","VBZ"},
"endecott":	{"NN"},
"ended":	{"VBD","VBN"},
"endemic":	{"JJ","NN"},
"endemical":	{"JJ"},
"endemism":	{"NN"},
"endergonic":	{"JJ"},
"endermatic":	{"JJ"},
"endermic":	{"JJ"},
"endevor":	{"NN"},
"endgame":	{"NN"},
"endgames":	{"NNS"},
"endicott":	{"NN"},
"ending":	{"VBG","NN"},
"endings":	{"NNS"},
"endive":	{"NN"},
"endives":	{"NNS"},
"endless":	{"JJ"},
"endlessly":	{"RB"},
"endlessness":	{"NN"},
"endoblast":	{"NN"},
"endocarditis":	{"NN"},
"endocardium":	{"NN"},
"endocarp":	{"NN"},
"endocentric":	{"JJ"},
"endocervicitis":	{"NNS"},
"endocranium":	{"NN"},
"endocrinal":	{"JJ"},
"endocrine":	{"JJ","NN"},
"endocrinologist":	{"NN"},
"endocrinologists":	{"NNS"},
"endocrinology":	{"NN"},
"endoderm":	{"NN"},
"endodontia":	{"NN"},
"endodontic":	{"JJ"},
"endodontics":	{"NN"},
"endodontist":	{"NN"},
"endoergic":	{"JJ"},
"endogamic":	{"JJ"},
"endogamous":	{"JJ"},
"endogamy":	{"NN"},
"endogen":	{"NN"},
"endogenetic":	{"JJ"},
"endogenic":	{"JJ"},
"endogenous":	{"JJ"},
"endogenously":	{"RB"},
"endogeny":	{"NN"},
"endolymph":	{"NN"},
"endometrial":	{"JJ"},
"endometriosis":	{"NN"},
"endometritis":	{"NN"},
"endometrium":	{"NN"},
"endomorph":	{"NN"},
"endomorphic":	{"JJ"},
"endomorphy":	{"NN"},
"endomycetales":	{"NNS"},
"endoneurium":	{"NN"},
"endonuclease":	{"NN"},
"endoparasite":	{"NN"},
"endoparasitic":	{"JJ"},
"endoplasm":	{"NN"},
"endoprocta":	{"NN"},
"endorphin":	{"NN"},
"endorse":	{"VB","VBP"},
"endorsed":	{"VBN","VBD"},
"endorsement":	{"NN"},
"endorsements":	{"NNS"},
"endorser":	{"NN"},
"endorsers":	{"NNS"},
"endorses":	{"VBZ"},
"endorsing":	{"VBG"},
"endoscope":	{"NN"},
"endoscopes":	{"NNS"},
"endoscopic":	{"JJ"},
"endoscopy":	{"NN"},
"endoskeleton":	{"NN"},
"endosperm":	{"NN"},
"endospore":	{"NN"},
"endosteum":	{"NN"},
"endothelial":	{"JJ","NN"},
"endothelium":	{"NN"},
"endothermal":	{"JJ"},
"endothermic":	{"JJ"},
"endotoxin":	{"NN"},
"endotoxins":	{"NNS"},
"endovascular":	{"JJ"},
"endovenous":	{"JJ"},
"endow":	{"VB","VBP"},
"endowed":	{"VBD","VBN"},
"endowing":	{"VBG"},
"endowment":	{"NN"},
"endowments":	{"NNS"},
"endows":	{"VBZ"},
"endozoan":	{"JJ","NN"},
"endozoic":	{"JJ"},
"endplate":	{"NN"},
"endpoint":	{"NN"},
"endpoints":	{"NNS"},
"endrocrine":	{"JJ"},
"ends":	{"VBZ","NNS"},
"endue":	{"VB","VBP"},
"endued":	{"VBD","VBN"},
"endues":	{"VBZ"},
"enduing":	{"VBG"},
"endurable":	{"JJ"},
"endurance":	{"NN"},
"endure":	{"VB","VBP"},
"endured":	{"VBN","VBD"},
"endures":	{"VBZ"},
"enduring":	{"VBG","JJ"},
"enduringly":	{"RB"},
"enduringness":	{"NN"},
"endways":	{"RB"},
"endwise":	{"RB"},
"ene":	{"NN"},
"enema":	{"NN"},
"enemas":	{"NNS"},
"enemies":	{"NNS"},
"enemy":	{"NN"},
"enemy-Jew":	{"NN"},
"enemy-jew":	{"NN"},
"energetic":	{"JJ"},
"energetically":	{"RB"},
"energid":	{"NN"},
"energies":	{"NNS"},
"energise":	{"VB","VBP"},
"energised":	{"VBD","VBN"},
"energiser":	{"NN"},
"energises":	{"VBZ"},
"energising":	{"JJ","VBG"},
"energize":	{"VB","VBP"},
"energized":	{"VBN","VBD"},
"energizer":	{"NN"},
"energizes":	{"VBZ"},
"energizing":	{"JJ","VBG"},
"energy":	{"NN"},
"energy-absorbing":	{"JJ"},
"energy-adjusted":	{"JJ"},
"energy-cogeneration":	{"NN"},
"energy-efficient":	{"JJ","NN"},
"energy-hungry":	{"JJ"},
"energy-industry":	{"NN"},
"energy-producing":	{"JJ"},
"energy-releasing":	{"JJ"},
"energy-services":	{"NNS","JJ"},
"energy-storing":	{"JJ"},
"energy-weighted":	{"JJ"},
"enervate":	{"VB","VBP"},
"enervated":	{"JJ","VBD","VBN"},
"enervates":	{"VBZ"},
"enervating":	{"JJ","VBG"},
"enervation":	{"NN"},
"enesco":	{"NN"},
"enets":	{"NNS"},
"enfant":	{"NN"},
"enfants":	{"NNS"},
"enfeeble":	{"VB","VBP"},
"enfeebled":	{"VBD","VBN","JJ"},
"enfeeblement":	{"NN"},
"enfeebles":	{"VBZ"},
"enfeebling":	{"VBG"},
"enfeoff":	{"VB","VBP"},
"enfeoffed":	{"VBD","VBN"},
"enfeoffing":	{"VBG"},
"enfeoffment":	{"NN"},
"enfeoffs":	{"VBZ"},
"enfilade":	{"NN","VB","VBP"},
"enfiladed":	{"VBD","VBN"},
"enfilades":	{"NNS","VBZ"},
"enfilading":	{"VBG"},
"enflurane":	{"NN"},
"enfold":	{"VB","VBP"},
"enfolded":	{"VBD","VBN"},
"enfolding":	{"VBG"},
"enfolds":	{"VBZ"},
"enforce":	{"VB","VBP"},
"enforceable":	{"JJ"},
"enforced":	{"JJ","VBD","VBN"},
"enforcement":	{"NN"},
"enforcer":	{"NN"},
"enforcers":	{"NNS"},
"enforces":	{"VBZ"},
"enforcing":	{"VBG"},
"enfranchise":	{"VB","VBP"},
"enfranchised":	{"VBD","VBN","JJ"},
"enfranchisement":	{"NN"},
"enfranchises":	{"VBZ"},
"enfranchising":	{"VBG"},
"engage":	{"VB","VBP"},
"engaged":	{"VBN","VBD","JJ"},
"engagement":	{"NN"},
"engagements":	{"NNS"},
"engages":	{"VBZ"},
"engaging":	{"JJ","VBG"},
"engagingly":	{"RB"},
"engelmannia":	{"NN"},
"engender":	{"VB","VBP"},
"engendered":	{"VBD","VBN"},
"engendering":	{"VBG"},
"engenders":	{"VBZ"},
"engild":	{"VB","VBP"},
"engilded":	{"VBD","VBN"},
"engilding":	{"VBG"},
"engilds":	{"VBZ"},
"engine":	{"NN"},
"engine-assembly":	{"NN"},
"engine-casting":	{"NN"},
"engine-driver":	{"NN"},
"engineer":	{"NN","VB","VBP"},
"engineered":	{"VBN","VBD"},
"engineering":	{"NN","VBG"},
"engineering-design":	{"JJ"},
"engineering-management":	{"JJ","NN"},
"engineering-services":	{"NNS"},
"engineers":	{"NNS","VBZ"},
"engineless":	{"JJ"},
"enginery":	{"NN"},
"engines":	{"NNS"},
"england-based":	{"JJ"},
"engle":	{"NN"},
"english-born":	{"JJ"},
"english-dialogue":	{"JJ"},
"english-dutch":	{"JJ"},
"english-gothic":	{"NN"},
"english-rights":	{"JJ"},
"english-speakers":	{"NNS"},
"english-speaking":	{"JJ"},
"english-weed":	{"NN"},
"englishy":	{"JJ"},
"englut":	{"VB","VBP"},
"engluts":	{"VBZ"},
"englutted":	{"VBD","VBN"},
"englutting":	{"VBG"},
"engorge":	{"VB","VBP"},
"engorged":	{"JJ","VBD","VBN"},
"engorgement":	{"NN"},
"engorges":	{"VBZ"},
"engorging":	{"VBG"},
"engraft":	{"VB","VBP"},
"engrafted":	{"VBD","VBN"},
"engrafting":	{"VBG"},
"engrafts":	{"VBZ"},
"engram":	{"NN"},
"engraulidae":	{"NN"},
"engraulis":	{"NNS"},
"engrave":	{"VB","VBP"},
"engraved":	{"VBD","VBN","JJ"},
"engraver":	{"NN"},
"engravers":	{"NNS"},
"engraves":	{"VBZ"},
"engraving":	{"NN","VBG"},
"engravings":	{"NNS"},
"engross":	{"VB","VBP"},
"engrossed":	{"JJ","VBD","VBN"},
"engrosses":	{"VBZ"},
"engrossing":	{"JJ","VBG"},
"engrossment":	{"NN"},
"engulf":	{"VB","VBP"},
"engulfed":	{"VBD","VBN"},
"engulfing":	{"VBG"},
"engulfs":	{"VBZ"},
"enhance":	{"VB","VBP"},
"enhanced":	{"JJ","VBD","VBN"},
"enhancement":	{"NN"},
"enhancements":	{"NNS"},
"enhancer":	{"NN"},
"enhancers":	{"NNS"},
"enhances":	{"VBZ"},
"enhancing":	{"VBG"},
"enhancive":	{"JJ"},
"enhydra":	{"NN"},
"enid":	{"NN"},
"enigma":	{"NN"},
"enigmas":	{"NNS"},
"enigmatic":	{"JJ"},
"enigmatical":	{"JJ"},
"enigmatically":	{"RB"},
"eniwetok":	{"NN"},
"enjambement":	{"NN"},
"enjambment":	{"NN"},
"enjoin":	{"VB","VBP"},
"enjoinder":	{"NN"},
"enjoined":	{"VBD","VBN"},
"enjoining":	{"VBG"},
"enjoinment":	{"NN"},
"enjoins":	{"VBZ"},
"enjoy":	{"VB","VBP"},
"enjoyable":	{"JJ"},
"enjoyableness":	{"NN"},
"enjoyably":	{"RB"},
"enjoyed":	{"VBD","VBN"},
"enjoyer":	{"NN"},
"enjoying":	{"VBG"},
"enjoyment":	{"NN"},
"enjoyments":	{"NNS"},
"enjoys":	{"VBZ"},
"enkaid":	{"NN"},
"enkephalin":	{"NN"},
"enki":	{"NN"},
"enkidu":	{"NN"},
"enkindle":	{"VB","VBP"},
"enkindled":	{"VBD","VBN"},
"enkindles":	{"VBZ"},
"enkindling":	{"VBG"},
"enl":	{"NN"},
"enlace":	{"VB","VBP"},
"enlaced":	{"VBD","VBN"},
"enlaces":	{"VBZ"},
"enlacing":	{"VBG"},
"enlarge":	{"VB","VBP"},
"enlarged":	{"VBD","VBN","JJ"},
"enlargement":	{"NN"},
"enlargements":	{"NNS"},
"enlarger":	{"NN"},
"enlargers":	{"NNS"},
"enlarges":	{"VBZ"},
"enlarging":	{"VBG"},
"enlighten":	{"VB","VBP"},
"enlightened":	{"JJ","VBD","VBN"},
"enlightening":	{"JJ","VBG"},
"enlightenment":	{"NN"},
"enlightens":	{"VBZ"},
"enlil":	{"NN"},
"enlist":	{"VB","VBP"},
"enlisted":	{"VBD","VBN","JJ"},
"enlistee":	{"NN"},
"enlisting":	{"VBG"},
"enlistment":	{"NN"},
"enlistments":	{"NNS"},
"enlists":	{"VBZ"},
"enliven":	{"VB","VBP"},
"enlivened":	{"VBD","VBN"},
"enlivener":	{"NN"},
"enlivening":	{"VBG"},
"enlivens":	{"VBZ"},
"enmesh":	{"VB","VBP"},
"enmeshed":	{"JJ","VBD","VBN"},
"enmeshes":	{"VBZ"},
"enmeshing":	{"VBG"},
"enmities":	{"NNS"},
"enmity":	{"NN"},
"ennead":	{"NN"},
"ennoble":	{"VB","VBP"},
"ennobled":	{"VBD","VBN"},
"ennoblement":	{"NN"},
"ennobles":	{"VBZ"},
"ennobling":	{"VBG","JJ"},
"ennui":	{"NN"},
"enny":	{"JJ"},
"enol":	{"NN"},
"enolic":	{"JJ"},
"enologist":	{"NN"},
"enology":	{"NN"},
"enophile":	{"NN"},
"enormities":	{"NNS"},
"enormity":	{"NN"},
"enormous":	{"JJ"},
"enormously":	{"RB"},
"enormousness":	{"NN"},
"enosis":	{"NN"},
"enough":	{"RB","JJ","NN","DT","PRP"},
"enounce":	{"VB","VBP"},
"enounced":	{"VBD","VBN"},
"enounces":	{"VBZ"},
"enouncing":	{"VBG"},
"enovid":	{"NN"},
"enoxacin":	{"NN"},
"enplane":	{"VB","VBP"},
"enplaned":	{"VBD","VBN"},
"enplanes":	{"VBZ"},
"enplaning":	{"VBG"},
"enquetes":	{"FW"},
"enquire":	{"VB","VBP"},
"enquired":	{"VBD","VBN"},
"enquirer":	{"NN"},
"enquirers":	{"NNS"},
"enquires":	{"VBZ"},
"enquiries":	{"NNS"},
"enquiring":	{"VBG","JJ"},
"enquiringly":	{"RB"},
"enquiry":	{"NN"},
"enrage":	{"VB","VBP"},
"enraged":	{"JJ","VBD","VBN"},
"enragement":	{"NN"},
"enrages":	{"VBZ"},
"enraging":	{"VBG"},
"enrapture":	{"VB","VBP"},
"enraptured":	{"VBD","VBN"},
"enraptures":	{"VBZ"},
"enrapturing":	{"VBG"},
"enrich":	{"VB","VBP"},
"enriched":	{"JJ","VBD","VBN"},
"enriches":	{"VBZ"},
"enriching":	{"VBG"},
"enrichment":	{"NN"},
"enrique":	{"NN"},
"enrobe":	{"VB","VBP"},
"enrobed":	{"VBD","VBN"},
"enrobes":	{"VBZ"},
"enrobing":	{"VBG"},
"enrol":	{"VB","VBP"},
"enroll":	{"VB","VBP"},
"enrolled":	{"VBD","VBN"},
"enrollee":	{"NN"},
"enrollees":	{"NNS"},
"enrolling":	{"VBG"},
"enrollment":	{"NN"},
"enrollments":	{"NNS"},
"enrolls":	{"VBZ"},
"enrolment":	{"NN"},
"enrolments":	{"NNS"},
"enrols":	{"VBZ"},
"enroute":	{"RB"},
"ensconce":	{"VB","VBP"},
"ensconced":	{"VBD","VBN"},
"ensconces":	{"VBZ"},
"ensconcing":	{"VBG"},
"ensemble":	{"NN","JJ"},
"ensembles":	{"NNS"},
"ensete":	{"NN"},
"enshrine":	{"VB","VBP"},
"enshrined":	{"VBD","VBN"},
"enshrines":	{"VBZ"},
"enshrining":	{"VBG"},
"enshroud":	{"VB","VBP"},
"enshrouded":	{"VBD","VBN"},
"enshrouding":	{"VBG"},
"enshrouds":	{"VBZ"},
"ensiform":	{"JJ"},
"ensign":	{"NN"},
"ensigns":	{"NNS"},
"ensilability":	{"NN"},
"ensilage":	{"NN"},
"ensile":	{"VB","VBP"},
"ensiled":	{"VBD","VBN"},
"ensiles":	{"VBZ"},
"ensiling":	{"VBG"},
"ensis":	{"NN"},
"enskied":	{"VBD","VBN"},
"enskies":	{"VBZ"},
"ensky":	{"VB","VBP"},
"enskying":	{"VBG"},
"enslave":	{"VB","VBP"},
"enslaved":	{"VBD","VBN"},
"enslavement":	{"NN"},
"enslaves":	{"VBZ"},
"enslaving":	{"VBG"},
"ensnare":	{"VB","VBP"},
"ensnared":	{"VBD","VBN"},
"ensnares":	{"VBZ"},
"ensnaring":	{"VBG"},
"ensnarl":	{"VB","VBP"},
"ensnarled":	{"VBD","VBN"},
"ensnarling":	{"VBG"},
"ensnarls":	{"VBZ"},
"ensolite":	{"NN"},
"ensorcelled":	{"JJ"},
"ensuant":	{"JJ"},
"ensue":	{"VB","VBP"},
"ensued":	{"VBD","VBN"},
"ensues":	{"VBZ"},
"ensuing":	{"JJ","VBG"},
"ensure":	{"VB","VBP"},
"ensured":	{"VBD","VBN"},
"ensures":	{"VBZ"},
"ensuring":	{"VBG"},
"entablature":	{"NN"},
"entail":	{"VB","NN","VBP"},
"entailed":	{"VBD","VBN"},
"entailing":	{"VBG"},
"entailment":	{"NN"},
"entails":	{"VBZ","NNS"},
"entandrophragma":	{"NN"},
"entangle":	{"VB","VBP"},
"entangled":	{"VBD","VBN","JJ"},
"entanglement":	{"NN"},
"entanglements":	{"NNS"},
"entangles":	{"VBZ"},
"entangling":	{"VBG"},
"entasis":	{"NN"},
"entelea":	{"NN"},
"entelechy":	{"NN"},
"entellus":	{"NNS"},
"entente":	{"NN"},
"ententes":	{"NNS"},
"enter":	{"VB","VBP"},
"enteral":	{"JJ"},
"entered":	{"VBD","VBN"},
"enteric":	{"JJ"},
"enterics":	{"NN"},
"entering":	{"VBG"},
"enteritis":	{"NN"},
"enterobacteria":	{"NN"},
"enterobacteriaceae":	{"NN"},
"enterobiasis":	{"NN"},
"enterobius":	{"NNS"},
"enteroceptor":	{"NN"},
"enterokinase":	{"NN"},
"enterolith":	{"NN"},
"enterolithiasis":	{"NN"},
"enterolobium":	{"NN"},
"enteron":	{"NN"},
"enteropathy":	{"NN"},
"enteroptosis":	{"NN"},
"enterostenosis":	{"NN"},
"enterostomy":	{"NN"},
"enterotomy":	{"NN"},
"enterotoxemia":	{"NN"},
"enterotoxin":	{"NN"},
"enterovirus":	{"NN"},
"enterprise":	{"NN"},
"enterpriser":	{"NN"},
"enterprises":	{"NNS"},
"enterprising":	{"JJ"},
"enterprisingly":	{"RB"},
"enterprisingness":	{"NN"},
"enters":	{"VBZ"},
"entertain":	{"VB","VBP"},
"entertained":	{"VBD","VBN"},
"entertainer":	{"NN"},
"entertainers":	{"NNS"},
"entertaining":	{"JJ","NN","VBG"},
"entertainingly":	{"RB"},
"entertainment":	{"NN"},
"entertainment-industry":	{"NN"},
"entertainment-law":	{"NN"},
"entertainments":	{"NNS"},
"entertains":	{"VBZ"},
"enthalpy":	{"NN"},
"enthral":	{"VB","VBP"},
"enthrall":	{"VB","VBP"},
"enthralled":	{"JJ","VBD","VBN"},
"enthralling":	{"JJ","VBG"},
"enthrallingly":	{"RB"},
"enthrallment":	{"NN"},
"enthralls":	{"VBZ"},
"enthrals":	{"VBZ"},
"enthrone":	{"VB","VBP"},
"enthroned":	{"VBD","VBN"},
"enthronement":	{"NN"},
"enthronements":	{"NNS"},
"enthrones":	{"VBZ"},
"enthroning":	{"VBG"},
"enthronisation":	{"NN"},
"enthronization":	{"NN"},
"enthuse":	{"VB","VBP"},
"enthused":	{"VBD","VBN"},
"enthuses":	{"VBZ"},
"enthusiam":	{"NN"},
"enthusiasm":	{"NN"},
"enthusiasms":	{"NNS"},
"enthusiast":	{"NN"},
"enthusiastic":	{"JJ"},
"enthusiastically":	{"RB"},
"enthusiasts":	{"NNS"},
"enthusing":	{"VBG"},
"entice":	{"VB","VBP"},
"enticed":	{"VBD","VBN"},
"enticement":	{"NN"},
"enticements":	{"NNS"},
"entices":	{"VBZ"},
"enticing":	{"JJ","VBG"},
"enticingly":	{"RB"},
"entire":	{"JJ"},
"entirely":	{"RB"},
"entireness":	{"NN"},
"entirety":	{"NN"},
"entitative":	{"JJ"},
"entities":	{"NNS"},
"entitle":	{"VB","VBP"},
"entitled":	{"VBN","VBD"},
"entitlement":	{"NN"},
"entitlements":	{"NNS"},
"entitles":	{"VBZ"},
"entitling":	{"VBG"},
"entity":	{"NN"},
"entlebucher":	{"NN"},
"entoblast":	{"NN"},
"entoderm":	{"NN"},
"entoloma":	{"NN"},
"entolomataceae":	{"NN"},
"entomb":	{"VB","VBP"},
"entombed":	{"VBD","VBN"},
"entombing":	{"VBG"},
"entombment":	{"NN"},
"entombs":	{"VBZ"},
"entomion":	{"NN"},
"entomologic":	{"JJ"},
"entomological":	{"JJ"},
"entomologist":	{"NN"},
"entomologists":	{"NNS"},
"entomology":	{"NN"},
"entomophilous":	{"JJ"},
"entomophobia":	{"NN"},
"entomophthora":	{"NN"},
"entomophthoraceae":	{"NN"},
"entomophthorales":	{"NNS"},
"entomostraca":	{"NN"},
"entoparasite":	{"NN"},
"entoproct":	{"NN"},
"entoprocta":	{"NN"},
"entourage":	{"NN"},
"entourages":	{"NNS"},
"entozoan":	{"JJ","NN"},
"entozoic":	{"JJ"},
"entozoon":	{"NN"},
"entr'acte":	{"NN"},
"entractes":	{"NNS"},
"entrails":	{"NNS"},
"entrain":	{"VB","VBP"},
"entrained":	{"VBD","VBN"},
"entraining":	{"VBG"},
"entrains":	{"VBZ"},
"entrance":	{"NN","VBP","VB"},
"entranced":	{"JJ","VBD","VBN"},
"entrancement":	{"NN"},
"entrances":	{"NNS","VBZ"},
"entranceway":	{"NN"},
"entrancing":	{"JJ","VBG"},
"entrant":	{"NN"},
"entrants":	{"NNS"},
"entrap":	{"VB","VBP"},
"entrapment":	{"NN"},
"entrapped":	{"VBD","VBN"},
"entrapping":	{"VBG"},
"entraps":	{"VBZ"},
"entre":	{"NN"},
"entreat":	{"VB","VBP"},
"entreated":	{"VBD","VBN"},
"entreaties":	{"NNS"},
"entreating":	{"VBG"},
"entreatingly":	{"RB"},
"entreats":	{"VBZ"},
"entreaty":	{"NN"},
"entrecote":	{"NN"},
"entree":	{"NN"},
"entrees":	{"NNS"},
"entremets":	{"NNS"},
"entrench":	{"VB","VBP"},
"entrenched":	{"JJ","VBD","VBN"},
"entrenches":	{"VBZ"},
"entrenching":	{"VBG"},
"entrenchment":	{"NN"},
"entrenchments":	{"NNS"},
"entrepot":	{"NN"},
"entreprenant":	{"JJ"},
"entrepreneur":	{"NN","VB","VBP"},
"entrepreneured":	{"VBD","VBN"},
"entrepreneurial":	{"JJ"},
"entrepreneurialism":	{"NN"},
"entrepreneurially":	{"RB"},
"entrepreneuring":	{"VBG"},
"entrepreneurism":	{"NN"},
"entrepreneurs":	{"NNS","VBZ"},
"entrepreneurship":	{"NN"},
"entresol":	{"NN"},
"entric":	{"NN"},
"entries":	{"NNS"},
"entropy":	{"NN"},
"entropy-increasing":	{"JJ"},
"entrust":	{"VB","VBP"},
"entrusted":	{"VBD","VBN"},
"entrusting":	{"VBG"},
"entrusts":	{"VBZ"},
"entry":	{"NN"},
"entry-level":	{"JJ"},
"entry-limit":	{"JJ"},
"entry-limited":	{"JJ"},
"entry-limiting":	{"JJ"},
"entry-price":	{"JJ"},
"entryway":	{"NN"},
"entryways":	{"NNS"},
"entsi":	{"NN"},
"entsy":	{"NN"},
"entwine":	{"VB","VBP"},
"entwined":	{"VBD","VBN"},
"entwines":	{"VBZ"},
"entwining":	{"VBG"},
"enucleate":	{"VB","VBP","JJ"},
"enucleated":	{"VBD","VBN"},
"enucleates":	{"VBZ"},
"enucleating":	{"VBG"},
"enucleation":	{"NN"},
"enuki":	{"NN"},
"enumerable":	{"JJ"},
"enumerate":	{"VB","VBP"},
"enumerated":	{"VBD","VBN"},
"enumerates":	{"VBZ"},
"enumerating":	{"VBG"},
"enumeration":	{"NN"},
"enumerator":	{"NN"},
"enunciate":	{"VB","VBP"},
"enunciated":	{"VBD","VBN"},
"enunciates":	{"VBZ"},
"enunciating":	{"VBG"},
"enunciation":	{"NN"},
"enure":	{"VB","VBP"},
"enured":	{"VBD","VBN"},
"enures":	{"VBZ"},
"enuresis":	{"NN"},
"enuring":	{"VBG"},
"envelop":	{"VB","VBP"},
"envelope":	{"NN"},
"enveloped":	{"VBN","VBD"},
"envelopes":	{"NNS"},
"enveloping":	{"VBG","NN"},
"envelopment":	{"NN"},
"envelops":	{"VBZ"},
"envenom":	{"VB","VBP"},
"envenomed":	{"VBD","VBN"},
"envenoming":	{"VBG"},
"envenoms":	{"VBZ"},
"enviable":	{"JJ"},
"enviably":	{"RB"},
"envied":	{"VBD","VBN"},
"envies":	{"VBZ"},
"envious":	{"JJ"},
"enviously":	{"RB"},
"enviousness":	{"NN"},
"environ":	{"VB","VBP"},
"environed":	{"VBD","VBN"},
"environing":	{"VBG"},
"environment":	{"NN"},
"environmental":	{"JJ"},
"environmental-impact":	{"JJ"},
"environmental-services":	{"NNS"},
"environmentalism":	{"NN"},
"environmentalist":	{"NN"},
"environmentalist-actor":	{"NN"},
"environmentalist-developer":	{"JJ"},
"environmentalists":	{"NNS"},
"environmentally":	{"RB"},
"environments":	{"NNS"},
"environs":	{"VBZ","NNS"},
"envisage":	{"VB","VBP"},
"envisaged":	{"VBD","VBN"},
"envisages":	{"VBZ"},
"envisaging":	{"VBG"},
"envision":	{"VB","VBP"},
"envisioned":	{"VBD","VBN"},
"envisioning":	{"VBG"},
"envisions":	{"VBZ"},
"envoi":	{"NN"},
"envoy":	{"NN"},
"envoys":	{"NNS"},
"envy":	{"NN","VB","VBP"},
"envy-quotient":	{"NN"},
"envying":	{"VBG"},
"enwrap":	{"VB","VBP"},
"enwrapped":	{"VBD","VBN"},
"enwrapping":	{"VBG"},
"enwraps":	{"VBZ"},
"enzootic":	{"JJ"},
"enzymatic":	{"JJ"},
"enzyme":	{"NN"},
"enzyme-like":	{"JJ"},
"enzymes":	{"NNS"},
"enzymologist":	{"NN"},
"enzymology":	{"NN"},
"eohippus":	{"NNS"},
"eolian":	{"NN"},
"eolic":	{"NN"},
"eolith":	{"NN"},
"eolithic":	{"JJ","NN"},
"eolotropic":	{"JJ"},
"eon":	{"NN"},
"eonian":	{"JJ"},
"eons":	{"NNS"},
"eoraptor":	{"NN"},
"eos":	{"NN"},
"eosin":	{"NN"},
"eosinopenia":	{"NN"},
"eosinophil":	{"NN"},
"eosinophile":	{"NN"},
"eosinophilia":	{"NN"},
"eosinophilic":	{"JJ"},
"epa":	{"NN"},
"epacridaceae":	{"NN"},
"epacris":	{"NNS"},
"epanalepsis":	{"NN"},
"epanaphora":	{"NN"},
"epanodos":	{"NN"},
"epanorthosis":	{"NN"},
"eparch":	{"NN"},
"eparchial":	{"JJ"},
"eparchy":	{"NN"},
"epaulet":	{"NN"},
"epaulets":	{"NNS"},
"epaulette":	{"NN"},
"epaulettes":	{"NNS"},
"epauliere":	{"NN"},
"epee":	{"NN"},
"epees":	{"NNS"},
"ependyma":	{"NN"},
"epenthesis":	{"NN"},
"epenthetic":	{"JJ"},
"epergne":	{"NN"},
"epha":	{"NN"},
"ephah":	{"NN"},
"ephedra":	{"NN"},
"ephedraceae":	{"NN"},
"ephedrine":	{"NN"},
"ephemera":	{"NN"},
"ephemeral":	{"JJ","NN"},
"ephemerality":	{"NN"},
"ephemeralness":	{"NN"},
"ephemerid":	{"NN"},
"ephemerida":	{"NN"},
"ephemeridae":	{"NN"},
"ephemeris":	{"NN"},
"ephemeron":	{"NN"},
"ephemeroptera":	{"NN"},
"ephemeropteran":	{"NN"},
"ephesian":	{"JJ","NN"},
"ephesians":	{"NNS"},
"ephestia":	{"NN"},
"ephesus":	{"NNS"},
"ephippidae":	{"NN"},
"ephippiorhynchus":	{"NNS"},
"epi":	{"NN"},
"epic":	{"NN","JJ"},
"epical":	{"JJ"},
"epicalyx":	{"NN"},
"epicanthus":	{"NN"},
"epicardia":	{"NN"},
"epicardium":	{"NN"},
"epicarp":	{"NN"},
"epicarpal":	{"JJ"},
"epicene":	{"JJ"},
"epicenter":	{"NN"},
"epicentre":	{"NN"},
"epicentres":	{"NNS"},
"epicondyle":	{"NN"},
"epicondylitis":	{"NNS"},
"epicranium":	{"NN"},
"epics":	{"NNS"},
"epictetus":	{"NNS"},
"epicure":	{"NN"},
"epicurean":	{"JJ","NN"},
"epicureanism":	{"JJ","NN"},
"epicures":	{"NNS"},
"epicurism":	{"NN"},
"epicurus":	{"NN"},
"epicycle":	{"NN"},
"epicycles":	{"NNS"},
"epicyclic":	{"JJ"},
"epicyclical":	{"JJ"},
"epicyclically":	{"RB"},
"epicycloid":	{"NN"},
"epideictic":	{"JJ"},
"epideictical":	{"JJ"},
"epidemic":	{"NN","JJ"},
"epidemics":	{"NNS"},
"epidemiologic":	{"JJ"},
"epidemiological":	{"JJ"},
"epidemiologist":	{"NN"},
"epidemiologists":	{"NNS"},
"epidemiology":	{"NN"},
"epidendron":	{"NN"},
"epidendrum":	{"NN"},
"epidermal":	{"JJ"},
"epidermic":	{"JJ"},
"epidermidis":	{"NN"},
"epidermis":	{"NN"},
"epidiascope":	{"NN"},
"epididymis":	{"NN"},
"epididymitis":	{"NN"},
"epidural":	{"JJ","NN"},
"epidurals":	{"NNS"},
"epigaea":	{"NN"},
"epigastric":	{"JJ"},
"epigastrium":	{"NN"},
"epigenesis":	{"NN"},
"epigenetic":	{"JJ"},
"epiglottal":	{"JJ"},
"epiglottis":	{"NN"},
"epiglottitis":	{"NNS"},
"epigon":	{"NN"},
"epigone":	{"NN"},
"epigram":	{"NN"},
"epigrammatic":	{"JJ"},
"epigrams":	{"NNS"},
"epigraph":	{"NN"},
"epigraphy":	{"NN"},
"epikeratophakia":	{"NN"},
"epilachna":	{"NN"},
"epilate":	{"VB","VBP"},
"epilated":	{"VBD","VBN"},
"epilates":	{"VBZ"},
"epilating":	{"VBG"},
"epilation":	{"NN"},
"epilator":	{"NN"},
"epilepsy":	{"NN"},
"epileptic":	{"NN","JJ"},
"epileptics":	{"NNS"},
"epilithic":	{"JJ"},
"epilobium":	{"NN"},
"epilog":	{"NN"},
"epilogue":	{"NN"},
"epilogues":	{"NNS"},
"epimedium":	{"NN"},
"epimetheus":	{"NN"},
"epimorphic":	{"JJ"},
"epinephelus":	{"NN"},
"epinephrin":	{"NN"},
"epinephrine":	{"NN"},
"epipactis":	{"NN"},
"epipaleolithic":	{"NN"},
"epiphenomenon":	{"NN"},
"epiphora":	{"NN"},
"epiphyllum":	{"NN"},
"epiphyseal":	{"JJ"},
"epiphyseal-diaphyseal":	{"JJ"},
"epiphysial":	{"JJ"},
"epiphysis":	{"NN"},
"epiphyte":	{"NN"},
"epiphytic":	{"JJ"},
"epiphytotic":	{"JJ"},
"epiplexis":	{"NN"},
"epipremnum":	{"NN"},
"epirus":	{"NN"},
"episcia":	{"NN"},
"episcleritis":	{"NN"},
"episcopacy":	{"NN"},
"episcopal":	{"JJ"},
"episcopalianism":	{"NN"},
"episcopate":	{"NN"},
"episiotomy":	{"NN"},
"episode":	{"NN"},
"episodes":	{"NNS"},
"episodic":	{"JJ"},
"episodically":	{"RB"},
"episome":	{"NN"},
"epispadias":	{"NNS"},
"episperm":	{"NN"},
"epistasis":	{"NN"},
"epistaxis":	{"NN"},
"episteme":	{"NN"},
"epistemic":	{"JJ"},
"epistemological":	{"JJ"},
"epistemologist":	{"NN"},
"epistemology":	{"NN"},
"epistle":	{"NN"},
"epistolary":	{"JJ"},
"epistolatory":	{"JJ"},
"epistrophe":	{"NN"},
"epitaph":	{"NN"},
"epitaphs":	{"NNS"},
"epitaxy":	{"NN"},
"epithalamium":	{"NN"},
"epithelial":	{"JJ"},
"epitheliod":	{"JJ"},
"epithelioma":	{"NN"},
"epithelium":	{"NN"},
"epithet":	{"NN"},
"epithets":	{"NNS"},
"epitome":	{"NN"},
"epitomise":	{"VB","VBP"},
"epitomised":	{"VBD","VBN"},
"epitomises":	{"VBZ"},
"epitomising":	{"VBG"},
"epitomize":	{"VB","VBP"},
"epitomized":	{"VBD","VBN"},
"epitomizes":	{"VBZ"},
"epitomizing":	{"VBG"},
"epitope":	{"NN"},
"epizoan":	{"JJ","NN"},
"epizoic":	{"JJ"},
"epizoon":	{"NN"},
"epizootic":	{"JJ","NN"},
"epo-treated":	{"JJ"},
"epoch":	{"NN"},
"epoch-making":	{"JJ"},
"epochal":	{"JJ"},
"epochs":	{"NNS"},
"epona":	{"NN"},
"eponym":	{"NN"},
"eponymic":	{"JJ"},
"eponymous":	{"JJ"},
"eponymy":	{"NN"},
"epos":	{"NNS"},
"epoxy":	{"NN"},
"eprom":	{"NN"},
"epsilon":	{"NN"},
"epsiode":	{"NN"},
"eptatretus":	{"NNS"},
"eptesicus":	{"NNS"},
"eq":	{"NN"},
"eqn.":	{"NN"},
"eqns.":	{"NN"},
"equ":	{"NN"},
"equable":	{"JJ"},
"equably":	{"RB"},
"equal":	{"JJ","VB","VBP","NN"},
"equal-opportunity":	{"NN","JJ"},
"equaled":	{"VBD","VBN"},
"equaling":	{"VBG"},
"equalisation":	{"NN"},
"equalise":	{"VB","VBP"},
"equalised":	{"VBD","VBN"},
"equaliser":	{"NN"},
"equalisers":	{"NNS"},
"equalises":	{"VBZ"},
"equalising":	{"VBG"},
"equalitarian":	{"JJ","NN"},
"equalitarianism":	{"NN"},
"equality":	{"NN"},
"equalization":	{"NN"},
"equalize":	{"VB","VBP"},
"equalized":	{"VBD","VBN"},
"equalizer":	{"NN"},
"equalizers":	{"NNS"},
"equalizes":	{"VBZ"},
"equalizing":	{"VBG"},
"equalled":	{"VBD","VBN"},
"equalling":	{"VBG"},
"equally":	{"RB"},
"equals":	{"VBZ","NNS"},
"equanil":	{"NN"},
"equanimity":	{"NN"},
"equanimous":	{"JJ"},
"equatability":	{"NN"},
"equate":	{"VB","VBP"},
"equated":	{"VBD","VBN"},
"equates":	{"VBZ"},
"equating":	{"VBG"},
"equation":	{"NN"},
"equations":	{"NNS"},
"equator":	{"NN"},
"equatorial":	{"JJ","NN"},
"equerries":	{"NNS"},
"equerry":	{"NN"},
"equestrian":	{"NN","JJ"},
"equestrians":	{"NNS"},
"equetus":	{"NNS"},
"equiangular":	{"JJ"},
"equid":	{"NN"},
"equidae":	{"NN"},
"equidistant":	{"JJ"},
"equidistantly":	{"RB"},
"equidistribution":	{"NN"},
"equilateral":	{"JJ"},
"equilibrate":	{"VB","VBP"},
"equilibrated":	{"VBD","VBN"},
"equilibrates":	{"VBZ"},
"equilibrating":	{"VBG"},
"equilibration":	{"NN"},
"equilibria":	{"NNS"},
"equilibrise":	{"VB","VBP"},
"equilibrium":	{"NN"},
"equilibriums":	{"NNS"},
"equilibrize":	{"VB","VBP"},
"equiment":	{"NN"},
"equine":	{"JJ"},
"equinoctial":	{"JJ","NN"},
"equinox":	{"NN"},
"equinoxes":	{"NNS"},
"equip":	{"VB","VBP"},
"equipage":	{"NN"},
"equipment":	{"NN"},
"equipment-leasing":	{"JJ"},
"equipment-packed":	{"JJ"},
"equipmwent-leasing":	{"NN"},
"equipoise":	{"NN","VB","VBP"},
"equipoised":	{"VBD","VBN"},
"equipoises":	{"VBZ"},
"equipoising":	{"VBG"},
"equipotent":	{"JJ"},
"equipped":	{"VBN","VBD","JJ"},
"equipping":	{"VBG"},
"equiprobable":	{"JJ"},
"equips":	{"VBZ"},
"equipt":	{"JJ"},
"equisetaceae":	{"NN"},
"equisetales":	{"NNS"},
"equisetatae":	{"NN"},
"equisetum":	{"NN"},
"equitable":	{"JJ"},
"equitably":	{"RB"},
"equitation":	{"NN"},
"equities":	{"NNS"},
"equity":	{"NN"},
"equity-like":	{"JJ"},
"equity-purchase":	{"JJ","NN"},
"equity-to-asset":	{"NN"},
"equityholders":	{"NNS"},
"equivalence":	{"NN"},
"equivalent":	{"NN","JJ"},
"equivalent-choice":	{"JJ"},
"equivalents":	{"NNS"},
"equivocal":	{"JJ"},
"equivocally":	{"RB"},
"equivocalness":	{"NN"},
"equivocate":	{"VB","VBP"},
"equivocated":	{"VBD","VBN"},
"equivocates":	{"VBZ"},
"equivocating":	{"VBG"},
"equivocation":	{"NN"},
"equivocator":	{"NN"},
"equus":	{"NN"},
"er":	{"NN","UH"},
"era":	{"NN"},
"eradicable":	{"JJ"},
"eradicate":	{"VB","VBP"},
"eradicated":	{"VBD","VBN"},
"eradicates":	{"VBZ"},
"eradicating":	{"VBG"},
"eradication":	{"NN"},
"eradicator":	{"NN"},
"eragrostis":	{"NNS"},
"eranthis":	{"NNS"},
"eras":	{"NNS"},
"erasable":	{"JJ"},
"erase":	{"VB","VBP"},
"erased":	{"VBD","VBN"},
"eraser":	{"NN"},
"eraser-fitted":	{"JJ"},
"erasers":	{"NNS"},
"erases":	{"VBZ"},
"erasing":	{"VBG"},
"erasmian":	{"JJ"},
"erastianism":	{"NN"},
"erasure":	{"NN"},
"erasures":	{"NNS"},
"erath":	{"NN"},
"erato":	{"NN"},
"eratosthenes":	{"NNS"},
"erawhere":	{"NN"},
"erbium":	{"NN"},
"ercilla":	{"NN"},
"erdmann":	{"NN"},
"erdos":	{"NN"},
"ere":	{"IN","CC"},
"erect":	{"VB","VBP","JJ"},
"erected":	{"VBD","VBN"},
"erectile":	{"JJ"},
"erecting":	{"VBG"},
"erection":	{"NN"},
"erections":	{"NNS"},
"erectly":	{"RB"},
"erectness":	{"NN"},
"erects":	{"VBZ"},
"eremite":	{"NN"},
"eremitic":	{"JJ"},
"eremitical":	{"JJ"},
"eremitism":	{"NN"},
"eresh-kigal":	{"NN"},
"ereshkigal":	{"NN"},
"ereshkigel":	{"NN"},
"erethism":	{"NN"},
"erethizon":	{"NN"},
"erethizontidae":	{"NN"},
"eretmochelys":	{"NNS"},
"erg":	{"NN"},
"ergo":	{"RB"},
"ergocalciferol":	{"NN"},
"ergodic":	{"JJ"},
"ergodicity":	{"NN"},
"ergometer":	{"NN"},
"ergonomic":	{"JJ"},
"ergonomically":	{"RB"},
"ergonomics":	{"NN"},
"ergonomist":	{"NN"},
"ergonomists":	{"NNS"},
"ergonovine":	{"NN"},
"ergosterol":	{"NN"},
"ergot":	{"NN"},
"ergotamine":	{"NN"},
"ergotic":	{"JJ"},
"ergotism":	{"NN"},
"ergotropic":	{"JJ"},
"ergotropism":	{"NN"},
"erianthus":	{"NNS"},
"erica":	{"NN"},
"ericaceae":	{"NN"},
"ericales":	{"NNS"},
"eridanus":	{"NN"},
"erigeron":	{"NN"},
"erignathus":	{"NNS"},
"erinaceidae":	{"NN"},
"erinaceus":	{"NNS"},
"eringo":	{"NN"},
"erinyes":	{"NNS"},
"eriobotrya":	{"NN"},
"eriocaulaceae":	{"NN"},
"eriocaulon":	{"NN"},
"eriodictyon":	{"NN"},
"eriogonum":	{"NN"},
"eriophorum":	{"NN"},
"eriophyllum":	{"NN"},
"eriosoma":	{"NN"},
"eris":	{"NNS"},
"eristic":	{"JJ","NN"},
"eristical":	{"JJ"},
"erithacus":	{"NNS"},
"erithmatic":	{"NN"},
"eritrean":	{"JJ","NN"},
"erivan":	{"NN"},
"erlang":	{"NN"},
"erlenmeyer":	{"NN"},
"ermine":	{"NN","NNS"},
"ermines":	{"NNS"},
"ern":	{"NN"},
"erne":	{"NN"},
"erode":	{"VB","VBP"},
"eroded":	{"JJ","VBD","VBN"},
"erodes":	{"VBZ"},
"eroding":	{"VBG"},
"erodium":	{"NN"},
"erogenous":	{"JJ"},
"erolia":	{"NN"},
"eromonga":	{"FW"},
"erose":	{"JJ"},
"erosion":	{"NN"},
"erosive":	{"JJ"},
"erotic":	{"JJ"},
"erotica":	{"NN"},
"erotically":	{"RB"},
"eroticisation":	{"NN"},
"eroticise":	{"VB","VBP"},
"eroticised":	{"VBD","VBN"},
"eroticises":	{"VBZ"},
"eroticising":	{"VBG"},
"eroticism":	{"NN"},
"eroticization":	{"NN"},
"eroticize":	{"VB","VBP"},
"eroticized":	{"VBD","VBN"},
"eroticizes":	{"VBZ"},
"eroticizing":	{"VBG"},
"erotism":	{"NN"},
"err":	{"VB","VBP"},
"errancy":	{"NN"},
"errand":	{"NN"},
"errands":	{"NNS"},
"errant":	{"JJ"},
"errata":	{"NNS"},
"erratic":	{"JJ"},
"erratically":	{"RB"},
"erratum":	{"NN"},
"erred":	{"VBD","VBN"},
"errhine":	{"JJ","NN"},
"erring":	{"VBG"},
"errol":	{"NN"},
"erroneous":	{"JJ"},
"erroneously":	{"RB"},
"erroneousness":	{"NN"},
"error":	{"NN"},
"error-free":	{"JJ"},
"error-laden":	{"JJ"},
"error-prone":	{"JJ","NN"},
"errorless":	{"JJ"},
"errors":	{"NNS"},
"errs":	{"VBZ"},
"ersatz":	{"JJ"},
"erst":	{"RB"},
"erstwhile":	{"JJ"},
"ert":	{"NN"},
"eruca":	{"NN"},
"eruct":	{"VB","VBP"},
"eructation":	{"NN"},
"eructed":	{"VBD","VBN"},
"eructing":	{"VBG"},
"eructs":	{"VBZ"},
"erudite":	{"JJ"},
"eruditely":	{"RB"},
"eruditeness":	{"NN"},
"erudition":	{"NN"},
"erupt":	{"VB","VBP"},
"erupted":	{"VBD","VBN"},
"erupting":	{"VBG"},
"eruption":	{"NN"},
"eruptions":	{"NNS","VBG"},
"eruptive":	{"JJ"},
"erupts":	{"VBZ"},
"ervin":	{"NN"},
"erving":	{"NN"},
"erwinia":	{"NN"},
"eryngium":	{"NN"},
"eryngo":	{"NN"},
"erysimum":	{"NN"},
"erysipelas":	{"NN"},
"erysiphaceae":	{"NN"},
"erysiphales":	{"NNS"},
"erysiphe":	{"NN"},
"erythema":	{"NN"},
"erythematous":	{"JJ"},
"erythrina":	{"NN"},
"erythrite":	{"NN"},
"erythroblast":	{"NN"},
"erythroblastosis":	{"NN"},
"erythrocebus":	{"NNS"},
"erythrocin":	{"NN"},
"erythrocyte":	{"NN"},
"erythrocytolysin":	{"NN"},
"erythroderma":	{"NN"},
"erythroid":	{"JJ","NN"},
"erythrolysin":	{"NN"},
"erythromycin":	{"NN"},
"erythronium":	{"NN"},
"erythropoiesis":	{"NN"},
"erythropoietic":	{"JJ"},
"erythropoietin":	{"NN"},
"erythroxylaceae":	{"NN"},
"erythroxylon":	{"NN"},
"erythroxylum":	{"NN"},
"esaki":	{"NN"},
"escadrille":	{"NN"},
"escalade":	{"VB","VBP","NN"},
"escaladed":	{"VBD","VBN"},
"escalader":	{"NN"},
"escalades":	{"VBZ"},
"escalading":	{"VBG"},
"escalate":	{"VB","VBP"},
"escalated":	{"VBD","VBN"},
"escalates":	{"VBZ"},
"escalating":	{"VBG"},
"escalation":	{"NN"},
"escalator":	{"NN"},
"escalators":	{"NNS"},
"escallop":	{"NN","VB","VBP"},
"escapade":	{"NN"},
"escapades":	{"NNS"},
"escape":	{"VB","NN","VBP"},
"escaped":	{"VBD","VBN","JJ"},
"escapee":	{"NN"},
"escapees":	{"NNS"},
"escapement":	{"NN"},
"escapes":	{"VBZ","NNS"},
"escaping":	{"VBG"},
"escapism":	{"NN"},
"escapist":	{"NN","JJ"},
"escapologist":	{"NN"},
"escapology":	{"NN"},
"escargot":	{"NN"},
"escarole":	{"NN"},
"escarp":	{"NN"},
"escarpment":	{"NN"},
"escarpments":	{"NNS"},
"eschalot":	{"NN"},
"eschar":	{"NN"},
"eschatological":	{"JJ"},
"eschatologically":	{"RB"},
"eschatologist":	{"NN"},
"eschatology":	{"NN"},
"eschaton":	{"NN"},
"escheat":	{"NN"},
"escheats":	{"NNS"},
"escherichia":	{"NN"},
"eschew":	{"VB","VBP"},
"eschewed":	{"VBD","VBN"},
"eschewing":	{"VBG"},
"eschews":	{"VBZ"},
"eschrichtiidae":	{"NN"},
"eschrichtius":	{"NNS"},
"eschscholtzia":	{"NN"},
"escolar":	{"NN"},
"escort":	{"NN","VB","VBP"},
"escorted":	{"VBD","VBN"},
"escorting":	{"VBG"},
"escorts":	{"VBZ","NNS"},
"escritoire":	{"NN"},
"escritoires":	{"NNS"},
"escrow":	{"NN","VB","VBP"},
"escrowed":	{"VBD","VBN"},
"escrowing":	{"VBG"},
"escrows":	{"VBZ"},
"escudo":	{"NN"},
"escudos":	{"NNS"},
"escutcheon":	{"NN"},
"escutcheons":	{"NNS"},
"ese":	{"NN"},
"esfahan":	{"NN"},
"esidrix":	{"NN"},
"eskalith":	{"NN"},
"esker":	{"NN"},
"eskimo-aleut":	{"NN"},
"esm":	{"NN"},
"esmolol":	{"NN"},
"esn":	{"NN"},
"esocidae":	{"NN"},
"esop":	{"NN"},
"esophageal":	{"JJ"},
"esophagi":	{"NNS"},
"esophagitis":	{"NN"},
"esophagoscope":	{"NN"},
"esophagus":	{"NN"},
"esophaguses":	{"NNS"},
"esoteric":	{"JJ"},
"esoterica":	{"NN"},
"esotropia":	{"NN"},
"esox":	{"NN"},
"esp":	{"NN"},
"espadrille":	{"NN"},
"espadrilles":	{"NNS"},
"espagnole":	{"NN"},
"espalier":	{"NN","VB","VBP"},
"espaliered":	{"VBD","VBN"},
"espaliering":	{"VBG"},
"espaliers":	{"NNS","VBZ"},
"espana":	{"NN"},
"espanol":	{"NN"},
"esparcet":	{"NN"},
"especial":	{"JJ"},
"especially":	{"RB"},
"esperantido":	{"NN"},
"espial":	{"NN"},
"espied":	{"VBD","VBN"},
"espies":	{"VBZ"},
"espionage":	{"NN"},
"esplanade":	{"NN"},
"esplanades":	{"NNS"},
"espoo":	{"NN"},
"espousal":	{"NN"},
"espouse":	{"VB","VBP"},
"espoused":	{"VBD","VBN"},
"espouses":	{"VBZ"},
"espousing":	{"VBG"},
"espresso":	{"NN"},
"espressos":	{"NNS"},
"esprit":	{"NN"},
"espy":	{"VB","VBP"},
"espying":	{"VBG"},
"esq":	{"NN"},
"esquimau":	{"NN"},
"esquire":	{"NN"},
"esr":	{"NN"},
"essay":	{"NN","VBP","VB"},
"essayed":	{"VBD","VBN"},
"essayer":	{"NN"},
"essaying":	{"VBG"},
"essayish":	{"JJ"},
"essayist":	{"NN"},
"essayists":	{"NNS"},
"essays":	{"NNS","VBZ"},
"esse":	{"NN"},
"esselen":	{"NN"},
"essence":	{"NN"},
"essences":	{"NNS"},
"essene":	{"JJ","NN"},
"essential":	{"JJ","NN"},
"essentiality":	{"NN"},
"essentially":	{"RB"},
"essentialness":	{"NN"},
"essentials":	{"NNS"},
"essonite":	{"NN"},
"est":	{"VBD","VBN"},
"esta":	{"NN"},
"establish":	{"VB","VBP"},
"established":	{"VBN","VBD","JJ"},
"establishes":	{"VBZ"},
"establishing":	{"VBG"},
"establishment":	{"NN"},
"establishmentarianism":	{"NN"},
"establishmentism":	{"NN"},
"establishments":	{"NNS"},
"estaminet":	{"NN"},
"estancia":	{"NN"},
"estancias":	{"NNS"},
"estanciero":	{"NN"},
"estancieros":	{"NNS"},
"estate":	{"NN"},
"estate-freeze":	{"JJ"},
"estate-tax":	{"JJ","NN"},
"estates":	{"NNS"},
"estazolam":	{"NN"},
"esteem":	{"VB","VBP","NN"},
"esteemed":	{"JJ","VBD","VBN"},
"esteeming":	{"VBG"},
"esteems":	{"VBZ"},
"ester":	{"NN"},
"esterases":	{"NNS"},
"esterify":	{"VB","VBP"},
"esters":	{"NNS"},
"esthesia":	{"NN"},
"esthesis":	{"NN"},
"esthete":	{"NN"},
"esthetic":	{"JJ","NN"},
"esthetical":	{"JJ"},
"esthetically":	{"RB"},
"esthetician":	{"NN"},
"esthetics":	{"NN","NNS"},
"estimable":	{"JJ"},
"estimate":	{"NN","VBP","VB"},
"estimated":	{"VBN","JJ","VBD"},
"estimates":	{"NNS","VBZ"},
"estimating":	{"VBG"},
"estimation":	{"NN"},
"estimations":	{"NNS"},
"estimator":	{"NN"},
"estimators":	{"NNS"},
"estival":	{"JJ"},
"estivate":	{"VB","VBP"},
"estivated":	{"VBD","VBN"},
"estivates":	{"VBZ"},
"estivating":	{"VBG"},
"estivation":	{"NN"},
"estonian-language":	{"JJ"},
"estoppel":	{"NN"},
"estradiol":	{"NN"},
"estragole":	{"NN"},
"estragon":	{"NN"},
"estrange":	{"VB","VBP"},
"estranged":	{"JJ","VBD","VBN"},
"estrangement":	{"NN"},
"estrangements":	{"NNS"},
"estranges":	{"VBZ"},
"estranging":	{"VBG"},
"estrilda":	{"NN"},
"estriol":	{"NN"},
"estrogen":	{"NN"},
"estrogen-replacement":	{"NN"},
"estrogenic":	{"JJ"},
"estrone":	{"NN"},
"estronol":	{"NN"},
"estrous":	{"JJ"},
"estrus":	{"NN"},
"estuarial":	{"JJ"},
"estuarian":	{"NN"},
"estuaries":	{"NNS"},
"estuarine":	{"JJ","NN"},
"estuary":	{"NN"},
"esurience":	{"NN"},
"esurient":	{"JJ"},
"et":	{"FW"},
"eta":	{"NN"},
"etagere":	{"NN"},
"etamin":	{"NN"},
"etamine":	{"NN"},
"etanercept":	{"NN"},
"etc":	{"RB"},
"etc.":	{"RB"},
"etcetera":	{"RB"},
"etch":	{"VB","VBP"},
"etched":	{"VBD","VBN"},
"etcher":	{"NN"},
"etches":	{"VBZ"},
"etching":	{"NN","VBG"},
"etchings":	{"NNS"},
"etd":	{"NN"},
"eternal":	{"JJ"},
"eternalisation":	{"NN"},
"eternalise":	{"VB","VBP"},
"eternalised":	{"VBD","VBN"},
"eternalises":	{"VBZ"},
"eternalising":	{"VBG"},
"eternalization":	{"NN"},
"eternalize":	{"VB","VBP"},
"eternalized":	{"VBD","VBN"},
"eternalizes":	{"VBZ"},
"eternalizing":	{"VBG"},
"eternally":	{"RB"},
"eternise":	{"VB","VBP"},
"eternity":	{"NN"},
"eternize":	{"VB","VBP"},
"etes":	{"FW"},
"etf":	{"NN"},
"ethanal":	{"NN"},
"ethanamide":	{"NN"},
"ethane":	{"NN"},
"ethanediol":	{"NN"},
"ethanoate":	{"NN"},
"ethanol":	{"NN"},
"ethanol-based":	{"JJ"},
"ethanol-powered":	{"JJ"},
"ethchlorvynol":	{"NN"},
"ethelbert":	{"NN"},
"ethelred":	{"NN"},
"ethene":	{"NN"},
"ether":	{"NN"},
"ethereal":	{"JJ"},
"etherealisation":	{"NN"},
"etherealise":	{"VB","VBP"},
"etherealised":	{"VBD","VBN"},
"etherealises":	{"VBZ"},
"etherealising":	{"VBG"},
"etherealization":	{"NN"},
"etherealize":	{"VB","VBP"},
"etherealized":	{"VBD","VBN"},
"etherealizes":	{"VBZ"},
"etherealizing":	{"VBG"},
"ethereally":	{"RB"},
"etherification":	{"NN"},
"etherified":	{"VBD","VBN"},
"etherifies":	{"VBZ"},
"etherify":	{"VB","VBP"},
"etherifying":	{"VBG"},
"etherise":	{"VB","VBP"},
"etherize":	{"VB","VBP"},
"ethic":	{"NN"},
"ethical":	{"JJ"},
"ethically":	{"RB"},
"ethician":	{"NN"},
"ethicism":	{"NN"},
"ethicist":	{"NN"},
"ethicists":	{"NNS"},
"ethics":	{"NN","NNS"},
"ethics-related":	{"JJ"},
"ethmoid":	{"JJ","NN"},
"ethnarch":	{"NN"},
"ethnic":	{"JJ","NN"},
"ethnical":	{"JJ"},
"ethnically":	{"RB"},
"ethnicities":	{"NNS"},
"ethnicity":	{"NN"},
"ethnics":	{"NNS"},
"ethnocentric":	{"JJ"},
"ethnocentricity":	{"NN"},
"ethnocentrism":	{"NN"},
"ethnographer":	{"NN"},
"ethnographers":	{"NNS"},
"ethnographic":	{"JJ"},
"ethnographical":	{"JJ"},
"ethnographically":	{"RB"},
"ethnography":	{"NN"},
"ethnologic":	{"JJ"},
"ethnological":	{"JJ"},
"ethnologist":	{"NN"},
"ethnologists":	{"NNS"},
"ethnology":	{"NN"},
"ethnos":	{"NN"},
"ethnoses":	{"NNS"},
"ethocaine":	{"NN"},
"ethologist":	{"NN"},
"ethology":	{"NN"},
"ethos":	{"NN"},
"ethosuximide":	{"NN"},
"ethoxyethane":	{"NN"},
"ethrane":	{"NN"},
"ethril":	{"NN"},
"ethyl":	{"NN"},
"ethylene":	{"NN"},
"ethyne":	{"NN"},
"etiolate":	{"VB","VBP"},
"etiolated":	{"JJ","VBD","VBN"},
"etiolates":	{"VBZ"},
"etiolating":	{"VBG"},
"etiolation":	{"NN"},
"etiologic":	{"JJ"},
"etiological":	{"JJ"},
"etiologically":	{"RB"},
"etiologies":	{"NNS"},
"etiologist":	{"NN"},
"etiology":	{"NN"},
"etiquette":	{"NN"},
"etodolac":	{"NN"},
"etropus":	{"NNS"},
"etude":	{"NN"},
"etui":	{"NN"},
"etymological":	{"JJ"},
"etymologically":	{"RB"},
"etymologies":	{"NNS"},
"etymologise":	{"VB","VBP"},
"etymologised":	{"VBD","VBN"},
"etymologises":	{"VBZ"},
"etymologising":	{"VBG"},
"etymologist":	{"NN"},
"etymologists":	{"NNS"},
"etymologize":	{"VB","VBP"},
"etymologized":	{"VBD","VBN"},
"etymologizes":	{"VBZ"},
"etymologizing":	{"VBG"},
"etymology":	{"NN"},
"etymon":	{"NN"},
"eu":	{"NN"},
"euarctos":	{"NNS"},
"euascomycetes":	{"NNS"},
"eubacteria":	{"NNS"},
"eubacteriales":	{"NNS"},
"eubacterium":	{"NN"},
"eubryales":	{"NNS"},
"eubstance":	{"NN"},
"eucalypt":	{"NN"},
"eucalypti":	{"NNS"},
"eucalyptus":	{"NN"},
"eucalyptuses":	{"NNS"},
"eucarya":	{"NN"},
"eucaryote":	{"NN"},
"eucaryotic":	{"JJ"},
"eucharistic":	{"JJ"},
"euchre":	{"NN"},
"eucinostomus":	{"NNS"},
"eudaemon":	{"NN"},
"eudaemonia":	{"NN"},
"eudaemonic":	{"JJ"},
"eudaimonia":	{"NN"},
"eudemon":	{"NN"},
"eudemonic":	{"JJ"},
"eudemonism":	{"NN"},
"euderma":	{"NN"},
"eudiometer":	{"NN"},
"eudyptes":	{"NNS"},
"eugenia":	{"NN"},
"eugenic":	{"JJ"},
"eugenics":	{"NN"},
"euglena":	{"NN"},
"euglenaceae":	{"NN"},
"euglenid":	{"NN"},
"euglenoid":	{"NN"},
"euglenophyceae":	{"NN"},
"euglenophyta":	{"NN"},
"euglenophyte":	{"NN"},
"eukaryote":	{"NN"},
"eukaryotic":	{"JJ"},
"euler":	{"NN"},
"eulogies":	{"NNS"},
"eulogise":	{"VB","VBP"},
"eulogised":	{"VBD","VBN"},
"eulogises":	{"VBZ"},
"eulogising":	{"VBG"},
"eulogist":	{"NN"},
"eulogistic":	{"JJ"},
"eulogists":	{"NNS"},
"eulogium":	{"NN"},
"eulogize":	{"VB","VBP"},
"eulogized":	{"VBD","VBN"},
"eulogizers":	{"NNS"},
"eulogizes":	{"VBZ"},
"eulogizing":	{"VBG"},
"eulogy":	{"NN"},
"eumeces":	{"NN"},
"eumenes":	{"NNS"},
"eumenides":	{"NNS"},
"eumetopias":	{"NNS"},
"eumops":	{"NNS"},
"eumycetes":	{"NNS"},
"eumycota":	{"NN"},
"eunectes":	{"NNS"},
"eunuch":	{"NN"},
"eunuchoidism":	{"NN"},
"eunuchs":	{"NNS"},
"euonymus":	{"NN"},
"eupatorium":	{"NN"},
"euphagus":	{"NN"},
"euphausiacea":	{"NN"},
"euphemise":	{"VB","VBP"},
"euphemised":	{"VBD","VBN"},
"euphemiser":	{"NN"},
"euphemises":	{"VBZ"},
"euphemising":	{"VBG"},
"euphemism":	{"NN"},
"euphemisms":	{"NNS"},
"euphemistic":	{"JJ"},
"euphemistically":	{"RB"},
"euphemize":	{"VB","VBP"},
"euphemized":	{"VBD","VBN"},
"euphemizer":	{"NN"},
"euphemizes":	{"VBZ"},
"euphemizing":	{"VBG"},
"euphonic":	{"JJ"},
"euphonical":	{"JJ"},
"euphonious":	{"JJ"},
"euphonium":	{"NN"},
"euphony":	{"NN"},
"euphorbia":	{"NN"},
"euphorbiaceae":	{"NN"},
"euphorbium":	{"NN"},
"euphoria":	{"NN"},
"euphoriant":	{"JJ"},
"euphoric":	{"JJ"},
"euphorically":	{"RB"},
"euphory":	{"NN"},
"euphractus":	{"NNS"},
"euphrosyne":	{"NN"},
"euphuism":	{"NN"},
"euplectella":	{"NN"},
"eupnea":	{"NN"},
"eupneic":	{"JJ"},
"eupnoea":	{"NN"},
"eupnoeic":	{"JJ"},
"euproctis":	{"NNS"},
"eurafrican":	{"JJ","NN"},
"eurasiatic":	{"JJ"},
"eureka":	{"UH"},
"eurhythmics":	{"NN"},
"eurhythmy":	{"NN"},
"euro":	{"NN"},
"euro-ashtrays":	{"NNS"},
"euro-banners":	{"NNS"},
"euro-barbecue":	{"NN"},
"euro-caps":	{"NNS"},
"euro-cards":	{"NNS"},
"euro-cigarette":	{"NN"},
"euro-enthusiasts":	{"NNS"},
"euro-factories":	{"NNS"},
"euro-housewife":	{"NN"},
"euro-jogging":	{"JJ"},
"euro-pillows":	{"NNS"},
"euro-playing":	{"JJ"},
"euro-products":	{"NNS"},
"euro-son":	{"NN"},
"euro-that":	{"NN"},
"euro-this":	{"NNS"},
"euro-watches":	{"NNS"},
"eurobabble":	{"NN"},
"eurocentrism":	{"NN"},
"eurocommercial":	{"JJ"},
"euroconsumer":	{"NN"},
"euroconvertible":	{"JJ"},
"eurocurrency":	{"NN"},
"eurodebentures":	{"NNS"},
"eurodollar":	{"NN"},
"euroissues":	{"NNS"},
"eurokitsch":	{"NN"},
"euromark":	{"NN"},
"euromyth":	{"NN"},
"euromyths":	{"NNS"},
"euronithopod":	{"NN"},
"euronithopoda":	{"NN"},
"euronotes":	{"NNS"},
"europa":	{"NN"},
"europan":	{"NN"},
"europe-based":	{"JJ"},
"european-based":	{"JJ"},
"european-branch":	{"JJ"},
"european-made":	{"JJ"},
"european-minded":	{"JJ"},
"europeanisation":	{"NN"},
"europeanise":	{"VB","VBP"},
"europeanised":	{"VBD","VBN"},
"europeanises":	{"VBZ"},
"europeanish":	{"JJ"},
"europeanising":	{"VBG"},
"europeanization":	{"NN"},
"europeanize":	{"VB","VBP"},
"europeanized":	{"VBD","VBN"},
"europeanizes":	{"VBZ"},
"europeanizing":	{"VBG"},
"europhoria":	{"NN"},
"europium":	{"NN"},
"europocentric":	{"JJ"},
"europol":	{"NN"},
"euros":	{"NNS"},
"eurotiales":	{"NNS"},
"eurotium":	{"NN"},
"euryale":	{"NN"},
"euryalida":	{"NN"},
"eurylaimi":	{"NN"},
"eurylaimidae":	{"NN"},
"eurypterid":	{"NN"},
"eurypterida":	{"NN"},
"eurythmics":	{"NN"},
"eurythmy":	{"NN"},
"eusebius":	{"NN"},
"eusporangiate":	{"JJ"},
"eusporangium":	{"NN"},
"eustachio":	{"NN"},
"eustoma":	{"NN"},
"eustress":	{"NN"},
"eutamias":	{"NNS"},
"eutectic":	{"NN","JJ"},
"euterpe":	{"NN"},
"euthanasia":	{"NN"},
"euthanise":	{"VB","VBP"},
"euthanised":	{"VBD","VBN"},
"euthanises":	{"VBZ"},
"euthanising":	{"VBG"},
"euthanize":	{"VB","VBP"},
"euthanized":	{"VBD","VBN"},
"euthanizes":	{"VBZ"},
"euthanizing":	{"VBG"},
"euthenics":	{"NN"},
"eutheria":	{"NN"},
"eutherian":	{"JJ","NN"},
"euthynnus":	{"NN"},
"eutrophic":	{"JJ"},
"eutrophication":	{"NN"},
"ev":	{"NN"},
"evacuant":	{"NN","JJ"},
"evacuate":	{"VB","VBP"},
"evacuated":	{"VBN","VBD"},
"evacuates":	{"VBZ"},
"evacuating":	{"VBG"},
"evacuation":	{"NN"},
"evacuations":	{"NNS"},
"evacuee":	{"NN"},
"evacuees":	{"NNS"},
"evade":	{"VB","VBP"},
"evaded":	{"VBD","VBN"},
"evader":	{"NN"},
"evaders":	{"NNS"},
"evades":	{"VBZ"},
"evading":	{"VBG"},
"evaluate":	{"VB","VBP"},
"evaluated":	{"VBD","VBN"},
"evaluates":	{"VBZ"},
"evaluating":	{"VBG"},
"evaluation":	{"NN"},
"evaluations":	{"NNS"},
"evaluative":	{"JJ"},
"evaluator":	{"NN"},
"evanesce":	{"VB","VBP"},
"evanesced":	{"VBD","VBN"},
"evanescence":	{"NN"},
"evanescent":	{"JJ"},
"evanesces":	{"VBZ"},
"evanescing":	{"VBG"},
"evangel":	{"NN"},
"evangelical":	{"JJ","NN"},
"evangelicalism":	{"NN"},
"evangelicals":	{"NNS"},
"evangeline":	{"NN"},
"evangelise":	{"VB","VBP"},
"evangelised":	{"VBD","VBN"},
"evangelises":	{"VBZ"},
"evangelising":	{"VBG"},
"evangelism":	{"NN"},
"evangelist":	{"NN"},
"evangelist-industrialist":	{"NN"},
"evangelistic":	{"JJ"},
"evangelists":	{"NNS"},
"evangelize":	{"VB","VBP"},
"evangelized":	{"VBD","VBN"},
"evangelizes":	{"VBZ"},
"evangelizing":	{"VBG"},
"evans":	{"NNS"},
"evansville":	{"NN"},
"evaporable":	{"JJ"},
"evaporate":	{"VB","VBP"},
"evaporated":	{"VBD","VBN"},
"evaporates":	{"VBZ"},
"evaporating":	{"VBG"},
"evaporation":	{"NN"},
"evaporative":	{"JJ"},
"evaporite":	{"NN"},
"evaporometer":	{"NN"},
"evasion":	{"NN"},
"evasions":	{"NNS"},
"evasive":	{"JJ"},
"evasively":	{"RB"},
"evasiveness":	{"NN"},
"eve":	{"NN"},
"evelyn":	{"NN"},
"even":	{"RB","JJ","VBP","VB","RP"},
"even-handed":	{"JJ"},
"even-handedly":	{"RB"},
"even-handedness":	{"NN"},
"even-larger":	{"JJ"},
"even-pinnate":	{"JJ"},
"even-tempered":	{"JJ"},
"even-textured":	{"JJ"},
"even-toed":	{"JJ"},
"evened":	{"VBD","VBN"},
"evenfall":	{"NN"},
"evenhanded":	{"JJ"},
"evenhandedly":	{"RB"},
"evening":	{"NN","VBG","UH"},
"evening-snow":	{"NN"},
"evenings":	{"NNS"},
"eveningwear":	{"NN"},
"evenk":	{"NN"},
"evenki":	{"NN"},
"evenly":	{"RB"},
"evenness":	{"NN"},
"evens":	{"NN","JJ","VBZ"},
"evensong":	{"NN"},
"event":	{"NN"},
"event-driven":	{"JJ"},
"event-risk":	{"JJ","NN"},
"eventful":	{"JJ"},
"eventfully":	{"RB"},
"eventide":	{"NN"},
"eventration":	{"NN"},
"events":	{"NNS"},
"eventshah-leh":	{"RB"},
"eventshahleh":	{"RB"},
"eventual":	{"JJ"},
"eventualities":	{"NNS"},
"eventuality":	{"NN"},
"eventually":	{"RB"},
"eventuate":	{"VB","VBP"},
"eventuated":	{"VBD","VBN"},
"eventuates":	{"VBZ"},
"eventuating":	{"VBG"},
"evenutally":	{"RB"},
"ever":	{"RB"},
"ever-anxious":	{"JJ"},
"ever-changing":	{"JJ"},
"ever-confident":	{"JJ"},
"ever-dying":	{"JJ"},
"ever-existent":	{"JJ"},
"ever-expanding":	{"JJ"},
"ever-faster":	{"JJ"},
"ever-greater":	{"JJ"},
"ever-growing":	{"JJ"},
"ever-higher":	{"JJ"},
"ever-increasing":	{"JJ"},
"ever-lovin":	{"JJ"},
"ever-more":	{"RB"},
"ever-narrowing":	{"JJ"},
"ever-optimistic":	{"JJ"},
"ever-present":	{"JJ"},
"ever-quieter":	{"JJ"},
"ever-so-Oxonian":	{"JJ"},
"ever-so-oxonian":	{"JJ"},
"ever-successful":	{"JJ"},
"ever-swelling":	{"JJ"},
"ever-tightening":	{"JJ"},
"ever-vigilant":	{"JJ"},
"ever-worsening":	{"JJ"},
"everglade":	{"NN"},
"everglades":	{"NNS"},
"evergreen":	{"JJ","NN"},
"evergreens":	{"NNS"},
"everlasting":	{"JJ"},
"everlastingly":	{"RB"},
"everlastingness":	{"NN"},
"everlys":	{"NNS"},
"evermore":	{"RB"},
"evernia":	{"NN"},
"evers":	{"NNS"},
"eversible":	{"JJ"},
"eversion":	{"NN"},
"eversteadier":	{"JJ"},
"evert":	{"VB","VBP"},
"everted":	{"VBD","VBN"},
"everting":	{"VBG"},
"everts":	{"VBZ"},
"every":	{"DT"},
"every-day":	{"JJ"},
"everybody":	{"PRP"},
"everyday":	{"JJ"},
"everydayness":	{"NN"},
"everyman":	{"NN"},
"everyone":	{"PRP"},
"everyplace":	{"RB"},
"everything":	{"PRP"},
"everywhere":	{"RB"},
"eves":	{"NNS"},
"evian":	{"NN"},
"evict":	{"VB","VBP"},
"evicted":	{"VBD","VBN"},
"evicting":	{"VBG"},
"eviction":	{"NN"},
"evictions":	{"NNS"},
"evicts":	{"VBZ"},
"evidence":	{"NN","VBP","VB"},
"evidenced":	{"VBD","VBN"},
"evidences":	{"NNS","VBZ"},
"evidencing":	{"VBG"},
"evident":	{"JJ"},
"evidential":	{"JJ"},
"evidentially":	{"RB"},
"evidentiary":	{"JJ"},
"evidently":	{"RB"},
"evil":	{"JJ","NN"},
"evil-but-cute":	{"JJ"},
"evil-doer":	{"NN"},
"evil-doers":	{"NNS"},
"evil-doing":	{"NN"},
"evil-looking":	{"JJ"},
"evil-minded":	{"JJ"},
"evildoer":	{"NN"},
"evildoers":	{"NNS"},
"evildoing":	{"NN"},
"evilly":	{"RB"},
"evilness":	{"NN"},
"evils":	{"NNS"},
"evince":	{"VB","VBP"},
"evinced":	{"VBD","VBN"},
"evinces":	{"VBZ"},
"evincing":	{"VBG"},
"eviscerate":	{"VB","VBP"},
"eviscerated":	{"VBD","VBN"},
"eviscerates":	{"VBZ"},
"eviscerating":	{"VBG"},
"evisceration":	{"NN"},
"evitable":	{"JJ"},
"evocation":	{"NN"},
"evocations":	{"NNS"},
"evocative":	{"JJ"},
"evocatively":	{"RB"},
"evoke":	{"VB","VBP"},
"evoked":	{"VBD","VBN"},
"evokes":	{"VBZ"},
"evoking":	{"VBG"},
"evolution":	{"NN"},
"evolutionarily":	{"RB"},
"evolutionary":	{"JJ"},
"evolutionism":	{"NN"},
"evolutionist":	{"NN"},
"evolutionists":	{"NNS"},
"evolutions":	{"NNS"},
"evolve":	{"VB","VBP"},
"evolved":	{"VBN","VBD"},
"evolves":	{"VBZ"},
"evolving":	{"VBG"},
"ew":	{"NN"},
"ewc":	{"NN"},
"ewe":	{"NN"},
"ewenki":	{"NN"},
"ewer":	{"NN"},
"ewers":	{"NNS"},
"ewes":	{"NNS"},
"ex":	{"NN","IN"},
"ex-Beecham":	{"JJ"},
"ex-Cubs":	{"NNS"},
"ex-FDA":	{"JJ"},
"ex-House":	{"JJ"},
"ex-Justice":	{"NN"},
"ex-National":	{"JJ"},
"ex-Tory":	{"NN"},
"ex-Yankee":	{"NN"},
"ex-accountant":	{"NN"},
"ex-aides":	{"NNS"},
"ex-bandits":	{"NNS"},
"ex-beecham":	{"JJ"},
"ex-boyfriend":	{"NN"},
"ex-brother-in-law":	{"NN"},
"ex-chairman":	{"NN"},
"ex-chief":	{"JJ","NN"},
"ex-convict":	{"NN"},
"ex-convicts":	{"NNS"},
"ex-cub":	{"JJ"},
"ex-cubs":	{"NNS"},
"ex-directory":	{"JJ"},
"ex-dividend":	{"JJ","NN","RB"},
"ex-employee":	{"NN"},
"ex-employees":	{"NNS"},
"ex-employer":	{"NN"},
"ex-fda":	{"JJ"},
"ex-fighter":	{"NN"},
"ex-franchise":	{"NN"},
"ex-furniture":	{"JJ"},
"ex-gambler":	{"NN"},
"ex-house":	{"JJ"},
"ex-housing":	{"JJ"},
"ex-hurler":	{"NN"},
"ex-husband":	{"NN"},
"ex-investment":	{"JJ"},
"ex-jazz":	{"JJ"},
"ex-justice":	{"NN"},
"ex-lawyer":	{"NN"},
"ex-liberals":	{"NNS"},
"ex-manager":	{"NN"},
"ex-mayor":	{"NN"},
"ex-member":	{"NN"},
"ex-musician":	{"NN"},
"ex-national":	{"JJ"},
"ex-officers":	{"NNS"},
"ex-officials":	{"NNS"},
"ex-officio":	{"JJ","NN"},
"ex-partners":	{"NNS"},
"ex-player":	{"NN"},
"ex-president":	{"NN","JJ"},
"ex-presidents":	{"NNS"},
"ex-prison":	{"NN"},
"ex-prize":	{"JJ"},
"ex-reporters":	{"NNS"},
"ex-schoolteacher":	{"NN"},
"ex-serviceman":	{"NN"},
"ex-singer":	{"NN"},
"ex-smokers":	{"NNS"},
"ex-spouse":	{"NN"},
"ex-spouses":	{"NNS"},
"ex-tory":	{"NN"},
"ex-truck":	{"JJ"},
"ex-trucking":	{"JJ"},
"ex-wife":	{"NN"},
"ex-wives":	{"NNS"},
"ex-yankee":	{"NN"},
"exabit":	{"NN"},
"exabyte":	{"NN"},
"exacerbate":	{"VB","VBP"},
"exacerbated":	{"VBD","VBN"},
"exacerbates":	{"VBZ"},
"exacerbating":	{"VBG"},
"exacerbation":	{"NN"},
"exacerbations":	{"NNS"},
"exachanges":	{"NNS"},
"exact":	{"JJ","VB","VBP"},
"exacta":	{"NN"},
"exacted":	{"VBD","VBN"},
"exacting":	{"JJ","VBG"},
"exaction":	{"NN"},
"exactitude":	{"NN"},
"exactly":	{"RB"},
"exactness":	{"NN"},
"exacts":	{"VBZ"},
"exacum":	{"NN"},
"exaeretodon":	{"NN"},
"exaggerate":	{"VB","VBP"},
"exaggerated":	{"JJ","VBD","VBN"},
"exaggeratedly":	{"RB"},
"exaggerates":	{"VBZ"},
"exaggerating":	{"VBG"},
"exaggeration":	{"NN"},
"exaggerations":	{"NNS"},
"exalt":	{"VB","VBP"},
"exaltation":	{"NN"},
"exaltations":	{"NNS"},
"exalted":	{"JJ","VBN","VBD"},
"exalting":	{"VBG"},
"exalts":	{"VBZ"},
"exam":	{"NN"},
"examen":	{"NN"},
"examination":	{"NN"},
"examinations":	{"NNS"},
"examine":	{"VB","VBP"},
"examined":	{"VBN","VBD"},
"examinee":	{"NN"},
"examinees":	{"NNS"},
"examiner":	{"NN"},
"examiners":	{"NNS"},
"examines":	{"VBZ"},
"examining":	{"VBG"},
"example":	{"NN"},
"examples":	{"NNS"},
"exams":	{"NNS"},
"exanimate":	{"JJ"},
"exanthem":	{"NN"},
"exanthema":	{"NN"},
"exarch":	{"NN"},
"exarchate":	{"NN"},
"exascale":	{"JJ"},
"exasperate":	{"VB","VBP"},
"exasperated":	{"JJ","VBD","VBN"},
"exasperatedly":	{"RB"},
"exasperates":	{"VBZ"},
"exasperating":	{"JJ","VBG"},
"exasperatingly":	{"RB"},
"exasperation":	{"NN"},
"exaugural":	{"JJ"},
"exbibit":	{"NN"},
"exbibyte":	{"NN"},
"exboyfriend":	{"NN"},
"excavate":	{"VB","VBP"},
"excavated":	{"VBD","VBN"},
"excavates":	{"VBZ"},
"excavating":	{"VBG"},
"excavation":	{"NN"},
"excavations":	{"NNS"},
"excavator":	{"NN"},
"excavators":	{"NNS"},
"exceed":	{"VB","VBP"},
"exceedance":	{"NN"},
"exceeded":	{"VBD","VBN"},
"exceeding":	{"VBG"},
"exceedingly":	{"RB"},
"exceeds":	{"VBZ"},
"excel":	{"VB","VBP"},
"excelled":	{"VBD","VBN"},
"excellence":	{"NN"},
"excellences":	{"NNS"},
"excellency":	{"NN"},
"excellent":	{"JJ"},
"excellently":	{"RB"},
"excelling":	{"VBG"},
"excels":	{"VBZ"},
"excelsin":	{"NN"},
"excelsior":	{"NN"},
"except":	{"IN","VB","VBP"},
"excepted":	{"VBN","VBD","RB"},
"excepting":	{"IN","VBG"},
"exception":	{"NN"},
"exceptionable":	{"JJ"},
"exceptional":	{"JJ"},
"exceptionalist":	{"NN"},
"exceptionalists":	{"NNS"},
"exceptionally":	{"RB"},
"exceptions":	{"NNS"},
"excepts":	{"VBZ"},
"excerpt":	{"NN","VB","VBP"},
"excerpted":	{"VBN","VBD"},
"excerpting":	{"VBG"},
"excerption":	{"NN"},
"excerpts":	{"NNS","VBZ"},
"excess":	{"JJ","NN","VB","VBP"},
"excessed":	{"VBD","VBN"},
"excesses":	{"NNS","VBZ"},
"excessing":	{"VBG"},
"excessive":	{"JJ"},
"excessively":	{"RB"},
"excessiveness":	{"NN"},
"exch":	{"NN"},
"exchange":	{"NN","VB","VBP"},
"exchange-listed":	{"JJ"},
"exchange-rate":	{"NN","JJ"},
"exchange-sponsored":	{"JJ"},
"exchangeability":	{"NN"},
"exchangeable":	{"JJ"},
"exchanged":	{"VBD","VBN"},
"exchanger":	{"NN"},
"exchangers":	{"NNS"},
"exchanges":	{"NNS","VBZ"},
"exchanging":	{"VBG"},
"exchequer":	{"NN"},
"excise":	{"VB","VBP","NN"},
"excise-tax":	{"JJ"},
"excised":	{"VBD","VBN"},
"exciseman":	{"NN"},
"excisemen":	{"NNS"},
"excises":	{"VBZ","NNS"},
"excising":	{"VBG"},
"excision":	{"NN"},
"excisions":	{"NNS"},
"excitability":	{"NN"},
"excitable":	{"JJ"},
"excitableness":	{"NN"},
"excitant":	{"JJ","NN"},
"excitation":	{"NN"},
"excitative":	{"JJ"},
"excitatory":	{"JJ"},
"excite":	{"VB","VBP"},
"excited":	{"VBN","JJ","VBD"},
"excitedly":	{"RB"},
"excitement":	{"NN"},
"excitements":	{"NNS"},
"exciter":	{"NN"},
"excites":	{"VBZ"},
"exciting":	{"JJ","VBG"},
"excitingly":	{"RB"},
"exclaim":	{"VB","VBP"},
"exclaimed":	{"VBD","VBN"},
"exclaiming":	{"VBG"},
"exclaims":	{"VBZ"},
"exclamation":	{"NN"},
"exclamations":	{"NNS"},
"exclamatory":	{"JJ"},
"exclude":	{"VB","VBP"},
"excluded":	{"VBN","VBD"},
"excludes":	{"VBZ"},
"excluding":	{"IN","VBG"},
"exclusion":	{"NN"},
"exclusionary":	{"JJ"},
"exclusions":	{"NNS"},
"exclusive":	{"JJ","NN"},
"exclusively":	{"RB"},
"exclusiveness":	{"NN"},
"exclusives":	{"NNS"},
"exclusivity":	{"NN"},
"excogitable":	{"JJ"},
"excogitate":	{"VB","VBP"},
"excogitated":	{"VBD","VBN"},
"excogitates":	{"VBZ"},
"excogitating":	{"VBG"},
"excogitation":	{"NN"},
"excogitative":	{"JJ"},
"excogitator":	{"NN"},
"excommunicate":	{"VB","VBP"},
"excommunicated":	{"VBD","VBN"},
"excommunicates":	{"VBZ"},
"excommunicating":	{"VBG"},
"excommunication":	{"NN"},
"excommunications":	{"NNS"},
"excoriate":	{"VB","VBP"},
"excoriated":	{"VBD","VBN"},
"excoriates":	{"VBZ"},
"excoriating":	{"VBG"},
"excoriation":	{"NN"},
"excrement":	{"NN"},
"excrescence":	{"NN"},
"excrescent":	{"JJ"},
"excreta":	{"NN"},
"excrete":	{"VB","VBP"},
"excreted":	{"VBD","VBN"},
"excretes":	{"VBZ"},
"excreting":	{"VBG"},
"excretion":	{"NN"},
"excretions":	{"NNS"},
"excretory":	{"JJ"},
"excruciate":	{"VB","VBP"},
"excruciated":	{"VBD","VBN"},
"excruciates":	{"VBZ"},
"excruciating":	{"JJ","VBG"},
"excruciatingly":	{"RB"},
"excruciation":	{"NN"},
"excrutiatingly":	{"RB"},
"exculpate":	{"VB","VBP"},
"exculpated":	{"VBD","VBN"},
"exculpates":	{"VBZ"},
"exculpating":	{"VBG"},
"exculpation":	{"NN"},
"exculpatory":	{"JJ"},
"excursion":	{"NN"},
"excursionist":	{"NN"},
"excursions":	{"NNS"},
"excursive":	{"JJ"},
"excursus":	{"NN"},
"excusable":	{"JJ"},
"excusably":	{"RB"},
"excusatory":	{"JJ"},
"excuse":	{"NN","VB","VBP"},
"excused":	{"VBD","VBN"},
"excuser":	{"NN"},
"excuses":	{"NNS","VBZ"},
"excusing":	{"VBG"},
"excutives":	{"NNS"},
"exe":	{"NN"},
"exec":	{"NN"},
"execrable":	{"JJ"},
"execrably":	{"RB"},
"execrate":	{"VB","VBP"},
"execrated":	{"VBD","VBN"},
"execrates":	{"VBZ"},
"execrating":	{"VBG"},
"execration":	{"NN"},
"execrations":	{"NNS"},
"execs":	{"NNS"},
"execuitive":	{"NN"},
"executability":	{"NN"},
"executable":	{"JJ"},
"executant":	{"NN"},
"execute":	{"VB","VBP"},
"executed":	{"VBN","VBD"},
"executes":	{"VBZ"},
"executing":	{"VBG"},
"execution":	{"NN"},
"executioner":	{"NN"},
"executioners":	{"NNS"},
"executions":	{"NNS"},
"executive":	{"NN","JJ"},
"executive-branch":	{"JJ","NN"},
"executive-legislative":	{"JJ"},
"executive-level":	{"JJ"},
"executive-model":	{"JJ"},
"executive-office":	{"NN"},
"executive-only":	{"JJ"},
"executive-type":	{"NN"},
"executives":	{"NNS"},
"executor":	{"NN"},
"executors":	{"NNS"},
"executrix":	{"NN"},
"exegeses":	{"NNS"},
"exegesis":	{"NN"},
"exegete":	{"NN"},
"exegetic":	{"JJ"},
"exegetical":	{"JJ"},
"exemplar":	{"NN"},
"exemplars":	{"NNS"},
"exemplary":	{"JJ"},
"exemplification":	{"NN"},
"exemplified":	{"VBD","VBN"},
"exemplifies":	{"VBZ"},
"exemplify":	{"VB","VBP"},
"exemplifying":	{"VBG"},
"exempt":	{"JJ","VB","VBP"},
"exempted":	{"VBD","VBN"},
"exempting":	{"VBG"},
"exemption":	{"NN"},
"exemptions":	{"NNS"},
"exempts":	{"VBZ"},
"exenterate":	{"VB","VBP"},
"exenterated":	{"VBD","VBN"},
"exenterates":	{"VBZ"},
"exenterating":	{"VBG"},
"exenteration":	{"NN"},
"exercisable":	{"JJ"},
"exercise":	{"NN","VB","VBP"},
"exercised":	{"VBD","VBN"},
"exerciser":	{"NN"},
"exercises":	{"NNS","VBZ"},
"exercising":	{"VBG"},
"exercycle":	{"NN"},
"exergonic":	{"JJ"},
"exerpts":	{"NNS"},
"exert":	{"VB","VBP"},
"exerted":	{"VBN","VBD"},
"exerting":	{"VBG"},
"exertion":	{"NN"},
"exertional":	{"JJ"},
"exertions":	{"NNS"},
"exerts":	{"VBZ"},
"exes":	{"NNS"},
"exeter":	{"NN"},
"exeuctive":	{"NN"},
"exfoliate":	{"VB","VBP"},
"exfoliated":	{"VBD","VBN"},
"exfoliates":	{"VBZ"},
"exfoliating":	{"VBG"},
"exfoliation":	{"NN"},
"exhalation":	{"NN"},
"exhale":	{"VB","VBP"},
"exhaled":	{"VBD","VBN"},
"exhales":	{"VBZ"},
"exhaling":	{"VBG"},
"exhanges":	{"NNS"},
"exhaust":	{"NN","VB","VBP"},
"exhausted":	{"JJ","VBN","VBD"},
"exhaustedly":	{"RB"},
"exhaustible":	{"JJ"},
"exhausting":	{"JJ","VBG"},
"exhaustingly":	{"RB"},
"exhaustion":	{"NN"},
"exhaustive":	{"JJ"},
"exhaustively":	{"RB"},
"exhausts":	{"NNS","VBZ"},
"exhibit":	{"NN","VB","VBP"},
"exhibited":	{"VBD","VBN"},
"exhibiting":	{"VBG"},
"exhibition":	{"NN"},
"exhibitioner":	{"NN"},
"exhibitionism":	{"NN"},
"exhibitionist":	{"NN","JJ"},
"exhibitionistic":	{"JJ"},
"exhibitionists":	{"NNS"},
"exhibitions":	{"NNS"},
"exhibitor":	{"NN"},
"exhibitors":	{"NNS"},
"exhibits":	{"NNS","VBZ"},
"exhilarate":	{"VB","VBP"},
"exhilarated":	{"JJ","VBD","VBN"},
"exhilarates":	{"VBZ"},
"exhilarating":	{"JJ","VBG"},
"exhilaration":	{"NN"},
"exhort":	{"VB","VBP"},
"exhortation":	{"NN"},
"exhortations":	{"NNS"},
"exhortative":	{"JJ"},
"exhortatory":	{"JJ"},
"exhorted":	{"VBD","VBN"},
"exhorting":	{"VBG"},
"exhorts":	{"VBZ"},
"exhumation":	{"NN"},
"exhumations":	{"NNS"},
"exhume":	{"VB","VBP"},
"exhumed":	{"VBD","VBN"},
"exhumes":	{"VBZ"},
"exhuming":	{"VBG"},
"exhusband":	{"NN"},
"exigencies":	{"NNS"},
"exigency":	{"NN"},
"exigent":	{"JJ"},
"exiguity":	{"NN"},
"exiguous":	{"JJ"},
"exile":	{"NN","VB","VBP"},
"exiled":	{"VBN","VBD"},
"exiles":	{"VBZ","NNS"},
"exilic":	{"JJ"},
"exiling":	{"VBG"},
"exist":	{"VB","VBP"},
"existance":	{"NN"},
"existed":	{"VBD","VBN"},
"existence":	{"NN"},
"existences":	{"NNS"},
"existent":	{"NN","JJ"},
"existential":	{"JJ"},
"existentialism":	{"NN"},
"existentialist":	{"NN","JJ"},
"existentialists":	{"NNS"},
"existents":	{"NNS"},
"existing":	{"VBG","JJ"},
"exists":	{"VBZ"},
"exit":	{"NN","VB","VBP"},
"exit-load":	{"JJ"},
"exit-poll":	{"NN"},
"exit-visa":	{"NN"},
"exit-visas":	{"NNS"},
"exited":	{"VBD","VBN"},
"exiting":	{"VBG"},
"exits":	{"NNS","VBZ"},
"exobiology":	{"NN"},
"exocarp":	{"NN"},
"exocentric":	{"JJ"},
"exocet":	{"NN"},
"exocoetidae":	{"NN"},
"exocrine":	{"JJ","NN"},
"exocycloida":	{"NN"},
"exode":	{"NN"},
"exoderm":	{"NN"},
"exodontia":	{"NN"},
"exodontic":	{"JJ"},
"exodontics":	{"NN"},
"exodontist":	{"NN"},
"exodus":	{"NN"},
"exoergic":	{"JJ"},
"exogamic":	{"JJ"},
"exogamous":	{"JJ"},
"exogamy":	{"NN"},
"exogen":	{"NN"},
"exogenic":	{"JJ"},
"exogenous":	{"JJ"},
"exomphalos":	{"NNS"},
"exon":	{"NN"},
"exonerate":	{"VB","VBP"},
"exonerated":	{"VBD","VBN"},
"exonerates":	{"VBZ"},
"exonerating":	{"VBG"},
"exoneration":	{"NN"},
"exonerative":	{"JJ"},
"exonuclease":	{"NN"},
"exophthalmos":	{"NN"},
"exopterygota":	{"NN"},
"exorbitance":	{"NN"},
"exorbitant":	{"JJ"},
"exorbitantly":	{"RB"},
"exorcise":	{"VB","VBP"},
"exorcised":	{"VBD","VBN"},
"exorciser":	{"NN"},
"exorcises":	{"VBZ"},
"exorcising":	{"VBG"},
"exorcism":	{"NN"},
"exorcisms":	{"NNS"},
"exorcist":	{"NN"},
"exorcists":	{"NNS"},
"exorcize":	{"VB","VBP"},
"exorcized":	{"VBD","VBN"},
"exorcizes":	{"VBZ"},
"exorcizing":	{"VBG"},
"exordium":	{"NN"},
"exoskeleton":	{"NN"},
"exoskeletons":	{"NNS"},
"exosphere":	{"NN"},
"exostosis":	{"NN"},
"exoteric":	{"JJ"},
"exotherm":	{"NN"},
"exothermal":	{"JJ"},
"exothermic":	{"JJ"},
"exotic":	{"JJ"},
"exotic-Hawaiian-locale":	{"JJ"},
"exotic-hawaiian-locale":	{"JJ"},
"exotically":	{"RB"},
"exoticism":	{"NN"},
"exoticness":	{"NN"},
"exotism":	{"NN"},
"exotoxin":	{"NN"},
"exotropia":	{"NN"},
"expand":	{"VB","VBP"},
"expandable":	{"JJ"},
"expanded":	{"VBN","VBD","JJ"},
"expandible":	{"JJ"},
"expanding":	{"VBG"},
"expanding-profit":	{"JJ"},
"expands":	{"VBZ"},
"expanse":	{"NN"},
"expanses":	{"NNS"},
"expansible":	{"JJ"},
"expansile":	{"JJ"},
"expansion":	{"NN"},
"expansion-contraction":	{"NN"},
"expansion-minded":	{"JJ"},
"expansionary":	{"JJ"},
"expansionism":	{"NN"},
"expansionist":	{"JJ","NN"},
"expansionists":	{"NNS"},
"expansions":	{"NNS"},
"expansive":	{"JJ"},
"expansively":	{"RB"},
"expansiveness":	{"NN"},
"expansivity":	{"NN"},
"expat":	{"NN"},
"expatiate":	{"VB","VBP"},
"expatiated":	{"VBD","VBN"},
"expatiates":	{"VBZ"},
"expatiating":	{"VBG"},
"expatiation":	{"NN"},
"expatriate":	{"NN","VB","VBP","JJ"},
"expatriated":	{"VBD","VBN"},
"expatriates":	{"NNS","VBZ"},
"expatriating":	{"VBG"},
"expatriation":	{"NN"},
"expats":	{"NNS"},
"expecially":	{"RB"},
"expect":	{"VB","VBP"},
"expectable":	{"JJ"},
"expectancies":	{"NNS"},
"expectancy":	{"NN"},
"expectant":	{"JJ"},
"expectantly":	{"RB"},
"expectation":	{"NN"},
"expectations":	{"NNS"},
"expected":	{"VBN","VBD","JJ"},
"expectedly":	{"RB"},
"expectedness":	{"NN"},
"expecting":	{"VBG"},
"expectorant":	{"NN","JJ"},
"expectorants":	{"NNS"},
"expectorate":	{"VB","VBP"},
"expectorated":	{"VBD","VBN"},
"expectorates":	{"VBZ"},
"expectorating":	{"VBG"},
"expectoration":	{"NN"},
"expectorator":	{"NN"},
"expects":	{"VBZ"},
"expedience":	{"NN"},
"expediencies":	{"NNS"},
"expediency":	{"NN"},
"expedient":	{"JJ","NN"},
"expediently":	{"RB"},
"expedients":	{"NNS"},
"expedite":	{"VB","VBP"},
"expedited":	{"VBD","VBN"},
"expedites":	{"VBZ"},
"expediting":	{"VBG"},
"expedition":	{"NN"},
"expeditionary":	{"JJ"},
"expeditions":	{"NNS"},
"expeditious":	{"JJ"},
"expeditiously":	{"RB"},
"expeditiousness":	{"NN"},
"expel":	{"VB","VBP"},
"expelled":	{"VBD","VBN"},
"expelling":	{"NN","VBG"},
"expels":	{"VBZ"},
"expend":	{"VB","VBP"},
"expendable":	{"JJ"},
"expended":	{"VBD","VBN"},
"expender":	{"NN"},
"expending":	{"VBG"},
"expenditure":	{"NN"},
"expenditures":	{"NNS"},
"expends":	{"VBZ"},
"expense":	{"NN","VB","VBP"},
"expense-account":	{"NN"},
"expense-paid":	{"JJ"},
"expense-reducing":	{"JJ"},
"expensed":	{"VBD","VBN"},
"expenses":	{"NNS","VBZ"},
"expensing":	{"VBG"},
"expensive":	{"JJ"},
"expensive-to-produce":	{"JJ"},
"expensively":	{"RB"},
"expensiveness":	{"NN"},
"experience":	{"NN","VB","VBP"},
"experience-oriented":	{"JJ"},
"experienced":	{"VBN","JJ","VBD"},
"experiences":	{"NNS","VBZ"},
"experiencing":	{"VBG"},
"experient":	{"JJ"},
"experiential":	{"JJ"},
"experientially":	{"RB"},
"experiment":	{"NN","VBP","VB"},
"experimental":	{"JJ"},
"experimental-theater":	{"JJ"},
"experimentalism":	{"NN"},
"experimentally":	{"RB"},
"experimentation":	{"NN"},
"experimentations":	{"NNS"},
"experimented":	{"VBD","VBN"},
"experimenter":	{"NN"},
"experimenters":	{"NNS"},
"experimenting":	{"VBG"},
"experiments":	{"NNS","VBZ"},
"expert":	{"NN","JJ"},
"expertise":	{"NN"},
"expertly":	{"RB"},
"expertness":	{"NN"},
"experts":	{"NNS"},
"expiable":	{"JJ"},
"expiate":	{"VB","VBP"},
"expiated":	{"VBD","VBN"},
"expiates":	{"VBZ"},
"expiating":	{"VBG"},
"expiation":	{"NN"},
"expiative":	{"JJ"},
"expiatory":	{"JJ"},
"expiration":	{"NN"},
"expiration-related":	{"JJ"},
"expirations":	{"NNS"},
"expiratory":	{"JJ"},
"expire":	{"VB","VBP"},
"expired":	{"VBD","VBN"},
"expires":	{"VBZ"},
"expiring":	{"VBG"},
"expiry":	{"NN"},
"explain":	{"VB","VBP"},
"explainable":	{"JJ"},
"explained":	{"VBD","VBN"},
"explaining":	{"VBG"},
"explains":	{"VBZ"},
"explanandum":	{"NN"},
"explanans":	{"NNS"},
"explanation":	{"NN"},
"explanations":	{"NNS"},
"explanatory":	{"JJ"},
"expletive":	{"NN"},
"expletives":	{"NNS"},
"explicable":	{"JJ"},
"explicandum":	{"NN"},
"explicate":	{"VB","VBP"},
"explicated":	{"VBD","VBN"},
"explicates":	{"VBZ"},
"explicating":	{"VBG"},
"explication":	{"NN"},
"explications":	{"NNS"},
"explicit":	{"JJ"},
"explicitly":	{"RB"},
"explicitness":	{"NN"},
"explode":	{"VB","VBP"},
"exploded":	{"JJ","VBD","VBN"},
"explodes":	{"VBZ"},
"exploding":	{"VBG"},
"exploding-wire":	{"JJ"},
"exploit":	{"NN","VB","VBP"},
"exploitation":	{"NN"},
"exploitative":	{"JJ"},
"exploitatory":	{"JJ"},
"exploited":	{"VBD","VBN"},
"exploiter":	{"NN"},
"exploiters":	{"NNS"},
"exploiting":	{"VBG"},
"exploitive":	{"JJ"},
"exploits":	{"VBZ","NNS"},
"exploration":	{"NN"},
"explorations":	{"NNS"},
"explorative":	{"JJ"},
"exploratory":	{"JJ"},
"explore":	{"VB","VBP"},
"explored":	{"VBN","VBD"},
"explorer":	{"NN"},
"explorers":	{"NNS"},
"explores":	{"VBZ"},
"exploring":	{"VBG"},
"explosion":	{"NN"},
"explosions":	{"NNS"},
"explosive":	{"JJ","NN"},
"explosively":	{"RB"},
"explosiveness":	{"NN"},
"explosives":	{"NNS"},
"explusion":	{"NN"},
"expo":	{"NN"},
"exponent":	{"NN"},
"exponential":	{"JJ"},
"exponentially":	{"RB"},
"exponentiation":	{"NN"},
"exponents":	{"NNS"},
"export":	{"NN","VB","VBP"},
"export-applications":	{"NNS"},
"export-boosting":	{"JJ"},
"export-bound":	{"JJ"},
"export-control":	{"JJ","NN"},
"export-driven":	{"JJ"},
"export-license":	{"JJ","NN"},
"export-oriented":	{"JJ"},
"export-promotion":	{"JJ"},
"export-related":	{"JJ"},
"export-subsidy":	{"NN"},
"exportable":	{"JJ"},
"exportation":	{"NN"},
"exported":	{"VBD","VBN"},
"exporter":	{"NN"},
"exporters":	{"NNS"},
"exporting":	{"VBG"},
"exports":	{"NNS","VBZ"},
"expos":	{"NNS"},
"expose":	{"VB","VBP"},
"exposed":	{"VBN","VBD","JJ"},
"exposes":	{"VBZ"},
"exposing":	{"VBG"},
"exposit":	{"VB","VBP"},
"exposited":	{"VBD","VBN"},
"expositing":	{"VBG"},
"exposition":	{"NN"},
"expositions":	{"NNS"},
"expositive":	{"JJ"},
"expositor":	{"NN"},
"expository":	{"JJ","NN"},
"exposits":	{"VBZ"},
"expostulate":	{"VB","VBP"},
"expostulated":	{"VBD","VBN"},
"expostulates":	{"VBZ"},
"expostulating":	{"VBG"},
"expostulation":	{"NN"},
"expostulations":	{"NNS"},
"exposure":	{"NN"},
"exposure-time":	{"NN"},
"exposures":	{"NNS"},
"expound":	{"VB","VBP"},
"expounded":	{"VBD","VBN"},
"expounder":	{"NN"},
"expounding":	{"VBG"},
"expounds":	{"VBZ"},
"express":	{"VB","VBP","JJ","RB","NN"},
"express-delivery":	{"NN"},
"express-mail":	{"NN"},
"expressage":	{"NN"},
"expressed":	{"VBD","VBN"},
"expresses":	{"VBZ","NNS"},
"expressible":	{"JJ"},
"expressing":	{"VBG"},
"expression":	{"NN"},
"expressionism":	{"NN"},
"expressionist":	{"NN","JJ"},
"expressionistic":	{"JJ"},
"expressionists":	{"NNS"},
"expressionless":	{"JJ"},
"expressionlessly":	{"RB"},
"expressions":	{"NNS"},
"expressive":	{"JJ"},
"expressively":	{"RB"},
"expressiveness":	{"NN"},
"expressly":	{"RB"},
"expressway":	{"NN"},
"expressways":	{"NNS"},
"expropriate":	{"VB","VBP"},
"expropriated":	{"VBD","VBN"},
"expropriates":	{"VBZ"},
"expropriating":	{"VBG"},
"expropriation":	{"NN"},
"expropriations":	{"NNS"},
"expulsion":	{"NN"},
"expulsions":	{"NNS"},
"expunction":	{"NN"},
"expunge":	{"VB","VBP"},
"expunged":	{"VBD","VBN"},
"expunges":	{"VBZ"},
"expunging":	{"VBG"},
"expurgate":	{"VB","VBP"},
"expurgated":	{"VBD","VBN","JJ"},
"expurgation":	{"NN"},
"expurgator":	{"NN"},
"exquisite":	{"JJ","NN"},
"exquisitely":	{"RB"},
"exquisiteness":	{"NN"},
"exsanguine":	{"JJ"},
"exsanguinous":	{"JJ"},
"exsert":	{"JJ","VB","VBP"},
"exserted":	{"VBD","VBN","JJ"},
"exsertile":	{"JJ"},
"exserting":	{"VBG"},
"exsertion":	{"NN"},
"exserts":	{"VBZ"},
"exsiccate":	{"VB","VBP"},
"exsiccated":	{"VBD","VBN"},
"exsiccates":	{"VBZ"},
"exsiccating":	{"VBG"},
"exsiccation":	{"NN"},
"exsiccative":	{"JJ"},
"exsiccator":	{"NN"},
"extant":	{"JJ"},
"extemporaneous":	{"JJ"},
"extemporaneously":	{"RB"},
"extemporarily":	{"RB"},
"extemporary":	{"JJ"},
"extempore":	{"JJ","RB"},
"extemporisation":	{"NN"},
"extemporise":	{"VB","VBP"},
"extemporised":	{"VBD","VBN"},
"extemporises":	{"VBZ"},
"extemporising":	{"VBG"},
"extemporization":	{"NN"},
"extemporize":	{"VB","VBP"},
"extemporized":	{"VBD","VBN"},
"extemporizes":	{"VBZ"},
"extemporizing":	{"VBG"},
"extend":	{"VB","VBP"},
"extendable":	{"JJ"},
"extended":	{"VBN","JJ","VBD"},
"extended-body":	{"JJ"},
"extended-care":	{"JJ"},
"extended-payment":	{"NN"},
"extended-range":	{"JJ"},
"extended-wear":	{"JJ"},
"extendible":	{"JJ"},
"extending":	{"VBG"},
"extends":	{"VBZ"},
"extensible":	{"JJ"},
"extensile":	{"JJ"},
"extension":	{"NN"},
"extensional":	{"JJ"},
"extensions":	{"NNS"},
"extensive":	{"JJ"},
"extensively":	{"RB"},
"extensiveness":	{"NN"},
"extensor":	{"NN"},
"extent":	{"NN"},
"extenuate":	{"VB","VBP"},
"extenuated":	{"VBD","VBN"},
"extenuates":	{"VBZ"},
"extenuating":	{"JJ","VBG"},
"extenuation":	{"NN"},
"exterior":	{"NN","JJ"},
"exteriorisation":	{"NN"},
"exteriorise":	{"VB","VBP"},
"exteriorised":	{"VBD","VBN"},
"exteriorises":	{"VBZ"},
"exteriorising":	{"VBG"},
"exteriorization":	{"NN"},
"exteriorize":	{"VB","VBP"},
"exteriorized":	{"VBD","VBN"},
"exteriorizes":	{"VBZ"},
"exteriorizing":	{"VBG"},
"exteriors":	{"NNS"},
"exterminable":	{"JJ"},
"exterminate":	{"VB","VBP"},
"exterminated":	{"VBD","VBN"},
"exterminates":	{"VBZ"},
"exterminating":	{"VBG"},
"extermination":	{"NN"},
"exterminationist":	{"NN"},
"exterminationists":	{"NNS"},
"exterminations":	{"NNS"},
"exterminator":	{"NN"},
"exterminators":	{"NNS"},
"extern":	{"NN","VB","VBP"},
"external":	{"JJ","NN"},
"external-trade":	{"JJ"},
"externalisation":	{"NN"},
"externalise":	{"VB","VBP"},
"externalised":	{"VBD","VBN"},
"externalises":	{"VBZ"},
"externalising":	{"VBG"},
"externality":	{"NN"},
"externalization":	{"NN"},
"externalize":	{"VB","VBP"},
"externalized":	{"VBD","VBN"},
"externalizes":	{"VBZ"},
"externalizing":	{"VBG"},
"externally":	{"RB"},
"externals":	{"NNS"},
"externed":	{"VBD","VBN"},
"externing":	{"VBG"},
"externs":	{"NNS","VBZ"},
"exteroception":	{"NN"},
"exteroceptive":	{"JJ"},
"exteroceptor":	{"NN"},
"exterritorial":	{"JJ"},
"extinct":	{"JJ"},
"extinction":	{"NN"},
"extinguish":	{"VB","VBP"},
"extinguishable":	{"JJ"},
"extinguished":	{"VBD","VBN"},
"extinguisher":	{"NN"},
"extinguishers":	{"NNS"},
"extinguishes":	{"VBZ"},
"extinguishing":	{"VBG"},
"extinguishment":	{"NN"},
"extirpable":	{"JJ"},
"extirpate":	{"VB","VBP"},
"extirpated":	{"VBD","VBN"},
"extirpates":	{"VBZ"},
"extirpating":	{"VBG"},
"extirpation":	{"NN"},
"extol":	{"VB","VBP"},
"extolled":	{"VBD","VBN"},
"extoller":	{"NN"},
"extolling":	{"VBG"},
"extollingly":	{"RB"},
"extolment":	{"NN"},
"extols":	{"VBZ"},
"extort":	{"VB","VBP"},
"extorted":	{"VBD","VBN"},
"extorting":	{"VBG"},
"extortion":	{"NN"},
"extortionate":	{"JJ"},
"extortionately":	{"RB"},
"extortioner":	{"NN"},
"extortionist":	{"NN"},
"extortionists":	{"NNS"},
"extorts":	{"VBZ"},
"extra":	{"JJ","NN","RB","PRP"},
"extra-caffeine":	{"JJ"},
"extra-curricular":	{"JJ"},
"extra-high":	{"JJ"},
"extra-literary":	{"JJ"},
"extra-musical":	{"JJ"},
"extra-nasty":	{"JJ"},
"extra-sensory":	{"JJ"},
"extra-thick":	{"JJ"},
"extracellular":	{"JJ"},
"extract":	{"VB","NN","VBP"},
"extractable":	{"JJ"},
"extracted":	{"VBD","VBN"},
"extractible":	{"JJ"},
"extracting":	{"VBG"},
"extraction":	{"NN"},
"extractor":	{"NN"},
"extractors":	{"NNS"},
"extracts":	{"NNS","VBZ"},
"extracurricular":	{"JJ","NN"},
"extracurriculars":	{"NNS"},
"extradite":	{"VB","VBP"},
"extradited":	{"VBD","VBN"},
"extradites":	{"VBZ"},
"extraditing":	{"VBG"},
"extradition":	{"NN"},
"extraditions":	{"NNS"},
"extrados":	{"NNS"},
"extradural":	{"JJ"},
"extragalactic":	{"JJ"},
"extrajudicial":	{"JJ"},
"extralegal":	{"JJ"},
"extralinguistic":	{"JJ"},
"extramarital":	{"JJ"},
"extramural":	{"JJ"},
"extraneous":	{"JJ"},
"extraneousness":	{"NN"},
"extraordinaire":	{"JJ"},
"extraordinarily":	{"RB"},
"extraordinariness":	{"NN"},
"extraordinary":	{"JJ"},
"extrapolate":	{"VB","VBP"},
"extrapolated":	{"VBD","VBN"},
"extrapolates":	{"VBZ"},
"extrapolating":	{"VBG"},
"extrapolation":	{"NN"},
"extrapolations":	{"NNS"},
"extras":	{"NNS"},
"extrasensory":	{"JJ"},
"extrasystole":	{"NN"},
"extrasystolic":	{"JJ"},
"extraterrestrial":	{"JJ","NN"},
"extraterrestrials":	{"NNS"},
"extraterritorial":	{"JJ"},
"extravagance":	{"NN"},
"extravagancy":	{"NN"},
"extravagant":	{"JJ"},
"extravagantly":	{"RB"},
"extravaganza":	{"NN"},
"extravaganzas":	{"NNS"},
"extravasate":	{"VB","VBP","NN"},
"extravasated":	{"VBD","VBN"},
"extravasates":	{"VBZ"},
"extravasating":	{"VBG"},
"extravasation":	{"NN"},
"extraversion":	{"NN"},
"extraversive":	{"JJ"},
"extravert":	{"NN","JJ"},
"extravertive":	{"JJ"},
"extraverts":	{"NNS"},
"extrema":	{"NNS"},
"extreme":	{"JJ","NN"},
"extremely":	{"RB"},
"extremeness":	{"NN"},
"extremes":	{"NNS"},
"extremis":	{"NN"},
"extremism":	{"NN"},
"extremist":	{"NN","JJ"},
"extremists":	{"NNS"},
"extremities":	{"NNS"},
"extremity":	{"NN"},
"extremophile":	{"NN"},
"extremophiles":	{"NNS"},
"extremum":	{"NN"},
"extricable":	{"JJ"},
"extricate":	{"VB","VBP"},
"extricated":	{"VBD","VBN"},
"extricates":	{"VBZ"},
"extricating":	{"VBG"},
"extrication":	{"NN"},
"extrinsic":	{"JJ"},
"extropic":	{"JJ"},
"extropy":	{"NN"},
"extrospective":	{"JJ"},
"extroversion":	{"NN"},
"extroversive":	{"JJ"},
"extrovert":	{"NN","JJ"},
"extroverted":	{"JJ"},
"extrovertish":	{"JJ"},
"extrovertive":	{"JJ"},
"extroverts":	{"NNS"},
"extrude":	{"VB","VBP"},
"extruded":	{"VBD","VBN"},
"extruder":	{"NN"},
"extrudes":	{"VBZ"},
"extruding":	{"VBG"},
"extrusion":	{"NN"},
"extrusions":	{"NNS"},
"extrusive":	{"JJ"},
"exuberance":	{"NN"},
"exuberant":	{"JJ"},
"exuberantly":	{"RB"},
"exuberate":	{"VB","VBP"},
"exuberated":	{"VBD","VBN"},
"exuberates":	{"VBZ"},
"exuberating":	{"VBG"},
"exudate":	{"NN"},
"exudation":	{"NN"},
"exude":	{"VB","VBP"},
"exuded":	{"VBD","VBN"},
"exudes":	{"VBZ"},
"exuding":	{"VBG"},
"exult":	{"VB","VBP"},
"exultant":	{"JJ"},
"exultantly":	{"RB"},
"exultation":	{"NN"},
"exulted":	{"VBD","VBN"},
"exulting":	{"VBG"},
"exultingly":	{"RB"},
"exults":	{"VBZ"},
"exurbia":	{"NN"},
"exuviae":	{"NN"},
"exuvial":	{"JJ"},
"exuviate":	{"VB","VBP"},
"exuviated":	{"VBD","VBN"},
"exuviates":	{"VBZ"},
"exuviating":	{"VBG"},
"exxon-owned":	{"JJ"},
"exxon-valdez":	{"JJ"},
"eyas":	{"NN"},
"eyasses":	{"NNS"},
"eye":	{"NN","VBP","VB"},
"eye-bath":	{"NN"},
"eye-beaming":	{"NN"},
"eye-beamings":	{"NNS"},
"eye-blink":	{"NN"},
"eye-catcher":	{"NN"},
"eye-catching":	{"JJ"},
"eye-deceiving":	{"JJ"},
"eye-drop":	{"NN"},
"eye-filling":	{"JJ"},
"eye-gouging":	{"NN"},
"eye-level":	{"JJ"},
"eye-liner":	{"NN"},
"eye-lotion":	{"NN"},
"eye-machine":	{"NN"},
"eye-opener":	{"NN"},
"eye-popping":	{"JJ"},
"eye-shade":	{"NN"},
"eye-shadow":	{"NN"},
"eye-strain":	{"NN"},
"eye-teeth":	{"NNS"},
"eye-to-eye":	{"JJ","RB"},
"eye-tooth":	{"NN"},
"eye-undeceiving":	{"NN"},
"eye-wash":	{"NN"},
"eye-watering":	{"JJ"},
"eye-wateringly":	{"RB"},
"eyeball":	{"NN","VBP","VB"},
"eyeballed":	{"VBD","VBN"},
"eyeballing":	{"VBG"},
"eyeballs":	{"NNS","VBZ"},
"eyebath":	{"NN"},
"eyebrow":	{"NN"},
"eyebrows":	{"NNS"},
"eyecup":	{"NN"},
"eyed":	{"VBD","VBN","JJ"},
"eyedness":	{"NN"},
"eyedrop":	{"NN"},
"eyeful":	{"NN"},
"eyefuls":	{"NNS"},
"eyeglass":	{"NN"},
"eyeglasses":	{"NNS"},
"eyehole":	{"NN"},
"eyeing":	{"VBG"},
"eyeish":	{"NN"},
"eyelash":	{"NN"},
"eyelashes":	{"NNS"},
"eyeless":	{"JJ"},
"eyelessness":	{"NN"},
"eyelet":	{"NN"},
"eyelets":	{"NNS"},
"eyelid":	{"NN"},
"eyelids":	{"NNS"},
"eyelike":	{"JJ","NN"},
"eyeline":	{"NN"},
"eyeliner":	{"NN"},
"eyeliners":	{"NNS"},
"eyepatch":	{"NN"},
"eyepiece":	{"NN"},
"eyepieces":	{"NNS"},
"eyes":	{"NNS","VBZ"},
"eyes-only":	{"JJ"},
"eyeshade":	{"NN"},
"eyeshadow":	{"NN"},
"eyeshot":	{"NN"},
"eyesight":	{"NN"},
"eyesore":	{"NN"},
"eyesores":	{"NNS"},
"eyespot":	{"NN"},
"eyestrain":	{"NN"},
"eyeteeth":	{"NNS"},
"eyetooth":	{"NN"},
"eyewash":	{"NN"},
"eyewear":	{"NN"},
"eyewitness":	{"NN"},
"eyewitnesses":	{"NNS"},
"eying":	{"VBG"},
"eyra":	{"NN"},
"eyre":	{"NN"},
"eyrie":	{"NN"},
"eyries":	{"NNS"},
"eyrir":	{"NN"},
"eyry":	{"NN"},
"eysenck":	{"NN"},
"ezechiel":	{"NN"},
"ezed":	{"NN"},
"ezekias":	{"NNS"},
"ezo":	{"NN"},
"ezo-yama-hagi":	{"NN"},
"f":	{"NN","SYM","LS"},
"f-Includes":	{"VBZ"},
"f-includes":	{"VBZ"},
"f-major":	{"NN"},
"f-plane":	{"NN"},
"f.i.s.c.":	{"NN"},
"f.o.b":	{"JJ"},
"fa":	{"NN"},
"faa":	{"NN"},
"fab":	{"JJ"},
"fabaceae":	{"NN"},
"fabiana":	{"NN"},
"fabianism":	{"NN"},
"fable":	{"NN","VB","VBP"},
"fabled":	{"JJ","VBD","VBN"},
"fables":	{"NNS","VBZ"},
"fabling":	{"VBG"},
"fabric":	{"NN"},
"fabricate":	{"VB","VBP"},
"fabricated":	{"VBD","VBN"},
"fabricates":	{"VBZ"},
"fabricating":	{"VBG"},
"fabrication":	{"NN"},
"fabrications":	{"NNS"},
"fabricator":	{"NN"},
"fabricators":	{"NNS"},
"fabrics":	{"NNS"},
"fabulations":	{"NNS"},
"fabulist":	{"NN"},
"fabulous":	{"JJ"},
"fabulously":	{"RB"},
"facade":	{"NN"},
"facades":	{"NNS"},
"face":	{"NN","VB","VBP"},
"face-amount":	{"JJ","NN"},
"face-harden":	{"VB"},
"face-lift":	{"VB","VBP"},
"face-lifted":	{"VBD","VBN"},
"face-lifting":	{"VBG"},
"face-lifts":	{"VBZ"},
"face-off":	{"NN"},
"face-offs":	{"NNS"},
"face-saving":	{"JJ"},
"face-to-face":	{"JJ"},
"face-to-wall":	{"RB"},
"faced":	{"VBD","VBN","JJ"},
"faceless":	{"JJ"},
"facelift":	{"NN"},
"facelifts":	{"NNS"},
"faceoff":	{"NN"},
"faceplate":	{"NN"},
"facer":	{"NN"},
"faces":	{"VBZ","NNS"},
"facet":	{"NN"},
"facet-plane":	{"NN"},
"facet-planes":	{"NNS"},
"faceted":	{"JJ"},
"facetious":	{"JJ"},
"facetiously":	{"RB"},
"facetiousness":	{"NN"},
"facets":	{"NNS"},
"facia":	{"NN"},
"facial":	{"JJ","NN"},
"facially":	{"RB"},
"facials":	{"NNS"},
"facile":	{"JJ"},
"facilitate":	{"VB","VBP"},
"facilitated":	{"VBD","VBN"},
"facilitates":	{"VBZ"},
"facilitating":	{"VBG"},
"facilitation":	{"NN"},
"facilitative":	{"JJ"},
"facilitator":	{"NN"},
"facilitators":	{"NNS"},
"facilitatory":	{"JJ"},
"facilities":	{"NNS"},
"facility":	{"NN"},
"facing":	{"VBG","NN"},
"facings":	{"NNS"},
"facsimile":	{"NN"},
"facsimiles":	{"NNS"},
"facsiport":	{"NN"},
"fact":	{"NN"},
"fact-bound":	{"JJ"},
"fact-finder":	{"NN"},
"fact-finding":	{"JJ"},
"faction":	{"NN"},
"factional":	{"JJ"},
"factions":	{"NNS"},
"factious":	{"JJ"},
"factitious":	{"JJ"},
"facto":	{"FW"},
"factoid":	{"NN"},
"factor":	{"NN","VB","VBP"},
"factored":	{"VBD","VBN"},
"factorial":	{"JJ","NN"},
"factories":	{"NNS"},
"factoring":	{"VBG","NN"},
"factorisation":	{"NN"},
"factorise":	{"VB","VBP"},
"factorised":	{"VBD","VBN"},
"factorises":	{"VBZ"},
"factorising":	{"VBG"},
"factorization":	{"NN"},
"factorize":	{"VB","VBP"},
"factorized":	{"VBD","VBN"},
"factorizes":	{"VBZ"},
"factorizing":	{"VBG"},
"factors":	{"NNS","VBZ"},
"factory":	{"NN"},
"factory-automation":	{"NN"},
"factory-jobs":	{"NNS"},
"factory-like":	{"JJ"},
"factory-made":	{"JJ"},
"factory-modernization":	{"NN"},
"factory-outlet":	{"JJ"},
"factotum":	{"NN"},
"factotums":	{"NNS"},
"facts":	{"NNS"},
"factual":	{"JJ"},
"factuality":	{"NN"},
"factually":	{"RB"},
"factualness":	{"NN"},
"facula":	{"NN"},
"facultative":	{"JJ"},
"faculties":	{"NNS"},
"faculty":	{"NN"},
"faculty-hiring":	{"JJ"},
"fad":	{"NN"},
"faddily":	{"RB"},
"faddish":	{"JJ"},
"faddishly":	{"RB"},
"faddishness":	{"NN"},
"faddist":	{"NN"},
"faddy":	{"JJ"},
"fade":	{"VB","VBP"},
"fade-in":	{"NN"},
"fade-ins":	{"NNS"},
"fade-out":	{"NN"},
"fade-outs":	{"NNS"},
"faded":	{"JJ","VBD","VBN"},
"fades":	{"VBZ"},
"fading":	{"VBG"},
"fado":	{"NN"},
"fads":	{"NNS"},
"fae":	{"IN","NN"},
"faecal":	{"JJ"},
"faecalith":	{"NN"},
"faeces":	{"NN"},
"faerie":	{"NN"},
"faeries":	{"NNS"},
"faery":	{"NN"},
"fag":	{"NN","VB","VBP"},
"fag-end":	{"NN"},
"fag-ends":	{"NNS"},
"fagaceae":	{"NN"},
"fagales":	{"NNS"},
"fagged":	{"JJ","VBD","VBN"},
"fagging":	{"VBG"},
"faggot":	{"NN","VB","VBP"},
"faggoted":	{"VBD","VBN"},
"faggoting":	{"VBG"},
"faggots":	{"NNS","VBZ"},
"fagopyrum":	{"NN"},
"fagot":	{"NN","VB","VBP"},
"fagoted":	{"VBD","VBN"},
"fagoting":	{"NN","VBG"},
"fagots":	{"VBZ"},
"fags":	{"NNS","VBZ"},
"fagus":	{"NN"},
"fahd":	{"NN"},
"faience":	{"NN"},
"fail":	{"VB","VBP","NN"},
"fail-safe":	{"JJ","NN"},
"failed":	{"VBD","VBN","JJ"},
"failing":	{"VBG","NN","IN","JJ"},
"failings":	{"NNS"},
"faille":	{"NN"},
"fails":	{"VBZ","NNS"},
"failure":	{"NN"},
"failure-to-supervise":	{"JJ"},
"failures":	{"NNS"},
"fain":	{"JJ","RB"},
"faineance":	{"NN"},
"faineant":	{"JJ"},
"faint":	{"JJ","VB","VBP","NN"},
"faint-hearted":	{"JJ"},
"fainted":	{"VBD","VBN"},
"fainter":	{"JJR"},
"faintest":	{"JJS","JJ"},
"fainthearted":	{"JJ"},
"faintheartedness":	{"NN"},
"fainting":	{"NN","VBG"},
"faintly":	{"RB"},
"faintness":	{"NN"},
"faints":	{"VBZ"},
"fair":	{"JJ","NN","RB","VB","VBP"},
"fair-and-square":	{"JJ"},
"fair-haired":	{"JJ"},
"fair-looking":	{"JJ"},
"fair-maids-of-france":	{"NN"},
"fair-market":	{"JJ"},
"fair-minded":	{"JJ"},
"fair-mindedness":	{"NN"},
"fair-priced":	{"JJ"},
"fair-sized":	{"JJ"},
"fair-trade-related":	{"JJ"},
"fair-use":	{"JJ"},
"fair-weather":	{"JJ"},
"fairbanks":	{"NNS"},
"faired":	{"VBD","VBN"},
"fairer":	{"JJR"},
"fairest":	{"JJS"},
"fairgoer":	{"NN"},
"fairgoers":	{"NNS"},
"fairground":	{"NN"},
"fairgrounds":	{"NNS"},
"fairies":	{"NNS"},
"fairing":	{"NN","VBG"},
"fairish":	{"JJ"},
"fairlead":	{"NN"},
"fairly":	{"RB"},
"fairness":	{"NN"},
"fairs":	{"NNS","VBZ"},
"fairway":	{"NN"},
"fairways":	{"NNS"},
"fairy":	{"NN","JJ"},
"fairy-land":	{"NN"},
"fairy-slipper":	{"NN"},
"fairy-tale":	{"NN","JJ"},
"fairyland":	{"NN"},
"fairylands":	{"NNS"},
"fairytale":	{"JJ","NN"},
"faisal":	{"NN"},
"faisalabad":	{"NN"},
"fait":	{"FW"},
"faith":	{"NN"},
"faith-based":	{"JJ"},
"faith-cure":	{"NN"},
"faith-healer":	{"NN"},
"faith-healers":	{"NNS"},
"faith-healing":	{"NN"},
"faithful":	{"JJ"},
"faithfully":	{"RB"},
"faithfulness":	{"NN"},
"faithless":	{"JJ","NN"},
"faithlessly":	{"RB"},
"faithlessness":	{"NN"},
"faiths":	{"NNS"},
"fajitas":	{"NNS"},
"fake":	{"JJ","NN","VBP","VB"},
"faked":	{"VBD","VBN"},
"fakeer":	{"NN"},
"faker":	{"NN"},
"fakery":	{"NN"},
"fakes":	{"NNS","VBZ"},
"faking":	{"VBG"},
"fakir":	{"NN"},
"fakirs":	{"NNS"},
"falafel":	{"NN"},
"falanga":	{"NN"},
"falange":	{"NN"},
"falangist":	{"NN"},
"falcate":	{"JJ"},
"falcatifolium":	{"NN"},
"falchion":	{"NN"},
"falciform":	{"JJ"},
"falco":	{"NN"},
"falcon":	{"NN"},
"falcon-gentil":	{"NN"},
"falcon-gentle":	{"NN"},
"falconer":	{"NN"},
"falconers":	{"NNS"},
"falconidae":	{"NN"},
"falconiformes":	{"NNS"},
"falconine":	{"JJ"},
"falconry":	{"NN"},
"falcons":	{"NNS"},
"falderol":	{"NN"},
"falkland":	{"NN"},
"falkner":	{"NN"},
"fall":	{"NN","VB","VBP"},
"fall-blooming":	{"JJ"},
"fall-board":	{"NN"},
"fall-flowering":	{"JJ"},
"fall-off":	{"NN"},
"fall-outs":	{"NNS"},
"fallacies":	{"NNS"},
"fallacious":	{"JJ"},
"fallaciously":	{"RB"},
"fallaciousness":	{"NN"},
"fallacy":	{"NN"},
"fallal":	{"NN"},
"fallback":	{"JJ","NN"},
"fallbacks":	{"NNS"},
"fallboard":	{"NN"},
"fallen":	{"VBN","JJ"},
"faller":	{"NN"},
"fallibility":	{"NN"},
"fallible":	{"JJ"},
"falling":	{"VBG","NN","JJ"},
"falloff":	{"NN"},
"fallon":	{"NN"},
"fallopio":	{"NN"},
"fallot":	{"NN"},
"fallout":	{"NN"},
"fallow":	{"JJ","NN","VBP","VB"},
"fallowed":	{"VBD","VBN"},
"fallowing":	{"VBG"},
"fallows":	{"VBZ"},
"falls":	{"VBZ","NNS"},
"false":	{"JJ","RB"},
"false-fronted":	{"JJ"},
"falsehood":	{"NN"},
"falsehoods":	{"NNS"},
"falsely":	{"RB"},
"falseness":	{"NN"},
"falsetto":	{"NN","RB"},
"falsettos":	{"NNS"},
"falsie":	{"NN"},
"falsifiable":	{"JJ"},
"falsification":	{"NN"},
"falsified":	{"VBD","VBN"},
"falsifier":	{"NN"},
"falsifies":	{"VBZ"},
"falsify":	{"VB","VBP"},
"falsifying":	{"VBG"},
"falsity":	{"NN"},
"falstaffian":	{"JJ"},
"falter":	{"VB","VBP"},
"faltered":	{"VBD","VBN"},
"faltering":	{"JJ","VBG"},
"falteringly":	{"RB"},
"falters":	{"VBZ"},
"falwell":	{"NN"},
"falwell-like":	{"JJ"},
"fame":	{"NN","VB","VBP"},
"famed":	{"JJ","VBN","VBD"},
"fames":	{"VBZ"},
"familial":	{"JJ"},
"familiar":	{"JJ","NN"},
"familiarisation":	{"NN"},
"familiarise":	{"VB","VBP"},
"familiarised":	{"VBD","VBN"},
"familiarises":	{"VBZ"},
"familiarising":	{"VBG"},
"familiarity":	{"NN"},
"familiarization":	{"NN"},
"familiarize":	{"VB","VBP"},
"familiarized":	{"VBD","VBN"},
"familiarizes":	{"VBZ"},
"familiarizing":	{"VBG"},
"familiarly":	{"RB"},
"familiarness":	{"NN"},
"families":	{"NNS"},
"familism":	{"NN"},
"familistical":	{"JJ"},
"famille":	{"FW"},
"family":	{"NN"},
"family-business":	{"NN"},
"family-centered":	{"JJ"},
"family-community":	{"NN"},
"family-entertainment":	{"JJ"},
"family-friendly":	{"JJ","NN"},
"family-oriented":	{"JJ"},
"family-owned":	{"JJ"},
"family-planning":	{"NN"},
"family-run":	{"JJ"},
"family-welfare":	{"NN"},
"famine":	{"NN"},
"famine-relief":	{"NN"},
"famines":	{"NNS"},
"faming":	{"VBG"},
"famish":	{"VB","VBP"},
"famished":	{"JJ","VBD","VBN"},
"famishes":	{"VBZ"},
"famishing":	{"VBG"},
"famishment":	{"NN"},
"famotidine":	{"NN"},
"famous":	{"JJ","NNS"},
"famously":	{"RB"},
"famuli":	{"NNS"},
"famulus":	{"NN"},
"fan":	{"NN","VB","VBP"},
"fan-jet":	{"NN"},
"fan-leafed":	{"JJ"},
"fan-leaved":	{"JJ"},
"fan-shaped":	{"JJ"},
"fanaloka":	{"NN"},
"fanatic":	{"NN","JJ"},
"fanatical":	{"JJ"},
"fanatically":	{"RB"},
"fanaticism":	{"NN"},
"fanatics":	{"NNS"},
"fanbase":	{"NN"},
"fanbases":	{"NNS"},
"fanboy":	{"NN"},
"fanboys":	{"NNS"},
"fancied":	{"VBD","VBN"},
"fancier":	{"NN","JJR"},
"fanciers":	{"NNS"},
"fancies":	{"VBZ","NNS"},
"fanciest":	{"JJS"},
"fancified":	{"VBD","VBN"},
"fancifies":	{"VBZ"},
"fanciful":	{"JJ"},
"fancifully":	{"RB"},
"fancify":	{"VB","VBP"},
"fancifying":	{"VBG"},
"fancy":	{"JJ","NN","VB","VBP"},
"fancy-free":	{"JJ"},
"fancying":	{"VBG"},
"fancywork":	{"NN"},
"fandango":	{"NN"},
"fandangos":	{"NNS"},
"fandom":	{"NN"},
"faneuil":	{"NN"},
"fanfare":	{"NN"},
"fanfares":	{"NNS"},
"fang":	{"NN"},
"fang-like":	{"JJ"},
"fanged":	{"JJ"},
"fangirl":	{"NN"},
"fangirls":	{"NNS"},
"fangs":	{"NNS"},
"fanion":	{"NN"},
"fanjet":	{"NN"},
"fanlight":	{"NN"},
"fanlights":	{"NNS"},
"fanlike":	{"JJ"},
"fanned":	{"VBD","VBN"},
"fannies":	{"NNS"},
"fanning":	{"VBG"},
"fanny":	{"NN"},
"fans":	{"NNS","VBZ"},
"fantabulous":	{"JJ"},
"fantail":	{"NN"},
"fantan":	{"NN"},
"fantasia":	{"NN"},
"fantasias":	{"NNS"},
"fantasied":	{"VBD","VBN"},
"fantasies":	{"NNS","VBZ"},
"fantasise":	{"VB","VBP"},
"fantasised":	{"VBD","VBN"},
"fantasises":	{"VBZ"},
"fantasising":	{"VBG"},
"fantasist":	{"NN"},
"fantasists":	{"NNS"},
"fantasize":	{"VB","VBP"},
"fantasized":	{"VBD","VBN"},
"fantasizes":	{"VBZ"},
"fantasizing":	{"VBG"},
"fantasm":	{"NN"},
"fantast":	{"NN"},
"fantastic":	{"JJ"},
"fantastical":	{"JJ"},
"fantastically":	{"RB"},
"fantasy":	{"NN","VB","VBP"},
"fantasying":	{"VBG"},
"fantod":	{"NN"},
"fantods":	{"NNS"},
"fanweed":	{"NN"},
"fanwort":	{"NN"},
"fao":	{"NN"},
"faq":	{"NN"},
"faqir":	{"NN"},
"faquir":	{"NN"},
"far":	{"RB","JJ"},
"far-afield":	{"JJ"},
"far-away":	{"JJ"},
"far-famed":	{"JJ"},
"far-fetched":	{"JJ"},
"far-flung":	{"JJ"},
"far-from-conciliatory":	{"JJ"},
"far-left":	{"JJ","NN"},
"far-off":	{"JJ"},
"far-out":	{"JJ"},
"far-ranging":	{"JJ"},
"far-reaching":	{"JJ"},
"far-right":	{"JJ"},
"far-sighted":	{"JJ"},
"farad":	{"NN"},
"farandole":	{"NN"},
"faraway":	{"JJ"},
"farawayness":	{"NN"},
"farc":	{"NN"},
"farce":	{"NN","VB","VBP"},
"farced":	{"VBD","VBN"},
"farces":	{"NNS","VBZ"},
"farcical":	{"JJ"},
"farcically":	{"RB"},
"farcing":	{"VBG"},
"farctate":	{"JJ"},
"fardel":	{"NN"},
"fare":	{"NN","VB","VBP"},
"fare-stage":	{"NN"},
"fare-thee-well":	{"NN"},
"fared":	{"VBD","VBN"},
"fares":	{"NNS","VBZ"},
"farewell":	{"NN","UH"},
"farfalle":	{"NN"},
"farfetched":	{"JJ"},
"farflung":	{"NN"},
"fargo":	{"NN"},
"farina":	{"NN"},
"farinaceous":	{"JJ"},
"faring":	{"VBG"},
"farkleberry":	{"NN"},
"farley":	{"NN"},
"farm":	{"NN","VB","VBP"},
"farm-engineering":	{"NN"},
"farm-equipment":	{"NN","JJ"},
"farm-machine":	{"NN"},
"farm-place":	{"NN"},
"farm-policy":	{"NN"},
"farm-product":	{"NN"},
"farm-state":	{"NNP","JJ"},
"farm-subsidy":	{"NN"},
"farm-supply":	{"JJ"},
"farm-trade":	{"JJ"},
"farmed":	{"VBD","VBN"},
"farmer":	{"NN"},
"farmer-type":	{"JJ"},
"farmerette":	{"NN"},
"farmers":	{"NNS"},
"farmhand":	{"NN"},
"farmhands":	{"NNS"},
"farmhouse":	{"NN"},
"farmhouses":	{"NNS"},
"farming":	{"NN","VBG"},
"farmington":	{"NN"},
"farmland":	{"NN"},
"farmlands":	{"NNS"},
"farmplace":	{"NN"},
"farms":	{"NNS","VBZ"},
"farmstead":	{"NN"},
"farmsteads":	{"NNS"},
"farmwives":	{"NNS"},
"farmworker":	{"NN"},
"farmworkers":	{"NNS"},
"farmyard":	{"NN"},
"farmyards":	{"NNS"},
"farness":	{"NN"},
"faro":	{"NN"},
"faroes":	{"NNS"},
"faroese":	{"NN"},
"farrago":	{"NN"},
"farragoes":	{"NNS"},
"farragos":	{"NNS"},
"farragut":	{"NN"},
"farreaching":	{"JJ"},
"farrell":	{"NN"},
"farrier":	{"NN"},
"farriers":	{"NNS"},
"farrow":	{"NN","VB","VBP"},
"farrowed":	{"VBD","VBN"},
"farrowing":	{"VBG"},
"farrowings":	{"NNS"},
"farrows":	{"VBZ"},
"farseeing":	{"JJ"},
"farsighted":	{"JJ","NN"},
"farsightedness":	{"NN"},
"fart":	{"VB","VBP","NN"},
"farted":	{"VBD","VBN"},
"farther":	{"RBR","JJR"},
"farthermost":	{"JJ"},
"farthest":	{"JJS","RBS"},
"farthing":	{"NN"},
"farthingale":	{"NN"},
"farthings":	{"NNS"},
"farting":	{"VBG"},
"fartlek":	{"NN"},
"farts":	{"VBZ","NNS"},
"fas-antigen":	{"NN"},
"fasces":	{"NNS"},
"fascia":	{"NN"},
"fascias":	{"NNS"},
"fascicle":	{"NN"},
"fascicles":	{"NNS"},
"fasciculation":	{"NN"},
"fasciculations":	{"NNS"},
"fascicule":	{"NN"},
"fasciculi":	{"NNS"},
"fasciculus":	{"NN"},
"fascimile-machine":	{"NN"},
"fascinate":	{"VB","VBP"},
"fascinated":	{"JJ","VBN","VBD"},
"fascinates":	{"VBZ"},
"fascinating":	{"JJ","VBG"},
"fascinatingly":	{"RB"},
"fascination":	{"NN"},
"fascinations":	{"NNS"},
"fascinative":	{"JJ"},
"fascio-communist":	{"JJ"},
"fasciola":	{"NN"},
"fascioliasis":	{"NN"},
"fasciolidae":	{"NN"},
"fasciolopsiasis":	{"NN"},
"fasciolopsis":	{"NN"},
"fasciolosis":	{"NN"},
"fascis":	{"NN"},
"fascism":	{"NN"},
"fascist":	{"JJ","NN"},
"fascista":	{"NN"},
"fascistic":	{"JJ"},
"fascists":	{"NNS"},
"fashion":	{"NN","VB","VBP"},
"fashionable":	{"JJ","NN"},
"fashionably":	{"RB"},
"fashioned":	{"JJ","VBD","VBN"},
"fashioning":	{"VBG"},
"fashionless":	{"JJ"},
"fashionmonger":	{"NN"},
"fashions":	{"NNS","VBZ"},
"fast":	{"RB","JJ","NN","VB","VBP"},
"fast-acting":	{"JJ"},
"fast-approaching":	{"JJ"},
"fast-breaking":	{"JJ"},
"fast-closing":	{"JJ"},
"fast-cut":	{"JJ"},
"fast-developing":	{"JJ"},
"fast-firing":	{"JJ"},
"fast-flying":	{"JJ"},
"fast-food":	{"NN"},
"fast-footed":	{"JJ"},
"fast-forward":	{"VB","VBP","NN"},
"fast-forwarded":	{"VBD","VBN"},
"fast-forwarding":	{"VBG"},
"fast-forwards":	{"VBZ"},
"fast-frozen":	{"JJ"},
"fast-grossing":	{"JJ"},
"fast-growing":	{"JJ"},
"fast-moving":	{"JJ","NN"},
"fast-opening":	{"JJ","NN"},
"fast-paced":	{"JJ"},
"fast-rising":	{"JJ"},
"fast-selling":	{"JJ"},
"fast-shrinking":	{"JJ"},
"fast-spreading":	{"JJ"},
"fast-talking":	{"NN"},
"fast-track":	{"JJ","NN","VB","VBP"},
"fast-tracked":	{"VBD","VBN"},
"fast-tracking":	{"VBG"},
"fast-tracks":	{"VBZ"},
"fast-vanishing":	{"JJ"},
"fastball":	{"NN"},
"fastballs":	{"NNS"},
"fasted":	{"VBD","VBN"},
"fasten":	{"VB","VBP"},
"fastened":	{"VBD","VBN"},
"fastener":	{"NN"},
"fasteners":	{"NNS"},
"fastening":	{"NN","VBG"},
"fastenings":	{"NNS"},
"fastens":	{"VBZ"},
"faster":	{"JJR"},
"faster-growing":	{"JJ"},
"faster-spending":	{"JJ"},
"faster-working":	{"JJ"},
"fastest":	{"JJS"},
"fastest-growing":	{"JJ"},
"fastidious":	{"JJ"},
"fastidiously":	{"RB"},
"fastidiousness":	{"NN"},
"fastigheter":	{"FW"},
"fastigiate":	{"JJ"},
"fasting":	{"VBG"},
"fastnacht":	{"NN"},
"fastness":	{"NN"},
"fastnesses":	{"NNS"},
"fastrack":	{"NN"},
"fasts":	{"VBZ","NNS"},
"fat":	{"JJ","NN"},
"fat-free":	{"JJ"},
"fat-soluble":	{"JJ"},
"fat-substitute":	{"JJ"},
"fat-tired":	{"JJ"},
"fatah":	{"NN"},
"fatah-rc":	{"NN"},
"fatal":	{"JJ"},
"fatalism":	{"NN"},
"fatalist":	{"NN"},
"fatalistic":	{"JJ"},
"fatalists":	{"NNS"},
"fatalities":	{"NNS"},
"fatality":	{"NN"},
"fatally":	{"RB"},
"fatback":	{"NN"},
"fatboy":	{"NN"},
"fate":	{"NN","VB","VBP"},
"fated":	{"JJ","VBD","VBN"},
"fateful":	{"JJ"},
"fatefully":	{"RB"},
"fates":	{"NNS","VBZ"},
"fathead":	{"NN"},
"fatheaded":	{"JJ"},
"fatheads":	{"NNS"},
"father":	{"NN","VB","VBP"},
"father-and-son":	{"JJ"},
"father-brother":	{"NN"},
"father-confessor":	{"NN"},
"father-figure":	{"NN"},
"father-figures":	{"NNS"},
"father-god":	{"NN"},
"father-in-law":	{"NN"},
"father-in-laws":	{"NNS"},
"father-murder":	{"NN"},
"father-son":	{"NN"},
"fathered":	{"VBD","VBN"},
"fatherhood":	{"NN"},
"fathering":	{"VBG","NN"},
"fatherland":	{"NN"},
"fatherlands":	{"NNS"},
"fatherless":	{"JJ"},
"fatherlike":	{"JJ"},
"fatherliness":	{"NN"},
"fatherly":	{"JJ"},
"fathers":	{"NNS","VBZ"},
"fathom":	{"VB","VBP","NN"},
"fathomable":	{"JJ"},
"fathomed":	{"VBD","VBN"},
"fathometer":	{"NN"},
"fathoming":	{"VBG"},
"fathoms":	{"VBZ","NNS"},
"fathuh":	{"NN"},
"fatigability":	{"NN"},
"fatigue":	{"NN","VB","VBP"},
"fatigued":	{"JJ","VBD","VBN"},
"fatigues":	{"NNS","VBZ"},
"fatiguing":	{"VBG","JJ"},
"fatiha":	{"NN"},
"fatihah":	{"NN"},
"fatima":	{"NN"},
"fatimah":	{"NN"},
"fatism":	{"NN"},
"fatless":	{"JJ"},
"fatness":	{"NN"},
"fatphobia":	{"NN"},
"fats":	{"NNS","VBZ"},
"fatso":	{"NN"},
"fatsoes":	{"NNS"},
"fatsos":	{"NNS"},
"fatted":	{"VBD","VBN","JJ"},
"fatten":	{"VB","VBP"},
"fattened":	{"VBD","VBN"},
"fattening":	{"JJ","VBG"},
"fattens":	{"VBZ"},
"fatter":	{"JJR"},
"fattest":	{"JJS"},
"fatties":	{"NNS"},
"fattiness":	{"NN"},
"fatting":	{"VBG"},
"fattish":	{"JJ"},
"fattism":	{"NN"},
"fatty":	{"JJ","NN"},
"fatuity":	{"NN"},
"fatuous":	{"JJ"},
"fatuously":	{"RB"},
"fatuousness":	{"NN"},
"fatwa":	{"NN"},
"fatwah":	{"NN"},
"fatwas":	{"NNS"},
"faubourg":	{"NN"},
"faucal":	{"JJ"},
"fauces":	{"NN"},
"faucet":	{"NN"},
"faucets":	{"NNS"},
"fauld":	{"NN"},
"faulknerian":	{"JJ"},
"fault":	{"NN","VB","VBP"},
"fault-tolerant":	{"JJ"},
"faulted":	{"VBN","VBD"},
"faultfinder":	{"NN"},
"faultfinding":	{"NN"},
"faultier":	{"JJR"},
"faultiest":	{"JJS"},
"faultily":	{"RB"},
"faultiness":	{"NN"},
"faulting":	{"VBG"},
"faultless":	{"JJ"},
"faultlessly":	{"RB"},
"faultlessness":	{"NN"},
"faultline":	{"NN"},
"faultlines":	{"NNS"},
"faults":	{"NNS","VBZ"},
"faulty":	{"JJ","NN"},
"faun":	{"NN"},
"fauna":	{"NN"},
"faunas":	{"NNS"},
"fauns":	{"NNS"},
"faunus":	{"NN"},
"fauteuil":	{"NN"},
"fauvism":	{"NN"},
"fauvist":	{"NN"},
"faux":	{"JJ"},
"faveolate":	{"JJ"},
"favism":	{"NN"},
"favor":	{"NN","VBP","VB"},
"favorability":	{"NN"},
"favorable":	{"JJ"},
"favorableness":	{"NN"},
"favorably":	{"RB"},
"favore":	{"FW"},
"favored":	{"VBN","VBD","JJ"},
"favorer":	{"NN"},
"favoring":	{"VBG"},
"favorite":	{"JJ","NN"},
"favorites":	{"NNS"},
"favoritism":	{"NN"},
"favors":	{"VBZ","NNS"},
"favour":	{"NN","VB","VBP"},
"favourable":	{"JJ"},
"favourableness":	{"NN"},
"favourably":	{"RB"},
"favoured":	{"VBD","VBN","JJ"},
"favouring":	{"VBG"},
"favourite":	{"JJ","NN"},
"favourites":	{"NNS"},
"favouritism":	{"NN"},
"favours":	{"NNS","VBZ"},
"favus":	{"NN"},
"fawn":	{"NN","JJ","VB","VBP"},
"fawn-colored":	{"JJ"},
"fawn-coloured":	{"JJ"},
"fawned":	{"VBD","VBN"},
"fawner":	{"NN"},
"fawning":	{"JJ","VBG"},
"fawns":	{"NNS","VBZ"},
"fax":	{"NN","VB","VBP"},
"faxed":	{"VBD","VBN"},
"faxes":	{"NNS","VBZ"},
"faxing":	{"NN","VBG"},
"fay":	{"NN","JJ","VB","VBP"},
"faye":	{"NN"},
"fayed":	{"VBD","VBN"},
"fayette":	{"NN"},
"fayetteville":	{"NN"},
"faying":	{"VBG"},
"fays":	{"NNS","VBZ"},
"faze":	{"VB","VBP"},
"fazed":	{"VBD","VBN"},
"fazes":	{"VBZ"},
"fazing":	{"VBG"},
"fcc":	{"NN"},
"fcs":	{"NNS"},
"fda":	{"NN"},
"fda-approved":	{"JJ"},
"fda-defined":	{"JJ"},
"fda-nih-industry":	{"JJ"},
"fda-regulated":	{"JJ"},
"fdic":	{"NN"},
"fdr":	{"NN"},
"fe":	{"NN"},
"fealty":	{"NN"},
"fear":	{"NN","VB","VBP"},
"fear-filled":	{"JJ"},
"fear-maddened":	{"JJ"},
"feare":	{"NN"},
"feared":	{"VBD","VBN"},
"fearful":	{"JJ"},
"fearfully":	{"RB"},
"fearfulness":	{"NN"},
"fearing":	{"VBG"},
"fearlast":	{"NN"},
"fearless":	{"JJ"},
"fearlessly":	{"RB"},
"fearlessness":	{"NN"},
"fears":	{"NNS","VBZ"},
"fearsome":	{"JJ"},
"fearsomely":	{"RB"},
"feasibility":	{"NN"},
"feasible":	{"JJ"},
"feasibleness":	{"NN"},
"feasibly":	{"RB"},
"feast":	{"NN","VB","VBP"},
"feasted":	{"VBD","VBN"},
"feasting":	{"VBG"},
"feasts":	{"NNS","VBZ"},
"feat":	{"NN"},
"feather":	{"VB","NN","VBP"},
"feather-bedding":	{"NN"},
"feather-foil":	{"NN"},
"feather-like":	{"JJ"},
"featherbed":	{"VB","VBP"},
"featherbedded":	{"VBD","VBN"},
"featherbedding":	{"NN","VBG"},
"featherbeds":	{"VBZ"},
"featherbrained":	{"JJ"},
"feathered":	{"JJ","VBD","VBN"},
"featheredge":	{"NN"},
"featheredged":	{"JJ"},
"featherfoil":	{"NN"},
"featheriness":	{"NN"},
"feathering":	{"NN","VBG"},
"featherless":	{"JJ"},
"featherlike":	{"JJ"},
"feathers":	{"NNS","VBZ"},
"feathertop":	{"NN"},
"featherweight":	{"NN"},
"feathery":	{"JJ","NN"},
"feats":	{"NNS"},
"feature":	{"NN","VBP","VB"},
"featured":	{"VBN","VBD","JJ"},
"featureless":	{"JJ"},
"features":	{"NNS","VBZ"},
"featuring":	{"VBG"},
"febricity":	{"NN"},
"febrifuge":	{"NN","JJ"},
"febrile":	{"JJ"},
"febrility":	{"NN"},
"fecal":	{"JJ"},
"fecalith":	{"NN"},
"feces":	{"NN"},
"fechner":	{"NN"},
"feckless":	{"JJ"},
"fecklessly":	{"RB"},
"fecklessness":	{"NN"},
"fecula":	{"NN"},
"feculence":	{"NN"},
"feculent":	{"JJ"},
"fecund":	{"JJ"},
"fecundate":	{"VB"},
"fecundation":	{"NN"},
"fecundity":	{"NN"},
"fed":	{"VBN","VBD","NN"},
"fed-bashing":	{"NN"},
"fed-watching":	{"JJ"},
"fedayee":	{"NN"},
"fedayeen":	{"NNS"},
"fedelline":	{"NN"},
"federal":	{"JJ","NN"},
"federal-corporate":	{"JJ"},
"federal-court":	{"JJ","NN"},
"federal-formula":	{"JJ"},
"federal-funds":	{"JJ"},
"federal-local":	{"JJ"},
"federal-question":	{"JJ"},
"federal-right":	{"JJ"},
"federal-state":	{"JJ","NN"},
"federal-state-local":	{"JJ"},
"federal-systems":	{"JJ"},
"federalisation":	{"NN"},
"federalise":	{"VB","VBP"},
"federalised":	{"VBD","VBN"},
"federalises":	{"VBZ"},
"federalising":	{"VBG"},
"federalism":	{"NN"},
"federalist":	{"NN"},
"federalists":	{"NNS"},
"federalization":	{"NN"},
"federalize":	{"VB","VBP"},
"federalized":	{"VBD","VBN"},
"federalizes":	{"VBZ"},
"federalizing":	{"VBG"},
"federally":	{"RB"},
"federals":	{"NNS"},
"federate":	{"VB","VBP"},
"federated":	{"VBD","VBN","JJ"},
"federates":	{"VBZ"},
"federating":	{"VBG"},
"federation":	{"NN"},
"federations":	{"NNS"},
"federita":	{"NN"},
"fedora":	{"NN"},
"fedoras":	{"NNS"},
"feds":	{"NNS"},
"fee":	{"NN","VB","VBP"},
"fee-for-service":	{"JJ","NN"},
"fee-forfeiture":	{"NN"},
"fee-per-case":	{"JJ"},
"fee-per-day":	{"NN"},
"fee-producing":	{"JJ","NN"},
"fee-related":	{"JJ"},
"fee-shifting":	{"JJ"},
"fee-tail":	{"NN"},
"feeble":	{"JJ"},
"feeble-minded":	{"JJ"},
"feebleminded":	{"JJ"},
"feeblemindedness":	{"NN"},
"feebleness":	{"NN"},
"feebler":	{"JJR"},
"feeblest":	{"JJS"},
"feebly":	{"RB"},
"feed":	{"VB","NN","VBD","VBN","VBP"},
"feed-grain":	{"NN"},
"feed-lot":	{"JJ"},
"feedback":	{"NN"},
"feedbag":	{"NN"},
"feedbags":	{"NNS"},
"feeder":	{"NN","JJ"},
"feeders":	{"NNS"},
"feeding":	{"VBG","NN"},
"feeding-pain":	{"JJ"},
"feedings":	{"NNS"},
"feedlot":	{"NN"},
"feedlots":	{"NNS"},
"feeds":	{"VBZ","NNS"},
"feedstock":	{"NN"},
"feedstocks":	{"NNS"},
"feeing":	{"VBG"},
"feel":	{"VBP","VB","NN"},
"feel-good":	{"JJ"},
"feel-goodism":	{"NN"},
"feeler":	{"NN"},
"feelers":	{"NNS"},
"feeling":	{"NN","JJ","VBG"},
"feeling-state":	{"NN"},
"feelingly":	{"RB"},
"feelings":	{"NNS"},
"feels":	{"VBZ"},
"fees":	{"NNS","VBZ"},
"feet":	{"NNS"},
"feetfirst":	{"RB"},
"feifer":	{"NN"},
"feign":	{"VB","VBP"},
"feigned":	{"JJ","VBD","VBN"},
"feigning":	{"VBG"},
"feigns":	{"VBZ"},
"feijoa":	{"NN"},
"feint":	{"NN","VB","VBP","JJ"},
"feinted":	{"VBD","VBN"},
"feinting":	{"VBG"},
"feints":	{"VBZ","NNS"},
"feist":	{"NN"},
"feistier":	{"JJR"},
"feistiest":	{"JJS"},
"feistiness":	{"NN"},
"feisty":	{"JJ"},
"felafel":	{"NN"},
"feldene":	{"NN"},
"feldspar":	{"NN"},
"feler":	{"NN"},
"felicia":	{"NN"},
"felicitate":	{"VB","VBP"},
"felicitated":	{"VBD","VBN"},
"felicitates":	{"VBZ"},
"felicitating":	{"VBG"},
"felicitation":	{"NN"},
"felicitations":	{"NNS"},
"felicities":	{"NNS"},
"felicitous":	{"JJ"},
"felicitously":	{"RB"},
"felicitousness":	{"NN"},
"felicity":	{"NN"},
"felid":	{"NN"},
"felidae":	{"NN"},
"feline":	{"JJ","NN"},
"felines":	{"NNS"},
"felis":	{"NN"},
"fell":	{"VBD","JJ","NN","VB","VBP"},
"fella":	{"NN"},
"fellah":	{"NN"},
"fellas":	{"NNS"},
"fellata":	{"NN"},
"fellate":	{"VB","VBP"},
"fellated":	{"VBD","VBN"},
"fellates":	{"VBZ"},
"fellating":	{"VBG"},
"fellatio":	{"NN"},
"fellation":	{"NN"},
"felled":	{"VBD","VBN"},
"feller":	{"NN"},
"fellers":	{"NNS"},
"fellies":	{"NNS"},
"felling":	{"VBG"},
"felloe":	{"NN"},
"felloes":	{"NNS"},
"fellow":	{"NN","JJ"},
"fellow-countryman":	{"NN"},
"fellow-craftsmen":	{"NNS"},
"fellow-creatures":	{"NNS"},
"fellow-employees":	{"NNS"},
"fellow-feeling":	{"NN"},
"fellow-men":	{"NNS"},
"fellow-traveller":	{"NN"},
"fellow-travellers":	{"NNS"},
"fellows":	{"NNS"},
"fellowship":	{"NN"},
"fellowships":	{"NNS"},
"fells":	{"VBZ","NNS"},
"felly":	{"NN"},
"felo-de-se":	{"NN"},
"felon":	{"NN"},
"felonies":	{"NNS"},
"felonious":	{"JJ"},
"felons":	{"NNS"},
"felony":	{"NN"},
"felspar":	{"NN"},
"felt":	{"VBD","VBN","NN","VB","VBP"},
"felt-pen":	{"NN"},
"felt-tip":	{"NN"},
"felt-tips":	{"NNS"},
"felted":	{"VBD","VBN"},
"felting":	{"VBG"},
"felts":	{"VBZ"},
"felucca":	{"NN"},
"felwort":	{"NN"},
"fema":	{"NN"},
"female":	{"JJ","NN"},
"female-dominated":	{"JJ"},
"female-headed":	{"JJ"},
"femaleness":	{"NN"},
"females":	{"NNS"},
"femicide":	{"NN"},
"femicides":	{"NNS"},
"feminine":	{"JJ"},
"feminine-care":	{"JJ"},
"feminineness":	{"NN"},
"femininity":	{"NN"},
"feminisation":	{"NN"},
"feminise":	{"VB","VBP"},
"feminised":	{"VBD","VBN"},
"feminises":	{"VBZ"},
"feminising":	{"VBG"},
"feminism":	{"NN"},
"feminist":	{"JJ","NN"},
"feminists":	{"NNS"},
"feminization":	{"NN"},
"feminize":	{"VB","VBP"},
"feminized":	{"VBD","VBN"},
"feminizes":	{"VBZ"},
"feminizing":	{"VBG"},
"femme":	{"NN"},
"femora":	{"NNS"},
"femoral":	{"JJ"},
"femtochemistry":	{"NN"},
"femtometer":	{"NN"},
"femtometre":	{"NN"},
"femtosecond":	{"NN"},
"femtovolt":	{"NN"},
"femur":	{"NN"},
"femurs":	{"NNS"},
"fen":	{"NN"},
"fence":	{"NN","VBP","VB"},
"fence-line":	{"JJ"},
"fence-sit":	{"NN"},
"fence-sitter":	{"NN"},
"fenced":	{"VBD","VBN"},
"fenced-in":	{"JJ"},
"fencelike":	{"JJ"},
"fencer":	{"NN"},
"fences":	{"NNS","VBZ"},
"fencesitter":	{"NN"},
"fencing":	{"NN","VBG"},
"fend":	{"VB","VBP"},
"fended":	{"VBD","VBN"},
"fender":	{"NN"},
"fender-bender":	{"NN"},
"fender-benders":	{"NNS"},
"fenders":	{"NNS"},
"fending":	{"VBG"},
"fends":	{"VBZ"},
"fenestella":	{"NN"},
"fenestra":	{"NN"},
"fenestral":	{"JJ"},
"fenestration":	{"NN"},
"fengtien":	{"NN"},
"fenland":	{"NN"},
"fennel":	{"NN"},
"fennic":	{"NN"},
"fenoldopam":	{"NN"},
"fenoprofen":	{"NN"},
"fenrir":	{"NN"},
"fens":	{"NNS"},
"fentanyl":	{"NN"},
"fenton":	{"NN"},
"fenugreek":	{"NN"},
"fenusa":	{"NN"},
"feoff":	{"NN"},
"feosol":	{"NN"},
"fer":	{"NN"},
"fer-de-lance":	{"NN"},
"feral":	{"JJ"},
"ferber":	{"NN"},
"fergon":	{"NN"},
"fergusonite":	{"NN"},
"feria":	{"NN"},
"ferial":	{"JJ"},
"ferine":	{"JJ"},
"fermat":	{"NN"},
"fermata":	{"NN"},
"ferment":	{"VB","VBP","NN"},
"fermentable":	{"JJ"},
"fermentation":	{"NN"},
"fermentations":	{"NNS"},
"fermented":	{"VBD","VBN"},
"fermenting":	{"VBG"},
"fermentologist":	{"NN"},
"ferments":	{"VBZ","NNS"},
"fermi":	{"NN"},
"fermion":	{"NN"},
"fermions":	{"NNS"},
"fermium":	{"NN"},
"fern":	{"NN"},
"fern-like":	{"JJ"},
"ferned":	{"JJ"},
"fernery":	{"NN"},
"fernless":	{"JJ"},
"fernlike":	{"JJ","NN"},
"ferns":	{"NNS"},
"ferny":	{"JJ"},
"ferocactus":	{"NNS"},
"ferocious":	{"JJ"},
"ferociously":	{"RB"},
"ferociousness":	{"NN"},
"ferocity":	{"NN"},
"ferranti-led":	{"JJ"},
"ferrara":	{"NN"},
"ferret":	{"NN","VB","VBP"},
"ferret-sized":	{"JJ"},
"ferreted":	{"VBD","VBN"},
"ferreting":	{"VBG"},
"ferrets":	{"VBZ","NNS"},
"ferric":	{"JJ"},
"ferricyanide":	{"NN"},
"ferried":	{"VBD","VBN"},
"ferries":	{"VBZ","NNS"},
"ferrimagnetism":	{"NN"},
"ferrite":	{"NN"},
"ferritin":	{"NN"},
"ferrocerium":	{"NN"},
"ferroconcrete":	{"NN"},
"ferrocyanide":	{"NN"},
"ferroelectric":	{"JJ"},
"ferromagnetic":	{"JJ"},
"ferromagnetism":	{"NN"},
"ferrous":	{"JJ"},
"ferrule":	{"NN"},
"ferrules":	{"NNS"},
"ferry":	{"NN","VB","VBP"},
"ferryboat":	{"NN"},
"ferryboats":	{"NNS"},
"ferrying":	{"VBG"},
"ferryman":	{"NN"},
"fertile":	{"JJ"},
"fertilisation":	{"NN"},
"fertilise":	{"VB","VBP"},
"fertilised":	{"VBD","VBN"},
"fertiliser":	{"NN"},
"fertilisers":	{"NNS"},
"fertilises":	{"VBZ"},
"fertilising":	{"VBG"},
"fertility":	{"NN"},
"fertility-control":	{"JJ"},
"fertilizable":	{"JJ"},
"fertilization":	{"NN"},
"fertilizations":	{"NNS"},
"fertilize":	{"VB","VBP"},
"fertilized":	{"VBD","VBN"},
"fertilizer":	{"NN"},
"fertilizers":	{"NNS"},
"fertilizes":	{"VBZ"},
"fertilizing":	{"VBG"},
"ferule":	{"NN"},
"fervency":	{"NN"},
"fervent":	{"JJ"},
"fervently":	{"RB"},
"fervid":	{"JJ"},
"fervidly":	{"RB"},
"fervidness":	{"NN"},
"fervor":	{"NN"},
"fervour":	{"NN"},
"fes":	{"NN"},
"fescue":	{"NN"},
"fess":	{"VB","VBP","NN"},
"fesse":	{"NN"},
"fessed":	{"VBD","VBN"},
"fesses":	{"VBZ","NNS"},
"fessing":	{"VBG"},
"fest":	{"NN"},
"festal":	{"JJ"},
"fester":	{"VB","VBP"},
"festered":	{"VBD","VBN"},
"festering":	{"VBG"},
"festers":	{"VBZ"},
"festinate":	{"VB","VBP"},
"festinated":	{"VBD","VBN"},
"festinates":	{"VBZ"},
"festinating":	{"VBG"},
"festination":	{"NN"},
"festival":	{"NN"},
"festival-oriented":	{"JJ"},
"festivals":	{"NNS"},
"festive":	{"JJ"},
"festivities":	{"NNS"},
"festivity":	{"NN"},
"festivus":	{"FW"},
"festoon":	{"NN","VB","VBP"},
"festooned":	{"VBD","VBN"},
"festoonery":	{"NN"},
"festooning":	{"VBG"},
"festoons":	{"VBZ","NNS"},
"festschrift":	{"NN"},
"festuca":	{"NN"},
"fet":	{"NN"},
"fetal":	{"JJ"},
"fetal-alcohol":	{"JJ"},
"fetal-protection":	{"JJ"},
"fetal-tissue":	{"JJ","NN"},
"fetal-vulnerability":	{"JJ"},
"fetch":	{"VB","VBP"},
"fetched":	{"VBD","VBN"},
"fetches":	{"VBZ"},
"fetching":	{"JJ","VBG"},
"fetchingly":	{"RB"},
"fete":	{"NN","VB","VBP"},
"feted":	{"VBD","VBN"},
"feterita":	{"NN"},
"fetes":	{"NNS","VBZ"},
"fetich":	{"NN"},
"fetichism":	{"NN"},
"feticide":	{"NN"},
"fetid":	{"JJ","NN"},
"fetidness":	{"NN"},
"feting":	{"VBG"},
"fetish":	{"NN"},
"fetishes":	{"NNS"},
"fetishisation":	{"NN"},
"fetishise":	{"VB","VBP"},
"fetishised":	{"VBD","VBN"},
"fetishises":	{"VBZ"},
"fetishising":	{"VBG"},
"fetishism":	{"NN"},
"fetishist":	{"NN"},
"fetishists":	{"NNS"},
"fetishization":	{"NN"},
"fetishize":	{"VB","VBP"},
"fetishized":	{"VBD","VBN"},
"fetishizes":	{"VBZ"},
"fetishizing":	{"VBG"},
"fetlock":	{"NN"},
"fetlocks":	{"NNS"},
"fetology":	{"NN"},
"fetometry":	{"NN"},
"fetoprotein":	{"NN"},
"fetor":	{"NN"},
"fetoscope":	{"NN"},
"fetoscopy":	{"NN"},
"fetter":	{"VB","VBP","NN"},
"fetterbush":	{"NN"},
"fettered":	{"VBD","VBN"},
"fettering":	{"VBG"},
"fetters":	{"VBZ","NNS"},
"fettle":	{"NN","VB","VBP"},
"fettled":	{"VBD","VBN"},
"fettles":	{"VBZ"},
"fettling":	{"VBG"},
"fettuccine":	{"NN"},
"fettuccini":	{"NN"},
"fetus":	{"NN"},
"fetuses":	{"NNS"},
"feud":	{"NN","VB","VBP"},
"feudal":	{"JJ","NN"},
"feudalisation":	{"NN"},
"feudalise":	{"VB","VBP"},
"feudalised":	{"VBD","VBN"},
"feudalises":	{"VBZ"},
"feudalising":	{"VBG"},
"feudalism":	{"NN"},
"feudalistic":	{"JJ"},
"feudalization":	{"NN"},
"feudalize":	{"VB","VBP"},
"feudalized":	{"VBD","VBN"},
"feudalizes":	{"VBZ"},
"feudalizing":	{"VBG"},
"feudally":	{"RB"},
"feudatory":	{"JJ","NN"},
"feuded":	{"VBD","VBN"},
"feuding":	{"VBG"},
"feuds":	{"NNS","VBZ"},
"fever":	{"NN","VB","VBP"},
"fevered":	{"JJ","VBD","VBN"},
"feverfew":	{"NN"},
"fevering":	{"VBG"},
"feverish":	{"JJ"},
"feverishly":	{"RB"},
"feverishness":	{"NN"},
"feverous":	{"JJ"},
"feverroot":	{"NN"},
"fevers":	{"NNS","VBZ"},
"few":	{"JJ","NN","DT"},
"fewer":	{"JJR"},
"fewer-than-expected":	{"JJ"},
"fewest":	{"JJS"},
"fewness":	{"NN"},
"fey":	{"JJ"},
"feyness":	{"NN"},
"fez":	{"NN"},
"fez-wearing":	{"JJ"},
"fezzes":	{"NNS"},
"fha":	{"NN"},
"fha-backed":	{"JJ"},
"fha-insured":	{"JJ"},
"fhlmc":	{"NN"},
"fiance":	{"NN"},
"fiancee":	{"NN"},
"fiancees":	{"NNS"},
"fiances":	{"NNS"},
"fiasco":	{"NN"},
"fiascoes":	{"NNS"},
"fiascos":	{"NNS"},
"fiat":	{"NN"},
"fiats":	{"NNS"},
"fib":	{"NN","VB","VBP"},
"fibbed":	{"VBD","VBN"},
"fibber":	{"NN"},
"fibbers":	{"NNS"},
"fibbing":	{"VBG"},
"fiber":	{"NN"},
"fiber-coupled":	{"JJ"},
"fiber-end":	{"JJ"},
"fiber-optic":	{"JJ"},
"fiber-optics":	{"NN"},
"fiber-photocathode":	{"NN"},
"fiber-producing":	{"JJ"},
"fiber-reinforced":	{"JJ"},
"fiber-related":	{"JJ"},
"fiberboard":	{"NN"},
"fiberglass":	{"NN"},
"fiberoptic":	{"JJ"},
"fiberoptics":	{"NN"},
"fibers":	{"NNS"},
"fiberscope":	{"NN"},
"fibre":	{"NN"},
"fibre-optic":	{"JJ"},
"fibreboard":	{"NN"},
"fibreglass":	{"NN"},
"fibreoptic":	{"JJ"},
"fibreoptics":	{"NN"},
"fibres":	{"NNS"},
"fibril":	{"NN"},
"fibrillate":	{"VB","VBP"},
"fibrillated":	{"VBD","VBN"},
"fibrillates":	{"VBZ"},
"fibrillating":	{"VBG"},
"fibrillation":	{"NN"},
"fibrillose":	{"JJ"},
"fibrin":	{"NN"},
"fibrinase":	{"NN"},
"fibrinogen":	{"NN"},
"fibrinolysin":	{"NN"},
"fibrinolysis":	{"NN"},
"fibrinopeptide":	{"NN"},
"fibrinous":	{"JJ"},
"fibroadenoma":	{"NN"},
"fibroblast":	{"NN"},
"fibrocalcific":	{"JJ"},
"fibrocartilage":	{"NN"},
"fibrocartilaginous":	{"JJ"},
"fibroid":	{"JJ","NN"},
"fibroids":	{"NNS"},
"fibroma":	{"NN"},
"fibromyositis":	{"NNS"},
"fibrosis":	{"NN"},
"fibrositis":	{"NN"},
"fibrosity":	{"NN"},
"fibrous":	{"JJ"},
"fibrousness":	{"NN"},
"fibs":	{"NNS","VBZ"},
"fibula":	{"NN"},
"fibulae":	{"NNS"},
"fica":	{"NN"},
"fice":	{"NN"},
"fiche":	{"NN"},
"fichu":	{"NN"},
"ficials":	{"NNS"},
"fickle":	{"JJ"},
"fickleness":	{"NN"},
"ficos":	{"NNS"},
"fictile":	{"JJ"},
"fiction":	{"NN"},
"fiction-writer":	{"NN"},
"fiction-writing":	{"NN"},
"fictional":	{"JJ"},
"fictionalisation":	{"NN"},
"fictionalise":	{"VB","VBP"},
"fictionalised":	{"VBD","VBN"},
"fictionalises":	{"VBZ"},
"fictionalising":	{"VBG"},
"fictionalization":	{"NN"},
"fictionalize":	{"VB","VBP"},
"fictionalized":	{"VBD","VBN"},
"fictionalizes":	{"VBZ"},
"fictionalizing":	{"VBG"},
"fictions":	{"NNS"},
"fictitious":	{"JJ"},
"fictitiously":	{"RB"},
"fictive":	{"JJ"},
"ficus":	{"NN","NNS"},
"fiddle":	{"NN","VB","VBP"},
"fiddle-faddle":	{"NN","VB","VBP"},
"fiddle-faddled":	{"VBD","VBN"},
"fiddle-faddler":	{"NN"},
"fiddle-faddles":	{"VBZ"},
"fiddle-faddling":	{"VBG"},
"fiddle-shaped":	{"JJ"},
"fiddled":	{"VBD","VBN"},
"fiddlehead":	{"NN"},
"fiddleneck":	{"NN"},
"fiddler":	{"NN"},
"fiddlers":	{"NNS"},
"fiddles":	{"NNS","VBZ"},
"fiddlestick":	{"NN"},
"fiddlesticks":	{"NNS","UH"},
"fiddling":	{"NN","JJ","VBG"},
"fide":	{"FW","JJ"},
"fidelity":	{"NN"},
"fidget":	{"VB","VBP","NN"},
"fidgeted":	{"VBD","VBN"},
"fidgetiness":	{"NN"},
"fidgeting":	{"VBG"},
"fidgets":	{"VBZ"},
"fidgety":	{"JJ"},
"fiducial":	{"JJ"},
"fiduciary":	{"JJ","NN"},
"fief":	{"NN"},
"fiefdom":	{"NN"},
"fiefdoms":	{"NNS"},
"field":	{"NN","VB","VBP"},
"field-based":	{"JJ"},
"field-crop":	{"JJ"},
"field-crop-seeds":	{"JJ"},
"field-flattening":	{"JJ"},
"field-goal":	{"NN"},
"field-hand":	{"NN"},
"field-hands":	{"NNS"},
"field-officials":	{"NNS"},
"field-sequential":	{"JJ"},
"field-service":	{"JJ"},
"field-services":	{"JJ"},
"field-test":	{"VB","VBP","NN"},
"field-tested":	{"VBD","VBN"},
"field-testing":	{"VBG"},
"field-tests":	{"VBZ","NNS"},
"fielded":	{"VBD","VBN"},
"fielder":	{"NN"},
"fielders":	{"NNS"},
"fieldfare":	{"NN"},
"fieldhand":	{"NN"},
"fielding":	{"VBG"},
"fieldmice":	{"NNS"},
"fieldmouse":	{"NN"},
"fields":	{"NNS","VBZ"},
"fieldsman":	{"NN"},
"fieldsmen":	{"NNS"},
"fieldstone":	{"NN"},
"fieldwork":	{"NN"},
"fieldworker":	{"NN"},
"fieldworkers":	{"NNS"},
"fiend":	{"NN"},
"fiendish":	{"JJ"},
"fiendishly":	{"RB"},
"fiendishness":	{"NN"},
"fierce":	{"JJ"},
"fiercely":	{"RB"},
"fierceness":	{"NN"},
"fiercer":	{"JJR"},
"fiercest":	{"JJS"},
"fierier":	{"JJR"},
"fieriest":	{"JJS"},
"fierily":	{"RB"},
"fieriness":	{"NN"},
"fiery":	{"JJ"},
"fiesta":	{"NN"},
"fiestas":	{"NNS"},
"fife":	{"NN"},
"fifes":	{"NNS"},
"fifo":	{"NN"},
"fifteen":	{"NN","CD"},
"fifteen-mile":	{"JJ"},
"fifteen-minute":	{"JJ"},
"fifteen-sixteenths":	{"NNS"},
"fifteenfold":	{"RB"},
"fifteenth":	{"NN","JJ"},
"fifteenth-century":	{"JJ"},
"fifth":	{"JJ","NN"},
"fifth-best":	{"JJ"},
"fifth-biggest":	{"JJ"},
"fifth-century":	{"JJ"},
"fifth-consecutive":	{"JJ"},
"fifth-generation":	{"JJ"},
"fifth-grade":	{"NN"},
"fifth-highest":	{"JJ"},
"fifth-inning":	{"NN"},
"fifth-largest":	{"JJ"},
"fifth-least":	{"JJ"},
"fifth-straight":	{"JJ"},
"fifthly":	{"RB"},
"fifties":	{"NNS"},
"fiftieth":	{"JJ","NN"},
"fifty":	{"CD","NN"},
"fifty-cent":	{"JJ"},
"fifty-dollar":	{"JJ"},
"fifty-eight":	{"CD","NN"},
"fifty-fifth":	{"JJ"},
"fifty-fifty":	{"RB","JJ"},
"fifty-five":	{"CD","NN"},
"fifty-four":	{"CD","NN"},
"fifty-nine":	{"CD","NN"},
"fifty-ninth":	{"JJ"},
"fifty-odd":	{"JJ"},
"fifty-one":	{"CD","NN"},
"fifty-pound":	{"JJ"},
"fifty-seven":	{"CD","NN"},
"fifty-six":	{"CD","NN"},
"fifty-three":	{"CD","NN"},
"fifty-two":	{"CD","NN"},
"fig":	{"NN"},
"fig-bird":	{"NN"},
"fig-shaped":	{"JJ"},
"fig.":	{"NN"},
"figeater":	{"NN"},
"figger":	{"VBP","VB"},
"fight":	{"NN","VB","VBP"},
"fighter":	{"NN"},
"fighter-bombers":	{"NNS"},
"fighter-jet":	{"NN"},
"fighter-plane":	{"NN"},
"fighters":	{"NNS"},
"fighting":	{"VBG","NN"},
"fights":	{"NNS","VBZ"},
"figment":	{"NN"},
"figs":	{"NNS"},
"figural":	{"JJ","NN"},
"figuration":	{"NN"},
"figurative":	{"JJ"},
"figuratively":	{"RB"},
"figure":	{"NN","VB","VBP"},
"figured":	{"JJ","VBD","VBN"},
"figurehead":	{"NN"},
"figureheads":	{"NNS"},
"figurer":	{"NN"},
"figures":	{"NNS","VBZ"},
"figures-order":	{"NNS","NN"},
"figurine":	{"NN"},
"figurines":	{"NNS"},
"figuring":	{"VBG"},
"figwort":	{"NN"},
"fijis":	{"NNS"},
"filaggrin":	{"NN"},
"filago":	{"NN"},
"filagree":	{"NN"},
"filament":	{"NN"},
"filamentlike":	{"JJ"},
"filamentous":	{"JJ"},
"filaments":	{"NNS"},
"filar":	{"JJ"},
"filaree":	{"NN"},
"filaria":	{"NN"},
"filarial":	{"JJ"},
"filariasis":	{"NN"},
"filariid":	{"JJ"},
"filariidae":	{"NN"},
"filature":	{"NN"},
"filbert":	{"NN"},
"filberts":	{"NNS"},
"filch":	{"VB","VBP"},
"filched":	{"VBD","VBN"},
"filches":	{"VBZ"},
"filching":	{"VBG"},
"file":	{"NN","VB","VBP"},
"file-like":	{"JJ"},
"file-sharing":	{"NN"},
"file-those":	{"NN"},
"filed":	{"VBN","VBD"},
"filefish":	{"NN"},
"filename":	{"NN"},
"filer":	{"NN"},
"filers":	{"NNS"},
"files":	{"NNS","VBZ"},
"filet":	{"NN","VB","VBP"},
"fileted":	{"VBD","VBN"},
"fileting":	{"VBG"},
"filets":	{"NNS","VBZ"},
"filial":	{"JJ"},
"filiale":	{"NN"},
"filiate":	{"VB","VBP"},
"filiated":	{"VBD","VBN"},
"filiates":	{"VBZ"},
"filiating":	{"VBG"},
"filiation":	{"NN"},
"filibuster":	{"NN","VB","VBP"},
"filibustered":	{"VBD","VBN"},
"filibusterer":	{"NN"},
"filibustering":	{"VBG"},
"filibusters":	{"NNS","VBZ"},
"filicales":	{"NNS"},
"filicide":	{"NN"},
"filicinae":	{"NN"},
"filicopsida":	{"NN"},
"filiform":	{"JJ"},
"filigree":	{"NN","VB","VBP"},
"filigreed":	{"VBD","VBN"},
"filigreeing":	{"VBG"},
"filigrees":	{"VBZ"},
"filing":	{"NN","VBG"},
"filings":	{"NNS"},
"fill":	{"VB","VBP","NN"},
"fill-in":	{"NN"},
"fill-in-your-favorite-epithet":	{"JJ"},
"fill-ins":	{"NNS"},
"fill-or-kill":	{"JJ"},
"fillagree":	{"NN"},
"fille":	{"NN"},
"filled":	{"VBN","VBD"},
"filler":	{"NN"},
"fillers":	{"NNS"},
"fillet":	{"NN","VB","VBP"},
"filleted":	{"VBD","VBN"},
"filleting":	{"VBG"},
"fillets":	{"NNS","VBZ"},
"fillies":	{"NNS"},
"filling":	{"VBG","NN","JJ"},
"fillings":	{"NNS"},
"fillip":	{"NN","VB","VBP"},
"filliped":	{"VBD","VBN"},
"filliping":	{"VBG"},
"fillips":	{"VBZ"},
"fills":	{"VBZ","NNS"},
"filly":	{"NN"},
"film":	{"NN","VB","VBP"},
"film-festival":	{"NN"},
"film-make":	{"VB"},
"film-maker":	{"NN"},
"film-makers":	{"NNS"},
"film-making":	{"NN"},
"film-processing":	{"NN"},
"filmable":	{"JJ"},
"filmdom":	{"NN"},
"filmed":	{"VBN","VBD"},
"filmier":	{"JJR"},
"filmiest":	{"JJS"},
"filming":	{"VBG","NN"},
"filmmaker":	{"NN"},
"filmmakers":	{"NNS"},
"filmmaking":	{"NN"},
"films":	{"NNS","VBZ"},
"filmstrip":	{"NN"},
"filmstrips":	{"NNS"},
"filmy":	{"JJ"},
"filoviridae":	{"NN"},
"filovirus":	{"NN"},
"fils":	{"NN"},
"filter":	{"NN","VB","VBP"},
"filter-paper":	{"NN"},
"filter-tip":	{"NN"},
"filter-tipped":	{"JJ"},
"filter-tips":	{"NNS"},
"filtered":	{"VBN","VBD"},
"filtering":	{"VBG"},
"filters":	{"NNS","VBZ"},
"filth":	{"NN"},
"filthier":	{"JJR"},
"filthiest":	{"JJS"},
"filthily":	{"RB"},
"filthiness":	{"NN"},
"filthy":	{"JJ","RB"},
"filtrate":	{"NN","VB","VBP"},
"filtrated":	{"VBD","VBN"},
"filtrates":	{"NNS","VBZ"},
"filtrating":	{"VBG"},
"filtration":	{"NN"},
"filum":	{"NN"},
"fimbria":	{"NN"},
"fimbriate":	{"JJ"},
"fin":	{"NN"},
"fin-syn":	{"JJ"},
"finable":	{"JJ"},
"finagle":	{"VB","VBP"},
"finagled":	{"VBD","VBN"},
"finagler":	{"NN"},
"finagles":	{"VBZ"},
"finagling":	{"VBG","NN"},
"final":	{"JJ","NN"},
"final-hour":	{"JJ"},
"finale":	{"NN"},
"finales":	{"NNS"},
"finalisation":	{"NN"},
"finalise":	{"VB","VBP"},
"finalised":	{"VBD","VBN"},
"finalises":	{"VBZ"},
"finalising":	{"VBG"},
"finalist":	{"NN"},
"finalists":	{"NNS"},
"finality":	{"NN"},
"finalization":	{"NN"},
"finalize":	{"VB","VBP"},
"finalized":	{"VBD","VBN"},
"finalizes":	{"VBZ"},
"finalizing":	{"VBG"},
"finally":	{"RB"},
"finals":	{"NNS"},
"finance":	{"NN","VBP","VB"},
"finance-director":	{"NN"},
"finance-minister":	{"NN"},
"financed":	{"VBN","VBD"},
"financeer":	{"NN"},
"financer":	{"NN"},
"finances":	{"NNS","VBZ"},
"financial":	{"JJ"},
"financial-aid":	{"NN"},
"financial-crimes":	{"NNS"},
"financial-data":	{"JJ"},
"financial-futures":	{"NNS"},
"financial-industrial":	{"JJ"},
"financial-market":	{"JJ","NN"},
"financial-planning":	{"JJ"},
"financial-related":	{"JJ"},
"financial-report":	{"JJ"},
"financial-service":	{"NN","JJ"},
"financial-services":	{"NNS","JJ","NN"},
"financial-support":	{"JJ"},
"financialise":	{"VB","VBP"},
"financialised":	{"VBD","VBN"},
"financialises":	{"VBZ"},
"financialising":	{"VBG"},
"financialization":	{"NN"},
"financialize":	{"VB","VBP"},
"financialized":	{"VBD","VBN"},
"financializes":	{"VBZ"},
"financializing":	{"VBG"},
"financially":	{"RB"},
"financials":	{"NNS"},
"financier":	{"NN"},
"financiers":	{"NNS"},
"financing":	{"NN","VBG"},
"financings":	{"NNS"},
"finback":	{"NN"},
"fincen":	{"NN"},
"finch":	{"NN"},
"finches":	{"NNS"},
"find":	{"VB","VBP","NN"},
"finder":	{"NN"},
"finders":	{"NNS"},
"finding":	{"VBG","NN"},
"findings":	{"NNS"},
"finds":	{"VBZ","NNS"},
"fine":	{"JJ","NN","VB","VBP","RB"},
"fine-art":	{"NN"},
"fine-arts":	{"NNS"},
"fine-boned":	{"JJ"},
"fine-chiseled":	{"JJ"},
"fine-draw":	{"VB","VBP"},
"fine-drawing":	{"VBG"},
"fine-drawn":	{"VBN"},
"fine-draws":	{"VBZ"},
"fine-drew":	{"VBD"},
"fine-feathered":	{"JJ"},
"fine-featured":	{"JJ"},
"fine-grained":	{"JJ"},
"fine-leafed":	{"JJ"},
"fine-leaved":	{"JJ"},
"fine-looking":	{"JJ"},
"fine-point":	{"JJ"},
"fine-textured":	{"JJ"},
"fine-tooth":	{"JJ"},
"fine-toothed":	{"JJ"},
"fine-tune":	{"VB","VBP","NN"},
"fine-tuned":	{"VBD","VBN"},
"fine-tunes":	{"VBZ"},
"fine-tuning":	{"VBG","NN"},
"fineable":	{"JJ"},
"fined":	{"VBN","VBD"},
"finedraw":	{"VB","VBP"},
"finedrawing":	{"VBG"},
"finedrawn":	{"VBN"},
"finedraws":	{"VBZ"},
"finedrew":	{"VBD"},
"finely":	{"RB"},
"finely-spun":	{"JJ"},
"fineness":	{"NN"},
"finer":	{"JJR"},
"finery":	{"NN"},
"fines":	{"NNS","VBZ"},
"finespun":	{"JJ"},
"finesse":	{"NN","VB","VBP"},
"finessed":	{"VBD","VBN"},
"finesses":	{"VBZ"},
"finessing":	{"VBG"},
"finest":	{"JJS"},
"finger":	{"NN","VB","VBP"},
"finger-flower":	{"NN"},
"finger-held":	{"JJ"},
"finger-nail":	{"NN"},
"finger-nails":	{"NNS"},
"finger-paint":	{"NN","VB","VBP"},
"finger-painted":	{"VBD","VBN"},
"finger-painting":	{"NN","VBG"},
"finger-paints":	{"NNS","VBZ"},
"finger-pointing":	{"NN"},
"finger-post":	{"NN"},
"finger-roll":	{"NN"},
"finger-root":	{"NN"},
"finger-sucking":	{"NN"},
"finger-tips":	{"NNS"},
"fingerboard":	{"NN"},
"fingerboards":	{"NNS"},
"fingerbreadth":	{"NN"},
"fingered":	{"VBD","VBN","JJ"},
"fingerflower":	{"NN"},
"fingering":	{"NN","VBG"},
"fingerings":	{"NNS"},
"fingerless":	{"JJ"},
"fingerlike":	{"JJ"},
"fingerling":	{"NN"},
"fingerlings":	{"NNS"},
"fingermark":	{"NN"},
"fingermarks":	{"NNS"},
"fingernail":	{"NN"},
"fingernails":	{"NNS"},
"fingerpaint":	{"NN"},
"fingerpointing":	{"NN"},
"fingerpost":	{"NN"},
"fingerprint":	{"NN","VB","VBP"},
"fingerprinted":	{"VBD","VBN"},
"fingerprinting":	{"NN","VBG"},
"fingerprints":	{"NNS","VBZ"},
"fingerroot":	{"NN"},
"fingers":	{"NNS","VBZ"},
"fingerspelling":	{"NN"},
"fingerstall":	{"NN"},
"fingertip":	{"NN"},
"fingertips":	{"NNS"},
"finial":	{"NN"},
"finical":	{"JJ"},
"finicky":	{"JJ"},
"fining":	{"VBG","NN"},
"finis":	{"NN"},
"finish":	{"VB","NN","VBP"},
"finished":	{"VBD","VBN","JJ"},
"finisher":	{"NN"},
"finishers":	{"NNS"},
"finishes":	{"VBZ","NNS"},
"finishing":	{"VBG","JJ"},
"finishing-school":	{"NN"},
"finite":	{"JJ"},
"finite-dimensional":	{"JJ"},
"finitely":	{"RB"},
"finiteness":	{"NN"},
"finitude":	{"NN"},
"fink":	{"NN","VB","VBP"},
"finked":	{"VBD","VBN"},
"finking":	{"VBG"},
"finks":	{"NNS","VBZ"},
"finnan":	{"NN"},
"finnbogadottir":	{"NN"},
"finned":	{"VBN","VBD","JJ"},
"finnegan":	{"NN"},
"finney":	{"NN"},
"finnic":	{"NN"},
"finning":	{"VBG"},
"finno-ugrian":	{"NN"},
"finno-ugric":	{"NN"},
"finno-ugric-speaking":	{"JJ"},
"finocchio":	{"NN"},
"fins":	{"NNS","VBZ"},
"fiord":	{"NN"},
"fiords":	{"NNS"},
"fipple":	{"NN"},
"fir":	{"NN"},
"fire":	{"NN","VB","VBP"},
"fire-alarm":	{"NN"},
"fire-alarms":	{"NNS"},
"fire-bush":	{"NN"},
"fire-colored":	{"JJ"},
"fire-control":	{"JJ"},
"fire-crackers":	{"NNS"},
"fire-drill":	{"NN"},
"fire-drills":	{"NNS"},
"fire-eater":	{"NN"},
"fire-eaters":	{"NNS"},
"fire-eating":	{"NN"},
"fire-engine":	{"JJ"},
"fire-engines":	{"NNS"},
"fire-escape":	{"NN"},
"fire-escapes":	{"NNS"},
"fire-fighter":	{"NN"},
"fire-fighters":	{"NNS"},
"fire-fighting":	{"NN"},
"fire-irons":	{"NNS"},
"fire-on-the-mountain":	{"NN"},
"fire-raiser":	{"NN"},
"fire-raisers":	{"NNS"},
"fire-raising":	{"NN"},
"fire-resistant":	{"JJ"},
"fire-resisting":	{"JJ"},
"fire-resistive":	{"JJ"},
"fire-retardant":	{"JJ"},
"fire-sale":	{"JJ"},
"fire-swallower":	{"NN"},
"fire-walker":	{"NN"},
"fire-walking":	{"NN"},
"fire-watcher":	{"NN"},
"fire-water":	{"NN"},
"fire-wheel":	{"NN"},
"fire-worship":	{"NN"},
"firearm":	{"NN"},
"firearms":	{"NNS"},
"fireball":	{"NN"},
"fireballs":	{"NNS"},
"firebase":	{"NN"},
"firebird":	{"NN"},
"fireboat":	{"NN"},
"firebomb":	{"NN","VB","VBP"},
"firebombed":	{"VBD","VBN"},
"firebombing":	{"NN","VBG"},
"firebombs":	{"NNS","VBZ"},
"firebox":	{"NN"},
"firebrand":	{"NN"},
"firebrands":	{"NNS"},
"firebrat":	{"NN"},
"firebreak":	{"NN"},
"firebreaks":	{"NNS"},
"firebrick":	{"NN"},
"firebricks":	{"NNS"},
"firebug":	{"NN"},
"firebugs":	{"NNS"},
"fireclay":	{"NN"},
"firecracker":	{"NN"},
"firecrackers":	{"NNS"},
"fired":	{"VBN","VBD"},
"firedamp":	{"NN"},
"firedog":	{"NN"},
"firedrake":	{"NN"},
"firefighter":	{"NN"},
"firefighters":	{"NNS"},
"firefighting":	{"NN"},
"fireflies":	{"NNS"},
"firefly":	{"NN"},
"fireguard":	{"NN"},
"fireguards":	{"NNS"},
"firehoops":	{"NNS"},
"firehouse":	{"NN"},
"firehouses":	{"NNS"},
"firelight":	{"NN"},
"firelighter":	{"NN"},
"firelighters":	{"NNS"},
"firelock":	{"NN"},
"fireman":	{"NN"},
"firemen":	{"NNS"},
"firenze":	{"NN"},
"fireplace":	{"NN"},
"fireplaces":	{"NNS"},
"fireplug":	{"NN"},
"firepower":	{"NN"},
"fireproof":	{"JJ","VB","VBP"},
"fireproofed":	{"VBD","VBN"},
"fireproofing":	{"NN","VBG"},
"fireproofs":	{"VBZ"},
"fireroom":	{"NN"},
"fires":	{"NNS","VBZ"},
"fireside":	{"NN","JJ"},
"firesides":	{"NNS"},
"firestone":	{"NN"},
"firestorm":	{"NN"},
"firestorms":	{"NNS"},
"firethorn":	{"NN"},
"firetrap":	{"NN"},
"firetraps":	{"NNS"},
"firewall":	{"NN"},
"firewalls":	{"NNS"},
"firewater":	{"NN"},
"fireweed":	{"NN"},
"firewood":	{"NN"},
"firework":	{"NN"},
"fireworks":	{"NNS"},
"firing":	{"VBG","NN"},
"firing-line":	{"NN"},
"firing-lines":	{"NNS"},
"firing-squad":	{"NN"},
"firing-squads":	{"NNS"},
"firings":	{"NNS"},
"firkin":	{"NN"},
"firm":	{"NN","JJ","VB","VBP","RB"},
"firma":	{"FW","NN"},
"firmament":	{"NN"},
"firmamental":	{"JJ"},
"firmed":	{"VBD","VBN"},
"firmer":	{"JJR"},
"firmest":	{"JJS"},
"firmiana":	{"NN"},
"firming":	{"VBG"},
"firmly":	{"RB"},
"firmness":	{"NN"},
"firms":	{"NNS","VBZ"},
"firmware":	{"NN"},
"firmwide":	{"RB"},
"first":	{"DT","PRP","RB","NN","JJ"},
"first-aid":	{"JJ"},
"first-amendment":	{"JJ"},
"first-born":	{"NN","JJ"},
"first-borns":	{"NNS"},
"first-class":	{"JJ","RB","NN"},
"first-come-first-served":	{"JJ"},
"first-degree":	{"JJ"},
"first-ever":	{"JJ"},
"first-floor":	{"NN"},
"first-floors":	{"NNS"},
"first-grade":	{"JJ"},
"first-grader":	{"NN"},
"first-graders":	{"NNS"},
"first-hand":	{"JJ","RB"},
"first-name":	{"JJ"},
"first-nighter":	{"NN"},
"first-person":	{"JJ"},
"first-rate":	{"JJ","NN"},
"first-rateness":	{"NN"},
"first-rater":	{"NN"},
"first-rates":	{"NNS"},
"first-run":	{"JJ"},
"first-strike":	{"JJ"},
"first-string":	{"JJ"},
"first-tier":	{"JJ"},
"first-time":	{"JJ"},
"firstborn":	{"NN","JJ"},
"firstfruits":	{"NNS"},
"firsthand":	{"JJ","RB"},
"firstie":	{"NN"},
"firsties":	{"NNS"},
"firstly":	{"RB"},
"firsts":	{"NNS"},
"firth":	{"NN"},
"firzite":	{"NN"},
"fisa":	{"NN"},
"fisc":	{"NN"},
"fiscal":	{"JJ"},
"fiscal-agent":	{"NN"},
"fiscal-first":	{"JJ"},
"fiscal-first-quarter":	{"JJ"},
"fiscal-fourth":	{"JJ"},
"fiscal-third":	{"JJ"},
"fiscal-year":	{"NN"},
"fiscally":	{"RB"},
"fischer":	{"NN"},
"fish":	{"NN","VB","VBP","NNS"},
"fish-export":	{"JJ"},
"fish-farm":	{"NN"},
"fish-fly":	{"NN"},
"fish-kettle":	{"NN"},
"fish-kettles":	{"NNS"},
"fish-knife":	{"NN"},
"fish-knives":	{"NNS"},
"fish-processing":	{"JJ"},
"fish-slice":	{"NN"},
"fish-slices":	{"NNS"},
"fish-worship":	{"NN"},
"fishapod":	{"NN"},
"fishapods":	{"NNS"},
"fishbone":	{"NN"},
"fishbowl":	{"NN"},
"fishbowls":	{"NNS"},
"fished":	{"VBD","VBN"},
"fisher":	{"NN"},
"fisheries":	{"NNS"},
"fisherman":	{"NN"},
"fishermen":	{"NNS"},
"fishers":	{"NNS"},
"fishery":	{"NN"},
"fishes":	{"NNS","VBZ"},
"fisheye":	{"NN"},
"fishgig":	{"NN"},
"fishhook":	{"NN"},
"fishhooks":	{"NNS"},
"fishier":	{"JJR"},
"fishiest":	{"JJS"},
"fishily":	{"RB"},
"fishing":	{"NN","VBG"},
"fishing-boat":	{"NN"},
"fishing-rod":	{"NN"},
"fishing-rods":	{"NNS"},
"fishing-tackle":	{"NN"},
"fishman":	{"NN"},
"fishmen":	{"NNS"},
"fishmonger":	{"NN"},
"fishmongers":	{"NNS"},
"fishnet":	{"NN"},
"fishpaste":	{"NN"},
"fishplate":	{"NN"},
"fishpond":	{"NN"},
"fishtail":	{"NN","VB","VBP"},
"fishtailed":	{"VBD","VBN"},
"fishtailing":	{"VBG"},
"fishtails":	{"NNS","VBZ"},
"fishwife":	{"NN"},
"fishwives":	{"NNS"},
"fishworm":	{"NN"},
"fishy":	{"JJ"},
"fisk":	{"VB","VBP"},
"fissile":	{"JJ"},
"fission":	{"NN"},
"fissionable":	{"JJ"},
"fissiparity":	{"NN"},
"fissiparous":	{"JJ"},
"fissiped":	{"NN"},
"fissipedia":	{"NN"},
"fissure":	{"NN","VB","VBP"},
"fissured":	{"VBN","VBD","JJ"},
"fissurella":	{"NN"},
"fissurellidae":	{"NN"},
"fissures":	{"NNS","VBZ"},
"fissuring":	{"VBG"},
"fist":	{"NN","VB","VBP"},
"fist-fighting":	{"NN"},
"fisted":	{"VBD","VBN"},
"fistfight":	{"NN"},
"fistful":	{"NN"},
"fistfuls":	{"NNS"},
"fisticuffs":	{"NN","NNS"},
"fisting":	{"VBG"},
"fistmele":	{"NN"},
"fists":	{"NNS","VBZ"},
"fistula":	{"NN"},
"fistular":	{"JJ"},
"fistularia":	{"NN"},
"fistulariidae":	{"NN"},
"fistulate":	{"JJ"},
"fistulina":	{"NN"},
"fistulinaceae":	{"NN"},
"fistulous":	{"JJ"},
"fit":	{"VB","NN","VBP","VBN","JJ","VBD","VBN"},
"fit-looking":	{"JJ"},
"fitch":	{"NN"},
"fitful":	{"JJ"},
"fitfully":	{"RB"},
"fitfulness":	{"NN"},
"fitly":	{"RB"},
"fitment":	{"NN"},
"fitments":	{"NNS"},
"fitness":	{"NN"},
"fitness-promoting":	{"JJ"},
"fits":	{"VBZ","NNS"},
"fitted":	{"JJ","VBD","VBN"},
"fitter":	{"NN","JJR"},
"fitters":	{"NNS"},
"fittest":	{"JJS"},
"fitting":	{"JJ","NN","VBG"},
"fittingly":	{"RB"},
"fittingness":	{"NN"},
"fittings":	{"NNS"},
"five":	{"CD","LS","PRP"},
"five-a-week":	{"JJ"},
"five-and-a-half":	{"NN"},
"five-and-dime":	{"JJ","NN"},
"five-and-twenty":	{"JJ"},
"five-blade":	{"JJ"},
"five-block":	{"JJ"},
"five-by-eight-inch":	{"JJ"},
"five-cent":	{"JJ"},
"five-column":	{"JJ"},
"five-consecutive":	{"JJ"},
"five-coordinate":	{"JJ"},
"five-count":	{"JJ"},
"five-course":	{"JJ"},
"five-cylinder":	{"JJ"},
"five-day":	{"JJ"},
"five-days-a-week":	{"JJ"},
"five-finger":	{"NN"},
"five-fold":	{"JJ"},
"five-foot":	{"JJ"},
"five-foot-wide":	{"JJ"},
"five-gallon":	{"JJ"},
"five-game":	{"JJ"},
"five-hitter":	{"NN"},
"five-home":	{"JJ"},
"five-home-run":	{"JJ"},
"five-hour":	{"JJ"},
"five-hundred-dollar":	{"JJ"},
"five-hundred-year-old":	{"JJ"},
"five-hundredth":	{"JJ"},
"five-inch":	{"JJ"},
"five-judge":	{"JJ"},
"five-lobed":	{"JJ"},
"five-member":	{"JJ"},
"five-membered":	{"JJ"},
"five-mile":	{"JJ"},
"five-minute":	{"JJ"},
"five-month":	{"JJ"},
"five-month-old":	{"JJ"},
"five-nation":	{"JJ"},
"five-needled":	{"JJ"},
"five-party":	{"JJ"},
"five-percentage-point":	{"JJ"},
"five-person":	{"JJ"},
"five-petaled":	{"JJ"},
"five-petalled":	{"JJ"},
"five-pfennig":	{"JJ"},
"five-ply":	{"JJ"},
"five-point":	{"JJ"},
"five-pointed":	{"JJ"},
"five-pound":	{"JJ"},
"five-round":	{"JJ"},
"five-row":	{"JJ"},
"five-session":	{"JJ","NN"},
"five-seventeen":	{"JJ"},
"five-sided":	{"JJ"},
"five-speed":	{"JJ"},
"five-spot":	{"NN"},
"five-star":	{"JJ"},
"five-story":	{"JJ"},
"five-volume":	{"JJ"},
"five-week":	{"JJ"},
"five-year-old":	{"JJ","NN"},
"five-years":	{"NNS"},
"fivefold":	{"JJ"},
"fivepence":	{"NN"},
"fiver":	{"NN"},
"fivers":	{"NNS"},
"fives":	{"NN"},
"fivesome":	{"NN"},
"fix":	{"VB","NN","VBP"},
"fixable":	{"JJ"},
"fixate":	{"VB","VBP"},
"fixated":	{"VBD","VBN","JJ"},
"fixates":	{"VBZ"},
"fixating":	{"VBG"},
"fixation":	{"NN"},
"fixations":	{"NNS"},
"fixative":	{"JJ","NN"},
"fixatives":	{"NNS"},
"fixed":	{"VBN","JJ","VBD"},
"fixed-dollar":	{"JJ"},
"fixed-income":	{"NN"},
"fixed-price":	{"JJ"},
"fixed-rate":	{"JJ","NN"},
"fixed-repayment":	{"JJ"},
"fixed-term":	{"NN"},
"fixedly":	{"RB"},
"fixedness":	{"NN"},
"fixedrate":	{"JJ","NN"},
"fixer":	{"NN"},
"fixer-upper":	{"NN"},
"fixers":	{"NNS"},
"fixes":	{"VBZ","NNS"},
"fixing":	{"VBG"},
"fixings":	{"NNS"},
"fixity":	{"NN"},
"fixture":	{"NN"},
"fixtures":	{"NNS"},
"fizgig":	{"NN"},
"fizz":	{"VB","VBP","NN"},
"fizzed":	{"VBD","VBN"},
"fizzes":	{"NNS","VBZ"},
"fizzier":	{"JJR"},
"fizziest":	{"JJS"},
"fizziness":	{"NN"},
"fizzing":	{"VBG"},
"fizzle":	{"VB","VBP","NN"},
"fizzled":	{"VBD","VBN"},
"fizzles":	{"VBZ","NNS"},
"fizzling":	{"VBG"},
"fizzy":	{"JJ"},
"fjord":	{"NN"},
"fjords":	{"NNS"},
"fl":	{"NN"},
"flab":	{"NN"},
"flabbergast":	{"VB","VBP"},
"flabbergasted":	{"VBD","VBN","JJ"},
"flabbergasting":	{"VBG"},
"flabbergasts":	{"VBZ"},
"flabbier":	{"JJR"},
"flabbiest":	{"JJS"},
"flabbily":	{"RB"},
"flabbiness":	{"NN"},
"flabby":	{"JJ"},
"flaccid":	{"JJ"},
"flaccidity":	{"NN"},
"flack":	{"NN"},
"flacks":	{"NNS"},
"flacourtia":	{"NN"},
"flacourtiaceae":	{"NN"},
"flag":	{"NN","VB","VBP"},
"flag-burner":	{"NN"},
"flag-burning":	{"NN"},
"flag-stick":	{"NN"},
"flag-waver":	{"NN"},
"flag-wavers":	{"NNS"},
"flag-waving":	{"NN"},
"flagellant":	{"NN"},
"flagellants":	{"NNS"},
"flagellata":	{"NN"},
"flagellate":	{"VB","VBP"},
"flagellated":	{"JJ","VBD","VBN"},
"flagellates":	{"VBZ"},
"flagellating":	{"VBG"},
"flagellation":	{"NN"},
"flagellum":	{"NN"},
"flageolet":	{"NN"},
"flagfish":	{"NN"},
"flagged":	{"JJ","VBD","VBN"},
"flagging":	{"JJ","NN","VBG"},
"flagitious":	{"JJ"},
"flagon":	{"NN"},
"flagons":	{"NNS"},
"flagpole":	{"NN"},
"flagpoles":	{"NNS"},
"flagrant":	{"JJ"},
"flagrante":	{"RB"},
"flagrantly":	{"RB"},
"flagroot":	{"NN"},
"flags":	{"NNS","VBZ"},
"flagship":	{"NN"},
"flagships":	{"NNS"},
"flagstaff":	{"NN"},
"flagstaffs":	{"NNS"},
"flagstone":	{"NN"},
"flagstones":	{"NNS"},
"flail":	{"VB","VBP","NN"},
"flailed":	{"VBD","VBN"},
"flailing":	{"VBG"},
"flails":	{"VBZ","NNS"},
"flair":	{"NN"},
"flak":	{"NN"},
"flake":	{"NN","VB","VBP"},
"flaked":	{"VBD","VBN"},
"flakes":	{"NNS","VBZ"},
"flakey":	{"JJ"},
"flakier":	{"JJR"},
"flakiest":	{"JJS"},
"flakiness":	{"NN"},
"flaking":	{"VBG"},
"flaky":	{"JJ"},
"flambe":	{"NN"},
"flambeau":	{"NN"},
"flamboyance":	{"NN"},
"flamboyant":	{"JJ"},
"flamboyantly":	{"RB"},
"flame":	{"NN","VB","VBP"},
"flame-colored":	{"JJ"},
"flame-coloured":	{"JJ"},
"flame-flower":	{"NN"},
"flame-orange":	{"JJ"},
"flame-out":	{"NN"},
"flame-retardant":	{"JJ"},
"flame-throwers":	{"NNS"},
"flamed":	{"VBD","VBN"},
"flamefish":	{"NN"},
"flameflower":	{"NN"},
"flamen":	{"NN"},
"flamenco":	{"NN"},
"flamencos":	{"NNS"},
"flameproof":	{"JJ"},
"flames":	{"NNS","VBZ"},
"flamethrower":	{"NN"},
"flaming":	{"JJ","VBG"},
"flamingo":	{"NN"},
"flamingoes":	{"NNS"},
"flamingos":	{"NNS"},
"flaminius":	{"NNS"},
"flammability":	{"NN"},
"flammable":	{"JJ"},
"flammulina":	{"NN"},
"flan":	{"NN"},
"flange":	{"NN"},
"flanges":	{"NNS"},
"flank":	{"NN","VB","VBP"},
"flanked":	{"VBD","VBN"},
"flanker":	{"NN"},
"flanking":	{"VBG"},
"flanks":	{"NNS","VBZ"},
"flannel":	{"NN","VBP","VB"},
"flannel-cake":	{"NN"},
"flannelbush":	{"NN"},
"flanneled":	{"VBD","VBN"},
"flannelette":	{"NN"},
"flanneling":	{"VBG"},
"flannelled":	{"VBD","VBN"},
"flannelling":	{"VBG"},
"flannels":	{"NNS","VBZ"},
"flans":	{"NNS"},
"flap":	{"NN","VB","VBP"},
"flapcake":	{"NN"},
"flapjack":	{"NN"},
"flapjacks":	{"NNS"},
"flapped":	{"VBD","VBN"},
"flapper":	{"NN"},
"flappers":	{"NNS"},
"flapping":	{"VBG"},
"flaps":	{"NNS","VBZ"},
"flare":	{"VB","VBP","NN"},
"flare-off":	{"NN"},
"flare-path":	{"NN"},
"flare-up":	{"NN"},
"flare-ups":	{"NNS"},
"flared":	{"VBD","VBN","JJ"},
"flares":	{"NNS","VBZ"},
"flaring":	{"JJ","VBG"},
"flash":	{"NN","VB","VBP","JJ"},
"flash-bulb":	{"NN"},
"flash-bulbs":	{"NNS"},
"flash-cubes":	{"NNS"},
"flash-forward":	{"NN"},
"flash-freeze":	{"VB"},
"flash-frozen":	{"JJ"},
"flashback":	{"NN"},
"flashbacks":	{"NNS"},
"flashboard":	{"NN"},
"flashboarding":	{"NN"},
"flashbulb":	{"NN"},
"flashbulbs":	{"NNS"},
"flashcard":	{"NN"},
"flashcards":	{"NNS"},
"flashed":	{"VBD","VBN"},
"flasher":	{"NN"},
"flashers":	{"NNS"},
"flashes":	{"NNS","VBZ"},
"flashflood":	{"NN"},
"flashgun":	{"NN"},
"flashguns":	{"NNS"},
"flashier":	{"JJR"},
"flashiest":	{"JJS"},
"flashily":	{"RB"},
"flashiness":	{"NN"},
"flashing":	{"JJ","VBG"},
"flashlight":	{"NN"},
"flashlight-type":	{"JJ"},
"flashlights":	{"NNS"},
"flashmob":	{"NN"},
"flashmobbing":	{"NN"},
"flashmobs":	{"NNS"},
"flashover":	{"NN"},
"flashpoint":	{"NN"},
"flashpoints":	{"NNS"},
"flashy":	{"JJ"},
"flask":	{"NN"},
"flaskful":	{"NN"},
"flasks":	{"NNS"},
"flat":	{"JJ","RB","NN"},
"flat-bed":	{"JJ","NN"},
"flat-bellied":	{"JJ"},
"flat-bottom":	{"JJ"},
"flat-bottomed":	{"JJ"},
"flat-footed":	{"JJ"},
"flat-growing":	{"JJ"},
"flat-headed":	{"JJ"},
"flat-mate":	{"NN"},
"flat-mates":	{"NNS"},
"flat-out":	{"JJ","RB"},
"flat-panel":	{"JJ"},
"flat-rolled":	{"JJ"},
"flat-to-lower":	{"JJ"},
"flat-top":	{"NN"},
"flat-topped":	{"JJ"},
"flatbed":	{"JJ","NN"},
"flatbeds":	{"NNS"},
"flatboat":	{"NN"},
"flatbottom":	{"JJ"},
"flatbottomed":	{"JJ"},
"flatbread":	{"NN"},
"flatbrod":	{"NN"},
"flatcar":	{"NN"},
"flatcars":	{"NNS"},
"flatfish":	{"NN","NNS"},
"flatfoot":	{"NN"},
"flathead":	{"NN","NNS"},
"flatiron":	{"NN"},
"flatish":	{"JJ"},
"flatland":	{"NN"},
"flatlands":	{"NNS"},
"flatlet":	{"NN"},
"flatlets":	{"NNS"},
"flatline":	{"VB","VBP"},
"flatlined":	{"VBD","VBN"},
"flatlines":	{"VBZ"},
"flatlining":	{"VBG"},
"flatly":	{"RB"},
"flatmate":	{"NN"},
"flatmates":	{"NNS"},
"flatness":	{"NN"},
"flatout":	{"JJ","RB"},
"flats":	{"NNS","VBZ"},
"flatted":	{"VBD","VBN"},
"flatten":	{"VB","VBP"},
"flattened":	{"VBD","VBN","JJ"},
"flattening":	{"VBG"},
"flattens":	{"VBZ"},
"flatter":	{"VB","VBP","JJR"},
"flattered":	{"VBN","JJ","VBD"},
"flatterer":	{"NN"},
"flatterers":	{"NNS"},
"flattering":	{"JJ","VBG"},
"flatteringly":	{"RB"},
"flatters":	{"VBZ"},
"flattery":	{"NN"},
"flattest":	{"JJS"},
"flatting":	{"VBG","NN"},
"flattish":	{"JJ"},
"flattop":	{"NN"},
"flattops":	{"NNS"},
"flatulence":	{"NN"},
"flatulency":	{"NN"},
"flatulent":	{"JJ"},
"flatus":	{"NN"},
"flatus-relieving":	{"JJ"},
"flatware":	{"NN"},
"flatwood":	{"NN"},
"flatwoods":	{"NNS"},
"flatwork":	{"NN"},
"flatworm":	{"NN"},
"flaunt":	{"VB","VBP"},
"flaunt-your-wealth":	{"JJ"},
"flaunted":	{"VBD","VBN"},
"flaunting":	{"VBG"},
"flaunts":	{"VBZ"},
"flaunty":	{"JJ"},
"flautist":	{"NN"},
"flautists":	{"NNS"},
"flavin":	{"NN"},
"flaviviridae":	{"NN"},
"flavivirus":	{"NN"},
"flavone":	{"NN"},
"flavonoid":	{"NN"},
"flavor":	{"NN","VB","VBP"},
"flavored":	{"VBD","VBN","JJ"},
"flavorer":	{"NN"},
"flavorful":	{"JJ"},
"flavoring":	{"NN","VBG"},
"flavorings":	{"NNS"},
"flavorless":	{"JJ"},
"flavorlessness":	{"NN"},
"flavorous":	{"JJ"},
"flavors":	{"NNS","VBZ"},
"flavorsome":	{"JJ"},
"flavorsomeness":	{"NN"},
"flavour":	{"NN","VB","VBP"},
"flavoured":	{"VBD","VBN","JJ"},
"flavourer":	{"NN"},
"flavourful":	{"JJ"},
"flavouring":	{"NN","VBG"},
"flavourings":	{"NNS"},
"flavourless":	{"JJ"},
"flavourlessness":	{"NN"},
"flavourous":	{"JJ"},
"flavours":	{"NNS","VBZ"},
"flavoursome":	{"JJ"},
"flavoursomeness":	{"NN"},
"flaw":	{"NN","VB","VBP"},
"flawed":	{"JJ","VBD","VBN"},
"flawing":	{"VBG"},
"flawless":	{"JJ"},
"flawlessly":	{"RB"},
"flawlessness":	{"NN"},
"flaws":	{"NNS","VBZ"},
"flax":	{"NN"},
"flaxedil":	{"NN"},
"flaxen":	{"JJ"},
"flaxseed":	{"NN"},
"flay":	{"VB","VBP"},
"flayed":	{"VBD","VBN"},
"flaying":	{"VBG"},
"flays":	{"VBZ"},
"flea":	{"NN"},
"flea-bite":	{"NN"},
"flea-bitten":	{"JJ"},
"flea-infested":	{"JJ"},
"flea-pit":	{"NN"},
"flea-pits":	{"NNS"},
"fleabag":	{"NN"},
"fleabags":	{"NNS"},
"fleabane":	{"NN"},
"fleapit":	{"NN"},
"fleapits":	{"NNS"},
"fleas":	{"NNS"},
"fleawort":	{"NN"},
"flecainide":	{"NN"},
"fleck":	{"NN","VB","VBP"},
"flecked":	{"JJ","VBD","VBN"},
"flecking":	{"VBG"},
"flecks":	{"NNS","VBZ"},
"flection":	{"NN"},
"fled":	{"VBD","VBN"},
"fledge":	{"VB","VBP"},
"fledged":	{"JJ","VBD","VBN"},
"fledgeless":	{"JJ"},
"fledgeling":	{"JJ","NN"},
"fledgelings":	{"NNS"},
"fledges":	{"VBZ"},
"fledging":	{"VBG"},
"fledgling":	{"NN","JJ"},
"fledglings":	{"NNS"},
"flee":	{"VB","VBP"},
"fleece":	{"NN","VB","VBP"},
"fleeceable":	{"JJ"},
"fleeced":	{"VBN","VBD"},
"fleeces":	{"NNS","VBZ"},
"fleecier":	{"JJR"},
"fleeciest":	{"JJS"},
"fleecing":	{"VBG"},
"fleecy":	{"JJ"},
"fleeing":	{"VBG"},
"fleer":	{"VB","VBP","NN"},
"fleered":	{"VBD","VBN"},
"fleering":	{"VBG"},
"fleeringly":	{"RB"},
"fleers":	{"VBZ"},
"flees":	{"VBZ"},
"fleet":	{"NN","JJ","VB","VBP"},
"fleeted":	{"VBD","VBN"},
"fleeting":	{"JJ","VBG"},
"fleetingly":	{"RB"},
"fleetingness":	{"NN"},
"fleetly":	{"RB"},
"fleetness":	{"NN"},
"fleets":	{"NNS","VBZ"},
"flense":	{"VB","VBP"},
"flensed":	{"VBD","VBN"},
"flenser":	{"NN"},
"flenses":	{"VBZ"},
"flensing":	{"VBG"},
"flesh":	{"NN","VB","VBP"},
"flesh-colored":	{"JJ"},
"flesh-coloured":	{"JJ"},
"flesh-eating":	{"JJ"},
"fleshed":	{"VBD","VBN"},
"fleshes":	{"VBZ"},
"fleshiness":	{"NN"},
"fleshing":	{"VBG"},
"fleshly":	{"JJ"},
"fleshpot":	{"NN"},
"fleshpots":	{"NNS"},
"fleshy":	{"JJ"},
"fletc":	{"NN"},
"fletcher":	{"NN"},
"fleur-de-lis":	{"NN"},
"fleur-de-lys":	{"NNS"},
"fleurs-de-lis":	{"NNS"},
"flew":	{"VBD"},
"flex":	{"NN","VB","VBP"},
"flex-time":	{"JJ"},
"flexed":	{"VBD","VBN"},
"flexeril":	{"NN"},
"flexes":	{"NNS","VBZ"},
"flexibility":	{"NN"},
"flexible":	{"JJ"},
"flexibleness":	{"NN"},
"flexibly":	{"RB"},
"flexicoker":	{"NN"},
"flexicokers":	{"NNS"},
"flexile":	{"JJ"},
"flexing":	{"VBG"},
"flexion":	{"NN"},
"flexor":	{"NN"},
"flextime":	{"NN"},
"flexuous":	{"JJ"},
"flexural":	{"JJ"},
"flexure":	{"NN"},
"flibbertigibbet":	{"NN"},
"flick":	{"VB","VBP","NN"},
"flick-knife":	{"NN"},
"flick-knives":	{"NNS"},
"flicked":	{"VBD","VBN"},
"flicker":	{"NN","VB","VBP"},
"flickered":	{"VBD","VBN"},
"flickering":	{"JJ","VBG"},
"flickers":	{"VBZ","NNS"},
"flickertail":	{"NN"},
"flicking":	{"VBG"},
"flicks":	{"VBZ","NNS"},
"flier":	{"NN"},
"fliers":	{"NNS"},
"flies":	{"NNS","VBZ"},
"flight":	{"NN","VB","VBP"},
"flight-attendant":	{"NN"},
"flight-attendants":	{"NNS"},
"flight-control":	{"NN"},
"flight-crew":	{"NN"},
"flight-deck":	{"NN"},
"flight-decks":	{"NNS"},
"flight-recorder":	{"NN"},
"flight-recorders":	{"NNS"},
"flight-test":	{"NN","VB","VBP"},
"flight-tested":	{"VBD","VBN"},
"flight-testing":	{"VBG"},
"flight-tests":	{"VBZ"},
"flight-to-quality":	{"JJ","NN"},
"flighted":	{"JJ","VBD","VBN"},
"flightier":	{"JJR"},
"flightiest":	{"JJS"},
"flightiness":	{"NN"},
"flighting":	{"VBG"},
"flightless":	{"JJ"},
"flights":	{"NNS","VBZ"},
"flighty":	{"JJ"},
"flim-flammery":	{"NN"},
"flimflam":	{"NN","VB","VBP"},
"flimflammed":	{"VBD","VBN"},
"flimflammer":	{"NN"},
"flimflamming":	{"VBG"},
"flimflams":	{"VBZ"},
"flimsier":	{"JJR"},
"flimsies":	{"NNS"},
"flimsiest":	{"JJS"},
"flimsily":	{"RB"},
"flimsiness":	{"NN"},
"flimsy":	{"JJ","NN"},
"flinch":	{"VB","VBP"},
"flinched":	{"VBD","VBN"},
"flinches":	{"VBZ"},
"flinching":	{"VBG"},
"flinders":	{"NNS"},
"flindersia":	{"NN"},
"flindosa":	{"NN"},
"flindosy":	{"NN"},
"fling":	{"VBP","NN","VB"},
"flinging":	{"VBG"},
"flings":	{"VBZ","NNS"},
"flint":	{"NN"},
"flinthead":	{"NN"},
"flintier":	{"JJR"},
"flintiest":	{"JJS"},
"flintless":	{"JJ"},
"flintlock":	{"NN"},
"flintlocks":	{"NNS"},
"flints":	{"NNS"},
"flintstone":	{"NN"},
"flinty":	{"JJ"},
"flip":	{"VB","VBP","JJ","NN","UH"},
"flip-flap":	{"RB"},
"flip-flop":	{"VB","VBP","NN"},
"flip-flopped":	{"VBD","VBN"},
"flip-flopping":	{"VBG"},
"flip-flops":	{"VBZ","NNS"},
"flippancy":	{"NN"},
"flippant":	{"JJ"},
"flippantly":	{"RB"},
"flipped":	{"VBD","VBN"},
"flipper":	{"NN"},
"flipper-like":	{"JJ"},
"flippers":	{"NNS"},
"flipping":	{"VBG","JJ","RB"},
"flips":	{"VBZ","NNS"},
"flirt":	{"VB","VBP","NN"},
"flirtation":	{"NN"},
"flirtations":	{"NNS"},
"flirtatious":	{"JJ"},
"flirtatiously":	{"RB"},
"flirted":	{"VBD","VBN"},
"flirting":	{"VBG"},
"flirts":	{"VBZ"},
"flit":	{"VB","VBP","NN"},
"flitch":	{"NN"},
"flite-king":	{"JJ"},
"flits":	{"VBZ"},
"flitted":	{"VBD","VBN"},
"flitter":	{"VB","VBP","NN"},
"flittered":	{"VBD","VBN"},
"flittering":	{"VBG"},
"flitters":	{"VBZ","NNS"},
"flitting":	{"VBG"},
"float":	{"VB","VBP","NN"},
"floatation":	{"NN"},
"floated":	{"VBD","VBN"},
"floater":	{"NN"},
"floating":	{"VBG","JJ","NN"},
"floating-load":	{"JJ"},
"floating-moss":	{"NN"},
"floating-point":	{"JJ","NN"},
"floating-rate":	{"JJ","NN"},
"floatplane":	{"NN"},
"floats":	{"VBZ","NNS"},
"floaty":	{"JJ"},
"floc":	{"NN"},
"floccose":	{"JJ"},
"flocculate":	{"VB","VBP"},
"flocculated":	{"VBD","VBN"},
"flocculates":	{"VBZ"},
"flocculating":	{"VBG"},
"flocculation":	{"NN"},
"floccule":	{"NN"},
"flocculent":	{"JJ"},
"flock":	{"NN","VB","VBP"},
"flocked":	{"VBD","VBN"},
"flocking":	{"VBG"},
"flocks":	{"NNS","VBZ"},
"floe":	{"NN"},
"floes":	{"NNS"},
"flog":	{"VB","VBP"},
"flogged":	{"VBD","VBN"},
"flogger":	{"NN"},
"flogging":	{"NN","VBG"},
"floggings":	{"NNS"},
"flogs":	{"VBZ"},
"flood":	{"NN","VB","VBP"},
"flood-control":	{"JJ"},
"flood-insurance":	{"NN"},
"flood-lighted":	{"JJ"},
"flood-prone":	{"JJ"},
"flood-ravaged":	{"JJ"},
"flood-tide":	{"NN"},
"flood-tides":	{"NNS"},
"flooded":	{"VBD","VBN"},
"floodgate":	{"NN"},
"floodgates":	{"NNS"},
"floodhead":	{"NN"},
"floodheads":	{"NNS"},
"flooding":	{"NN","VBG"},
"floodlight":	{"VB","VBP","NN"},
"floodlighted":	{"VBD","VBN"},
"floodlighting":	{"VBG"},
"floodlights":	{"NNS","VBZ"},
"floodlit":	{"JJ","VBD","VBN"},
"floodplain":	{"NN"},
"floods":	{"NNS","VBZ"},
"floodwater":	{"NN"},
"floodwaters":	{"NNS"},
"floor":	{"NN","VBP","VB"},
"floor-board":	{"NN"},
"floor-boards":	{"NNS"},
"floor-covering":	{"NN"},
"floor-length":	{"JJ"},
"floor-level":	{"JJ"},
"floor-to-ceiling":	{"JJ"},
"floorboard":	{"NN"},
"floorboards":	{"NNS"},
"floored":	{"VBD","VBN","JJ"},
"flooring":	{"NN","VBG"},
"floorings":	{"NNS"},
"floors":	{"NNS","VBZ"},
"floorshow":	{"NN"},
"floorwalker":	{"NN"},
"floorward":	{"RB"},
"floozie":	{"NN"},
"floozies":	{"NNS"},
"floozy":	{"NN"},
"flop":	{"NN","VB","VBP","RB"},
"flophouse":	{"NN"},
"flophouses":	{"NNS"},
"flopped":	{"VBD","VBN"},
"floppier":	{"JJR"},
"floppiest":	{"JJS"},
"flopping":	{"VBG"},
"floppy":	{"JJ"},
"floppy-disk":	{"NN"},
"floppy-tie":	{"JJ"},
"flops":	{"VBZ","NNS"},
"flora":	{"NN"},
"floral":	{"JJ"},
"floreal":	{"NN"},
"florescence":	{"NN"},
"floret":	{"NN"},
"florets":	{"NNS"},
"florey":	{"NN"},
"floricultural":	{"JJ"},
"floriculture":	{"NN"},
"florid":	{"JJ"},
"floridian":	{"NN"},
"floridity":	{"NN"},
"floridly":	{"RB"},
"floridness":	{"NN"},
"florilegium":	{"NN"},
"florin":	{"NN"},
"florins":	{"NNS"},
"florio":	{"NN"},
"florist":	{"NN"},
"florists":	{"NNS"},
"flory":	{"JJ"},
"floss":	{"NN","VB","VBP"},
"flossed":	{"VBD","VBN"},
"flosses":	{"VBZ"},
"flossing":	{"VBG"},
"flossy":	{"JJ"},
"flotation":	{"NN"},
"flotation-type":	{"JJ"},
"flotations":	{"NNS"},
"flotilla":	{"NN"},
"flotillas":	{"NNS"},
"flotsam":	{"NN"},
"flounce":	{"NN","VB","VBP"},
"flounced":	{"VBD","VBN","JJ"},
"flounces":	{"VBZ","NNS"},
"flouncing":	{"VBG"},
"flounder":	{"VB","VBP","NN"},
"floundered":	{"VBN","VBD"},
"floundering":	{"VBG","NN"},
"flounders":	{"VBZ","NNS"},
"flour":	{"NN","VB","VBP"},
"flour-milling":	{"JJ","NN"},
"floured":	{"VBN","VBD"},
"flouring":	{"VBG"},
"flourish":	{"VB","VBP","NN"},
"flourished":	{"VBD","VBN"},
"flourishes":	{"NNS","VBZ"},
"flourishing":	{"JJ","VBG"},
"flours":	{"VBZ"},
"floury":	{"JJ"},
"flout":	{"VB","VBP"},
"flouted":	{"VBD","VBN"},
"flouter":	{"NN"},
"flouting":	{"VBG"},
"floutingly":	{"RB"},
"flouts":	{"VBZ"},
"flow":	{"NN","VB","VBP"},
"flowage":	{"NN"},
"flowchart":	{"NN"},
"flowed":	{"VBD","VBN"},
"flower":	{"NN","VBP","VB"},
"flower-bordered":	{"JJ"},
"flower-girl":	{"NN"},
"flower-girls":	{"NNS"},
"flower-inscribed":	{"JJ"},
"flower-of-an-hour":	{"NN"},
"flower-scented":	{"JJ"},
"flower-show":	{"NN"},
"flowerbed":	{"NN"},
"flowerbeds":	{"NNS"},
"flowered":	{"JJ","VBD","VBN"},
"floweret":	{"NN"},
"flowerier":	{"JJR"},
"floweriest":	{"JJS"},
"flowering":	{"NN","JJ","VBG"},
"flowerless":	{"JJ"},
"flowerpot":	{"NN"},
"flowerpots":	{"NNS"},
"flowers":	{"NNS","VBZ"},
"flowers-of-an-hour":	{"NN"},
"flowery":	{"JJ"},
"flowing":	{"VBG","JJ"},
"flown":	{"VBN"},
"flows":	{"NNS","VBZ"},
"floxuridine":	{"NN"},
"flu":	{"NN"},
"flu-like":	{"JJ"},
"flub":	{"NN","VB","VBP"},
"flubbed":	{"VBD","VBN"},
"flubbing":	{"VBG"},
"flubs":	{"VBZ"},
"fluctuate":	{"VB","VBP"},
"fluctuated":	{"VBD","VBN"},
"fluctuates":	{"VBZ"},
"fluctuating":	{"VBG"},
"fluctuation":	{"NN"},
"fluctuations":	{"NNS"},
"flue":	{"NN"},
"flue-cured":	{"JJ"},
"fluegelhorn":	{"NN"},
"fluency":	{"NN"},
"fluent":	{"JJ"},
"fluently":	{"RB"},
"flues":	{"NNS"},
"fluff":	{"NN","VB","VBP"},
"fluffed":	{"VBD","VBN"},
"fluffier":	{"JJR"},
"fluffiest":	{"JJS"},
"fluffiness":	{"NN"},
"fluffing":	{"VBG"},
"fluffs":	{"VBZ"},
"fluffy":	{"JJ"},
"flugelhorn":	{"NN"},
"fluid":	{"NN","JJ"},
"fluid-filled":	{"JJ"},
"fluidity":	{"NN"},
"fluidness":	{"NN"},
"fluidounce":	{"NN"},
"fluidram":	{"NN"},
"fluids":	{"NNS"},
"fluke":	{"NN"},
"flukes":	{"NNS"},
"flukey":	{"JJ"},
"fluky":	{"JJ"},
"flume":	{"NN"},
"flumes":	{"NNS"},
"flummery":	{"NN"},
"flummox":	{"VB","VBP"},
"flummoxed":	{"VBD","VBN","JJ"},
"flummoxes":	{"VBZ"},
"flummoxing":	{"VBG"},
"flump":	{"NN","VB","VBP"},
"flumped":	{"VBD","VBN"},
"flumping":	{"VBG"},
"flumps":	{"NNS","VBZ"},
"flung":	{"VBD","VBN"},
"flunitrazepan":	{"NN"},
"flunk":	{"VB","VBP"},
"flunked":	{"VBD","VBN"},
"flunkeies":	{"NNS"},
"flunkey":	{"NN"},
"flunkeys":	{"NNS"},
"flunking":	{"VBG"},
"flunks":	{"VBZ"},
"flunky":	{"NN"},
"fluor":	{"NN"},
"fluorapatite":	{"NN"},
"fluoresce":	{"VB","VBP"},
"fluoresced":	{"VBD","VBN"},
"fluorescein":	{"NN"},
"fluorescein-labeled":	{"JJ"},
"fluoresceine":	{"NN"},
"fluorescence":	{"NN"},
"fluorescent":	{"JJ"},
"fluoresces":	{"VBZ"},
"fluorescing":	{"VBG"},
"fluoridate":	{"VB","VBP"},
"fluoridated":	{"VBD","VBN"},
"fluoridates":	{"VBZ"},
"fluoridating":	{"VBG"},
"fluoridation":	{"NN"},
"fluoride":	{"NN"},
"fluoridisation":	{"NN"},
"fluoridise":	{"VB","VBP"},
"fluoridised":	{"VBD","VBN"},
"fluoridises":	{"VBZ"},
"fluoridising":	{"VBG"},
"fluoridization":	{"NN"},
"fluoridize":	{"VB","VBP"},
"fluoridized":	{"VBD","VBN"},
"fluoridizes":	{"VBZ"},
"fluoridizing":	{"VBG"},
"fluorinate":	{"VB","VBN"},
"fluorinated":	{"VBD","VBN"},
"fluorinates":	{"VBZ"},
"fluorinating":	{"VBG"},
"fluorine":	{"NN"},
"fluorite":	{"NN"},
"fluoroboride":	{"NN"},
"fluorocarbon":	{"NN"},
"fluorocarbons":	{"NNS"},
"fluorochrome":	{"NN"},
"fluoroform":	{"NN"},
"fluoropolymer":	{"NN"},
"fluoropolymers":	{"NNS"},
"fluoroscope":	{"NN"},
"fluoroscopy":	{"NN"},
"fluorosis":	{"NN"},
"fluorouracil":	{"NN"},
"fluorspar":	{"NN"},
"fluosilicate":	{"NN"},
"fluoxetine":	{"NN"},
"fluphenazine":	{"NN"},
"flurazepam":	{"NN"},
"flurbiprofen":	{"NN"},
"flurried":	{"VBD","VBN","JJ"},
"flurries":	{"NNS","VBZ"},
"flurry":	{"NN","VBP","VB"},
"flurrying":	{"VBG"},
"flush":	{"NN","VB","VBP","JJ"},
"flush-seamed":	{"JJ"},
"flushed":	{"JJ","VBD","VBN"},
"flushes":	{"NNS","VBZ"},
"flushing":	{"NN","VBG"},
"fluster":	{"NN","VB","VBP"},
"flustered":	{"VBD","VBN","JJ"},
"flustering":	{"VBG"},
"flusters":	{"VBZ"},
"flute":	{"VB","VBP","NN"},
"fluted":	{"VBN","VBD","JJ"},
"flutes":	{"VBZ","NNS"},
"fluting":	{"NN","JJ","VBG"},
"flutist":	{"NN"},
"flutists":	{"NNS"},
"flutter":	{"VB","VBP","NN"},
"fluttered":	{"VBD","VBN"},
"fluttering":	{"VBG"},
"flutters":	{"VBZ","NNS"},
"fluvastatin":	{"NN"},
"fluvial":	{"JJ"},
"flux":	{"NN","VB","VBP"},
"fluxed":	{"VBD","VBN"},
"fluxes":	{"NNS","VBZ"},
"fluxing":	{"VBG"},
"fluxion":	{"NN"},
"fluxmeter":	{"NN"},
"fly":	{"VB","NN","VBP","JJ"},
"fly-boy":	{"NN"},
"fly-by":	{"NN"},
"fly-by-night":	{"NN","JJ"},
"fly-by-nighters":	{"NNS"},
"fly-by-nights":	{"NNS"},
"fly-bys":	{"NNS"},
"fly-dotted":	{"JJ"},
"fly-fish":	{"VB","VBP"},
"fly-fished":	{"VBD","VBN"},
"fly-fishes":	{"VBZ"},
"fly-fishing":	{"NN","VBG"},
"fly-half":	{"NN"},
"fly-halves":	{"NNS"},
"fly-spray":	{"NN"},
"flyaway":	{"JJ"},
"flyblown":	{"JJ"},
"flybridge":	{"NN"},
"flycatcher":	{"NN"},
"flycatchers":	{"NNS"},
"flyer":	{"NN"},
"flyers":	{"NNS"},
"flying":	{"VBG","NN","JJ"},
"flying-mount":	{"NN"},
"flyleaf":	{"NN"},
"flyleaves":	{"NNS"},
"flyover":	{"NN"},
"flyovers":	{"NNS"},
"flypaper":	{"NN"},
"flypast":	{"NN"},
"flypasts":	{"NNS"},
"flyspeck":	{"NN","VB","VBP"},
"flyspecked":	{"VBD","VBN"},
"flyspecking":	{"VBG"},
"flyspecks":	{"NNS","VBZ"},
"flyswat":	{"NN"},
"flyswatter":	{"NN"},
"flytrap":	{"NN"},
"flyway":	{"NN"},
"flyways":	{"NNS"},
"flyweight":	{"NN"},
"flyweights":	{"NNS"},
"flywheel":	{"NN"},
"flywheels":	{"NNS"},
"fm":	{"NN"},
"fmri":	{"NN"},
"fnma":	{"NN"},
"fo":	{"NN"},
"fo'c'sle":	{"NN"},
"foal":	{"NN","VBP","VB"},
"foaled":	{"VBD","VBN"},
"foaling":	{"VBG"},
"foals":	{"NNS","VBZ"},
"foam":	{"NN","VB","VBP"},
"foamed":	{"VBD","VBN"},
"foamed-core":	{"JJ"},
"foamed-in-place":	{"JJ"},
"foamflower":	{"NN"},
"foaminess":	{"NN"},
"foaming":	{"VBG"},
"foams":	{"NNS","VBZ"},
"foamy":	{"JJ"},
"foamy-necked":	{"JJ"},
"fob":	{"NN","VBP","VB"},
"fobbed":	{"VBD","VBN"},
"fobbing":	{"VBG"},
"fobs":	{"NNS","VBZ"},
"focal":	{"JJ"},
"focalisation":	{"NN"},
"focalise":	{"VB","VBP"},
"focalised":	{"VBD","VBN"},
"focalises":	{"VBZ"},
"focalising":	{"VBG"},
"focalization":	{"NN"},
"focalize":	{"VB","VBP"},
"focalized":	{"VBD","VBN"},
"focalizes":	{"VBZ"},
"focalizing":	{"VBG"},
"focally":	{"RB"},
"foci":	{"NNS"},
"focus":	{"NN","VB","VBP"},
"focus-group":	{"JJ"},
"focused":	{"VBN","VBD","JJ"},
"focused-factory":	{"JJ"},
"focuses":	{"VBZ","NNS"},
"focusing":	{"VBG"},
"focussed":	{"JJ","VBN","VBD"},
"focusses":	{"VBZ"},
"focussing":	{"VBG"},
"fodder":	{"NN","VB","VBP"},
"foddered":	{"VBD","VBN"},
"foddering":	{"VBG"},
"fodders":	{"VBZ"},
"foe":	{"NN"},
"foehn":	{"NN"},
"foeman":	{"NN"},
"foeniculum":	{"NN"},
"foes":	{"NNS"},
"foetal":	{"JJ"},
"foetid":	{"JJ"},
"foetology":	{"NN"},
"foetometry":	{"NN"},
"foetoprotein":	{"NN"},
"foetor":	{"NN"},
"foetoscope":	{"NN"},
"foetoscopy":	{"NN"},
"foetus":	{"NN"},
"foetuses":	{"NNS"},
"fog":	{"NN","VB","VBP"},
"fog-enshrouded":	{"JJ"},
"fog-free":	{"JJ"},
"fog-shrouded":	{"JJ"},
"fogbank":	{"NN"},
"fogbound":	{"JJ"},
"fogeies":	{"NNS"},
"fogey":	{"NN"},
"fogeys":	{"NNS"},
"fogged":	{"VBD","VBN"},
"foggier":	{"JJR"},
"foggiest":	{"JJS"},
"fogginess":	{"NN"},
"fogging":	{"VBG"},
"foggy":	{"JJ"},
"foghorn":	{"NN"},
"foghorns":	{"NNS"},
"fogies":	{"NNS"},
"foglamp":	{"NN"},
"fogs":	{"NNS","VBZ"},
"fogsignal":	{"NN"},
"fogy":	{"NN"},
"fogyish":	{"JJ"},
"fogys":	{"NNS"},
"foh":	{"IN"},
"fohn":	{"NN"},
"foible":	{"NN"},
"foibles":	{"NNS"},
"foil":	{"NN","VB","VBP"},
"foiled":	{"JJ","VBD","VBN"},
"foiling":	{"NN","VBG"},
"foils":	{"NNS","VBZ"},
"foist":	{"VB","VBP"},
"foisted":	{"VBD","VBN"},
"foisting":	{"VBG"},
"foists":	{"VBZ"},
"folacin":	{"NN"},
"folate":	{"NN"},
"fold":	{"VB","VBP","NN"},
"foldability":	{"NN"},
"foldable":	{"JJ"},
"foldaway":	{"JJ"},
"folded":	{"VBD","VBN"},
"folder":	{"NN"},
"folderal":	{"NN"},
"folderol":	{"NN"},
"folders":	{"NNS"},
"folding":	{"JJ","VBG","NN"},
"foldout":	{"NN"},
"folds":	{"VBZ","NNS"},
"foliaceous":	{"JJ"},
"foliage":	{"NN"},
"foliaged":	{"JJ"},
"foliate":	{"VB","VBP","JJ"},
"foliated":	{"JJ","VBD","VBN"},
"foliates":	{"VBZ"},
"foliating":	{"VBG"},
"foliation":	{"NN"},
"folie":	{"NN"},
"folio":	{"NN","VB","VBP"},
"folioed":	{"VBD","VBN"},
"folioing":	{"VBG"},
"foliolate":	{"JJ"},
"folios":	{"NNS","VBZ"},
"foliose":	{"JJ"},
"folium":	{"NN"},
"folk":	{"NN","NNS","JJ"},
"folk-dance":	{"NN"},
"folk-lore":	{"NN"},
"folk-music":	{"NN"},
"folk-tale":	{"NN"},
"folkish":	{"JJ"},
"folklike":	{"JJ"},
"folklore":	{"NN"},
"folks":	{"NNS"},
"folksong":	{"NN"},
"folksongs":	{"NNS"},
"folksy":	{"JJ"},
"folktale":	{"NN"},
"follicle":	{"NN"},
"follicles":	{"NNS"},
"follicular":	{"JJ"},
"folliculitis":	{"NN"},
"follies":	{"NNS"},
"follow":	{"VB","VBP"},
"follow-on":	{"NN"},
"follow-through":	{"NN"},
"follow-up":	{"NN","JJ"},
"follow-ups":	{"NNS"},
"followed":	{"VBD","VBN"},
"follower":	{"NN"},
"followers":	{"NNS"},
"followership":	{"NN"},
"following":	{"VBG","JJ","NN","IN"},
"followings":	{"NNS"},
"follows":	{"VBZ"},
"followthrough":	{"JJ"},
"followup":	{"NN"},
"folly":	{"NN"},
"folsom":	{"NN"},
"foment":	{"VB","VBP"},
"fomentation":	{"NN"},
"fomented":	{"VBD","VBN"},
"fomenter":	{"NN"},
"fomenting":	{"VBG"},
"foments":	{"VBZ","NNS"},
"fomes":	{"NN"},
"fomite":	{"NN"},
"fomites":	{"NNS"},
"fomor":	{"NN"},
"fomorian":	{"NN"},
"fond":	{"JJ"},
"fondant":	{"NN"},
"fonder":	{"JJR"},
"fondest":	{"JJS"},
"fondle":	{"VB","VBP"},
"fondled":	{"VBD","VBN"},
"fondler":	{"NN"},
"fondles":	{"VBZ"},
"fondling":	{"VBG"},
"fondly":	{"RB"},
"fondness":	{"NN"},
"fondu":	{"NN"},
"fondue":	{"NN"},
"fondues":	{"NNS"},
"font":	{"NN"},
"fontaine":	{"NN"},
"fontanel":	{"NN"},
"fontanelle":	{"NN"},
"fontanne":	{"NN"},
"fontenoy":	{"NN"},
"fonts":	{"NNS"},
"food":	{"NN"},
"food-aid":	{"JJ"},
"food-canning":	{"NN"},
"food-chain":	{"NN"},
"food-chains":	{"NNS"},
"food-color":	{"NN"},
"food-fish":	{"NNS"},
"food-importing":	{"JJ"},
"food-industry":	{"NN"},
"food-packaging":	{"JJ"},
"food-poisoning":	{"NN"},
"food-preservation":	{"NN"},
"food-price":	{"JJ"},
"food-processing":	{"NN","JJ"},
"food-production":	{"NN"},
"food-products":	{"NNS"},
"food-safety":	{"JJ","NN"},
"food-scare":	{"NN"},
"food-sector":	{"JJ"},
"food-service":	{"NN","JJ"},
"food-services":	{"NNS"},
"food-shop":	{"JJ"},
"foodie":	{"NN"},
"foodies":	{"NNS"},
"foodless":	{"JJ"},
"foods":	{"NNS"},
"foodservice":	{"NN"},
"foodstuff":	{"NN"},
"foodstuffs":	{"NNS"},
"fool":	{"NN","VB","JJ","VBP"},
"fooled":	{"VBD","VBN"},
"foolery":	{"NN"},
"foolhardiness":	{"NN"},
"foolhardy":	{"JJ"},
"fooling":	{"VBG"},
"foolish":	{"JJ"},
"foolishly":	{"RB"},
"foolishness":	{"NN"},
"foolproof":	{"JJ"},
"fools":	{"NNS","VBZ"},
"foolscap":	{"NN"},
"foot":	{"NN","VB","VBP"},
"foot-and-mouth":	{"NN","JJ"},
"foot-dragging":	{"NN"},
"foot-high":	{"JJ"},
"foot-lambert":	{"NN"},
"foot-loose":	{"JJ"},
"foot-pound":	{"NN"},
"foot-poundal":	{"NN"},
"foot-shaped":	{"JJ"},
"foot-tall":	{"JJ"},
"foot-thick":	{"JJ"},
"foot-ton":	{"NN"},
"footage":	{"NN"},
"football":	{"NN"},
"football-shaped":	{"JJ"},
"footballer":	{"NN"},
"footballers":	{"NNS"},
"footballs":	{"NNS"},
"footbath":	{"NN"},
"footboard":	{"NN"},
"footbridge":	{"NN"},
"footbridges":	{"NNS"},
"footcandle":	{"NN"},
"footed":	{"JJ","VBD","VBN"},
"footedness":	{"NN"},
"footer":	{"NN"},
"footfall":	{"NN"},
"footfalls":	{"NNS"},
"footfault":	{"NN"},
"footgear":	{"NN"},
"foothill":	{"NN"},
"foothills":	{"NNS"},
"foothold":	{"NN"},
"footholds":	{"NNS"},
"footing":	{"NN","VBG"},
"footle":	{"VB","VBP"},
"footled":	{"VBD","VBN"},
"footles":	{"VBZ"},
"footless":	{"JJ"},
"footlights":	{"NNS"},
"footling":	{"JJ","VBG"},
"footlocker":	{"NN"},
"footloose":	{"JJ","NN"},
"footman":	{"NN"},
"footmark":	{"NN"},
"footmen":	{"NNS"},
"footnote":	{"NN","VB","VBP"},
"footnoted":	{"VBD","VBN"},
"footnotes":	{"NNS","VBZ"},
"footnoting":	{"VBG"},
"footpad":	{"NN"},
"footpath":	{"NN"},
"footpaths":	{"NNS"},
"footplate":	{"NN"},
"footplates":	{"NNS"},
"footprint":	{"NN"},
"footprints":	{"NNS"},
"footrace":	{"NN"},
"footrest":	{"NN"},
"footrests":	{"NNS"},
"foots":	{"VBZ"},
"footslog":	{"VB"},
"footslogger":	{"NN"},
"footsore":	{"JJ"},
"footstall":	{"NN"},
"footstep":	{"NN"},
"footsteps":	{"NNS"},
"footsteps-of-spring":	{"NN"},
"footstool":	{"NN"},
"footstools":	{"NNS"},
"footsure":	{"JJ"},
"footsy":	{"NN"},
"footwall":	{"NN"},
"footwear":	{"NN"},
"footwork":	{"NN"},
"fop":	{"NN"},
"foppish":	{"JJ"},
"foppishness":	{"NN"},
"for":	{"IN","CC","RP"},
"for-profit":	{"JJ","NN"},
"forage":	{"NN","VB","VBP"},
"foraged":	{"VBD","VBN"},
"forager":	{"NN"},
"foragers":	{"NNS"},
"forages":	{"NNS","VBZ"},
"foraging":	{"VBG"},
"foram":	{"NN"},
"foramen":	{"NN"},
"foraminifer":	{"NN"},
"foraminifera":	{"NN"},
"foray":	{"NN","VB","VBP"},
"forayed":	{"VBD","VBN"},
"foraying":	{"VBG"},
"forays":	{"NNS","VBZ"},
"forbad":	{"VBD"},
"forbade":	{"VBD"},
"forbear":	{"VB","VBP","NN"},
"forbearance":	{"NN"},
"forbearing":	{"JJ","VBG"},
"forbears":	{"NNS","VBZ"},
"forbid":	{"VB","VBP"},
"forbiddance":	{"NN"},
"forbidden":	{"VBN","JJ"},
"forbidding":	{"JJ","VBG"},
"forbidding-looking":	{"JJ"},
"forbiddingly":	{"RB"},
"forbids":	{"VBZ"},
"forbore":	{"VBD"},
"forborne":	{"VBN"},
"force":	{"NN","VB","VBP"},
"force-fear":	{"JJ"},
"force-fed":	{"VBD","VBN"},
"force-feed":	{"VB","VBP"},
"force-feeding":	{"VBG"},
"force-feeds":	{"VBZ"},
"force-land":	{"VB","VBP"},
"force-level":	{"JJ"},
"force-out":	{"NN"},
"force-rate":	{"NN"},
"forced":	{"VBN","VBD","JJ"},
"forced-birther":	{"NN"},
"forced-birthers":	{"NNS"},
"forceful":	{"JJ"},
"forcefully":	{"RB"},
"forcefulness":	{"NN"},
"forceless":	{"JJ"},
"forcemeat":	{"NN"},
"forceps":	{"NNS"},
"forces":	{"NNS","VBZ"},
"forcible":	{"JJ"},
"forcibly":	{"RB"},
"forcing":	{"VBG"},
"forcipate":	{"JJ"},
"ford":	{"NN","VB","VBP"},
"fordable":	{"JJ"},
"forded":	{"VBD","VBN"},
"fordhooks":	{"NNS"},
"fording":	{"VBG"},
"fords":	{"NNS","VBZ"},
"fore":	{"NN","JJ","RB","UH"},
"fore-and-aft":	{"JJ"},
"fore-and-after":	{"NN"},
"fore-play":	{"NN"},
"fore-topmast":	{"NN"},
"fore-topsail":	{"NN"},
"fore-wing":	{"NN"},
"forearm":	{"NN","VB","VBP"},
"forearmed":	{"VBD","VBN","JJ"},
"forearming":	{"VBG"},
"forearms":	{"NNS","VBZ"},
"forebear":	{"NN"},
"forebears":	{"NNS"},
"forebode":	{"VB","VBP"},
"foreboded":	{"VBD","VBN"},
"forebodes":	{"VBZ"},
"foreboding":	{"JJ","NN","VBG"},
"forebodings":	{"NNS"},
"forebrain":	{"NN"},
"forecast":	{"NN","VBD","VBN","VBP","VB"},
"forecasted":	{"VBD","VBN"},
"forecaster":	{"NN"},
"forecasters":	{"NNS"},
"forecasting":	{"VBG"},
"forecastle":	{"NN"},
"forecastles":	{"NNS"},
"forecasts":	{"NNS","VBZ"},
"foreclose":	{"VB","VBP"},
"foreclosed":	{"VBD","VBN"},
"forecloses":	{"VBZ"},
"foreclosing":	{"VBG"},
"foreclosure":	{"NN"},
"foreclosures":	{"NNS"},
"forecourt":	{"NN"},
"forecourts":	{"NNS"},
"foredate":	{"VB","VBP"},
"foredated":	{"VBD","VBN"},
"foredates":	{"VBZ"},
"foredating":	{"VBG"},
"foredeck":	{"NN"},
"foredecks":	{"NNS"},
"foredge":	{"NN"},
"foredoom":	{"VB","VBP","NN"},
"foredoomed":	{"VBD","VBN"},
"foredooming":	{"VBG"},
"foredooms":	{"VBZ"},
"forefather":	{"NN"},
"forefathers":	{"NNS"},
"forefeet":	{"NNS"},
"forefend":	{"VB","VBP"},
"forefinger":	{"NN"},
"forefingers":	{"NNS"},
"forefoot":	{"NN"},
"forefront":	{"NN"},
"foregather":	{"VB","VBP"},
"foregathered":	{"VBD","VBN"},
"foregathering":	{"VBG"},
"foregathers":	{"VBZ"},
"forego":	{"VB","VBP"},
"foregoes":	{"VBZ"},
"foregoing":	{"JJ","VBG"},
"foregone":	{"JJ","VBN"},
"foreground":	{"NN","VB","VBP"},
"foregrounded":	{"VBD","VBN"},
"foregrounding":	{"VBG"},
"foregrounds":	{"NNS","VBZ"},
"forehand":	{"NN","JJ"},
"forehanded":	{"JJ"},
"forehead":	{"NN"},
"foreheads":	{"NNS"},
"foreign":	{"JJ"},
"foreign-affairs":	{"NNS"},
"foreign-aid":	{"NN","JJ"},
"foreign-airline":	{"NN"},
"foreign-assistance":	{"NN"},
"foreign-bank":	{"JJ"},
"foreign-based":	{"JJ"},
"foreign-born":	{"JJ"},
"foreign-car":	{"NN"},
"foreign-country":	{"JJ"},
"foreign-currency":	{"NN","JJ"},
"foreign-debt":	{"NN","JJ"},
"foreign-entry-limit":	{"JJ"},
"foreign-equity":	{"NN"},
"foreign-exchange":	{"JJ","NN"},
"foreign-exchange-rate":	{"JJ","NN"},
"foreign-flag":	{"NN"},
"foreign-investment":	{"JJ"},
"foreign-investor":	{"NN"},
"foreign-led":	{"JJ"},
"foreign-loan":	{"JJ"},
"foreign-made":	{"JJ"},
"foreign-movie":	{"NN"},
"foreign-owned":	{"JJ"},
"foreign-ownership":	{"NN"},
"foreign-policy":	{"NN","JJ"},
"foreign-registered":	{"JJ"},
"foreign-sounding":	{"JJ"},
"foreign-stock":	{"JJ"},
"foreign-trade":	{"JJ","NN"},
"foreign-trading":	{"JJ"},
"foreign-transaction":	{"NN"},
"foreigner":	{"NN"},
"foreigners":	{"NNS"},
"foreignness":	{"NN"},
"foreknew":	{"VBD"},
"foreknow":	{"VB","VBP"},
"foreknowable":	{"JJ"},
"foreknowing":	{"VBG"},
"foreknowingly":	{"RB"},
"foreknowledge":	{"NN"},
"foreknown":	{"VBN"},
"foreknows":	{"VBZ"},
"forelady":	{"NN"},
"foreland":	{"NN"},
"foreleg":	{"NN"},
"forelegs":	{"NNS"},
"forelimb":	{"NN"},
"forelock":	{"NN"},
"forelocks":	{"NNS"},
"foreman":	{"NN"},
"foremanship":	{"NN"},
"foremast":	{"NN"},
"foremen":	{"NNS"},
"foremilk":	{"NN"},
"foremost":	{"JJ","RB"},
"foremother":	{"NN"},
"forename":	{"NN"},
"forenames":	{"NNS"},
"forenoon":	{"NN"},
"forensic":	{"JJ"},
"forensics":	{"NN"},
"foreordain":	{"VB","VBP"},
"foreordained":	{"JJ","VBD","VBN"},
"foreordaining":	{"VBG"},
"foreordains":	{"VBZ"},
"foreordination":	{"NN"},
"forepart":	{"NN"},
"forepaw":	{"NN"},
"forepaws":	{"NNS"},
"foreperson":	{"NN"},
"foreplay":	{"NN"},
"forequarter":	{"NN"},
"forerunner":	{"NN"},
"forerunners":	{"NNS"},
"foresail":	{"NN"},
"foresaw":	{"VBD"},
"foresee":	{"VB","VBP"},
"foreseeable":	{"JJ"},
"foreseeing":	{"VBG"},
"foreseen":	{"VBN"},
"foresees":	{"VBZ"},
"foreshadow":	{"VB","VBP"},
"foreshadowed":	{"VBD","VBN"},
"foreshadowing":	{"VBG"},
"foreshadows":	{"VBZ"},
"foreshank":	{"NN"},
"foreshock":	{"NN"},
"foreshore":	{"NN"},
"foreshores":	{"NNS"},
"foreshorten":	{"VB","VBP"},
"foreshortened":	{"VBD","VBN","JJ"},
"foreshortening":	{"VBG"},
"foreshortens":	{"VBZ"},
"foreshow":	{"VB","VBP"},
"foreshowed":	{"VBD","VBN"},
"foreshowing":	{"VBG"},
"foreshows":	{"VBZ"},
"foresight":	{"NN"},
"foresighted":	{"JJ"},
"foresightedness":	{"NN"},
"foresightful":	{"JJ"},
"foresightfulness":	{"NN"},
"foreskin":	{"NN"},
"foreskins":	{"NNS"},
"forest":	{"NN","VB","VBP"},
"forest-product":	{"NN"},
"forest-products":	{"NNS","JJ"},
"forestage":	{"NN"},
"forestall":	{"VB","VBP"},
"forestalled":	{"VBD","VBN"},
"forestalling":	{"VBG"},
"forestalls":	{"VBZ"},
"forestay":	{"NN"},
"forested":	{"VBD","VBN","JJ"},
"forester":	{"NN"},
"foresters":	{"NNS"},
"forestiera":	{"NN"},
"foresting":	{"VBG"},
"forestry":	{"NN"},
"forests":	{"NNS","VBZ"},
"foreswear":	{"VB","VBP"},
"foreswearing":	{"VBG"},
"foreswears":	{"VBZ"},
"foreswore":	{"VBD"},
"foresworn":	{"VBN"},
"foretaste":	{"NN","VB","VBP"},
"foretasted":	{"VBD","VBN"},
"foretastes":	{"VBZ"},
"foretasting":	{"VBG"},
"foretell":	{"VB","VBP"},
"foretelling":	{"VBG"},
"foretells":	{"VBZ"},
"forethought":	{"NN"},
"forethoughtful":	{"JJ"},
"foretoken":	{"NN"},
"foretold":	{"VBD","VBN"},
"foretop":	{"NN"},
"forever":	{"RB"},
"forever-cathy":	{"NN"},
"forevermore":	{"RB"},
"forewarn":	{"VB","VBP"},
"forewarned":	{"VBD","VBN"},
"forewarning":	{"NN","VBG"},
"forewarnings":	{"NNS"},
"forewarns":	{"VBZ"},
"forewent":	{"VBD"},
"forewing":	{"NN"},
"forewoman":	{"NN"},
"forewomen":	{"NNS"},
"foreword":	{"NN"},
"forewords":	{"NNS"},
"forfeit":	{"VB","VBP","NN","JJ"},
"forfeitable":	{"JJ"},
"forfeited":	{"VBD","VBN"},
"forfeiting":	{"VBG"},
"forfeits":	{"VBZ","NNS"},
"forfeiture":	{"NN"},
"forfeitures":	{"NNS"},
"forfend":	{"VB","VBP"},
"forfended":	{"VBD","VBN"},
"forfending":	{"VBG"},
"forfends":	{"VBZ"},
"forficate":	{"JJ"},
"forficula":	{"NN"},
"forficulidae":	{"NN"},
"forgather":	{"VB","VBP"},
"forgathered":	{"VBD","VBN"},
"forgathering":	{"VBG"},
"forgathers":	{"VBZ"},
"forgave":	{"VBD"},
"forge":	{"VB","VBP","NN"},
"forged":	{"VBD","VBN"},
"forger":	{"NN"},
"forgeries":	{"NNS"},
"forgers":	{"NNS"},
"forgery":	{"NN"},
"forges":	{"VBZ","NNS"},
"forget":	{"VB","VBP"},
"forget-me-not":	{"NN"},
"forget-me-nots":	{"NNS"},
"forgetful":	{"JJ"},
"forgetfully":	{"RB"},
"forgetfulness":	{"NN"},
"forgets":	{"VBZ"},
"forgettable":	{"JJ"},
"forgetting":	{"VBG"},
"forging":	{"NN","VBG"},
"forgings":	{"NNS"},
"forgitful":	{"JJ"},
"forgivable":	{"JJ"},
"forgivably":	{"RB"},
"forgive":	{"VB","VBP"},
"forgiven":	{"VBN"},
"forgiveness":	{"NN"},
"forgiver":	{"NN"},
"forgives":	{"VBZ"},
"forgiving":	{"JJ","VBG"},
"forgivingly":	{"RB"},
"forgivingness":	{"NN"},
"forgo":	{"VB","VBP"},
"forgoes":	{"VBZ"},
"forgoing":	{"VBG"},
"forgone":	{"VBN"},
"forgot":	{"VBD"},
"forgotten":	{"VBN","JJ"},
"forint":	{"NN"},
"forints":	{"NNS"},
"forisque":	{"FW"},
"fork":	{"NN","VB","VBP"},
"fork-lift":	{"NN"},
"fork-like":	{"JJ"},
"forked":	{"JJ","VBD","VBN"},
"forking":	{"VBG"},
"forklift":	{"NN"},
"forklifts":	{"NNS"},
"forks":	{"VBZ","NNS"},
"forlorn":	{"JJ"},
"forlornly":	{"RB"},
"forlornness":	{"NN"},
"form":	{"NN","VB","VBP"},
"form-creating":	{"JJ"},
"form-dictionary":	{"NN"},
"form-letter":	{"JJ","NN"},
"form-only":	{"JJ"},
"forma":	{"NN"},
"formability":	{"NN"},
"formal":	{"JJ","NN"},
"formaldehyde":	{"NN"},
"formalin":	{"NN"},
"formalisation":	{"NN"},
"formalise":	{"VB","VBP"},
"formalised":	{"VBD","VBN"},
"formalises":	{"VBZ"},
"formalising":	{"VBG"},
"formalism":	{"NN"},
"formalist":	{"NN","JJ"},
"formalistic":	{"JJ"},
"formalists":	{"NNS"},
"formalities":	{"NNS"},
"formality":	{"NN"},
"formalization":	{"NN"},
"formalize":	{"VB","VBP"},
"formalized":	{"VBD","VBN"},
"formalizes":	{"VBZ"},
"formalizing":	{"VBG"},
"formally":	{"RB"},
"formalness":	{"NN"},
"formals":	{"NNS"},
"formalwear":	{"NN"},
"forman":	{"NN"},
"format":	{"NN","VB","VBP"},
"formation":	{"NN"},
"formations":	{"NNS"},
"formative":	{"JJ"},
"formats":	{"NNS","VBZ"},
"formatted":	{"VBD","VBN","JJ"},
"formatting":	{"NN","VBG"},
"formed":	{"VBN","VBD","JJ"},
"formed-tooth":	{"JJ"},
"former":	{"JJ","NN"},
"formerly":	{"RB"},
"formic":	{"JJ"},
"formicariidae":	{"NN"},
"formicarius":	{"NNS"},
"formicary":	{"NN"},
"formicate":	{"VB","VBP"},
"formicated":	{"VBD","VBN"},
"formicates":	{"VBZ"},
"formicating":	{"VBG"},
"formication":	{"NN"},
"formicidae":	{"NN"},
"formidability":	{"NN"},
"formidable":	{"JJ"},
"formidable-appearing":	{"JJ"},
"formidably":	{"RB"},
"forming":	{"VBG"},
"formless":	{"JJ"},
"formlessly":	{"RB"},
"formlessness":	{"NN"},
"formol":	{"NN"},
"formosa":	{"NN"},
"formosan":	{"JJ","NN"},
"forms":	{"NNS","VBZ"},
"forms-processing":	{"NN"},
"formula":	{"NN"},
"formula-based":	{"JJ"},
"formulae":	{"NNS"},
"formulaic":	{"JJ"},
"formularisation":	{"NN"},
"formularise":	{"VB","VBP"},
"formularised":	{"VBD","VBN"},
"formulariser":	{"NN"},
"formularises":	{"VBZ"},
"formularising":	{"VBG"},
"formularization":	{"NN"},
"formularize":	{"VB","VBP"},
"formularized":	{"VBD","VBN"},
"formularizer":	{"NN"},
"formularizes":	{"VBZ"},
"formularizing":	{"VBG"},
"formulary":	{"NN"},
"formulas":	{"NNS"},
"formulate":	{"VB","VBP"},
"formulated":	{"VBD","VBN"},
"formulates":	{"VBZ"},
"formulating":	{"VBG"},
"formulation":	{"NN"},
"formulations":	{"NNS"},
"fornax":	{"NN"},
"fornicate":	{"VB","VBP"},
"fornicated":	{"VBD","VBN"},
"fornicates":	{"VBZ"},
"fornicating":	{"VBG"},
"fornication":	{"NN"},
"fornicator":	{"NN"},
"fornicatress":	{"NN"},
"fornix":	{"NN"},
"forrad":	{"RB"},
"forrader":	{"RB"},
"forrard":	{"RB"},
"forrester":	{"NN"},
"forsake":	{"VB","VBP"},
"forsaken":	{"JJ","VBN"},
"forsakes":	{"VBZ"},
"forsaking":	{"VBG"},
"forseeable":	{"JJ"},
"forseti":	{"NN"},
"forsook":	{"VBD"},
"forsooth":	{"RB"},
"forswear":	{"VB","VBP"},
"forswearing":	{"VBG"},
"forswears":	{"VBZ"},
"forswore":	{"VBD"},
"forsworn":	{"VBN"},
"forsythia":	{"NN"},
"forsythias":	{"NNS"},
"fort":	{"NN","VB","VBP"},
"fort-lamy":	{"NN"},
"fortaz":	{"NN"},
"forte":	{"NN","JJ","RB"},
"forte-piano":	{"NN"},
"forte-pianos":	{"NNS"},
"forted":	{"VBD","VBN"},
"fortemente":	{"JJ"},
"forth":	{"RB","RP"},
"forthcoming":	{"JJ"},
"forthcomingness":	{"NN"},
"forthright":	{"JJ","RB"},
"forthrightly":	{"RB"},
"forthrightness":	{"NN"},
"forthwith":	{"RB"},
"forties":	{"NNS"},
"fortieth":	{"NN","JJ"},
"fortification":	{"NN"},
"fortifications":	{"NNS"},
"fortified":	{"VBD","VBN","JJ"},
"fortifies":	{"VBZ"},
"fortify":	{"VB","VBP"},
"fortifying":	{"VBG"},
"forting":	{"VBG"},
"fortiori":	{"FW"},
"fortissimo":	{"JJ","RB"},
"fortitude":	{"NN"},
"fortnight":	{"NN"},
"fortnightly":	{"JJ","RB"},
"fortran":	{"NN"},
"fortress":	{"NN"},
"fortress-like":	{"JJ"},
"fortresses":	{"NNS"},
"fortresseurope":	{"NN"},
"forts":	{"NNS","VBZ"},
"fortuitous":	{"JJ"},
"fortuitously":	{"RB"},
"fortuitousness":	{"NN"},
"fortuity":	{"NN"},
"fortuna":	{"NN"},
"fortunate":	{"JJ"},
"fortunately":	{"RB"},
"fortune":	{"NN","VB","VBP"},
"fortune-cookie":	{"NN"},
"fortune-cookies":	{"NNS"},
"fortune-happy":	{"JJ"},
"fortune-hunter":	{"NN"},
"fortune-teller":	{"NN"},
"fortune-tellers":	{"NNS"},
"fortuned":	{"VBD","VBN"},
"fortunella":	{"NN"},
"fortunes":	{"NNS","VBZ"},
"fortuneteller":	{"NN"},
"fortunetelling":	{"NN"},
"fortuning":	{"VBG"},
"forty":	{"NN","CD"},
"forty-eight":	{"NN","CD"},
"forty-eighth":	{"NN","JJ"},
"forty-fifth":	{"NN","JJ"},
"forty-first":	{"NN","JJ"},
"forty-five":	{"JJ","CD","NN"},
"forty-fold":	{"JJ"},
"forty-four":	{"NN","CD"},
"forty-fourth":	{"NN","JJ"},
"forty-nine":	{"NN","CD"},
"forty-niner":	{"NN"},
"forty-niners":	{"NNS"},
"forty-ninth":	{"NN","JJ"},
"forty-one":	{"NN","CD"},
"forty-second":	{"NN","JJ"},
"forty-seven":	{"NN","CD"},
"forty-seventh":	{"NN","JJ"},
"forty-six":	{"NN","CD"},
"forty-sixth":	{"NN","JJ"},
"forty-third":	{"NN","JJ"},
"forty-three":	{"NN","CD"},
"forty-two":	{"NN","CD"},
"forum":	{"NN"},
"forums":	{"NNS"},
"forward":	{"RB","JJ","RP","VB","VBP","NN"},
"forward-looking":	{"JJ"},
"forward-moving":	{"JJ"},
"forward-rate":	{"JJ"},
"forwarded":	{"VBN","VBD"},
"forwarder":	{"NN"},
"forwarders":	{"NNS"},
"forwarding":	{"VBG"},
"forwardness":	{"NN"},
"forwards":	{"RB","VBZ"},
"forwent":	{"VBD"},
"foryml":	{"NN"},
"fosamax":	{"NN"},
"fosbury":	{"NN"},
"fossa":	{"NN"},
"fosse":	{"NN"},
"fossil":	{"NN"},
"fossiliferous":	{"JJ"},
"fossilisation":	{"NN"},
"fossilise":	{"VB","VBP"},
"fossilised":	{"VBD","VBN"},
"fossilises":	{"VBZ"},
"fossilising":	{"VBG"},
"fossilist":	{"NN"},
"fossilization":	{"NN"},
"fossilize":	{"VB","VBP"},
"fossilized":	{"VBD","VBN"},
"fossilizes":	{"VBZ"},
"fossilizing":	{"VBG"},
"fossilology":	{"NN"},
"fossils":	{"NNS"},
"fossorial":	{"JJ"},
"foster":	{"JJ","VB","VBP"},
"foster-brother":	{"NN"},
"foster-care":	{"JJ"},
"foster-child":	{"NN"},
"foster-daughter":	{"NN"},
"foster-father":	{"NN"},
"foster-mother":	{"NN"},
"foster-nurse":	{"NN"},
"foster-parent":	{"NN"},
"foster-sister":	{"NN"},
"foster-son":	{"NN"},
"fosterage":	{"NN"},
"fostered":	{"VBD","VBN"},
"fostering":	{"VBG"},
"fosterling":	{"NN"},
"fosters":	{"VBZ"},
"fothergilla":	{"NN"},
"fought":	{"VBD","VBN"},
"fought-for":	{"JJ"},
"foul":	{"JJ","NN","VBP","VB"},
"foul-mouthed":	{"JJ"},
"foul-smelling":	{"JJ"},
"foul-spoken":	{"JJ"},
"foul-up":	{"NN"},
"foul-ups":	{"NNS"},
"foulard":	{"NN"},
"fouled":	{"VBD","VBN"},
"fouler":	{"JJR"},
"foulest":	{"JJS"},
"fouling":	{"VBG"},
"foully":	{"RB"},
"foulmart":	{"NN"},
"foulness":	{"NN"},
"fouls":	{"NNS","VBZ"},
"foumart":	{"NN"},
"found":	{"VBD","VBN","VB","VBP"},
"foundation":	{"NN"},
"foundation-stone":	{"NN"},
"foundation-stones":	{"NNS"},
"foundations":	{"NNS"},
"founded":	{"VBN","VBD","JJ"},
"founder":	{"NN","VB","VBP"},
"founder-conductor":	{"NN"},
"founder-originator":	{"NN"},
"foundered":	{"VBD","VBN"},
"foundering":	{"VBG"},
"founders":	{"NNS","VBZ"},
"founding":	{"NN","VBG","JJ"},
"foundling":	{"NN"},
"foundlings":	{"NNS"},
"foundress":	{"NN"},
"foundries":	{"NNS"},
"foundry":	{"NN"},
"founds":	{"VBZ"},
"fount":	{"NN"},
"fountain":	{"NN"},
"fountain-falls":	{"NNS"},
"fountain-head":	{"NN"},
"fountain-like":	{"JJ"},
"fountained":	{"JJ"},
"fountainhead":	{"NN"},
"fountainless":	{"JJ"},
"fountains":	{"NNS"},
"founts":	{"NNS"},
"fouquieria":	{"NN"},
"fouquieriaceae":	{"NN"},
"four":	{"CD","LS","NN"},
"four-bagger":	{"NN"},
"four-baggers":	{"NNS"},
"four-by-four":	{"NN"},
"four-by-fours":	{"NNS"},
"four-color":	{"JJ","NN"},
"four-colour":	{"JJ","NN"},
"four-cycle":	{"JJ"},
"four-dimensional":	{"JJ"},
"four-door":	{"JJ"},
"four-engined":	{"JJ"},
"four-eyed":	{"JJ"},
"four-eyes":	{"NN"},
"four-fifths":	{"NNS"},
"four-flush":	{"VB","VBP"},
"four-flushed":	{"VBD","VBN"},
"four-flusher":	{"NN"},
"four-flushes":	{"VBZ"},
"four-flushing":	{"VBG"},
"four-fold":	{"RB"},
"four-foot":	{"NN"},
"four-footed":	{"JJ"},
"four-for-one":	{"RB"},
"four-four":	{"JJ","NN"},
"four-four-time":	{"NN"},
"four-handed":	{"JJ"},
"four-hundredth":	{"JJ"},
"four-in-hand":	{"NN","JJ"},
"four-in-hands":	{"NNS"},
"four-leaf":	{"JJ"},
"four-leaved":	{"JJ"},
"four-legged":	{"JJ"},
"four-legged-friend":	{"NN"},
"four-legged-friends":	{"NNS"},
"four-master":	{"NN"},
"four-mile":	{"JJ"},
"four-o'clock":	{"NN","JJ"},
"four-o'clocks":	{"NNS"},
"four-part":	{"JJ"},
"four-peat":	{"NN"},
"four-peats":	{"NNS"},
"four-point":	{"JJ"},
"four-poster":	{"NN","JJ"},
"four-posters":	{"NNS"},
"four-seater":	{"NN"},
"four-seaters":	{"NNS"},
"four-speed":	{"NN"},
"four-speeds":	{"NNS"},
"four-square":	{"JJ","RB"},
"four-star":	{"JJ"},
"four-stroke":	{"JJ"},
"four-stroking":	{"NN"},
"four-top":	{"NN"},
"four-tops":	{"NNS"},
"four-vector":	{"NN"},
"four-vectors":	{"NNS"},
"four-walling":	{"NN"},
"four-way":	{"JJ"},
"four-wheel":	{"JJ"},
"four-wheel-drive":	{"NN","JJ"},
"four-wheeled":	{"JJ"},
"four-wheeler":	{"NN"},
"four-wheelers":	{"NNS"},
"fourball":	{"NN"},
"fourballs":	{"NNS"},
"fourfold":	{"JJ","RB"},
"fourier":	{"NN"},
"fourpence":	{"NN"},
"fourpenny":	{"JJ"},
"fours":	{"NNS"},
"fourscore":	{"NN","JJ"},
"foursome":	{"NN"},
"foursomes":	{"NNS"},
"foursquare":	{"JJ","NN","RB"},
"fourteen":	{"CD","NN"},
"fourteen-nation":	{"NN"},
"fourteen-team":	{"JJ"},
"fourteen-year-old":	{"JJ"},
"fourteenth":	{"NN","JJ"},
"fourth":	{"JJ","NN"},
"fourth-biggest":	{"JJ"},
"fourth-century":	{"JJ"},
"fourth-class":	{"JJ"},
"fourth-consecutive":	{"JJ"},
"fourth-down":	{"NN"},
"fourth-fifths":	{"NNS"},
"fourth-flight":	{"JJ"},
"fourth-generation":	{"JJ"},
"fourth-grade":	{"JJ"},
"fourth-hand":	{"JJ"},
"fourth-largest":	{"JJ"},
"fourth-level":	{"JJ"},
"fourth-period":	{"JJ"},
"fourth-quarter":	{"JJ","NN"},
"fourth-ranked":	{"JJ"},
"fourth-ranking":	{"JJ"},
"fourth-round":	{"JJ"},
"fourth-tier":	{"NN"},
"fourth-year":	{"JJ"},
"fourthly":	{"RB"},
"fourthquarter":	{"NN"},
"fovea":	{"NN"},
"fowl":	{"NN","NNS","VB","VBP"},
"fowled":	{"VBD","VBN"},
"fowler":	{"NN"},
"fowling":	{"VBG","NN"},
"fowls":	{"VBZ","NNS"},
"fox":	{"NN","VB","VBP"},
"fox-hounds":	{"NNS"},
"fox-terrier":	{"NN"},
"fox-trot":	{"NN"},
"foxberry":	{"NN"},
"foxed":	{"VBD","VBN"},
"foxes":	{"NNS","VBZ"},
"foxglove":	{"NN"},
"foxgloves":	{"NNS"},
"foxhole":	{"NN"},
"foxholes":	{"NNS"},
"foxhound":	{"NN"},
"foxhunt":	{"NN"},
"foxhunting":	{"NN"},
"foxier":	{"JJR"},
"foxiest":	{"JJS"},
"foxily":	{"RB"},
"foxiness":	{"NN"},
"foxing":	{"VBG"},
"foxtail":	{"NN"},
"foxtrot":	{"NN","VB","VBP"},
"foxtrots":	{"NNS","VBZ"},
"foxtrotted":	{"VBD","VBN"},
"foxtrotting":	{"VBG"},
"foxy":	{"JJ"},
"foyer":	{"NN"},
"foyers":	{"NNS"},
"fpd":	{"NN"},
"fps":	{"NN"},
"fr":	{"NN"},
"fracas":	{"NNS","NN"},
"fracases":	{"NNS"},
"fractal":	{"NN"},
"fractals":	{"NNS"},
"fraction":	{"NN","VB","VBP"},
"fractional":	{"JJ"},
"fractionally":	{"RB"},
"fractionate":	{"VB","VBP"},
"fractionated":	{"VBD","VBN"},
"fractionates":	{"VBZ"},
"fractionating":	{"VBG"},
"fractionation":	{"NN"},
"fractionator":	{"NN"},
"fractioned":	{"VBD","VBN"},
"fractioning":	{"VBG"},
"fractions":	{"NNS","VBZ"},
"fractious":	{"JJ"},
"fractiously":	{"RB"},
"fractiousness":	{"NN"},
"fracture":	{"NN","VB","VBP"},
"fractured":	{"JJ","VBD","VBN"},
"fractures":	{"NNS","VBZ"},
"fracturing":	{"VBG"},
"fradicin":	{"NN"},
"fragaria":	{"NN"},
"fragile":	{"JJ"},
"fragility":	{"NN"},
"fragment":	{"NN","VB","VBP"},
"fragmental":	{"JJ"},
"fragmentarily":	{"RB"},
"fragmentary":	{"JJ"},
"fragmentation":	{"NN"},
"fragmentations":	{"NNS"},
"fragmented":	{"JJ","VBD","VBN"},
"fragmenting":	{"VBG"},
"fragmentise":	{"VB","VBP"},
"fragmentised":	{"VBD","VBN"},
"fragmentises":	{"VBZ"},
"fragmentising":	{"VBG"},
"fragmentization":	{"NN"},
"fragmentize":	{"VB","VBP"},
"fragmentized":	{"VBD","VBN"},
"fragmentizes":	{"VBZ"},
"fragmentizing":	{"VBG"},
"fragments":	{"NNS","VBZ"},
"fragonard":	{"NN"},
"fragrance":	{"NN"},
"fragrances":	{"NNS"},
"fragrancy":	{"NN"},
"fragrans":	{"NN"},
"fragrant":	{"JJ"},
"fragrantly":	{"RB"},
"frail":	{"JJ"},
"frailer":	{"JJR"},
"frailest":	{"JJS"},
"frailness":	{"NN"},
"frailties":	{"NNS"},
"frailty":	{"NN"},
"fraise":	{"NN"},
"frambesia":	{"NN"},
"framboesia":	{"NN"},
"framboise":	{"NN"},
"frame":	{"NN","VB","VBP"},
"frame-up":	{"NN"},
"frame-ups":	{"NNS"},
"framed":	{"VBD","VBN"},
"framelet":	{"NN"},
"framer":	{"NN"},
"framers":	{"NNS"},
"frames":	{"NNS","VBZ"},
"framework":	{"NN"},
"frameworks":	{"NNS"},
"framing":	{"NN","VBG"},
"franc":	{"NN"},
"franc-denominated":	{"JJ"},
"franc-tireur":	{"NN"},
"franca":	{"NN"},
"franche-comte":	{"NN"},
"franchise":	{"NN","VB","VBP"},
"franchised":	{"VBD","VBN"},
"franchisee":	{"NN"},
"franchisees":	{"NNS"},
"franchiser":	{"NN"},
"franchisers":	{"NNS"},
"franchises":	{"NNS","VBZ"},
"franchising":	{"VBG"},
"franchisor":	{"NN"},
"franchisors":	{"NNS"},
"francisco-based":	{"JJ"},
"francisella":	{"NN"},
"francium":	{"NN"},
"franck":	{"NN"},
"franco-american":	{"NN"},
"francoa":	{"NN"},
"francophil":	{"NN"},
"francs":	{"NNS"},
"frangibility":	{"NN"},
"frangible":	{"JJ"},
"frangibleness":	{"NN"},
"frangipane":	{"NN"},
"frangipani":	{"NN"},
"frangipanni":	{"NN"},
"frank":	{"JJ","VB","VBP","NN"},
"franked":	{"VBD","VBN"},
"franker":	{"JJR"},
"frankest":	{"JJS"},
"frankfurt-based":	{"JJ"},
"frankfurter":	{"NN"},
"frankfurters":	{"NNS"},
"frankincense":	{"NN"},
"franking":	{"VBG"},
"frankish":	{"JJ"},
"frankliniella":	{"NN"},
"frankly":	{"RB"},
"frankness":	{"NN"},
"franks":	{"NNS","VBZ"},
"franks-in-buns":	{"NNS"},
"franny":	{"NN"},
"frantic":	{"JJ"},
"frantically":	{"RB"},
"frap":	{"VB","VBP"},
"frappe":	{"NN","JJ"},
"frapped":	{"VBD","VBN"},
"frapping":	{"VBG"},
"fraps":	{"VBZ"},
"frasera":	{"NN"},
"frat":	{"NN"},
"fratercula":	{"NN"},
"fraternal":	{"JJ"},
"fraternally":	{"RB"},
"fraternisation":	{"NN"},
"fraternise":	{"VB","VBP"},
"fraternised":	{"VBD","VBN"},
"fraternises":	{"VBZ"},
"fraternising":	{"VBG"},
"fraternities":	{"NNS"},
"fraternity":	{"NN"},
"fraternization":	{"NN"},
"fraternize":	{"VB","VBP"},
"fraternized":	{"VBD","VBN"},
"fraternizes":	{"VBZ"},
"fraternizing":	{"VBG"},
"fratricide":	{"NN"},
"frats":	{"NNS"},
"frattier":	{"JJR"},
"frattiest":	{"JJS"},
"fratty":	{"JJ"},
"fraud":	{"NN"},
"fraud-related":	{"JJ"},
"frauds":	{"NNS"},
"fraudulence":	{"NN"},
"fraudulent":	{"JJ"},
"fraudulently":	{"RB"},
"fraught":	{"JJ"},
"fraxinella":	{"NN"},
"fraxinus":	{"NN"},
"fray":	{"NN","VB","VBP"},
"frayed":	{"VBD","VBN","JJ"},
"fraying":	{"VBG"},
"frays":	{"VBZ"},
"frazier":	{"NN"},
"frazzle":	{"NN","VB","VBP"},
"frazzled":	{"VBN","VBD"},
"frazzles":	{"VBZ"},
"frazzling":	{"VBG"},
"freak":	{"VB","VBP","NN","JJ"},
"freaked":	{"VBD","VBN"},
"freakier":	{"JJR"},
"freakiest":	{"JJS"},
"freaking":	{"VBG"},
"freakish":	{"JJ"},
"freakishly":	{"RB"},
"freakishness":	{"NN"},
"freaks":	{"VBZ"},
"freaky":	{"JJ"},
"freckle":	{"NN","VB","VBP"},
"freckled":	{"JJ","VBD","VBN"},
"freckles":	{"NNS","VBZ"},
"freckling":	{"VBG"},
"frederick":	{"NN"},
"fredericksburg":	{"NN"},
"fredericton":	{"NN"},
"free":	{"JJ","VB","RB","VBP"},
"free-agent":	{"NN"},
"free-and-easy":	{"JJ"},
"free-associate":	{"VB","VBP"},
"free-associated":	{"VBD","VBN"},
"free-associates":	{"VBZ"},
"free-associating":	{"VBG"},
"free-base":	{"NN"},
"free-blown":	{"JJ"},
"free-burning":	{"JJ"},
"free-buying":	{"JJ"},
"free-choice":	{"JJ"},
"free-drink":	{"JJ"},
"free-enterprise":	{"NN"},
"free-fall":	{"NN"},
"free-falling":	{"JJ"},
"free-floater":	{"NN"},
"free-flying":	{"JJ"},
"free-for-all":	{"NN"},
"free-for-alls":	{"NNS"},
"free-hand":	{"JJ","RB"},
"free-handed":	{"JJ"},
"free-holders":	{"NNS"},
"free-lance":	{"NN"},
"free-liver":	{"NN"},
"free-living":	{"JJ"},
"free-mail":	{"NN"},
"free-market":	{"JJ","NN"},
"free-market-oriented":	{"JJ"},
"free-marketeer":	{"NN"},
"free-marketeers":	{"NNS"},
"free-marketer":	{"NN"},
"free-marketers":	{"NNS"},
"free-on-board":	{"JJ"},
"free-range":	{"JJ"},
"free-reed":	{"NN"},
"free-soil":	{"JJ"},
"free-speech":	{"NN"},
"free-spending":	{"JJ"},
"free-spirited":	{"JJ"},
"free-spiritedness":	{"NN"},
"free-spoken":	{"JJ"},
"free-standing":	{"JJ"},
"free-swimming":	{"JJ"},
"free-thinker":	{"NN"},
"free-thinkers":	{"NNS"},
"free-thinking":	{"JJ"},
"free-throw":	{"JJ","NN"},
"free-trade":	{"JJ","NN"},
"free-traders":	{"NNS"},
"free-travel":	{"JJ"},
"free-wheeling":	{"JJ"},
"free-world":	{"JJ"},
"freebase":	{"NN","VB","VBP"},
"freebased":	{"VBD","VBN"},
"freebases":	{"VBZ"},
"freebasing":	{"VBG"},
"freebee":	{"NN"},
"freebie":	{"NN"},
"freebies":	{"NNS"},
"freebooter":	{"NN"},
"freebooters":	{"NNS"},
"freeborn":	{"JJ"},
"freed":	{"VBD","VBN"},
"freedman":	{"NN"},
"freedmen":	{"NNS"},
"freedom":	{"NN"},
"freedom-conscious":	{"JJ"},
"freedom-loving":	{"JJ"},
"freedoms":	{"NNS"},
"freedwoman":	{"NN"},
"freefall":	{"NN"},
"freehand":	{"JJ","RB"},
"freehanded":	{"JJ"},
"freehearted":	{"JJ"},
"freehold":	{"NN","JJ","RB"},
"freeholder":	{"NN"},
"freeholders":	{"NNS"},
"freeing":	{"VBG"},
"freelance":	{"JJ","RB","NN","VB","VBP"},
"freelanced":	{"VBD","VBN"},
"freelancer":	{"NN"},
"freelancers":	{"NNS"},
"freelances":	{"NNS","VBZ"},
"freelancing":	{"VBG"},
"freeload":	{"VB","VBP"},
"freeloaded":	{"VBD","VBN"},
"freeloader":	{"NN"},
"freeloaders":	{"NNS"},
"freeloading":	{"VBG"},
"freeloads":	{"VBZ"},
"freely":	{"RB"},
"freemail":	{"NN"},
"freeman":	{"NN"},
"freemarket":	{"JJ","NN"},
"freemason":	{"NN"},
"freemasonry":	{"NN"},
"freemen":	{"NNS"},
"freeport":	{"NN"},
"freer":	{"JJR"},
"freer-spending":	{"JJ"},
"frees":	{"VBZ"},
"freescrip":	{"NN"},
"freesia":	{"NN"},
"freesias":	{"NNS"},
"freespender":	{"NN"},
"freest":	{"JJS"},
"freestanding":	{"JJ"},
"freestone":	{"NN"},
"freestyle":	{"NN","JJ"},
"freestylers":	{"NNS"},
"freetail":	{"NN"},
"freethinker":	{"NN"},
"freethinkers":	{"NNS"},
"freethinking":	{"JJ"},
"freetime":	{"NN"},
"freeware":	{"NN"},
"freeway":	{"NN"},
"freeways":	{"NNS"},
"freewheel":	{"VB","VBP"},
"freewheeled":	{"VBD","VBN"},
"freewheeler":	{"NN"},
"freewheelers":	{"NNS"},
"freewheeling":	{"JJ","VBG"},
"freewheels":	{"VBZ"},
"freewill":	{"JJ"},
"freewoman":	{"NN"},
"freeze":	{"NN","VB","VBP"},
"freeze-dried":	{"VBD","VBN","JJ"},
"freeze-dries":	{"VBZ"},
"freeze-dry":	{"VB","VBP"},
"freeze-drying":	{"VBG","NN"},
"freeze-out":	{"JJ","NN"},
"freezed":	{"VBD"},
"freezer":	{"NN"},
"freezers":	{"NNS"},
"freezes":	{"VBZ","NNS"},
"freezing":	{"NN","JJ","RB","VBG"},
"fregata":	{"NN"},
"fregatidae":	{"NN"},
"freight":	{"NN","VB","VBP"},
"freight-bums":	{"NNS"},
"freight-car":	{"NN"},
"freight-cost":	{"JJ"},
"freight-forwarding":	{"JJ"},
"freight-hauling":	{"JJ"},
"freight-jumper":	{"NN"},
"freight-rate":	{"JJ"},
"freight-transport":	{"JJ","NN"},
"freightage":	{"NN"},
"freighted":	{"VBD","VBN"},
"freighter":	{"NN"},
"freighters":	{"NNS"},
"freighting":	{"VBG"},
"freightliner":	{"NN"},
"freights":	{"VBZ","NNS"},
"fremontia":	{"NN"},
"fremontodendron":	{"NN"},
"french-born":	{"JJ"},
"french-franc":	{"NN"},
"french-government-owned":	{"JJ"},
"french-italian":	{"JJ"},
"french-language":	{"JJ"},
"french-made":	{"JJ"},
"french-modeled":	{"JJ"},
"french-polished":	{"JJ"},
"french-speaking":	{"JJ"},
"frenemies":	{"NNS"},
"frenetic":	{"JJ"},
"frenetically":	{"RB"},
"frenzied":	{"JJ","VBD","VBN"},
"frenziedly":	{"RB"},
"frenzies":	{"NNS","VBZ"},
"frenzy":	{"NN","VB","VBP"},
"frenzy-free":	{"JJ"},
"frenzying":	{"VBG"},
"frequence":	{"NN"},
"frequencies":	{"NNS"},
"frequency":	{"NN"},
"frequency-control":	{"JJ"},
"frequency-independent":	{"JJ"},
"frequency-modulation":	{"NN"},
"frequent":	{"JJ","VB","VBP"},
"frequent-flier":	{"JJ"},
"frequent-flyer":	{"NN"},
"frequentative":	{"NN"},
"frequented":	{"VBD","VBN"},
"frequenter":	{"NN"},
"frequenting":	{"VBG"},
"frequently":	{"RB"},
"frequents":	{"VBZ"},
"fresco":	{"NN","VB","VBP"},
"frescoed":	{"VBD","VBN"},
"frescoes":	{"NNS","VBZ"},
"frescoing":	{"NN","VBG"},
"frescos":	{"NNS","VBZ"},
"fresh":	{"JJ","RB"},
"fresh-cut":	{"JJ"},
"fresh-faced":	{"JJ"},
"fresh-fruit":	{"JJ","NN"},
"fresh-ground":	{"JJ"},
"fresh-perked":	{"JJ"},
"freshborn":	{"NN"},
"freshen":	{"VB","VBP"},
"freshened":	{"VBD","VBN"},
"freshener":	{"NN"},
"freshening":	{"VBG"},
"freshens":	{"VBZ"},
"fresher":	{"NN","JJR"},
"freshers":	{"NNS"},
"freshest":	{"JJS"},
"freshet":	{"NN"},
"freshly":	{"RB"},
"freshly-ground":	{"JJ"},
"freshman":	{"NN"},
"freshmen":	{"NNS"},
"freshness":	{"NN"},
"freshwater":	{"JJ"},
"fresnel":	{"NN"},
"fret":	{"VB","VBP","NN"},
"fretful":	{"JJ"},
"fretfully":	{"RB"},
"fretfulness":	{"NN"},
"frets":	{"VBZ","NNS"},
"fretsaw":	{"NN"},
"fretsaws":	{"NNS"},
"fretted":	{"JJ","VBD","VBN"},
"fretting":	{"VBG"},
"fretwork":	{"NN"},
"frey":	{"NN"},
"freya":	{"NN"},
"freyja":	{"NN"},
"freyr":	{"NN"},
"frg":	{"NN"},
"friability":	{"NN"},
"friable":	{"JJ"},
"friar":	{"NN"},
"friar's-cowl":	{"NN"},
"friaries":	{"NNS"},
"friars":	{"NNS"},
"friary":	{"NN"},
"fricandeau":	{"NN"},
"fricassee":	{"NN","VB","VBP"},
"fricasseed":	{"VBD","VBN"},
"fricasseeing":	{"VBG"},
"fricassees":	{"NNS","VBZ"},
"fricative":	{"NN","JJ"},
"fricatives":	{"NNS"},
"frick":	{"NN"},
"friction":	{"NN"},
"friction-free":	{"JJ"},
"frictional":	{"JJ"},
"frictionless":	{"JJ"},
"frictions":	{"NNS"},
"fridge":	{"NN"},
"fridges":	{"NNS"},
"fried":	{"JJ","VBD","VBN"},
"friedcake":	{"NN"},
"friend":	{"NN","VB","VBP"},
"friend-of-the-court":	{"JJ"},
"friended":	{"VBD","VBN"},
"friending":	{"VBG"},
"friendless":	{"JJ"},
"friendlessness":	{"NN"},
"friendlier":	{"JJR"},
"friendlies":	{"NNS"},
"friendliest":	{"JJS"},
"friendlily":	{"RB"},
"friendliness":	{"NN"},
"friendly":	{"JJ","NN"},
"friends":	{"NNS","VBZ"},
"friendship":	{"NN"},
"friendships":	{"NNS"},
"frier":	{"NN"},
"friers":	{"NNS"},
"fries":	{"VBZ","NNS"},
"friesland":	{"NN"},
"frieze":	{"NN"},
"friezes":	{"NNS"},
"frig":	{"VB","VBP"},
"frigate":	{"NN"},
"frigates":	{"NNS"},
"frigga":	{"NN"},
"frigged":	{"VBD","VBN"},
"frigging":	{"VBG","JJ"},
"fright":	{"NN","VB","VBP"},
"frighted":	{"VBD","VBN"},
"frighten":	{"VB","VBP"},
"frightened":	{"JJ","VBD","VBN"},
"frightening":	{"JJ","VBG"},
"frighteningly":	{"RB"},
"frightens":	{"VBZ"},
"frightful":	{"JJ"},
"frightfully":	{"RB"},
"frightfulness":	{"NN"},
"frighting":	{"VBG"},
"frights":	{"VBZ"},
"frigid":	{"JJ"},
"frigidity":	{"NN"},
"frigidly":	{"RB"},
"frigidness":	{"NN"},
"frigorific":	{"JJ"},
"frigs":	{"VBZ"},
"frijol":	{"NN"},
"frijole":	{"NN"},
"frijolillo":	{"NN"},
"frijolito":	{"NN"},
"frill":	{"NN","VB","VBP"},
"frilled":	{"JJ","VBD","VBN"},
"frilling":	{"VBG","NN"},
"frills":	{"NNS","VBZ"},
"frilly":	{"JJ"},
"frimaire":	{"NN"},
"fringe":	{"NN","JJ","VB","VBP"},
"fringe-benefit":	{"NN"},
"fringed":	{"JJ","VBD","VBN"},
"fringed-wrapped":	{"JJ"},
"fringepod":	{"NN"},
"fringes":	{"NNS","VBZ"},
"fringilla":	{"NN"},
"fringillidae":	{"NN"},
"fringing":	{"VBG"},
"fringy":	{"JJ"},
"fripperies":	{"NNS"},
"frippery":	{"NN"},
"frisch":	{"NN"},
"frise":	{"NN"},
"frisia":	{"NN"},
"frisk":	{"VB","VBP"},
"frisked":	{"VBD","VBN"},
"friskier":	{"JJR"},
"friskiest":	{"JJS"},
"friskily":	{"RB"},
"friskiness":	{"NN"},
"frisking":	{"VBG"},
"frisks":	{"VBZ"},
"frisky":	{"JJ"},
"frisson":	{"NN"},
"frissons":	{"NNS"},
"fritillaria":	{"NN"},
"fritillary":	{"NN"},
"frittata":	{"NN"},
"fritter":	{"VB","VBP","NN"},
"frittered":	{"VBD","VBN"},
"frittering":	{"VBG"},
"fritters":	{"VBZ","NNS"},
"friuli":	{"NN"},
"friulian":	{"NN"},
"frivol":	{"VB","VBP"},
"frivoled":	{"VBD","VBN"},
"frivoler":	{"NN"},
"frivoling":	{"VBG"},
"frivolities":	{"NNS"},
"frivolity":	{"NN"},
"frivolled":	{"VBD","VBN"},
"frivoller":	{"NN"},
"frivolling":	{"VBG"},
"frivolous":	{"JJ"},
"frivolously":	{"RB"},
"frivolousness":	{"NN"},
"frivols":	{"VBZ"},
"frizz":	{"VB","VBP","NN"},
"frizzed":	{"VBD","VBN"},
"frizzes":	{"VBZ"},
"frizzier":	{"JJR"},
"frizziest":	{"JJS"},
"frizzing":	{"VBG"},
"frizzle":	{"NN","VB","VBP"},
"frizzled":	{"VBD","VBN"},
"frizzles":	{"VBZ"},
"frizzling":	{"VBG"},
"frizzly":	{"JJ"},
"frizzy":	{"JJ"},
"fro":	{"RB"},
"frobisher":	{"NN"},
"frock":	{"NN","VB","VBP"},
"frocked":	{"VBD","VBN"},
"frocking":	{"VBG"},
"frocks":	{"NNS","VBZ"},
"froebel":	{"NN"},
"froelichia":	{"NN"},
"frog":	{"NN"},
"frog's-bit":	{"NN"},
"frog-eating":	{"JJ"},
"frog-haiku":	{"NN"},
"frog-marched":	{"JJ"},
"frogbit":	{"NN"},
"frogfish":	{"NN"},
"froghopper":	{"NN"},
"frogman":	{"NN"},
"frogmarch":	{"VB","VBP"},
"frogmarched":	{"VBD","VBN"},
"frogmarches":	{"VBZ"},
"frogmarching":	{"VBG"},
"frogmen":	{"NNS"},
"frogmouth":	{"NN"},
"frogs":	{"NNS"},
"frolic":	{"VB","VBP","NN"},
"frolicked":	{"VBD","VBN"},
"frolicking":	{"VBG"},
"frolicky":	{"JJ"},
"frolics":	{"VBZ","NNS"},
"frolicsome":	{"JJ"},
"frolicsomeness":	{"NN"},
"from":	{"IN"},
"frond":	{"NN"},
"fronds":	{"NNS"},
"front":	{"NN","JJ","VB","VBP"},
"front-back":	{"JJ"},
"front-desk":	{"NN","JJ"},
"front-end":	{"JJ"},
"front-line":	{"JJ","NN"},
"front-lines":	{"NNS"},
"front-load":	{"VB","VBP"},
"front-loaded":	{"VBD","VBN"},
"front-loaders":	{"NNS"},
"front-loading":	{"VBG"},
"front-loads":	{"VBZ"},
"front-office":	{"NN"},
"front-page":	{"JJ"},
"front-runner":	{"NN"},
"front-runners":	{"NNS"},
"front-running":	{"NN"},
"front-seat":	{"NN"},
"front-stall":	{"NN"},
"frontage":	{"NN"},
"frontal":	{"JJ","NN"},
"frontally":	{"RB"},
"frontbencher":	{"NN"},
"fronted":	{"JJ","VBD","VBN"},
"frontend":	{"NN"},
"frontier":	{"NN"},
"frontiers":	{"NNS"},
"frontiersman":	{"NN"},
"frontiersmen":	{"NNS"},
"frontierswoman":	{"NN"},
"fronting":	{"VBG"},
"frontispiece":	{"NN"},
"frontispieces":	{"NNS"},
"frontlet":	{"NN"},
"frontline":	{"NN"},
"frontmost":	{"JJ"},
"frontrunner":	{"NN"},
"fronts":	{"NNS","VBZ"},
"frontstall":	{"NN"},
"frontward":	{"RB"},
"frontwards":	{"RB"},
"frore":	{"JJ"},
"fros":	{"NNS"},
"frost":	{"NN","VB","VBP"},
"frost-bitten":	{"JJ"},
"frost-bound":	{"JJ"},
"frost-weed":	{"NN"},
"frostbit":	{"VBD"},
"frostbite":	{"NN","VB","VBP"},
"frostbites":	{"VBZ"},
"frostbiting":	{"VBG"},
"frostbitten":	{"JJ","VBN"},
"frosted":	{"JJ","VBD","VBN"},
"frostian":	{"JJ"},
"frostier":	{"JJR"},
"frostiest":	{"JJS"},
"frostily":	{"RB"},
"frostiness":	{"NN"},
"frosting":	{"NN","VBG"},
"frosts":	{"NNS","VBZ"},
"frostweed":	{"NN"},
"frostwort":	{"NN"},
"frosty":	{"JJ"},
"froth":	{"NN","VB","VBP"},
"frothed":	{"VBD","VBN"},
"frothier":	{"JJR"},
"frothiest":	{"JJS"},
"frothily":	{"RB"},
"frothiness":	{"NN"},
"frothing":	{"VBG"},
"froths":	{"VBZ"},
"frothy":	{"JJ"},
"frottage":	{"NN"},
"frotteur":	{"NN"},
"froward":	{"JJ"},
"frown":	{"NN","VB","VBP"},
"frowned":	{"VBD","VBN"},
"frowning":	{"VBG"},
"frowningly":	{"RB"},
"frowns":	{"NNS","VBZ"},
"frowsty":	{"JJ"},
"frowsy":	{"JJ"},
"frowzled":	{"JJ"},
"frowzy":	{"JJ"},
"froze":	{"VBD"},
"frozen":	{"VBN","JJ"},
"frozen-embryo":	{"NN"},
"frozen-food":	{"NN"},
"frozen-foods":	{"NNS"},
"frozen-pizza":	{"NN"},
"frs":	{"NNS"},
"fructidor":	{"NN"},
"fructification":	{"NN"},
"fructified":	{"VBD","VBN"},
"fructifies":	{"VBZ"},
"fructify":	{"VB","VBP"},
"fructifying":	{"VBG"},
"fructose":	{"NN"},
"fructosuria":	{"NN"},
"frugal":	{"JJ"},
"frugality":	{"NN"},
"frugally":	{"RB"},
"frugalness":	{"NN"},
"fruit":	{"NN","NNS","VBP","VB"},
"fruit-concentrate":	{"JJ"},
"fruit-eating":	{"JJ"},
"fruit-flavored":	{"JJ"},
"fruit-juice":	{"NN"},
"fruitage":	{"NN"},
"fruitbowl":	{"NN"},
"fruitcake":	{"NN"},
"fruitcakes":	{"NNS"},
"fruited":	{"VBD","VBN"},
"fruiterer":	{"NN"},
"fruiterers":	{"NNS"},
"fruitful":	{"JJ"},
"fruitfully":	{"RB"},
"fruitfulness":	{"NN"},
"fruitier":	{"JJR"},
"fruitiest":	{"JJS"},
"fruiting":	{"VBG"},
"fruition":	{"NN"},
"fruitless":	{"JJ"},
"fruitlessly":	{"RB"},
"fruitlessness":	{"NN"},
"fruitlet":	{"NN"},
"fruits":	{"NNS","VBZ"},
"fruitwood":	{"NN"},
"fruity":	{"JJ"},
"frumenty":	{"NN"},
"frump":	{"NN"},
"frumpily":	{"RB"},
"frumpish":	{"JJ"},
"frumpishly":	{"RB"},
"frumps":	{"NNS"},
"frumpy":	{"JJ"},
"frunze":	{"NN"},
"frustrate":	{"VB","VBP"},
"frustrated":	{"VBN","JJ","VBD"},
"frustratedly":	{"RB"},
"frustrates":	{"VBZ"},
"frustrating":	{"JJ","VBG"},
"frustratingly":	{"RB"},
"frustration":	{"NN"},
"frustrations":	{"NNS"},
"frustrative":	{"JJ"},
"frustum":	{"NN"},
"fruticose":	{"JJ"},
"fruticulose":	{"JJ"},
"fry":	{"VB","VBP","NN","NNS"},
"fry-pan":	{"NN"},
"fry-up":	{"NN"},
"fry-ups":	{"NNS"},
"frye":	{"NN"},
"fryer":	{"NN"},
"fryers":	{"NNS"},
"frying":	{"VBG"},
"frying-pan":	{"NN"},
"frying-pans":	{"NNS"},
"frypan":	{"NN"},
"frypans":	{"NNS"},
"fsb":	{"NN"},
"fsh":	{"NN"},
"ft":	{"NN","NNS"},
"ft-l":	{"NN"},
"ft.":	{"NN","NNS"},
"ftc":	{"NN"},
"fthm":	{"NN"},
"fto":	{"NN"},
"ftp":	{"NN","VB","VBP"},
"ftped":	{"VBD","VBN"},
"ftping":	{"VBG"},
"ftps":	{"VBZ"},
"fu":	{"NN"},
"fucaceae":	{"NN"},
"fucales":	{"NNS"},
"fuchs":	{"NNS"},
"fuchsia":	{"NN"},
"fuchsias":	{"NNS"},
"fuck":	{"NN","VB","VBP","UH"},
"fuck-all":	{"NN"},
"fuck-up":	{"NN"},
"fuckable":	{"JJ"},
"fucked":	{"VBD","VBN","JJ"},
"fucked-up":	{"JJ"},
"fucken":	{"JJ"},
"fucker":	{"NN"},
"fuckers":	{"NNS"},
"fuckhead":	{"NN"},
"fuckheads":	{"NNS"},
"fucking":	{"JJ","RB","VBG"},
"fucks":	{"NNS","VBZ"},
"fuckup":	{"NN"},
"fucoid":	{"NN"},
"fucus":	{"NN"},
"fuddle":	{"VB","VBP","NN"},
"fuddled":	{"JJ","VBD","VBN"},
"fuddles":	{"VBZ"},
"fuddling":	{"VBG"},
"fuddy-duddies":	{"NNS"},
"fuddy-duddy":	{"NN","JJ"},
"fudge":	{"NN","VB","VBP"},
"fudged":	{"VBD","VBN"},
"fudges":	{"VBZ"},
"fudging":	{"VBG"},
"fuego":	{"NN"},
"fuel":	{"NN","VB","VBP"},
"fuel-cost":	{"JJ"},
"fuel-distribution":	{"NN"},
"fuel-economy":	{"NN"},
"fuel-efficiency":	{"JJ"},
"fuel-efficient":	{"JJ"},
"fuel-guzzling":	{"JJ"},
"fuel-injected":	{"JJ"},
"fuel-neutral":	{"JJ"},
"fuel-services":	{"NNS"},
"fuel-storage":	{"NN"},
"fueled":	{"VBN","VBD","JJ"},
"fueling":	{"VBG"},
"fuelled":	{"VBD","VBN","JJ"},
"fuelling":	{"VBG"},
"fueloil":	{"NN"},
"fuels":	{"NNS","VBZ"},
"fuer":	{"NN"},
"fug":	{"NN"},
"fugacious":	{"JJ"},
"fugaciousness":	{"NN"},
"fugacity":	{"NN"},
"fugal":	{"JJ"},
"fugally":	{"RB"},
"fugard":	{"NN"},
"fuggy":	{"JJ"},
"fugitive":	{"NN","JJ"},
"fugitives":	{"NNS"},
"fugleman":	{"NN"},
"fugly":	{"JJ"},
"fugo":	{"NN"},
"fugu":	{"NN"},
"fugual":	{"JJ"},
"fugue":	{"NN"},
"fugures":	{"NNS"},
"fuji-apple":	{"JJ"},
"fuji-san":	{"NN"},
"fujinoyama":	{"NN"},
"fujiyama":	{"NN"},
"fukien":	{"NN"},
"fukkianese":	{"NN"},
"fukuoka":	{"NN"},
"ful":	{"NN"},
"fula":	{"NN"},
"fulah":	{"NN"},
"fulani":	{"NN"},
"fulbe":	{"NN"},
"fulbright":	{"NN"},
"fulcrum":	{"NN"},
"fulfil":	{"VB","VBP"},
"fulfill":	{"VB","VBP"},
"fulfilled":	{"JJ","VBD","VBN"},
"fulfilling":	{"JJ","VBG"},
"fulfillment":	{"NN"},
"fulfills":	{"VBZ"},
"fulfilment":	{"NN"},
"fulfils":	{"VBZ"},
"fulgent":	{"JJ"},
"fulgid":	{"JJ"},
"fulgoridae":	{"NN"},
"fulgurant":	{"JJ"},
"fulgurate":	{"VB","VBP"},
"fulgurated":	{"VBD","VBN"},
"fulgurates":	{"VBZ"},
"fulgurating":	{"JJ","VBG"},
"fulgurous":	{"JJ"},
"fulica":	{"NN"},
"full":	{"JJ","RB","NN"},
"full-back":	{"NN"},
"full-backs":	{"NNS"},
"full-blood":	{"NN","JJ"},
"full-blooded":	{"JJ"},
"full-bloodedness":	{"NN"},
"full-bloods":	{"NNS"},
"full-blown":	{"JJ"},
"full-board":	{"NN"},
"full-bodied":	{"JJ"},
"full-bore":	{"JJ","RB"},
"full-bosomed":	{"JJ"},
"full-bottomed":	{"JJ"},
"full-cream":	{"JJ"},
"full-dress":	{"JJ"},
"full-face":	{"JJ"},
"full-faced":	{"JJ"},
"full-fare":	{"JJ"},
"full-fashioned":	{"JJ"},
"full-featured":	{"JJ"},
"full-flavored":	{"JJ"},
"full-flavoured":	{"JJ"},
"full-fledged":	{"JJ"},
"full-frontal":	{"JJ"},
"full-grown":	{"JJ"},
"full-length":	{"JJ"},
"full-mouthed":	{"JJ"},
"full-on":	{"JJ"},
"full-page":	{"JJ"},
"full-rigged":	{"JJ"},
"full-sailed":	{"JJ"},
"full-scale":	{"JJ"},
"full-serve":	{"JJ"},
"full-service":	{"JJ"},
"full-size":	{"JJ"},
"full-sized":	{"JJ"},
"full-strength":	{"JJ"},
"full-term":	{"JJ"},
"full-throated":	{"JJ"},
"full-throttle":	{"JJ","RB"},
"full-time":	{"JJ","RB","NN"},
"full-timer":	{"NN"},
"full-timers":	{"NNS"},
"full-up":	{"JJ"},
"full-year":	{"JJ"},
"fullback":	{"NN"},
"fullbacking":	{"VBG"},
"fullbacks":	{"NNS"},
"fullblood":	{"NN","JJ"},
"fulled":	{"VBD","VBN"},
"fuller":	{"NN","JJR","VB","VBP"},
"fullered":	{"VBD","VBN"},
"fullerene":	{"NN"},
"fulleride":	{"NN"},
"fullerides":	{"NNS"},
"fulleries":	{"NNS"},
"fullering":	{"VBG"},
"fullers":	{"NNS","VBZ"},
"fullery":	{"NN"},
"fullest":	{"JJS"},
"fullface":	{"NN","RB"},
"fulling":	{"VBG"},
"fullish":	{"JJ"},
"fulllength":	{"JJ"},
"fullness":	{"NN"},
"fulls":	{"VBZ"},
"fullscale":	{"JJ"},
"fully":	{"RB"},
"fully-featured":	{"JJ"},
"fully-fitted":	{"JJ"},
"fulmar":	{"NN"},
"fulmarus":	{"NN"},
"fulminant":	{"JJ"},
"fulminate":	{"VB","VBP"},
"fulminated":	{"VBD","VBN"},
"fulminates":	{"VBZ"},
"fulminating":	{"VBG"},
"fulmination":	{"NN"},
"fulminations":	{"NNS"},
"fulsome":	{"JJ"},
"fulsomely":	{"RB"},
"fulsomeness":	{"NN"},
"fulvicin":	{"NN"},
"fumaria":	{"NN"},
"fumariaceae":	{"NN"},
"fumble":	{"VB","VBP","NN"},
"fumbled":	{"VBD","VBN"},
"fumbler":	{"NN"},
"fumbles":	{"VBZ"},
"fumbling":	{"NN","VBG"},
"fume":	{"NN","VB","VBP"},
"fume-filled":	{"JJ"},
"fumed":	{"VBD","VBN"},
"fumed-oak":	{"JJ","NN"},
"fumeroot":	{"NN"},
"fumes":	{"NNS","VBZ"},
"fumewort":	{"NN"},
"fumigant":	{"NN"},
"fumigants":	{"NNS"},
"fumigate":	{"VB","VBP"},
"fumigated":	{"VBD","VBN"},
"fumigates":	{"VBZ"},
"fumigating":	{"VBG"},
"fumigation":	{"NN"},
"fumigator":	{"NN"},
"fuming":	{"VBG"},
"fumio":	{"NN"},
"fumitory":	{"NN"},
"fun":	{"NN","JJ"},
"fun-fair":	{"NN"},
"fun-filled":	{"JJ"},
"fun-in-the-sun":	{"JJ"},
"fun-loving":	{"JJ"},
"funafuti":	{"NN"},
"funambulism":	{"NN"},
"funambulist":	{"NN"},
"function":	{"NN","VB","VBP"},
"functional":	{"JJ"},
"functionalism":	{"NN"},
"functionalist":	{"NN","JJ"},
"functionalists":	{"NNS"},
"functionality":	{"NN"},
"functionally":	{"RB"},
"functionaries":	{"NNS"},
"functionary":	{"NN"},
"functioned":	{"VBD","VBN"},
"functioning":	{"VBG"},
"functions":	{"NNS","VBZ"},
"fund":	{"NN","VB","VBP"},
"fund-objective":	{"JJ"},
"fund-raise":	{"VB","VBP"},
"fund-raised":	{"VBD","VBN"},
"fund-raiser":	{"NN"},
"fund-raisers":	{"NNS"},
"fund-raises":	{"VBZ"},
"fund-raising":	{"NN","VBG"},
"fund-research":	{"JJ","NN"},
"fund-selling":	{"JJ"},
"fundamantal":	{"JJ"},
"fundamantalist":	{"NN"},
"fundament":	{"NN"},
"fundamental":	{"JJ","NN"},
"fundamentalism":	{"NN"},
"fundamentalist":	{"NN","JJ"},
"fundamentalistic":	{"JJ"},
"fundamentalists":	{"NNS"},
"fundamentally":	{"RB"},
"fundamentals":	{"NNS"},
"funded":	{"VBN","VBD","JJ"},
"funder":	{"NN"},
"funders":	{"NNS"},
"funding":	{"NN","VBG"},
"fundraise":	{"VB","VBP"},
"fundraised":	{"VBD","VBN"},
"fundraiser":	{"NN"},
"fundraisers":	{"NNS"},
"fundraises":	{"VBZ"},
"fundraising":	{"NN","VBG"},
"funds":	{"NNS","VBZ"},
"funds-management":	{"NN"},
"funds-service":	{"JJ"},
"fundulus":	{"NNS"},
"fundus":	{"NN"},
"funeral":	{"NN","JJ"},
"funeral-accessories":	{"NNS"},
"funeral-residence":	{"NN"},
"funerals":	{"NNS"},
"funerary":	{"JJ"},
"funereal":	{"JJ"},
"funfair":	{"NN"},
"funfairs":	{"NNS"},
"fungal":	{"JJ"},
"fungi":	{"NNS"},
"fungia":	{"NN"},
"fungibility":	{"NN"},
"fungible":	{"JJ"},
"fungicidal":	{"JJ"},
"fungicide":	{"NN"},
"fungicides":	{"NNS"},
"fungoid":	{"JJ"},
"fungous":	{"JJ"},
"fungus":	{"NN"},
"fungus-produced":	{"JJ"},
"funguses":	{"NNS"},
"funguslike":	{"JJ"},
"funicle":	{"NN"},
"funicular":	{"JJ","NN"},
"funiculitis":	{"NNS"},
"funiculus":	{"NN"},
"funk":	{"NN","VBP","VB"},
"funka":	{"NN"},
"funkaceae":	{"NN"},
"funked":	{"VBD","VBN"},
"funkier":	{"JJR"},
"funkiest":	{"JJS"},
"funking":	{"VBG"},
"funks":	{"NNS","VBZ"},
"funky":	{"JJ"},
"funn-eeee":	{"JJ"},
"funn-ih":	{"JJ"},
"funnel":	{"NN","VB","VBP"},
"funnel-shaped":	{"JJ"},
"funneled":	{"VBD","VBN","JJ"},
"funneling":	{"VBG"},
"funnelled":	{"VBD","VBN","JJ"},
"funnelling":	{"VBG"},
"funnels":	{"NNS","VBZ"},
"funnier":	{"JJR"},
"funnies":	{"NNS"},
"funniest":	{"JJS"},
"funnily":	{"RB"},
"funniness":	{"NN"},
"funny":	{"JJ","NN"},
"funny-bone":	{"NN"},
"funrun":	{"NN"},
"fuqra":	{"NN"},
"fur":	{"NN","VB","VBP"},
"fur-and-leather":	{"JJ"},
"fur-bearing":	{"JJ"},
"fur-lined":	{"JJ"},
"fur-making":	{"JJ"},
"fur-piece":	{"NN"},
"fur-production":	{"JJ"},
"furan":	{"NN"},
"furane":	{"NN"},
"furbelow":	{"NN"},
"furbelows":	{"NNS"},
"furbish":	{"VB","VBP"},
"furbished":	{"VBD","VBN"},
"furbishes":	{"VBZ"},
"furbishing":	{"VBG"},
"furcate":	{"JJ"},
"furcation":	{"NN"},
"furcula":	{"NN"},
"furfural":	{"NN"},
"furfuraldehyde":	{"NN"},
"furfuran":	{"NN"},
"furies":	{"NNS"},
"furious":	{"JJ"},
"furiously":	{"RB"},
"furiousness":	{"NN"},
"furl":	{"VB","VBP"},
"furled":	{"VBD","VBN","JJ"},
"furlike":	{"JJ"},
"furling":	{"VBG"},
"furlong":	{"NN"},
"furlongs":	{"NNS"},
"furlough":	{"NN","VB","VBP"},
"furloughed":	{"VBD","VBN"},
"furloughing":	{"VBG"},
"furloughs":	{"NNS","VBZ"},
"furls":	{"VBZ"},
"furnace":	{"NN"},
"furnaces":	{"NNS"},
"furnariidae":	{"NN"},
"furnarius":	{"NNS"},
"furnish":	{"VB","VBP"},
"furnished":	{"JJ","VBD","VBN"},
"furnishes":	{"VBZ"},
"furnishing":	{"NN","VBG"},
"furnishings":	{"NNS"},
"furniture":	{"NN"},
"furnivall":	{"NN"},
"furor":	{"NN"},
"furore":	{"NN"},
"furosemide":	{"NN"},
"furred":	{"JJ","VBD","VBN"},
"furrier":	{"NN","JJR"},
"furriers":	{"NNS"},
"furriest":	{"JJS"},
"furring":	{"VBG"},
"furrow":	{"NN","VB","VBP"},
"furrowed":	{"JJ","VBD","VBN"},
"furrowing":	{"VBG"},
"furrows":	{"NNS","VBZ"},
"furry":	{"JJ"},
"furs":	{"NNS","VBZ"},
"further":	{"RBR","JJR","VB","VBP"},
"furtherance":	{"NN"},
"furthered":	{"VBD","VBN"},
"furthering":	{"VBG"},
"furthermore":	{"RB"},
"furthermost":	{"JJ"},
"furthers":	{"VBZ"},
"furthest":	{"JJS","RBS"},
"furtive":	{"JJ"},
"furtively":	{"RB"},
"furtiveness":	{"NN"},
"furuncle":	{"NN"},
"furunculosis":	{"NN"},
"fury":	{"NN"},
"furze":	{"NN"},
"fusain":	{"NN"},
"fusanus":	{"NN"},
"fuschia":	{"NN"},
"fuscoboletinus":	{"NN"},
"fuscous":	{"JJ"},
"fuse":	{"NN","VB","VBP"},
"fused":	{"JJ","VBD","VBN"},
"fusee":	{"NN"},
"fuselage":	{"NN"},
"fuselages":	{"NNS"},
"fuses":	{"VBZ","NNS"},
"fusible":	{"JJ"},
"fusiform":	{"JJ"},
"fusil":	{"NN"},
"fusilier":	{"NN"},
"fusiliers":	{"NNS"},
"fusillade":	{"NN"},
"fusillades":	{"NNS"},
"fusing":	{"VBG"},
"fusion":	{"NN"},
"fusions":	{"NNS"},
"fuss":	{"NN","VB","VBP"},
"fuss-budget":	{"NN"},
"fussed":	{"VBD","VBN","JJ"},
"fusses":	{"VBZ","NNS"},
"fussier":	{"JJR"},
"fussiest":	{"JJS"},
"fussily":	{"RB"},
"fussiness":	{"NN"},
"fussing":	{"VBG"},
"fusspot":	{"NN"},
"fussy":	{"JJ"},
"fustian":	{"NN","JJ"},
"fustier":	{"JJR"},
"fustiest":	{"JJS"},
"fustigate":	{"VB","VBP"},
"fustigated":	{"VBD","VBN"},
"fustigates":	{"VBZ"},
"fustigating":	{"VBG"},
"fustigation":	{"NN"},
"fustigator":	{"NN"},
"fustigatory":	{"JJ"},
"fustiness":	{"NN"},
"fusty":	{"JJ"},
"futile":	{"JJ"},
"futilely":	{"RB"},
"futility":	{"NN"},
"futon":	{"NN"},
"futons":	{"NNS"},
"future":	{"NN","JJ"},
"future-day":	{"JJ"},
"future-time":	{"JJ"},
"futureless":	{"JJ"},
"futures":	{"NNS"},
"futures-exchange":	{"NN"},
"futures-investment":	{"JJ"},
"futures-market":	{"NN"},
"futures-related":	{"JJ"},
"futures-trading":	{"JJ"},
"futurism":	{"NN"},
"futurist":	{"NN"},
"futuristic":	{"JJ"},
"futuristics":	{"NN"},
"futurists":	{"NNS"},
"futurity":	{"NN"},
"futurology":	{"NN"},
"fuze":	{"NN","VB","VBP"},
"fuzed":	{"VBD","VBN"},
"fuzee":	{"NN"},
"fuzes":	{"VBZ","NNS"},
"fuzing":	{"VBG"},
"fuzz":	{"NN","VB","VBP"},
"fuzzed":	{"JJ","VBD","VBN"},
"fuzzes":	{"VBZ"},
"fuzzier":	{"JJR"},
"fuzziest":	{"JJS"},
"fuzziness":	{"NN"},
"fuzzing":	{"VBG"},
"fuzzy":	{"JJ"},
"fws":	{"NNS"},
"g":	{"NN","SYM","LS"},
"g-force":	{"NN"},
"g-forces":	{"NNS"},
"g-jo":	{"NN"},
"g-man":	{"NN"},
"g-p":	{"NN"},
"g-string":	{"NN"},
"g.i.":	{"VB"},
"gaap":	{"NN"},
"gab":	{"NN","VB","VBP"},
"gaba":	{"NN"},
"gabapentin":	{"NN"},
"gabardine":	{"NN"},
"gabardines":	{"NNS"},
"gabbed":	{"VBD","VBN"},
"gabbing":	{"VBG"},
"gabble":	{"VB","VBP","NN"},
"gabbled":	{"VBD","VBN"},
"gabbles":	{"VBZ"},
"gabbling":	{"VBG"},
"gabbro":	{"NN"},
"gabby":	{"JJ"},
"gaberdine":	{"NN"},
"gabfest":	{"NN"},
"gabfests":	{"NNS"},
"gable":	{"NN"},
"gable-like":	{"JJ"},
"gabled":	{"JJ"},
"gabor":	{"NN"},
"gaboriau":	{"NN"},
"gabs":	{"VBZ"},
"gabun":	{"NN"},
"gad":	{"VB","VBP"},
"gadaba":	{"NN"},
"gadabout":	{"NN"},
"gadabouts":	{"NNS"},
"gadded":	{"VBD","VBN"},
"gaddi":	{"NN"},
"gadding":	{"VBG"},
"gadflies":	{"NNS"},
"gadfly":	{"NN"},
"gadget":	{"NN"},
"gadgeteer":	{"NN"},
"gadgetry":	{"NN"},
"gadgets":	{"NNS"},
"gadidae":	{"NN"},
"gadiformes":	{"NNS"},
"gadoid":	{"NN"},
"gadolinite":	{"NN"},
"gadolinium":	{"NN"},
"gads":	{"VBZ"},
"gadsden":	{"NN"},
"gadus":	{"NNS"},
"gaea":	{"NN"},
"gaelic-speaking":	{"JJ"},
"gaff":	{"NN","VB","VBP"},
"gaffe":	{"NN"},
"gaffed":	{"VBD","VBN"},
"gaffer":	{"NN"},
"gaffers":	{"NNS"},
"gaffes":	{"NNS"},
"gaffing":	{"VBG"},
"gaffs":	{"NNS","VBZ"},
"gaffsail":	{"NN"},
"gafsa":	{"NN"},
"gag":	{"NN","VB","VBP"},
"gaga":	{"NN","JJ"},
"gagarin":	{"NN"},
"gage":	{"NN","VB","VBP"},
"gaged":	{"VBD","VBN"},
"gages":	{"NNS","VBZ"},
"gagged":	{"VBD","VBN"},
"gagging":	{"VBG"},
"gaggle":	{"NN"},
"gaggles":	{"NNS"},
"gaging":	{"VBG"},
"gagline":	{"NN"},
"gagman":	{"NN"},
"gags":	{"NNS","VBZ"},
"gagster":	{"NN"},
"gagwriter":	{"NN"},
"gagwriters":	{"NNS"},
"gai":	{"NN"},
"gaia":	{"NN"},
"gaiety":	{"NN"},
"gail":	{"NN"},
"gaillardia":	{"NN"},
"gaily":	{"RB"},
"gain":	{"NN","VBP","VB"},
"gained":	{"VBD","VBN"},
"gainer":	{"NN"},
"gainers":	{"NNS"},
"gainful":	{"JJ"},
"gainfully":	{"RB"},
"gainfulness":	{"NN"},
"gaining":	{"VBG"},
"gainlessly":	{"RB"},
"gainly":	{"RB","JJ"},
"gains":	{"NNS","VBZ"},
"gains-tax":	{"JJ","NN"},
"gains-tax-cut":	{"JJ"},
"gainsaid":	{"VBD","VBN"},
"gainsay":	{"VB","VBP"},
"gainsaying":	{"VBG"},
"gainsays":	{"VBZ"},
"gaiseric":	{"NN"},
"gait":	{"NN","VB","VBP"},
"gaited":	{"JJ","VBD","VBN"},
"gaiter":	{"NN"},
"gaiters":	{"NNS"},
"gaiting":	{"VBG"},
"gaits":	{"NNS","VBZ"},
"gal":	{"NN"},
"gala":	{"NN"},
"galactagogue":	{"NN","JJ"},
"galactic":	{"JJ"},
"galactocele":	{"NN"},
"galactose":	{"NN"},
"galactosemia":	{"NN"},
"galactosis":	{"NN"},
"galago":	{"NN"},
"galan":	{"NN"},
"galangal":	{"NN"},
"galantine":	{"NN"},
"galas":	{"NNS"},
"galatea":	{"NN"},
"galatia":	{"NN"},
"galatian":	{"NN"},
"galax":	{"NN"},
"galaxies":	{"NNS"},
"galaxy":	{"NN"},
"galbanum":	{"NN"},
"galbraith":	{"NN"},
"galbula":	{"FW"},
"galbulidae":	{"NN"},
"gale":	{"NN"},
"galea":	{"NN"},
"galega":	{"NN"},
"galen":	{"NN"},
"galena":	{"NN"},
"galeocerdo":	{"NN"},
"galeopsis":	{"NN"},
"galeorhinus":	{"NN"},
"galere":	{"NN"},
"gales":	{"NNS"},
"galicia":	{"NN"},
"galician":	{"NN"},
"galingale":	{"NN"},
"galium":	{"NN"},
"gall":	{"NN","VB","VBP"},
"gall-berry":	{"NN"},
"gall-bladder":	{"NN"},
"gallamine":	{"NN"},
"gallant":	{"JJ","NN","VB","VBP"},
"gallanted":	{"VBD","VBN"},
"gallanting":	{"VBG"},
"gallantly":	{"RB"},
"gallantry":	{"NN"},
"gallants":	{"NNS","VBZ"},
"gallaudet":	{"NN"},
"gallberry":	{"NN"},
"gallbladder":	{"NN"},
"galled":	{"VBD","VBN"},
"galleon":	{"NN"},
"galleons":	{"NNS"},
"galleria":	{"NN"},
"galleries":	{"NNS"},
"gallery":	{"NN"},
"gallet":	{"NN"},
"galley":	{"NN"},
"galleys":	{"NNS"},
"gallfly":	{"NN"},
"gallia":	{"NN"},
"galliano":	{"NN"},
"gallican":	{"JJ"},
"gallicanism":	{"NN"},
"gallicism":	{"NN"},
"galliformes":	{"NNS"},
"gallimaufry":	{"NN"},
"gallina":	{"NN"},
"gallinacean":	{"NN"},
"gallinaceous":	{"JJ"},
"gallinago":	{"NN"},
"galling":	{"JJ","VBG"},
"gallinula":	{"NN"},
"gallinule":	{"NN"},
"gallirallus":	{"NN"},
"gallium":	{"NN"},
"gallivant":	{"VB","VBP"},
"gallivanted":	{"VBD","VBN"},
"gallivanting":	{"VBG"},
"gallivants":	{"VBZ"},
"gallon":	{"NN"},
"gallonage":	{"NN"},
"gallons":	{"NNS"},
"gallop":	{"NN","VB","VBP"},
"galloped":	{"VBD","VBN"},
"galloping":	{"JJ","VBG"},
"gallops":	{"VBZ"},
"gallous":	{"NNS"},
"galloway":	{"NN"},
"gallows":	{"NN","NNS"},
"gallows-tree":	{"NN"},
"galls":	{"NNS","VBZ"},
"gallstone":	{"NN"},
"gallstones":	{"NNS"},
"gallup":	{"NN"},
"gallus":	{"NN"},
"gallus-snapping":	{"JJ"},
"galois":	{"NN"},
"galoot":	{"NN"},
"galore":	{"RB","JJ"},
"galosh":	{"NN"},
"gals":	{"NNS"},
"galton":	{"NN"},
"galumph":	{"VB","VBP"},
"galumphed":	{"VBD","VBN"},
"galumphing":	{"VBG"},
"galumphs":	{"VBZ"},
"galvani":	{"NN"},
"galvanic":	{"JJ"},
"galvanisation":	{"NN"},
"galvanise":	{"VB","VBP"},
"galvanised":	{"VBD","VBN","JJ"},
"galvaniser":	{"NN"},
"galvanises":	{"VBZ"},
"galvanising":	{"VBG"},
"galvanism":	{"NN"},
"galvanization":	{"NN"},
"galvanize":	{"VB","VBP"},
"galvanized":	{"JJ","VBD","VBN"},
"galvanizer":	{"NN"},
"galvanizes":	{"VBZ"},
"galvanizing":	{"VBG"},
"galvanometer":	{"NN"},
"galwegian":	{"JJ"},
"gam":	{"NN"},
"gamba":	{"NN"},
"gambelia":	{"NN"},
"gambist":	{"NN"},
"gambit":	{"NN"},
"gambits":	{"NNS"},
"gamble":	{"VB","VBP","NN"},
"gambled":	{"VBD","VBN"},
"gambler":	{"NN"},
"gambler-politician":	{"NN"},
"gamblers":	{"NNS"},
"gambles":	{"NNS","VBZ"},
"gambling":	{"NN","VBG"},
"gamboge":	{"NN"},
"gambol":	{"VB","VBP","NN"},
"gamboled":	{"VBD","VBN"},
"gamboling":	{"VBG"},
"gambolled":	{"VBD","VBN"},
"gambolling":	{"VBG"},
"gambols":	{"VBZ"},
"gambrel":	{"NN"},
"gambusia":	{"NN"},
"game":	{"NN","JJ","VBP","VB"},
"game-boy":	{"NN"},
"game-high":	{"JJ","NN"},
"game-management":	{"NN"},
"game-show":	{"NN"},
"game-shows":	{"NNS"},
"game-winner":	{"NN"},
"game-winning":	{"JJ"},
"gamebag":	{"NN"},
"gamebird":	{"NN"},
"gameboard":	{"NN"},
"gamecock":	{"NN"},
"gamed":	{"VBD","VBN"},
"gamekeeper":	{"NN"},
"gamekeepers":	{"NNS"},
"gamelan":	{"NN"},
"gamely":	{"RB"},
"gameness":	{"NN"},
"gamer":	{"NN"},
"gamers":	{"NNS"},
"games":	{"NNS","VBZ"},
"games-master":	{"NN"},
"games-mistress":	{"NN"},
"gamesmanship":	{"NN"},
"gamesmen":	{"NNS"},
"gametangium":	{"NN"},
"gamete":	{"NN"},
"gametes":	{"NNS"},
"gametic":	{"JJ"},
"gametocide":	{"NN"},
"gametocyte":	{"NN"},
"gametoecium":	{"NN"},
"gametogenesis":	{"NN"},
"gametophore":	{"NN"},
"gametophyte":	{"NN"},
"gamey":	{"JJ"},
"gamin":	{"NN"},
"gamine":	{"NN","JJ"},
"gaminess":	{"NN"},
"gaming":	{"NN","VBG"},
"gaming-card":	{"NN"},
"gaming-industry":	{"NN"},
"gamma":	{"NN"},
"gamma-interferon":	{"NN"},
"gammas":	{"NNS"},
"gammon":	{"NN"},
"gammopathy":	{"NN"},
"gammy":	{"JJ"},
"gamopetalous":	{"JJ"},
"gamow":	{"NN"},
"gamp":	{"NN"},
"gamut":	{"NN"},
"gamy":	{"JJ"},
"ganapati":	{"NN"},
"gand":	{"NN"},
"gander":	{"NN"},
"ganders":	{"NNS"},
"gandhian":	{"JJ"},
"ganef":	{"NN"},
"ganesa":	{"NN"},
"ganesh":	{"NN"},
"ganesha":	{"NN"},
"gang":	{"NN","VB","VBP"},
"gang-rape":	{"VB","VBP","NN"},
"gang-raped":	{"VBD","VBN"},
"gang-rapes":	{"VBZ","NNS"},
"gang-raping":	{"VBG"},
"gangbang":	{"NN","VB","VBP"},
"gangbanged":	{"VBD","VBN"},
"gangbanging":	{"VBG"},
"gangbangs":	{"NNS","VBZ"},
"gangboard":	{"NN"},
"gangbusters":	{"NNS"},
"gangdom":	{"NN"},
"ganged":	{"VBD","VBN"},
"ganger":	{"NN"},
"ganging":	{"VBG"},
"gangland":	{"JJ","NN"},
"ganglia":	{"NNS"},
"gangling":	{"JJ"},
"gangliocyte":	{"NN"},
"ganglion":	{"NN"},
"ganglions":	{"NNS"},
"gangly":	{"JJ"},
"gangplank":	{"NN"},
"gangplanks":	{"NNS"},
"gangrene":	{"NN","VB","VBP"},
"gangrened":	{"VBD","VBN"},
"gangrenes":	{"VBZ"},
"gangrening":	{"VBG"},
"gangrenous":	{"JJ"},
"gangs":	{"NNS","VBZ"},
"gangsaw":	{"NN"},
"gangsta":	{"NN"},
"gangstalking":	{"NN"},
"gangstas":	{"NNS"},
"gangster":	{"NN"},
"gangsterish":	{"JJ"},
"gangsters":	{"NNS"},
"gangway":	{"NN","UH"},
"gangways":	{"NNS"},
"ganja":	{"NN"},
"gannet":	{"NN"},
"gannets":	{"NNS"},
"ganof":	{"NN"},
"ganoid":	{"NN"},
"ganoidei":	{"NN"},
"ganoin":	{"NN"},
"ganoine":	{"NN"},
"gansu":	{"NN"},
"gantanol":	{"NN"},
"gantlet":	{"NN"},
"gantries":	{"NNS"},
"gantrisin":	{"NN"},
"gantry":	{"NN"},
"gaol":	{"NN","VB","VBP"},
"gaolbird":	{"NN"},
"gaolbirds":	{"NNS"},
"gaolbreak":	{"NN"},
"gaolbreaks":	{"NNS"},
"gaoled":	{"VBD","VBN"},
"gaoler":	{"NN"},
"gaolers":	{"NNS"},
"gaoling":	{"VBG"},
"gaols":	{"NNS","VBZ"},
"gap":	{"NN","VB","VBP"},
"gap-toothed":	{"JJ"},
"gape":	{"VB","VBP","NN"},
"gaped":	{"VBD","VBN"},
"gapes":	{"VBZ","NNS"},
"gaping":	{"JJ","VBG"},
"gapped":	{"VBD","VBN"},
"gapping":	{"VBG"},
"gaps":	{"NNS","VBZ"},
"gapt":	{"NN"},
"gar":	{"NN"},
"garage":	{"NN","VB","VBP"},
"garaged":	{"VBD","VBN"},
"garages":	{"NNS","VBZ"},
"garaging":	{"VBG"},
"garambulla":	{"NN"},
"garamycin":	{"NN"},
"garand":	{"NN"},
"garb":	{"NN","VB","VBP"},
"garbage":	{"NN"},
"garbage-disposal":	{"NN"},
"garbage-in":	{"JJ"},
"garbage-incinerator":	{"NN"},
"garbage-out":	{"JJ"},
"garbage-to-energy":	{"JJ"},
"garbageman":	{"NN"},
"garbanzo":	{"NN"},
"garbanzos":	{"NNS"},
"garbed":	{"VBD","VBN","JJ"},
"garbing":	{"VBG"},
"garble":	{"VB","VBP","NN"},
"garbled":	{"JJ","VBD","VBN"},
"garbles":	{"VBZ"},
"garbling":	{"VBG"},
"garbo":	{"NN"},
"garboard":	{"NN"},
"garboil":	{"NN"},
"garbology":	{"NN"},
"garbs":	{"VBZ"},
"garcinia":	{"NN"},
"gardant":	{"JJ"},
"garde":	{"NN"},
"garden":	{"NN","VB","VBP"},
"garden-shrub":	{"NN"},
"garden-variety":	{"JJ"},
"gardened":	{"VBD","VBN"},
"gardener":	{"NN"},
"gardeners":	{"NNS"},
"gardenettes":	{"NNS"},
"gardenia":	{"NN"},
"gardenias":	{"NNS"},
"gardening":	{"NN","VBG"},
"gardens":	{"NNS","VBZ"},
"gardiner":	{"NN"},
"gardner":	{"NN"},
"garfish":	{"NN"},
"garganey":	{"NN"},
"gargantua":	{"NN"},
"gargantuan":	{"JJ"},
"garget":	{"NN"},
"gargle":	{"VB","VBP","NN"},
"gargled":	{"VBD","VBN"},
"gargles":	{"VBZ","NNS"},
"gargling":	{"VBG"},
"gargoyle":	{"NN"},
"gargoyles":	{"NNS"},
"gargoylism":	{"NN"},
"gari":	{"NN"},
"garish":	{"JJ"},
"garishly":	{"RB"},
"garishness":	{"NN"},
"garland":	{"NN","VBP","VB"},
"garlanded":	{"VBD","VBN"},
"garlanding":	{"VBG"},
"garlands":	{"NNS","VBZ"},
"garlic":	{"NN"},
"garlicked":	{"JJ"},
"garlicky":	{"JJ"},
"garment":	{"NN","VB","VBP"},
"garment-industry":	{"NN"},
"garment-worker":	{"NN"},
"garmented":	{"VBD","VBN"},
"garmenting":	{"VBG"},
"garmentless":	{"JJ"},
"garmentmaker":	{"NN"},
"garments":	{"NNS","VBZ"},
"garner":	{"VB","VBP"},
"garnered":	{"VBD","VBN"},
"garnering":	{"VBG"},
"garners":	{"VBZ"},
"garnet":	{"NN"},
"garnet-colored":	{"JJ"},
"garnet-coloured":	{"JJ"},
"garnets":	{"NNS"},
"garnier":	{"NN"},
"garnierite":	{"NN"},
"garnish":	{"NN","VB","VBP"},
"garnished":	{"VBD","VBN"},
"garnishee":	{"NN","VB","VBP"},
"garnisheed":	{"VBD","VBN"},
"garnisheeing":	{"VBG"},
"garnishees":	{"VBZ"},
"garnishes":	{"NNS","VBZ"},
"garnishing":	{"VBG"},
"garnishment":	{"NN"},
"garonne":	{"NN"},
"garotte":	{"NN","VB","VBP"},
"garotted":	{"VBD","VBN"},
"garottes":	{"NNS","VBZ"},
"garotting":	{"VBG"},
"garoupa":	{"NN"},
"garpian":	{"JJ"},
"garpike":	{"NN"},
"garret":	{"NN"},
"garrets":	{"NNS"},
"garrick":	{"NN"},
"garrison":	{"NN","VB","VBP"},
"garrisoned":	{"VBD","VBN"},
"garrisonian":	{"NN"},
"garrisoning":	{"VBG"},
"garrisons":	{"NNS","VBZ"},
"garrote":	{"NN","VB","VBP"},
"garroted":	{"VBD","VBN"},
"garroter":	{"NN"},
"garrotes":	{"NNS","VBZ"},
"garroting":	{"VBG"},
"garrotte":	{"VB","VBP","NN"},
"garrotted":	{"VBD","VBN"},
"garrotter":	{"NN"},
"garrottes":	{"VBZ","NNS"},
"garrotting":	{"VBG"},
"garrulinae":	{"NN"},
"garrulity":	{"NN"},
"garrulous":	{"JJ"},
"garrulously":	{"RB"},
"garrulousness":	{"NN"},
"garter":	{"NN","VB","VBP"},
"gartered":	{"VBD","VBN"},
"gartering":	{"VBG"},
"garters":	{"VBZ"},
"gartner":	{"NN"},
"garuda":	{"NN"},
"gary":	{"NN"},
"gas":	{"NN","VB","VBP"},
"gas-company":	{"NN"},
"gas-cooled":	{"JJ"},
"gas-derived":	{"JJ"},
"gas-filled":	{"JJ"},
"gas-fired":	{"JJ"},
"gas-gathering":	{"JJ"},
"gas-glass":	{"NN"},
"gas-guzzler":	{"NN"},
"gas-guzzlers":	{"NNS"},
"gas-guzzling":	{"JJ"},
"gas-one-tenth":	{"NN"},
"gas-pipeline":	{"JJ"},
"gas-producing":	{"JJ","NN"},
"gas-reactor":	{"JJ"},
"gas-saving":	{"JJ"},
"gas-station":	{"NN"},
"gas-stations":	{"NNS"},
"gas-tax":	{"NN"},
"gas-tax-increasing":	{"JJ"},
"gas-tight":	{"JJ"},
"gas-turbine":	{"JJ"},
"gasbag":	{"NN"},
"gasbags":	{"NNS"},
"gascogne":	{"NN"},
"gasconade":	{"NN","VB","VBP"},
"gasconaded":	{"VBD","VBN"},
"gasconader":	{"NN"},
"gasconades":	{"NNS","VBZ"},
"gasconading":	{"VBG"},
"gascony":	{"NN"},
"gaseous":	{"JJ"},
"gaseousness":	{"NN"},
"gases":	{"NNS","VBZ"},
"gasfield":	{"NN"},
"gash":	{"NN","VB","VBP"},
"gashed":	{"VBD","VBN"},
"gasherbrum":	{"NN"},
"gashes":	{"NNS","VBZ"},
"gashing":	{"VBG"},
"gasification":	{"NN"},
"gasified":	{"VBD","VBN"},
"gasifies":	{"VBZ"},
"gasify":	{"VB","VBP"},
"gasifying":	{"VBG"},
"gaskell":	{"NN"},
"gasket":	{"NN"},
"gaskets":	{"NNS"},
"gaskin":	{"NN"},
"gaslight":	{"NN"},
"gaslights":	{"NNS"},
"gasman":	{"NN"},
"gasmask":	{"NN"},
"gasmen":	{"NNS"},
"gasohol":	{"NN"},
"gasolene":	{"NN"},
"gasoline":	{"NN"},
"gasoline-powered":	{"JJ"},
"gasometer":	{"NN"},
"gasometers":	{"NNS"},
"gasp":	{"VB","VBP","NN"},
"gaspar":	{"NN"},
"gasped":	{"VBD","VBN"},
"gasping":	{"VBG","JJ"},
"gaspingly":	{"RB"},
"gasps":	{"NNS","VBZ"},
"gassed":	{"VBN","VBD","JJ"},
"gasser":	{"NN"},
"gasses":	{"NNS","VBZ"},
"gassier":	{"JJR"},
"gassiest":	{"JJS"},
"gassiness":	{"NN"},
"gassing":	{"NN","VBG"},
"gassings":	{"NNS"},
"gassy":	{"JJ"},
"gasteromycete":	{"NN"},
"gasteromycetes":	{"NNS"},
"gasterophilidae":	{"NN"},
"gasterophilus":	{"NNS"},
"gasteropoda":	{"NN"},
"gasterosteidae":	{"NN"},
"gasterosteus":	{"NNS"},
"gaston":	{"NN"},
"gastralgia":	{"NN"},
"gastrectomy":	{"NN"},
"gastric":	{"JJ"},
"gastrin":	{"NN"},
"gastritis":	{"NN"},
"gastro-intestinal":	{"JJ"},
"gastroboletus":	{"NNS"},
"gastrocnemius":	{"NN"},
"gastrocybe":	{"NN"},
"gastroduodenal":	{"JJ"},
"gastroenteritis":	{"NN"},
"gastroenterologist":	{"NN"},
"gastroenterology":	{"NN"},
"gastroenterostomy":	{"NN"},
"gastroesophageal":	{"JJ"},
"gastrogavage":	{"NN"},
"gastrointestinal":	{"JJ"},
"gastrolobium":	{"NN"},
"gastromy":	{"NN"},
"gastromycete":	{"NN"},
"gastromycetes":	{"NNS"},
"gastronome":	{"NN"},
"gastronomes":	{"NNS"},
"gastronomic":	{"JJ"},
"gastronomical":	{"JJ"},
"gastronomically":	{"RB"},
"gastronomy":	{"NN"},
"gastrophryne":	{"NN"},
"gastropod":	{"NN"},
"gastropoda":	{"NN"},
"gastroscope":	{"NN"},
"gastroscopy":	{"NN"},
"gastrostomy":	{"NN"},
"gastrula":	{"NN"},
"gastrulation":	{"NN"},
"gasworks":	{"NN","NNS"},
"gat":	{"NN"},
"gate":	{"NN","VBP","VB"},
"gate-crash":	{"VB","VBP"},
"gate-crashed":	{"VBD","VBN"},
"gate-crashes":	{"VBZ"},
"gate-crashing":	{"VBG"},
"gate-post":	{"NN"},
"gateau":	{"NN"},
"gateaux":	{"NNS"},
"gatecrash":	{"VB","VBP"},
"gatecrashed":	{"VBD","VBN"},
"gatecrasher":	{"NN"},
"gatecrashers":	{"NNS"},
"gatecrashes":	{"VBZ"},
"gatecrashing":	{"VBG"},
"gated":	{"VBD","VBN"},
"gatefold":	{"NN"},
"gatehouse":	{"NN"},
"gatehouses":	{"NNS"},
"gatekeeper":	{"NN"},
"gatekeepers":	{"NNS"},
"gatepost":	{"NN"},
"gateposts":	{"NNS"},
"gates":	{"NNS","VBZ"},
"gateway":	{"NN"},
"gateways":	{"NNS"},
"gather":	{"VB","NN","VBP"},
"gathered":	{"VBD","VBN"},
"gatherer":	{"NN"},
"gatherers":	{"NNS"},
"gathering":	{"NN","JJ","VBG"},
"gatherings":	{"NNS"},
"gathers":	{"VBZ","NNS"},
"gathic":	{"NN"},
"gating":	{"VBG"},
"gatling":	{"NN"},
"gato":	{"NN"},
"gator":	{"NN"},
"gators":	{"NNS"},
"gatsby-in-reverse":	{"NN"},
"gatt":	{"NN"},
"gauche":	{"JJ"},
"gaucheness":	{"NN"},
"gaucherie":	{"NN"},
"gaucheries":	{"NNS"},
"gaucho":	{"NN"},
"gauchos":	{"NNS"},
"gaud":	{"NN"},
"gaudery":	{"NN"},
"gaudier":	{"JJR"},
"gaudiest":	{"JJS"},
"gaudily":	{"RB"},
"gaudiness":	{"NN"},
"gaudy":	{"JJ"},
"gauffer":	{"NN","VB","VBP"},
"gauge":	{"NN","VB","VBP"},
"gauged":	{"VBN","VBD"},
"gauges":	{"NNS","VBZ"},
"gauging":	{"VBG"},
"gauguinesque":	{"JJ"},
"gaultheria":	{"NN"},
"gaumless":	{"JJ"},
"gaunt":	{"JJ"},
"gauntlet":	{"NN"},
"gauntleted":	{"JJ"},
"gauntness":	{"NN"},
"gauntry":	{"NN"},
"gaur":	{"NN"},
"gauri":	{"NN"},
"gauss":	{"NN"},
"gaussian":	{"JJ"},
"gaussmeter":	{"NN"},
"gautama":	{"NN"},
"gauze":	{"NN"},
"gauze-like":	{"JJ"},
"gauzy":	{"JJ"},
"gavage":	{"NN"},
"gave":	{"VBD"},
"gavel":	{"NN","VB","VBP"},
"gaveled":	{"VBD","VBN"},
"gaveling":	{"VBG"},
"gavelled":	{"VBD","VBN"},
"gavelling":	{"VBG"},
"gavels":	{"NNS","VBZ"},
"gavia":	{"NN"},
"gavial":	{"NN"},
"gavialidae":	{"NN"},
"gavialis":	{"NNS"},
"gavidae":	{"NN"},
"gaviiformes":	{"NNS"},
"gavotte":	{"NN"},
"gavottes":	{"NNS"},
"gawain":	{"NN"},
"gawk":	{"VB","VBP"},
"gawked":	{"VBD","VBN"},
"gawker":	{"NN"},
"gawkier":	{"JJR"},
"gawkiest":	{"JJS"},
"gawkily":	{"RB"},
"gawkiness":	{"NN"},
"gawking":	{"VBG"},
"gawks":	{"VBZ"},
"gawky":	{"JJ"},
"gawp":	{"VB","VBP"},
"gawped":	{"VBD","VBN"},
"gawping":	{"VBG"},
"gawps":	{"VBZ"},
"gay":	{"JJ","NN"},
"gay-bashing":	{"JJ"},
"gay-ess":	{"VBP","VB"},
"gay-feather":	{"NN"},
"gay-lussac":	{"NN"},
"gay-rights":	{"NNS"},
"gay-student":	{"JJ"},
"gayal":	{"NN"},
"gayety":	{"NN"},
"gayfeather":	{"NN"},
"gaylussacia":	{"NN"},
"gayly":	{"RB"},
"gayness":	{"NN"},
"gaynor":	{"NN"},
"gays":	{"NNS"},
"gaywings":	{"NNS"},
"gaza":	{"NN"},
"gazania":	{"NN"},
"gaze":	{"VB","NN","VBP"},
"gazebo":	{"NN"},
"gazebos":	{"NNS"},
"gazed":	{"VBD","VBN"},
"gazella":	{"NN"},
"gazelle":	{"NN","NNS"},
"gazelles":	{"NNS"},
"gazer":	{"NN"},
"gazes":	{"VBZ","NNS"},
"gazette":	{"NN","VB","VBP"},
"gazetted":	{"VBD","VBN"},
"gazetteer":	{"NN"},
"gazetteers":	{"NNS"},
"gazettes":	{"NNS","VBZ"},
"gazetting":	{"VBG"},
"gazillion":	{"NN"},
"gazillions":	{"NNS"},
"gazing":	{"VBG"},
"gazpacho":	{"NN"},
"gazump":	{"VB","VBP"},
"gazumped":	{"VBD","VBN"},
"gazumper":	{"NN"},
"gazumping":	{"VBG","NN"},
"gazumps":	{"VBZ"},
"gb":	{"NN"},
"gbit":	{"NN"},
"gbu-28":	{"NN"},
"gc":	{"NN"},
"gca":	{"NN"},
"gcse":	{"NN"},
"gd":	{"NN"},
"gdp":	{"NN"},
"ge":	{"NN"},
"gean":	{"NN"},
"gear":	{"NN","VBP","VB"},
"gear-box":	{"NN"},
"gear-change":	{"NN"},
"gear-lever":	{"NN"},
"gear-levers":	{"NNS"},
"gear-sets":	{"NNS"},
"gear-stick":	{"NN"},
"gear-sticks":	{"NNS"},
"gearbox":	{"NN"},
"gearboxes":	{"NNS"},
"geared":	{"VBD","VBN"},
"gearing":	{"NN","VBG"},
"gears":	{"NNS","VBZ"},
"gearset":	{"NN"},
"gearshift":	{"NN"},
"gearshifts":	{"NNS"},
"gearstick":	{"NN"},
"gearsticks":	{"NNS"},
"geartrain":	{"NN"},
"gearwheel":	{"NN"},
"geary":	{"NN"},
"geastraceae":	{"NN"},
"geastrum":	{"NN"},
"geatish":	{"JJ"},
"geb":	{"NN"},
"gecekondu":	{"NN","FW"},
"gecekondular":	{"NNS"},
"gecko":	{"NN"},
"geckoes":	{"NNS"},
"geckos":	{"NNS"},
"gee":	{"UH","VB","VBP"},
"gee-gee":	{"NN"},
"gee-gees":	{"NNS"},
"geebung":	{"NN"},
"geed":	{"VBD","VBN"},
"geeing":	{"VBG"},
"geek":	{"NN","VB","VBP"},
"geeked":	{"VBD","VBN"},
"geeking":	{"VBG"},
"geeks":	{"NNS","VBZ"},
"geeky":	{"JJ"},
"gees":	{"VBZ"},
"geese":	{"NNS"},
"geezer":	{"NN"},
"geezerhood":	{"NN"},
"geezers":	{"NNS"},
"geffen":	{"NN"},
"gegenschein":	{"NN"},
"geglossaceae":	{"NN"},
"gehenna":	{"NN"},
"geilivable":	{"FW"},
"geisel":	{"NN"},
"geisha":	{"NN"},
"geishas":	{"NNS"},
"gekkonidae":	{"NN"},
"gel":	{"NN","VB","VBP"},
"gelatin":	{"NN"},
"gelatin-like":	{"JJ"},
"gelatine":	{"NN"},
"gelatinisation":	{"NN"},
"gelatinise":	{"VB","VBP"},
"gelatinised":	{"VBD","VBN"},
"gelatiniser":	{"NN"},
"gelatinises":	{"VBZ"},
"gelatinising":	{"VBG"},
"gelatinization":	{"NN"},
"gelatinize":	{"VB","VBP"},
"gelatinized":	{"VBD","VBN"},
"gelatinizer":	{"NN"},
"gelatinizes":	{"VBZ"},
"gelatinizing":	{"VBG"},
"gelatinlike":	{"JJ"},
"gelatinous":	{"JJ"},
"gelatinousness":	{"NN"},
"geld":	{"VB","VBP"},
"gelded":	{"VBD","VBN"},
"gelding":	{"NN","VBG"},
"geldings":	{"NNS"},
"gelds":	{"VBZ"},
"gelechia":	{"NN"},
"gelechiid":	{"NN"},
"gelechiidae":	{"NN"},
"gelid":	{"JJ"},
"gelidity":	{"NN"},
"gelignite":	{"NN"},
"gell-mann":	{"NN"},
"gelled":	{"VBD","VBN"},
"gelling":	{"VBG"},
"gelly":	{"NN"},
"gels":	{"VBZ","NNS"},
"gelsemium":	{"NN"},
"gelt":	{"NN"},
"gem":	{"NN","VB","VBP"},
"gemara":	{"NN"},
"gemfibrozil":	{"NN"},
"geminate":	{"JJ","VB","VBP"},
"geminated":	{"VBD","VBN"},
"geminately":	{"RB"},
"geminates":	{"VBZ"},
"geminating":	{"VBG"},
"gemination":	{"NN"},
"gemlike":	{"JJ"},
"gemma":	{"NN"},
"gemmation":	{"NN"},
"gemmed":	{"VBD","VBN"},
"gemmiferous":	{"JJ"},
"gemming":	{"VBG"},
"gemmule":	{"NN"},
"gemonil":	{"NN"},
"gempylid":	{"NN"},
"gempylidae":	{"NN"},
"gempylus":	{"NNS"},
"gems":	{"NNS","VBZ"},
"gemsbok":	{"NN","NNS"},
"gemsboks":	{"NNS"},
"gemsbuck":	{"NN"},
"gemstone":	{"NN"},
"gemstones":	{"NNS"},
"gen":	{"NN","VB","VBP"},
"gendarme":	{"NN"},
"gendarmerie":	{"NN"},
"gendarmery":	{"NN"},
"gendarmes":	{"NNS"},
"gender":	{"NN","VB","VBP"},
"gendered":	{"VBD","VBN"},
"gendering":	{"VBG"},
"genders":	{"NNS","VBZ"},
"gene":	{"NN"},
"gene-copying":	{"JJ"},
"gene-replication":	{"NN"},
"gene-spliced":	{"JJ"},
"gene-splicing":	{"NN"},
"gene-therapy":	{"NN"},
"genealogic":	{"JJ"},
"genealogical":	{"JJ"},
"genealogically":	{"RB"},
"genealogies":	{"NNS"},
"genealogist":	{"NN"},
"genealogists":	{"NNS"},
"genealogy":	{"NN"},
"genera":	{"NNS"},
"general":	{"JJ","NN"},
"general-appeal":	{"JJ"},
"general-director":	{"NN"},
"general-election":	{"NN"},
"general-insurance":	{"NN"},
"general-interest":	{"JJ"},
"general-management":	{"NN"},
"general-merchandise":	{"NN"},
"general-practice":	{"NN"},
"general-practitioner":	{"NN"},
"general-purpose":	{"JJ"},
"general-staff":	{"NN"},
"generalcy":	{"NN"},
"generalisation":	{"NN"},
"generalisations":	{"NNS"},
"generalise":	{"VB","VBP"},
"generalised":	{"JJ","VBD","VBN"},
"generalises":	{"VBZ"},
"generalising":	{"VBG"},
"generalissimo":	{"NN"},
"generalist":	{"NN","JJ"},
"generalistic":	{"JJ"},
"generalists":	{"NNS"},
"generalities":	{"NNS"},
"generality":	{"NN"},
"generalization":	{"NN"},
"generalizations":	{"NNS"},
"generalize":	{"VB","VBP"},
"generalized":	{"JJ","VBD","VBN"},
"generalizes":	{"VBZ"},
"generalizing":	{"VBG"},
"generally":	{"RB"},
"generalpurpose":	{"JJ"},
"generals":	{"NNS"},
"generalship":	{"NN"},
"generate":	{"VB","VBP"},
"generated":	{"VBN","VBD"},
"generates":	{"VBZ"},
"generating":	{"VBG"},
"generation":	{"NN"},
"generation-skipping":	{"JJ"},
"generational":	{"JJ"},
"generations":	{"NNS"},
"generative":	{"JJ"},
"generator":	{"NN"},
"generators":	{"NNS"},
"generic":	{"JJ"},
"generic-drug":	{"NN","JJ"},
"generic-industry":	{"JJ"},
"generically":	{"RB"},
"generics":	{"NNS"},
"generics-maker":	{"NN"},
"generosity":	{"NN"},
"generous":	{"JJ"},
"generously":	{"RB"},
"generousness":	{"NN"},
"genes":	{"NNS"},
"geneses":	{"NNS"},
"genesis":	{"NN"},
"genet":	{"NN"},
"genetic":	{"JJ"},
"genetic-engineering":	{"JJ"},
"genetical":	{"JJ"},
"genetically":	{"RB"},
"geneticism":	{"NN"},
"geneticist":	{"NN"},
"geneticists":	{"NNS"},
"genetics":	{"NN"},
"genetta":	{"NN"},
"geneva-based":	{"JJ"},
"genevan":	{"NN"},
"geneve":	{"NN"},
"genf":	{"NN"},
"genial":	{"JJ"},
"geniality":	{"NN"},
"genially":	{"RB"},
"genic":	{"JJ"},
"geniculate":	{"JJ"},
"genie":	{"NN"},
"genies":	{"NNS"},
"genii":	{"NNS"},
"genip":	{"NN"},
"genipa":	{"NN"},
"genipap":	{"NN"},
"genista":	{"NN"},
"genital":	{"JJ","NN"},
"genitalia":	{"NNS"},
"genitals":	{"NNS"},
"genitive":	{"JJ","NN"},
"genitor":	{"NN"},
"genitourinary":	{"JJ"},
"genius":	{"NN"},
"geniuses":	{"NNS"},
"genlisea":	{"NN"},
"genocide":	{"NN"},
"genoese":	{"JJ","NN"},
"genoise":	{"NN"},
"genome":	{"NN"},
"genomes":	{"NNS"},
"genomics":	{"NN"},
"genotype":	{"NN"},
"genotypes":	{"NNS"},
"genotypic":	{"JJ"},
"genotypical":	{"JJ"},
"genova":	{"NN"},
"genovese":	{"JJ"},
"genprobe":	{"NN"},
"genre":	{"NN"},
"genre-painting":	{"NN"},
"genres":	{"NNS"},
"gens":	{"NNS","VBZ"},
"genseric":	{"NN"},
"gent":	{"NN"},
"gentamicin":	{"NN"},
"genteel":	{"JJ"},
"genteelly":	{"RB"},
"genteelness":	{"NN"},
"gentian":	{"NN"},
"gentiana":	{"NN"},
"gentianaceae":	{"NN"},
"gentianales":	{"NNS"},
"gentianella":	{"NN"},
"gentianopsis":	{"NN"},
"gentians":	{"NNS"},
"gentile":	{"JJ","NN"},
"gentility":	{"NN"},
"gentle":	{"JJ","VB","VBP"},
"gentled":	{"VBD","VBN"},
"gentlefolk":	{"NNS"},
"gentleladies":	{"NNS"},
"gentlelady":	{"NN"},
"gentleman":	{"NN"},
"gentleman's-cane":	{"NN"},
"gentleman-at-arms":	{"NNS"},
"gentlemanlike":	{"JJ"},
"gentlemanly":	{"JJ"},
"gentlemen":	{"NNS"},
"gentleness":	{"NN"},
"gentler":	{"JJR"},
"gentler-sloping":	{"JJ"},
"gentles":	{"VBZ"},
"gentlest":	{"JJS"},
"gentlewoman":	{"NN"},
"gentlewomen":	{"NNS"},
"gentling":	{"VBG"},
"gently":	{"RB"},
"gentrification":	{"NN"},
"gentrified":	{"VBD","VBN"},
"gentrifies":	{"VBZ"},
"gentrify":	{"VB","VBP"},
"gentrifying":	{"VBG"},
"gentry":	{"NNS"},
"gents":	{"NNS"},
"genu":	{"NN"},
"genuflect":	{"VB","VBP"},
"genuflected":	{"VBD","VBN"},
"genuflecting":	{"VBG"},
"genuflection":	{"NN"},
"genuflects":	{"VBZ"},
"genuflexion":	{"NN"},
"genuine":	{"JJ"},
"genuinely":	{"RB"},
"genuineness":	{"NN"},
"genus":	{"NN"},
"genus-fenusa":	{"NN"},
"genus-megapodius":	{"NNS"},
"genus-milvus":	{"NNS"},
"genyonemus":	{"NNS"},
"geo-political":	{"JJ"},
"geocentric":	{"JJ"},
"geocentricism":	{"NN"},
"geochelone":	{"NN"},
"geochemistry":	{"NN"},
"geococcyx":	{"NN"},
"geode":	{"NN"},
"geodesic":	{"JJ"},
"geodesical":	{"JJ"},
"geodesy":	{"NN"},
"geodetic":	{"JJ"},
"geoduck":	{"NN"},
"geoengineering":	{"NN"},
"geofence":	{"NN"},
"geofences":	{"NNS"},
"geofencing":	{"NN"},
"geoff":	{"NN"},
"geoffrey":	{"NN"},
"geoffroea":	{"NN"},
"geoglossaceae":	{"NN"},
"geoglossum":	{"NN"},
"geographer":	{"NN"},
"geographers":	{"NNS"},
"geographic":	{"JJ"},
"geographical":	{"JJ"},
"geographically":	{"RB"},
"geographics":	{"NN"},
"geography":	{"NN"},
"geolite":	{"NN"},
"geolocated":	{"JJ"},
"geolocation":	{"NN"},
"geologic":	{"JJ"},
"geological":	{"JJ"},
"geologically":	{"RB"},
"geologist":	{"NN"},
"geologists":	{"NNS"},
"geology":	{"NN"},
"geomancer":	{"NN"},
"geomancy":	{"NN"},
"geomechanical":	{"NN"},
"geometer":	{"NN"},
"geometric":	{"JJ"},
"geometrical":	{"JJ"},
"geometrically":	{"RB"},
"geometrician":	{"NN"},
"geometrid":	{"NN"},
"geometridae":	{"NN"},
"geometry":	{"NN"},
"geomorphologic":	{"JJ"},
"geomorphological":	{"JJ"},
"geomorphology":	{"NN"},
"geomyidae":	{"NN"},
"geophagia":	{"NN"},
"geophagy":	{"NN"},
"geophilidae":	{"NN"},
"geophilomorpha":	{"NN"},
"geophilus":	{"NNS"},
"geophysical":	{"JJ"},
"geophysicist":	{"NN"},
"geophysicists":	{"NNS"},
"geophysics":	{"NN"},
"geophyte":	{"NN"},
"geophytic":	{"JJ"},
"geopolitical":	{"JJ"},
"geopolitics":	{"NN"},
"georgette":	{"NN"},
"georgia-based":	{"JJ"},
"geos":	{"NNS"},
"geosciences":	{"NNS"},
"geosocial":	{"JJ"},
"geosphere":	{"NN"},
"geostationary":	{"JJ"},
"geostrategic":	{"JJ"},
"geostrategy":	{"NN"},
"geosynchronous":	{"JJ"},
"geotag":	{"VB","VBP"},
"geotagged":	{"VBD","VBN"},
"geotagging":	{"VBG"},
"geotags":	{"VBZ"},
"geothermal":	{"JJ"},
"geothermally":	{"RB"},
"geothermic":	{"JJ"},
"geothlypis":	{"NN"},
"geotropism":	{"NN"},
"gephardtian":	{"JJ"},
"geracomium":	{"NN"},
"geraint":	{"NN"},
"geraldine":	{"NN"},
"geraniaceae":	{"NN"},
"geraniales":	{"NNS"},
"geranium":	{"NN"},
"geraniums":	{"NNS"},
"gerardia":	{"NN"},
"gerbera":	{"NN"},
"gerbert":	{"NN"},
"gerbil":	{"NN"},
"gerbille":	{"NN"},
"gerbillinae":	{"NN"},
"gerbillus":	{"NNS"},
"gerbils":	{"NNS"},
"gerea":	{"NN"},
"gerenuk":	{"NN"},
"gerfalcon":	{"NN"},
"geriatric":	{"JJ","NN"},
"geriatrician":	{"NN"},
"geriatricians":	{"NNS"},
"geriatrics":	{"NN"},
"germ":	{"NN"},
"german-american":	{"JJ"},
"german-born":	{"JJ"},
"german-built":	{"JJ"},
"german-french":	{"JJ"},
"german-italian":	{"JJ"},
"german-language":	{"JJ"},
"german-made":	{"JJ"},
"german-speaking":	{"JJ"},
"germander":	{"NN"},
"germane":	{"JJ"},
"germaneness":	{"NN"},
"germanism":	{"NN"},
"germanist":	{"NN"},
"germanite":	{"NN"},
"germanium":	{"NN"},
"germano-slavic":	{"JJ"},
"germany-based":	{"JJ"},
"germfree":	{"JJ"},
"germicidal":	{"JJ"},
"germicide":	{"NN"},
"germinal":	{"JJ"},
"germinate":	{"VB","VBP"},
"germinated":	{"VBD","VBN"},
"germinates":	{"VBZ"},
"germinating":	{"VBG"},
"germination":	{"NN"},
"germplasm":	{"NN"},
"germs":	{"NNS"},
"germy":	{"JJ"},
"gerontocracy":	{"NN"},
"gerontological":	{"JJ"},
"gerontologist":	{"NN"},
"gerontologists":	{"NNS"},
"gerontology":	{"NN"},
"gerreidae":	{"NN"},
"gerres":	{"NNS"},
"gerrhonotus":	{"NNS"},
"gerridae":	{"NN"},
"gerrididae":	{"NN"},
"gerris":	{"NN"},
"gerrymander":	{"NN","VB","VBP"},
"gerrymandered":	{"VBD","VBN"},
"gerrymandering":	{"NN","VBG"},
"gerrymanders":	{"NNS","VBZ"},
"gertrude":	{"NN"},
"gerund":	{"NN"},
"gerundial":	{"JJ"},
"gerunds":	{"NNS"},
"geryon":	{"NN"},
"gesell":	{"NN"},
"gesner":	{"NN"},
"gesneria":	{"NN"},
"gesneriaceae":	{"NN"},
"gesneriad":	{"NN"},
"gesso":	{"NN"},
"gestalt":	{"NN"},
"gestapo":	{"NN"},
"gestapo-style":	{"JJ"},
"gestate":	{"VB","VBP"},
"gestated":	{"VBD","VBN"},
"gestates":	{"VBZ"},
"gestating":	{"VBG"},
"gestation":	{"NN"},
"gestational":	{"JJ","NN"},
"gesticulate":	{"VB","VBP"},
"gesticulated":	{"VBD","VBN"},
"gesticulates":	{"VBZ"},
"gesticulating":	{"VBG"},
"gesticulation":	{"NN"},
"gesticulations":	{"NNS"},
"gestural":	{"JJ"},
"gesture":	{"NN","VBP","VB"},
"gestured":	{"VBD","VBN"},
"gestures":	{"NNS","VBZ"},
"gesturing":	{"VBG"},
"get":	{"VB","VBP"},
"get-along":	{"JJ"},
"get-at-able":	{"JJ"},
"get-go":	{"NN"},
"get-out-of-my-way":	{"JJ"},
"get-out-the-vote":	{"JJ"},
"get-rich-quick":	{"JJ"},
"get-together":	{"NN"},
"get-togethers":	{"NNS"},
"get-tough":	{"JJ"},
"get-up-and-go":	{"NN"},
"geta":	{"NN"},
"getable":	{"JJ"},
"getatable":	{"JJ"},
"getaway":	{"NN"},
"getaways":	{"NNS"},
"gets":	{"VBZ"},
"gettable":	{"JJ"},
"getting":	{"VBG"},
"getup":	{"NN"},
"getups":	{"NNS"},
"geum":	{"NN"},
"gewgaw":	{"NN"},
"geyser":	{"NN"},
"geysers":	{"NNS"},
"ghanese":	{"JJ"},
"ghanian":	{"JJ","NN"},
"gharry":	{"NN"},
"ghastlier":	{"JJR"},
"ghastliest":	{"JJS"},
"ghastliness":	{"NN"},
"ghastly":	{"JJ"},
"ghat":	{"NN"},
"ghatti":	{"NN"},
"ghazal":	{"NN"},
"ghazals":	{"NNS"},
"ghb":	{"NN"},
"ghee":	{"NN"},
"gheg":	{"NN"},
"ghent":	{"NN"},
"gherkin":	{"NN"},
"gherkins":	{"NNS"},
"ghetto":	{"NN"},
"ghettoes":	{"NNS"},
"ghettoisation":	{"NN"},
"ghettoise":	{"VB","VBP"},
"ghettoised":	{"VBD","VBN"},
"ghettoises":	{"VBZ"},
"ghettoising":	{"VBG"},
"ghettoization":	{"NN"},
"ghettoize":	{"VB","VBP"},
"ghettoized":	{"VBD","VBN"},
"ghettoizes":	{"VBZ"},
"ghettoizing":	{"VBG"},
"ghettos":	{"NNS"},
"ghilianii":	{"FW"},
"ghillie":	{"NN"},
"ghost":	{"NN","VBP","VB"},
"ghost-busting":	{"NN"},
"ghostbuster":	{"NN"},
"ghostbusters":	{"NNS"},
"ghostbusting":	{"NN"},
"ghosted":	{"VBD","VBN"},
"ghostfish":	{"NN"},
"ghosting":	{"VBG"},
"ghostlier":	{"JJR"},
"ghostliest":	{"JJS"},
"ghostlike":	{"JJ"},
"ghostliness":	{"NN"},
"ghostly":	{"JJ"},
"ghosts":	{"NNS","VBZ"},
"ghostwrite":	{"VB","VBP"},
"ghostwriter":	{"NN"},
"ghoul":	{"NN"},
"ghoulish":	{"JJ"},
"ghouls":	{"NNS"},
"ghq":	{"NN"},
"ghrelin":	{"NN"},
"ghrf":	{"NN"},
"ghz":	{"NN"},
"gia":	{"NN"},
"giant":	{"JJ","NN"},
"giantess":	{"NN"},
"giantesses":	{"NNS"},
"giantism":	{"NN"},
"giants":	{"NNS"},
"giaour":	{"NN"},
"giardia":	{"NN"},
"giardiasis":	{"NN"},
"gib":	{"NN"},
"gibber":	{"VB","VBP"},
"gibbered":	{"VBD","VBN"},
"gibberellin":	{"NN"},
"gibbering":	{"VBG","JJ"},
"gibberish":	{"NN"},
"gibbers":	{"VBZ"},
"gibbet":	{"NN","VB","VBP"},
"gibbeted":	{"VBD","VBN"},
"gibbeting":	{"VBG"},
"gibbets":	{"NNS","VBZ"},
"gibbetted":	{"VBD","VBN"},
"gibbetting":	{"VBG"},
"gibbon":	{"NN"},
"gibbons":	{"NNS"},
"gibbose":	{"JJ"},
"gibbosity":	{"NN"},
"gibbous":	{"JJ"},
"gibbousness":	{"NN"},
"gibbsite":	{"NN"},
"gibe":	{"NN","VB","VBP"},
"gibed":	{"VBD","VBN"},
"gibelike":	{"JJ"},
"giber":	{"NN"},
"gibes":	{"NNS","VBZ"},
"gibing":	{"VBG"},
"gibingly":	{"RB"},
"giblet":	{"NN"},
"giblets":	{"NNS"},
"gibran":	{"NN"},
"gidar":	{"NN"},
"giddied":	{"VBD","VBN"},
"giddier":	{"JJR"},
"giddies":	{"VBZ"},
"giddiest":	{"JJS"},
"giddily":	{"RB"},
"giddiness":	{"NN"},
"giddy":	{"JJ","VB","VBP"},
"giddying":	{"VBG"},
"gide":	{"NN"},
"gidgee":	{"NN"},
"gielgud":	{"NN"},
"gift":	{"NN","VB","VBP"},
"gift-giving":	{"NN","JJ"},
"gift-products":	{"NNS"},
"gift-wrap":	{"VB","VBP"},
"gift-wrapped":	{"VBD","VBN"},
"gift-wrapping":	{"VBG"},
"gift-wraps":	{"VBZ"},
"gifted":	{"JJ","VBN","VBD"},
"gifting":	{"VBG"},
"gifts":	{"NNS","VBZ"},
"gig":	{"NN","VB","VBP"},
"gigabit":	{"NN"},
"gigabyte":	{"NN"},
"gigabytes":	{"NNS"},
"gigacycle":	{"NN"},
"gigahertz":	{"NN","NNS"},
"gigantic":	{"JJ"},
"gigantism":	{"NN"},
"gigartinaceae":	{"NN"},
"gigged":	{"VBD","VBN"},
"gigging":	{"VBG"},
"giggle":	{"VB","VBP","NN"},
"giggled":	{"VBD","VBN"},
"giggler":	{"NN"},
"giggles":	{"VBZ","NNS"},
"giggling":	{"VBG"},
"giggly":	{"JJ"},
"gigo":	{"NN"},
"gigolo":	{"NN"},
"gigolos":	{"NNS"},
"gigot":	{"NN"},
"gigs":	{"NNS","VBZ"},
"gigue":	{"NN"},
"gigue-like":	{"JJ"},
"gikuyu":	{"NN"},
"gila":	{"NN"},
"gilbertian":	{"JJ"},
"gild":	{"VB","VBP"},
"gilded":	{"JJ","VBD","VBN"},
"gilder":	{"NN"},
"gildhall":	{"NN"},
"gilding":	{"NN","VBG"},
"gilds":	{"VBZ"},
"gilgamesh":	{"NN"},
"gilgamish":	{"NN"},
"gill":	{"NN","VB","VBP"},
"gill-less":	{"JJ"},
"gill-over-the-ground":	{"NN"},
"gilled":	{"VBD","VBN"},
"gillette":	{"NN"},
"gillie":	{"NN"},
"gilling":	{"VBG"},
"gills":	{"NNS","VBZ"},
"gillyflower":	{"NN"},
"gilman":	{"NN"},
"gilmer":	{"NN"},
"gilt":	{"JJ","NN"},
"gilt-edged":	{"JJ"},
"gilts":	{"NNS"},
"gimbal":	{"VB","VBP"},
"gimbaled":	{"VBD","VBN"},
"gimbaling":	{"VBG"},
"gimballed":	{"VBD","VBN"},
"gimballing":	{"VBG"},
"gimbals":	{"VBZ","NNS"},
"gimcrack":	{"JJ","NN"},
"gimcrackery":	{"NN"},
"gimcracks":	{"NNS"},
"gimel":	{"NN"},
"gimlet":	{"NN","JJ"},
"gimlets":	{"NNS"},
"gimmick":	{"NN","VB","VBP"},
"gimmick-ridden":	{"JJ"},
"gimmicked":	{"VBD","VBN"},
"gimmicking":	{"VBG"},
"gimmickry":	{"NN"},
"gimmicks":	{"VBZ","NNS"},
"gimmicky":	{"JJ"},
"gimp":	{"NN"},
"gimpiness":	{"NN"},
"gimpy":	{"JJ"},
"gin":	{"NN","VB","VBP"},
"gin-and-tonics":	{"NNS"},
"ginep":	{"NN"},
"ginger":	{"NN","JJ","VB","VBP"},
"ginger-ale":	{"NN"},
"ginger-ales":	{"NNS"},
"ginger-beer":	{"NN"},
"ginger-beers":	{"NNS"},
"ginger-nut":	{"NN"},
"ginger-nuts":	{"NNS"},
"ginger-scented":	{"JJ"},
"ginger-snap":	{"NN"},
"gingerbread":	{"NN"},
"gingered":	{"VBD","VBN"},
"gingering":	{"VBG"},
"gingerly":	{"RB","JJ"},
"gingerol":	{"NN"},
"gingerroot":	{"NN"},
"gingers":	{"VBZ"},
"gingersnap":	{"NN"},
"gingery":	{"JJ"},
"gingham":	{"NN"},
"gingiva":	{"NN"},
"gingival":	{"JJ"},
"gingivitis":	{"NN"},
"gingko":	{"NN"},
"ginglymostoma":	{"NN"},
"ginglymus":	{"NNS"},
"ginkgo":	{"NN"},
"ginkgoaceae":	{"NN"},
"ginkgoales":	{"NNS"},
"ginkgoes":	{"NNS"},
"ginkgophytina":	{"NN"},
"ginkgopsida":	{"NN"},
"ginmill":	{"NN"},
"ginned":	{"VBD","VBN"},
"ginning":	{"VBG"},
"ginormous":	{"JJ"},
"ginormously":	{"RB"},
"gins":	{"NNS","VBZ"},
"ginseng":	{"NN"},
"ginza":	{"NN"},
"ginzo":	{"NN"},
"gip":	{"VB","VBP"},
"gipped":	{"VBD","VBN"},
"gipper":	{"NN"},
"gipping":	{"VBG"},
"gips":	{"VBZ"},
"gipsies":	{"NNS"},
"gipsy":	{"NN"},
"gipsywort":	{"NN"},
"giraffa":	{"NN"},
"giraffe":	{"NN","NNS"},
"giraffes":	{"NNS"},
"giraffidae":	{"NN"},
"girandola":	{"NN"},
"girandole":	{"NN"},
"girard":	{"NN"},
"girasol":	{"NN"},
"giraudoux":	{"NN"},
"gird":	{"VB","VBP"},
"girded":	{"VBD","VBN"},
"girder":	{"NN"},
"girders":	{"NNS"},
"girding":	{"VBG"},
"girdle":	{"NN","VB","VBP"},
"girdled":	{"VBD","VBN"},
"girdles":	{"NNS","VBZ"},
"girdling":	{"VBG"},
"girds":	{"VBZ"},
"giriama":	{"NN"},
"girl":	{"NN"},
"girl-friend":	{"NN"},
"girl-san":	{"NN"},
"girlfriend":	{"NN"},
"girlfriends":	{"NNS"},
"girlhood":	{"NN"},
"girlie":	{"JJ","NN"},
"girlies":	{"NNS"},
"girlish":	{"JJ"},
"girlishly":	{"RB"},
"girlishness":	{"NN"},
"girls":	{"NNS"},
"girly":	{"JJ"},
"giro":	{"NN"},
"gironde":	{"NN"},
"girondin":	{"NN"},
"girondism":	{"NN"},
"girondist":	{"NN"},
"giros":	{"NNS"},
"girru":	{"NN"},
"girt":	{"VBD","VBN"},
"girth":	{"NN","VB","VBP"},
"girthed":	{"VBD","VBN"},
"girthing":	{"VBG"},
"girths":	{"NNS","VBZ"},
"gish":	{"NN"},
"gismo":	{"NN"},
"gist":	{"NN"},
"git":	{"NN"},
"gita":	{"NN"},
"gitana":	{"NN"},
"gitano":	{"NN"},
"gits":	{"NNS"},
"gittern":	{"NN"},
"give":	{"VB","NN","VBP"},
"give-and-go":	{"NN"},
"give-and-take":	{"NN"},
"give-away":	{"JJ"},
"giveaway":	{"NN","JJ"},
"giveaways":	{"NNS"},
"givebacks":	{"NNS"},
"given":	{"VBN","JJ","IN","NN"},
"givenness":	{"NN"},
"giver":	{"NN"},
"givers":	{"NNS"},
"gives":	{"VBZ"},
"giving":	{"VBG","JJ","NN"},
"givings":	{"NNS"},
"gizeh":	{"NN"},
"gizmo":	{"NN"},
"gizmos":	{"NNS"},
"gizzard":	{"NN"},
"gjellerup":	{"NN"},
"gl":	{"NN"},
"glabella":	{"NN"},
"glabellar":	{"JJ"},
"glabrescent":	{"JJ"},
"glabrous":	{"JJ"},
"glace":	{"JJ"},
"glacial":	{"JJ"},
"glacially":	{"RB"},
"glaciate":	{"VB","VBP"},
"glaciated":	{"VBD","VBN"},
"glaciates":	{"VBZ"},
"glaciating":	{"VBG"},
"glaciation":	{"NN"},
"glaciations":	{"NNS"},
"glacier":	{"NN"},
"glacier-like":	{"JJ"},
"glaciers":	{"NNS"},
"glad":	{"JJ","VB","VBP"},
"glad-hand":	{"VB","VBP"},
"glad-handed":	{"VBD","VBN"},
"glad-handing":	{"VBG"},
"glad-hands":	{"VBZ"},
"gladded":	{"VBD","VBN"},
"gladden":	{"VB","VBP"},
"gladdened":	{"VBD","VBN"},
"gladdening":	{"VBG"},
"gladdens":	{"VBZ"},
"gladder":	{"JJR"},
"gladdest":	{"JJS"},
"gladding":	{"VBG"},
"gladdon":	{"NN"},
"glade":	{"NN"},
"glades":	{"NNS"},
"gladfulness":	{"NN"},
"gladiator":	{"NN"},
"gladiatorial":	{"JJ"},
"gladiators":	{"NNS"},
"gladiola":	{"NN"},
"gladioli":	{"NNS"},
"gladiolus":	{"NN"},
"gladioluses":	{"NNS"},
"gladly":	{"RB"},
"gladness":	{"NN"},
"glads":	{"VBZ"},
"gladsome":	{"JJ"},
"gladsomeness":	{"NN"},
"glamor":	{"NN"},
"glamorisation":	{"NN"},
"glamorise":	{"VB","VBP"},
"glamorised":	{"VBD","VBN"},
"glamorises":	{"VBZ"},
"glamorising":	{"VBG"},
"glamorization":	{"NN"},
"glamorize":	{"VB","VBP"},
"glamorized":	{"VBN","VBD"},
"glamorizes":	{"VBZ"},
"glamorizing":	{"VBG"},
"glamorous":	{"JJ"},
"glamorously":	{"RB"},
"glamour":	{"NN"},
"glamourisation":	{"NN"},
"glamourise":	{"VB"},
"glamourization":	{"NN"},
"glamourize":	{"VB"},
"glamourous":	{"JJ"},
"glance":	{"VB","VBP","NN"},
"glanced":	{"VBD","VBN"},
"glances":	{"NNS","VBZ"},
"glancing":	{"JJ","VBG"},
"glancingly":	{"RB"},
"gland":	{"NN"},
"glandered":	{"JJ"},
"glanderous":	{"JJ"},
"glanders":	{"NN"},
"glandes":	{"NNS"},
"glandlike":	{"JJ"},
"glands":	{"NNS"},
"glandular":	{"JJ"},
"glans":	{"NN"},
"glare":	{"NN","VB","VBP"},
"glared":	{"VBD","VBN"},
"glareola":	{"NN"},
"glareole":	{"NN"},
"glareolidae":	{"NN"},
"glares":	{"NNS","VBZ"},
"glarier":	{"JJR"},
"glariest":	{"JJS"},
"glariness":	{"NN"},
"glaring":	{"JJ","VBG"},
"glaringly":	{"RB"},
"glary":	{"JJ"},
"glaser":	{"NN"},
"glasnost":	{"NN"},
"glass":	{"NN","VBP","VB"},
"glass-blower":	{"NN"},
"glass-bottom":	{"JJ"},
"glass-container":	{"NN","JJ"},
"glass-cutter":	{"NN"},
"glass-fiber":	{"JJ"},
"glass-like":	{"JJ"},
"glass-making":	{"NN","JJ"},
"glass-strewn":	{"JJ"},
"glassblower":	{"NN"},
"glassed":	{"VBD","VBN"},
"glasser":	{"NN"},
"glasses":	{"NNS","VBZ"},
"glassful":	{"NN"},
"glassfuls":	{"NNS"},
"glasshouse":	{"NN"},
"glasshousees":	{"NNS"},
"glassier":	{"JJR"},
"glassiest":	{"JJS"},
"glassily":	{"RB"},
"glassiness":	{"NN"},
"glassing":	{"VBG"},
"glassless":	{"JJ"},
"glassmaker":	{"NN"},
"glassware":	{"NN"},
"glasswork":	{"NN"},
"glassworker":	{"NN"},
"glassworks":	{"NN","NNS"},
"glasswort":	{"NN"},
"glassy":	{"JJ"},
"glassy-eyed":	{"JJ"},
"glaucium":	{"NN"},
"glaucoma":	{"NN"},
"glaucomys":	{"NNS"},
"glauconite":	{"NN"},
"glaucous":	{"JJ"},
"glaux":	{"NN"},
"glaze":	{"VB","VBP","NN"},
"glazed":	{"JJ","VBD","VBN"},
"glazer":	{"NN"},
"glazes":	{"NNS","VBZ"},
"glazier":	{"NN"},
"glaziers":	{"NNS"},
"glazing":	{"NN","VBG"},
"gleam":	{"NN","VB","VBP"},
"gleamed":	{"VBD","VBN"},
"gleaming":	{"JJ","VBG"},
"gleams":	{"NNS","VBZ"},
"glean":	{"VB","VBP"},
"gleaned":	{"VBD","VBN"},
"gleaner":	{"NN"},
"gleaning":	{"VBG"},
"gleans":	{"VBZ"},
"gleason":	{"NN"},
"gleba":	{"NN"},
"glebe":	{"NN"},
"glechoma":	{"NN"},
"gleditsia":	{"NN"},
"glee":	{"NN"},
"glee-club":	{"NN"},
"gleeful":	{"JJ"},
"gleefully":	{"RB"},
"gleefulness":	{"NN"},
"glees":	{"NNS"},
"gleet":	{"NN"},
"gleichenia":	{"NN"},
"gleicheniaceae":	{"NN"},
"glen":	{"NN"},
"glendower":	{"NN"},
"glengarry":	{"NN"},
"glens":	{"NNS"},
"glia":	{"NN"},
"glial":	{"NN","JJ"},
"glib":	{"JJ"},
"glib-tongued":	{"JJ"},
"glibber":	{"JJR"},
"glibbest":	{"JJS"},
"glibly":	{"RB"},
"glibness":	{"NN"},
"glide":	{"VB","VBP","NN"},
"glide-bombing":	{"VBG"},
"glide-bombs":	{"VBZ"},
"glided":	{"VBD","VBN"},
"glider":	{"NN"},
"gliders":	{"NNS"},
"glides":	{"VBZ","NNS"},
"gliding":	{"VBG","NN"},
"glimmer":	{"VB","VBP","NN"},
"glimmered":	{"VBD","VBN"},
"glimmering":	{"NN","VBG"},
"glimmerings":	{"NNS"},
"glimmers":	{"VBZ","NNS"},
"glimmery":	{"JJ"},
"glimpse":	{"NN","VB","VBP"},
"glimpsed":	{"VBD","VBN"},
"glimpses":	{"NNS","VBZ"},
"glimpsing":	{"VBG"},
"glinka":	{"NN"},
"glint":	{"VB","VBP","NN"},
"glinted":	{"VBD","VBN"},
"glinting":	{"VBG"},
"glints":	{"NNS","VBZ"},
"glioblastoma":	{"NN"},
"glioblastomas":	{"NNS"},
"glioblastomata":	{"NNS"},
"glioma":	{"NN"},
"glipizide":	{"NN"},
"gliricidia":	{"NN"},
"gliridae":	{"NN"},
"glis":	{"NN"},
"glissade":	{"NN","VB","VBP"},
"glissaded":	{"VBD","VBN"},
"glissades":	{"NNS","VBZ"},
"glissading":	{"VBG"},
"glissandi":	{"NNS"},
"glissando":	{"NN"},
"glissandos":	{"NNS"},
"glisten":	{"VB","VBP"},
"glistened":	{"VBD","VBN"},
"glistening":	{"VBG"},
"glistens":	{"VBZ"},
"glister":	{"NN"},
"glistering":	{"JJ"},
"glitch":	{"NN"},
"glitches":	{"NNS"},
"glitter":	{"VB","VBP","NN"},
"glitterati":	{"NNS"},
"glittered":	{"VBD","VBN"},
"glittering":	{"JJ","VBG"},
"glitters":	{"VBZ"},
"glittery":	{"JJ"},
"glitz":	{"NN"},
"glitzier":	{"JJR"},
"glitziest":	{"JJS"},
"glitzy":	{"JJ"},
"gloam":	{"NN"},
"gloaming":	{"NN"},
"gloat":	{"VB","VBP","NN"},
"gloated":	{"VBD","VBN"},
"gloater":	{"NN"},
"gloaters":	{"NNS"},
"gloating":	{"JJ","VBG"},
"gloatingly":	{"RB"},
"gloats":	{"VBZ"},
"glob":	{"NN"},
"glob-flakes":	{"NNS"},
"global":	{"JJ"},
"global-funds":	{"JJ"},
"global-market":	{"JJ"},
"global-news":	{"NN"},
"global-warming":	{"NN"},
"globalisation":	{"NN"},
"globalise":	{"VB","VBP"},
"globalised":	{"VBD","VBN"},
"globalises":	{"VBZ"},
"globalising":	{"VBG"},
"globalism":	{"NN"},
"globalist":	{"NN"},
"globalists":	{"NNS"},
"globalization":	{"NN"},
"globalize":	{"VB","NN"},
"globalized":	{"VBD","VBN"},
"globalizing":	{"VBG"},
"globaliztion":	{"NN"},
"globally":	{"RB"},
"globe":	{"NN","VB","VBP"},
"globe-girdling":	{"JJ"},
"globe-spanning":	{"JJ"},
"globe-trot":	{"VB","VBP"},
"globe-trots":	{"VBZ"},
"globe-trotted":	{"VBD","VBN"},
"globe-trotter":	{"NN"},
"globe-trotters":	{"NNS"},
"globe-trotting":	{"VBG","JJ"},
"globed":	{"VBD","VBN"},
"globefish":	{"NN"},
"globeflower":	{"NN"},
"globes":	{"NNS","VBZ"},
"globetrotter":	{"NN"},
"globetrotters":	{"NNS"},
"globicephala":	{"NN"},
"globigerina":	{"NN"},
"globigerinidae":	{"NN"},
"globigii":	{"NNS"},
"globin":	{"NN"},
"globing":	{"VBG"},
"globose":	{"JJ"},
"globosity":	{"NN"},
"globs":	{"NNS"},
"globular":	{"JJ"},
"globularness":	{"NN"},
"globule":	{"NN"},
"globules":	{"NNS"},
"globulin":	{"NN"},
"globulins":	{"NNS"},
"glochid":	{"NN"},
"glochidium":	{"NN"},
"glockenspiel":	{"NN"},
"glockenspiels":	{"NNS"},
"glogg":	{"NN"},
"glom":	{"VB","VBP"},
"glomerular":	{"JJ"},
"glomerule":	{"NN"},
"glomerulonephritis":	{"NN"},
"glomerulus":	{"NN"},
"glommed":	{"VBD","VBN"},
"glomming":	{"VBG"},
"gloms":	{"VBZ"},
"gloom":	{"NN","VB","VBP"},
"gloom-and-doom":	{"JJ"},
"gloomed":	{"VBD","VBN"},
"gloomful":	{"JJ"},
"gloomier":	{"JJR"},
"gloomiest":	{"JJS"},
"gloomily":	{"RB"},
"gloominess":	{"NN"},
"glooming":	{"VBG"},
"glooms":	{"VBZ"},
"gloomy":	{"JJ"},
"gloop":	{"NN"},
"glop":	{"NN"},
"gloppy":	{"JJ"},
"gloried":	{"VBD","VBN"},
"glories":	{"NNS","VBZ"},
"glorification":	{"NN"},
"glorified":	{"JJ","VBD","VBN"},
"glorifies":	{"VBZ"},
"glorify":	{"VB","VBP"},
"glorifying":	{"VBG"},
"gloriole":	{"NN"},
"gloriosa":	{"NN"},
"glorious":	{"JJ"},
"gloriously":	{"RB"},
"glory":	{"NN","VBP","VB"},
"glorying":	{"VBG"},
"gloss":	{"NN","VB","VBP"},
"glossa":	{"NN"},
"glossalgia":	{"NN"},
"glossaries":	{"NNS"},
"glossarist":	{"NN"},
"glossary":	{"NN"},
"glossed":	{"VBD","VBN"},
"glosses":	{"NNS","VBZ"},
"glossier":	{"JJR"},
"glossies":	{"NNS"},
"glossiest":	{"JJS"},
"glossily":	{"RB"},
"glossina":	{"NN"},
"glossiness":	{"NN"},
"glossing":	{"VBG"},
"glossinidae":	{"NN"},
"glossitis":	{"NN"},
"glossodia":	{"NN"},
"glossodynia":	{"NN"},
"glossolalia":	{"NN"},
"glossopharyngeal":	{"JJ"},
"glossopsitta":	{"NN"},
"glossoptosis":	{"NN"},
"glossy":	{"JJ","NN"},
"glossy-coated":	{"JJ"},
"glossy-furred":	{"JJ"},
"glossy-haired":	{"JJ"},
"glottal":	{"JJ"},
"glottides":	{"NNS"},
"glottis":	{"NN"},
"glottises":	{"NNS"},
"glottochronological":	{"JJ"},
"glottochronology":	{"NN"},
"glove":	{"NN","VB","VBP"},
"gloved":	{"VBD","VBN","JJ"},
"gloveless":	{"JJ"},
"glover":	{"NN"},
"gloves":	{"NNS","VBZ"},
"gloving":	{"VBG"},
"glow":	{"VB","VBP","NN"},
"glow-in-the-dark":	{"JJ"},
"glowed":	{"VBD","VBN"},
"glower":	{"VB","VBP"},
"glowered":	{"VBD","VBN"},
"glowering":	{"VBG","JJ"},
"gloweringly":	{"RB"},
"glowers":	{"VBZ"},
"glowing":	{"JJ","VBG"},
"glowingly":	{"RB"},
"glows":	{"VBZ","NNS"},
"glowworm":	{"NN"},
"gloxinia":	{"NN"},
"glucagon":	{"NN"},
"glucinium":	{"NN"},
"gluck":	{"NN"},
"glucocorticoid":	{"NN"},
"glucophage":	{"NN"},
"glucosamine":	{"NN"},
"glucose":	{"NN"},
"glucoside":	{"NN"},
"glucosuria":	{"NN"},
"glucotrol":	{"NN"},
"glue":	{"NN","VB","VBP"},
"glued":	{"VBD","VBN"},
"glues":	{"VBZ","NNS"},
"gluey":	{"JJ"},
"glueyness":	{"NN"},
"glug":	{"NN"},
"gluiness":	{"NN"},
"gluing":	{"VBG"},
"glum":	{"JJ"},
"glume":	{"NN"},
"glumly":	{"RB"},
"glummer":	{"JJR"},
"glummest":	{"JJS"},
"glumness":	{"NN"},
"gluon":	{"NN"},
"glut":	{"NN","VB","VBP"},
"glutamate":	{"NN"},
"glutamic":	{"JJ"},
"glutamine":	{"NN"},
"glutaric":	{"JJ"},
"glute":	{"NN"},
"gluteal":	{"JJ"},
"glutelin":	{"NN"},
"gluten":	{"NN"},
"glutethimide":	{"NN"},
"gluteus":	{"NN"},
"glutinosity":	{"NN"},
"glutinous":	{"JJ"},
"glutinousness":	{"NN"},
"gluts":	{"NNS","VBZ"},
"glutted":	{"VBD","VBN","JJ"},
"glutting":	{"VBG"},
"glutton":	{"NN"},
"gluttonise":	{"VB","VBP"},
"gluttonize":	{"VB","VBP"},
"gluttonous":	{"JJ"},
"gluttonously":	{"RB"},
"gluttons":	{"NNS"},
"gluttony":	{"NN"},
"glyburide":	{"NN"},
"glyceraldehyde":	{"NN"},
"glyceria":	{"NN"},
"glyceride":	{"NN"},
"glycerin":	{"NN"},
"glycerinated":	{"JJ"},
"glycerine":	{"NN"},
"glycerite":	{"NN"},
"glycerogel":	{"NN"},
"glycerogelatin":	{"NN"},
"glycerol":	{"NN"},
"glycerole":	{"NN"},
"glycerolise":	{"VB","VBP"},
"glycerolize":	{"VB","VBP"},
"glycerolized":	{"VBD","VBN"},
"glyceryl":	{"NN"},
"glycine":	{"NN"},
"glycogen":	{"NN"},
"glycogenesis":	{"NN"},
"glycogenic":	{"JJ"},
"glycol":	{"NN"},
"glycols":	{"NNS"},
"glycolysis":	{"NN"},
"glycoprotein":	{"NN"},
"glycoside":	{"NN"},
"glycosides":	{"NNS"},
"glycosuria":	{"NN"},
"glycyrrhiza":	{"NN"},
"glyoxaline":	{"NN"},
"glyph":	{"NN"},
"glyptics":	{"NN"},
"glyptography":	{"NN"},
"gm":	{"NN","NNS"},
"gm-toyota":	{"JJ"},
"gm.":	{"NN"},
"gmr":	{"NN"},
"gms":	{"NNS"},
"gmt":	{"NN"},
"gnaphalium":	{"NN"},
"gnarl":	{"NN","VB","VBP"},
"gnarled":	{"JJ","VBD","VBN"},
"gnarling":	{"VBG"},
"gnarls":	{"VBZ","NNS"},
"gnarly":	{"JJ"},
"gnash":	{"VB","VBP"},
"gnashed":	{"VBD","VBN"},
"gnashers":	{"NNS"},
"gnashes":	{"VBZ"},
"gnashing":	{"VBG"},
"gnat":	{"NN"},
"gnatcatcher":	{"NN"},
"gnathion":	{"NN"},
"gnathostomata":	{"NN"},
"gnathostome":	{"NN"},
"gnats":	{"NNS"},
"gnaw":	{"VB","VBP"},
"gnawed":	{"VBD","VBN"},
"gnawer":	{"NN"},
"gnawing":	{"NN","JJ","VBG"},
"gnaws":	{"VBZ"},
"gneiss":	{"NN"},
"gnetaceae":	{"NN"},
"gnetales":	{"NNS"},
"gnetophyta":	{"NN"},
"gnetophytina":	{"NN"},
"gnetopsida":	{"NN"},
"gnetum":	{"NN"},
"gnocchi":	{"NNS"},
"gnome":	{"NN"},
"gnomelike":	{"JJ"},
"gnomes":	{"NNS"},
"gnomic":	{"JJ"},
"gnomically":	{"RB"},
"gnomish":	{"JJ"},
"gnomon":	{"NN"},
"gnosis":	{"NN"},
"gnostic":	{"JJ"},
"gnosticism":	{"NN"},
"gnp":	{"NN"},
"gnp-based":	{"JJ"},
"gnu":	{"NN","NNS"},
"gnus":	{"NNS"},
"go":	{"VB","VBP","NN"},
"go-ahead":	{"NN","JJ"},
"go-along":	{"JJ"},
"go-around":	{"NN"},
"go-as-you-please":	{"JJ"},
"go-between":	{"NN"},
"go-betweens":	{"NNS"},
"go-cart":	{"NN"},
"go-carts":	{"NNS"},
"go-getter":	{"NN"},
"go-getters":	{"NNS"},
"go-getting":	{"JJ"},
"go-go":	{"JJ"},
"go-go-go":	{"NN"},
"go-it-alone":	{"JJ"},
"go-kart":	{"NN"},
"go-karting":	{"NN"},
"go-karts":	{"NNS"},
"go-round":	{"NN"},
"go-slow":	{"NN"},
"go-slows":	{"NNS"},
"go-to-meeting":	{"JJ"},
"go-to-war":	{"JJ"},
"goa":	{"NN"},
"goad":	{"VB","VBP","NN"},
"goaded":	{"VBD","VBN"},
"goading":	{"VBG"},
"goads":	{"VBZ","NNS"},
"goal":	{"NN"},
"goal-area":	{"NN"},
"goal-directed":	{"JJ"},
"goal-kick":	{"NN"},
"goal-line":	{"NN"},
"goal-lines":	{"NNS"},
"goal-mouth":	{"NN"},
"goal-oriented":	{"JJ"},
"goal-post":	{"NN"},
"goal-values":	{"NNS"},
"goalie":	{"NN"},
"goalies":	{"NNS"},
"goalkeeper":	{"NN"},
"goalkeepers":	{"NNS"},
"goalless":	{"JJ"},
"goalmouth":	{"NN"},
"goalmouths":	{"NNS"},
"goalpost":	{"NN"},
"goalposts":	{"NNS"},
"goals":	{"NNS"},
"goalscorer":	{"NN"},
"goalscorers":	{"NNS"},
"goaltender":	{"NN"},
"goaltenders":	{"NNS"},
"goat":	{"NN"},
"goat-drawn":	{"JJ"},
"goatee":	{"NN"},
"goateed":	{"JJ"},
"goatees":	{"NNS"},
"goatfish":	{"NN"},
"goatherd":	{"NN"},
"goatherds":	{"NNS"},
"goats":	{"NNS"},
"goatsbeard":	{"NN"},
"goatsfoot":	{"NN"},
"goatskin":	{"NN"},
"goatsucker":	{"NN"},
"gob":	{"NN","VB","VBP"},
"gob-stopper":	{"NN"},
"gobbet":	{"NN"},
"gobbets":	{"NNS"},
"gobble":	{"VB","VBP","NN"},
"gobbled":	{"VBD","VBN"},
"gobbledygook":	{"NN"},
"gobbler":	{"NN"},
"gobblers":	{"NNS"},
"gobbles":	{"VBZ","NNS"},
"gobbling":	{"VBG"},
"gobi":	{"NN"},
"gobies":	{"NNS"},
"gobiesocidae":	{"NN"},
"gobiesox":	{"NN"},
"gobiidae":	{"NN"},
"gobio":	{"NN"},
"goblet":	{"NN"},
"goblet-shaped":	{"JJ"},
"goblets":	{"NNS"},
"goblin":	{"NN"},
"goblins":	{"NNS"},
"gobs":	{"NNS","VBZ"},
"gobsmacked":	{"JJ"},
"gobsmackingly":	{"RB"},
"goby":	{"NN","NNS"},
"god":	{"NN"},
"god-awful":	{"JJ"},
"god-curst":	{"JJ"},
"god-like":	{"JJ"},
"godard":	{"NN"},
"godchild":	{"NN"},
"godchildren":	{"NNS"},
"goddam":	{"JJ"},
"goddamit":	{"UH"},
"goddammit":	{"UH"},
"goddamn":	{"JJ","RB"},
"goddamned":	{"JJ","RB"},
"goddard":	{"NN"},
"goddaughter":	{"NN"},
"goddaughters":	{"NNS"},
"goddess":	{"NN"},
"goddesses":	{"NNS"},
"godel":	{"NN"},
"godfather":	{"VB","VBP"},
"godforsaken":	{"NN","JJ"},
"godhead":	{"NN"},
"godless":	{"JJ"},
"godlessness":	{"NN"},
"godlier":	{"JJR"},
"godliest":	{"JJS"},
"godlike":	{"JJ"},
"godliness":	{"NN"},
"godly":	{"JJ"},
"godmother":	{"NN"},
"godmothers":	{"NNS"},
"godown":	{"NN"},
"godparent":	{"NN"},
"godparents":	{"NNS"},
"gods":	{"NNS"},
"godsend":	{"NN"},
"godson":	{"NN"},
"godsons":	{"NNS"},
"godspeed":	{"NN"},
"godwit":	{"NN"},
"goer":	{"NN"},
"goes":	{"VBZ","NNS"},
"goeteborg":	{"NN"},
"goethean":	{"JJ"},
"goethian":	{"JJ"},
"goethite":	{"NN"},
"gofer":	{"NN"},
"gofers":	{"NNS"},
"goffer":	{"NN","VB","VBP"},
"goffered":	{"VBD","VBN"},
"goffering":	{"VBG"},
"goffers":	{"VBZ"},
"goggle":	{"VB","VBP","NN"},
"goggle-box":	{"NN"},
"goggle-eye":	{"NN"},
"goggle-eyed":	{"JJ"},
"goggled":	{"VBD","VBN"},
"goggles":	{"NNS","VBZ"},
"goggling":	{"VBG"},
"gogh":	{"NN"},
"gogol":	{"NN"},
"goidelic":	{"NN"},
"goin":	{"NN"},
"going":	{"VBG","NN","JJ"},
"going-home":	{"JJ"},
"going-over":	{"NN"},
"going-private":	{"JJ"},
"goings":	{"NNS"},
"goings-on":	{"NNS"},
"goings-over":	{"NNS"},
"goiter":	{"NN"},
"goitre":	{"NN"},
"goitrogen":	{"NN"},
"goitrogens":	{"NNS"},
"golan":	{"NN"},
"gold":	{"NN","JJ"},
"gold-backed":	{"JJ"},
"gold-based":	{"JJ"},
"gold-bearing":	{"JJ"},
"gold-beater":	{"NN"},
"gold-card-carrying":	{"JJ"},
"gold-colored":	{"JJ"},
"gold-coloured":	{"JJ"},
"gold-convertible":	{"JJ"},
"gold-digger":	{"NN"},
"gold-diggers":	{"NNS"},
"gold-dust":	{"NN"},
"gold-field":	{"NN"},
"gold-filled":	{"JJ"},
"gold-leaf":	{"JJ","NN"},
"gold-medal":	{"NN"},
"gold-mine":	{"NN"},
"gold-mining":	{"JJ","NN"},
"gold-mining-company":	{"JJ"},
"gold-oriented":	{"JJ"},
"gold-phone":	{"NN"},
"gold-plate":	{"NN","VB","VBP"},
"gold-plated":	{"JJ","VBD","VBN"},
"gold-plates":	{"VBZ"},
"gold-plating":	{"VBG"},
"gold-rush":	{"NN"},
"gold-rushs":	{"NNS"},
"gold-share":	{"JJ"},
"gold-wire":	{"NN"},
"gold-worker":	{"NN"},
"goldbeater":	{"NN"},
"goldbrick":	{"NN","VB","VBP"},
"goldbricked":	{"VBD","VBN"},
"goldbricking":	{"VBG"},
"goldbricks":	{"VBZ","NNS"},
"goldcrest":	{"NN"},
"goldcup":	{"NN"},
"golden":	{"JJ"},
"golden-brown":	{"JJ"},
"golden-crusted":	{"JJ"},
"golden-green":	{"JJ"},
"golden-parachute":	{"JJ"},
"golden-share":	{"NN"},
"golden-yellow":	{"JJ"},
"goldenbush":	{"NN"},
"goldeneye":	{"NN"},
"goldenrod":	{"NN"},
"goldenseal":	{"NN"},
"goldfield":	{"NN"},
"goldfields":	{"NNS"},
"goldfinch":	{"NN"},
"goldfish":	{"NN","NNS"},
"goldin":	{"NN"},
"goldmark":	{"NN"},
"goldmine":	{"NN"},
"goldoni":	{"NN"},
"golds":	{"NNS"},
"goldsboro":	{"NN"},
"goldsmith":	{"NN"},
"goldsmiths":	{"NNS"},
"goldstock":	{"NN"},
"goldstone":	{"NN"},
"goldthread":	{"NN"},
"goldworker":	{"NN"},
"golem":	{"NN"},
"golf":	{"NN","VB","VBP"},
"golf-ball":	{"NN"},
"golf-club":	{"NN"},
"golf-clubs":	{"NNS"},
"golf-course":	{"NN"},
"golf-courses":	{"NNS"},
"golf-links":	{"NN","NNS"},
"golfcart":	{"NN"},
"golfed":	{"VBD","VBN"},
"golfer":	{"NN"},
"golfers":	{"NNS"},
"golfing":	{"NN","VBG"},
"golfs":	{"NNS","VBZ"},
"golgi":	{"NN"},
"goliard":	{"NN"},
"gollies":	{"NNS"},
"golliwog":	{"NN"},
"golliwogg":	{"NN"},
"golliwogs":	{"NNS"},
"golly":	{"UH","NN"},
"golosh":	{"NN"},
"goma":	{"NN"},
"gombrowicz":	{"NN"},
"gomel":	{"NN"},
"gomorrha":	{"NN"},
"gomphothere":	{"NN"},
"gomphotheriidae":	{"NN"},
"gomphotherium":	{"NN"},
"gomphrena":	{"NN"},
"gomuti":	{"NN"},
"gonad":	{"NN"},
"gonadal":	{"JJ"},
"gonadotrophic":	{"JJ"},
"gonadotrophin":	{"NN"},
"gonadotropic":	{"JJ"},
"gonadotropin":	{"NN"},
"gonads":	{"NNS"},
"goncourt":	{"NN"},
"gond":	{"NN"},
"gondi":	{"NN"},
"gondola":	{"NN"},
"gondolas":	{"NNS"},
"gondolier":	{"NN"},
"gondoliere":	{"NN"},
"gondoliers":	{"NNS"},
"gone":	{"VBN","JJ","IN"},
"goner":	{"NN"},
"goners":	{"NNS"},
"gong":	{"NN","VB","VBP"},
"gonged":	{"VBD","VBN"},
"gonging":	{"VBG"},
"gonglike":	{"JJ"},
"gongora":	{"NN"},
"gongorism":	{"NN"},
"gongorist":	{"NN"},
"gongs":	{"NNS","VBZ"},
"gonif":	{"NN"},
"goniff":	{"NN"},
"goniometer":	{"NN"},
"gonion":	{"NN"},
"goniopteris":	{"NNS"},
"gonioscopy":	{"NN"},
"gonna":	{"RB"},
"gonne":	{"NN"},
"gonococcus":	{"NN"},
"gonorhynchidae":	{"NN"},
"gonorhynchus":	{"NNS"},
"gonorrhea":	{"NN"},
"gonorrhoea":	{"NN"},
"gonzo":	{"NN","JJ"},
"goo":	{"NN"},
"goober":	{"NN"},
"good":	{"JJ","NN","RB"},
"good-by":	{"NN"},
"good-bye":	{"NN"},
"good-cop":	{"JJ"},
"good-driver":	{"JJ"},
"good-faith":	{"NN"},
"good-for-naught":	{"JJ","NN"},
"good-for-nothing":	{"JJ","NN"},
"good-for-nothings":	{"NNS"},
"good-for-you":	{"JJ"},
"good-hearted":	{"JJ"},
"good-humored":	{"JJ"},
"good-humoredly":	{"RB"},
"good-humoredness":	{"NN"},
"good-humoured":	{"JJ"},
"good-humouredly":	{"RB"},
"good-humouredness":	{"NN"},
"good-king-henry":	{"NN"},
"good-living":	{"JJ"},
"good-looking":	{"JJ"},
"good-natured":	{"JJ"},
"good-naturedly":	{"RB"},
"good-naturedness":	{"NN"},
"good-neighborliness":	{"NN"},
"good-neighbourliness":	{"NN"},
"good-news":	{"NN"},
"good-night":	{"JJ","NN"},
"good-quality":	{"JJ","NN"},
"good-size":	{"JJ"},
"good-tempered":	{"JJ"},
"good-temperedness":	{"NN"},
"good-til-canceled":	{"JJ"},
"good-till-canceled":	{"JJ"},
"good-time":	{"JJ"},
"good-will":	{"JJ","NN"},
"goodall":	{"NN"},
"goodby":	{"NN"},
"goodbye":	{"UH","NN"},
"goodbyes":	{"NNS"},
"goodenia":	{"NN"},
"goodeniaceae":	{"NN"},
"goodies":	{"NNS"},
"goodish":	{"JJ"},
"goodlier":	{"JJR"},
"goodliest":	{"JJS"},
"goodly":	{"JJ"},
"goodman":	{"NN"},
"goodness":	{"NN"},
"goodnight":	{"UH"},
"goods":	{"NNS"},
"goods-producing":	{"JJ"},
"goodwill":	{"NN"},
"goody":	{"NN","UH"},
"goody-goodies":	{"NNS"},
"goody-goody":	{"JJ","NN"},
"goodyear":	{"NN"},
"goodyera":	{"NN"},
"gooey":	{"JJ"},
"goof":	{"VB","VBP","NN"},
"goof-off":	{"NN"},
"goof-offs":	{"NNS"},
"goof-proof":	{"NN"},
"goofball":	{"NN"},
"goofballs":	{"NNS"},
"goofed":	{"VBD","VBN"},
"goofier":	{"JJR"},
"goofiest":	{"JJS"},
"goofiness":	{"NN"},
"goofing":	{"VBG"},
"goofproof":	{"JJ"},
"goofs":	{"VBZ","NNS"},
"goofy":	{"JJ"},
"google":	{"VB","VBP","NN"},
"googled":	{"VBD","VBN"},
"googles":	{"VBZ","NNS"},
"googlies":	{"NNS"},
"googling":	{"VBG"},
"googly":	{"NN"},
"googol":	{"NN"},
"googolplex":	{"NN"},
"gooier":	{"JJR"},
"gooiest":	{"JJS"},
"gook":	{"NN"},
"goolick":	{"NN"},
"goon":	{"NN"},
"gooney":	{"NN"},
"goonie":	{"NN"},
"goons":	{"NNS"},
"goony":	{"NN"},
"goooolick":	{"NN"},
"goop":	{"NN"},
"goosander":	{"NN"},
"goose":	{"NN","VB","VBP"},
"goose-flesh":	{"NN"},
"goose-pimples":	{"NNS"},
"goose-step":	{"VB","VBP","NN"},
"goose-stepped":	{"VBD","VBN"},
"goose-stepping":	{"VBG"},
"goose-steps":	{"VBZ"},
"goose-tansy":	{"NN"},
"gooseberries":	{"NNS"},
"gooseberry":	{"NN"},
"goosebump":	{"NN"},
"goosebumps":	{"NNS"},
"goosed":	{"VBD","VBN"},
"goosefish":	{"NN"},
"gooseflesh":	{"NN"},
"goosefoot":	{"NN"},
"gooselike":	{"JJ"},
"gooseneck":	{"NN"},
"gooses":	{"VBZ","NNS"},
"goosey":	{"JJ"},
"gooshey":	{"JJ"},
"goosing":	{"VBG"},
"goosy":	{"JJ"},
"gop":	{"NN"},
"gopher":	{"NN"},
"gophers":	{"NNS"},
"gopherus":	{"NN"},
"gopherwood":	{"NN"},
"goral":	{"NN"},
"gorbachev-era":	{"NN"},
"gordius":	{"NN"},
"gore":	{"NN","VB","VBP"},
"gored":	{"VBN","VBD"},
"gores":	{"VBZ"},
"gorgas":	{"NNS"},
"gorge":	{"NN","VB","VBP","JJ"},
"gorged":	{"VBD","VBN"},
"gorgeous":	{"JJ"},
"gorgeously":	{"RB"},
"gorger":	{"NN"},
"gorgerin":	{"NN"},
"gorges":	{"NNS","VBZ"},
"gorget":	{"NN"},
"gorging":	{"VBG"},
"gorgon":	{"NN"},
"gorgonacea":	{"NN"},
"gorgoniacea":	{"NN"},
"gorgonian":	{"NN"},
"gorgonocephalus":	{"NNS"},
"gorgons":	{"NNS"},
"gorier":	{"JJR"},
"goriest":	{"JJS"},
"gorilla":	{"NN"},
"gorillas":	{"NNS"},
"goring":	{"VBG"},
"gorki":	{"NN"},
"gorkiy":	{"NN"},
"gorman":	{"NN"},
"gormandise":	{"VB","VBP"},
"gormandised":	{"VBD","VBN"},
"gormandiser":	{"NN"},
"gormandises":	{"VBZ"},
"gormandising":	{"VBG"},
"gormandize":	{"VB","VBP"},
"gormandized":	{"VBD","VBN"},
"gormandizer":	{"NN"},
"gormandizes":	{"VBZ"},
"gormandizing":	{"VBG"},
"gormless":	{"JJ"},
"gormlessly":	{"RB"},
"gormlessness":	{"NN"},
"gorse":	{"NN"},
"gorup":	{"NN"},
"gory":	{"JJ"},
"gosaimasu":	{"FW"},
"gosainthan":	{"NN"},
"gosan-chiku":	{"NN"},
"gosh":	{"UH"},
"goshawk":	{"NN"},
"goshen":	{"NN"},
"gosling":	{"NN"},
"goslings":	{"NNS"},
"gosmore":	{"NN"},
"gospel":	{"NN"},
"gospel-singer":	{"NN"},
"gospeler":	{"NN"},
"gospelers":	{"NNS"},
"gospeller":	{"NN"},
"gospels":	{"NNS"},
"gossamer":	{"NN"},
"gossip":	{"NN","VBP","VB"},
"gossiped":	{"VBD","VBN"},
"gossiper":	{"NN"},
"gossiping":	{"NN","VBG"},
"gossipmonger":	{"NN"},
"gossipmongering":	{"NN"},
"gossips":	{"VBZ","NNS"},
"gossipy":	{"JJ"},
"gossypium":	{"NN"},
"got":	{"VBD","VBN"},
"goteborg":	{"NN"},
"goth":	{"NN","JJ"},
"gothenburg":	{"NN"},
"gothite":	{"NN"},
"gott":	{"NN"},
"gotta":	{"NN","VBP","VBZ"},
"gotten":	{"VBN"},
"gotterdammerung":	{"NN"},
"gottlieb":	{"NN"},
"gouache":	{"NN"},
"gouda":	{"NN"},
"goudy":	{"NN"},
"gouge":	{"VB","VBP","NN"},
"gouged":	{"VBD","VBN"},
"gouger":	{"NN"},
"gougers":	{"NNS"},
"gouges":	{"VBZ","NNS"},
"gough":	{"NN"},
"gouging":	{"VBG","NN"},
"goujon":	{"NN"},
"goulash":	{"NN"},
"gouldoid":	{"JJ"},
"gounod":	{"NN"},
"gourd":	{"NN"},
"gourde":	{"NN"},
"gourds":	{"NNS"},
"gourmand":	{"NN"},
"gourmandism":	{"NN"},
"gourmandize":	{"VB"},
"gourmandizer":	{"NN"},
"gourmands":	{"NNS"},
"gourmet":	{"NN","JJ"},
"gourmet-food":	{"NN"},
"gourmets":	{"NNS"},
"gout":	{"NN"},
"goutte":	{"FW"},
"gouty":	{"JJ"},
"gouverne":	{"FW"},
"govern":	{"VB","VBP"},
"governable":	{"JJ"},
"governance":	{"NN"},
"governed":	{"VBD","VBN"},
"governess":	{"NN"},
"governesses":	{"NNS"},
"governing":	{"VBG","JJ"},
"government":	{"NN"},
"government-agency":	{"JJ","NN"},
"government-appointed":	{"JJ"},
"government-approved":	{"JJ"},
"government-assisted":	{"JJ"},
"government-backed":	{"JJ"},
"government-blessed":	{"JJ"},
"government-bond":	{"NN","JJ"},
"government-business":	{"NN"},
"government-certified":	{"JJ"},
"government-controlled":	{"JJ"},
"government-dominated":	{"JJ"},
"government-encouraged":	{"JJ"},
"government-funded":	{"JJ"},
"government-guaranteed":	{"JJ"},
"government-held":	{"JJ"},
"government-imposed":	{"JJ"},
"government-in-exile":	{"NN"},
"government-insured":	{"JJ"},
"government-leaked":	{"JJ"},
"government-managed":	{"JJ"},
"government-mandated":	{"JJ"},
"government-operated":	{"JJ"},
"government-orchestrated":	{"JJ"},
"government-ordered":	{"JJ"},
"government-owned":	{"JJ"},
"government-plus":	{"JJ"},
"government-provided":	{"JJ"},
"government-relations":	{"NNS"},
"government-run":	{"JJ"},
"government-sanctioned":	{"JJ"},
"government-securities":	{"NNS","JJ"},
"government-sponsored":	{"JJ"},
"government-subsidized":	{"JJ"},
"government-supported":	{"JJ"},
"government-to-government":	{"JJ"},
"governmental":	{"JJ"},
"governmental-affairs":	{"NNS","JJ"},
"governmentally":	{"RB"},
"governments":	{"NNS"},
"governor":	{"NN"},
"governor-elect":	{"NN"},
"governors":	{"NNS"},
"governors-association":	{"NN"},
"governorship":	{"NN"},
"governorships":	{"NNS"},
"governs":	{"VBZ"},
"gown":	{"NN","VB","VBP"},
"gowned":	{"VBD","VBN","JJ"},
"gowning":	{"VBG"},
"gowns":	{"NNS","VBZ"},
"goy":	{"NN"},
"gp":	{"NN"},
"gpa":	{"NN"},
"gpd":	{"NN"},
"gpo":	{"NN"},
"gps":	{"NNS"},
"grab":	{"VB","NN","VBP"},
"grab-bag":	{"NN"},
"grab-bags":	{"NNS"},
"grabbag":	{"NN"},
"grabbed":	{"VBD","VBN"},
"grabber":	{"NN"},
"grabbing":	{"VBG"},
"grabby":	{"JJ"},
"grabs":	{"NNS","VBZ"},
"grace":	{"NN","VB","VBP"},
"graced":	{"VBD","VBN"},
"graceful":	{"JJ"},
"gracefully":	{"RB"},
"gracefulness":	{"NN"},
"graceless":	{"JJ"},
"gracelessly":	{"RB"},
"gracelessness":	{"NN"},
"graces":	{"VBZ","NNS"},
"gracie":	{"NN"},
"gracilariid":	{"NN"},
"gracilariidae":	{"NN"},
"gracile":	{"JJ"},
"gracility":	{"NN"},
"gracillariidae":	{"NN"},
"gracing":	{"VBG"},
"gracious":	{"JJ"},
"graciously":	{"RB"},
"graciousness":	{"NN"},
"grackle":	{"NN"},
"gracula":	{"NN"},
"grad":	{"NN"},
"gradability":	{"NN"},
"gradable":	{"JJ"},
"gradate":	{"VB","VBP"},
"gradated":	{"VBD","VBN"},
"gradates":	{"VBZ"},
"gradating":	{"VBG"},
"gradation":	{"NN"},
"gradational":	{"JJ"},
"gradations":	{"NNS"},
"gradatory":	{"JJ"},
"grade":	{"NN","VB","VBP"},
"grade-A":	{"JJ"},
"grade-a":	{"JJ"},
"grade-appropriate":	{"JJ"},
"grade-constructed":	{"JJ"},
"grade-equivalent":	{"NN"},
"grade-equivalents":	{"NNS"},
"grade-school":	{"NN"},
"graded":	{"JJ","VBN","VBD"},
"grader":	{"NN"},
"graders":	{"NNS"},
"grades":	{"NNS","VBZ"},
"gradient":	{"NN"},
"gradients":	{"NNS"},
"grading":	{"NN","VBG"},
"grads":	{"NNS"},
"gradual":	{"JJ"},
"gradualism":	{"NN"},
"gradualist":	{"NN"},
"graduality":	{"NN"},
"gradually":	{"RB"},
"gradualness":	{"NN"},
"graduate":	{"NN","VB","JJ","VBP"},
"graduate-student":	{"NN"},
"graduated":	{"VBD","VBN","JJ"},
"graduates":	{"NNS","VBZ"},
"graduating":	{"VBG"},
"graduation":	{"NN"},
"graduations":	{"NNS"},
"graeco-roman":	{"JJ"},
"graecophile":	{"JJ","NN"},
"graecophilic":	{"JJ"},
"graffiti":	{"NN"},
"graffito":	{"NN"},
"graft":	{"NN","VB","VBP"},
"graft-riddled":	{"JJ"},
"grafted":	{"VBD","VBN"},
"grafting":	{"VBG"},
"grafts":	{"NNS","VBZ"},
"graham-flour-based":	{"JJ"},
"grail":	{"NN"},
"grain":	{"NN","VB","VBP"},
"grain-exporting":	{"NN"},
"grain-storage":	{"NN"},
"grain-trading":	{"JJ"},
"grained":	{"JJ","VBD","VBN"},
"grainfield":	{"NN"},
"grainger":	{"NN"},
"graininess":	{"NN"},
"graining":	{"VBG"},
"grains":	{"NNS","VBZ"},
"grainy":	{"JJ"},
"gram":	{"NN"},
"gram-negative":	{"JJ"},
"gram-positive":	{"JJ"},
"grama":	{"NN"},
"gramicidin":	{"NN"},
"graminaceae":	{"NN"},
"graminales":	{"NNS"},
"gramineae":	{"NN"},
"gramma":	{"NN"},
"grammar":	{"NN"},
"grammar-school":	{"NN"},
"grammar-schools":	{"NNS"},
"grammarian":	{"NN"},
"grammarians":	{"NNS"},
"grammars":	{"NNS"},
"grammatic":	{"JJ"},
"grammatical":	{"JJ"},
"grammatically":	{"RB"},
"grammatolatry":	{"NN"},
"grammatophyllum":	{"NN"},
"gramme":	{"NN"},
"gramophone":	{"NN"},
"gramophones":	{"NNS"},
"gramps":	{"NN"},
"grampus":	{"NN"},
"grams":	{"NNS"},
"gran":	{"NN"},
"granada":	{"NN"},
"granadilla":	{"NN"},
"granadillo":	{"NN"},
"granaries":	{"NNS"},
"granary":	{"NN","JJ"},
"grand":	{"JJ","NN","NNS"},
"grand-daughter":	{"NN"},
"grand-juries":	{"NNS"},
"grand-jury":	{"NN"},
"grand-looking":	{"JJ"},
"grand-prize":	{"NN"},
"grand-slam":	{"JJ","NN"},
"grand-slams":	{"NNS"},
"grandad":	{"NN"},
"grandaddies":	{"NNS"},
"grandaddy":	{"NN"},
"grandads":	{"NNS"},
"grandaunt":	{"NN"},
"grandchild":	{"NN"},
"grandchildren":	{"NNS"},
"granddad":	{"NN"},
"granddaddies":	{"NNS"},
"granddaddy":	{"NN"},
"granddads":	{"NNS"},
"granddaughter":	{"NN"},
"granddaughters":	{"NNS"},
"grandee":	{"NN"},
"grandees":	{"NNS"},
"grander":	{"JJR"},
"grandest":	{"JJS"},
"grandeur":	{"NN"},
"grandfather":	{"NN","VB","VBP"},
"grandfather-father-to-son":	{"JJ"},
"grandfathered":	{"VBD","VBN"},
"grandfathering":	{"VBG"},
"grandfathers":	{"NNS","VBZ"},
"grandiloquence":	{"NN"},
"grandiloquent":	{"JJ"},
"grandiloquently":	{"RB"},
"grandiose":	{"JJ"},
"grandiosely":	{"RB"},
"grandiosity":	{"NN"},
"grandkids":	{"NNS"},
"grandly":	{"RB"},
"grandma":	{"NN"},
"grandmas":	{"NNS"},
"grandmaster":	{"NN"},
"grandmasters":	{"NNS"},
"grandmother":	{"NN"},
"grandmotherly":	{"JJ"},
"grandmothers":	{"NNS"},
"grandnephew":	{"NN"},
"grandness":	{"NN"},
"grandniece":	{"NN"},
"grandpa":	{"NN"},
"grandparent":	{"NN"},
"grandparents":	{"NNS"},
"grandpas":	{"NNS"},
"grandson":	{"NN"},
"grandsons":	{"NNS"},
"grandstand":	{"NN","VB","VBP"},
"grandstanded":	{"VBD","VBN"},
"grandstander":	{"NN"},
"grandstanding":	{"NN","VBG"},
"grandstands":	{"NNS","VBZ"},
"granduncle":	{"NN"},
"grange":	{"NN"},
"granger":	{"NN"},
"granges":	{"NNS"},
"granicus":	{"NNS"},
"granite":	{"NN"},
"granitelike":	{"JJ"},
"granites":	{"NNS"},
"graniteware":	{"NN"},
"granitic":	{"JJ"},
"grannie":	{"NN","JJ"},
"grannies":	{"NNS"},
"granny":	{"NN","JJ"},
"granola":	{"NN"},
"grans":	{"NNS"},
"grant":	{"NN","VB","VBP"},
"grant-in-aid":	{"NN"},
"granted":	{"VBN","VBD","RB","IN"},
"grantee":	{"NN"},
"granter":	{"NN"},
"granth":	{"NN"},
"granting":	{"VBG"},
"grantor":	{"NN"},
"grantors":	{"NNS"},
"grants":	{"NNS","VBZ"},
"grants-in-aid":	{"NNS"},
"granular":	{"JJ"},
"granular-type":	{"JJ"},
"granularity":	{"NN"},
"granulate":	{"VB","VBP"},
"granulated":	{"JJ","VBD","VBN"},
"granulates":	{"VBZ"},
"granulating":	{"VBG"},
"granulation":	{"NN"},
"granule":	{"NN"},
"granules":	{"NNS"},
"granuliferous":	{"JJ"},
"granulocyte":	{"NN"},
"granulocyte-macrophage":	{"NN"},
"granulocytic":	{"JJ"},
"granulocytopenia":	{"NN"},
"granuloma":	{"NN"},
"granulomatous":	{"JJ"},
"granulose":	{"JJ"},
"granville-barker":	{"NN"},
"grape":	{"NN"},
"grape-arbor":	{"NN"},
"grape-shot":	{"NN"},
"grape-sized":	{"JJ"},
"grape-sugar":	{"NN"},
"grape-vine":	{"NN"},
"grapefruit":	{"NN","NNS"},
"grapefruits":	{"NNS"},
"grapelike":	{"JJ"},
"grapes":	{"NNS"},
"grapeshot":	{"NN"},
"grapevine":	{"NN"},
"grapevines":	{"NNS"},
"grapey":	{"JJ"},
"graph":	{"NN","VB","VBP"},
"graphed":	{"VBD","VBN"},
"grapheme":	{"NN"},
"graphic":	{"JJ"},
"graphic-arts":	{"NNS"},
"graphical":	{"JJ"},
"graphically":	{"RB"},
"graphics":	{"NNS"},
"graphing":	{"VBG"},
"graphite":	{"NN"},
"graphite-plastic":	{"JJ"},
"graphologist":	{"NN"},
"graphologists":	{"NNS"},
"graphology":	{"NN"},
"graphospasm":	{"NN"},
"graphs":	{"VBZ","NNS"},
"grapnel":	{"NN"},
"grapo":	{"NN"},
"grappa":	{"NN"},
"grappelli":	{"NN"},
"grapple":	{"VB","VBP"},
"grappled":	{"VBD","VBN"},
"grappler":	{"NN"},
"grapples":	{"VBZ"},
"grappling":	{"VBG"},
"grappling-hook":	{"NN"},
"grappling-hooks":	{"NNS"},
"grappling-iron":	{"NN"},
"grappling-irons":	{"NNS"},
"graptophyllum":	{"NN"},
"grapy":	{"NN"},
"gras":	{"NN"},
"grasp":	{"VB","NN","VBP"},
"graspable":	{"JJ"},
"grasped":	{"VBD","VBN"},
"grasping":	{"JJ","VBG"},
"grasps":	{"VBZ"},
"grass":	{"NN","VBP","VB"},
"grass-covered":	{"JJ"},
"grass-eating":	{"JJ"},
"grass-fed":	{"JJ"},
"grass-green":	{"JJ"},
"grass-of-parnassus":	{"NNS"},
"grass-roots":	{"JJ","NNS"},
"grassed":	{"VBD","VBN"},
"grassers":	{"NNS"},
"grasses":	{"NNS","VBZ"},
"grassfinch":	{"NN"},
"grassfire":	{"NN"},
"grasshopper":	{"NN"},
"grasshoppers":	{"NNS"},
"grassier":	{"JJR"},
"grassiest":	{"JJS"},
"grassing":	{"VBG"},
"grassland":	{"NN"},
"grassless":	{"JJ"},
"grasslike":	{"JJ"},
"grassroots":	{"JJ"},
"grassroots-fueled":	{"JJ"},
"grassy":	{"JJ"},
"grassy-leafed":	{"JJ"},
"grassy-leaved":	{"JJ"},
"grata":	{"NN"},
"grate":	{"VB","VBP","NN"},
"grated":	{"VBD","VBN"},
"grateful":	{"JJ"},
"gratefully":	{"RB"},
"gratefulness":	{"NN"},
"grater":	{"NN"},
"graters":	{"NNS"},
"grates":	{"VBZ","NNS"},
"graticule":	{"NN"},
"gratification":	{"NN"},
"gratified":	{"VBD","VBN"},
"gratifies":	{"VBZ"},
"gratify":	{"VB","VBP"},
"gratifying":	{"JJ","VBG"},
"gratifyingly":	{"RB"},
"grating":	{"JJ","NN","VBG"},
"gratingly":	{"RB"},
"gratings":	{"NNS"},
"gratis":	{"JJ","RB"},
"gratitude":	{"NN"},
"gratuities":	{"NNS"},
"gratuitous":	{"JJ"},
"gratuitously":	{"RB"},
"gratuity":	{"NN"},
"gratulatory":	{"JJ"},
"graunt":	{"VB","VBP"},
"graunted":	{"VBD","VBN"},
"graunting":	{"VBG"},
"graunts":	{"VBZ"},
"grave":	{"NN","JJ","VB","VBP"},
"graved":	{"VBD","VBN"},
"gravedigger":	{"NN"},
"gravediggers":	{"NNS"},
"gravel":	{"NN","VB","VBP"},
"gravel-chewing":	{"JJ"},
"gravel-voiced":	{"JJ"},
"graveled":	{"VBD","VBN"},
"graveling":	{"VBG"},
"gravelled":	{"VBD","VBN"},
"gravelling":	{"VBG"},
"gravelly":	{"JJ"},
"gravels":	{"VBZ"},
"gravelweed":	{"NN"},
"gravely":	{"RB"},
"graven":	{"JJ"},
"graveness":	{"NN"},
"graver":	{"NN","JJR"},
"graverobber":	{"NN"},
"graves":	{"NNS","VBZ"},
"gravest":	{"JJS"},
"gravestone":	{"NN"},
"gravestones":	{"NNS"},
"graveyard":	{"NN"},
"graveyards":	{"NNS"},
"gravid":	{"JJ"},
"gravida":	{"NN"},
"gravidation":	{"NN"},
"gravidity":	{"NN"},
"gravidness":	{"NN"},
"gravies":	{"NNS"},
"gravimeter":	{"NN"},
"gravimetric":	{"JJ"},
"gravimetry":	{"NN"},
"graving":	{"NN","VBG"},
"gravitas":	{"NN"},
"gravitate":	{"VB","VBP"},
"gravitated":	{"VBD","VBN"},
"gravitates":	{"VBZ"},
"gravitating":	{"VBG"},
"gravitation":	{"NN"},
"gravitational":	{"JJ"},
"gravitationally":	{"RB"},
"gravitative":	{"JJ"},
"graviton":	{"NN"},
"gravity":	{"NN"},
"gravity-assist":	{"NN"},
"gravure":	{"NN"},
"gravy":	{"NN"},
"gray":	{"JJ","NN","VB","VBP"},
"gray-backs":	{"NNS"},
"gray-beard":	{"JJ"},
"gray-bearded":	{"JJ"},
"gray-black":	{"JJ"},
"gray-blue":	{"JJ"},
"gray-brown":	{"JJ"},
"gray-flannel":	{"JJ","NN"},
"gray-green":	{"JJ"},
"gray-haired":	{"JJ"},
"gray-headed":	{"JJ"},
"gray-looking":	{"JJ"},
"gray-market":	{"JJ"},
"gray-pink":	{"JJ"},
"gray-thatched":	{"JJ"},
"gray-white":	{"JJ"},
"grayback":	{"NN"},
"graybeard":	{"NN"},
"graybeards":	{"NNS"},
"grayed":	{"VBD","VBN"},
"grayer":	{"JJ","NN"},
"grayhen":	{"NN"},
"graying":	{"VBG","NN"},
"grayish":	{"JJ"},
"grayish-black":	{"JJ"},
"grayish-blue":	{"JJ"},
"grayish-brown":	{"JJ"},
"grayish-green":	{"JJ"},
"grayish-pink":	{"JJ"},
"grayish-white":	{"JJ"},
"graylag":	{"NN"},
"grayly":	{"RB"},
"grayness":	{"NN"},
"grays":	{"VBZ","NNS"},
"graz":	{"NN"},
"graze":	{"VB","VBP","NN"},
"grazed":	{"VBD","VBN","JJ"},
"grazer":	{"NN"},
"grazers":	{"NNS"},
"grazes":	{"VBZ","NNS"},
"grazier":	{"NN"},
"graziery":	{"NN"},
"grazing":	{"NN","VBG"},
"grease":	{"NN","VB","VBP"},
"grease-gun":	{"NN"},
"grease-paint":	{"NN"},
"grease-proof":	{"JJ"},
"grease-removal":	{"JJ"},
"greaseball":	{"NN"},
"greased":	{"VBD","VBN"},
"greasepaint":	{"NN"},
"greaseproof":	{"JJ"},
"greaser":	{"NN"},
"greases":	{"VBZ"},
"greasewood":	{"NN"},
"greasier":	{"JJR"},
"greasiest":	{"JJS"},
"greasily":	{"RB"},
"greasiness":	{"NN"},
"greasing":	{"VBG"},
"greasy":	{"JJ"},
"great":	{"JJ","NN"},
"great-aunt":	{"NN"},
"great-grandchildren":	{"NNS"},
"great-grandfather":	{"NN"},
"great-grandmother":	{"NN"},
"great-grandparent":	{"NN"},
"great-grandparents":	{"NNS"},
"great-grandson":	{"NN"},
"great-great-grandfather":	{"JJ","NN"},
"great-nephew":	{"NN"},
"great-niece":	{"NN"},
"great-nieces":	{"NNS"},
"great-quality":	{"NN"},
"great-uncle":	{"NN"},
"great-uncles":	{"NNS"},
"greatcoat":	{"NN"},
"greatcoated":	{"JJ"},
"greatcoats":	{"NNS"},
"greate":	{"JJ"},
"greaten":	{"VB","VBP"},
"greatened":	{"VBD","VBN"},
"greatening":	{"VBG"},
"greatens":	{"VBZ"},
"greater":	{"JJR"},
"greater-fool":	{"JJ"},
"greater-than-expected":	{"JJ"},
"greatest":	{"JJS"},
"greathearted":	{"JJ"},
"greatly":	{"RB"},
"greatness":	{"NN"},
"greats":	{"NNS"},
"greave":	{"NN"},
"greaves":	{"NNS"},
"grebe":	{"NN"},
"grebes":	{"NNS"},
"greco-roman":	{"JJ"},
"greed":	{"NN"},
"greedier":	{"JJR"},
"greediest":	{"JJS"},
"greedily":	{"RB"},
"greediness":	{"NN"},
"greedy":	{"JJ"},
"greegree":	{"NN"},
"greek-born":	{"JJ"},
"greek-canadian":	{"JJ"},
"greek-speaking":	{"JJ"},
"greeley":	{"NN"},
"green":	{"JJ","NN","VB","VBP"},
"green-blind":	{"JJ"},
"green-blindness":	{"NN"},
"green-brown":	{"JJ"},
"green-bugs":	{"NNS"},
"green-eyed":	{"JJ"},
"green-labeled":	{"JJ"},
"green-lipped":	{"JJ"},
"green-scaled":	{"JJ"},
"green-tinted":	{"JJ"},
"green-white":	{"JJ"},
"greenback":	{"NN"},
"greenbacks":	{"NNS"},
"greenbelt":	{"NN"},
"greenberg":	{"NN"},
"greenbottle":	{"NN"},
"greenbrier":	{"NN"},
"greened":	{"VBD","VBN"},
"greener":	{"JJR"},
"greenery":	{"NN"},
"greenest":	{"JJS"},
"greeneye":	{"NN"},
"greenfield":	{"JJ"},
"greenflies":	{"NNS"},
"greenfly":	{"NN","NNS"},
"greengage":	{"NN"},
"greengages":	{"NNS"},
"greengrocer":	{"NN"},
"greengrocers":	{"NNS"},
"greengrocery":	{"NN"},
"greenhood":	{"NN"},
"greenhorn":	{"NN"},
"greenhorns":	{"NNS"},
"greenhouse":	{"NN","JJ"},
"greenhouse-effect":	{"JJ"},
"greenhouse-gas":	{"NN"},
"greenhouse-gases":	{"NNS"},
"greenhouse-produced":	{"JJ"},
"greenhouses":	{"NNS"},
"greening":	{"NN","VBG"},
"greenish":	{"JJ"},
"greenish-brown":	{"JJ"},
"greenish-gray":	{"JJ"},
"greenish-grey":	{"JJ"},
"greenish-white":	{"JJ"},
"greenishness":	{"NN"},
"greenlight":	{"VB","VBP"},
"greenlighted":	{"VBD","VBN"},
"greenlighting":	{"VBG"},
"greenlights":	{"VBZ"},
"greenling":	{"NN"},
"greenlit":	{"VBD","VBN"},
"greenly":	{"RB"},
"greenmail":	{"NN"},
"greenmailer":	{"NN"},
"greenmarket":	{"NN"},
"greenness":	{"NN"},
"greenockite":	{"NN"},
"greenpeace":	{"NN"},
"greenroom":	{"NN"},
"greenrooms":	{"NNS"},
"greens":	{"NNS","VBZ"},
"greensand":	{"NN"},
"greenshank":	{"NN"},
"greensick":	{"JJ"},
"greensickness":	{"NN"},
"greenside":	{"JJ"},
"greenskeeper":	{"NN"},
"greensward":	{"NN"},
"greenville":	{"NN"},
"greenware":	{"NN"},
"greenway":	{"NN"},
"greenweed":	{"NN"},
"greenwing":	{"NN"},
"greenwood":	{"NN"},
"greet":	{"VB","VBP"},
"greeted":	{"VBN","VBD"},
"greeter":	{"NN"},
"greeters":	{"NNS"},
"greeting":	{"NN","VBG"},
"greetings":	{"NNS"},
"greets":	{"VBZ"},
"gregarine":	{"NN"},
"gregarinida":	{"NN"},
"gregarious":	{"JJ"},
"gregariously":	{"RB"},
"gregariousness":	{"NN"},
"gregg":	{"NN"},
"greisen":	{"NN"},
"gremlin":	{"NN"},
"gremlins":	{"NNS"},
"grenade":	{"NN"},
"grenades":	{"NNS"},
"grenadier":	{"NN"},
"grenadiers":	{"NNS"},
"grenadine":	{"NN"},
"gres-gris":	{"NN"},
"gresham":	{"NN"},
"gret":	{"JJ"},
"gretzky":	{"NN"},
"grevillea":	{"NN"},
"grevouselye":	{"RB"},
"grew":	{"VBD"},
"grewia":	{"NN"},
"grey":	{"JJ","NN","VBP","VB"},
"grey-black":	{"JJ"},
"grey-blue":	{"JJ"},
"grey-brown":	{"JJ"},
"grey-green":	{"JJ"},
"grey-haired":	{"JJ"},
"grey-headed":	{"JJ"},
"grey-pink":	{"JJ"},
"grey-skied":	{"JJ"},
"grey-white":	{"JJ"},
"greyback":	{"NN"},
"greybeard":	{"NN"},
"greyed":	{"VBN","VBD"},
"greyhen":	{"NN"},
"greyhound":	{"NN"},
"greyhounds":	{"NNS"},
"greying":	{"JJ","NN","VBG"},
"greyish":	{"JJ"},
"greyish-black":	{"JJ"},
"greyish-blue":	{"JJ"},
"greyish-brown":	{"JJ"},
"greyish-green":	{"JJ"},
"greyish-pink":	{"JJ"},
"greyish-white":	{"JJ"},
"greylag":	{"NN"},
"greyly":	{"RB"},
"greyness":	{"NN"},
"greys":	{"VBZ","NNS"},
"gri-gri":	{"NN"},
"grias":	{"NN"},
"grid":	{"NN"},
"griddle":	{"NN","VB","VBP"},
"griddlecake":	{"NN"},
"griddled":	{"VBD","VBN"},
"griddles":	{"NNS","VBZ"},
"griddling":	{"VBG"},
"gridiron":	{"NN"},
"gridlike":	{"JJ"},
"gridlock":	{"NN"},
"gridlocked":	{"JJ"},
"grids":	{"NNS"},
"grief":	{"NN"},
"grief-stricken":	{"JJ"},
"grievance":	{"NN"},
"grievances":	{"NNS"},
"grieve":	{"VB","VBP"},
"grieved":	{"VBN","JJ","VBD"},
"griever":	{"NN"},
"grieves":	{"VBZ"},
"grieving":	{"VBG"},
"grievous":	{"JJ"},
"grievously":	{"RB"},
"griffin":	{"NN"},
"griffins":	{"NNS"},
"griffon":	{"NN"},
"grifter":	{"NN"},
"grifters":	{"NNS"},
"grigri":	{"NN"},
"grill":	{"NN","VB","VBP"},
"grill-room":	{"NN"},
"grill-rooms":	{"NNS"},
"grille":	{"NN"},
"grille-route":	{"NN"},
"grilled":	{"JJ","VBD","VBN"},
"grilled-chicken":	{"JJ"},
"grilles":	{"NNS"},
"grillework":	{"NN"},
"grilling":	{"NN","VBG"},
"grillings":	{"NNS"},
"grillroom":	{"NN"},
"grillrooms":	{"NNS"},
"grills":	{"NNS","VBZ"},
"grillwork":	{"NN"},
"grillworks":	{"NNS"},
"grillz":	{"NN"},
"grim":	{"JJ"},
"grimace":	{"VB","VBP","NN"},
"grimaced":	{"VBD","VBN"},
"grimaces":	{"VBZ","NNS"},
"grimacing":	{"VBG"},
"grime":	{"NN","VB","VBP"},
"grimed":	{"VBN","VBD"},
"grimes":	{"VBZ"},
"grimier":	{"JJR"},
"grimiest":	{"JJS"},
"griminess":	{"NN"},
"griming":	{"VBG"},
"grimly":	{"RB"},
"grimmer":	{"JJR"},
"grimmest":	{"JJS"},
"grimness":	{"NN"},
"grimoire":	{"NN"},
"grimy":	{"JJ"},
"grin":	{"NN","VB","VBP"},
"grind":	{"VB","VBP","NN"},
"grindcore":	{"NN"},
"grindelia":	{"NN"},
"grinder":	{"NN"},
"grinders":	{"NNS"},
"grinding":	{"JJ","VBG","NN"},
"grindingly":	{"RB"},
"grindings":	{"NNS"},
"grindle":	{"NN"},
"grinds":	{"VBZ","NNS"},
"grindstone":	{"NN"},
"grindstones":	{"NNS"},
"gringo":	{"NN"},
"gringos":	{"NNS"},
"grinned":	{"VBD","VBN"},
"grinner":	{"NN"},
"grinning":	{"NN","VBG"},
"grins":	{"NNS","VBZ"},
"griot":	{"NN"},
"grip":	{"NN","VBP","VB"},
"gripe":	{"NN","VB","VBP"},
"griped":	{"VBD","VBN"},
"gripes":	{"NNS","VBZ"},
"griping":	{"JJ","VBG"},
"grippe":	{"NN"},
"gripped":	{"VBD","VBN"},
"gripping":	{"JJ","NN","VBG"},
"grips":	{"NNS","VBZ"},
"gripsack":	{"NN"},
"grisaille":	{"NN"},
"griselinia":	{"NN"},
"griseofulvin":	{"NN"},
"grisha-class":	{"JJ"},
"grislier":	{"JJR"},
"grisliest":	{"JJS"},
"grisly":	{"JJ"},
"grison":	{"NN"},
"grissino":	{"NN"},
"grist":	{"NN"},
"gristle":	{"NN"},
"gristly":	{"JJ"},
"gristmill":	{"NN"},
"griswold":	{"NN"},
"grit":	{"NN","VB","VBP"},
"grit-impregnated":	{"JJ"},
"gritrock":	{"NN"},
"grits":	{"NNS","VBZ"},
"gritstone":	{"NN"},
"gritted":	{"VBD","VBN"},
"grittier":	{"JJR"},
"grittiest":	{"JJS"},
"gritting":	{"VBG"},
"gritty":	{"JJ"},
"gritty-eyed":	{"JJ"},
"grivet":	{"NN"},
"grizzle":	{"VB","VBP"},
"grizzled":	{"JJ","VBD","VBN"},
"grizzles":	{"VBZ"},
"grizzlies":	{"NNS"},
"grizzling":	{"VBG"},
"grizzly":	{"NN","JJ"},
"groak":	{"VB","VBP"},
"groaked":	{"VBD","VBN"},
"groaker":	{"NN"},
"groakers":	{"NNS"},
"groaking":	{"VBG"},
"groaks":	{"VBZ"},
"groan":	{"NN","VB","VBP"},
"groaned":	{"VBD","VBN"},
"groaner":	{"NN"},
"groaning":	{"VBG"},
"groans":	{"NNS","VBZ"},
"groat":	{"NN"},
"groats":	{"NNS"},
"grocer":	{"NN"},
"groceries":	{"NNS"},
"grocers":	{"NNS"},
"grocery":	{"NN"},
"grocery-products":	{"NNS"},
"grocery-store":	{"JJ"},
"groenendael":	{"NN"},
"groenlandia":	{"NN"},
"grog":	{"NN"},
"groggier":	{"JJR"},
"groggiest":	{"JJS"},
"groggily":	{"RB"},
"grogginess":	{"NN"},
"groggy":	{"JJ"},
"grogram":	{"NN"},
"groid":	{"NN"},
"groids":	{"NNS"},
"groin":	{"NN","VB","VBP"},
"groined":	{"VBD","VBN"},
"groining":	{"VBG"},
"groins":	{"NNS","VBZ"},
"grok":	{"VB","VBP"},
"grokked":	{"VBD","VBN"},
"grokking":	{"VBG"},
"groks":	{"VBZ"},
"grommet":	{"NN"},
"grommets":	{"NNS"},
"gromwell":	{"NN"},
"gromyko":	{"NN"},
"gronland":	{"NN"},
"groom":	{"NN","VB","VBP"},
"groom-to-be":	{"NN"},
"groomed":	{"VBD","VBN","JJ"},
"grooming":	{"NN","VBG"},
"grooms":	{"NNS","VBZ"},
"groomsman":	{"NN"},
"groomsmen":	{"NNS"},
"groove":	{"NN","VB","VBP"},
"grooved":	{"JJ","VBD","VBN"},
"groover":	{"NN"},
"grooves":	{"NNS","VBZ"},
"groovier":	{"JJR"},
"grooviest":	{"JJS"},
"grooving":	{"VBG"},
"groovy":	{"JJ"},
"grope":	{"VB","VBP","NN"},
"groped":	{"VBD","VBN"},
"gropes":	{"VBZ","NNS"},
"groping":	{"NN","VBG"},
"gropingly":	{"RB"},
"gropings":	{"NNS"},
"gropius":	{"NN"},
"grosbeak":	{"NN"},
"groschen":	{"NN","NNS"},
"grosgrain":	{"NN"},
"gross":	{"JJ","NN","NNS","VB","VBP","RB"},
"gross-income":	{"NN"},
"gross-profit":	{"NN"},
"grossbeak":	{"NN"},
"grossed":	{"VBD","VBN"},
"grosser":	{"JJR"},
"grosses":	{"NNS","VBZ"},
"grossest":	{"JJS"},
"grossing":	{"VBG"},
"grossly":	{"RB"},
"grossness":	{"NN"},
"grossulariaceae":	{"NN"},
"grosz":	{"NN"},
"grot":	{"NN"},
"grotesque":	{"JJ","NN"},
"grotesquely":	{"RB"},
"grotesqueness":	{"NN"},
"grotesquerie":	{"NN"},
"grotesquery":	{"NN"},
"grotesques":	{"NNS"},
"grotius":	{"NN"},
"grottier":	{"JJR"},
"grottiest":	{"JJS"},
"grotto":	{"NN"},
"grottoes":	{"NNS"},
"grottos":	{"NNS"},
"grotty":	{"JJ"},
"grouch":	{"NN","VB","VBP"},
"grouched":	{"VBD","VBN"},
"grouches":	{"NNS","VBZ"},
"grouchier":	{"JJR"},
"grouchiest":	{"JJS"},
"grouchily":	{"RB"},
"grouching":	{"VBG"},
"groucho":	{"NN"},
"grouchy":	{"JJ"},
"ground":	{"NN","VBD","VBN","VB","VBP","JJ"},
"ground-bait":	{"NN"},
"ground-based":	{"JJ"},
"ground-berry":	{"NN"},
"ground-cargo":	{"NN"},
"ground-floor":	{"JJ"},
"ground-glass":	{"JJ"},
"ground-handling":	{"NNS","NN"},
"ground-hugging":	{"JJ"},
"ground-launched":	{"JJ"},
"ground-level":	{"NN"},
"ground-plan":	{"NN"},
"ground-plans":	{"NNS"},
"ground-rent":	{"NN"},
"ground-rents":	{"NNS"},
"ground-shaker":	{"NN"},
"ground-support":	{"JJ"},
"ground-swell":	{"NN"},
"ground-truck":	{"NN"},
"ground-water":	{"NN"},
"groundball":	{"NN"},
"groundberry":	{"NN"},
"groundbreaker":	{"NN"},
"groundbreakers":	{"NNS"},
"groundbreaking":	{"JJ"},
"groundcover":	{"NN"},
"grounded":	{"JJ","VBD","VBN"},
"grounder":	{"NN"},
"grounders":	{"NNS"},
"groundfish":	{"NN"},
"groundhog":	{"NN"},
"groundhogs":	{"NNS"},
"grounding":	{"NN","VBG"},
"groundkeeper":	{"NN"},
"groundless":	{"JJ"},
"groundlessly":	{"RB"},
"groundlessness":	{"NN"},
"groundling":	{"NN"},
"groundmass":	{"NN"},
"groundnut":	{"NN"},
"groundnuts":	{"NNS"},
"grounds":	{"NNS","VBZ"},
"grounds-care":	{"JJ"},
"groundsel":	{"NN"},
"groundsheet":	{"NN"},
"groundsheets":	{"NNS"},
"groundskeeper":	{"NN"},
"groundskeepers":	{"NNS"},
"groundsman":	{"NN"},
"groundsmen":	{"NNS"},
"groundspeed":	{"NN"},
"groundswell":	{"NN"},
"groundup":	{"JJ"},
"groundwater":	{"NN"},
"groundwave":	{"NN"},
"groundwork":	{"NN"},
"group":	{"NN","VB","VBP"},
"group-health":	{"NN"},
"group-identities":	{"NNS"},
"group-identity":	{"NN"},
"group-of-seven":	{"NN"},
"grouped":	{"VBD","VBN"},
"grouper":	{"NN"},
"groupie":	{"NN"},
"groupies":	{"NNS"},
"grouping":	{"NN","VBG"},
"groupings":	{"NNS"},
"groups":	{"NNS","VBZ"},
"groupthink":	{"NN"},
"groupware":	{"NN"},
"grouse":	{"NN","NNS","VB","VBP"},
"grouse-berry":	{"NN"},
"grouseberry":	{"NN"},
"groused":	{"VBD","VBN"},
"grouses":	{"NNS","VBZ"},
"grousing":	{"VBG"},
"grout":	{"NN","VB","VBP"},
"grouted":	{"VBD","VBN"},
"grouting":	{"VBG"},
"grouts":	{"VBZ"},
"grove":	{"NN"},
"grovel":	{"VB","VBP"},
"groveled":	{"VBD","VBN"},
"groveler":	{"NN"},
"grovelike":	{"JJ"},
"groveling":	{"JJ","VBG"},
"grovelled":	{"VBD","VBN"},
"groveller":	{"NN"},
"grovelling":	{"JJ","VBG"},
"grovels":	{"VBZ"},
"grover":	{"NN"},
"groves":	{"NNS"},
"grow":	{"VB","VBP"},
"grow-or-die":	{"JJ"},
"grower":	{"NN"},
"growers":	{"NNS"},
"growing":	{"VBG","JJ"},
"growing-waiting":	{"NN"},
"growl":	{"NN","VB","VBP"},
"growled":	{"VBD","VBN"},
"growler":	{"NN"},
"growling":	{"VBG"},
"growls":	{"NNS","VBZ"},
"grown":	{"VBN","JJ"},
"grown-up":	{"JJ","NN"},
"grown-ups":	{"NNS"},
"grownup":	{"NN"},
"grownups":	{"NNS"},
"grows":	{"VBZ"},
"growth":	{"NN","JJ"},
"growth-and-income":	{"JJ"},
"growth-controlling":	{"JJ"},
"growth-fund":	{"NN"},
"growth-minded":	{"JJ"},
"growth-oriented":	{"JJ"},
"growth-stock":	{"JJ","NN"},
"growth-stunting":	{"JJ"},
"growth-suppressing":	{"JJ"},
"growths":	{"NNS"},
"growthy":	{"JJ"},
"groyne":	{"NN"},
"groynes":	{"NNS"},
"grub":	{"NN","VB","VBP"},
"grubbed":	{"VBD","VBN"},
"grubbier":	{"JJR"},
"grubbiest":	{"JJS"},
"grubbily":	{"RB"},
"grubbiness":	{"NN"},
"grubbing":	{"VBG"},
"grubby":	{"JJ"},
"grubs":	{"NNS","VBZ"},
"grubstake":	{"NN"},
"grudge":	{"VB","VBP","NN"},
"grudged":	{"VBD","VBN"},
"grudges":	{"VBZ","NNS"},
"grudging":	{"JJ","VBG"},
"grudgingly":	{"RB"},
"gruel":	{"NN"},
"grueling":	{"JJ"},
"gruelling":	{"JJ"},
"gruesome":	{"JJ"},
"gruesomely":	{"RB"},
"gruesomeness":	{"NN"},
"gruff":	{"JJ"},
"gruffly":	{"RB"},
"gruffness":	{"NN"},
"grugru":	{"NN"},
"gruidae":	{"NN"},
"gruiformes":	{"NNS"},
"gruit":	{"NN"},
"gruits":	{"NNS"},
"grumble":	{"VB","VBP","NN"},
"grumbled":	{"VBD","VBN"},
"grumbler":	{"NN"},
"grumbles":	{"VBZ","NNS"},
"grumbling":	{"JJ","NN","VBG"},
"grumblings":	{"NNS"},
"grume":	{"NN"},
"grummet":	{"NN"},
"grumose":	{"JJ"},
"grumous":	{"JJ"},
"grump":	{"NN","VB","VBP"},
"grumped":	{"VBD","VBN"},
"grumpier":	{"JJR"},
"grumpiest":	{"JJS"},
"grumpily":	{"RB"},
"grumpiness":	{"NN"},
"grumping":	{"VBG"},
"grumps":	{"NNS","VBZ"},
"grumpy":	{"JJ"},
"grundyism":	{"NN"},
"grunge":	{"NN"},
"grungily":	{"RB"},
"grungy":	{"JJ"},
"grunt":	{"NN","VB","VBP"},
"grunt-hoot":	{"VB"},
"grunted":	{"VBD","VBN"},
"grunter":	{"NN"},
"grunting":	{"VBG"},
"gruntle":	{"VB","VBP"},
"gruntled":	{"VBD","VBN"},
"gruntles":	{"VBZ"},
"gruntling":	{"VBG"},
"grunts":	{"NNS","VBZ"},
"grupera":	{"NN"},
"grus":	{"NN"},
"gruyere":	{"NN"},
"gryllidae":	{"NN"},
"gryphon":	{"NN"},
"gsa":	{"NN"},
"gspc":	{"NN"},
"gsr":	{"NN"},
"gu":	{"JJ","NN"},
"guacamole":	{"NN"},
"guacharo":	{"NN"},
"guadalajara":	{"NN"},
"guaiac":	{"NN"},
"guaiacum":	{"NN"},
"guaira":	{"NN"},
"guallatiri":	{"NN"},
"guama":	{"NN"},
"guan":	{"NN"},
"guanabana":	{"NN"},
"guanabenz":	{"NN"},
"guanaco":	{"NN"},
"guangdong":	{"NN"},
"guanidine":	{"NN"},
"guanine":	{"NN"},
"guano":	{"NN"},
"guanosine":	{"NN"},
"guantanamo":	{"NN"},
"guar":	{"NN"},
"guarani":	{"NN"},
"guarantee":	{"NN","VB","VBP"},
"guaranteed":	{"VBN","VBD","JJ"},
"guaranteed-neutral":	{"JJ"},
"guaranteeing":	{"VBG"},
"guarantees":	{"NNS","VBZ"},
"guarantied":	{"VBD","VBN"},
"guaranties":	{"NNS","VBZ"},
"guarantor":	{"NN"},
"guarantors":	{"NNS"},
"guaranty":	{"NN","VB","VBP"},
"guarantying":	{"VBG"},
"guard":	{"NN","VB","VBP"},
"guard-room":	{"NN"},
"guardant":	{"JJ"},
"guarded":	{"JJ","VBD","VBN"},
"guardedly":	{"RB"},
"guardedness":	{"NN"},
"guardhouse":	{"NN"},
"guardhouses":	{"NNS"},
"guardian":	{"NN"},
"guardians":	{"NNS"},
"guardianship":	{"NN"},
"guarding":	{"VBG"},
"guardrail":	{"NN"},
"guardrails":	{"NNS"},
"guardroom":	{"NN"},
"guardrooms":	{"NNS"},
"guards":	{"NNS","VBZ"},
"guardsman":	{"NN"},
"guardsmen":	{"NNS"},
"guarneri":	{"NN"},
"guarnerius":	{"NNS"},
"guarnieri":	{"NN"},
"guava":	{"NN"},
"guavas":	{"NNS"},
"guayaquil":	{"NN"},
"guayule":	{"NN"},
"gubbins":	{"NN","NNS"},
"gubernatorial":	{"JJ"},
"gucci":	{"NN"},
"guck":	{"NN"},
"gudgeon":	{"NN"},
"guenevere":	{"NN"},
"guenon":	{"NN"},
"guerdon":	{"NN"},
"guereza":	{"NN"},
"gueridon":	{"NN"},
"guerilla":	{"NN","JJ"},
"guerrilla":	{"NN"},
"guerrilla-held":	{"JJ"},
"guerrillas":	{"NNS"},
"guess":	{"VBP","NN","VB"},
"guessed":	{"VBD","VBN"},
"guesser":	{"NN"},
"guesses":	{"NNS","VBZ"},
"guessing":	{"VBG"},
"guesstimate":	{"NN"},
"guesstimates":	{"NNS"},
"guesswork":	{"NN"},
"guest":	{"NN","JJ","VB","VBP"},
"guested":	{"VBD","VBN"},
"guesthouse":	{"NN"},
"guesthouses":	{"NNS"},
"guestimate":	{"NN"},
"guesting":	{"VBG"},
"guestroom":	{"NN"},
"guests":	{"NNS","VBZ"},
"guestworker":	{"NN"},
"guevina":	{"NN"},
"guff":	{"NN"},
"guffaw":	{"VB","VBP","NN"},
"guffawed":	{"VBD","VBN"},
"guffawing":	{"VBG"},
"guffaws":	{"VBZ","NNS"},
"guggenheim":	{"NN"},
"guggle":	{"VB","VBP"},
"guggled":	{"VBD","VBN"},
"guggles":	{"VBZ"},
"guggling":	{"VBG"},
"gui":	{"NN"},
"guib":	{"NN"},
"guidance":	{"NN"},
"guide":	{"NN","VB","VBP"},
"guide-dog":	{"NN"},
"guide-dogs":	{"NNS"},
"guide-line":	{"NN"},
"guide-lines":	{"NNS"},
"guideboard":	{"NN"},
"guidebook":	{"NN"},
"guidebooks":	{"NNS","VBZ"},
"guided":	{"VBN","VBD","JJ"},
"guided-missile":	{"NN"},
"guided-missiles":	{"NNS"},
"guideline":	{"NN"},
"guidelines":	{"NNS"},
"guidepost":	{"NN"},
"guideposts":	{"NNS"},
"guides":	{"NNS","VBZ"},
"guidewheels":	{"NNS"},
"guideword":	{"NN"},
"guiding":	{"JJ","VBG"},
"guild":	{"NN"},
"guilder":	{"NN"},
"guilders":	{"NNS"},
"guildhall":	{"NN"},
"guildhalls":	{"NNS"},
"guilds":	{"NNS"},
"guile":	{"NN"},
"guileful":	{"JJ"},
"guilefully":	{"RB"},
"guilefulness":	{"NN"},
"guileless":	{"JJ"},
"guilelessly":	{"RB"},
"guillemot":	{"NN"},
"guilloche":	{"NN"},
"guillotine":	{"NN","VB","VBP"},
"guillotined":	{"VBD","VBN"},
"guillotines":	{"NNS","VBZ"},
"guillotining":	{"VBG"},
"guilt":	{"NN"},
"guilt-ridden":	{"JJ"},
"guiltier":	{"JJR"},
"guiltiest":	{"JJS"},
"guiltily":	{"RB"},
"guiltiness":	{"NN"},
"guiltless":	{"JJ"},
"guiltlessness":	{"NN"},
"guilty":	{"JJ"},
"guimpe":	{"NN"},
"guinea":	{"NN"},
"guineas":	{"NNS"},
"guise":	{"NN"},
"guises":	{"NNS"},
"guitar":	{"NN"},
"guitar-shaped":	{"JJ"},
"guitar-strumming":	{"VBG"},
"guitar-twanging":	{"JJ"},
"guitarfish":	{"NN"},
"guitarist":	{"NN"},
"guitarists":	{"NNS"},
"guitars":	{"NNS"},
"gujarat":	{"NN"},
"gujarati":	{"NN"},
"gujerat":	{"NN"},
"gujerati":	{"NN"},
"gula":	{"NN"},
"gulag":	{"NN"},
"gulags":	{"NNS"},
"gulch":	{"NN"},
"gulches":	{"NNS"},
"gulden":	{"NN","NNS"},
"guldens":	{"NNS"},
"gulf":	{"NN"},
"gulfs":	{"NNS"},
"gulfstream":	{"NN"},
"gulfweed":	{"NN"},
"gull":	{"NN","VB","VBP"},
"gulled":	{"VBD","VBN"},
"gullet":	{"NN"},
"gullets":	{"NNS"},
"gulley":	{"NN"},
"gullibility":	{"NN"},
"gullible":	{"JJ"},
"gullied":	{"VBD","VBN"},
"gullies":	{"NNS","VBZ"},
"gulling":	{"VBG"},
"gulliver":	{"NN"},
"gulls":	{"NNS","VBZ"},
"gully":	{"NN","VB","VBP"},
"gullying":	{"VBG"},
"gulo":	{"NN"},
"gulp":	{"NN","VB","VBP"},
"gulped":	{"VBD","VBN"},
"gulper":	{"NN"},
"gulping":	{"NN","VBG"},
"gulps":	{"NNS","VBZ"},
"gulu":	{"NN"},
"gum":	{"NN","VB","VBP"},
"gum-chewing":	{"JJ"},
"gum-drop":	{"NN"},
"gum-lac":	{"NN"},
"gum-like":	{"JJ"},
"gum-tree":	{"NN"},
"gum-trees":	{"NNS"},
"gumbo":	{"NN"},
"gumbo-limbo":	{"NN"},
"gumboil":	{"NN"},
"gumboot":	{"NN"},
"gumboots":	{"NNS"},
"gumbos":	{"NNS"},
"gumdrop":	{"NN"},
"gumdrops":	{"NNS"},
"gumma":	{"NN"},
"gummed":	{"VBD","VBN"},
"gummier":	{"JJR"},
"gummiest":	{"JJS"},
"gumminess":	{"NN"},
"gumming":	{"VBG"},
"gummite":	{"NN"},
"gummosis":	{"NN"},
"gummy":	{"JJ"},
"gump":	{"NN"},
"gumption":	{"NN"},
"gumptious":	{"JJ"},
"gums":	{"NNS","VBZ"},
"gumshield":	{"NN"},
"gumshoe":	{"NN"},
"gumshoes":	{"NNS"},
"gumweed":	{"NN"},
"gumwood":	{"NN"},
"gun":	{"NN","VB","VBP"},
"gun-carriage":	{"NN"},
"gun-carriages":	{"NNS"},
"gun-carrying":	{"JJ"},
"gun-control":	{"NN"},
"gun-metal":	{"NN"},
"gun-runner":	{"NN"},
"gun-runners":	{"NNS"},
"gun-running":	{"NN"},
"gun-shot":	{"NN"},
"gun-shy":	{"JJ"},
"gun-sight":	{"NN"},
"gun-slinger":	{"NN"},
"gun-slinging":	{"JJ"},
"gunbarrel":	{"NN"},
"gunbattle":	{"NN"},
"gunbattles":	{"NNS"},
"gunboat":	{"NN"},
"gunboats":	{"NNS"},
"guncotton":	{"NN"},
"gunfight":	{"NN"},
"gunfighter":	{"NN"},
"gunfighters":	{"NNS"},
"gunfights":	{"NNS"},
"gunfire":	{"NN"},
"gunflint":	{"NN"},
"gung-ho":	{"JJ"},
"gungho":	{"JJ"},
"gunite":	{"NN"},
"gunk":	{"NN"},
"gunkier":	{"JJR"},
"gunkiest":	{"JJS"},
"gunky":	{"JJ"},
"gunloading":	{"NN"},
"gunlock":	{"NN"},
"gunman":	{"NN"},
"gunmen":	{"NNS"},
"gunmetal":	{"NN"},
"gunmetal-gray":	{"JJ"},
"gunned":	{"VBN","VBD"},
"gunnel":	{"NN"},
"gunnels":	{"NNS"},
"gunner":	{"NN"},
"gunners":	{"NNS"},
"gunnery":	{"NN"},
"gunning":	{"VBG"},
"gunny":	{"NN"},
"gunnysack":	{"NN"},
"gunnysacks":	{"NNS"},
"gunplay":	{"NN"},
"gunpoint":	{"NN"},
"gunpowder":	{"NN"},
"gunroom":	{"NN"},
"gunrunner":	{"NN"},
"gunrunners":	{"NNS"},
"gunrunning":	{"NN"},
"guns":	{"NNS","VBZ"},
"gunship":	{"NN"},
"gunships":	{"NNS"},
"gunshot":	{"NN"},
"gunshots":	{"NNS"},
"gunsight":	{"NN"},
"gunslinger":	{"NN"},
"gunslingers":	{"NNS"},
"gunslinging":	{"NN"},
"gunsmith":	{"NN"},
"gunsmiths":	{"NNS"},
"gunstock":	{"NN"},
"gunwale":	{"NN"},
"gunwales":	{"NNS"},
"guomindang":	{"NN"},
"guppies":	{"NNS"},
"guppy":	{"NN"},
"gur":	{"NN"},
"gurgle":	{"VB","VBP","NN"},
"gurgled":	{"VBD","VBN"},
"gurgles":	{"VBZ"},
"gurgling":	{"VBG"},
"gurnard":	{"NN","NNS"},
"gurnards":	{"NNS"},
"gurney":	{"NN"},
"gurneys":	{"NNS"},
"guru":	{"NN"},
"gurus":	{"NNS"},
"gus":	{"NN"},
"gush":	{"VBP","NN","VB"},
"gushed":	{"VBD","VBN"},
"gusher":	{"NN"},
"gushers":	{"NNS"},
"gushes":	{"VBZ"},
"gushier":	{"JJR"},
"gushiest":	{"JJS"},
"gushily":	{"RB"},
"gushiness":	{"NN"},
"gushing":	{"JJ","VBG"},
"gushingly":	{"RB"},
"gushy":	{"JJ"},
"gusset":	{"NN"},
"gusseted":	{"JJ"},
"gussets":	{"NNS"},
"gussied":	{"VBD","VBN"},
"gussies":	{"VBZ"},
"gussy":	{"VB","VBP"},
"gussying":	{"VBG"},
"gust":	{"NN","VB","VBP"},
"gustation":	{"NN"},
"gustative":	{"JJ"},
"gustatorial":	{"JJ"},
"gustatory":	{"JJ"},
"gustave":	{"NN"},
"gustavus":	{"NNS"},
"gusted":	{"VBD","VBN"},
"gustier":	{"JJR"},
"gustiest":	{"JJS"},
"gusting":	{"VBG"},
"gusto":	{"NN"},
"gusts":	{"VBZ","NNS"},
"gusty":	{"JJ"},
"gut":	{"NN","VB","VBP","JJ"},
"gut-Democratic":	{"JJ"},
"gut-democratic":	{"JJ"},
"gut-flattening":	{"JJ"},
"gut-wrenching":	{"JJ"},
"gutenberg":	{"NN"},
"gutierrezia":	{"NN"},
"gutless":	{"JJ"},
"gutlessness":	{"NN"},
"guts":	{"NNS","VBZ"},
"gutsier":	{"JJR"},
"gutsiest":	{"JJS"},
"gutsiness":	{"NN"},
"gutsy":	{"JJ"},
"gutta-percha":	{"NN"},
"gutted":	{"JJ","VBN","VBD"},
"gutter":	{"NN","VB","VBP"},
"guttered":	{"VBD","VBN"},
"guttering":	{"VBG","NN"},
"gutters":	{"NNS","VBZ"},
"guttersnipe":	{"NN"},
"guttersnipes":	{"NNS"},
"guttiferae":	{"NN"},
"guttiferales":	{"NNS"},
"gutting":	{"VBG"},
"guttle":	{"VB","VBP"},
"guttled":	{"VBD","VBN"},
"guttles":	{"VBZ"},
"guttling":	{"VBG"},
"guttman-type":	{"JJ"},
"guttural":	{"JJ","NN"},
"gutturalism":	{"NN"},
"gutturality":	{"NN"},
"gutturally":	{"RB"},
"gutturalness":	{"NN"},
"guvnor":	{"NN"},
"guvnors":	{"NNS"},
"guy":	{"NN","VB","VBP"},
"guyed":	{"VBD","VBN"},
"guying":	{"VBG"},
"guyot":	{"NN"},
"guys":	{"NNS","VBZ"},
"guzzle":	{"VB","VBP"},
"guzzled":	{"VBD","VBN"},
"guzzler":	{"NN"},
"guzzlers":	{"NNS"},
"guzzles":	{"VBZ"},
"guzzling":	{"VBG","JJ"},
"gweilo":	{"NN"},
"gweilos":	{"NNS"},
"gwydion":	{"NN"},
"gwynn":	{"NN"},
"gy":	{"NN"},
"gybe":	{"VB","VBP"},
"gybed":	{"VBD","VBN"},
"gybes":	{"VBZ"},
"gybing":	{"VBG"},
"gym":	{"NN"},
"gymkhana":	{"NN"},
"gymkhanas":	{"NNS"},
"gymnadenia":	{"NN"},
"gymnadeniopsis":	{"NN"},
"gymnasia":	{"NNS"},
"gymnasium":	{"NN"},
"gymnasium-sized":	{"JJ"},
"gymnasiums":	{"NNS"},
"gymnast":	{"NN"},
"gymnastic":	{"JJ"},
"gymnastics":	{"NNS"},
"gymnasts":	{"NNS"},
"gymnelis":	{"NN"},
"gymnocalycium":	{"NN"},
"gymnocarpium":	{"NN"},
"gymnocladus":	{"NNS"},
"gymnogyps":	{"NNS"},
"gymnomycota":	{"NN"},
"gymnophiona":	{"NN"},
"gymnopilus":	{"NNS"},
"gymnorhina":	{"NN"},
"gymnosophical":	{"JJ"},
"gymnosophist":	{"NN"},
"gymnosophy":	{"NN"},
"gymnosperm":	{"NN"},
"gymnospermae":	{"NN"},
"gymnospermophyta":	{"NN"},
"gymnospermous":	{"JJ"},
"gymnosporangium":	{"NN"},
"gymnura":	{"NN"},
"gyms":	{"NNS"},
"gymslip":	{"NN"},
"gymslips":	{"NNS"},
"gynaecological":	{"JJ"},
"gynaecologist":	{"NN"},
"gynaecologists":	{"NNS"},
"gynaecology":	{"NN"},
"gynaeolatry":	{"NN"},
"gynandromorph":	{"NN"},
"gynandromorphic":	{"JJ"},
"gynandromorphous":	{"JJ"},
"gynarchy":	{"NN"},
"gynecocracy":	{"NN"},
"gynecologic":	{"JJ"},
"gynecological":	{"JJ"},
"gynecologist":	{"NN"},
"gynecologists":	{"NNS"},
"gynecology":	{"NN"},
"gynecomastia":	{"NN"},
"gyneolatry":	{"NN"},
"gynne":	{"NN"},
"gynobase":	{"NN"},
"gynoecium":	{"NN"},
"gynogenesis":	{"NN"},
"gynophobia":	{"NN"},
"gynophore":	{"NN"},
"gynostegium":	{"NN"},
"gynura":	{"NN"},
"gyp":	{"NN","VB","VBP"},
"gypaetus":	{"NNS"},
"gypped":	{"VBD","VBN"},
"gypping":	{"VBG"},
"gyps":	{"NNS","VBZ"},
"gypsies":	{"NNS"},
"gypsophila":	{"NN"},
"gypsum":	{"NN"},
"gypsy":	{"NN"},
"gypsyweed":	{"NN"},
"gypsywort":	{"NN"},
"gyral":	{"JJ"},
"gyrate":	{"VB","VBP"},
"gyrated":	{"VBD","VBN"},
"gyrates":	{"VBZ"},
"gyrating":	{"VBG"},
"gyration":	{"NN"},
"gyrations":	{"NNS"},
"gyre":	{"NN"},
"gyrfalcon":	{"NN"},
"gyrinidae":	{"NN"},
"gyro":	{"NN"},
"gyro-platform-servo":	{"JJ"},
"gyro-stabilized":	{"JJ"},
"gyrocompass":	{"NN"},
"gyromitra":	{"NN"},
"gyroplane":	{"NN"},
"gyros":	{"NNS"},
"gyroscope":	{"NN"},
"gyroscopes":	{"NNS"},
"gyroscopic":	{"JJ"},
"gyrostabiliser":	{"NN"},
"gyrostabilizer":	{"NN"},
"gyrus":	{"NN"},
"gywn":	{"NN"},
"h":	{"NN","SYM","LS"},
"h-bomb":	{"NN"},
"h-shaped":	{"JJ"},
"h.p.":	{"NN"},
"h2o":	{"NN"},
"ha":	{"UH","NN"},
"ha'p'orth":	{"NN"},
"ha'penny":	{"NN"},
"ha-ha":	{"UH","NN"},
"haaaa":	{"UH"},
"haart":	{"NN"},
"haastia":	{"NN"},
"habacuc":	{"NN"},
"habanera":	{"NN"},
"habe":	{"FW"},
"habeas":	{"NN"},
"habeas-corpus":	{"NN"},
"habenaria":	{"NN"},
"haberdasher":	{"NN"},
"haberdasheries":	{"NNS"},
"haberdashers":	{"NNS"},
"haberdashery":	{"NN"},
"habergeon":	{"NN"},
"habiliment":	{"NN"},
"habilimented":	{"JJ"},
"habilitate":	{"VB","VBP"},
"habilitated":	{"VBD","VBN"},
"habilitates":	{"VBZ"},
"habilitating":	{"VBG"},
"habilitation":	{"NN"},
"habilitator":	{"NN"},
"habit":	{"NN","VB","VBP"},
"habit-forming":	{"JJ"},
"habitability":	{"NN"},
"habitable":	{"JJ"},
"habitableness":	{"NN"},
"habitant":	{"NN"},
"habitants":	{"NNS"},
"habitat":	{"NN"},
"habitation":	{"NN"},
"habitations":	{"NNS"},
"habitats":	{"NNS"},
"habited":	{"JJ","VBD","VBN"},
"habiting":	{"VBG"},
"habits":	{"NNS","VBZ"},
"habitual":	{"JJ"},
"habitually":	{"RB"},
"habituate":	{"VB","VBP"},
"habituated":	{"VBD","VBN"},
"habituates":	{"VBZ"},
"habituating":	{"VBG"},
"habituation":	{"NN"},
"habitude":	{"NN"},
"habitue":	{"NN"},
"habitues":	{"NNS"},
"habitus":	{"NN"},
"hable":	{"JJ"},
"hacek":	{"NN"},
"hacer":	{"FW"},
"hachiman":	{"NN"},
"hachure":	{"NN"},
"hacienda":	{"NN"},
"haciendas":	{"NNS"},
"hack":	{"VB","VBP","NN"},
"hack-driver":	{"NN"},
"hackamore":	{"NN"},
"hackberry":	{"NN"},
"hackbut":	{"NN"},
"hacked":	{"VBD","VBN"},
"hackee":	{"NN"},
"hackelia":	{"NN"},
"hacker":	{"NN"},
"hackers":	{"NNS"},
"hackier":	{"JJR"},
"hackiest":	{"JJS"},
"hacking":	{"NN","JJ","VBG"},
"hackle":	{"NN"},
"hackles":	{"NNS"},
"hackmatack":	{"NN"},
"hackney":	{"NN","VB","VBP"},
"hackneyed":	{"JJ","VBD","VBN"},
"hackneying":	{"VBG"},
"hackneys":	{"VBZ","NNS"},
"hacks":	{"VBZ","NNS"},
"hacksaw":	{"NN"},
"hacksaws":	{"NNS"},
"hackwork":	{"NN"},
"hacky":	{"JJ"},
"had":	{"VBD","VBN"},
"hadal":	{"JJ"},
"haddock":	{"NN","NNS"},
"hadean":	{"JJ","NN"},
"hadith":	{"NN"},
"hadj":	{"NN"},
"hadjes":	{"NNS"},
"hadji":	{"NN"},
"hadjis":	{"NNS"},
"hadley":	{"NN"},
"hadrian":	{"NN"},
"hadron":	{"NN"},
"hadrosaur":	{"NN"},
"hadrosauridae":	{"NN"},
"hadrosaurus":	{"NN"},
"haec":	{"FW"},
"haecceity":	{"NN"},
"haeckel":	{"NN"},
"haem":	{"NN"},
"haemagglutinate":	{"VB","VBP"},
"haemagglutination":	{"NN"},
"haemal":	{"JJ"},
"haemangioma":	{"NN"},
"haemanthus":	{"NNS"},
"haematal":	{"JJ"},
"haematemesis":	{"NN"},
"haematic":	{"JJ"},
"haematinic":	{"NN"},
"haematite":	{"NN"},
"haematobia":	{"NN"},
"haematocele":	{"NN"},
"haematochezia":	{"NN"},
"haematocoele":	{"NN"},
"haematocolpometra":	{"NN"},
"haematocolpos":	{"NNS"},
"haematocrit":	{"NN"},
"haematocytopenia":	{"NN"},
"haematocyturia":	{"NN"},
"haematogenesis":	{"NN"},
"haematogenic":	{"JJ"},
"haematohiston":	{"NN"},
"haematoidin":	{"NN"},
"haematological":	{"JJ"},
"haematologist":	{"NN"},
"haematology":	{"NN"},
"haematolysis":	{"NN"},
"haematoma":	{"NN"},
"haematopodidae":	{"NN"},
"haematopoiesis":	{"NN"},
"haematopoietic":	{"JJ"},
"haematopus":	{"NNS"},
"haematoxylon":	{"NN"},
"haematoxylum":	{"NN"},
"haematuria":	{"NN"},
"haemic":	{"JJ"},
"haemitin":	{"NN"},
"haemodialysis":	{"NN"},
"haemodoraceae":	{"NN"},
"haemodorum":	{"NN"},
"haemogenesis":	{"NN"},
"haemoglobin":	{"NN"},
"haemoglobinemia":	{"NN"},
"haemoglobinopathy":	{"NN"},
"haemoglobinuria":	{"NN"},
"haemolysin":	{"NN"},
"haemolysis":	{"NN"},
"haemolytic":	{"JJ"},
"haemophile":	{"NN"},
"haemophilia":	{"NN"},
"haemophiliac":	{"NN"},
"haemophilic":	{"JJ"},
"haemopis":	{"NN"},
"haemopoiesis":	{"NN"},
"haemopoietic":	{"JJ"},
"haemoproteid":	{"NN"},
"haemoproteidae":	{"NN"},
"haemoprotein":	{"NN"},
"haemoproteus":	{"NNS"},
"haemoptysis":	{"NN"},
"haemorrhage":	{"NN","VB","VBP"},
"haemorrhaged":	{"VBD","VBN"},
"haemorrhages":	{"NNS","VBZ"},
"haemorrhagic":	{"JJ"},
"haemorrhaging":	{"VBG"},
"haemorrhoid":	{"NN"},
"haemorrhoidectomy":	{"NN"},
"haemosiderin":	{"NN"},
"haemosiderosis":	{"NN"},
"haemosporidia":	{"NN"},
"haemosporidian":	{"NN"},
"haemostasia":	{"NN"},
"haemostasis":	{"NN"},
"haemostat":	{"NN"},
"haemothorax":	{"NN"},
"haemulidae":	{"NN"},
"haemulon":	{"NN"},
"hafez":	{"NN"},
"haflis":	{"NNS"},
"hafnium":	{"NN"},
"haft":	{"NN"},
"hafta":	{"VBP"},
"haftarah":	{"NN"},
"haftorah":	{"NN"},
"hafts":	{"NNS"},
"hag":	{"NN"},
"hag-ridden":	{"JJ"},
"hagada":	{"NN"},
"haganah":	{"NN"},
"hagberry":	{"NN"},
"hagbut":	{"NN"},
"hagerstown":	{"NN"},
"hagfish":	{"NN"},
"haggadah":	{"NN"},
"haggard":	{"JJ","NN"},
"haggardly":	{"RB"},
"haggis":	{"NN"},
"haggises":	{"NNS"},
"haggle":	{"VB","VBP","NN"},
"haggled":	{"VBD","VBN"},
"haggler":	{"NN"},
"haggles":	{"VBZ","NNS"},
"haggling":	{"VBG","NN"},
"hagglings":	{"NNS"},
"hagiographa":	{"NN"},
"hagiographer":	{"NN"},
"hagiographies":	{"NNS"},
"hagiographist":	{"NN"},
"hagiography":	{"NN"},
"hagiolatry":	{"NN"},
"hagiologist":	{"NN"},
"hagiology":	{"NN"},
"hagridden":	{"JJ"},
"hags":	{"NNS"},
"hah":	{"UH"},
"hahn":	{"NN"},
"hahnium":	{"NN"},
"haick":	{"NN"},
"haida":	{"NN"},
"haifa":	{"NN"},
"haight":	{"NN"},
"haik":	{"NN"},
"haiku":	{"NN","NNS"},
"haikus":	{"NNS"},
"hail":	{"VB","VBP","NN","UH"},
"hail-fellow":	{"JJ"},
"hail-fellow-well-met":	{"JJ"},
"haile":	{"NN"},
"hailed":	{"VBD","VBN"},
"hailing":	{"VBG"},
"hails":	{"VBZ"},
"hailstone":	{"NN"},
"hailstones":	{"NNS"},
"hailstorm":	{"NN"},
"hailstorms":	{"NNS"},
"hainan":	{"NN"},
"haiphong":	{"NN"},
"hair":	{"NN"},
"hair's-breadth":	{"NN"},
"hair-care":	{"NN","JJ"},
"hair-drier":	{"NN"},
"hair-dryer":	{"NN"},
"hair-grip":	{"NN"},
"hair-grips":	{"NNS"},
"hair-growing":	{"JJ"},
"hair-line":	{"NN"},
"hair-net":	{"NN"},
"hair-oil":	{"NN"},
"hair-piece":	{"NN"},
"hair-raiser":	{"NN"},
"hair-raising":	{"JJ"},
"hair-relaxer":	{"NN"},
"hair-restorer":	{"NN"},
"hair-restorers":	{"NNS"},
"hair-shirt":	{"NN"},
"hair-shirted":	{"JJ"},
"hair-shirts":	{"NNS"},
"hair-slide":	{"NN"},
"hair-slides":	{"NNS"},
"hair-splitting":	{"NN"},
"hair-style":	{"NN"},
"hair-stylist":	{"NN"},
"hair-stylists":	{"NNS"},
"hair-trigger":	{"NN","JJ"},
"hair-triggers":	{"NNS"},
"hairball":	{"NN"},
"hairbrush":	{"NN"},
"hairbrushes":	{"NNS"},
"haircare":	{"NN","JJ"},
"haircloth":	{"NN"},
"haircut":	{"NN"},
"haircuts":	{"NNS"},
"hairdo":	{"NN"},
"hairdos":	{"NNS"},
"hairdresser":	{"NN"},
"hairdressers":	{"NNS"},
"hairdressing":	{"NN"},
"haired":	{"JJ"},
"hairgrip":	{"NN"},
"hairgrips":	{"NNS"},
"hairier":	{"JJR"},
"hairiest":	{"JJS"},
"hairiness":	{"NN"},
"hairless":	{"JJ"},
"hairlessness":	{"NN"},
"hairlike":	{"JJ"},
"hairline":	{"NN","JJ"},
"hairlines":	{"NNS"},
"hairnet":	{"NN"},
"hairnets":	{"NNS"},
"hairpiece":	{"NN"},
"hairpieces":	{"NNS"},
"hairpin":	{"NN"},
"hairpins":	{"NNS"},
"hairs":	{"NNS"},
"hairsbreadth":	{"NN"},
"hairshirt":	{"NN"},
"hairsplitter":	{"NN"},
"hairsplitting":	{"NN"},
"hairspray":	{"NN"},
"hairspring":	{"NN"},
"hairstreak":	{"NN"},
"hairstyle":	{"NN"},
"hairstyles":	{"NNS"},
"hairstylist":	{"NN"},
"hairstylists":	{"NNS"},
"hairtail":	{"NN"},
"hairtonic":	{"NN"},
"hairweaving":	{"NN"},
"hairy":	{"JJ"},
"hairyknuckled":	{"JJ"},
"haj":	{"NN"},
"haji":	{"NN"},
"hajj":	{"NN"},
"hajji":	{"NN"},
"hajjis":	{"NNS"},
"hajs":	{"NNS"},
"hake":	{"NN","NNS"},
"hakea":	{"NN"},
"hakeem":	{"NN"},
"hakenkreuz":	{"NN"},
"hakham":	{"NN"},
"hakim":	{"NN"},
"hakka":	{"NN"},
"hal":	{"NN"},
"halab":	{"NN"},
"halacha":	{"NN"},
"halaka":	{"NN"},
"halakah":	{"NN"},
"halal":	{"JJ","NN","VB","VBP"},
"halalled":	{"VBD","VBN"},
"halalling":	{"VBG"},
"halals":	{"VBZ"},
"halberd":	{"NN"},
"halberdier":	{"NN"},
"halberds":	{"NNS"},
"halchidhoma":	{"NN"},
"halcion":	{"NN"},
"halcyon":	{"JJ"},
"haldane":	{"NN"},
"haldea":	{"NN"},
"haldol":	{"NN"},
"hale":	{"JJ","VBP","VB"},
"haled":	{"VBD","VBN"},
"haleness":	{"NN"},
"halenia":	{"NN"},
"haler":	{"NN"},
"hales":	{"VBZ"},
"halesia":	{"NN"},
"halevy":	{"NN"},
"half":	{"NN","PDT","DT","RB"},
"half-a-dozen":	{"NN"},
"half-a-million":	{"JJ"},
"half-acceptance":	{"NN"},
"half-acre":	{"JJ"},
"half-aloud":	{"RB"},
"half-an-hour":	{"NN"},
"half-and-half":	{"NN"},
"half-baked":	{"JJ"},
"half-billion":	{"JJ"},
"half-block":	{"NN"},
"half-blood":	{"JJ"},
"half-blooded":	{"JJ"},
"half-bottles":	{"NNS"},
"half-bound":	{"JJ"},
"half-bred":	{"JJ"},
"half-breed":	{"JJ","NN"},
"half-breeds":	{"NNS"},
"half-brother":	{"NN"},
"half-brothers":	{"NNS"},
"half-caste":	{"NN","JJ"},
"half-castes":	{"NNS"},
"half-century":	{"NN"},
"half-chapter":	{"NN"},
"half-city":	{"NN"},
"half-clad":	{"JJ"},
"half-closed":	{"JJ"},
"half-clothed":	{"JJ"},
"half-cock":	{"NN"},
"half-cocked":	{"JJ"},
"half-completed":	{"JJ"},
"half-conscious":	{"JJ"},
"half-court":	{"NN","JJ"},
"half-crazed":	{"JJ"},
"half-crazy":	{"JJ"},
"half-crocked":	{"JJ"},
"half-cup":	{"JJ"},
"half-darkness":	{"NN"},
"half-digested":	{"JJ"},
"half-dozen":	{"NN","JJ"},
"half-dressed":	{"JJ"},
"half-drunk":	{"JJ"},
"half-educated":	{"JJ"},
"half-empty":	{"JJ"},
"half-evergreen":	{"JJ"},
"half-expressed":	{"JJ"},
"half-faced":	{"JJ"},
"half-filled":	{"JJ"},
"half-forgotten":	{"JJ"},
"half-full":	{"JJ"},
"half-gainer":	{"NN"},
"half-gourd":	{"NN"},
"half-grown":	{"JJ"},
"half-hardy":	{"JJ"},
"half-hearted":	{"JJ"},
"half-heartedly":	{"RB"},
"half-holiday":	{"NN"},
"half-horse":	{"JJ"},
"half-hour":	{"NN","JJ"},
"half-hourly":	{"JJ","RB"},
"half-hours":	{"NNS"},
"half-implemented":	{"JJ"},
"half-inch":	{"NN","VB","VBP"},
"half-inched":	{"VBD","VBN"},
"half-inches":	{"VBZ"},
"half-inching":	{"VBG"},
"half-industrial":	{"JJ"},
"half-intensity":	{"NN"},
"half-interest":	{"NN"},
"half-jokingly":	{"RB"},
"half-length":	{"JJ"},
"half-life":	{"NN"},
"half-light":	{"NN"},
"half-man":	{"NN"},
"half-mast":	{"NN","VB","VBP"},
"half-masted":	{"VBD","VBN"},
"half-masting":	{"VBG"},
"half-masts":	{"VBZ"},
"half-measure":	{"NN"},
"half-measures":	{"NNS"},
"half-melted":	{"JJ"},
"half-mile":	{"JJ","NN"},
"half-million":	{"JJ"},
"half-mincing":	{"JJ"},
"half-moon":	{"NN"},
"half-moons":	{"NNS"},
"half-murmured":	{"JJ"},
"half-off":	{"JJ"},
"half-owned":	{"JJ"},
"half-past":	{"JJ"},
"half-pay":	{"NN"},
"half-percent":	{"JJ"},
"half-pint":	{"NN"},
"half-point":	{"JJ"},
"half-price":	{"RB","JJ","NN"},
"half-reached":	{"JJ"},
"half-reformed":	{"JJ"},
"half-relief":	{"NN"},
"half-reluctant":	{"JJ"},
"half-seas-over":	{"JJ"},
"half-seriously":	{"RB"},
"half-share":	{"NN"},
"half-sister":	{"NN"},
"half-size":	{"NN","JJ"},
"half-slip":	{"NN"},
"half-smile":	{"NN"},
"half-speed":	{"JJ"},
"half-staff":	{"JJ"},
"half-standard":	{"JJ"},
"half-starved":	{"JJ"},
"half-states":	{"NNS"},
"half-straightened":	{"JJ"},
"half-swamped":	{"JJ"},
"half-swimming":	{"JJ"},
"half-term":	{"NN"},
"half-timber":	{"JJ"},
"half-timbered":	{"JJ"},
"half-time":	{"NN"},
"half-track":	{"NN"},
"half-tracked":	{"JJ"},
"half-transparent":	{"JJ"},
"half-truth":	{"JJ","NN"},
"half-turned":	{"JJ"},
"half-understood":	{"JJ"},
"half-way":	{"JJ","RB"},
"half-well":	{"JJ"},
"half-wit":	{"NN"},
"half-witted":	{"JJ"},
"half-year":	{"JJ","NN"},
"half-yearly":	{"JJ","RB"},
"halfback":	{"NN"},
"halfbacks":	{"NNS"},
"halfbeak":	{"NN"},
"halfhearted":	{"JJ"},
"halfheartedly":	{"RB"},
"halfmile":	{"NN"},
"halfpenny":	{"NN"},
"halfpennyworth":	{"NN"},
"halftime":	{"NN"},
"halftone":	{"NN"},
"halfway":	{"RB","JJ"},
"halfways":	{"RB"},
"haliaeetus":	{"NNS"},
"halibut":	{"NN","NNS"},
"halicarnassus":	{"NNS"},
"halicoeres":	{"NNS"},
"halictidae":	{"NN"},
"halide":	{"NN"},
"halides":	{"NNS"},
"halifax":	{"NN"},
"halimodendron":	{"NN"},
"haling":	{"VBG"},
"haliotidae":	{"NN"},
"haliotis":	{"NN"},
"halite":	{"NN"},
"halitosis":	{"NN"},
"halitus":	{"NN"},
"hall":	{"NN"},
"hall-mark":	{"NN"},
"hallah":	{"NN"},
"halle-an-der-saale":	{"NN"},
"hallel":	{"NN"},
"hallelujah":	{"NN","UH"},
"hallelujahs":	{"NNS"},
"halley":	{"NN"},
"halliard":	{"NN"},
"hallmark":	{"NN","VB","VBP"},
"hallmarked":	{"VBD","VBN"},
"hallmarking":	{"VBG"},
"hallmarks":	{"NNS","VBZ"},
"hallo":	{"UH","NN"},
"halloa":	{"UH","NN","VB","VBP"},
"halloaed":	{"VBD","VBN"},
"halloaing":	{"VBG"},
"halloas":	{"VBZ","NNS"},
"halloo":	{"UH","NN","VB","VBP"},
"hallooed":	{"VBD","VBN"},
"hallooing":	{"VBG"},
"halloos":	{"NNS","VBZ"},
"hallos":	{"NNS"},
"hallow":	{"VB","VBP"},
"hallowed":	{"JJ","VBD","VBN"},
"hallowing":	{"VBG"},
"hallowmas":	{"NNS"},
"hallowmass":	{"NN"},
"hallows":	{"VBZ"},
"halls":	{"NNS"},
"hallstand":	{"NN"},
"hallucinate":	{"VB","VBP"},
"hallucinated":	{"VBD","VBN"},
"hallucinates":	{"VBZ"},
"hallucinating":	{"VBG"},
"hallucination":	{"NN"},
"hallucinations":	{"NNS"},
"hallucinatory":	{"JJ"},
"hallucinogen":	{"NN"},
"hallucinogenic":	{"JJ"},
"hallucinogens":	{"NNS"},
"hallucinosis":	{"NN"},
"hallux":	{"NN"},
"hallway":	{"NN"},
"hallways":	{"NNS"},
"halm":	{"NN"},
"halma":	{"NN"},
"halo":	{"NN","VB","VBP"},
"haloalkane":	{"NN"},
"halobacter":	{"NN"},
"halobacteria":	{"NN"},
"halobacterium":	{"NN"},
"halocarbon":	{"NN"},
"halocarpus":	{"NNS"},
"haloed":	{"VBD","VBN"},
"haloes":	{"NNS","VBZ"},
"haloform":	{"NN"},
"halogen":	{"NN"},
"halogenate":	{"VB","VBP"},
"halogenated":	{"VBD","VBN"},
"halogenates":	{"VBZ"},
"halogenating":	{"VBG"},
"halogens":	{"NNS"},
"halogeton":	{"NN"},
"haloing":	{"VBG"},
"halon":	{"NN"},
"haloperidol":	{"NN"},
"halophil":	{"NN"},
"halophile":	{"NN"},
"halophyte":	{"NN"},
"haloragaceae":	{"NN"},
"haloragidaceae":	{"NN"},
"halos":	{"NNS","VBZ"},
"halothane":	{"NN"},
"halt":	{"VB","NN","VBP"},
"halted":	{"VBD","VBN"},
"halter":	{"NN","VB","VBP"},
"haltere":	{"NN"},
"haltered":	{"VBD","VBN"},
"haltering":	{"VBG"},
"halters":	{"NNS","VBZ"},
"halting":	{"JJ","VBG"},
"haltingly":	{"RB"},
"halts":	{"VBZ","NNS"},
"halvah":	{"NN"},
"halve":	{"VB","VBP"},
"halved":	{"VBD","VBN"},
"halves":	{"VBZ","NNS"},
"halving":	{"VBG"},
"halyard":	{"NN"},
"halyards":	{"NNS"},
"ham":	{"NN","VBP","VB"},
"ham-fisted":	{"JJ"},
"ham-handed":	{"JJ"},
"ham-like":	{"JJ"},
"ham-radio":	{"NN"},
"hama-style":	{"JJ"},
"hamadryad":	{"NN"},
"hamakua":	{"NN"},
"hamamelidaceae":	{"NN"},
"hamamelidae":	{"NN"},
"hamamelidanthum":	{"NN"},
"hamamelidoxylon":	{"NN"},
"hamamelis":	{"NN"},
"hamamelites":	{"NNS"},
"hamartia":	{"NN"},
"hamartoma":	{"NN"},
"hamate":	{"JJ"},
"hamburg":	{"NN"},
"hamburger":	{"NN"},
"hamburgers":	{"NNS"},
"hame":	{"NN"},
"hamelia":	{"NN"},
"hamelin":	{"NN"},
"hameln":	{"NN"},
"hamilton-oriented":	{"JJ"},
"haminoea":	{"NN"},
"hamitic":	{"NN"},
"hamito-semitic":	{"NN"},
"hamlet":	{"NN"},
"hamlets":	{"NNS"},
"hamm":	{"NN"},
"hammarskjold":	{"NN"},
"hammed":	{"VBD","VBN"},
"hammer":	{"NN","VB","VBP"},
"hammer-shaped":	{"JJ"},
"hammered":	{"JJ","VBD","VBN"},
"hammerhead":	{"NN"},
"hammering":	{"NN","VBG"},
"hammerless":	{"JJ"},
"hammerlock":	{"NN"},
"hammers":	{"NNS","VBZ"},
"hammertoe":	{"NN"},
"hammett":	{"NN"},
"hamming":	{"NN","VBG"},
"hammock":	{"NN"},
"hammocks":	{"NNS"},
"hammurabi":	{"NN"},
"hammurapi":	{"NN"},
"hammy":	{"JJ"},
"hamper":	{"VB","VBP","NN"},
"hampered":	{"VBN","VBD"},
"hampering":	{"VBG"},
"hampers":	{"VBZ","NNS"},
"hampshire":	{"NN"},
"hampton":	{"NN"},
"hams":	{"NNS","VBZ"},
"hamster":	{"NN"},
"hamsters":	{"NNS"},
"hamstring":	{"NN","VB","VBP"},
"hamstringing":	{"NN","VBG"},
"hamstrings":	{"NNS","VBZ"},
"hamstrung":	{"VBN","VBD"},
"hamsun":	{"NN"},
"han-gook":	{"NN"},
"hand":	{"NN","VB","VBP"},
"hand-delivered":	{"JJ"},
"hand-drier":	{"NN"},
"hand-driers":	{"NNS"},
"hand-dryer":	{"NN"},
"hand-dryers":	{"NNS"},
"hand-fed":	{"VBD","VBN"},
"hand-feed":	{"VB","VBP"},
"hand-feeding":	{"VBG"},
"hand-feeds":	{"VBZ"},
"hand-held":	{"JJ","NN"},
"hand-helds":	{"NNS"},
"hand-holder":	{"NN"},
"hand-holders":	{"NNS"},
"hand-holding":	{"NN","JJ"},
"hand-knit":	{"JJ","VB","VBP","VBD","VBN"},
"hand-knits":	{"NNS"},
"hand-knitted":	{"VBD","VBN"},
"hand-knitting":	{"VBG"},
"hand-list":	{"NN"},
"hand-lists":	{"NNS"},
"hand-loomed":	{"JJ"},
"hand-me-down":	{"JJ","NN"},
"hand-me-downs":	{"NNS"},
"hand-me-up":	{"NN"},
"hand-off":	{"NN"},
"hand-offs":	{"NNS"},
"hand-out":	{"NN"},
"hand-painted":	{"NN"},
"hand-pick":	{"VB","VBP"},
"hand-picked":	{"JJ","VBN","VBD"},
"hand-picking":	{"VBG"},
"hand-picks":	{"VBZ"},
"hand-piece":	{"NN"},
"hand-play":	{"NN"},
"hand-plays":	{"NNS"},
"hand-printed":	{"JJ"},
"hand-rear":	{"VB","VBP"},
"hand-reared":	{"VBD","VBN","JJ"},
"hand-rearing":	{"VBG"},
"hand-rears":	{"VBZ"},
"hand-running":	{"RB"},
"hand-spray":	{"NN"},
"hand-sprays":	{"NNS"},
"hand-stitched":	{"JJ"},
"hand-to-hand":	{"JJ"},
"hand-to-mouth":	{"JJ","RB"},
"hand-tool":	{"NN"},
"hand-tools":	{"NNS"},
"hand-wash":	{"VB","VBP"},
"hand-washed":	{"VBD","VBN"},
"hand-washes":	{"VBZ"},
"hand-washing":	{"VBG"},
"hand-worker":	{"NN"},
"hand-workers":	{"NNS"},
"hand-woven":	{"JJ"},
"hand-wringer":	{"NN"},
"hand-wringers":	{"NNS"},
"hand-wringing":	{"NN"},
"handbag":	{"NN"},
"handbags":	{"NNS"},
"handball":	{"NN"},
"handballs":	{"NNS"},
"handbarrow":	{"NN"},
"handbasin":	{"NN"},
"handbasket":	{"NN"},
"handbell":	{"NN"},
"handbill":	{"NN"},
"handbills":	{"NNS"},
"handbook":	{"NN"},
"handbooks":	{"NNS"},
"handbow":	{"NN"},
"handbrake":	{"NN"},
"handbrakes":	{"NNS"},
"handbreadth":	{"NN"},
"handcar":	{"NN"},
"handcars":	{"NNS"},
"handcart":	{"NN"},
"handcarts":	{"NNS"},
"handclap":	{"NN"},
"handclaps":	{"NNS"},
"handclasp":	{"NN"},
"handcolor":	{"VB","VBP"},
"handcolour":	{"VB","VBP"},
"handcraft":	{"VB","VBP","NN"},
"handcrafted":	{"JJ","VBD","VBN"},
"handcrafting":	{"VBG"},
"handcrafts":	{"VBZ"},
"handcuff":	{"VB","VBP"},
"handcuffed":	{"VBD","VBN"},
"handcuffing":	{"VBG"},
"handcuffs":	{"NNS","VBZ"},
"hande":	{"NN"},
"handed":	{"VBD","VBN","JJ"},
"handed-down":	{"JJ"},
"handedness":	{"NN"},
"handelian":	{"JJ"},
"hander":	{"NN"},
"handful":	{"NN"},
"handfuls":	{"NNS"},
"handgrip":	{"NN"},
"handgun":	{"NN"},
"handguns":	{"NNS"},
"handheld":	{"JJ","NN"},
"handhelds":	{"NNS"},
"handhold":	{"NN"},
"handholds":	{"NNS"},
"handicap":	{"NN","VB","VBP"},
"handicapped":	{"JJ","VBD","VBN","NNS"},
"handicapper":	{"NN"},
"handicapping":	{"VBG"},
"handicaps":	{"VBZ","NNS"},
"handicraft":	{"NN"},
"handicrafts":	{"NNS"},
"handicraftsman":	{"NN"},
"handier":	{"JJR"},
"handiest":	{"JJS"},
"handily":	{"RB"},
"handiness":	{"NN"},
"handing":	{"VBG"},
"handiwork":	{"NN"},
"handkerchief":	{"NN"},
"handkerchiefs":	{"NNS"},
"handle":	{"VB","NN","VBP"},
"handle-bars":	{"NNS"},
"handlebar":	{"NN"},
"handlebars":	{"NNS"},
"handled":	{"VBN","VBD"},
"handleless":	{"JJ"},
"handler":	{"NN"},
"handlers":	{"NNS"},
"handles":	{"VBZ","NNS"},
"handless":	{"JJ"},
"handline":	{"NN"},
"handling":	{"VBG","NN"},
"handlock":	{"NN"},
"handloom":	{"NN"},
"handlooms":	{"NNS"},
"handmade":	{"JJ"},
"handmaid":	{"NN"},
"handmaiden":	{"NN"},
"handmaidens":	{"NNS"},
"handoff":	{"NN"},
"handout":	{"NN"},
"handouts":	{"NNS"},
"handover":	{"NN"},
"handovers":	{"NNS"},
"handpick":	{"VB","VBP"},
"handpicked":	{"JJ","VBD","VBN"},
"handpicking":	{"VBG"},
"handpicks":	{"VBZ"},
"handrail":	{"NN"},
"handrails":	{"NNS"},
"handrest":	{"NN"},
"hands":	{"NNS","VBZ"},
"hands-down":	{"JJ"},
"hands-off":	{"JJ"},
"hands-off-all-sweets":	{"NNS"},
"hands-on":	{"JJ"},
"handsaw":	{"NN"},
"handsaws":	{"NNS"},
"handsbreadth":	{"NN"},
"handscrolls":	{"NNS"},
"handset":	{"NN"},
"handsets":	{"NNS"},
"handsewn":	{"JJ"},
"handshake":	{"NN"},
"handshaker":	{"NN"},
"handshakes":	{"NNS"},
"handshaking":	{"NN"},
"handsier":	{"JJR"},
"handsiest":	{"JJS"},
"handsome":	{"JJ"},
"handsomely":	{"RB"},
"handsomeness":	{"NN"},
"handspike":	{"NN"},
"handspikes":	{"NNS"},
"handspring":	{"NN"},
"handsprings":	{"NNS"},
"handstamp":	{"NN","VB","VBP"},
"handstand":	{"NN"},
"handstands":	{"NNS"},
"handstitched":	{"JJ"},
"handsy":	{"JJ"},
"handwash":	{"VB","VBP"},
"handwashed":	{"VBD","VBN"},
"handwashes":	{"VBZ"},
"handwashing":	{"VBG"},
"handwear":	{"NN"},
"handwheel":	{"NN"},
"handwork":	{"NN"},
"handwoven":	{"JJ"},
"handwrite":	{"VB","VBP"},
"handwrites":	{"VBZ"},
"handwriting":	{"NN","VBG"},
"handwritten":	{"JJ","VBN"},
"handwrote":	{"VBD"},
"handy":	{"JJ"},
"handyman":	{"NN"},
"handyman-carpenter":	{"NN"},
"handymen":	{"NNS"},
"hang":	{"VB","NN","VBP"},
"hang-tough":	{"JJ"},
"hang-up":	{"NN"},
"hang-ups":	{"NNS"},
"hangar":	{"NN"},
"hangars":	{"NNS"},
"hangbird":	{"NN"},
"hangchow":	{"NN"},
"hangdog":	{"JJ"},
"hanged":	{"VBN","VBD"},
"hanger":	{"NN"},
"hanger-on":	{"NN"},
"hangers":	{"NNS"},
"hangers-on":	{"NNS"},
"hanging":	{"VBG","NN"},
"hangings":	{"NNS"},
"hangman":	{"NN"},
"hangmen":	{"NNS"},
"hangnail":	{"NN"},
"hangnails":	{"NNS"},
"hangout":	{"NN"},
"hangouts":	{"NNS"},
"hangover":	{"NN"},
"hangovers":	{"NNS"},
"hangs":	{"VBZ"},
"hangups":	{"NNS"},
"hangzhou":	{"NN"},
"hani":	{"NN"},
"hank":	{"NN"},
"hanker":	{"VB","VBP"},
"hankered":	{"VBD","VBN"},
"hankering":	{"NN","VBG"},
"hankerings":	{"NNS"},
"hankers":	{"VBZ"},
"hankey":	{"NN"},
"hankie":	{"NN"},
"hankies":	{"NNS"},
"hanks":	{"NNS"},
"hanky":	{"NN"},
"hanky-panky":	{"NN"},
"hannah":	{"NN"},
"hannover":	{"NN"},
"hannukah":	{"NN"},
"hanoi-backed":	{"JJ"},
"hanover":	{"NN"},
"hanoverian":	{"JJ","NN"},
"hansom":	{"NN"},
"hansoms":	{"NNS"},
"hanukah":	{"NN"},
"hanuman":	{"NN"},
"hao":	{"NN"},
"haole":	{"NN"},
"haoma":	{"NN"},
"hap":	{"NN","VB","VBP"},
"haphazard":	{"JJ"},
"haphazardly":	{"RB"},
"haphazardness":	{"NN"},
"haphtarah":	{"NN"},
"haphtorah":	{"NN"},
"hapless":	{"JJ"},
"haploid":	{"JJ"},
"haploidic":	{"JJ"},
"haploidy":	{"NN"},
"haplopappus":	{"NNS"},
"haplosporidia":	{"NN"},
"haplosporidian":	{"NN"},
"haplotype":	{"NN"},
"haplotyped":	{"JJ"},
"haplotyping":	{"NN"},
"haply":	{"RB"},
"happed":	{"VBD","VBN"},
"happen":	{"VB","VBP"},
"happened":	{"VBD","VBN"},
"happening":	{"VBG","NN"},
"happenings":	{"NNS"},
"happens":	{"VBZ"},
"happenstance":	{"NN"},
"happier":	{"JJR"},
"happiest":	{"JJS"},
"happily":	{"RB"},
"happiness":	{"NN"},
"happing":	{"VBG"},
"happy":	{"JJ"},
"happy-go-lucky":	{"JJ"},
"haps":	{"NNS","VBZ"},
"haptic":	{"JJ"},
"haptically":	{"RB"},
"haptics":	{"NN"},
"haptoglobin":	{"NN"},
"hara-kiri":	{"NN"},
"harakiri":	{"NN"},
"harangue":	{"VB","VBP","NN"},
"harangued":	{"VBD","VBN"},
"haranguer":	{"NN"},
"harangues":	{"NNS","VBZ"},
"haranguing":	{"VBG"},
"harass":	{"VB","VBP"},
"harassed":	{"JJ","VBD","VBN"},
"harasser":	{"NN"},
"harasses":	{"VBZ"},
"harassing":	{"VBG"},
"harassment":	{"NN"},
"harbinger":	{"NN","VB","VBP"},
"harbingered":	{"VBD","VBN"},
"harbingering":	{"VBG"},
"harbingers":	{"NNS","VBZ"},
"harbor":	{"NN","VBP","VB"},
"harborage":	{"NN"},
"harbored":	{"VBD","VBN"},
"harboring":	{"VBG"},
"harbors":	{"VBZ","NNS"},
"harborside":	{"NN"},
"harbour":	{"NN","VB","VBP"},
"harbour-master":	{"NN"},
"harbourage":	{"NN"},
"harboured":	{"VBD","VBN"},
"harbouring":	{"VBG"},
"harbours":	{"NNS","VBZ"},
"hard":	{"JJ","RB"},
"hard-and-fast":	{"JJ"},
"hard-baked":	{"JJ"},
"hard-bitten":	{"JJ"},
"hard-boiled":	{"JJ"},
"hard-charging":	{"JJ","NN"},
"hard-come-by":	{"JJ"},
"hard-core":	{"JJ"},
"hard-cover":	{"NN"},
"hard-currencies":	{"NNS"},
"hard-currency":	{"NN"},
"hard-disk":	{"NN"},
"hard-disks":	{"NNS"},
"hard-drinking":	{"JJ"},
"hard-earned":	{"JJ"},
"hard-edged":	{"JJ"},
"hard-fought":	{"JJ"},
"hard-hit":	{"JJ"},
"hard-hitting":	{"JJ"},
"hard-line":	{"JJ"},
"hard-liner":	{"NN"},
"hard-liners":	{"NNS"},
"hard-liquor":	{"JJ","NN"},
"hard-nosed":	{"JJ"},
"hard-of-hearing":	{"JJ"},
"hard-on":	{"NN"},
"hard-pressed":	{"JJ"},
"hard-riding":	{"JJ"},
"hard-sell":	{"NN"},
"hard-shelled":	{"JJ"},
"hard-surface":	{"NN","JJ"},
"hard-to-fault":	{"JJ"},
"hard-to-fill":	{"JJ"},
"hard-to-fit":	{"JJ"},
"hard-to-get":	{"JJ"},
"hard-to-please":	{"JJ"},
"hard-to-spot":	{"JJ"},
"hard-wire":	{"JJ"},
"hard-won":	{"JJ"},
"hard-working":	{"JJ"},
"hardback":	{"NN","JJ"},
"hardbacked":	{"JJ"},
"hardbacks":	{"NNS"},
"hardbake":	{"NN"},
"hardball":	{"NN"},
"hardboard":	{"NN"},
"hardboiled":	{"JJ"},
"hardbound":	{"JJ"},
"hardcore":	{"JJ"},
"hardcover":	{"NN","JJ"},
"hardcovers":	{"NNS"},
"harddisk":	{"NN"},
"harden":	{"VB","VBP"},
"hardenbergia":	{"NN"},
"hardened":	{"JJ","VBD","VBN"},
"hardener":	{"NN"},
"hardening":	{"NN","VBG"},
"hardens":	{"VBZ"},
"harder":	{"JJR"},
"harder-line":	{"JJ"},
"hardest":	{"JJS"},
"hardest-hit":	{"JJ"},
"hardfisted":	{"JJ"},
"hardhead":	{"NN"},
"hardheaded":	{"JJ"},
"hardheads":	{"NNS"},
"hardhearted":	{"JJ"},
"hardheartedness":	{"NN"},
"hardier":	{"JJR"},
"hardiest":	{"JJS"},
"hardihood":	{"NN"},
"hardiness":	{"NN"},
"hardinggrass":	{"NN"},
"hardline":	{"JJ"},
"hardliner":	{"NN"},
"hardliners":	{"NNS"},
"hardly":	{"RB"},
"hardness":	{"NN"},
"hardpan":	{"NN"},
"hardscrabble":	{"JJ"},
"hardship":	{"NN"},
"hardships":	{"NNS"},
"hardtack":	{"NN"},
"hardtack-box":	{"NN"},
"hardtop":	{"NN"},
"hardware":	{"NN"},
"hardware-maintenance":	{"NN"},
"hardware-store":	{"NN"},
"hardwareman":	{"NN"},
"hardwood":	{"NN"},
"hardwoods":	{"NNS"},
"hardworking":	{"JJ"},
"hardy":	{"JJ"},
"hare":	{"NN","VB","VBP"},
"hare-brained":	{"JJ"},
"harebell":	{"NN"},
"harebrained":	{"JJ"},
"hared":	{"VBD","VBN"},
"haredi":	{"NN"},
"hareem":	{"NN"},
"harefoot":	{"NN"},
"harelip":	{"NN"},
"harelips":	{"NNS"},
"harem":	{"NN"},
"harems":	{"NNS"},
"hares":	{"NNS","VBZ"},
"hargeisa":	{"NN"},
"haricot":	{"NN"},
"harijan":	{"NN"},
"harikari":	{"NN"},
"haring":	{"VBG"},
"hark":	{"VB","VBP"},
"harkat-ul-jihad-e-islami":	{"NN"},
"harkat-ul-mujahidin":	{"NN"},
"harked":	{"VBD","VBN"},
"harken":	{"VB","VBP"},
"harkened":	{"VBD","VBN"},
"harkening":	{"VBG"},
"harkens":	{"VBZ"},
"harking":	{"VBG","NN"},
"harks":	{"VBZ"},
"harlan":	{"NN"},
"harlequin":	{"NN","JJ"},
"harlequin-snake":	{"NN"},
"harlequinade":	{"NN"},
"harlequins":	{"NNS"},
"harlot":	{"NN"},
"harlotry":	{"NN"},
"harlots":	{"NNS"},
"harlow":	{"NN"},
"harm":	{"NN","VB","VBP"},
"harmattan":	{"NN"},
"harmed":	{"VBD","VBN"},
"harmful":	{"JJ"},
"harmfully":	{"RB"},
"harmfulness":	{"NN"},
"harming":	{"VBG"},
"harmless":	{"JJ"},
"harmlessly":	{"RB"},
"harmlessness":	{"NN"},
"harmonic":	{"JJ","NN"},
"harmonica":	{"NN"},
"harmonical":	{"JJ"},
"harmonically":	{"RB"},
"harmonics":	{"NNS"},
"harmonies":	{"NNS"},
"harmonious":	{"JJ"},
"harmoniously":	{"RB"},
"harmoniousness":	{"NN"},
"harmonisation":	{"NN"},
"harmonise":	{"VB","VBP"},
"harmonised":	{"VBD","VBN"},
"harmoniser":	{"NN"},
"harmonises":	{"VBZ"},
"harmonising":	{"VBG"},
"harmonium":	{"NN"},
"harmonizable":	{"JJ"},
"harmonization":	{"NN"},
"harmonize":	{"VB","VBP"},
"harmonized":	{"VBD","VBN"},
"harmonizer":	{"NN"},
"harmonizes":	{"VBZ"},
"harmonizing":	{"VBG"},
"harmony":	{"NN"},
"harms":	{"VBZ","NNS"},
"harmsworth":	{"NN"},
"harness":	{"NN","VB","VBP"},
"harness-emotions":	{"JJ"},
"harnessed":	{"VBD","VBN"},
"harnesses":	{"NNS","VBZ"},
"harnessing":	{"VBG"},
"harp":	{"NN","VB","VBP"},
"harp-shaped":	{"JJ"},
"harped":	{"VBD","VBN"},
"harper":	{"NN"},
"harpia":	{"NN"},
"harpies":	{"NNS"},
"harping":	{"VBG"},
"harpist":	{"NN"},
"harpists":	{"NNS"},
"harpo":	{"NN"},
"harpoon":	{"NN","VB","VBP"},
"harpooned":	{"VBD","VBN"},
"harpooneer":	{"NN"},
"harpooner":	{"NN"},
"harpooning":	{"VBG"},
"harpoons":	{"NNS","VBZ"},
"harps":	{"NNS","VBZ"},
"harpsichord":	{"NN"},
"harpsichordist":	{"NN"},
"harpsichordists":	{"NNS"},
"harpsichords":	{"NNS"},
"harpulla":	{"NN"},
"harpullia":	{"NN"},
"harpy":	{"NN"},
"harquebus":	{"NN"},
"harrassment":	{"NN"},
"harridan":	{"NN"},
"harridans":	{"NNS"},
"harried":	{"VBD","VBN"},
"harrier":	{"NN"},
"harries":	{"VBZ"},
"harriman":	{"NN"},
"harris":	{"NN"},
"harrisia":	{"NN"},
"harrod":	{"NN"},
"harrow":	{"VB","VBP","NN"},
"harrowed":	{"VBD","VBN"},
"harrowing":	{"JJ","VBG"},
"harrows":	{"NNS","VBZ"},
"harrumph":	{"VB","VBP","NN"},
"harrumphed":	{"VBD","VBN"},
"harrumphing":	{"VBG"},
"harrumphs":	{"VBZ"},
"harry":	{"VB","VBP"},
"harrying":	{"VBG"},
"harsh":	{"JJ"},
"harsh-voiced":	{"JJ"},
"harshen":	{"VB","VBP"},
"harshened":	{"VBD","VBN"},
"harshening":	{"VBG"},
"harshens":	{"VBZ"},
"harsher":	{"JJR"},
"harshest":	{"JJS"},
"harshly":	{"RB"},
"harshness":	{"NN"},
"hart":	{"NN","NNS"},
"hart's-tongue":	{"NN"},
"harte":	{"NN"},
"hartebeest":	{"NN"},
"hartes":	{"NNS"},
"hartford-based":	{"JJ"},
"hartley":	{"NN"},
"harts":	{"NNS"},
"harum-scarum":	{"JJ"},
"harvest":	{"NN","VB","VBP"},
"harvest-lice":	{"NN"},
"harvested":	{"VBD","VBN"},
"harvester":	{"NN"},
"harvesters":	{"NNS"},
"harvestfish":	{"NN"},
"harvesting":	{"NN","VBG"},
"harvestman":	{"NN"},
"harvests":	{"NNS","VBZ"},
"has":	{"VBZ"},
"has-been":	{"NN"},
"has-beens":	{"NNS"},
"haschisch":	{"NN"},
"hasdrubal":	{"NN"},
"hasek":	{"NN"},
"hash":	{"NN","VB","VBP"},
"hashed":	{"VBD","VBN"},
"hasheesh":	{"NN"},
"hasher":	{"NN"},
"hashers":	{"NNS"},
"hashes":	{"VBZ","NNS"},
"hashing":	{"VBG"},
"hashish":	{"NN"},
"hashmark":	{"NN"},
"hashtag":	{"NN","VB","VBP"},
"hashtagged":	{"VBD","VBN"},
"hashtagging":	{"VBG"},
"hashtags":	{"NNS","VBZ"},
"hasid":	{"NN"},
"hasidic":	{"JJ"},
"hasidim":	{"NN"},
"hasidism":	{"NN"},
"haslet":	{"NN"},
"hasp":	{"NN"},
"hasps":	{"NNS"},
"hassel":	{"NN"},
"hassid":	{"NN"},
"hassidic":	{"JJ"},
"hassidim":	{"NN"},
"hassidism":	{"NN"},
"hassium":	{"NN"},
"hassle":	{"NN","VB","VBP"},
"hassled":	{"VBD","VBN"},
"hassles":	{"NNS","VBZ"},
"hassling":	{"VBG"},
"hassock":	{"NN"},
"hassocks":	{"NNS"},
"hast":	{"VBP"},
"hasta":	{"NN"},
"hastate":	{"JJ"},
"haste":	{"NN","VB","VBP"},
"hasted":	{"VBD","VBN"},
"hasten":	{"VB","VBP"},
"hastened":	{"VBD","VBN"},
"hastening":	{"VBG"},
"hastens":	{"VBZ"},
"hastes":	{"VBZ"},
"hastier":	{"JJR"},
"hastiest":	{"JJS"},
"hastily":	{"RB"},
"hastily-summoned":	{"JJ"},
"hastinapura":	{"NN"},
"hastiness":	{"NN"},
"hasting":	{"VBG"},
"hasty":	{"JJ"},
"hat":	{"NN","VB","VBP"},
"hatband":	{"NN"},
"hatbands":	{"NNS"},
"hatbox":	{"NN"},
"hatboxes":	{"NNS"},
"hatch":	{"NN","VB","VBP"},
"hatchback":	{"NN"},
"hatchbacks":	{"NNS"},
"hatched":	{"VBD","VBN"},
"hatchel":	{"NN","VB","VBP"},
"hatcheled":	{"VBD","VBN"},
"hatcheling":	{"VBG"},
"hatchelled":	{"VBD","VBN"},
"hatchelling":	{"VBG"},
"hatchels":	{"VBZ"},
"hatcheries":	{"NNS"},
"hatchery":	{"NN"},
"hatches":	{"VBZ"},
"hatchet":	{"NN","JJ"},
"hatchet-faced":	{"JJ"},
"hatchets":	{"NNS"},
"hatching":	{"NN","VBG"},
"hatchings":	{"NNS"},
"hatchling":	{"NN"},
"hatchway":	{"NN"},
"hatchways":	{"NNS"},
"hate":	{"VBP","NN","VB"},
"hate-mongering":	{"NN"},
"hated":	{"VBD","VBN","JJ"},
"hateful":	{"JJ"},
"hatefully":	{"RB"},
"hatefulness":	{"NN"},
"hatemonger":	{"NN"},
"hater":	{"NN"},
"haters":	{"NNS"},
"hates":	{"VBZ"},
"hatfield":	{"NN"},
"hatful":	{"NN"},
"hath":	{"VBZ"},
"hating":	{"VBG"},
"hatiora":	{"NN"},
"hatless":	{"JJ"},
"hatmaker":	{"NN"},
"hatpin":	{"NN"},
"hatpins":	{"NNS"},
"hatrack":	{"NN"},
"hatred":	{"NN"},
"hats":	{"NNS","VBZ"},
"hatted":	{"VBD","VBN"},
"hatter":	{"NN"},
"hatters":	{"NNS"},
"hattiesburg":	{"NN"},
"hatting":	{"VBG"},
"hauberk":	{"NN"},
"haughtier":	{"JJR"},
"haughtiest":	{"JJS"},
"haughtily":	{"RB"},
"haughtiness":	{"NN"},
"haughty":	{"JJ"},
"haul":	{"VB","VBP","NN"},
"haulage":	{"NN"},
"hauled":	{"VBD","VBN"},
"hauler":	{"NN"},
"haulers":	{"NNS"},
"haulier":	{"NN"},
"hauliers":	{"NNS"},
"hauling":	{"VBG"},
"haulm":	{"NN"},
"hauls":	{"NNS","VBZ"},
"haunch":	{"NN"},
"haunches":	{"NNS"},
"haunt":	{"VB","VBP","NN"},
"haunted":	{"VBD","VBN","JJ"},
"haunting":	{"JJ","VBG"},
"hauntingly":	{"RB"},
"haunts":	{"VBZ","NNS"},
"hausa":	{"NN"},
"hausen":	{"NN"},
"hausmannite":	{"NN"},
"haussa":	{"NN"},
"haustorium":	{"NN"},
"hautbois":	{"NNS"},
"hautboy":	{"NN"},
"haute":	{"JJ"},
"haute-normandie":	{"NN"},
"hauteur":	{"NN"},
"havasupai":	{"NN"},
"have":	{"VB","VBP","NN"},
"have-not":	{"NN"},
"have-nots":	{"NNS"},
"havelock":	{"NN"},
"haven":	{"NN","VB","VBP"},
"havened":	{"VBD","VBN"},
"havening":	{"VBG"},
"havens":	{"NNS","VBZ"},
"haver":	{"VB","VBP"},
"havered":	{"VBD","VBN"},
"havering":	{"VBG"},
"havers":	{"VBZ"},
"haversack":	{"NN"},
"haversacks":	{"NNS"},
"haves":	{"NNS"},
"having":	{"VBG","NN"},
"havoc":	{"NN","VB","VBP"},
"havocked":	{"VBD","VBN"},
"havocking":	{"VBG"},
"havocs":	{"VBZ"},
"haw":	{"VB","VBP","NN","UH"},
"haw-haw":	{"NN"},
"hawai'i":	{"NN"},
"hawala":	{"NN"},
"hawed":	{"VBD","VBN"},
"hawfinch":	{"NN"},
"hawing":	{"VBG","NN"},
"hawk":	{"NN","VB","VBP"},
"hawk's-beard":	{"NN"},
"hawk's-beards":	{"NNS"},
"hawk-eyed":	{"JJ"},
"hawk-faced":	{"JJ"},
"hawk-hatching":	{"JJ"},
"hawk-hunting":	{"JJ"},
"hawkbill":	{"NN"},
"hawkbit":	{"NN"},
"hawke":	{"NN"},
"hawked":	{"VBD","VBN"},
"hawker":	{"NN"},
"hawkers":	{"NNS"},
"hawking":	{"VBG"},
"hawkins":	{"NNS"},
"hawkish":	{"JJ"},
"hawkishness":	{"NN"},
"hawkmoth":	{"NN"},
"hawks":	{"NNS","VBZ"},
"hawksbill":	{"NN"},
"hawkshaw":	{"NN"},
"hawkweed":	{"NN"},
"hawkyns":	{"NNS"},
"haws":	{"NNS","VBZ"},
"hawse":	{"NN"},
"hawsehole":	{"NN"},
"hawsepipe":	{"NN"},
"hawser":	{"NN"},
"hawsers":	{"NNS"},
"hawthorn":	{"NN"},
"hawthorns":	{"NNS"},
"hay":	{"NN","VB","VBP"},
"hay-fever":	{"NN"},
"hay-scented":	{"NN"},
"hay-shakers":	{"NNS"},
"hay-wagon":	{"NN"},
"hayastan":	{"NN"},
"haycock":	{"NN"},
"hayden":	{"NN"},
"hayed":	{"VBD","VBN"},
"hayek":	{"NN"},
"hayfield":	{"NN"},
"hayfields":	{"NNS"},
"hayfork":	{"NN"},
"haying":	{"VBG"},
"hayloft":	{"NN"},
"haylofts":	{"NNS"},
"haymaker":	{"NN"},
"haymaking":	{"NN"},
"haymow":	{"NN"},
"hayrack":	{"NN"},
"hayrick":	{"NN"},
"hayrig":	{"NN"},
"hays":	{"NNS","VBZ"},
"hayseed":	{"NN"},
"haystack":	{"NN"},
"haystacks":	{"NNS"},
"hayti":	{"NN"},
"haywire":	{"JJ"},
"haywood":	{"NN"},
"hazan":	{"NN"},
"hazard":	{"NN","VB","VBP"},
"hazarded":	{"VBD","VBN"},
"hazardia":	{"NN"},
"hazarding":	{"VBG"},
"hazardous":	{"JJ"},
"hazardous-waste":	{"NN","JJ"},
"hazardous-waste-site":	{"NN"},
"hazardously":	{"RB"},
"hazardousness":	{"NN"},
"hazards":	{"NNS","VBZ"},
"haze":	{"NN","VB","VBP"},
"hazed":	{"VBD","VBN"},
"hazel":	{"NN","JJ"},
"hazel-brown":	{"JJ"},
"hazelnut":	{"NN"},
"hazelnuts":	{"NNS"},
"hazels":	{"NNS"},
"hazelwood":	{"NN"},
"hazes":	{"NNS","VBZ"},
"hazier":	{"JJR"},
"haziest":	{"JJS"},
"hazily":	{"RB"},
"haziness":	{"NN"},
"hazing":	{"VBG","NN"},
"hazmat":	{"NN"},
"hazy":	{"JJ"},
"hb":	{"NN"},
"hcfc":	{"NN"},
"hcfcs":	{"NNS"},
"hcg":	{"NN"},
"hdl":	{"NN"},
"hdtv":	{"NN"},
"hdtv-screen":	{"JJ"},
"hdtvs":	{"NNS"},
"he":	{"PRP","NN"},
"he-goat":	{"NN"},
"he-goes-or-I-go":	{"JJ"},
"he-goes-or-i-go":	{"JJ"},
"he-huckleberry":	{"NN"},
"he-man":	{"NN"},
"he-men":	{"NNS"},
"head":	{"NN","VB","VBP"},
"head-and-shoulders":	{"NNS"},
"head-butting":	{"JJ"},
"head-cold":	{"NN"},
"head-dress":	{"NN"},
"head-dresses":	{"NNS"},
"head-hunter":	{"NN"},
"head-hunters":	{"NNS"},
"head-hunting":	{"NN"},
"head-in-the-clouds":	{"JJ"},
"head-injury":	{"NN"},
"head-on":	{"RB","JJ"},
"head-rest":	{"NN"},
"head-set":	{"NN"},
"head-shrinker":	{"NN"},
"head-start":	{"NN"},
"head-starts":	{"NNS"},
"head-to-head":	{"RB","JJ","NN"},
"head-to-heads":	{"NNS"},
"head-topper":	{"NN"},
"head-tossing":	{"NN"},
"headache":	{"NN"},
"headaches":	{"NNS"},
"headband":	{"NN"},
"headbands":	{"NNS"},
"headbang":	{"VB","VBP"},
"headbanged":	{"VBD","VBN"},
"headbanger":	{"NN"},
"headbangers":	{"NNS"},
"headbanging":	{"VBG","JJ","NN"},
"headbangs":	{"VBZ"},
"headboard":	{"NN"},
"headboards":	{"NNS"},
"headbutt":	{"VB","VBP"},
"headbutted":	{"VBD","VBN"},
"headbutting":	{"VBG"},
"headbutts":	{"VBZ"},
"headcheese":	{"NN"},
"headcount":	{"NN"},
"headcount-control":	{"NN"},
"headcounter":	{"NN"},
"headdress":	{"NN"},
"headdresses":	{"NNS"},
"heade":	{"NN"},
"headed":	{"VBN","VBD","JJ"},
"header":	{"NN"},
"headers":	{"NNS"},
"headfast":	{"NN"},
"headfirst":	{"RB"},
"headfish":	{"NN"},
"headful":	{"NN"},
"headgear":	{"NN"},
"headhunter":	{"NN"},
"headhunters":	{"NNS"},
"headier":	{"JJR"},
"headiest":	{"JJS"},
"heading":	{"VBG","NN"},
"headings":	{"NNS"},
"headlamp":	{"NN"},
"headlamps":	{"NNS"},
"headland":	{"NN"},
"headlands":	{"NNS"},
"headless":	{"JJ"},
"headlight":	{"NN"},
"headlights":	{"NNS"},
"headlike":	{"JJ"},
"headline":	{"NN","VBP","VB"},
"headline-grabbing":	{"JJ"},
"headlined":	{"VBD","VBN"},
"headliner":	{"NN"},
"headliners":	{"NNS"},
"headlines":	{"NNS","VBZ"},
"headlinese":	{"NN"},
"headlining":	{"VBG"},
"headlock":	{"NN"},
"headlocks":	{"NNS"},
"headlong":	{"RB","JJ"},
"headman":	{"NN"},
"headmaster":	{"NN"},
"headmasters":	{"NNS"},
"headmastership":	{"NN"},
"headmen":	{"NNS"},
"headmistress":	{"NN"},
"headmistresses":	{"NNS"},
"headmistressship":	{"NN"},
"headphone":	{"NN"},
"headphones":	{"NNS"},
"headpiece":	{"NN"},
"headpieces":	{"NNS"},
"headpin":	{"NN"},
"headquarter":	{"VB","VBP"},
"headquartered":	{"VBD","VBN","JJ"},
"headquartering":	{"VBG"},
"headquarters":	{"NN","NNS","VBZ"},
"headrace":	{"NN"},
"headrest":	{"NN"},
"headrests":	{"NNS"},
"headroom":	{"NN"},
"heads":	{"NNS","VBZ"},
"heads-up":	{"UH"},
"headsail":	{"NN"},
"headscarf":	{"NN"},
"headscarves":	{"NNS"},
"headset":	{"NN"},
"headsets":	{"NNS"},
"headshake":	{"NN"},
"headshaking":	{"NN"},
"headship":	{"NN"},
"headships":	{"NNS"},
"headshot":	{"NN"},
"headsman":	{"NN"},
"headspace":	{"NN"},
"headspring":	{"NN"},
"headstall":	{"NN"},
"headstand":	{"NN"},
"headstands":	{"NNS"},
"headstart":	{"NN"},
"headstarts":	{"NNS"},
"headstock":	{"NN"},
"headstone":	{"NN"},
"headstones":	{"NNS"},
"headstream":	{"NN"},
"headstrong":	{"JJ"},
"headwaiter":	{"NN"},
"headwall":	{"NN"},
"headwalls":	{"NNS"},
"headwater":	{"NN"},
"headwaters":	{"NNS"},
"headway":	{"NN"},
"headwind":	{"NN"},
"headwinds":	{"NNS"},
"headword":	{"NN"},
"headwords":	{"NNS"},
"heady":	{"JJ"},
"heal":	{"VB","VBP"},
"healed":	{"VBD","VBN"},
"healer":	{"NN"},
"healers":	{"NNS"},
"healing":	{"NN","VBG"},
"heals":	{"VBZ"},
"health":	{"NN"},
"health-and-benefits":	{"JJ"},
"health-benefits":	{"JJ"},
"health-care":	{"NN","JJ"},
"health-care-product":	{"NN"},
"health-care-services":	{"JJ"},
"health-club":	{"NN"},
"health-clubs":	{"NNS"},
"health-conscious":	{"JJ"},
"health-coverage":	{"NN"},
"health-expenditure":	{"JJ"},
"health-food":	{"NN"},
"health-foods":	{"NNS"},
"health-insurance":	{"NN"},
"health-maintenance":	{"NN"},
"health-oriented":	{"JJ"},
"health-products":	{"NNS"},
"health-related":	{"JJ"},
"health-services":	{"NNS"},
"healthcare":	{"NN"},
"healthful":	{"JJ"},
"healthfulness":	{"NN"},
"healthier":	{"JJR"},
"healthiest":	{"JJS"},
"healthily":	{"RB"},
"healthiness":	{"NN"},
"healthy":	{"JJ"},
"healthy-looking":	{"JJ"},
"healy":	{"NN"},
"heap":	{"NN","VB","VBP"},
"heaped":	{"JJ","VBD","VBN"},
"heaping":	{"VBG"},
"heaps":	{"NNS","VBZ"},
"hear":	{"VB","VBP"},
"hearable":	{"JJ"},
"heard":	{"VBN","VBD"},
"heare":	{"VB","VBP"},
"hearer":	{"NN"},
"hearers":	{"NNS"},
"hearest":	{"VBP","VB"},
"hearing":	{"NN","VBG"},
"hearing-aid":	{"NN"},
"hearing-aids":	{"NNS"},
"hearing-impaired":	{"JJ"},
"hearings":	{"NNS"},
"hearken":	{"VB","VBP"},
"hearkened":	{"VBD","VBN"},
"hearkening":	{"VBG"},
"hearkens":	{"VBZ"},
"hears":	{"VBZ"},
"hearsay":	{"NN"},
"hearse":	{"NN"},
"hearses":	{"NNS"},
"heart":	{"NN","VB","VBP"},
"heart-break":	{"NN"},
"heart-breaking":	{"JJ"},
"heart-breaks":	{"NNS"},
"heart-broken":	{"JJ"},
"heart-disease":	{"NN"},
"heart-healthy":	{"JJ"},
"heart-leaf":	{"NN"},
"heart-measuring":	{"JJ"},
"heart-pounding":	{"JJ"},
"heart-rending":	{"JJ"},
"heart-shaped":	{"JJ"},
"heart-stopping":	{"JJ"},
"heart-throb":	{"NN"},
"heart-throbs":	{"NNS"},
"heart-to-heart":	{"JJ","NN"},
"heart-to-hearts":	{"NNS"},
"heart-warming":	{"JJ"},
"heart-whole":	{"JJ"},
"heart-wrenching":	{"JJ"},
"heartache":	{"NN"},
"heartaches":	{"NNS"},
"heartbeat":	{"NN"},
"heartbeats":	{"NNS"},
"heartbreak":	{"NN"},
"heartbreaker":	{"NN"},
"heartbreaking":	{"JJ"},
"heartbreakingly":	{"RB"},
"heartbreaks":	{"NNS"},
"heartbroken":	{"JJ"},
"heartburn":	{"NN"},
"heartburning":	{"NN"},
"hearted":	{"VBD","VBN","JJ"},
"heartedly":	{"RB"},
"hearten":	{"VB","VBP"},
"heartened":	{"VBD","VBN","JJ"},
"heartening":	{"JJ","VBG"},
"hearteningly":	{"RB"},
"heartens":	{"VBZ"},
"heartfelt":	{"JJ"},
"heartful":	{"JJ"},
"hearth":	{"NN"},
"hearthrug":	{"NN"},
"hearths":	{"NNS"},
"hearthstone":	{"NN"},
"heartier":	{"JJR"},
"heartiest":	{"JJS"},
"heartily":	{"RB"},
"heartiness":	{"NN"},
"hearting":	{"VBG"},
"heartland":	{"NN"},
"heartlands":	{"NNS"},
"heartleaf":	{"NN"},
"heartless":	{"JJ"},
"heartlessly":	{"RB"},
"heartlessness":	{"NN"},
"heartrending":	{"JJ"},
"heartrot":	{"NN"},
"hearts":	{"NNS","VBZ"},
"heartsease":	{"NN"},
"heartseed":	{"NN"},
"heartsick":	{"JJ"},
"heartsickness":	{"NN"},
"heartstopping":	{"JJ"},
"heartstring-plucking":	{"JJ"},
"heartstrings":	{"NNS"},
"heartthrob":	{"NN"},
"heartthrobs":	{"NNS"},
"heartwarming":	{"JJ"},
"heartwarmingly":	{"RB"},
"heartwood":	{"NN"},
"hearty":	{"JJ","NN"},
"heat":	{"NN","VB","VBP"},
"heat-absorbing":	{"JJ"},
"heat-and-eat":	{"JJ"},
"heat-denatured":	{"JJ"},
"heat-processing":	{"JJ"},
"heat-releasing":	{"JJ"},
"heat-resistant":	{"JJ"},
"heat-treatment":	{"NN"},
"heat-using":	{"JJ"},
"heatable":	{"JJ"},
"heated":	{"VBN","JJ","VBD"},
"heatedly":	{"RB"},
"heater":	{"NN"},
"heaters":	{"NNS"},
"heath":	{"NN"},
"heathen":	{"NN","NNS","JJ"},
"heathenish":	{"JJ"},
"heathenism":	{"NN"},
"heathens":	{"NNS"},
"heather":	{"NN"},
"heathfowl":	{"NN"},
"heathland":	{"NN"},
"heathlike":	{"JJ"},
"heathrow":	{"NN"},
"heaths":	{"NNS"},
"heating":	{"NN","VBG"},
"heatless":	{"JJ"},
"heats":	{"NNS","VBZ"},
"heatshield":	{"NN"},
"heatstroke":	{"NN"},
"heaume":	{"NN"},
"heave":	{"NN","VB","VBP"},
"heaved":	{"VBD","VBN"},
"heaven":	{"NN"},
"heaven-sent":	{"JJ"},
"heavenly":	{"JJ"},
"heavens":	{"NNS"},
"heavenward":	{"RB"},
"heavenwardly":	{"RB"},
"heavenwards":	{"RB"},
"heaver":	{"NN"},
"heavers":	{"NNS"},
"heaves":	{"NNS","VBZ"},
"heavier":	{"JJR"},
"heavier-than-air":	{"JJ"},
"heavier-than-normal":	{"JJ"},
"heavier-than-usual":	{"JJ"},
"heavies":	{"NNS"},
"heaviest":	{"JJS"},
"heavily":	{"RB"},
"heavily-upholstered":	{"JJ"},
"heaviness":	{"NN"},
"heaving":	{"JJ","VBG"},
"heaviside":	{"NN"},
"heavy":	{"JJ","RB","NN"},
"heavy-armed":	{"JJ"},
"heavy-coated":	{"JJ"},
"heavy-construction":	{"NN"},
"heavy-crude":	{"NN"},
"heavy-duty":	{"JJ"},
"heavy-electrical-goods":	{"JJ"},
"heavy-faced":	{"JJ"},
"heavy-footed":	{"JJ"},
"heavy-framed":	{"JJ"},
"heavy-handed":	{"JJ"},
"heavy-handedness":	{"NN"},
"heavy-hitter":	{"NN"},
"heavy-hitters":	{"NNS"},
"heavy-industry":	{"NN"},
"heavy-laden":	{"JJ"},
"heavy-limbed":	{"JJ"},
"heavy-machine":	{"JJ"},
"heavy-tracked":	{"JJ"},
"heavy-truck":	{"NN","NNS"},
"heavy-water":	{"NN"},
"heavy-weight":	{"JJ"},
"heavyhearted":	{"JJ"},
"heavyheartedness":	{"NN"},
"heavyset":	{"JJ"},
"heavyweight":	{"NN"},
"heavyweights":	{"NNS"},
"hebbel":	{"NN"},
"hebdomad":	{"NN"},
"hebdomadal":	{"JJ"},
"hebdomadally":	{"RB"},
"hebdomadary":	{"JJ"},
"hebe":	{"NN"},
"hebei":	{"NN"},
"hebephrenia":	{"NN"},
"hebephrenic":	{"JJ"},
"hebert":	{"NN"},
"hebetude":	{"NN"},
"hebraical":	{"JJ"},
"hecate":	{"NN"},
"hecatomb":	{"NN"},
"hecht":	{"NN"},
"heck":	{"NN","UH"},
"heckelphone":	{"NN"},
"heckle":	{"VB","VBP","NN"},
"heckled":	{"VBD","VBN"},
"heckler":	{"NN"},
"hecklers":	{"NNS"},
"heckles":	{"VBZ","NNS"},
"heckling":	{"VBG","NN"},
"heckman":	{"NN"},
"hectare":	{"NN"},
"hectares":	{"NNS"},
"hectic":	{"JJ"},
"hectically":	{"RB"},
"hectogram":	{"NN"},
"hectograph":	{"NN","VB","VBP"},
"hectographed":	{"VBD","VBN"},
"hectographic":	{"JJ"},
"hectographically":	{"RB"},
"hectographing":	{"VBG"},
"hectographs":	{"NNS","VBZ"},
"hectography":	{"NN"},
"hectoliter":	{"NN"},
"hectolitre":	{"NN"},
"hectometer":	{"NN"},
"hectometre":	{"NN"},
"hector":	{"VB","VBP"},
"hectored":	{"VBD","VBN"},
"hectoring":	{"VBG","JJ"},
"hectors":	{"VBZ"},
"hedeoma":	{"NN"},
"hedera":	{"NN"},
"hedge":	{"NN","VB","VBP"},
"hedge-sparrow":	{"NN"},
"hedged":	{"VBD","VBN","JJ"},
"hedgefund":	{"NN"},
"hedgehog":	{"NN"},
"hedgehogs":	{"NNS"},
"hedgehop":	{"VB","VBP"},
"hedgehopped":	{"VBD","VBN"},
"hedgehopper":	{"NN"},
"hedgehopping":	{"VBG","NN"},
"hedgehops":	{"VBZ"},
"hedger":	{"NN"},
"hedgerow":	{"NN"},
"hedgerows":	{"NNS"},
"hedgers":	{"NNS"},
"hedges":	{"NNS","VBZ"},
"hedging":	{"VBG"},
"hediondilla":	{"NN"},
"hedjaz":	{"NN"},
"hedonic":	{"JJ"},
"hedonism":	{"NN"},
"hedonist":	{"NN"},
"hedonistic":	{"JJ"},
"hedonists":	{"NNS"},
"hedysarum":	{"NN"},
"hee-haw":	{"NN"},
"heebie-jeebies":	{"NNS"},
"heed":	{"NN","VB","VBP"},
"heeded":	{"VBD","VBN"},
"heedful":	{"JJ"},
"heedfully":	{"RB"},
"heedfulness":	{"NN"},
"heeding":	{"VBG"},
"heedless":	{"JJ","NN"},
"heedlessly":	{"RB"},
"heedlessness":	{"NN"},
"heeds":	{"NNS","VBZ"},
"heel":	{"NN","VB","VBP"},
"heelbone":	{"NN"},
"heeled":	{"VBD","VBN","JJ"},
"heeler":	{"NN"},
"heelers":	{"NNS"},
"heeling":	{"VBG"},
"heels":	{"NNS","VBZ"},
"heelsthe":	{"DT"},
"hefa":	{"NN"},
"hefner":	{"NN"},
"heft":	{"NN","VB","VBP"},
"hefted":	{"VBD","VBN"},
"heftier":	{"JJR"},
"heftiest":	{"JJS"},
"heftiness":	{"NN"},
"hefting":	{"VBG"},
"hefts":	{"VBZ"},
"hefty":	{"JJ"},
"hegari":	{"NN"},
"hegelian":	{"JJ","NN"},
"hegemon":	{"NN"},
"hegemonic":	{"JJ"},
"hegemony":	{"NN"},
"heh":	{"UH"},
"heh-heh":	{"UH"},
"heidegger":	{"NN"},
"heifer":	{"NN"},
"heifers":	{"NNS"},
"heighborhoods":	{"NNS"},
"height":	{"NN"},
"height-to-diameter":	{"NN"},
"heighten":	{"VB","VBP"},
"heightened":	{"VBD","VBN"},
"heightening":	{"VBG"},
"heightens":	{"VBZ"},
"heights":	{"NNS"},
"heilong":	{"NN"},
"heimdal":	{"NN"},
"heimdall":	{"NN"},
"heimdallr":	{"NN"},
"heinlein":	{"NN"},
"heinous":	{"JJ"},
"heinously":	{"RB"},
"heinousness":	{"NN"},
"heinz":	{"NN"},
"heinze":	{"NN"},
"heir":	{"NN"},
"heir-apparent":	{"NN"},
"heir-at-law":	{"NN"},
"heir-designate":	{"NN"},
"heiress":	{"NN"},
"heiresses":	{"NNS"},
"heirloom":	{"NN"},
"heirlooms":	{"NNS"},
"heirs":	{"NNS"},
"heirs-apparent":	{"NNS"},
"heist":	{"NN","VB","VBP"},
"heisted":	{"VBD","VBN"},
"heisting":	{"VBG"},
"heists":	{"NNS","VBZ"},
"hejaz":	{"NN"},
"hel":	{"NN"},
"hela":	{"NN"},
"held":	{"VBN","VBD"},
"helenium":	{"NN"},
"heleodytes":	{"NN"},
"heliac":	{"JJ"},
"heliacal":	{"JJ"},
"heliamphora":	{"NN"},
"helianthemum":	{"NN"},
"helianthus":	{"NN"},
"helibor":	{"NN"},
"helical":	{"JJ"},
"helices":	{"NNS"},
"helichrysum":	{"NN"},
"helicidae":	{"NN"},
"helicon":	{"NN"},
"helicopter":	{"NN","VB","VBP"},
"helicopter-borne":	{"JJ"},
"helicoptered":	{"VBD","VBN"},
"helicoptering":	{"VBG"},
"helicopters":	{"NNS","VBZ"},
"helicteres":	{"NNS"},
"helio-copter":	{"NN"},
"helio-copters":	{"NNS"},
"heliobacter":	{"NN"},
"heliocentric":	{"JJ"},
"heliogram":	{"NN"},
"heliograph":	{"NN"},
"heliogravure":	{"NN"},
"heliolatry":	{"NN"},
"heliometer":	{"NN"},
"helion":	{"NN"},
"heliopause":	{"NN"},
"heliophila":	{"NN"},
"heliopsis":	{"NN"},
"helios":	{"NN"},
"heliosphere":	{"NN"},
"heliotherapy":	{"NN"},
"heliothis":	{"NN"},
"heliotrope":	{"NN"},
"heliotropism":	{"NN"},
"heliotype":	{"NN"},
"heliozoa":	{"NN"},
"heliozoan":	{"NN"},
"heliport":	{"NN"},
"heliports":	{"NNS"},
"helipterum":	{"NN"},
"helium":	{"NN"},
"helix":	{"NN"},
"hell":	{"NN","UH"},
"hell-bent":	{"JJ"},
"hell-bound":	{"JJ"},
"hell-fire":	{"NN"},
"hell-for-leather":	{"RB"},
"hell-kite":	{"NN"},
"hell-kitten":	{"NN"},
"hell-raising":	{"NN"},
"hell-rooster":	{"NN"},
"hellbender":	{"NN"},
"hellcat":	{"NN"},
"hellebore":	{"NN"},
"helleborine":	{"NN"},
"helleborus":	{"NN"},
"hellenistical":	{"JJ"},
"heller":	{"NN"},
"helleri":	{"NN"},
"hellfire":	{"NN"},
"hellgrammiate":	{"NN"},
"hellhole":	{"NN"},
"hellholes":	{"NNS"},
"hellhound":	{"NN"},
"hellion":	{"NN"},
"hellish":	{"JJ"},
"hellishly":	{"RB"},
"hello":	{"UH","NN"},
"helloed":	{"VBD","VBN"},
"helloes":	{"VBZ"},
"helloing":	{"VBG"},
"hellos":	{"NNS"},
"hells":	{"NNS"},
"helluva":	{"JJ"},
"helm":	{"NN","VB","VBP"},
"helmed":	{"VBD","VBN"},
"helmet":	{"NN"},
"helmet-shaped":	{"JJ"},
"helmeted":	{"VBD","VBN","JJ"},
"helmetflower":	{"NN"},
"helmeting":	{"VBG"},
"helmets":	{"NNS","VBZ"},
"helmholtz":	{"NN"},
"helming":	{"VBG"},
"helminth":	{"NN"},
"helminthiasis":	{"NN"},
"helminthic":	{"JJ","NN"},
"helminthostachys":	{"NNS"},
"helms":	{"NNS","VBZ"},
"helmsman":	{"NN"},
"helmsmen":	{"NNS"},
"heloderma":	{"NN"},
"helodermatidae":	{"NN"},
"helot":	{"NN"},
"helotiaceae":	{"NN"},
"helotiales":	{"NNS"},
"helotism":	{"NN"},
"helotium":	{"NN"},
"help":	{"VB","NN","VBP"},
"help-me-make-it-through-the-fiscal-nigh":	{"JJ"},
"help-wanted":	{"JJ"},
"helpdesk":	{"NN"},
"helped":	{"VBD","VBN"},
"helper":	{"NN"},
"helpers":	{"NNS"},
"helpful":	{"JJ"},
"helpfully":	{"RB"},
"helpfulness":	{"NN"},
"helping":	{"VBG","NN"},
"helpings":	{"NNS"},
"helpless":	{"JJ"},
"helplessly":	{"RB"},
"helplessness":	{"NN"},
"helpmate":	{"NN"},
"helpmates":	{"NNS"},
"helpmeet":	{"NN"},
"helps":	{"VBZ","NNS"},
"helsingfors":	{"NNS"},
"helsinki-based":	{"JJ"},
"helter-skelter":	{"JJ","RB","NN"},
"helve":	{"NN"},
"helvella":	{"NN"},
"helvellaceae":	{"NN"},
"helvetica":	{"NN"},
"helwingia":	{"NN"},
"helxine":	{"NN"},
"hem":	{"NN","VB","VBP"},
"hemachatus":	{"NN"},
"hemagglutinate":	{"VB"},
"hemagglutination":	{"NN"},
"hemal":	{"JJ"},
"hemangioma":	{"NN"},
"hematal":	{"JJ"},
"hematemesis":	{"NN"},
"hematic":	{"JJ"},
"hematin":	{"NN"},
"hematinic":	{"JJ"},
"hematite":	{"NN"},
"hematocele":	{"NN"},
"hematochezia":	{"NN"},
"hematochrome":	{"NN"},
"hematocoele":	{"NN"},
"hematocolpometra":	{"NN"},
"hematocolpos":	{"NNS"},
"hematocrit":	{"NN"},
"hematocyst":	{"NN"},
"hematocytopenia":	{"NN"},
"hematocyturia":	{"NN"},
"hematogenesis":	{"NN"},
"hematogenic":	{"JJ"},
"hematohiston":	{"NN"},
"hematoidin":	{"NN"},
"hematologic":	{"JJ"},
"hematological":	{"JJ"},
"hematologist":	{"NN"},
"hematology":	{"NN"},
"hematolysis":	{"NN"},
"hematoma":	{"NN"},
"hematopoiesis":	{"NN"},
"hematopoietic":	{"JJ"},
"hematuria":	{"NN"},
"heme":	{"NN"},
"hemeralopia":	{"NN"},
"hemerobiid":	{"NN"},
"hemerobiidae":	{"NN"},
"hemerocallidaceae":	{"NN"},
"hemerocallis":	{"NN"},
"hemetin":	{"NN"},
"hemiacetal":	{"NN"},
"hemianopia":	{"NN"},
"hemianopsia":	{"NN"},
"hemiascomycetes":	{"NNS"},
"hemic":	{"JJ"},
"hemicrania":	{"NN"},
"hemicycle":	{"NN"},
"hemidemisemiquaver":	{"NN"},
"hemiepiphyte":	{"NN"},
"hemigalus":	{"NN"},
"hemigrammus":	{"NN"},
"hemimetabola":	{"NN"},
"hemimetabolic":	{"JJ"},
"hemimetabolism":	{"NN"},
"hemimetabolous":	{"JJ"},
"hemimetaboly":	{"NN"},
"hemimetamorphic":	{"JJ"},
"hemimetamorphosis":	{"NN"},
"hemimetamorphous":	{"JJ"},
"hemimorphite":	{"NN"},
"hemin":	{"NN"},
"heming":	{"NN"},
"hemingwayesque":	{"JJ"},
"hemiparasite":	{"NN"},
"hemiparasitic":	{"JJ"},
"hemiplegia":	{"NN"},
"hemiplegic":	{"NN"},
"hemipode":	{"NN"},
"hemiprocnidae":	{"NN"},
"hemiptera":	{"NN"},
"hemipteran":	{"JJ"},
"hemipteron":	{"NN"},
"hemipteronatus":	{"NN"},
"hemiramphidae":	{"NN"},
"hemisphere":	{"NN"},
"hemispheres":	{"NNS"},
"hemispheric":	{"JJ"},
"hemispherical":	{"JJ"},
"hemitripterus":	{"NN"},
"hemline":	{"NN"},
"hemlines":	{"NNS"},
"hemlock":	{"NN"},
"hemlocks":	{"NNS"},
"hemmed":	{"VBD","VBN"},
"hemmer":	{"NN"},
"hemming":	{"NN","VBG"},
"hemming-stitch":	{"NN"},
"hemminge":	{"NN"},
"hemochromatosis":	{"NN"},
"hemodialysis":	{"NN"},
"hemodialyzer":	{"NN"},
"hemodynamic":	{"JJ"},
"hemodynamics":	{"NN"},
"hemofil":	{"NN"},
"hemogenesis":	{"NN"},
"hemoglobin":	{"NN"},
"hemoglobinemia":	{"NN"},
"hemoglobinopathy":	{"NN"},
"hemoglobinuria":	{"NN"},
"hemolysin":	{"NN"},
"hemolysis":	{"NN"},
"hemolytic":	{"JJ"},
"hemophile":	{"NN"},
"hemophilia":	{"NN"},
"hemophiliac":	{"NN"},
"hemophiliacs":	{"NNS"},
"hemophilic":	{"JJ"},
"hemopoiesis":	{"NN"},
"hemopoietic":	{"JJ"},
"hemoprotein":	{"NN"},
"hemoptysis":	{"NN"},
"hemorrhage":	{"NN","VB","VBP"},
"hemorrhaged":	{"VBD","VBN"},
"hemorrhages":	{"NNS","VBZ"},
"hemorrhagic":	{"JJ"},
"hemorrhaging":	{"VBG"},
"hemorrhoid":	{"NN"},
"hemorrhoidectomy":	{"NN"},
"hemorrhoids":	{"NNS"},
"hemosiderin":	{"NN"},
"hemosiderosis":	{"NN"},
"hemostasia":	{"NN"},
"hemostasis":	{"NN"},
"hemostat":	{"NN"},
"hemostatic":	{"JJ"},
"hemothorax":	{"NN"},
"hemp":	{"NN"},
"hempen":	{"JJ"},
"hems":	{"VBZ","NNS"},
"hemstitch":	{"NN"},
"hemstitching":	{"NN"},
"hen":	{"NN"},
"hen-coop":	{"NN"},
"hen-house":	{"NN"},
"hen-of-the-woods":	{"NNS"},
"hen-parties":	{"NNS"},
"hen-party":	{"NN"},
"henbane":	{"NN"},
"henbit":	{"NN"},
"hence":	{"RB"},
"henceforth":	{"RB"},
"henceforward":	{"RB"},
"henchman":	{"NN"},
"henchmen":	{"NNS"},
"hencoop":	{"NN"},
"hendiadys":	{"NNS"},
"henhouse":	{"NN"},
"henhouses":	{"NNS"},
"henley":	{"NN"},
"henna":	{"NN","VB","VBP"},
"hennaed":	{"JJ","VBD","VBN"},
"hennaing":	{"VBG"},
"hennas":	{"VBZ"},
"henning":	{"NN"},
"henpeck":	{"VB","VBP"},
"henpecked":	{"JJ","VBD","VBN"},
"henpecking":	{"VBG"},
"henpecks":	{"VBZ"},
"henri":	{"NN"},
"henroost":	{"NN"},
"hens":	{"NNS"},
"hep":	{"JJ"},
"hepadnavirus":	{"NN"},
"heparin":	{"NN"},
"hepatic":	{"JJ"},
"hepatica":	{"NN"},
"hepaticae":	{"NN"},
"hepaticopsida":	{"NN"},
"hepatitis":	{"NN"},
"hepatocarcinoma":	{"NN"},
"hepatoflavin":	{"NN"},
"hepatoma":	{"NN"},
"hepatomegaly":	{"NN"},
"hepatotoxic":	{"JJ"},
"hepatotoxin":	{"NN"},
"hepburn":	{"NN"},
"hephaestus":	{"NN"},
"hephaistos":	{"NN"},
"heptachlor":	{"NN"},
"heptad":	{"NN"},
"heptagon":	{"NN"},
"heptane":	{"NN"},
"hepworth":	{"NN"},
"her":	{"PRP$","PRP"},
"heracles":	{"NN"},
"heracleum":	{"NN"},
"heraclitus":	{"NN"},
"herakles":	{"NN"},
"herald":	{"VB","VBP","NN"},
"heralded":	{"VBD","VBN"},
"heraldic":	{"JJ"},
"heralding":	{"VBG"},
"heraldist":	{"JJ"},
"heraldry":	{"NN"},
"heralds":	{"VBZ","NNS"},
"herat":	{"NN"},
"herb":	{"NN"},
"herbaceous":	{"JJ"},
"herbage":	{"NN"},
"herbal":	{"JJ","NN"},
"herbalist":	{"NN"},
"herbalists":	{"NNS"},
"herbals":	{"NNS"},
"herbarium":	{"NN"},
"herbart":	{"NN"},
"herbicide":	{"NN"},
"herbicides":	{"NNS"},
"herbivore":	{"NN"},
"herbivores":	{"NNS"},
"herbivorous":	{"JJ"},
"herbs":	{"NNS"},
"herculaneum":	{"NN"},
"herculean":	{"JJ"},
"hercules'-club":	{"NN"},
"hercules'-clubs":	{"NNS"},
"hercules-club":	{"NN"},
"herculius":	{"NN"},
"herd":	{"NN","VBP","VB"},
"herd-owner":	{"NN"},
"herded":	{"VBD","VBN"},
"herder":	{"NN"},
"herding":	{"VBG"},
"herds":	{"NNS","VBZ"},
"herdsman":	{"NN"},
"herdsmen":	{"NNS"},
"here":	{"RB","UH"},
"here-for":	{"JJ"},
"hereabout":	{"RB"},
"hereabouts":	{"RB"},
"hereafter":	{"RB","NN"},
"hereby":	{"RB"},
"hereditament":	{"NN"},
"hereditarianism":	{"NN"},
"hereditary":	{"JJ"},
"heredity":	{"NN"},
"herein":	{"RB"},
"hereinafter":	{"RB"},
"hereinbefore":	{"RB"},
"hereness":	{"NN"},
"hereof":	{"RB"},
"herero":	{"NN"},
"heresies":	{"NNS"},
"heresy":	{"NN"},
"heretic":	{"NN"},
"heretical":	{"JJ"},
"heretics":	{"NN"},
"hereto":	{"RB"},
"heretofore":	{"RB"},
"heretofore-accepted":	{"JJ"},
"hereunder":	{"RB"},
"hereunto":	{"RB"},
"hereupon":	{"RB"},
"herewith":	{"RB"},
"heritable":	{"JJ"},
"heritage":	{"NN"},
"heritages":	{"NNS"},
"heritiera":	{"NN"},
"heritor":	{"NN"},
"herm":	{"NN"},
"hermann":	{"NN"},
"hermannia":	{"NN"},
"hermaphrodism":	{"NN"},
"hermaphrodite":	{"NN","JJ"},
"hermaphrodites":	{"NNS"},
"hermaphroditic":	{"JJ"},
"hermaphroditism":	{"NN"},
"hermaphroditus":	{"NNS"},
"hermeneutic":	{"JJ"},
"hermeneutics":	{"NN"},
"hermetic":	{"JJ"},
"hermetically":	{"RB"},
"hermissenda":	{"NN"},
"hermit":	{"NN"},
"hermitage":	{"NN"},
"hermitages":	{"NNS"},
"hermitic":	{"JJ"},
"hermitical":	{"JJ"},
"hermits":	{"NNS"},
"hermosillo":	{"NN"},
"hernaria":	{"NN"},
"hernia":	{"NN"},
"hernias":	{"NNS"},
"herniate":	{"VB","VBP"},
"herniated":	{"VBD","VBN"},
"herniates":	{"VBZ"},
"herniating":	{"VBG"},
"herniation":	{"NN"},
"hero":	{"NN"},
"hero-worship":	{"NN","VB","VBP"},
"hero-worshipped":	{"VBD","VBN"},
"hero-worshippers":	{"NNS"},
"hero-worshipping":	{"VBG"},
"hero-worships":	{"VBZ"},
"heroes":	{"NNS"},
"heroic":	{"JJ"},
"heroical":	{"JJ"},
"heroically":	{"RB"},
"heroics":	{"NNS"},
"heroin":	{"NN"},
"heroin-user":	{"NN"},
"heroine":	{"NN"},
"heroines":	{"NNS"},
"heroism":	{"NN"},
"heron":	{"NN"},
"heronry":	{"NN"},
"herons":	{"NNS"},
"herpangia":	{"NN"},
"herpes":	{"NN"},
"herpestes":	{"NNS"},
"herpetological":	{"JJ"},
"herpetologist":	{"NN"},
"herpetologists":	{"NNS"},
"herpetology":	{"NN"},
"herrenvolk":	{"NN"},
"herrerasaur":	{"NN"},
"herrerasaurus":	{"NN"},
"herrick":	{"NN"},
"herring":	{"NN","NNS"},
"herringbone":	{"NN"},
"herrings":	{"NNS"},
"hers":	{"PRP"},
"herschel":	{"NN"},
"herself":	{"PRP"},
"hershey":	{"NN"},
"hertha":	{"NN"},
"hertz":	{"NN","NNS"},
"hertzian":	{"JJ"},
"herzberg":	{"NN"},
"heshvan":	{"NN"},
"hesiod":	{"NN"},
"hesiometer":	{"NN"},
"hesitance":	{"NN"},
"hesitancy":	{"NN"},
"hesitant":	{"JJ","NN"},
"hesitantly":	{"RB"},
"hesitate":	{"VB","VBP"},
"hesitated":	{"VBD","VBN"},
"hesitater":	{"NN"},
"hesitates":	{"VBZ"},
"hesitating":	{"VBG"},
"hesitatingly":	{"RB"},
"hesitation":	{"NN"},
"hesitations":	{"NNS"},
"hesitator":	{"NN"},
"hesperian":	{"JJ"},
"hesperides":	{"NNS"},
"hesperiphona":	{"NN"},
"hesperis":	{"NN"},
"hesperus":	{"NN"},
"hessian":	{"NN"},
"hessonite":	{"NN"},
"hestia":	{"NN"},
"heston":	{"NN"},
"het":	{"JJ"},
"heteranthera":	{"NN"},
"heterobasidiomycetes":	{"NNS"},
"heterocephalus":	{"NNS"},
"heterocercal":	{"JJ"},
"heterocycle":	{"NN"},
"heterocyclic":	{"JJ"},
"heterodactyl":	{"JJ"},
"heterodon":	{"NN"},
"heterodox":	{"JJ"},
"heterodoxy":	{"NN"},
"heterodyne":	{"JJ","VB","VBP"},
"heterodyned":	{"VBD","VBN"},
"heterodynes":	{"VBZ"},
"heterodyning":	{"VBG"},
"heteroecious":	{"JJ"},
"heterogamous":	{"JJ"},
"heterogeneity":	{"NN"},
"heterogeneous":	{"JJ"},
"heterogeneously":	{"RB"},
"heterogeneousness":	{"NN"},
"heterogenesis":	{"NN"},
"heterogenous":	{"JJ"},
"heterograft":	{"NN"},
"heteroicous":	{"JJ"},
"heterojNction":	{"NN"},
"heterokontae":	{"NN"},
"heterokontophyta":	{"NN"},
"heterologic":	{"JJ"},
"heterological":	{"JJ"},
"heterologous":	{"JJ"},
"heterology":	{"NN"},
"heteromeles":	{"NNS"},
"heterometabolic":	{"JJ"},
"heterometabolism":	{"NN"},
"heterometabolous":	{"JJ"},
"heterometaboly":	{"NN"},
"heteromyidae":	{"NN"},
"heteronormal":	{"JJ"},
"heteronormative":	{"JJ"},
"heteronormatively":	{"RB"},
"heteronormativities":	{"NNS"},
"heteronormativity":	{"NN"},
"heteronym":	{"NN"},
"heteroploid":	{"NN"},
"heteroploidy":	{"NN"},
"heteroptera":	{"NN"},
"heteroscelus":	{"NNS"},
"heterosexism":	{"NN"},
"heterosexual":	{"NN","JJ"},
"heterosexualism":	{"NN"},
"heterosexuality":	{"NN"},
"heterosexuals":	{"NNS"},
"heterosis":	{"NN"},
"heterosomata":	{"NN"},
"heterosporous":	{"JJ"},
"heterospory":	{"NN"},
"heterostracan":	{"NN"},
"heterostraci":	{"NN"},
"heterotaxy":	{"NN"},
"heterotheca":	{"NN"},
"heterothermic":	{"JJ"},
"heterotrichales":	{"NNS"},
"heterotroph":	{"NN"},
"heterotrophic":	{"JJ"},
"heterozygosity":	{"NN"},
"heterozygote":	{"NN"},
"heterozygous":	{"JJ"},
"heth":	{"NN"},
"heuchera":	{"NN"},
"heulandite":	{"NN"},
"heuristic":	{"JJ"},
"heuristics":	{"NN"},
"heute":	{"FW"},
"hevea":	{"NN"},
"hevesy":	{"NN"},
"hew":	{"VB","VBP"},
"hewed":	{"VBD","VBN"},
"hewer":	{"NN"},
"hewing":	{"VBG"},
"hewlett":	{"NN"},
"hewn":	{"VBN"},
"hews":	{"VBZ"},
"hex":	{"NN","VB","VBP"},
"hexachlorophene":	{"NN"},
"hexad":	{"NN"},
"hexadecimal":	{"JJ"},
"hexadrol":	{"NN"},
"hexagon":	{"NN"},
"hexagonal":	{"JJ"},
"hexagons":	{"NNS"},
"hexagram":	{"NN"},
"hexagrammidae":	{"NN"},
"hexagrammos":	{"NN"},
"hexahedron":	{"NN"},
"hexalectris":	{"NNS"},
"hexametaphosphate":	{"NN"},
"hexameter":	{"NN"},
"hexamita":	{"NN"},
"hexanchidae":	{"NN"},
"hexanchus":	{"NN"},
"hexane":	{"NN"},
"hexangular":	{"JJ"},
"hexapod":	{"NN"},
"hexapoda":	{"NN"},
"hexed":	{"VBD","VBN"},
"hexenbesen":	{"NN"},
"hexes":	{"NNS","VBZ"},
"hexestrol":	{"NN"},
"hexing":	{"VBG"},
"hexose":	{"NN"},
"hey":	{"UH"},
"heyday":	{"NN"},
"heyerdahl":	{"NN"},
"heyrovsky":	{"NN"},
"heyse":	{"NN"},
"heyward":	{"NN"},
"hezekiah":	{"NN"},
"hf":	{"NN"},
"hfc":	{"NN"},
"hg":	{"NN"},
"hhs":	{"NNS"},
"hi":	{"UH"},
"hi-fi":	{"JJ","NN"},
"hi-fis":	{"NNS"},
"hi-graders":	{"NNS"},
"hi-tech":	{"JJ","NN"},
"hiatus":	{"NN"},
"hibachi":	{"NN"},
"hibbertia":	{"NN"},
"hibbing":	{"NN"},
"hibernal":	{"JJ"},
"hibernate":	{"VB","VBP"},
"hibernated":	{"VBD","VBN"},
"hibernates":	{"VBZ"},
"hibernating":	{"VBG"},
"hibernation":	{"NN"},
"hibernia":	{"NN"},
"hibiscus":	{"NNS","NN"},
"hiccough":	{"NN","VB","VBP"},
"hiccoughed":	{"VBN","VBD"},
"hiccoughing":	{"VBG"},
"hiccoughs":	{"NNS","VBZ"},
"hiccup":	{"NN","VBP","VB"},
"hiccupped":	{"VBD","VBN"},
"hiccupping":	{"VBG"},
"hiccups":	{"NNS","VBZ"},
"hick":	{"NN","JJ"},
"hick-self":	{"NN"},
"hickey":	{"NN"},
"hickeys":	{"NNS"},
"hickock":	{"NN"},
"hickories":	{"NNS"},
"hickory":	{"NN"},
"hicks":	{"NNS"},
"hid":	{"VBD"},
"hidatsa":	{"NN"},
"hidden":	{"VBN","JJ"},
"hiddenite":	{"NN"},
"hiddenness":	{"NN"},
"hide":	{"VB","VBP","NN"},
"hide-and-seek":	{"NN"},
"hide-out":	{"NN"},
"hideaway":	{"NN"},
"hideaways":	{"NNS"},
"hidebound":	{"JJ"},
"hideous":	{"JJ"},
"hideously":	{"RB"},
"hideousness":	{"NN"},
"hideout":	{"NN"},
"hideouts":	{"NNS"},
"hiders":	{"NNS"},
"hides":	{"VBZ","NNS"},
"hiding":	{"VBG","NN"},
"hiding-place":	{"NN"},
"hiding-places":	{"NNS"},
"hidrosis":	{"NN"},
"hidrotic":	{"JJ"},
"hie":	{"VB","VBP"},
"hied":	{"VBD","VBN"},
"hieing":	{"VBG"},
"hiemal":	{"JJ"},
"hieracium":	{"NN"},
"hierarch":	{"NN"},
"hierarchal":	{"JJ"},
"hierarchic":	{"JJ"},
"hierarchical":	{"JJ"},
"hierarchically":	{"RB"},
"hierarchies":	{"NNS"},
"hierarchiolgy":	{"NN"},
"hierarchy":	{"NN"},
"hieratic":	{"JJ"},
"hieratical":	{"JJ"},
"hierocracy":	{"NN"},
"hieroglyph":	{"NN"},
"hieroglyphic":	{"JJ"},
"hieroglyphical":	{"JJ"},
"hieroglyphically":	{"RB"},
"hieroglyphics":	{"NN","NNS"},
"hieroglyphs":	{"NNS"},
"hierolatry":	{"NN"},
"hieronymus":	{"NNS"},
"hies":	{"VBZ"},
"hifalutin":	{"JJ"},
"higginson":	{"NN"},
"higgle":	{"VB","VBP"},
"higgledy-piggledy":	{"JJ","RB"},
"high":	{"JJ","NN","RB"},
"high-ability":	{"JJ"},
"high-achieving":	{"JJ"},
"high-angle":	{"JJ"},
"high-bandwidth":	{"JJ"},
"high-carb":	{"NN"},
"high-class":	{"JJ"},
"high-colored":	{"JJ"},
"high-coloured":	{"JJ"},
"high-compression":	{"JJ"},
"high-context":	{"JJ"},
"high-definition":	{"JJ"},
"high-density":	{"JJ"},
"high-dependency":	{"JJ"},
"high-end":	{"JJ"},
"high-energy":	{"JJ"},
"high-fashion":	{"JJ"},
"high-fiber":	{"JJ"},
"high-five":	{"NN","VB","VBP"},
"high-fived":	{"VBD","VBN"},
"high-fives":	{"NNS","VBZ"},
"high-fiving":	{"VBG"},
"high-flier":	{"NN"},
"high-fliers":	{"NNS"},
"high-flyer":	{"NN"},
"high-flyers":	{"NNS"},
"high-flying":	{"JJ"},
"high-grade":	{"JJ"},
"high-handed":	{"JJ"},
"high-handedly":	{"RB"},
"high-handedness":	{"NN"},
"high-hat":	{"NN","JJ","VB","VBP"},
"high-hats":	{"NNS","VBZ"},
"high-hatted":	{"VBD","VBN"},
"high-hatting":	{"VBG"},
"high-heeled":	{"JJ"},
"high-impact":	{"JJ"},
"high-income":	{"JJ"},
"high-interest":	{"JJ"},
"high-jump":	{"JJ"},
"high-key":	{"JJ"},
"high-keyed":	{"JJ"},
"high-level":	{"JJ"},
"high-maintenance":	{"JJ"},
"high-minded":	{"JJ"},
"high-mindedly":	{"RB"},
"high-mindedness":	{"NN"},
"high-muck-a-muck":	{"NN"},
"high-necked":	{"JJ"},
"high-octane":	{"JJ"},
"high-performance":	{"JJ"},
"high-pitched":	{"JJ"},
"high-powered":	{"JJ"},
"high-pressure":	{"JJ","VB","VBP"},
"high-pressured":	{"VBD","VBN"},
"high-pressures":	{"VBZ"},
"high-pressuring":	{"VBG"},
"high-priced":	{"JJ"},
"high-protein":	{"JJ"},
"high-ranking":	{"JJ"},
"high-resolution":	{"JJ"},
"high-rise":	{"JJ","NN"},
"high-rises":	{"NNS"},
"high-risk":	{"JJ"},
"high-rolling":	{"JJ"},
"high-school":	{"JJ"},
"high-schooler":	{"NN"},
"high-schoolers":	{"NNS"},
"high-scoring":	{"JJ"},
"high-sounding":	{"JJ"},
"high-speed":	{"JJ"},
"high-spending":	{"JJ"},
"high-spirited":	{"JJ"},
"high-spiritedly":	{"RB"},
"high-stepper":	{"NN"},
"high-steppers":	{"NNS"},
"high-stepping":	{"JJ"},
"high-sticking":	{"NN"},
"high-strung":	{"JJ"},
"high-style":	{"JJ"},
"high-tail":	{"VB","VBP"},
"high-tailed":	{"VBD","VBN"},
"high-tailing":	{"VBG"},
"high-tails":	{"VBZ"},
"high-tech":	{"JJ"},
"high-technology":	{"JJ"},
"high-tension":	{"JJ"},
"high-test":	{"JJ","NN"},
"high-tests":	{"NNS"},
"high-toned":	{"JJ"},
"high-top":	{"JJ","NN"},
"high-tops":	{"NNS"},
"high-up":	{"NN"},
"high-ups":	{"NNS"},
"high-velocity":	{"JJ"},
"high-voltage":	{"JJ"},
"high-water":	{"JJ"},
"high-wire":	{"JJ"},
"highball":	{"NN","VB","VBP"},
"highballed":	{"VBD","VBN"},
"highballing":	{"VBG"},
"highballs":	{"NNS","VBZ"},
"highborn":	{"JJ"},
"highboy":	{"NN"},
"highboys":	{"NNS"},
"highbred":	{"JJ"},
"highbrow":	{"NN","JJ"},
"highbrowed":	{"JJ"},
"highbrowism":	{"NN"},
"highbrows":	{"NNS"},
"highbush":	{"JJ"},
"highchair":	{"NN"},
"highchairs":	{"NNS"},
"higher":	{"JJR"},
"higher-quality":	{"JJR"},
"higher-resolution":	{"JJR"},
"higher-risk":	{"JJR"},
"higher-up":	{"NN"},
"higher-ups":	{"NNS"},
"highermost":	{"JJ"},
"highest":	{"JJS"},
"highest-grossing":	{"JJ"},
"highest-quality":	{"JJS"},
"highest-resolution":	{"JJS"},
"highest-risk":	{"JJS"},
"highfalutin":	{"JJ"},
"highfaluting":	{"JJ"},
"highflier":	{"NN"},
"highfliers":	{"NNS"},
"highflyer":	{"NN"},
"highflyers":	{"NNS"},
"highflying":	{"JJ"},
"highhanded":	{"JJ"},
"highhandedly":	{"RB"},
"highhandedness":	{"NN"},
"highish":	{"JJ"},
"highjack":	{"NN","VB","VBP"},
"highjacked":	{"VBD","VBN"},
"highjacker":	{"NN"},
"highjacking":	{"NN","VBG"},
"highjacks":	{"NNS","VBZ"},
"highland":	{"JJ","NN"},
"highlander":	{"NN"},
"highlanders":	{"NNS"},
"highlands":	{"NNS"},
"highlife":	{"NN"},
"highlight":	{"NN","VB","VBP"},
"highlighted":	{"VBD","VBN"},
"highlighter":	{"NN"},
"highlighters":	{"NNS"},
"highlighting":	{"NN","VBG"},
"highlights":	{"NNS","VBZ"},
"highly":	{"RB"},
"highly-charged":	{"JJ"},
"highly-paid":	{"JJ"},
"highly-rated":	{"JJ"},
"highly-strung":	{"JJ"},
"highly-trained":	{"JJ"},
"highman":	{"NN"},
"highmen":	{"NNS"},
"highmost":	{"JJ"},
"highness":	{"NN"},
"highnesses":	{"NNS"},
"highroad":	{"NN"},
"highroads":	{"NNS"},
"highs":	{"NNS"},
"highspot":	{"NN"},
"highspots":	{"NNS"},
"hightail":	{"VB","VBP"},
"hightailed":	{"VBD","VBN"},
"hightailing":	{"VBG"},
"hightails":	{"VBZ"},
"hightechnologies":	{"NNS"},
"hightop":	{"NN"},
"highveld":	{"NN"},
"highwater":	{"NN"},
"highway":	{"NN"},
"highwayman":	{"NN"},
"highwaymen":	{"NNS"},
"highways":	{"NNS"},
"highwrought":	{"JJ"},
"higi":	{"NN"},
"hijab":	{"NN"},
"hijabs":	{"NNS"},
"hijack":	{"VB","VBP","NN"},
"hijacked":	{"VBN","VBD"},
"hijacker":	{"NN"},
"hijackers":	{"NNS"},
"hijacking":	{"NN","VBG"},
"hijackings":	{"NNS"},
"hijacks":	{"VBZ","NNS"},
"hijaz":	{"NN"},
"hijinks":	{"NNS"},
"hike":	{"NN","VB","VBP"},
"hiked":	{"VBD","VBN"},
"hiker":	{"NN"},
"hikers":	{"NNS"},
"hikes":	{"VBZ","NNS"},
"hiking":	{"NN","VBG"},
"hilar":	{"JJ"},
"hilarious":	{"JJ"},
"hilariously":	{"RB"},
"hilarity":	{"NN"},
"hilbert":	{"NN"},
"hildebrand":	{"NN"},
"hill":	{"NN","VB","VBP"},
"hillbillies":	{"NNS"},
"hillbilly":	{"NN"},
"hilled":	{"VBD","VBN"},
"hillel":	{"NN"},
"hillier":	{"JJR"},
"hilliest":	{"JJS"},
"hilliness":	{"NN"},
"hilling":	{"VBG"},
"hillock":	{"NN"},
"hillocks":	{"NNS"},
"hills":	{"NNS","VBZ"},
"hills-hollywood":	{"JJ"},
"hillside":	{"NN"},
"hillsides":	{"NNS"},
"hilltop":	{"NN"},
"hilltops":	{"NNS"},
"hillwalker":	{"NN"},
"hillwalkers":	{"NNS"},
"hillwalking":	{"NN"},
"hilly":	{"JJ"},
"hilo":	{"NN"},
"hilt":	{"NN"},
"hilts":	{"NNS"},
"hilum":	{"NN"},
"hilus":	{"NN"},
"him":	{"PRP"},
"himalaya":	{"NN"},
"himalayish":	{"NN"},
"himantoglossum":	{"NN"},
"himantopus":	{"NN"},
"himself":	{"PRP"},
"hin":	{"NN"},
"hinault":	{"NN"},
"hinayana":	{"NN"},
"hinayanism":	{"NN"},
"hinayanist":	{"NN"},
"hind":	{"JJ","NN","NNS"},
"hindbrain":	{"NN"},
"hindenburg":	{"NN"},
"hinder":	{"VB","VBP"},
"hinderance":	{"NN"},
"hindered":	{"VBD","VBN"},
"hindering":	{"VBG"},
"hinderingly":	{"RB"},
"hindermost":	{"JJ"},
"hinders":	{"VBZ"},
"hindfoot":	{"NN"},
"hindgut":	{"NN"},
"hindlimb":	{"NN"},
"hindmost":	{"JJ"},
"hindoo":	{"JJ","NN"},
"hindooism":	{"NN"},
"hindoostani":	{"NN"},
"hindostani":	{"NN"},
"hindquarter":	{"NN"},
"hindquarters":	{"NNS"},
"hindrance":	{"NN"},
"hindrances":	{"NNS"},
"hinds":	{"NNS"},
"hindshank":	{"NN"},
"hindsight":	{"NN"},
"hinduish":	{"JJ"},
"hine":	{"NN"},
"hinge":	{"NN","VB","VBP"},
"hinged":	{"VBN","VBD","JJ"},
"hinges":	{"NNS","VBZ"},
"hinging":	{"VBG"},
"hinny":	{"NN"},
"hint":	{"NN","VB","VBP"},
"hinted":	{"VBD","VBN"},
"hinterland":	{"NN"},
"hinterlands":	{"NNS"},
"hinting":	{"NN","VBG"},
"hints":	{"NNS","VBZ"},
"hip":	{"NN","JJ","UH","VB","VBP"},
"hip-hop":	{"NN"},
"hip-huggers":	{"NNS"},
"hip-length":	{"JJ"},
"hip-pocket":	{"NN"},
"hipbone":	{"NN"},
"hipflask":	{"NN"},
"hiphop":	{"NN"},
"hiplength":	{"JJ"},
"hipless":	{"JJ"},
"hiplike":	{"JJ"},
"hipline":	{"NN"},
"hipparchus":	{"NNS"},
"hippeastrum":	{"NN"},
"hipped":	{"JJ","VBD","VBN"},
"hipper":	{"JJR"},
"hippest":	{"JJS"},
"hippie":	{"NN"},
"hippies":	{"NNS"},
"hipping":	{"VBG"},
"hippo":	{"NN"},
"hippobosca":	{"NN"},
"hippoboscid":	{"NN"},
"hippoboscidae":	{"NN"},
"hippocampus":	{"NN"},
"hippocastanaceae":	{"NN"},
"hippocratic":	{"JJ"},
"hippocrepis":	{"NN"},
"hippodamia":	{"NN"},
"hippodrome":	{"NN"},
"hippoglossoides":	{"NNS"},
"hippoglossus":	{"NNS"},
"hippopotami":	{"NNS"},
"hippopotamidae":	{"NN"},
"hippopotamus":	{"NN"},
"hippopotamuses":	{"NNS"},
"hippos":	{"NNS"},
"hipposideridae":	{"NN"},
"hipposideros":	{"NNS"},
"hippotragus":	{"NNS"},
"hippy":	{"NN"},
"hips":	{"NNS","VBZ"},
"hipster":	{"NN"},
"hipsters":	{"NNS"},
"hipsurus":	{"NN"},
"hircine":	{"JJ"},
"hire":	{"VB","VBP","NN"},
"hire-purchase":	{"NN"},
"hired":	{"VBN","VBD"},
"hireling":	{"NN"},
"hirelings":	{"NNS"},
"hirer":	{"NN"},
"hires":	{"VBZ","NNS"},
"hiring":	{"VBG"},
"hirschfeld":	{"NN"},
"hirschsprung":	{"NN"},
"hirsute":	{"JJ"},
"hirsuteness":	{"NN"},
"hirsutism":	{"NN"},
"hirudinea":	{"NN"},
"hirudinean":	{"NN"},
"hirudinidae":	{"NN"},
"hirudo":	{"NN"},
"hirundinidae":	{"NN"},
"hirundo":	{"NN"},
"his":	{"PRP$","PRP"},
"hispanic-market":	{"JJ"},
"hispaniolan":	{"JJ"},
"hispid":	{"JJ"},
"hiss":	{"VB","VBP","NN"},
"hissed":	{"VBD","VBN"},
"hisself":	{"PRP"},
"hisser":	{"NN"},
"hisses":	{"VBZ","NNS"},
"hissing":	{"NN","VBG"},
"histaminase":	{"NN"},
"histamine":	{"NN"},
"histidine":	{"NN"},
"histiocyte":	{"NN"},
"histiocytosis":	{"NN"},
"histochemical":	{"JJ"},
"histocompatibility":	{"NN"},
"histogram":	{"NN"},
"histoincompatibility":	{"NN"},
"histologic":	{"JJ"},
"histological":	{"JJ"},
"histologically":	{"RB"},
"histologist":	{"NN"},
"histology":	{"NN"},
"histone":	{"NN"},
"historian":	{"NN"},
"historians":	{"NNS"},
"historic":	{"JJ"},
"historical":	{"JJ"},
"historical-claims":	{"NNS"},
"historically":	{"RB"},
"historicalness":	{"NN"},
"historichomes":	{"NNS"},
"historicise":	{"VB","VBP"},
"historicised":	{"VBD","VBN"},
"historicises":	{"VBZ"},
"historicising":	{"VBG"},
"historicism":	{"NN"},
"historicity":	{"NN"},
"historicize":	{"VB","VBP"},
"historicized":	{"VBD","VBN"},
"historicizes":	{"VBZ"},
"historicizing":	{"VBG"},
"historied":	{"JJ"},
"histories":	{"NNS"},
"historiographer":	{"NN"},
"historiography":	{"NN"},
"history":	{"NN"},
"history-making":	{"JJ"},
"history-reenactment":	{"NN"},
"histrion":	{"NN"},
"histrionic":	{"JJ"},
"histrionics":	{"NNS"},
"hit":	{"VBD","NN","VB","VBN","VBP"},
"hit-and-miss":	{"JJ"},
"hit-and-run":	{"JJ"},
"hit-making":	{"JJ"},
"hit-man":	{"NN"},
"hit-or-miss":	{"JJ"},
"hit-run":	{"NN"},
"hitch":	{"VB","VBP","NN"},
"hitch-hike":	{"VB","VBP"},
"hitch-hiked":	{"VBD","VBN"},
"hitch-hiker":	{"NN"},
"hitch-hikers":	{"NNS"},
"hitch-hikes":	{"VBZ"},
"hitch-hiking":	{"VBG"},
"hitched":	{"VBN","VBD"},
"hitches":	{"NNS","VBZ"},
"hitchhike":	{"VB","VBP"},
"hitchhiked":	{"VBD","VBN"},
"hitchhiker":	{"NN"},
"hitchhikers":	{"NNS"},
"hitchhikes":	{"VBZ"},
"hitchhiking":	{"VBG"},
"hitching":	{"VBG"},
"hitchings":	{"NNS"},
"hitchiti":	{"NN"},
"hitchrack":	{"NN"},
"hither":	{"RB"},
"hitherto":	{"RB"},
"hitlerian":	{"JJ"},
"hitless":	{"JJ"},
"hitmakers":	{"NNS"},
"hitman":	{"NN"},
"hitmen":	{"NNS"},
"hits":	{"NNS","VBZ"},
"hitter":	{"NN"},
"hitters":	{"NNS"},
"hitting":	{"VBG"},
"hitting-pitching":	{"JJ"},
"hitwoman":	{"NN"},
"hiv":	{"NN"},
"hiv-related":	{"JJ"},
"hive":	{"NN","VB","VBP"},
"hived":	{"VBD","VBN"},
"hives":	{"NNS","VBZ"},
"hiving":	{"VBG"},
"hizballah":	{"NN"},
"hizbullah":	{"NN"},
"hl":	{"NN"},
"hlts":	{"NNS"},
"hm":	{"UH"},
"hmm":	{"UH"},
"hmmm":	{"UH"},
"hmo":	{"NN"},
"hmong":	{"JJ","NN"},
"hn":	{"NN"},
"ho":	{"UH","NN"},
"ho-hum":	{"UH","JJ"},
"hoactzin":	{"NN"},
"hoagie":	{"NN"},
"hoagland":	{"NN"},
"hoagy":	{"NN"},
"hoar":	{"JJ"},
"hoard":	{"NN","VB","VBP"},
"hoarded":	{"VBD","VBN"},
"hoarder":	{"NN"},
"hoarders":	{"NNS"},
"hoarding":	{"NN","VBG"},
"hoardings":	{"NNS"},
"hoards":	{"VBZ","NNS"},
"hoarfrost":	{"NN"},
"hoarier":	{"JJR"},
"hoariest":	{"JJS"},
"hoariness":	{"NN"},
"hoarse":	{"JJ"},
"hoarsely":	{"RB"},
"hoarseness":	{"NN"},
"hoary":	{"JJ"},
"hoatzin":	{"NN"},
"hoax":	{"NN","VB","VBP"},
"hoaxed":	{"VBD","VBN"},
"hoaxer":	{"NN"},
"hoaxers":	{"NNS"},
"hoaxes":	{"NNS","VBZ"},
"hoaxing":	{"VBG"},
"hob":	{"NN","VB","VBP"},
"hobart":	{"NN"},
"hobbed":	{"VBD","VBN"},
"hobbies":	{"NNS"},
"hobbing":	{"VBG"},
"hobble":	{"VB","VBP","NN"},
"hobbled":	{"VBD","VBN"},
"hobbledehoy":	{"NN"},
"hobbler":	{"NN"},
"hobbles":	{"VBZ"},
"hobbling":	{"VBG","NN"},
"hobby":	{"NN"},
"hobbyhorse":	{"NN"},
"hobbyhorses":	{"NNS"},
"hobbyism":	{"NN"},
"hobbyist":	{"NN"},
"hobbyists":	{"NNS"},
"hobgoblin":	{"NN"},
"hobgoblins":	{"NNS"},
"hobnail":	{"NN"},
"hobnailed":	{"JJ"},
"hobnob":	{"VB","VBP"},
"hobnobbed":	{"VBD","VBN"},
"hobnobbing":	{"VBG"},
"hobnobs":	{"VBZ"},
"hobo":	{"NN"},
"hoboes":	{"NNS"},
"hoboken":	{"NN"},
"hobos":	{"NNS"},
"hobs":	{"NNS","VBZ"},
"hobson":	{"NN"},
"hoc":	{"FW"},
"hock":	{"NN","VB","VBP"},
"hock-joint":	{"NN"},
"hocked":	{"VBD","VBN"},
"hockey":	{"NN"},
"hocking":	{"VBG"},
"hocks":	{"NNS","VBZ"},
"hocus-pocus":	{"NN"},
"hod":	{"NN"},
"hodeida":	{"NN"},
"hoder":	{"NN"},
"hodge-podge":	{"NN"},
"hodgepodge":	{"NN"},
"hodman":	{"NN"},
"hodometer":	{"NN"},
"hodoscope":	{"NN"},
"hodr":	{"NN"},
"hods":	{"NNS"},
"hodur":	{"NN"},
"hoe":	{"NN","VB","VBP"},
"hoecake":	{"NN"},
"hoed":	{"VBD","VBN"},
"hoeing":	{"VBG"},
"hoenir":	{"NN"},
"hoes":	{"NNS","VBZ"},
"hoffman":	{"NN"},
"hoffmann":	{"NN"},
"hoffmannsthal":	{"NN"},
"hofstra":	{"NN"},
"hog":	{"NN","VB","VBP"},
"hog-tie":	{"VB","VBP"},
"hog-tied":	{"VBD","VBN"},
"hog-ties":	{"VBZ"},
"hog-tying":	{"VBG"},
"hogan":	{"NN"},
"hogback":	{"NN"},
"hogchoker":	{"NN"},
"hogfish":	{"NN"},
"hogg":	{"NN"},
"hogged":	{"JJ","VBD","VBN"},
"hogget":	{"NN"},
"hogging":	{"VBG"},
"hoggish":	{"JJ"},
"hoggishness":	{"NN"},
"hogs":	{"NNS","VBZ"},
"hogshead":	{"NN"},
"hogsheads":	{"NNS"},
"hogwash":	{"NN"},
"hogweed":	{"NN"},
"hohenlinden":	{"NN"},
"hohenzollern":	{"NN"},
"hoheria":	{"NN"},
"hohhot":	{"NN"},
"hoi-polloi":	{"NNS"},
"hoist":	{"VB","VBP","NN"},
"hoisted":	{"VBD","VBN"},
"hoister":	{"NN"},
"hoisting":	{"NN","VBG"},
"hoists":	{"VBZ","NNS"},
"hoity-toity":	{"JJ"},
"hoka":	{"NN"},
"hokan":	{"NN"},
"hoke":	{"VB","VBP"},
"hoked":	{"VBD","VBN"},
"hokes":	{"VBZ"},
"hokey":	{"JJ"},
"hoking":	{"VBG"},
"hokkianese":	{"NN"},
"hokum":	{"NN"},
"holarrhena":	{"NN"},
"holbrookia":	{"NN"},
"holcus":	{"NN"},
"hold":	{"VB","VBP","NN"},
"hold-all":	{"NN"},
"hold-alls":	{"NNS"},
"hold-back":	{"NN"},
"hold-down":	{"NN"},
"holdall":	{"NN"},
"holdalls":	{"NNS"},
"holder":	{"NN"},
"holders":	{"NNS"},
"holdfast":	{"NN"},
"holding":	{"VBG","NN"},
"holdings":	{"NNS"},
"holdout":	{"NN"},
"holdouts":	{"NNS"},
"holdover":	{"NN"},
"holdovers":	{"NNS"},
"holds":	{"VBZ","NNS"},
"holdup":	{"NN"},
"holdups":	{"NNS"},
"hole":	{"NN","VB","VBP"},
"hole-and-corner":	{"JJ"},
"hole-in-corner":	{"JJ"},
"hole-in-the-wall":	{"NN"},
"holed":	{"VBD","VBN"},
"holes":	{"NNS","VBZ"},
"holey":	{"JJ"},
"holibut":	{"NN"},
"holiday":	{"NN","VBP","VB"},
"holiday-season":	{"JJ","NN"},
"holidayed":	{"VBD","VBN"},
"holidaying":	{"VBG"},
"holidaymaker":	{"NN"},
"holidaymakers":	{"NNS"},
"holidays":	{"NNS","VBZ"},
"holier":	{"JJR"},
"holier-than-thou":	{"JJ"},
"holies":	{"NNS"},
"holiest":	{"JJS"},
"holiness":	{"NN"},
"holing":	{"VBG"},
"holism":	{"NN"},
"holistic":	{"JJ"},
"holistically":	{"RB"},
"holla":	{"NN"},
"hollandaise":	{"JJ","NN"},
"hollander":	{"NN"},
"hollas":	{"NNS"},
"holler":	{"VB","VBP","NN"},
"hollered":	{"VBD","VBN"},
"hollering":	{"VBG","NN"},
"hollerith":	{"NN"},
"hollers":	{"VBZ","NNS"},
"hollo":	{"NN","UH","VB","VBP"},
"holloa":	{"NN","UH","VB","VBP"},
"holloaed":	{"VBD","VBN"},
"holloaing":	{"VBG"},
"holloas":	{"NNS","VBZ"},
"holloed":	{"VBD","VBN"},
"holloing":	{"VBG"},
"hollos":	{"NNS","VBZ"},
"hollow":	{"JJ","VB","VBP","NN"},
"hollow-back":	{"NN"},
"hollow-eyed":	{"JJ"},
"hollow-horned":	{"JJ"},
"holloware":	{"NN"},
"hollowed":	{"VBD","VBN"},
"hollowing":	{"VBG"},
"hollowly":	{"RB"},
"hollowness":	{"NN"},
"hollows":	{"NNS","VBZ"},
"hollowware":	{"NN"},
"holly":	{"NN"},
"hollygrape":	{"NN"},
"hollyhock":	{"NN"},
"hollyhocks":	{"NNS"},
"holmium":	{"NN"},
"holocaust":	{"NN"},
"holocausts":	{"NNS"},
"holocene":	{"NN"},
"holocentridae":	{"NN"},
"holocentrus":	{"NN"},
"holocephalan":	{"NN"},
"holocephali":	{"NN"},
"holocephalian":	{"NN"},
"holofernes":	{"NNS"},
"hologram":	{"NN"},
"holograms":	{"NNS"},
"holograph":	{"NN"},
"holographic":	{"JJ"},
"holographical":	{"JJ"},
"holography":	{"NN"},
"holometabola":	{"NN"},
"holometabolic":	{"JJ"},
"holometabolism":	{"NN"},
"holometabolous":	{"JJ"},
"holometaboly":	{"NN"},
"holonym":	{"NN"},
"holonymy":	{"NN"},
"holophyte":	{"NN"},
"holophytic":	{"JJ"},
"holored":	{"VBN"},
"holothuria":	{"NN"},
"holothurian":	{"NN"},
"holothuridae":	{"NN"},
"holothuroidea":	{"NN"},
"holotype":	{"NN"},
"holozoic":	{"JJ"},
"holstein-friesian":	{"NN"},
"holster":	{"NN"},
"holstered":	{"JJ"},
"holsters":	{"NNS"},
"holtz":	{"NN"},
"holy":	{"JJ"},
"holystone":	{"NN","VB","VBP"},
"holystoned":	{"VBD","VBN"},
"holystones":	{"NNS","VBZ"},
"holystoning":	{"VBG"},
"homage":	{"NN"},
"homaridae":	{"NN"},
"homarus":	{"NN"},
"hombre":	{"NN"},
"homburg":	{"NN"},
"home":	{"NN","RB","JJ","VB","VBP"},
"home-acquisition":	{"JJ"},
"home-and-home":	{"JJ"},
"home-audience":	{"NN"},
"home-baked":	{"JJ"},
"home-blend":	{"NN"},
"home-bound":	{"JJ"},
"home-bred":	{"JJ"},
"home-brewed":	{"JJ"},
"home-builder":	{"NN"},
"home-building":	{"JJ","NN"},
"home-buying":	{"JJ","NN"},
"home-care":	{"JJ","NN"},
"home-center":	{"NN"},
"home-city":	{"NN"},
"home-comings":	{"NNS"},
"home-computer":	{"NN"},
"home-court":	{"NN","JJ"},
"home-cured":	{"JJ"},
"home-delivered":	{"JJ"},
"home-delivery":	{"NN"},
"home-entertainment":	{"JJ"},
"home-equity":	{"JJ","NN"},
"home-farm":	{"NN"},
"home-fashion":	{"NN"},
"home-field":	{"NN"},
"home-fields":	{"NNS"},
"home-for-the-night":	{"NN"},
"home-furnishing":	{"NN"},
"home-furnishings":	{"NNS"},
"home-grown":	{"JJ"},
"home-health-care":	{"JJ"},
"home-improvement":	{"NN","JJ"},
"home-keeping":	{"JJ"},
"home-loving":	{"JJ"},
"home-made":	{"JJ"},
"home-market":	{"JJ"},
"home-mortgage":	{"JJ"},
"home-nursing":	{"JJ"},
"home-office":	{"JJ"},
"home-owner":	{"NN"},
"home-owners":	{"NNS"},
"home-ownership":	{"NN"},
"home-plate":	{"NN"},
"home-produced":	{"JJ"},
"home-run":	{"NN"},
"home-sale":	{"JJ"},
"home-school":	{"VB","VBP","JJ"},
"home-schooled":	{"VBD","VBN"},
"home-schooling":	{"VBG"},
"home-schools":	{"VBZ","NNS"},
"home-service":	{"JJ"},
"home-sharing":	{"NN"},
"home-shopping":	{"NN"},
"home-state":	{"JJ"},
"home-style":	{"JJ"},
"home-team":	{"JJ"},
"home-trading":	{"NN"},
"home-video":	{"NN"},
"homebodies":	{"NNS"},
"homebody":	{"NN"},
"homebound":	{"JJ"},
"homeboy":	{"NN"},
"homeboys":	{"NNS"},
"homebrew":	{"NN"},
"homebuilder":	{"NN"},
"homebuilders":	{"NNS"},
"homebuilding":	{"NN"},
"homecoming":	{"NN"},
"homecomings":	{"NNS"},
"homed":	{"VBD","VBN"},
"homeequity":	{"NN"},
"homefolk":	{"NN"},
"homegirl":	{"NN"},
"homegirls":	{"NNS"},
"homegrown":	{"JJ"},
"homeier":	{"JJR"},
"homeies":	{"NNS"},
"homeiest":	{"JJS"},
"homel":	{"NN"},
"homeland":	{"NN"},
"homelands":	{"NNS"},
"homeless":	{"JJ","NNS"},
"homelessness":	{"NN"},
"homelier":	{"JJR"},
"homeliest":	{"JJS"},
"homelike":	{"JJ"},
"homeliness":	{"NN"},
"homely":	{"JJ"},
"homemade":	{"JJ"},
"homemaker":	{"NN"},
"homemakers":	{"NNS"},
"homemaking":	{"NN"},
"homemaster":	{"JJ"},
"homeobox":	{"NN"},
"homeopath":	{"NN"},
"homeopathic":	{"JJ"},
"homeopaths":	{"NNS"},
"homeopathy":	{"NN"},
"homeostasis":	{"NN"},
"homeostatic":	{"JJ"},
"homeostatically":	{"RB"},
"homeotherm":	{"NN"},
"homeothermic":	{"JJ"},
"homeowner":	{"NN"},
"homeowners":	{"NNS"},
"homeownership":	{"NN"},
"homepage":	{"NN"},
"homepages":	{"NNS"},
"homer":	{"NN","VB","VBP"},
"homered":	{"VBD","VBN"},
"homering":	{"VBG"},
"homerists":	{"NNS"},
"homeroom":	{"NN"},
"homers":	{"NNS","VBZ"},
"homerun":	{"NN"},
"homes":	{"NNS","VBZ"},
"homeshopping":	{"NN"},
"homesick":	{"JJ"},
"homesickness":	{"NN"},
"homespun":	{"JJ","NN"},
"homestand":	{"NN","CC"},
"homestead":	{"NN","VB","VBP"},
"homesteaded":	{"VBD","VBN"},
"homesteader":	{"NN"},
"homesteaders":	{"NNS"},
"homesteading":	{"VBG"},
"homesteads":	{"NNS","VBZ"},
"homestretch":	{"NN"},
"hometown":	{"NN"},
"hometowns":	{"NNS"},
"homeward":	{"RB","JJ"},
"homeward-bound":	{"JJ"},
"homewards":	{"RB"},
"homework":	{"NN"},
"homey":	{"JJ","NN"},
"homicidal":	{"JJ"},
"homicide":	{"NN"},
"homicides":	{"NNS"},
"homier":	{"JJR"},
"homiest":	{"JJS"},
"homiletic":	{"JJ"},
"homiletical":	{"JJ"},
"homiletics":	{"NN"},
"homilies":	{"NNS"},
"homily":	{"NN"},
"hominal":	{"JJ"},
"homing":	{"JJ","VBG"},
"hominian":	{"JJ"},
"hominid":	{"NN"},
"hominidae":	{"NN"},
"hominin":	{"NN","JJ"},
"hominine":	{"JJ"},
"hominins":	{"NNS"},
"hominisation":	{"NN"},
"hominise":	{"VB","VBP"},
"hominised":	{"VBD","VBN"},
"hominises":	{"VBZ"},
"hominising":	{"VBG"},
"hominization":	{"NN"},
"hominize":	{"VB","VBP"},
"hominized":	{"VBD","VBN"},
"hominizes":	{"VBZ"},
"hominizing":	{"VBG"},
"hominoid":	{"NN","JJ"},
"hominoidea":	{"NN"},
"hominoids":	{"NNS"},
"hominy":	{"NN"},
"hommos":	{"NN"},
"homo":	{"NN"},
"homo-hatred":	{"JJ"},
"homobasidiomycetes":	{"NNS"},
"homocentric":	{"JJ"},
"homocercal":	{"JJ"},
"homochromatic":	{"JJ"},
"homocyclic":	{"JJ"},
"homoecious":	{"JJ"},
"homoeopath":	{"NN"},
"homoeopathic":	{"JJ"},
"homoeopaths":	{"NNS"},
"homoeopathy":	{"NN"},
"homoerotic":	{"JJ"},
"homoeroticism":	{"NN"},
"homogenate":	{"NN"},
"homogeneity":	{"NN"},
"homogeneous":	{"JJ"},
"homogeneously":	{"RB"},
"homogeneousness":	{"NN"},
"homogenisation":	{"NN"},
"homogenise":	{"VB","VBP"},
"homogenised":	{"JJ","VBD","VBN"},
"homogenises":	{"VBZ"},
"homogenising":	{"VBG"},
"homogenization":	{"NN"},
"homogenize":	{"VB","VBP"},
"homogenized":	{"JJ","VBD","VBN"},
"homogenizes":	{"VBZ"},
"homogenizing":	{"VBG"},
"homogenous":	{"JJ"},
"homogeny":	{"NN"},
"homograft":	{"NN"},
"homograph":	{"NN"},
"homographs":	{"NNS"},
"homogyne":	{"NN"},
"homoiotherm":	{"NN"},
"homoiothermic":	{"JJ"},
"homologic":	{"JJ"},
"homological":	{"JJ"},
"homologise":	{"VB","VBP"},
"homologised":	{"VBD","VBN"},
"homologiser":	{"NN"},
"homologises":	{"VBZ"},
"homologising":	{"VBG"},
"homologize":	{"VB","VBP"},
"homologized":	{"VBD","VBN"},
"homologizer":	{"NN"},
"homologizes":	{"VBZ"},
"homologizing":	{"VBG"},
"homologous":	{"JJ"},
"homology":	{"NN"},
"homomorphism":	{"NN"},
"homomorphy":	{"NN"},
"homona":	{"NN"},
"homonym":	{"NN"},
"homonymic":	{"JJ"},
"homonymous":	{"JJ"},
"homonymy":	{"NN"},
"homophile":	{"NN"},
"homophobe":	{"NN"},
"homophobes":	{"NNS"},
"homophobia":	{"NN"},
"homophobic":	{"JJ"},
"homophone":	{"NN"},
"homophonic":	{"JJ"},
"homophonous":	{"JJ"},
"homophony":	{"NN"},
"homopolymers":	{"NNS"},
"homoptera":	{"NN"},
"homopteran":	{"NN"},
"homos":	{"NNS"},
"homosexual":	{"JJ","NN"},
"homosexualism":	{"NN"},
"homosexuality":	{"NN"},
"homosexuals":	{"NNS"},
"homosporous":	{"JJ"},
"homospory":	{"NN"},
"homostyled":	{"JJ"},
"homostylic":	{"JJ"},
"homostylous":	{"JJ"},
"homotherm":	{"NN"},
"homothermic":	{"JJ"},
"homozygosity":	{"NN"},
"homozygote":	{"NN"},
"homozygous":	{"JJ"},
"homunculus":	{"NN"},
"homy":	{"JJ"},
"homyel":	{"NN"},
"hon":	{"NN"},
"honcho":	{"NN"},
"honchos":	{"NNS"},
"hone":	{"VB","NN","VBP"},
"honed":	{"VBD","VBN"},
"honegger":	{"NN"},
"hones":	{"VBZ"},
"honest":	{"JJ","RB"},
"honest-to-Betsy":	{"RB"},
"honest-to-betsy":	{"RB"},
"honest-to-god":	{"JJ"},
"honest-to-goodness":	{"JJ"},
"honestly":	{"RB"},
"honestness":	{"NN"},
"honesty":	{"NN"},
"honey":	{"NN","VB","VBP"},
"honey-colored":	{"JJ"},
"honey-coloured":	{"JJ"},
"honey-flower":	{"NN"},
"honey-in-the-sun":	{"JJ"},
"honey-scented":	{"JJ"},
"honeybee":	{"NN"},
"honeybees":	{"NNS"},
"honeybells":	{"NNS"},
"honeycomb":	{"NN","VB","VBP"},
"honeycombed":	{"JJ","VBD","VBN"},
"honeycombing":	{"VBG"},
"honeycombs":	{"NNS","VBZ"},
"honeycreeper":	{"NN"},
"honeydew":	{"NN"},
"honeyed":	{"JJ","VBD","VBN"},
"honeyflower":	{"NN"},
"honeying":	{"VBG"},
"honeylike":	{"JJ"},
"honeymoon":	{"NN","VB","VBP"},
"honeymooned":	{"VBD","VBN"},
"honeymooner":	{"NN"},
"honeymooners":	{"NNS"},
"honeymooning":	{"VBG"},
"honeymoons":	{"NNS","VBZ"},
"honeypot":	{"NN"},
"honeypots":	{"NNS"},
"honeys":	{"NNS","VBZ"},
"honeysucker":	{"NN"},
"honeysuckle":	{"NN"},
"honeysuckles":	{"NNS"},
"honiara":	{"NN"},
"honied":	{"JJ","VBD","VBN"},
"honiedly":	{"RB"},
"honing":	{"VBG"},
"honk":	{"NN","VB","VBP"},
"honked":	{"VBD","VBN"},
"honker":	{"NN"},
"honkey":	{"NN"},
"honkie":	{"NN"},
"honkies":	{"NNS"},
"honking":	{"VBG"},
"honks":	{"NNS","VBZ"},
"honky":	{"NN"},
"honky-tonk":	{"NN","JJ"},
"honky-tonks":	{"NNS"},
"honkytonk":	{"NN"},
"honolulu-based":	{"JJ"},
"honor":	{"NN","VBP","VB"},
"honorable":	{"JJ"},
"honorableness":	{"NN"},
"honorably":	{"RB"},
"honoraria":	{"NNS"},
"honorarium":	{"NN"},
"honorariums":	{"NNS"},
"honorary":	{"JJ"},
"honored":	{"VBN","VBD"},
"honoree":	{"NN"},
"honorific":	{"NN","JJ"},
"honoring":	{"VBG"},
"honors":	{"NNS","VBZ"},
"honour":	{"NN","VB","VBP"},
"honourable":	{"JJ"},
"honourableness":	{"NN"},
"honourably":	{"RB"},
"honoured":	{"VBN","VBD"},
"honouring":	{"VBG"},
"honours":	{"NNS","VBZ"},
"hoo-ha":	{"NN"},
"hoo-hah":	{"NN"},
"hoo-pig":	{"UH"},
"hooch":	{"NN"},
"hood":	{"NN","VB","VBP"},
"hooded":	{"VBD","VBN","JJ"},
"hoodie":	{"NN"},
"hoodies":	{"NNS"},
"hooding":	{"VBG"},
"hoodle":	{"UH"},
"hoodlum":	{"NN"},
"hoodlums":	{"NNS"},
"hoodmold":	{"NN"},
"hoodmould":	{"NN"},
"hoodoo":	{"NN","VB","VBP"},
"hoodooed":	{"VBD","VBN"},
"hoodooing":	{"VBG"},
"hoodooism":	{"NN"},
"hoodoos":	{"NNS","VBZ"},
"hoods":	{"NNS","VBZ"},
"hoodwink":	{"VB","VBP"},
"hoodwinked":	{"VBD","VBN"},
"hoodwinking":	{"VBG"},
"hoodwinks":	{"VBZ"},
"hoody":	{"NN"},
"hooey":	{"NN"},
"hoof":	{"NN","VB","VBP"},
"hoof-and-mouth":	{"JJ"},
"hoof-mark":	{"NN"},
"hoofed":	{"JJ","VBD","VBN"},
"hoofer":	{"NN"},
"hoofing":	{"VBG"},
"hooflike":	{"JJ"},
"hoofmarks":	{"NNS"},
"hoofprint":	{"NN"},
"hoofs":	{"NNS","VBZ"},
"hook":	{"NN","VB","VBP"},
"hook-nosed":	{"JJ"},
"hook-shaped":	{"JJ"},
"hook-up":	{"NN"},
"hookah":	{"NN"},
"hooke":	{"NN"},
"hooked":	{"JJ","VBD","VBN"},
"hooker":	{"NN"},
"hookers":	{"NNS"},
"hooking":	{"VBG"},
"hooklike":	{"JJ"},
"hooknose":	{"NN"},
"hooks":	{"NNS","VBZ"},
"hookup":	{"NN"},
"hookups":	{"NNS"},
"hookworm":	{"NN"},
"hooky":	{"NN"},
"hooligan":	{"NN"},
"hooliganism":	{"NN"},
"hoop":	{"NN","VB","VBP"},
"hooped":	{"VBD","VBN","JJ"},
"hooping":	{"VBG"},
"hoopla":	{"NN"},
"hoopoe":	{"NN"},
"hoopoo":	{"NN"},
"hoops":	{"NNS","VBZ"},
"hoopskirt":	{"NN"},
"hooray":	{"NN","UH","VB","VBP"},
"hoorayed":	{"VBD","VBN"},
"hooraying":	{"VBG"},
"hoorays":	{"NNS","VBZ"},
"hoosegow":	{"NN"},
"hoosegows":	{"NNS"},
"hoosgow":	{"NN"},
"hoot":	{"NN","VB","VBP"},
"hootch":	{"NN"},
"hooted":	{"VBD","VBN"},
"hooter":	{"NN"},
"hooters":	{"NNS"},
"hooting":	{"VBG"},
"hoots":	{"NNS","VBZ"},
"hooved":	{"JJ"},
"hoover":	{"NN","VBP","VB"},
"hoovered":	{"VBD","VBN"},
"hoovering":	{"VBG","NN"},
"hoovers":	{"NNS","VBZ"},
"hooves":	{"NNS"},
"hop":	{"VB","NN","VBP"},
"hop-picker":	{"NN"},
"hop-skip":	{"NN"},
"hop-step-and-jump":	{"NN"},
"hope":	{"VBP","NN","VB"},
"hoped":	{"VBD","VBN"},
"hoped-for":	{"JJ"},
"hopeful":	{"JJ","NN"},
"hopefully":	{"RB"},
"hopefulness":	{"NN"},
"hopefuls":	{"NNS"},
"hopeh":	{"NN"},
"hopei":	{"NN"},
"hopeless":	{"JJ"},
"hopelessly":	{"RB"},
"hopelessness":	{"NN"},
"hoper":	{"NN"},
"hopes":	{"VBZ","NNS"},
"hoping":	{"VBG"},
"hopkinson":	{"NN"},
"hopped":	{"VBD","VBN"},
"hopped-up":	{"JJ"},
"hopper":	{"NN"},
"hoppers":	{"NNS"},
"hopping":	{"VBG"},
"hopple":	{"VB","VBP","NN"},
"hoppled":	{"VBD","VBN"},
"hopples":	{"NNS","VBZ"},
"hoppling":	{"VBG"},
"hops":	{"NNS","VBZ"},
"hopsack":	{"NN"},
"hopsacking":	{"NN"},
"hopscotch":	{"NN"},
"hopwood":	{"NN"},
"horary":	{"JJ"},
"horcruxes":	{"NN"},
"horde":	{"NN"},
"hordeolum":	{"NN"},
"hordes":	{"NNS"},
"hordeum":	{"NN"},
"horehound":	{"NN"},
"horizon":	{"NN"},
"horizons":	{"NNS"},
"horizontal":	{"JJ","NN"},
"horizontal-restraints":	{"NNS"},
"horizontality":	{"NN"},
"horizontally":	{"RB"},
"horizontals":	{"NNS"},
"hormonal":	{"JJ"},
"hormone":	{"NN"},
"hormone-treated":	{"JJ"},
"hormones":	{"NNS"},
"horn":	{"NN","VB","VBP"},
"horn-rim":	{"JJ"},
"horn-rimmed":	{"JJ"},
"horn-shaped":	{"JJ"},
"hornbeam":	{"NN"},
"hornbill":	{"NN"},
"hornbills":	{"NNS"},
"hornblende":	{"NN"},
"hornbook":	{"NN"},
"horne":	{"NN"},
"horned":	{"JJ","VBD","VBN"},
"horneophyton":	{"NN"},
"hornet":	{"NN"},
"hornets":	{"NNS"},
"horney":	{"NN"},
"hornfels":	{"NN","NNS"},
"hornier":	{"JJR"},
"horniest":	{"JJS"},
"horniness":	{"NN"},
"horning":	{"VBG"},
"hornist":	{"NN"},
"hornless":	{"JJ"},
"hornlike":	{"JJ"},
"hornpipe":	{"NN"},
"hornpipes":	{"NNS"},
"hornpout":	{"NN"},
"horns":	{"NNS","VBZ"},
"hornstone":	{"NN"},
"hornswoggle":	{"VB","NN"},
"hornwort":	{"NN"},
"horny":	{"JJ"},
"horologe":	{"NN"},
"horologer":	{"NN"},
"horologist":	{"NN"},
"horology":	{"NN"},
"horoscope":	{"NN"},
"horoscopes":	{"NNS"},
"horoscopy":	{"NN"},
"horrendous":	{"JJ"},
"horrendously":	{"RB"},
"horrible":	{"JJ"},
"horribly":	{"RB"},
"horrid":	{"JJ"},
"horridly":	{"RB"},
"horridness":	{"NN"},
"horrific":	{"JJ"},
"horrifically":	{"RB"},
"horrified":	{"JJ","VBD","VBN"},
"horrifies":	{"VBZ"},
"horrify":	{"VB","VBP"},
"horrifying":	{"JJ","VBG"},
"horrifyingly":	{"RB"},
"horripilate":	{"VB","VBP"},
"horripilated":	{"VBD","VBN"},
"horripilates":	{"VBZ"},
"horripilating":	{"VBG"},
"horripilation":	{"NN"},
"horror":	{"NN","JJ"},
"horror-stricken":	{"JJ"},
"horror-struck":	{"JJ"},
"horrors":	{"NNS","UH"},
"hors":	{"FW"},
"horse":	{"NN","VBP","VB"},
"horse-and-buggy":	{"JJ"},
"horse-blanket":	{"RB"},
"horse-breeding":	{"NN"},
"horse-brier":	{"NN"},
"horse-cart":	{"NN"},
"horse-chestnut":	{"NN"},
"horse-chestnuts":	{"NNS"},
"horse-drawn":	{"JJ"},
"horse-head":	{"NN"},
"horse-meat":	{"NN"},
"horse-packing":	{"JJ"},
"horse-pistol":	{"NN"},
"horse-player":	{"NN"},
"horse-playing":	{"JJ"},
"horse-race":	{"NN"},
"horse-racing":	{"NN"},
"horse-radish":	{"NN"},
"horse-steak":	{"NN"},
"horse-trade":	{"VB","VBP"},
"horse-traded":	{"VBD","VBN"},
"horse-trades":	{"VBZ"},
"horse-trading":	{"NN","VBG"},
"horse-trail":	{"NN"},
"horse-whip":	{"NN","VB","VBP"},
"horse-whipped":	{"VBD","VBN"},
"horse-whipping":	{"VBG"},
"horse-whips":	{"NNS","VBZ"},
"horseback":	{"NN","JJ"},
"horsebean":	{"NN"},
"horsebox":	{"NN"},
"horsecar":	{"NN"},
"horsecloth":	{"NN"},
"horsed":	{"VBD","VBN"},
"horsedom":	{"NN"},
"horsefish":	{"NN"},
"horseflesh":	{"NN"},
"horseflies":	{"NNS"},
"horsefly":	{"NN"},
"horsehair":	{"NN"},
"horsehead":	{"NN"},
"horsehide":	{"NN"},
"horselaugh":	{"NN"},
"horseleech":	{"NN"},
"horselike":	{"JJ"},
"horseman":	{"NN"},
"horsemanship":	{"NN"},
"horsemeat":	{"NN"},
"horsemen":	{"NNS"},
"horsemint":	{"NN"},
"horseplay":	{"NN"},
"horsepond":	{"NN"},
"horsepower":	{"NN","NNS"},
"horsepower-hour":	{"NN"},
"horseradish":	{"NN"},
"horses":	{"NNS","VBZ"},
"horseshit":	{"NN"},
"horseshoe":	{"NN","VB","VBP"},
"horseshoed":	{"VBD","VBN"},
"horseshoeing":	{"VBG"},
"horseshoer":	{"NN"},
"horseshoers":	{"NNS"},
"horseshoes":	{"NNS","VBZ"},
"horseshow":	{"NN"},
"horsetail":	{"NN"},
"horseweed":	{"NN"},
"horsewhip":	{"NN","VB","VBP"},
"horsewhipped":	{"VBD","VBN"},
"horsewhipping":	{"VBG"},
"horsewhips":	{"NNS","VBZ"},
"horsewoman":	{"NN"},
"horsewomen":	{"NNS"},
"horsing":	{"VBG"},
"horst":	{"NN"},
"horta":	{"NN"},
"hortative":	{"JJ"},
"hortatory":	{"JJ"},
"hortensia":	{"NN"},
"horticultural":	{"JJ"},
"horticultural-products":	{"NNS"},
"horticulturally":	{"RB"},
"horticulture":	{"NN"},
"horticulturist":	{"NN"},
"horus":	{"NN"},
"hosanna":	{"UH","NN"},
"hosannas":	{"NNS"},
"hose":	{"NN","VB","VBP"},
"hosed":	{"VBD","VBN"},
"hosepipe":	{"NN"},
"hosepipes":	{"NNS"},
"hoses":	{"NNS","VBZ"},
"hosier":	{"NN"},
"hosiery":	{"NN"},
"hosing":	{"VBG"},
"hospice":	{"NN"},
"hospices":	{"NNS"},
"hospitable":	{"JJ"},
"hospitableness":	{"NN"},
"hospitably":	{"RB"},
"hospital":	{"NN"},
"hospital-care":	{"NN"},
"hospitalisation":	{"NN"},
"hospitalise":	{"VB","VBP"},
"hospitalised":	{"VBD","VBN"},
"hospitalises":	{"VBZ"},
"hospitalising":	{"VBG"},
"hospitality":	{"NN"},
"hospitalization":	{"NN"},
"hospitalize":	{"VB","VBP"},
"hospitalized":	{"VBD","VBN"},
"hospitalizes":	{"VBZ"},
"hospitalizing":	{"VBG"},
"hospitals":	{"NNS"},
"hoss":	{"NN","NNS"},
"hosses":	{"NNS"},
"host":	{"NN","VB","VBP"},
"host-specific":	{"JJ"},
"hosta":	{"NN"},
"hostaceae":	{"NN"},
"hostage":	{"NN"},
"hostages":	{"NNS"},
"hoste":	{"NN"},
"hosted":	{"VBD","VBN"},
"hostel":	{"NN","VB","VBP"},
"hosteled":	{"VBD","VBN"},
"hosteler":	{"NN"},
"hosteling":	{"VBG"},
"hosteller":	{"NN"},
"hostelries":	{"NNS"},
"hostelry":	{"NN"},
"hostels":	{"NNS","VBZ"},
"hostess":	{"NN"},
"hostesses":	{"NNS"},
"hostile":	{"JJ"},
"hostile-bid":	{"JJ"},
"hostilely":	{"RB"},
"hostilities":	{"NNS"},
"hostility":	{"NN","JJ"},
"hosting":	{"VBG"},
"hostler":	{"NN"},
"hostlers":	{"NNS"},
"hosts":	{"NNS","VBZ"},
"hot":	{"JJ","VB","VBP"},
"hot-air":	{"JJ"},
"hot-blooded":	{"JJ"},
"hot-buttons":	{"NNS"},
"hot-cereals":	{"NNS"},
"hot-cold":	{"JJ"},
"hot-colored":	{"JJ"},
"hot-dipped":	{"JJ"},
"hot-dog":	{"VB","VBP","NN","JJ"},
"hot-dogged":	{"VBD","VBN"},
"hot-dogger":	{"NN"},
"hot-dogging":	{"VBG"},
"hot-dogs":	{"VBZ"},
"hot-formed":	{"JJ"},
"hot-headed":	{"JJ"},
"hot-headedly":	{"RB"},
"hot-headedness":	{"NN"},
"hot-honey":	{"JJ"},
"hot-line":	{"NN"},
"hot-pink":	{"JJ"},
"hot-rod":	{"NN"},
"hot-rods":	{"NNS"},
"hot-rolled":	{"JJ"},
"hot-selling":	{"JJ"},
"hot-shot":	{"JJ","NN"},
"hot-slough":	{"JJ"},
"hot-tempered":	{"JJ"},
"hot-ticket":	{"JJ"},
"hot-tub":	{"VB","VBP"},
"hot-tubbed":	{"VBD","VBN"},
"hot-tubbing":	{"VBG"},
"hot-tubs":	{"VBZ"},
"hot-water":	{"NN"},
"hot-wire":	{"VB","VBP"},
"hot-wired":	{"VBD","VBN"},
"hot-wires":	{"VBZ"},
"hot-wiring":	{"VBG"},
"hot-work":	{"VB","VBP"},
"hot-worked":	{"VBD","VBN"},
"hot-working":	{"VBG"},
"hot-works":	{"VBZ"},
"hotbed":	{"NN"},
"hotbeds":	{"NNS"},
"hotbox":	{"NN"},
"hotcake":	{"NN"},
"hotchpotch":	{"NN"},
"hotdog":	{"VB","NN"},
"hotdogs":	{"NNS"},
"hotei":	{"NN"},
"hotei-chiku":	{"NN"},
"hotel":	{"NN"},
"hotel-casino":	{"NN"},
"hotel-casinos":	{"NNS"},
"hotel-management":	{"NN"},
"hotel-motel":	{"NN"},
"hotel-restaurant":	{"NN"},
"hotelier":	{"NN"},
"hoteliers":	{"NNS"},
"hotelkeeper":	{"NN"},
"hotelman":	{"NN"},
"hotels":	{"NNS"},
"hotfoot":	{"VB","VBP","RB"},
"hotfooted":	{"VBD","VBN"},
"hotfooting":	{"VBG"},
"hotfoots":	{"VBZ"},
"hoth":	{"NN"},
"hothead":	{"NN"},
"hotheaded":	{"JJ"},
"hotheadedly":	{"RB"},
"hotheads":	{"NNS"},
"hothouse":	{"NN"},
"hothouses":	{"NNS"},
"hothr":	{"NN"},
"hotline":	{"NN"},
"hotlines":	{"NNS"},
"hotly":	{"RB"},
"hotness":	{"NN"},
"hotplate":	{"NN"},
"hotplates":	{"NNS"},
"hotpot":	{"NN"},
"hotpots":	{"NNS"},
"hotrod":	{"NN"},
"hots":	{"VBZ"},
"hotshot":	{"NN"},
"hotshots":	{"NNS"},
"hotspot":	{"NN"},
"hotspots":	{"NNS"},
"hotspur":	{"NN"},
"hotted":	{"VBD","VBN"},
"hotter":	{"JJR"},
"hottest":	{"JJS"},
"hottest-selling":	{"JJ"},
"hotting":	{"VBG"},
"hottish":	{"JJ"},
"hottonia":	{"NN"},
"houdah":	{"NN"},
"hough":	{"NN"},
"houghton":	{"NN"},
"houhere":	{"NN"},
"hoummos":	{"NN"},
"hound":	{"NN","VB","VBP"},
"hound's-tongue":	{"NN"},
"hound's-tooth":	{"NN"},
"hounded":	{"VBD","VBN"},
"hounding":	{"VBG"},
"hounds":	{"VBZ","NNS"},
"houndstooth":	{"NN"},
"hour":	{"NN"},
"hour-and-a-half":	{"NN"},
"hour-hand":	{"NN"},
"hour-hands":	{"NNS"},
"hour-long":	{"JJ"},
"hourglass":	{"NN"},
"hourglass-shaped":	{"JJ"},
"hourglasses":	{"NNS"},
"houri":	{"NN"},
"hourlong":	{"JJ"},
"hourly":	{"JJ","RB"},
"hours":	{"NNS"},
"hours-long":	{"JJ"},
"hourslong":	{"JJ"},
"housatonic":	{"NN"},
"house":	{"NN","VB","VBP"},
"house-agent":	{"NN"},
"house-bound":	{"JJ"},
"house-builder":	{"NN"},
"house-building":	{"NN"},
"house-cleaning":	{"NN"},
"house-dog":	{"NN"},
"house-flies":	{"NNS"},
"house-floor":	{"JJ"},
"house-fly":	{"NN"},
"house-martin":	{"NN"},
"house-martins":	{"NNS"},
"house-mother":	{"NN"},
"house-painting":	{"JJ"},
"house-passed":	{"JJ"},
"house-proud":	{"JJ"},
"house-raising":	{"NN"},
"house-sparrow":	{"NN"},
"house-to-house":	{"JJ","RB"},
"house-tops":	{"NNS"},
"house-train":	{"VB","VBP"},
"house-trained":	{"JJ","VBD","VBN"},
"house-training":	{"VBG"},
"house-trains":	{"VBZ"},
"house-warming":	{"NN"},
"houseboat":	{"NN"},
"houseboats":	{"NNS"},
"housebound":	{"JJ"},
"housebreak":	{"VB","VBP"},
"housebreaker":	{"NN"},
"housebreakers":	{"NNS"},
"housebreaking":	{"VBG","NN"},
"housebreaks":	{"VBZ"},
"housebroke":	{"VBD"},
"housebroken":	{"VBN"},
"housebuilder":	{"NN"},
"houseclean":	{"VB","VBP"},
"housecleaned":	{"VBD","VBN"},
"housecleaning":	{"NN","VBG"},
"housecleans":	{"VBZ"},
"housecoat":	{"NN"},
"housecoats":	{"NNS"},
"housecraft":	{"NN"},
"housed":	{"VBD","VBN"},
"housedog":	{"NN"},
"housefather":	{"NN"},
"houseflies":	{"NNS"},
"housefly":	{"NN"},
"houseful":	{"NN"},
"houseguest":	{"NN"},
"household":	{"NN","JJ"},
"household-products":	{"NNS"},
"household-type":	{"JJ"},
"householder":	{"NN"},
"householders":	{"NNS"},
"households":	{"NNS"},
"househusband":	{"NN"},
"househusbands":	{"NNS"},
"housekeep":	{"VB","VBP"},
"housekeeper":	{"NN"},
"housekeepers":	{"NNS"},
"housekeeping":	{"NN","VBG"},
"housekeeps":	{"VBZ"},
"housekept":	{"VBD","VBN"},
"houselights":	{"NNS"},
"housemaid":	{"NN"},
"housemaids":	{"NNS"},
"houseman":	{"NN"},
"housemaster":	{"NN"},
"housemasters":	{"NNS"},
"housemate":	{"NN"},
"housemates":	{"NNS"},
"housemen":	{"NNS"},
"housemistress":	{"NN"},
"housemistresses":	{"NNS"},
"housemother":	{"NN"},
"housepaint":	{"NN"},
"houseplant":	{"NN"},
"houseplants":	{"NNS"},
"houseroom":	{"NN"},
"houses":	{"NNS","VBZ"},
"housetop":	{"NN"},
"housetops":	{"NNS"},
"housewares":	{"NNS"},
"housewarming":	{"NN"},
"housewarmings":	{"NNS"},
"housewife":	{"NN"},
"housewifely":	{"JJ"},
"housewifery":	{"NN"},
"housewives":	{"NNS"},
"housework":	{"NN"},
"housewrecker":	{"NN"},
"housing":	{"NN","VBG"},
"housing-assistance":	{"JJ"},
"housing-construction":	{"NN"},
"housing-discrimination":	{"NN"},
"housing-loan":	{"NN"},
"housing-policy":	{"NN"},
"housing-related":	{"JJ"},
"housings":	{"NNS"},
"housman":	{"NN"},
"houston-area":	{"JJ"},
"houston-dallas":	{"JJ"},
"houten":	{"NN"},
"houttuynia":	{"NN"},
"houyhnhnm":	{"NN"},
"houyhnhnms":	{"NNS"},
"hove":	{"VBD","VBN"},
"hovea":	{"NN"},
"hovel":	{"NN"},
"hovels":	{"NNS"},
"hover":	{"VB","VBP"},
"hovercraft":	{"NN","NNS"},
"hovercrafts":	{"NNS"},
"hovered":	{"VBD","VBN"},
"hovering":	{"VBG"},
"hovers":	{"VBZ"},
"how":	{"WRB","RB"},
"how-d'ye-do":	{"NN"},
"how-do-you-do":	{"NN"},
"how-to":	{"JJ","NN"},
"howard":	{"NN"},
"howdah":	{"NN"},
"howdahs":	{"NNS"},
"howdy":	{"UH"},
"howe":	{"NN"},
"howells":	{"NNS"},
"however":	{"RB","WRB","IN"},
"howitzer":	{"NN"},
"howitzers":	{"NNS"},
"howl":	{"NN","VB","VBP"},
"howled":	{"VBD","VBN"},
"howler":	{"NN"},
"howlers":	{"NNS"},
"howling":	{"JJ","VBG"},
"howls":	{"NNS","VBZ"},
"howsabout":	{"RB"},
"howse":	{"NN"},
"howsomever":	{"RB"},
"howzit":	{"NN"},
"hoy":	{"NN","UH"},
"hoya":	{"NN"},
"hoyden":	{"NN"},
"hoydenish":	{"JJ"},
"hoydenism":	{"NN"},
"hoydens":	{"NNS"},
"hoys":	{"NNS"},
"hp":	{"NN"},
"hp.":	{"NN"},
"hr":	{"NN"},
"hr.":	{"NN"},
"hrolf":	{"NN"},
"hrs":	{"NNS"},
"hrt":	{"NN"},
"hrvatska":	{"NN"},
"hryvnia":	{"NN"},
"hs":	{"NN"},
"hs1":	{"NN"},
"hs2":	{"NN"},
"hsian":	{"NN"},
"hsv-1":	{"NN"},
"hsv-2":	{"NN"},
"hsv-i":	{"NN"},
"hsv-ii":	{"NN"},
"htlv-1":	{"NN"},
"html":	{"NN"},
"hua":	{"NN"},
"huainaputina":	{"NN"},
"hualapai":	{"NN"},
"hualpai":	{"NN"},
"huamachil":	{"NN"},
"huambo":	{"NN"},
"huarache":	{"NN"},
"huaraches":	{"NNS"},
"huascaran":	{"NN"},
"hub":	{"NN"},
"hub-and-spoke":	{"NN"},
"hub-cap":	{"NN"},
"hubba":	{"UH"},
"hubbies":	{"NNS"},
"hubble":	{"NN"},
"hubble-bubble":	{"NN"},
"hubbly-bubbly":	{"NN"},
"hubbub":	{"NN"},
"hubby":	{"NN"},
"hubcap":	{"NN"},
"hubcaps":	{"NNS"},
"hubel":	{"NN"},
"hubert":	{"NN"},
"hubris":	{"NN"},
"hubs":	{"NNS"},
"huck":	{"NN"},
"huckaback":	{"NN"},
"huckleberries":	{"NNS"},
"huckleberry":	{"NN"},
"huckster":	{"NN","VB","VBP"},
"huckstered":	{"VBD","VBN"},
"huckstering":	{"VBG"},
"hucksterism":	{"NN"},
"hucksters":	{"NNS","VBZ"},
"hud":	{"NN"},
"hud-backed":	{"JJ"},
"hud-related":	{"JJ"},
"hud-subsidized":	{"JJ"},
"hud-supervised":	{"JJ"},
"huddle":	{"VB","VBP","NN"},
"huddled":	{"VBD","VBN"},
"huddler":	{"NN"},
"huddles":	{"VBZ","NNS"},
"huddling":	{"VBG"},
"hudood":	{"NN"},
"hudsonia":	{"NN"},
"hudud":	{"NN"},
"hue":	{"NN"},
"hueless":	{"JJ"},
"hues":	{"NNS"},
"huey":	{"NN"},
"huff":	{"NN","VB","VBP"},
"huffed":	{"VBD","VBN"},
"huffily":	{"RB"},
"huffiness":	{"NN"},
"huffing":	{"NN","VBG"},
"huffish":	{"JJ"},
"huffishness":	{"NN"},
"huffman":	{"NN"},
"huffs":	{"VBZ"},
"huffy":	{"JJ"},
"hug":	{"VB","VBP","NN"},
"hug-me-tight":	{"NN"},
"huge":	{"JJ"},
"hugely":	{"RB"},
"hugged":	{"VBD","VBN"},
"hugger":	{"NN"},
"hugger-mugger":	{"JJ","NN","RB"},
"hugging":	{"VBG"},
"huggings":	{"NNS"},
"huggins":	{"NNS"},
"hugoesque":	{"JJ"},
"hugs":	{"NNS","VBZ"},
"hugueninia":	{"NN"},
"huguenot":	{"NN"},
"huh":	{"UH"},
"huh-uh":	{"JJ"},
"huisache":	{"NN"},
"huitotoes":	{"NNS"},
"huitre":	{"NN"},
"huji":	{"NN"},
"hula":	{"NN"},
"hula-hoop":	{"NN"},
"hula-hula":	{"NN"},
"hulk":	{"NN","VB","VBP"},
"hulked":	{"VBD","VBN"},
"hulking":	{"JJ","VBG"},
"hulks":	{"VBZ","NNS"},
"hulky":	{"JJ"},
"hull":	{"NN","VB","VBP"},
"hull-first":	{"RB"},
"hullabaloo":	{"NN"},
"hulled":	{"VBD","VBN"},
"hulling":	{"VBG"},
"hullo":	{"UH"},
"hulls":	{"NNS","VBZ"},
"hulsea":	{"NN"},
"hum":	{"VB","VBP","NN","UH"},
"hum-vee":	{"NN"},
"humaine":	{"NN"},
"human":	{"JJ","NN"},
"human-based":	{"JJ"},
"human-centered":	{"JJ"},
"human-centred":	{"JJ"},
"human-generated":	{"JJ"},
"human-leukocyte-derived":	{"JJ"},
"human-resources":	{"NN"},
"human-rights":	{"NNS"},
"human-robot":	{"NN"},
"human-sized":	{"JJ"},
"human-sounding":	{"JJ"},
"humane":	{"JJ"},
"humanely":	{"RB"},
"humaneness":	{"NN"},
"humanisation":	{"NN"},
"humanise":	{"VB","VBP"},
"humanised":	{"VBD","VBN"},
"humanises":	{"VBZ"},
"humanising":	{"VBG"},
"humanism":	{"NN"},
"humanist":	{"NN"},
"humanistic":	{"JJ"},
"humanists":	{"NNS"},
"humanitarian":	{"JJ","NN"},
"humanitarianism":	{"NN"},
"humanitarians":	{"NNS"},
"humanities":	{"NNS"},
"humanity":	{"NN"},
"humanization":	{"NN"},
"humanize":	{"VB","VBP"},
"humanized":	{"VBD","VBN"},
"humanizes":	{"VBZ"},
"humanizing":	{"VBG"},
"humankind":	{"NN"},
"humanlike":	{"JJ"},
"humanly":	{"RB"},
"humanness":	{"NN"},
"humanoid":	{"JJ","NN"},
"humanoids":	{"NNS"},
"humans":	{"NNS"},
"humate":	{"NN"},
"humber":	{"NN"},
"humble":	{"JJ","VBP","VB"},
"humblebee":	{"NN"},
"humbled":	{"VBD","VBN"},
"humbleness":	{"NN"},
"humbler":	{"JJR"},
"humbles":	{"VBZ"},
"humblest":	{"JJS"},
"humbling":	{"JJ","VBG"},
"humbly":	{"RB"},
"humboldt":	{"NN"},
"humbug":	{"NN","VB","VBP"},
"humbugged":	{"VBD","VBN"},
"humbugging":	{"VBG"},
"humbugs":	{"NNS","VBZ"},
"humdinger":	{"NN"},
"humdingers":	{"NNS"},
"humdrum":	{"JJ"},
"humectant":	{"JJ"},
"humeri":	{"NNS"},
"humerus":	{"NN"},
"humic":	{"JJ"},
"humid":	{"JJ"},
"humidified":	{"VBD","VBN"},
"humidifies":	{"VBZ"},
"humidify":	{"VB","VBP"},
"humidifying":	{"VBG"},
"humidity":	{"NN"},
"humidness":	{"NN"},
"humification":	{"NN"},
"humified":	{"VBD","VBN"},
"humifies":	{"VBZ"},
"humify":	{"VB","VBP"},
"humifying":	{"VBG"},
"humilation":	{"NN"},
"humiliate":	{"VB","VBP"},
"humiliated":	{"VBD","VBN","JJ"},
"humiliates":	{"VBZ"},
"humiliating":	{"JJ","VBG"},
"humiliatingly":	{"RB"},
"humiliation":	{"NN"},
"humiliations":	{"NNS"},
"humility":	{"NN"},
"humin":	{"NN"},
"humly":	{"RB"},
"hummable":	{"JJ"},
"hummed":	{"VBD","VBN"},
"hummer":	{"NN"},
"humming":	{"VBG"},
"hummingbird":	{"NN"},
"hummingbirds":	{"NNS"},
"hummock":	{"NN"},
"hummocks":	{"NNS"},
"hummus":	{"NN"},
"humongous":	{"JJ"},
"humor":	{"NN","VB","VBP"},
"humoral":	{"JJ"},
"humored":	{"VBD","VBN"},
"humoring":	{"VBG"},
"humorist":	{"NN"},
"humorists":	{"NNS"},
"humorless":	{"JJ"},
"humorlessly":	{"RB"},
"humorous":	{"JJ"},
"humorously":	{"RB"},
"humorousness":	{"NN"},
"humors":	{"VBZ","NNS"},
"humour":	{"NN","VBP","VB"},
"humoured":	{"VBD","VBN"},
"humouring":	{"VBG"},
"humourist":	{"NN"},
"humourless":	{"JJ"},
"humourlessly":	{"RB"},
"humourous":	{"JJ"},
"humours":	{"VBZ"},
"humous":	{"NN"},
"hump":	{"NN","VB","VBP"},
"hump-backed":	{"JJ"},
"humpback":	{"NN"},
"humpbacked":	{"JJ"},
"humpbacks":	{"NNS"},
"humped":	{"JJ","VBD","VBN"},
"humperdinck":	{"NN"},
"humping":	{"VBG"},
"humps":	{"NNS","VBZ"},
"hums":	{"NNS","VBZ"},
"humulin":	{"NN"},
"humulus":	{"NN"},
"humus":	{"NN"},
"humvee":	{"NN"},
"hunch":	{"NN","VB","VBP"},
"hunchback":	{"NN"},
"hunchbacked":	{"JJ"},
"hunched":	{"VBD","VBN","JJ"},
"hunched-up":	{"JJ"},
"hunches":	{"NNS","VBZ"},
"hunching":	{"VBG"},
"hundred":	{"NN","CD"},
"hundred-and-eightieth":	{"JJ","NN"},
"hundred-and-eighty-degree":	{"JJ"},
"hundred-and-fifteenth":	{"JJ","NN"},
"hundred-and-fifth":	{"JJ","NN"},
"hundred-and-fiftieth":	{"JJ","NN"},
"hundred-and-fifty":	{"NN","CD"},
"hundred-and-fifty-fifth":	{"JJ","NN"},
"hundred-and-first":	{"JJ","NN"},
"hundred-and-fortieth":	{"JJ","NN"},
"hundred-and-forty-fifth":	{"JJ","NN"},
"hundred-and-ninetieth":	{"JJ","NN"},
"hundred-and-seventieth":	{"JJ","NN"},
"hundred-and-seventy-fifth":	{"JJ","NN"},
"hundred-and-sixtieth":	{"JJ","NN"},
"hundred-and-sixty-fifth":	{"JJ","NN"},
"hundred-and-tenth":	{"JJ","NN"},
"hundred-and-thirtieth":	{"JJ","NN"},
"hundred-and-thirty-fifth":	{"JJ","NN"},
"hundred-and-twentieth":	{"JJ","NN"},
"hundred-and-twenty-fifth":	{"JJ","NN"},
"hundred-leaf":	{"JJ"},
"hundred-odd":	{"JJ"},
"hundred-percenter":	{"NN"},
"hundred-thousand-share":	{"JJ"},
"hundred-yen":	{"JJ"},
"hundredfold":	{"RB"},
"hundreds":	{"NNS"},
"hundreds-of-billions-of-yen":	{"JJ"},
"hundredth":	{"JJ","NN"},
"hundredweight":	{"NN"},
"hundredweights":	{"NNS"},
"hung":	{"VBD","VBN","JJ"},
"hunger":	{"NN","VBP","VB"},
"hungered":	{"VBD","VBN"},
"hungering":	{"VBG"},
"hungers":	{"VBZ"},
"hungrier":	{"JJR"},
"hungriest":	{"JJS"},
"hungrily":	{"RB"},
"hungriness":	{"NN"},
"hungry":	{"JJ"},
"hunk":	{"NN"},
"hunker":	{"VB","VBP"},
"hunkered":	{"VBD","VBN"},
"hunkering":	{"VBG"},
"hunkerish":	{"JJ"},
"hunkers":	{"VBZ"},
"hunkpapa":	{"NN"},
"hunks":	{"NNS"},
"hunky-dory":	{"JJ"},
"hunnemannia":	{"NN"},
"hunt":	{"NN","VB","VBP"},
"hunted":	{"VBD","VBN"},
"hunter":	{"NN"},
"hunter-gatherer":	{"NN"},
"hunter-gatherers":	{"NNS"},
"hunter-killer":	{"NN","JJ"},
"hunters":	{"NNS"},
"hunting":	{"NN","JJ","VBG"},
"hunting-gear":	{"JJ"},
"huntington":	{"NN"},
"huntress":	{"NN"},
"huntresses":	{"NNS"},
"hunts":	{"NNS","VBZ"},
"huntsman":	{"NN"},
"huntsmen":	{"NNS"},
"huntsville":	{"NN"},
"hupa":	{"NN"},
"hurdle":	{"NN","VB","VBP"},
"hurdled":	{"VBD","VBN"},
"hurdler":	{"NN"},
"hurdlers":	{"NNS"},
"hurdles":	{"NNS","VBZ"},
"hurdling":	{"NN","VBG"},
"hurdy-gurdies":	{"NNS"},
"hurdy-gurdy":	{"NN"},
"hurl":	{"VB","VBP"},
"hurled":	{"VBD","VBN"},
"hurler":	{"NN"},
"hurlers":	{"NNS"},
"hurley":	{"NN"},
"hurling":	{"NN","VBG"},
"hurls":	{"VBZ"},
"hurok":	{"NN"},
"hurrah":	{"NN","VB","VBP","UH"},
"hurrahed":	{"VBD","VBN"},
"hurrahing":	{"VBG"},
"hurrahs":	{"VBZ","NNS"},
"hurray":	{"UH","NN"},
"hurricane":	{"NN"},
"hurricane-hit":	{"JJ"},
"hurricane-prone":	{"JJ"},
"hurricane-ravaged":	{"JJ"},
"hurricane-related":	{"JJ"},
"hurricane-stricken":	{"JJ"},
"hurricane-wracked":	{"JJ"},
"hurricanes":	{"NNS"},
"hurried":	{"JJ","VBD","VBN"},
"hurriedly":	{"RB"},
"hurriedness":	{"NN"},
"hurries":	{"VBZ"},
"hurry":	{"NN","VB","VBP"},
"hurrying":	{"VBG"},
"hurst":	{"NN"},
"hurt":	{"VBN","VB","VBD","NN","VBP","JJ"},
"hurtful":	{"JJ"},
"hurtfully":	{"RB"},
"hurtfulness":	{"NN"},
"hurting":	{"VBG"},
"hurtle":	{"VB","VBP"},
"hurtled":	{"VBD","VBN"},
"hurtles":	{"VBZ"},
"hurtling":	{"VBG"},
"hurts":	{"VBZ","NNS"},
"hus":	{"NN"},
"husain":	{"NN"},
"husayn":	{"NN"},
"husband":	{"NN","VBP","VB"},
"husband-and-wife":	{"JJ","NN"},
"husband-stealer":	{"NN"},
"husband-wife":	{"JJ"},
"husbanded":	{"VBD","VBN"},
"husbanding":	{"VBG"},
"husbandly":	{"JJ"},
"husbandman":	{"NN"},
"husbandry":	{"NN"},
"husbands":	{"NNS","VBZ"},
"husbun":	{"NN"},
"hush":	{"VB","VBP","NN"},
"hush-hush":	{"JJ"},
"hush-money":	{"NN"},
"hushed":	{"VBD","VBN","JJ"},
"hushed-up":	{"JJ"},
"hushes":	{"VBZ"},
"hushing":	{"VBG"},
"hushpuppy":	{"NN"},
"husk":	{"NN","VB","VBP"},
"husked":	{"VBD","VBN"},
"huskier":	{"JJR"},
"huskies":	{"NNS"},
"huskiest":	{"JJS"},
"huskily":	{"RB"},
"huskiness":	{"NN"},
"husking":	{"VBG"},
"husks":	{"NNS","VBZ"},
"husky":	{"JJ","NN"},
"husky-voiced":	{"JJ"},
"huss":	{"NN"},
"hussar":	{"NN"},
"hussars":	{"NNS"},
"husserl":	{"NN"},
"hussies":	{"NNS"},
"hussite":	{"NN"},
"hussy":	{"NN"},
"huster":	{"NN"},
"hustings":	{"NNS"},
"hustle":	{"VB","VBP","NN"},
"hustled":	{"VBD","VBN"},
"hustler":	{"NN"},
"hustlers":	{"NNS"},
"hustles":	{"VBZ","NNS"},
"hustling":	{"VBG"},
"hut":	{"NN","VB","VBP"},
"hutch":	{"NN"},
"hutches":	{"NNS"},
"hutchins":	{"NNS"},
"hutchinson":	{"NN"},
"hutchison":	{"NN"},
"hutment":	{"NN"},
"hutments":	{"NNS"},
"hutong":	{"NN"},
"huts":	{"NNS","VBZ"},
"hutted":	{"VBD","VBN"},
"hutting":	{"VBG"},
"hutton":	{"NN"},
"hutu":	{"NN"},
"hutzpah":	{"NN"},
"huxleian":	{"JJ"},
"huxleyan":	{"JJ"},
"huygens":	{"NNS"},
"huzzahs":	{"NNS"},
"hwang":	{"NN"},
"hyacinth":	{"NN"},
"hyacinthaceae":	{"NN"},
"hyacinthoides":	{"NNS"},
"hyacinths":	{"NNS"},
"hyades":	{"NNS"},
"hyaena":	{"NN"},
"hyaenidae":	{"NN"},
"hyalin":	{"NN"},
"hyaline":	{"JJ","NN"},
"hyalinisation":	{"NN"},
"hyalinization":	{"NN"},
"hyaloid":	{"JJ"},
"hyalophora":	{"NN"},
"hyaloplasm":	{"NN"},
"hyaloplasmic":	{"JJ"},
"hyalosperma":	{"NN"},
"hyalospongiae":	{"NN"},
"hyaluronic":	{"JJ"},
"hyaluronidase":	{"NN"},
"hyatt":	{"NN"},
"hyazyme":	{"NN"},
"hybanthus":	{"NN"},
"hybrid":	{"JJ","NN"},
"hybridisation":	{"NN"},
"hybridise":	{"VB","VBP"},
"hybridised":	{"VBD","VBN"},
"hybridises":	{"VBZ"},
"hybridising":	{"VBG"},
"hybridization":	{"NN"},
"hybridize":	{"VB","VBP"},
"hybridized":	{"VBD","VBN"},
"hybridizes":	{"VBZ"},
"hybridizing":	{"VBG"},
"hybridoma":	{"NN"},
"hybrids":	{"NNS"},
"hydantoin":	{"NN"},
"hydathode":	{"NN"},
"hydatid":	{"NN"},
"hydatidosis":	{"NN"},
"hyde-to-jekyll":	{"JJ"},
"hyderabad":	{"NN"},
"hydnaceae":	{"NN"},
"hydnocarpus":	{"NNS"},
"hydnoraceae":	{"NN"},
"hydnum":	{"NN"},
"hydra":	{"NN"},
"hydra-headed":	{"JJ"},
"hydra-matic":	{"JJ"},
"hydralazine":	{"NN"},
"hydramnios":	{"NN"},
"hydrangea":	{"NN"},
"hydrangeaceae":	{"NN"},
"hydrant":	{"NN"},
"hydrargyrum":	{"NN"},
"hydrarthrosis":	{"NN"},
"hydrastis":	{"NN"},
"hydrate":	{"NN","VB","VBP"},
"hydrated":	{"VBD","VBN"},
"hydrates":	{"VBZ"},
"hydrating":	{"VBG"},
"hydration":	{"NN"},
"hydraulic":	{"JJ"},
"hydraulically":	{"RB"},
"hydraulicly":	{"RB"},
"hydraulics":	{"NN"},
"hydrazine":	{"NN"},
"hydrazoite":	{"NN"},
"hydremia":	{"NN"},
"hydric":	{"JJ"},
"hydride":	{"NN"},
"hydrides":	{"NNS"},
"hydrido":	{"NN"},
"hydrilla":	{"NN"},
"hydrobates":	{"NNS"},
"hydrobatidae":	{"NN"},
"hydrocarbon":	{"NN"},
"hydrocarbon-storage":	{"NN"},
"hydrocarbons":	{"NNS"},
"hydrocele":	{"NN"},
"hydrocephalic":	{"JJ"},
"hydrocephalus":	{"NN"},
"hydrocephaly":	{"NN"},
"hydrocharidaceae":	{"NN"},
"hydrocharis":	{"NN"},
"hydrocharitaceae":	{"NN"},
"hydrochemistry":	{"NN"},
"hydrochloride":	{"NN"},
"hydrochlorofluorocarbon":	{"NN"},
"hydrochlorothiazide":	{"NN"},
"hydrochlorothiazides":	{"NNS"},
"hydrochoeridae":	{"NN"},
"hydrochoerus":	{"NN"},
"hydrocolloid":	{"NN"},
"hydrocortisone":	{"NN"},
"hydrocortone":	{"NN"},
"hydrocracking":	{"NN"},
"hydrodamalis":	{"NN"},
"hydrodiuril":	{"NN"},
"hydrodynamic":	{"JJ"},
"hydrodynamics":	{"NN"},
"hydroelectric":	{"JJ"},
"hydroelectricity":	{"NN"},
"hydroflumethiazide":	{"NN"},
"hydrofluorocarbon":	{"NN"},
"hydrofluorocarbons":	{"NNS"},
"hydrofoil":	{"NN"},
"hydrogel":	{"NN"},
"hydrogen":	{"NN"},
"hydrogen-bomb":	{"NN"},
"hydrogen-bombs":	{"NNS"},
"hydrogenate":	{"VB","VBP"},
"hydrogenated":	{"VBD","VBN"},
"hydrogenates":	{"VBZ"},
"hydrogenating":	{"VBG"},
"hydrogenation":	{"NN"},
"hydrographic":	{"JJ"},
"hydrographical":	{"JJ"},
"hydrography":	{"NN"},
"hydroid":	{"JJ"},
"hydrokinetic":	{"JJ"},
"hydrokinetics":	{"NN"},
"hydrolise":	{"VB","VBP"},
"hydrolised":	{"VBD","VBN"},
"hydrolises":	{"VBZ"},
"hydrolising":	{"VBG"},
"hydrolith":	{"NN"},
"hydrolize":	{"VB","VBP"},
"hydrolized":	{"VBD","VBN"},
"hydrolizes":	{"VBZ"},
"hydrolizing":	{"VBG"},
"hydrologist":	{"NN"},
"hydrology":	{"NN"},
"hydrolysable":	{"JJ"},
"hydrolysate":	{"NN"},
"hydrolysation":	{"NN"},
"hydrolyse":	{"VB","VBP"},
"hydrolysed":	{"VBD","VBN"},
"hydrolyser":	{"NN"},
"hydrolyses":	{"VBZ","NNS"},
"hydrolysing":	{"VBG"},
"hydrolysis":	{"NN"},
"hydrolyzable":	{"JJ"},
"hydrolyzation":	{"NN"},
"hydrolyze":	{"VB","VBP"},
"hydrolyzed":	{"VBD","VBN"},
"hydrolyzer":	{"NN"},
"hydrolyzes":	{"VBZ"},
"hydrolyzing":	{"VBG"},
"hydromancer":	{"NN"},
"hydromancy":	{"NN"},
"hydromantes":	{"NNS"},
"hydromel":	{"NN"},
"hydrometer":	{"NN"},
"hydrometric":	{"JJ"},
"hydrometry":	{"NN"},
"hydromorphone":	{"NN"},
"hydromyinae":	{"NN"},
"hydromys":	{"NNS"},
"hydronephrosis":	{"NN"},
"hydropathic":	{"JJ"},
"hydropathy":	{"NN"},
"hydrophidae":	{"NN"},
"hydrophilic":	{"JJ"},
"hydrophobia":	{"NN"},
"hydrophobic":	{"JJ"},
"hydrophobicity":	{"NN"},
"hydrophyllaceae":	{"NN"},
"hydrophyllum":	{"NN"},
"hydrophyte":	{"NN"},
"hydrophytic":	{"JJ"},
"hydroplane":	{"NN","VBP","VB"},
"hydroplaned":	{"VBD","VBN"},
"hydroplanes":	{"NNS","VBZ"},
"hydroplaning":	{"VBG"},
"hydroponic":	{"JJ"},
"hydroponics":	{"NN"},
"hydrops":	{"NN"},
"hydrosphere":	{"NN"},
"hydrostatic":	{"JJ"},
"hydrostatics":	{"NN"},
"hydrotherapy":	{"NN"},
"hydrothorax":	{"NN"},
"hydrous":	{"JJ"},
"hydroxazine":	{"NN"},
"hydroxide":	{"NN"},
"hydroxides":	{"NNS"},
"hydroxy":	{"JJ","NN"},
"hydroxybenzene":	{"NN"},
"hydroxychloroquine":	{"NN"},
"hydroxyl":	{"NN"},
"hydroxyl-rich":	{"JJ"},
"hydroxylation":	{"NN"},
"hydroxymethyl":	{"NN"},
"hydroxyproline":	{"NN"},
"hydroxytetracycline":	{"NN"},
"hydroxyzine":	{"NN"},
"hydrozoa":	{"NN"},
"hydrozoan":	{"NN"},
"hydrus":	{"NN"},
"hyemoschus":	{"NNS"},
"hyena":	{"NN"},
"hyenas":	{"NNS"},
"hygeia":	{"NN"},
"hygge":	{"NN"},
"hygiene":	{"NN"},
"hygienic":	{"JJ"},
"hygienical":	{"JJ"},
"hygienically":	{"RB"},
"hygienics":	{"NN"},
"hygienise":	{"VB","VBP"},
"hygienised":	{"VBD","VBN"},
"hygienises":	{"VBZ"},
"hygienising":	{"VBG"},
"hygienist":	{"NN"},
"hygienists":	{"NNS"},
"hygienize":	{"VB","VBP"},
"hygienized":	{"VBD","VBN"},
"hygienizes":	{"VBZ"},
"hygienizing":	{"VBG"},
"hygrocybe":	{"NN"},
"hygrodeik":	{"NN"},
"hygrometer":	{"NN"},
"hygrophoraceae":	{"NN"},
"hygrophorus":	{"NN"},
"hygrophyte":	{"NN"},
"hygrophytic":	{"JJ"},
"hygroscope":	{"NN"},
"hygroscopic":	{"JJ"},
"hygroton":	{"NN"},
"hygrotrama":	{"NN"},
"hying":	{"VBG"},
"hyla":	{"NN"},
"hylactophryne":	{"NN"},
"hylidae":	{"NN"},
"hylobates":	{"NNS"},
"hylobatidae":	{"NN"},
"hylocereus":	{"NNS"},
"hylocichla":	{"NN"},
"hylophylax":	{"NN"},
"hym":	{"PRP"},
"hymen":	{"NN"},
"hymenaea":	{"NN"},
"hymenal":	{"JJ"},
"hymenanthera":	{"NN"},
"hymeneal":	{"JJ","NN"},
"hymeneals":	{"NNS"},
"hymenium":	{"NN"},
"hymenogastrales":	{"NNS"},
"hymenomycetes":	{"NNS"},
"hymenophyllaceae":	{"NN"},
"hymenophyllum":	{"NN"},
"hymenopter":	{"NN"},
"hymenoptera":	{"NN"},
"hymenopteran":	{"NN"},
"hymenopteron":	{"NN"},
"hymenopterous":	{"JJ"},
"hymens":	{"NNS"},
"hymie":	{"NN"},
"hymn":	{"NN","VB","VBP"},
"hymnal":	{"NN"},
"hymnary":	{"NN"},
"hymnbook":	{"NN"},
"hymned":	{"VBD","VBN"},
"hymning":	{"VBG"},
"hymnody":	{"NN"},
"hymns":	{"NNS","VBZ"},
"hymselfe":	{"NN"},
"hynerpeton":	{"NN"},
"hyoid":	{"JJ","NN"},
"hyoscine":	{"NN"},
"hyoscyamine":	{"NN"},
"hyoscyamus":	{"NNS"},
"hypaethral":	{"JJ"},
"hypallage":	{"NN"},
"hypanthium":	{"NN"},
"hypatia":	{"NN"},
"hype":	{"NN","VB","VBP"},
"hyped":	{"VBD","VBN"},
"hyped-up":	{"JJ"},
"hypentelium":	{"NN"},
"hyper":	{"JJ"},
"hyper-competitive":	{"JJ"},
"hyper-inflation":	{"NN"},
"hyper-trader":	{"NN"},
"hyperacidity":	{"NN"},
"hyperactive":	{"JJ"},
"hyperactively":	{"RB"},
"hyperactivity":	{"NN"},
"hyperacusia":	{"NN"},
"hyperacusis":	{"NN"},
"hyperadrenalism":	{"NN"},
"hyperadrenocorticism":	{"NN"},
"hyperaemia":	{"NN"},
"hyperaldosteronism":	{"NN"},
"hyperalimentation":	{"NN"},
"hyperbaton":	{"NN"},
"hyperbetalipoproteinemia":	{"NN"},
"hyperbilirubinemia":	{"NN"},
"hyperbola":	{"NN"},
"hyperbole":	{"NN"},
"hyperbolic":	{"JJ"},
"hyperbolically":	{"RB"},
"hyperbolise":	{"VB","VBP"},
"hyperbolised":	{"VBD","VBN"},
"hyperbolises":	{"VBZ"},
"hyperbolising":	{"VBG"},
"hyperbolize":	{"VB","VBP"},
"hyperbolized":	{"VBD","VBN"},
"hyperbolizes":	{"VBZ"},
"hyperbolizing":	{"VBG"},
"hyperboloid":	{"NN"},
"hyperboloidal":	{"JJ"},
"hyperborean":	{"NN"},
"hypercalcaemia":	{"NN"},
"hypercalcemia":	{"NN"},
"hypercalcinuria":	{"NN"},
"hypercalciuria":	{"NN"},
"hypercapnia":	{"NN"},
"hypercarbia":	{"NN"},
"hypercatalectic":	{"JJ","NN"},
"hypercellularity":	{"NN"},
"hypercholesteremia":	{"NN"},
"hypercholesterolemia":	{"NN"},
"hypercoaster":	{"NN"},
"hypercritical":	{"JJ"},
"hyperdactyly":	{"NN"},
"hyperdrive":	{"NN"},
"hyperdrives":	{"NNS"},
"hyperemesis":	{"NN"},
"hyperemia":	{"NN"},
"hyperemic":	{"JJ"},
"hyperextend":	{"VB","VBP"},
"hyperextended":	{"VBD","VBN"},
"hyperextending":	{"VBG"},
"hyperextends":	{"VBZ"},
"hyperextension":	{"NN"},
"hyperfine":	{"JJ"},
"hyperglucose":	{"NN"},
"hyperglycaemia":	{"NN"},
"hyperglycemia":	{"NN"},
"hyperhidrosis":	{"NN"},
"hypericaceae":	{"NN"},
"hypericales":	{"NNS"},
"hypericism":	{"NN"},
"hypericum":	{"NN"},
"hyperidrosis":	{"NN"},
"hyperinflation":	{"NN"},
"hyperion":	{"NN"},
"hyperkalemia":	{"NN"},
"hyperkineses":	{"NNS"},
"hyperkinesia":	{"NN"},
"hyperkinesis":	{"NN"},
"hyperkinetic":	{"JJ"},
"hyperkinetically":	{"RB"},
"hyperlink":	{"NN","VB","VBP"},
"hyperlinked":	{"VBD","VBN"},
"hyperlinking":	{"VBG"},
"hyperlinks":	{"NNS","VBZ"},
"hyperlipaemia":	{"NN"},
"hyperlipemia":	{"NN"},
"hyperlipidaemia":	{"NN"},
"hyperlipidemia":	{"NN"},
"hyperlipoidaemia":	{"NN"},
"hyperlipoidemia":	{"NN"},
"hyperlipoproteinemia":	{"NN"},
"hyperlite":	{"NN"},
"hyperlocal":	{"JJ"},
"hypermarket":	{"NN"},
"hypermarkets":	{"NNS"},
"hypermastigina":	{"NN"},
"hypermastigote":	{"NN"},
"hypermedia":	{"NN"},
"hypermenorrhea":	{"NN"},
"hypermetropia":	{"NN"},
"hypermetropic":	{"JJ"},
"hypermetropy":	{"NN"},
"hypermotility":	{"NN"},
"hypernatremia":	{"NN"},
"hypernym":	{"NN"},
"hypernymy":	{"NN"},
"hyperoartia":	{"NN"},
"hyperodontidae":	{"NN"},
"hyperoglyphe":	{"NN"},
"hyperon":	{"NN"},
"hyperoodon":	{"NN"},
"hyperope":	{"NN"},
"hyperopia":	{"NN"},
"hyperopic":	{"JJ"},
"hyperotreta":	{"NN"},
"hyperparathyroidism":	{"NN"},
"hyperpartisan":	{"JJ"},
"hyperpiesia":	{"NN"},
"hyperpiesis":	{"NN"},
"hyperpigmentation":	{"NN"},
"hyperpituitarism":	{"NN"},
"hyperplasia":	{"NN"},
"hyperpnea":	{"NN"},
"hyperpyrexia":	{"NN"},
"hyperrational":	{"JJ"},
"hypersecretion":	{"NN"},
"hypersensitised":	{"JJ"},
"hypersensitive":	{"JJ"},
"hypersensitivity":	{"NN"},
"hypersensitized":	{"JJ"},
"hypersexualisation":	{"NN"},
"hypersexualise":	{"VB","VBP"},
"hypersexualised":	{"VBD","VBN"},
"hypersexualises":	{"VBZ"},
"hypersexualising":	{"VBG"},
"hypersexuality":	{"NN"},
"hypersexualization":	{"NN"},
"hypersexualize":	{"VB","VBP"},
"hypersexualized":	{"VBD","VBN"},
"hypersexualizes":	{"VBZ"},
"hypersexualizing":	{"VBG"},
"hypersexually":	{"RB"},
"hypersomnia":	{"NN"},
"hypersonic":	{"JJ"},
"hyperspectral":	{"JJ"},
"hypersplenism":	{"NN"},
"hyperstat":	{"NN"},
"hypertensin":	{"NN"},
"hypertension":	{"NN"},
"hypertensive":	{"JJ"},
"hypertext":	{"NN"},
"hyperthermal":	{"JJ"},
"hyperthermia":	{"NN"},
"hyperthermy":	{"NN"},
"hyperthyroidism":	{"NN"},
"hypertonia":	{"NN"},
"hypertonic":	{"JJ"},
"hypertonicity":	{"NN"},
"hypertonus":	{"NN"},
"hypertrophic":	{"JJ"},
"hypertrophied":	{"VBD","VBN"},
"hypertrophies":	{"NNS","VBZ"},
"hypertrophy":	{"NN","VB","VBP"},
"hypertrophying":	{"VBG"},
"hypervelocity":	{"NN"},
"hyperventilate":	{"VB","VBP"},
"hyperventilated":	{"VBD","VBN"},
"hyperventilates":	{"VBZ"},
"hyperventilating":	{"VBG"},
"hyperventilation":	{"NN"},
"hypervitaminosis":	{"NN"},
"hypervolaemia":	{"NN"},
"hypervolemia":	{"NN"},
"hyperzeal":	{"NN"},
"hypes":	{"VBZ"},
"hypesthesia":	{"NN"},
"hypethral":	{"JJ"},
"hypha":	{"NN"},
"hyphantria":	{"NN"},
"hyphema":	{"NN"},
"hyphen":	{"NN","VB","VBP"},
"hyphenate":	{"VB","VBP"},
"hyphenated":	{"JJ","VBD","VBN"},
"hyphenates":	{"VBZ"},
"hyphenating":	{"VBG"},
"hyphenation":	{"NN"},
"hyphened":	{"VBD","VBN"},
"hyphening":	{"VBG"},
"hyphens":	{"NNS","VBZ"},
"hyping":	{"VBG"},
"hypnagogic":	{"JJ"},
"hypnagogue":	{"NN"},
"hypnoanalysis":	{"NN"},
"hypnogenesis":	{"NN"},
"hypnogogic":	{"JJ"},
"hypnoid":	{"JJ"},
"hypnopedia":	{"NN"},
"hypnophobia":	{"NN"},
"hypnos":	{"NNS"},
"hypnosis":	{"NN"},
"hypnotherapy":	{"NN"},
"hypnotic":	{"JJ"},
"hypnotically":	{"RB"},
"hypnotise":	{"VB","VBP"},
"hypnotised":	{"VBD","VBN"},
"hypnotiser":	{"NN"},
"hypnotises":	{"VBZ"},
"hypnotising":	{"VBG"},
"hypnotism":	{"NN"},
"hypnotist":	{"NN"},
"hypnotists":	{"NNS"},
"hypnotize":	{"VB","VBP"},
"hypnotized":	{"VBD","VBN"},
"hypnotizer":	{"NN"},
"hypnotizes":	{"VBZ"},
"hypnotizing":	{"VBG"},
"hypo":	{"NN"},
"hypoactive":	{"JJ"},
"hypoadrenalism":	{"NN"},
"hypoadrenocorticism":	{"NN"},
"hypobasidium":	{"NN"},
"hypobetalipoproteinemia":	{"NN"},
"hypoblast":	{"NN"},
"hypocalcaemia":	{"NN"},
"hypocalcemia":	{"NN"},
"hypocapnia":	{"NN"},
"hypocellularity":	{"NN"},
"hypochaeris":	{"NNS"},
"hypochlorite":	{"NN"},
"hypochoeris":	{"NNS"},
"hypochondria":	{"NN"},
"hypochondriac":	{"NN","JJ"},
"hypochondriacal":	{"JJ"},
"hypochondriacs":	{"NNS"},
"hypochondriasis":	{"NN"},
"hypochondrium":	{"NN"},
"hypocorism":	{"NN"},
"hypocracy":	{"NN"},
"hypocreaceae":	{"NN"},
"hypocreales":	{"NNS"},
"hypocrisies":	{"NNS"},
"hypocrisy":	{"NN"},
"hypocrite":	{"NN"},
"hypocrites":	{"NNS"},
"hypocritical":	{"JJ"},
"hypocritically":	{"RB"},
"hypocycloid":	{"NN"},
"hypoderma":	{"NN"},
"hypodermal":	{"JJ"},
"hypodermatidae":	{"NN"},
"hypodermic":	{"JJ","NN"},
"hypodermics":	{"NNS"},
"hypodermis":	{"NN"},
"hypoesthesia":	{"NN"},
"hypogammaglobulinemia":	{"NN"},
"hypoglossal":	{"JJ"},
"hypoglycaemia":	{"NN"},
"hypoglycaemic":	{"JJ"},
"hypoglycemia":	{"NN"},
"hypoglycemic":	{"JJ"},
"hypognathous":	{"JJ"},
"hypogonadism":	{"NN"},
"hypokalaemia":	{"NN"},
"hypokalemia":	{"NN"},
"hypolipoproteinemia":	{"NN"},
"hyponatremia":	{"NN"},
"hyponym":	{"NN"},
"hyponymy":	{"NN"},
"hypopachus":	{"NNS"},
"hypoparathyroidism":	{"NN"},
"hypophyseal":	{"JJ"},
"hypophysectomise":	{"VB","VBP"},
"hypophysectomised":	{"JJ","VBD","VBN"},
"hypophysectomises":	{"VBZ"},
"hypophysectomising":	{"VBG"},
"hypophysectomize":	{"VB","VBP"},
"hypophysectomized":	{"JJ","VBD","VBN"},
"hypophysectomizes":	{"VBZ"},
"hypophysectomizing":	{"VBG"},
"hypophysectomy":	{"NN"},
"hypophysial":	{"JJ"},
"hypophysis":	{"NN"},
"hypopigmentation":	{"NN"},
"hypopitys":	{"NNS"},
"hypoplasia":	{"NN"},
"hypopnea":	{"NN"},
"hypoproteinemia":	{"NN"},
"hypos":	{"NNS"},
"hyposmia":	{"NN"},
"hypospadias":	{"NNS"},
"hypostasis":	{"NN"},
"hypostatisation":	{"NN"},
"hypostatise":	{"VB","VBP"},
"hypostatised":	{"VBD","VBN"},
"hypostatises":	{"VBZ"},
"hypostatising":	{"VBG"},
"hypostatization":	{"NN"},
"hypostatize":	{"VB","VBP"},
"hypostatized":	{"VBD","VBN"},
"hypostatizes":	{"VBZ"},
"hypostatizing":	{"VBG"},
"hypotension":	{"NN"},
"hypotensive":	{"JJ"},
"hypotenuse":	{"NN"},
"hypothalamic":	{"JJ"},
"hypothalamic-cortical":	{"JJ"},
"hypothalamically":	{"RB"},
"hypothalamus":	{"NN"},
"hypothecate":	{"VB","VBP"},
"hypothecated":	{"VBD","VBN"},
"hypothecates":	{"VBZ"},
"hypothecating":	{"VBG"},
"hypothermia":	{"NN"},
"hypothermic":	{"JJ"},
"hypotheses":	{"NNS"},
"hypothesis":	{"NN"},
"hypothesise":	{"VB","VBP"},
"hypothesised":	{"VBD","VBN"},
"hypothesises":	{"VBZ"},
"hypothesising":	{"VBG"},
"hypothesize":	{"VB","VBP"},
"hypothesized":	{"VBD","VBN"},
"hypothesizes":	{"VBZ"},
"hypothesizing":	{"VBG"},
"hypothetic":	{"JJ"},
"hypothetical":	{"JJ","NN"},
"hypothetically":	{"RB"},
"hypotheticals":	{"NNS"},
"hypothrombinemia":	{"NN"},
"hypothyroidism":	{"NN"},
"hypotonia":	{"NN"},
"hypotonic":	{"JJ"},
"hypotonicity":	{"NN"},
"hypotonus":	{"NN"},
"hypovitaminosis":	{"NN"},
"hypovolaemia":	{"NN"},
"hypovolaemic":	{"JJ"},
"hypovolemia":	{"NN"},
"hypovolemic":	{"JJ"},
"hypoxaemia":	{"NN"},
"hypoxia":	{"NN"},
"hypoxic":	{"JJ"},
"hypoxidaceae":	{"NN"},
"hypoxis":	{"NN"},
"hypozeugma":	{"NN"},
"hypozeuxis":	{"NN"},
"hypsiglena":	{"NN"},
"hypsiprymnodon":	{"NN"},
"hypsography":	{"NN"},
"hypsometer":	{"NN"},
"hypsometry":	{"NN"},
"hyracoidea":	{"NN"},
"hyracotherium":	{"NN"},
"hyrax":	{"NN"},
"hys":	{"PRP$"},
"hyson":	{"NN"},
"hyssop":	{"NN"},
"hyssopus":	{"NN"},
"hysterectomy":	{"NN"},
"hysteresis":	{"NN"},
"hysteria":	{"NN"},
"hysteric":	{"JJ"},
"hysterical":	{"JJ"},
"hysterically":	{"RB"},
"hysterics":	{"NNS"},
"hysterocatalepsy":	{"NN"},
"hysteron-proteron":	{"NN"},
"hysterosalpingogram":	{"NN"},
"hysteroscopy":	{"NN"},
"hysterotomy":	{"NN"},
"hystricidae":	{"NN"},
"hystricomorpha":	{"NN"},
"hytrin":	{"NN"},
"hytt":	{"PRP"},
"hz":	{"NN"},
"i":	{"NN","SYM","LS"},
"i-beam":	{"NN"},
"i-th":	{"NN"},
"i.d":	{"NN"},
"i.d.":	{"NN"},
"i.e.":	{"RB"},
"i.e.d.":	{"NN"},
"i.q.":	{"NN"},
"i.w.w.":	{"NN"},
"i860":	{"NN"},
"iPad":	{"NN"},
"iWatch":	{"NN"},
"ia":	{"NN"},
"iaa":	{"NN"},
"iaea":	{"NN"},
"iain":	{"NN"},
"iamb":	{"NN"},
"iambi":	{"NNS"},
"iambic":	{"JJ","NN"},
"iambics":	{"NNS"},
"iambus":	{"NN"},
"iambuses":	{"NNS"},
"ianfu":	{"NN"},
"iapetus":	{"NNS"},
"iatrogenic":	{"JJ"},
"ib.":	{"RB"},
"ibadan":	{"NN"},
"ibda-c":	{"NN"},
"iberis":	{"NNS"},
"ibero-mesornis":	{"NNS"},
"ibert":	{"NN"},
"ibex":	{"NN","NNS"},
"ibexes":	{"NNS"},
"ibid":	{"RB"},
"ibidem":	{"RB"},
"ibis":	{"NN"},
"ibises":	{"NNS"},
"ibm-based":	{"JJ"},
"ibm-bashing":	{"NN"},
"ibm-compatible":	{"JJ"},
"ibm-oriented":	{"JJ"},
"ibm-remarketer":	{"JJ"},
"ibn":	{"NN"},
"ibn-roshd":	{"NN"},
"ibn-sina":	{"NN"},
"ibrd":	{"NN"},
"ibsenian":	{"JJ"},
"ibuprofen":	{"NN"},
"ic":	{"JJ","NN"},
"icaco":	{"NN"},
"icao":	{"NN"},
"icbm":	{"NN"},
"icc":	{"NN"},
"ice":	{"NN","VB","VBP"},
"ice-baggers":	{"NNS"},
"ice-breaker":	{"NN"},
"ice-breakers":	{"NNS"},
"ice-chest":	{"NN"},
"ice-clogged":	{"JJ"},
"ice-cold":	{"JJ"},
"ice-core":	{"NN"},
"ice-cream":	{"NN"},
"ice-creams":	{"NNS"},
"ice-cube":	{"NN"},
"ice-cubes":	{"NNS"},
"ice-feeling":	{"NN"},
"ice-filled":	{"JJ"},
"ice-free":	{"JJ"},
"ice-skate":	{"NN","VB","VBP"},
"ice-skated":	{"VBD","VBN"},
"ice-skater":	{"NN"},
"ice-skaters":	{"NNS"},
"ice-skates":	{"NNS","VBZ"},
"ice-skating":	{"VBG","NN"},
"ice-wagon":	{"NN"},
"iceberg":	{"NN"},
"icebergs":	{"NNS"},
"iceboat":	{"NN"},
"icebound":	{"JJ"},
"icebox":	{"NN"},
"iceboxes":	{"NNS"},
"icebreaker":	{"NN"},
"icebreakers":	{"NNS"},
"icebreaking":	{"JJ"},
"icecap":	{"NN"},
"icecream":	{"NN"},
"iced":	{"JJ","VBD","VBN"},
"iced-tea":	{"NN"},
"icefall":	{"NN"},
"icehouse":	{"NN"},
"icelandic-speaking":	{"JJ"},
"iceman":	{"NN"},
"icemen":	{"NNS"},
"icepick":	{"NN"},
"ices":	{"VBZ","NNS"},
"icetray":	{"NN"},
"ich":	{"NN"},
"ichneumon":	{"NN"},
"ichneumon-fly":	{"NN"},
"ichneumonidae":	{"NN"},
"ichor":	{"NN"},
"ichorous":	{"JJ"},
"ichthyolatry":	{"NN"},
"ichthyologist":	{"NN"},
"ichthyology":	{"NN"},
"ichthyosaur":	{"NN"},
"ichthyosauria":	{"NN"},
"ichthyosauridae":	{"NN"},
"ichthyosaurus":	{"NN"},
"ichthyosis":	{"NN"},
"ichyostega":	{"NN"},
"ici":	{"NN"},
"icicle":	{"NN"},
"icicles":	{"NNS"},
"icier":	{"JJR"},
"iciest":	{"JJS"},
"icily":	{"RB"},
"iciness":	{"NN"},
"icing":	{"NN","VBG"},
"icky":	{"JJ"},
"icon":	{"NN"},
"iconic":	{"JJ"},
"iconically":	{"RB"},
"iconoclasm":	{"NN"},
"iconoclast":	{"NN"},
"iconoclastic":	{"JJ"},
"iconoclasts":	{"NNS"},
"iconography":	{"NN"},
"iconolatry":	{"NN"},
"iconology":	{"NN"},
"iconoscope":	{"NN"},
"icons":	{"NNS"},
"icosahedral":	{"JJ"},
"icosahedron":	{"NN"},
"icsh":	{"NN"},
"ictal":	{"JJ"},
"ictalurus":	{"NN"},
"icteria":	{"NN"},
"icteric":	{"JJ"},
"icteridae":	{"NN"},
"icterogenic":	{"JJ"},
"icterus":	{"NN"},
"ictic":	{"JJ"},
"ictiobus":	{"NN"},
"ictodosaur":	{"NN"},
"ictodosauria":	{"NN"},
"ictonyx":	{"NN"},
"ictus":	{"NN"},
"icu":	{"NN"},
"icy":	{"JJ"},
"id":	{"NN"},
"idaho-based":	{"JJ"},
"iddm":	{"NN"},
"idea":	{"NN"},
"idea-exchange":	{"NN"},
"ideal":	{"JJ","NN"},
"idealisation":	{"NN"},
"idealise":	{"VB","VBP"},
"idealised":	{"VBD","VBN","JJ"},
"idealises":	{"VBZ"},
"idealising":	{"VBG"},
"idealism":	{"NN"},
"idealist":	{"NN"},
"idealistic":	{"JJ"},
"idealists":	{"NNS"},
"ideality":	{"NN"},
"idealization":	{"NN"},
"idealize":	{"VB","VBP"},
"idealized":	{"VBD","VBN","JJ"},
"idealizes":	{"VBZ"},
"idealizing":	{"VBG"},
"ideally":	{"RB"},
"idealogue":	{"NN"},
"ideals":	{"NNS"},
"ideas":	{"NNS"},
"ideate":	{"VB","VBP"},
"ideated":	{"VBD","VBN"},
"ideates":	{"VBZ"},
"ideating":	{"VBG"},
"ideation":	{"NN"},
"ideational":	{"JJ"},
"idempotent":	{"JJ"},
"identical":	{"JJ"},
"identically":	{"RB"},
"identicalness":	{"NN"},
"identifiable":	{"JJ"},
"identifiably":	{"RB"},
"identification":	{"NN"},
"identifications":	{"NNS"},
"identified":	{"VBN","VBD"},
"identifier":	{"NN"},
"identifiers":	{"NNS"},
"identifies":	{"VBZ"},
"identify":	{"VB","VBP"},
"identifying":	{"VBG"},
"identikit":	{"NN"},
"identikits":	{"NNS"},
"identities":	{"NNS"},
"identity":	{"NN"},
"identity-management":	{"NN"},
"ideogram":	{"NN"},
"ideograms":	{"NNS"},
"ideograph":	{"NN"},
"ideographic":	{"JJ"},
"ideographically":	{"RB"},
"ideographs":	{"NNS"},
"ideography":	{"NN"},
"ideologic":	{"JJ"},
"ideological":	{"JJ"},
"ideologically":	{"RB"},
"ideologies":	{"NNS"},
"ideologism":	{"NN"},
"ideologist":	{"NN"},
"ideologists":	{"NNS"},
"ideologue":	{"NN"},
"ideologues":	{"NNS"},
"ideology":	{"NN"},
"ides":	{"NNS"},
"idesia":	{"NN"},
"idf":	{"NN"},
"idiocies":	{"NNS"},
"idiocy":	{"NN"},
"idiographic":	{"JJ"},
"idiolatry":	{"NN"},
"idiolect":	{"NN"},
"idiom":	{"NN"},
"idiomatic":	{"JJ"},
"idiomatical":	{"JJ"},
"idiomatically":	{"RB"},
"idioms":	{"NNS"},
"idiopathic":	{"JJ"},
"idiopathy":	{"NN"},
"idiosyncrasies":	{"NNS"},
"idiosyncrasy":	{"NN"},
"idiosyncratic":	{"JJ"},
"idiot":	{"NN"},
"idiot-grin":	{"NN"},
"idiotic":	{"JJ"},
"idiotically":	{"RB"},
"idiots":	{"NNS"},
"idiotype":	{"NN"},
"idiotypes":	{"NNS"},
"iditarod":	{"NN"},
"idle":	{"JJ","VB","VBP"},
"idled":	{"VBD","VBN"},
"idleness":	{"NN"},
"idler":	{"NN","JJR"},
"idlers":	{"NNS"},
"idles":	{"VBZ"},
"idlest":	{"JJS"},
"idling":	{"VBG"},
"idlings":	{"NNS"},
"idly":	{"RB"},
"ido":	{"NN"},
"idocrase":	{"NN"},
"idol":	{"NN"},
"idol-worship":	{"NN"},
"idolater":	{"NN"},
"idolatress":	{"NN"},
"idolatrous":	{"JJ"},
"idolatrously":	{"RB"},
"idolatry":	{"NN"},
"idolisation":	{"NN"},
"idolise":	{"VB","VBP"},
"idolised":	{"VBD","VBN"},
"idoliser":	{"NN"},
"idolises":	{"VBZ"},
"idolising":	{"VBG"},
"idolization":	{"NN"},
"idolize":	{"VB","VBP"},
"idolized":	{"VBD","VBN"},
"idolizer":	{"NN"},
"idolizes":	{"VBZ"},
"idolizing":	{"VBG"},
"idols":	{"NNS"},
"idosyncratic":	{"JJ"},
"idp":	{"NN"},
"ids":	{"NNS"},
"idun":	{"NN"},
"idyl":	{"NN"},
"idyll":	{"NN"},
"idyllic":	{"JJ"},
"idyllically":	{"RB"},
"idylls":	{"NNS"},
"ie":	{"RB"},
"ied":	{"NN"},
"if":	{"CC","NN","IN"},
"ifc":	{"NN"},
"iffy":	{"JJ"},
"ifs":	{"NNS"},
"ig":	{"NN"},
"iga":	{"NN"},
"igbo":	{"NN"},
"igd":	{"NN"},
"ige":	{"NN"},
"igg":	{"NN"},
"igigi":	{"NN"},
"iglesias":	{"NNS"},
"igloo":	{"NN"},
"igloos":	{"NNS"},
"iglu":	{"NN"},
"igm":	{"NN"},
"ignatius":	{"NN"},
"igneous":	{"JJ"},
"ignescent":	{"JJ"},
"ignitable":	{"JJ"},
"ignite":	{"VB","VBP"},
"ignited":	{"VBD","VBN"},
"igniter":	{"NN"},
"ignites":	{"VBZ"},
"ignitible":	{"JJ"},
"igniting":	{"VBG"},
"ignition":	{"NN"},
"ignitions":	{"NNS"},
"ignitor":	{"NN"},
"ignobility":	{"NN"},
"ignoble":	{"JJ"},
"ignobleness":	{"NN"},
"ignobly":	{"RB"},
"ignominious":	{"JJ"},
"ignominiously":	{"RB"},
"ignominiousness":	{"NN"},
"ignominy":	{"NN"},
"ignoramus":	{"NN"},
"ignoramuses":	{"NNS"},
"ignorance":	{"NN"},
"ignorant":	{"JJ"},
"ignorantly":	{"RB"},
"ignorantness":	{"NN"},
"ignore":	{"VB","VBP"},
"ignored":	{"VBN","VBD"},
"ignores":	{"VBZ"},
"ignoring":	{"VBG"},
"iguana":	{"NN"},
"iguanas":	{"NNS"},
"iguania":	{"NN"},
"iguanid":	{"NN"},
"iguanidae":	{"NN"},
"iguanodon":	{"NN"},
"iguanodontidae":	{"NN"},
"iguassu":	{"NN"},
"iguazu":	{"NN"},
"ii":	{"NN","CD","LS","SYM"},
"iii":	{"SYM"},
"iis":	{"NN"},
"ij":	{"NN"},
"ijssel":	{"NN"},
"ijsselmeer":	{"NN"},
"ijtihad":	{"NN"},
"ikey-kikey":	{"JJ"},
"ikhanaton":	{"NN"},
"ikon":	{"NN"},
"ilama":	{"NN"},
"ilang-ilang":	{"NN"},
"ile-de-france":	{"NN"},
"ile-st-louis":	{"NNS"},
"ileitis":	{"NN"},
"ileostomy":	{"NN"},
"ileum":	{"NN"},
"ileus":	{"NN"},
"ilex":	{"NN"},
"ilexes":	{"NNS"},
"iliac":	{"JJ"},
"iliamna":	{"NN"},
"ilion":	{"NN"},
"ilium":	{"NN"},
"ilk":	{"NN"},
"ill":	{"JJ","RB","NN"},
"ill-advised":	{"JJ"},
"ill-affected":	{"JJ"},
"ill-being":	{"NN"},
"ill-bred":	{"JJ"},
"ill-breeding":	{"NN"},
"ill-chosen":	{"JJ"},
"ill-conceived":	{"JJ"},
"ill-considered":	{"JJ"},
"ill-defined":	{"JJ"},
"ill-disposed":	{"JJ"},
"ill-dressed":	{"JJ"},
"ill-equipped":	{"JJ"},
"ill-famed":	{"JJ"},
"ill-fated":	{"JJ"},
"ill-favored":	{"JJ"},
"ill-favoured":	{"JJ"},
"ill-fed":	{"JJ"},
"ill-fitting":	{"JJ"},
"ill-formed":	{"JJ"},
"ill-founded":	{"JJ"},
"ill-gotten":	{"JJ"},
"ill-humored":	{"JJ"},
"ill-humoured":	{"JJ"},
"ill-judged":	{"JJ"},
"ill-mannered":	{"JJ"},
"ill-natured":	{"JJ"},
"ill-omened":	{"JJ"},
"ill-prepared":	{"JJ"},
"ill-proportioned":	{"JJ"},
"ill-scented":	{"JJ"},
"ill-shapen":	{"JJ"},
"ill-smelling":	{"JJ"},
"ill-sorted":	{"JJ"},
"ill-starred":	{"JJ"},
"ill-suited":	{"JJ"},
"ill-tempered":	{"JJ"},
"ill-timed":	{"JJ"},
"ill-trained":	{"JJ"},
"ill-treat":	{"VB","VBP"},
"ill-treated":	{"VBD","VBN"},
"ill-treating":	{"VBG"},
"ill-treatment":	{"NN"},
"ill-treats":	{"VBZ"},
"ill-understood":	{"JJ"},
"ill-usage":	{"NN"},
"ill-use":	{"NN"},
"ill-used":	{"JJ"},
"illampu":	{"NN"},
"illation":	{"NN"},
"illative":	{"JJ"},
"illecebrum":	{"NN"},
"illegal":	{"JJ","NN"},
"illegalise":	{"VB","VBP"},
"illegalised":	{"VBD","VBN"},
"illegalises":	{"VBZ"},
"illegalising":	{"VBG"},
"illegalities":	{"NNS"},
"illegality":	{"NN"},
"illegalize":	{"VB","VBP"},
"illegalized":	{"VBD","VBN"},
"illegalizes":	{"VBZ"},
"illegalizing":	{"VBG"},
"illegally":	{"RB"},
"illegals":	{"NNS"},
"illegibility":	{"NN"},
"illegible":	{"JJ"},
"illegibly":	{"RB"},
"illegitimacy":	{"NN"},
"illegitimate":	{"JJ"},
"illegitimately":	{"RB"},
"illiberal":	{"JJ"},
"illiberality":	{"NN"},
"illiberally":	{"RB"},
"illicit":	{"JJ"},
"illicitly":	{"RB"},
"illicitness":	{"NN"},
"illicium":	{"NN"},
"illimani":	{"NN"},
"illimitable":	{"JJ"},
"illinois-based":	{"JJ"},
"illinoisan":	{"NN"},
"illiquid":	{"JJ","NN"},
"illiquidity":	{"NN"},
"illiteracy":	{"NN"},
"illiterate":	{"JJ","NN"},
"illiterates":	{"NNS"},
"illness":	{"NN"},
"illnesses":	{"NNS"},
"illogic":	{"NN"},
"illogical":	{"JJ"},
"illogicality":	{"NN"},
"illogically":	{"RB"},
"illogicalness":	{"NN"},
"ills":	{"NNS"},
"illume":	{"VB","VBP"},
"illumed":	{"VBD","VBN"},
"illumes":	{"VBZ"},
"illuminance":	{"NN"},
"illuminant":	{"NN"},
"illuminate":	{"VB","VBP"},
"illuminated":	{"VBD","VBN","JJ"},
"illuminates":	{"VBZ"},
"illuminating":	{"JJ","VBG"},
"illumination":	{"NN"},
"illuminations":	{"NNS"},
"illumine":	{"VB","VBP"},
"illumined":	{"VBD","VBN"},
"illumines":	{"VBZ"},
"illuming":	{"VBG"},
"illumining":	{"VBG"},
"illusion":	{"NN"},
"illusional":	{"JJ"},
"illusionary":	{"JJ"},
"illusionist":	{"NN"},
"illusionists":	{"NNS"},
"illusions":	{"NNS"},
"illusive":	{"JJ"},
"illusiveness":	{"NN"},
"illusory":	{"JJ"},
"illustrate":	{"VB","VBP"},
"illustrated":	{"JJ","VBD","VBN"},
"illustrates":	{"VBZ"},
"illustrating":	{"VBG"},
"illustration":	{"NN"},
"illustrations":	{"NNS"},
"illustrative":	{"JJ"},
"illustrator":	{"NN"},
"illustrators":	{"NNS"},
"illustrious":	{"JJ"},
"illustriously":	{"RB"},
"illustriousness":	{"NN"},
"illyria":	{"NN"},
"illyrian":	{"NN"},
"ilmen":	{"NN"},
"ilmenite":	{"NN"},
"ilo":	{"NN"},
"ilosone":	{"NN"},
"ilx":	{"JJ"},
"ilxx":	{"JJ"},
"ilxxx":	{"JJ"},
"ilyushin":	{"NN"},
"image":	{"NN","VB","VBP"},
"image-building":	{"NN"},
"image-making":	{"NN","JJ"},
"image-processing":	{"NN","JJ"},
"image-provoking":	{"JJ"},
"imaged":	{"VBD","VBN"},
"imagery":	{"NN"},
"images":	{"NNS","VBZ"},
"imaginable":	{"JJ"},
"imaginary":	{"JJ"},
"imagination":	{"NN"},
"imaginations":	{"NNS"},
"imaginative":	{"JJ"},
"imaginatively":	{"RB"},
"imaginativeness":	{"NN"},
"imagine":	{"VB","VBP"},
"imagined":	{"VBD","VBN"},
"imagines":	{"VBZ"},
"imaging":	{"NN","VBG"},
"imagining":	{"VBG"},
"imaginings":	{"NNS"},
"imagism":	{"NN"},
"imagnation":	{"NN"},
"imago":	{"NN"},
"imam":	{"NN"},
"imams":	{"NNS"},
"imaret":	{"NN"},
"imaum":	{"NN"},
"imavate":	{"NN"},
"imbalance":	{"NN"},
"imbalanced":	{"JJ"},
"imbalances":	{"NNS"},
"imbauba":	{"NN"},
"imbecile":	{"NN","JJ"},
"imbeciles":	{"NNS"},
"imbecilic":	{"JJ"},
"imbecilities":	{"NNS"},
"imbecility":	{"NN"},
"imbed":	{"VB","VBP"},
"imbedded":	{"JJ","VBD","VBN"},
"imbedding":	{"VBG"},
"imbeds":	{"VBZ"},
"imbibe":	{"VB","VBP"},
"imbibed":	{"VBN","VBD"},
"imbiber":	{"NN"},
"imbibes":	{"VBZ"},
"imbibing":	{"VBG"},
"imbibition":	{"NN"},
"imbricate":	{"JJ","VB","VBP"},
"imbricated":	{"VBD","VBN"},
"imbricates":	{"VBZ"},
"imbricating":	{"VBG"},
"imbrication":	{"NN"},
"imbroglio":	{"NN"},
"imbroglios":	{"NNS"},
"imbrue":	{"VB","VBP"},
"imbrued":	{"VBD","VBN"},
"imbrues":	{"VBZ"},
"imbruing":	{"VBG"},
"imbue":	{"VB","VBP"},
"imbued":	{"VBD","VBN","JJ"},
"imbues":	{"VBZ"},
"imbuing":	{"VBG"},
"imcomparable":	{"JJ"},
"imcomplete":	{"JJ"},
"imf":	{"NN"},
"imf-approved":	{"JJ"},
"imf-guided":	{"JJ"},
"imhoff":	{"NN"},
"imidazole":	{"NN"},
"imide":	{"NN"},
"iminazole":	{"NN"},
"imipramine":	{"NN"},
"imitate":	{"VB","VBP"},
"imitated":	{"VBN","VBD"},
"imitates":	{"VBZ"},
"imitating":	{"VBG"},
"imitation":	{"NN","JJ"},
"imitation-caning":	{"JJ"},
"imitation-woodgrain":	{"NN"},
"imitations":	{"NNS"},
"imitative":	{"JJ"},
"imitator":	{"NN"},
"imitators":	{"NNS"},
"immaculate":	{"JJ"},
"immaculately":	{"RB"},
"immaculateness":	{"NN"},
"immanence":	{"NN"},
"immanency":	{"NN"},
"immanent":	{"JJ"},
"immaterial":	{"JJ"},
"immaterialise":	{"VB","VBP"},
"immaterialised":	{"VBD","VBN"},
"immaterialises":	{"VBZ"},
"immaterialising":	{"VBG"},
"immateriality":	{"NN"},
"immaterialize":	{"VB","VBP"},
"immaterialized":	{"VBD","VBN"},
"immaterializes":	{"VBZ"},
"immaterializing":	{"VBG"},
"immature":	{"JJ"},
"immaturely":	{"RB"},
"immatureness":	{"NN"},
"immaturity":	{"NN"},
"immeasurable":	{"JJ"},
"immeasurably":	{"RB"},
"immediacy":	{"NN"},
"immediate":	{"JJ"},
"immediate-response":	{"JJ"},
"immediately":	{"RB","IN"},
"immediateness":	{"NN"},
"immemorial":	{"JJ"},
"immense":	{"JJ"},
"immensely":	{"RB"},
"immenseness":	{"NN"},
"immensities":	{"NNS"},
"immensity":	{"NN"},
"immensurable":	{"JJ"},
"immerse":	{"VB","VBP"},
"immersed":	{"VBN","VBD","JJ"},
"immerses":	{"VBZ"},
"immersing":	{"VBG"},
"immersion":	{"NN"},
"immigrant":	{"NN"},
"immigrants":	{"NNS"},
"immigrate":	{"VB","VBP"},
"immigrated":	{"VBD","VBN"},
"immigrates":	{"VBZ"},
"immigrating":	{"VBG"},
"immigration":	{"NN"},
"imminence":	{"NN"},
"imminency":	{"NN"},
"imminent":	{"JJ"},
"imminently":	{"RB"},
"imminentness":	{"NN"},
"immingle":	{"VB","VBP"},
"immingled":	{"VBD","VBN"},
"immingles":	{"VBZ"},
"immingling":	{"VBG"},
"immiscible":	{"JJ"},
"immiserated":	{"JJ"},
"immiseration":	{"NN"},
"immiserations":	{"NNS"},
"immix":	{"VB","VBP"},
"immobile":	{"JJ"},
"immobilisation":	{"NN"},
"immobilise":	{"VB","VBP"},
"immobilised":	{"VBD","VBN"},
"immobilises":	{"VBZ"},
"immobilising":	{"VBG"},
"immobility":	{"NN"},
"immobilization":	{"NN"},
"immobilize":	{"VB","VBP"},
"immobilized":	{"VBD","VBN"},
"immobilizes":	{"VBZ"},
"immobilizing":	{"VBG"},
"immoderate":	{"JJ"},
"immoderately":	{"RB"},
"immoderateness":	{"NN"},
"immoderation":	{"NN"},
"immodest":	{"JJ"},
"immodestly":	{"RB"},
"immodesty":	{"NN"},
"immolate":	{"VB","VBP"},
"immolated":	{"VBD","VBN"},
"immolates":	{"VBZ"},
"immolating":	{"VBG"},
"immolation":	{"NN"},
"immoral":	{"JJ"},
"immoralities":	{"NNS"},
"immorality":	{"NN"},
"immorally":	{"RB"},
"immortal":	{"JJ","NN"},
"immortalise":	{"VB","VBP"},
"immortalised":	{"VBD","VBN"},
"immortalises":	{"VBZ"},
"immortalising":	{"VBG"},
"immortality":	{"NN"},
"immortalize":	{"VB","VBP"},
"immortalized":	{"VBD","VBN"},
"immortalizes":	{"VBZ"},
"immortalizing":	{"VBG"},
"immortals":	{"NNS"},
"immortelle":	{"NN"},
"immotile":	{"JJ"},
"immotility":	{"NN"},
"immovability":	{"NN"},
"immovable":	{"JJ"},
"immovableness":	{"NN"},
"immovably":	{"RB"},
"immoveable":	{"JJ"},
"immune":	{"JJ"},
"immune-system":	{"NN"},
"immunisation":	{"NN"},
"immunise":	{"VB","VBP"},
"immunised":	{"VBD","VBN"},
"immunises":	{"VBZ"},
"immunising":	{"VBG"},
"immunities":	{"NNS"},
"immunity":	{"NN"},
"immunization":	{"NN"},
"immunize":	{"VB","VBP"},
"immunized":	{"VBD","VBN"},
"immunizes":	{"VBZ"},
"immunizing":	{"VBG"},
"immunoassay":	{"NN"},
"immunochemical":	{"JJ"},
"immunochemistry":	{"NN"},
"immunocompetence":	{"NN"},
"immunocompetent":	{"JJ"},
"immunocompromised":	{"JJ"},
"immunocyte":	{"NN"},
"immunocytes":	{"NNS"},
"immunodeficiency":	{"NN"},
"immunodeficient":	{"JJ"},
"immunoelectrophoresis":	{"NN"},
"immunofluorescence":	{"NN"},
"immunogen":	{"NN"},
"immunogenic":	{"JJ"},
"immunogenicity":	{"NN"},
"immunoglobulin":	{"NN"},
"immunohistochemistry":	{"NN"},
"immunologic":	{"JJ","NN"},
"immunological":	{"JJ"},
"immunologically":	{"RB"},
"immunologist":	{"NN"},
"immunology":	{"NN"},
"immunopathology":	{"NN"},
"immunosuppressant":	{"NN"},
"immunosuppressed":	{"JJ"},
"immunosuppression":	{"NN"},
"immunosuppressive":	{"JJ"},
"immunosuppressor":	{"NN"},
"immunotherapeutic":	{"JJ"},
"immunotherapy":	{"NN"},
"immure":	{"VB","VBP"},
"immured":	{"VBD","VBN"},
"immurement":	{"NN"},
"immures":	{"VBZ"},
"immuring":	{"VBG"},
"immutability":	{"NN"},
"immutable":	{"JJ"},
"immutableness":	{"NN"},
"immutably":	{"RB"},
"imo":	{"NN"},
"imp":	{"NN","VB","VBP"},
"impact":	{"NN","VB","VBP"},
"impacted":	{"JJ","VBD","VBN"},
"impacting":	{"VBG"},
"impaction":	{"NN"},
"impacts":	{"NNS","VBZ"},
"impair":	{"VB","VBP"},
"impaired":	{"VBD","VBN","JJ"},
"impairer":	{"NN"},
"impairing":	{"VBG"},
"impairment":	{"NN"},
"impairs":	{"VBZ"},
"impala":	{"NN","NNS"},
"impalas":	{"NNS"},
"impale":	{"VB","VBP"},
"impaled":	{"VBD","VBN"},
"impalement":	{"NN"},
"impalements":	{"NNS"},
"impales":	{"VBZ"},
"impaling":	{"VBG"},
"impalpability":	{"NN"},
"impalpable":	{"JJ"},
"impalpably":	{"RB"},
"impanel":	{"VB","VBP"},
"impaneled":	{"VBD","VBN"},
"impaneling":	{"VBG"},
"impanelled":	{"VBD","VBN"},
"impanelling":	{"VBG"},
"impanels":	{"VBZ"},
"imparipinnate":	{"JJ"},
"impart":	{"VB","VBP"},
"impartation":	{"NN"},
"imparted":	{"VBN","VBD"},
"impartial":	{"JJ"},
"impartiality":	{"NN"},
"impartially":	{"RB"},
"imparting":	{"VBG"},
"imparts":	{"VBZ"},
"impassable":	{"JJ"},
"impasse":	{"NN"},
"impassible":	{"JJ"},
"impassion":	{"VB","VBP"},
"impassioned":	{"JJ","VBD","VBN"},
"impassioning":	{"VBG"},
"impassions":	{"VBZ"},
"impassive":	{"JJ"},
"impassively":	{"RB"},
"impassiveness":	{"NN"},
"impassivity":	{"NN"},
"impasto":	{"NN"},
"impatience":	{"NN"},
"impatiens":	{"NNS"},
"impatient":	{"JJ"},
"impatiently":	{"RB"},
"impayable":	{"JJ"},
"impeach":	{"VB","VBP"},
"impeachability":	{"NN"},
"impeachable":	{"JJ"},
"impeached":	{"VBD","VBN"},
"impeaches":	{"VBZ"},
"impeaching":	{"VBG"},
"impeachment":	{"NN"},
"impeachments":	{"NNS"},
"impeccability":	{"NN"},
"impeccable":	{"JJ"},
"impeccably":	{"RB"},
"impeccant":	{"JJ"},
"impecunious":	{"JJ"},
"impecuniousness":	{"NN"},
"imped":	{"VBD","VBN"},
"impedance":	{"NN"},
"impede":	{"VB","VBP"},
"impeded":	{"VBD","VBN"},
"impedes":	{"VBZ"},
"impediment":	{"NN"},
"impedimenta":	{"NNS"},
"impediments":	{"NNS"},
"impeding":	{"VBG"},
"impeditive":	{"JJ"},
"impel":	{"VB","VBP"},
"impelled":	{"VBD","VBN"},
"impellent":	{"JJ"},
"impeller":	{"NN"},
"impelling":	{"VBG"},
"impels":	{"VBZ"},
"impend":	{"VB","VBP"},
"impended":	{"VBD","VBN"},
"impendence":	{"NN"},
"impendency":	{"NN"},
"impendent":	{"JJ"},
"impending":	{"JJ","VBG"},
"impends":	{"VBZ"},
"impenetrability":	{"NN"},
"impenetrable":	{"JJ"},
"impenetrableness":	{"NN"},
"impenitence":	{"NN"},
"impenitency":	{"NN"},
"impenitent":	{"JJ"},
"impenitently":	{"RB"},
"imperative":	{"JJ","NN"},
"imperatively":	{"RB"},
"imperativeness":	{"NN"},
"imperatives":	{"NNS"},
"imperceptibility":	{"NN"},
"imperceptible":	{"JJ"},
"imperceptibly":	{"RB"},
"imperfect":	{"JJ","NN"},
"imperfectability":	{"NN"},
"imperfectibility":	{"NN"},
"imperfectible":	{"JJ"},
"imperfection":	{"NN"},
"imperfections":	{"NNS"},
"imperfective":	{"NN"},
"imperfectly":	{"RB"},
"imperfectness":	{"NN"},
"imperforate":	{"JJ"},
"imperial":	{"JJ"},
"imperialism":	{"NN"},
"imperialist":	{"NN","JJ"},
"imperialistic":	{"JJ"},
"imperialists":	{"NNS"},
"imperially":	{"RB"},
"imperil":	{"VB","VBP"},
"imperiled":	{"VBD","VBN"},
"imperiling":	{"VBG"},
"imperilled":	{"VBD","VBN"},
"imperilling":	{"VBG"},
"imperils":	{"VBZ"},
"imperious":	{"JJ"},
"imperiously":	{"RB"},
"imperiousness":	{"NN"},
"imperishability":	{"NN"},
"imperishable":	{"JJ"},
"imperishableness":	{"NN"},
"imperishingness":	{"NN"},
"imperium":	{"NN"},
"impermanence":	{"NN"},
"impermanency":	{"NN"},
"impermanent":	{"JJ"},
"impermeability":	{"NN"},
"impermeable":	{"JJ"},
"impermeableness":	{"NN"},
"impermissibility":	{"NN"},
"impermissible":	{"JJ"},
"impermissibly":	{"RB"},
"impersonal":	{"JJ"},
"impersonalized":	{"JJ"},
"impersonally":	{"RB"},
"impersonate":	{"VB","VBP"},
"impersonated":	{"VBD","VBN"},
"impersonates":	{"VBZ"},
"impersonating":	{"VBG"},
"impersonation":	{"NN"},
"impersonations":	{"NNS"},
"impersonator":	{"NN"},
"impersonators":	{"NNS"},
"impertinence":	{"NN"},
"impertinences":	{"NNS"},
"impertinent":	{"JJ"},
"impertinently":	{"RB"},
"imperturbability":	{"NN"},
"imperturbable":	{"JJ"},
"imperturbableness":	{"NN"},
"imperviable":	{"JJ"},
"impervious":	{"JJ"},
"imperviousness":	{"NN"},
"impetiginous":	{"JJ"},
"impetigo":	{"NN"},
"impetuosity":	{"NN"},
"impetuous":	{"JJ"},
"impetuously":	{"RB"},
"impetuousness":	{"NN"},
"impetus":	{"NN"},
"impieties":	{"NNS"},
"impiety":	{"NN"},
"imping":	{"VBG"},
"impinge":	{"VB","VBP"},
"impinged":	{"VBD","VBN"},
"impingement":	{"NN"},
"impinges":	{"VBZ"},
"impinging":	{"VBG"},
"impious":	{"JJ"},
"impiously":	{"RB"},
"impiousness":	{"NN"},
"impish":	{"JJ"},
"impishly":	{"RB"},
"impishness":	{"NN"},
"implacable":	{"JJ"},
"implant":	{"VB","VBP","NN"},
"implantable":	{"JJ"},
"implantation":	{"NN"},
"implanted":	{"VBD","VBN"},
"implanting":	{"VBG"},
"implants":	{"NNS","VBZ"},
"implausibility":	{"NN"},
"implausible":	{"JJ"},
"implausibleness":	{"NN"},
"implausibly":	{"RB"},
"implement":	{"VB","VBP","NN"},
"implemental":	{"JJ"},
"implementation":	{"NN"},
"implemented":	{"VBD","VBN"},
"implementer":	{"NN"},
"implementing":	{"VBG"},
"implements":	{"NNS","VBZ"},
"implicate":	{"VB","VBP"},
"implicated":	{"VBD","VBN"},
"implicates":	{"VBZ"},
"implicating":	{"VBG"},
"implication":	{"NN"},
"implicational":	{"JJ"},
"implications":	{"NNS"},
"implicative":	{"JJ"},
"implicit":	{"JJ"},
"implicitly":	{"RB"},
"implicitness":	{"NN"},
"implied":	{"VBD","VBN","JJ"},
"implies":	{"VBZ"},
"implike":	{"JJ"},
"implode":	{"VB","VBP"},
"imploded":	{"VBD","VBN"},
"implodes":	{"VBZ"},
"imploding":	{"VBG"},
"implore":	{"VB","VBP"},
"implored":	{"VBD","VBN"},
"implores":	{"VBZ"},
"imploring":	{"JJ","VBG"},
"imploringly":	{"RB"},
"implosion":	{"NN"},
"implosions":	{"NNS"},
"impluvia":	{"NNS"},
"impluvium":	{"NN"},
"impluviums":	{"NNS"},
"imply":	{"VB","VBP"},
"implying":	{"VBG"},
"impolite":	{"JJ"},
"impolitely":	{"RB"},
"impoliteness":	{"NN"},
"impolitic":	{"JJ"},
"imponderable":	{"JJ","NN"},
"imponderables":	{"NNS"},
"import":	{"NN","VB","VBP"},
"import-export":	{"NN"},
"import-incentive":	{"JJ"},
"import-restricting":	{"JJ"},
"import-screening":	{"NN"},
"importance":	{"NN"},
"important":	{"JJ"},
"important-looking":	{"JJ"},
"importantly":	{"RB"},
"importation":	{"NN"},
"imported":	{"VBN","VBD","JJ"},
"imported-food":	{"NN"},
"importee":	{"NN"},
"importer":	{"NN"},
"importers":	{"NNS"},
"importing":	{"VBG"},
"importive":	{"JJ"},
"imports":	{"NNS","VBZ"},
"importunate":	{"JJ"},
"importunately":	{"RB"},
"importune":	{"VB","VBP"},
"importuned":	{"VBD","VBN"},
"importunes":	{"VBZ"},
"importuning":	{"VBG"},
"importunities":	{"NNS"},
"importunity":	{"NN"},
"impose":	{"VB","VBP"},
"imposed":	{"VBN","VBD"},
"imposes":	{"VBZ"},
"imposing":	{"VBG","JJ"},
"imposingly":	{"JJ"},
"imposition":	{"NN"},
"impossibility":	{"NN"},
"impossible":	{"JJ","NN"},
"impossibleness":	{"NN"},
"impossibly":	{"RB"},
"impost":	{"NN"},
"imposter":	{"NN"},
"impostor":	{"NN"},
"impostors":	{"NNS"},
"imposture":	{"NN"},
"impostures":	{"NNS"},
"impotence":	{"NN"},
"impotency":	{"NN"},
"impotent":	{"JJ"},
"impotently":	{"RB"},
"impound":	{"VB","VBP"},
"impounded":	{"VBD","VBN"},
"impounding":	{"NN","VBG"},
"impoundment":	{"NN"},
"impoundments":	{"NNS"},
"impounds":	{"VBZ"},
"impoverish":	{"VB","VBP"},
"impoverished":	{"JJ","VBN","VBD"},
"impoverishes":	{"VBZ"},
"impoverishing":	{"VBG"},
"impoverishment":	{"NN"},
"impracticability":	{"NN"},
"impracticable":	{"JJ"},
"impracticableness":	{"NN"},
"impracticably":	{"RB"},
"impractical":	{"JJ"},
"impracticality":	{"NN"},
"imprecate":	{"VB","VBP"},
"imprecated":	{"VBD","VBN"},
"imprecates":	{"VBZ"},
"imprecating":	{"VBG"},
"imprecation":	{"NN"},
"imprecations":	{"NNS"},
"imprecise":	{"JJ"},
"imprecisely":	{"RB"},
"impreciseness":	{"NN"},
"imprecision":	{"NN"},
"impregnability":	{"NN"},
"impregnable":	{"JJ"},
"impregnably":	{"RB"},
"impregnate":	{"VB","VBP"},
"impregnated":	{"VBD","VBN","JJ"},
"impregnates":	{"VBZ"},
"impregnating":	{"VBG"},
"impregnation":	{"NN"},
"impresario":	{"NN"},
"impress":	{"VB","NN","VBP"},
"impressed":	{"VBN","VBD","JJ"},
"impresser":	{"NN"},
"impresses":	{"VBZ","NNS"},
"impressible":	{"JJ"},
"impressing":	{"VBG"},
"impression":	{"NN"},
"impressionable":	{"JJ"},
"impressionism":	{"NN"},
"impressionist":	{"NN","JJ"},
"impressionistic":	{"JJ"},
"impressionistically":	{"RB"},
"impressionists":	{"NNS"},
"impressions":	{"NNS"},
"impressive":	{"JJ"},
"impressively":	{"RB"},
"impressiveness":	{"NN"},
"impressment":	{"NN"},
"imprimatur":	{"NN"},
"imprimaturs":	{"NNS"},
"imprint":	{"NN","VB","VBP"},
"imprinted":	{"VBD","VBN"},
"imprinting":	{"NN","VBG"},
"imprints":	{"VBZ","NNS"},
"imprison":	{"VB","VBP"},
"imprisoned":	{"VBN","VBD"},
"imprisoning":	{"VBG"},
"imprisonment":	{"NN"},
"imprisons":	{"VBZ"},
"improbability":	{"NN"},
"improbable":	{"JJ"},
"improbableness":	{"NN"},
"improbably":	{"RB"},
"impromptu":	{"JJ","RB","NN"},
"improper":	{"JJ"},
"improperly":	{"RB"},
"improperness":	{"NN"},
"improprieties":	{"NNS"},
"impropriety":	{"NN"},
"improvable":	{"JJ"},
"improve":	{"VB","VBP"},
"improved":	{"VBN","VBD","JJ"},
"improvement":	{"NN"},
"improvements":	{"NNS"},
"improver":	{"NN"},
"improves":	{"VBZ"},
"improvidence":	{"NN"},
"improvident":	{"JJ"},
"improvidently":	{"RB"},
"improving":	{"VBG"},
"improvisation":	{"NN"},
"improvisational":	{"JJ"},
"improvisations":	{"NNS"},
"improvisatory":	{"JJ"},
"improvise":	{"VB","VBP"},
"improvised":	{"VBD","VBN"},
"improviser":	{"NN"},
"improvisers":	{"NNS"},
"improvises":	{"VBZ"},
"improvising":	{"VBG"},
"imprudence":	{"NN"},
"imprudent":	{"JJ"},
"imprudently":	{"RB"},
"imps":	{"NNS","VBZ"},
"impudence":	{"NN"},
"impudent":	{"JJ"},
"impudently":	{"RB"},
"impugn":	{"VB","VBP"},
"impugnable":	{"JJ"},
"impugned":	{"VBD","VBN"},
"impugning":	{"VBG"},
"impugns":	{"VBZ"},
"impuissance":	{"NN"},
"impuissant":	{"JJ"},
"impulse":	{"NN"},
"impulse-bought":	{"VBD","VBN"},
"impulse-buy":	{"VB","VBP"},
"impulse-buying":	{"VBG"},
"impulse-buys":	{"VBZ"},
"impulse-related":	{"JJ"},
"impulses":	{"NNS"},
"impulsion":	{"NN"},
"impulsive":	{"JJ"},
"impulsively":	{"RB"},
"impulsiveness":	{"NN"},
"impunity":	{"NN"},
"impure":	{"JJ"},
"impureness":	{"NN"},
"impurities":	{"NNS"},
"impurity":	{"NN"},
"impurity-doped":	{"JJ"},
"imput":	{"NN"},
"imputable":	{"JJ"},
"imputation":	{"NN"},
"impute":	{"VB","VBP"},
"imputed":	{"VBD","VBN"},
"imputes":	{"VBZ"},
"imputing":	{"VBG"},
"imputrescible":	{"JJ"},
"imu":	{"NN"},
"imuran":	{"NN"},
"in":	{"IN","RB","JJ","NN","RP"},
"in-accord-with-nature":	{"JJ"},
"in-and-outer":	{"NN"},
"in-basket":	{"NN"},
"in-between":	{"JJ"},
"in-bounds":	{"JJ"},
"in-chief":	{"JJ"},
"in-crowd":	{"NN"},
"in-depth":	{"JJ"},
"in-fighting":	{"NN"},
"in-flight":	{"JJ"},
"in-group":	{"NN"},
"in-groups":	{"NNS"},
"in-grown":	{"JJ"},
"in-home":	{"JJ"},
"in-house":	{"JJ","RB"},
"in-joke":	{"NN"},
"in-jokes":	{"NNS"},
"in-kind":	{"JJ"},
"in-law":	{"JJ","NN"},
"in-laws":	{"NNS"},
"in-line":	{"JJ","NN"},
"in-migrants":	{"NNS"},
"in-migration":	{"NN"},
"in-office":	{"JJ"},
"in-patient":	{"JJ","NN"},
"in-patients":	{"NNS"},
"in-person":	{"JJ"},
"in-plant":	{"JJ"},
"in-room":	{"JJ"},
"in-situ":	{"JJ","RB"},
"in-state":	{"JJ"},
"in-store":	{"JJ"},
"in-swinger":	{"NN"},
"in-swingers":	{"NNS"},
"in-tray":	{"NN"},
"in-trays":	{"NNS"},
"in-your-face":	{"JJ"},
"inNdant":	{"JJ"},
"ina":	{"NN"},
"inability":	{"NN"},
"inaccessibility":	{"NN"},
"inaccessible":	{"JJ"},
"inaccessibly":	{"RB"},
"inaccuracies":	{"NNS"},
"inaccuracy":	{"NN"},
"inaccurate":	{"JJ"},
"inaccurately":	{"RB"},
"inachis":	{"NN"},
"inaction":	{"NN"},
"inactivate":	{"VB","VBP"},
"inactivated":	{"VBD","VBN"},
"inactivates":	{"VBZ"},
"inactivating":	{"VBG"},
"inactivation":	{"NN"},
"inactive":	{"JJ"},
"inactiveness":	{"NN"},
"inactivity":	{"NN"},
"inadequacies":	{"NNS"},
"inadequacy":	{"NN"},
"inadequate":	{"JJ"},
"inadequately":	{"RB"},
"inadequateness":	{"NN"},
"inadmissibility":	{"NN"},
"inadmissible":	{"JJ"},
"inadvertence":	{"NN"},
"inadvertency":	{"NN"},
"inadvertent":	{"JJ"},
"inadvertently":	{"RB"},
"inadvisability":	{"NN"},
"inadvisable":	{"JJ"},
"inadvisably":	{"RB"},
"inaesthetic":	{"JJ"},
"inalienable":	{"JJ"},
"inalienably":	{"RB"},
"inalterable":	{"JJ"},
"inamorata":	{"NN"},
"inamorato":	{"NN"},
"inane":	{"JJ"},
"inanely":	{"RB"},
"inanimate":	{"JJ"},
"inanimateness":	{"NN"},
"inanition":	{"NN"},
"inanity":	{"NN"},
"inanna":	{"NN"},
"inapplicability":	{"NN"},
"inapplicable":	{"JJ"},
"inapposite":	{"JJ"},
"inappositeness":	{"NN"},
"inappreciable":	{"JJ"},
"inappropriacy":	{"NN"},
"inappropriate":	{"JJ"},
"inappropriately":	{"RB"},
"inappropriateness":	{"NN"},
"inapt":	{"JJ"},
"inaptitude":	{"NN"},
"inaptly":	{"RB"},
"inaptness":	{"NN"},
"inarguable":	{"JJ"},
"inarticulacy":	{"NN"},
"inarticulate":	{"JJ"},
"inarticulately":	{"RB"},
"inarticulateness":	{"NN"},
"inartistic":	{"JJ"},
"inasmuch":	{"RB"},
"inattention":	{"NN"},
"inattentive":	{"JJ"},
"inattentively":	{"RB"},
"inattentiveness":	{"NN"},
"inaudibility":	{"NN"},
"inaudible":	{"JJ"},
"inaudibleness":	{"NN"},
"inaudibly":	{"RB"},
"inaugural":	{"JJ","NN"},
"inaugurally":	{"RB"},
"inaugurate":	{"VB","VBP"},
"inaugurated":	{"VBD","VBN"},
"inaugurates":	{"VBZ"},
"inaugurating":	{"VBG"},
"inauguration":	{"NN"},
"inaugurations":	{"NNS"},
"inaugurator":	{"NN"},
"inaugurators":	{"NNS"},
"inauspicious":	{"JJ"},
"inauspiciously":	{"RB"},
"inauspiciousness":	{"NN"},
"inauthentic":	{"JJ"},
"inboard":	{"JJ","RB"},
"inboards":	{"NNS"},
"inborn":	{"JJ"},
"inbound":	{"JJ"},
"inbred":	{"JJ"},
"inbreeding":	{"NN"},
"inbuilt":	{"JJ"},
"inc":	{"NN"},
"inc.":	{"NNP","NN"},
"incalculable":	{"JJ"},
"incalescence":	{"NN"},
"incandesce":	{"VB","VBP"},
"incandesced":	{"VBD","VBN"},
"incandescence":	{"NN"},
"incandescent":	{"JJ"},
"incandesces":	{"VBZ"},
"incandescing":	{"VBG"},
"incant":	{"VB","VBP"},
"incantation":	{"NN"},
"incantations":	{"NNS"},
"incanted":	{"VBD","VBN"},
"incanting":	{"VBG"},
"incants":	{"VBZ"},
"incapability":	{"NN"},
"incapable":	{"JJ"},
"incapableness":	{"NN"},
"incapacitate":	{"VB","VBP"},
"incapacitated":	{"VBD","VBN","JJ"},
"incapacitates":	{"VBZ"},
"incapacitating":	{"VBG"},
"incapacity":	{"NN"},
"incarcerate":	{"VB","VBP"},
"incarcerated":	{"VBN","VBD"},
"incarcerates":	{"VBZ"},
"incarcerating":	{"VBG"},
"incarceration":	{"NN"},
"incarcerator":	{"NN"},
"incarcerators":	{"NNS"},
"incarnadine":	{"NN","JJ"},
"incarnate":	{"JJ","VBP","VB"},
"incarnated":	{"VBD","VBN"},
"incarnates":	{"VBZ"},
"incarnating":	{"VBG"},
"incarnation":	{"NN"},
"incarnations":	{"NNS"},
"incase":	{"VB","VBP"},
"incased":	{"VBD","VBN"},
"incasement":	{"NN"},
"incases":	{"VBZ"},
"incasing":	{"VBG"},
"incaution":	{"NN"},
"incautious":	{"JJ"},
"incautiously":	{"RB"},
"incautiousness":	{"NN"},
"incendiaries":	{"NNS"},
"incendiarism":	{"NN"},
"incendiary":	{"JJ","NN"},
"incense":	{"NN","VB","VBP"},
"incensed":	{"JJ","VBD","VBN"},
"incenses":	{"VBZ"},
"incensing":	{"VBG"},
"incentive":	{"NN"},
"incentive-backed":	{"JJ"},
"incentive-bonus":	{"NN"},
"incentive-buoyed":	{"JJ"},
"incentive-maximizing":	{"JJ"},
"incentive-pay":	{"JJ"},
"incentive-reduced":	{"JJ"},
"incentive-spurred":	{"JJ"},
"incentives":	{"NNS"},
"incept":	{"VB","VBP"},
"incepted":	{"VBD","VBN"},
"incepting":	{"VBG"},
"inception":	{"NN"},
"inceptor":	{"NN"},
"incepts":	{"VBZ"},
"incertain":	{"JJ"},
"incertitude":	{"NN"},
"incessancy":	{"NN"},
"incessant":	{"JJ"},
"incessantly":	{"RB"},
"incessantness":	{"NN"},
"incest":	{"NN"},
"incestuous":	{"JJ"},
"incestuously":	{"RB"},
"inch":	{"NN","VB","VBP"},
"inched":	{"VBD","VBN"},
"incheon":	{"NN"},
"inches":	{"NNS","VBZ"},
"inching":	{"VBG"},
"inchoate":	{"JJ"},
"inchoative":	{"JJ","NN"},
"inchon":	{"NN"},
"inchworm":	{"NN"},
"incidence":	{"NN"},
"incidences":	{"NNS"},
"incident":	{"NN","JJ"},
"incidental":	{"JJ","NN"},
"incidentally":	{"RB"},
"incidentals":	{"NNS"},
"incidents":	{"NNS"},
"incienso":	{"NN"},
"incinerate":	{"VB","VBP"},
"incinerated":	{"VBD","VBN"},
"incinerates":	{"VBZ"},
"incinerating":	{"VBG"},
"incineration":	{"NN"},
"incinerator":	{"NN"},
"incinerators":	{"NNS"},
"incipience":	{"NN"},
"incipiency":	{"NN"},
"incipient":	{"JJ"},
"incise":	{"VB","VBP"},
"incised":	{"JJ","VBD","VBN"},
"incises":	{"VBZ"},
"incising":	{"VBG"},
"incision":	{"NN"},
"incisions":	{"NNS"},
"incisive":	{"JJ"},
"incisively":	{"RB"},
"incisiveness":	{"NN"},
"incisor":	{"NN"},
"incisors":	{"NNS"},
"incisura":	{"NN"},
"incisure":	{"NN"},
"incitation":	{"NN"},
"incite":	{"VB","VBP"},
"incited":	{"VBD","VBN"},
"incitement":	{"NN"},
"incitements":	{"NNS"},
"inciter":	{"NN"},
"incites":	{"VBZ"},
"inciting":	{"VBG","JJ"},
"incitive":	{"JJ"},
"incivility":	{"NN"},
"incivilization":	{"NN"},
"inclemency":	{"NN"},
"inclement":	{"JJ"},
"inclementness":	{"NN"},
"inclination":	{"NN"},
"inclinations":	{"NNS"},
"incline":	{"VB","NN","VBP"},
"inclined":	{"VBN","JJ","VBD"},
"inclines":	{"VBZ","NNS"},
"inclining":	{"VBG"},
"inclinometer":	{"NN"},
"inclose":	{"VB","VBP"},
"inclosed":	{"VBD","VBN"},
"incloses":	{"VBZ"},
"inclosing":	{"VBG"},
"inclosure":	{"NN"},
"include":	{"VB","VBP"},
"included":	{"VBD","VBN","JJ"},
"includee":	{"VBP","VB"},
"includes":	{"VBZ"},
"including":	{"VBG","IN"},
"inclusion":	{"NN"},
"inclusions":	{"NNS"},
"inclusive":	{"JJ"},
"inclusively":	{"RB"},
"inclusiveness":	{"NN"},
"incognito":	{"RB","JJ","NN"},
"incognitos":	{"NNS"},
"incognizable":	{"JJ"},
"incognizance":	{"NN"},
"incognizant":	{"JJ"},
"incognoscible":	{"JJ"},
"incoherence":	{"NN"},
"incoherency":	{"NN"},
"incoherent":	{"JJ"},
"incoherently":	{"RB"},
"incombustible":	{"JJ"},
"income":	{"NN"},
"income-earner":	{"NN"},
"income-oriented":	{"JJ"},
"income-paying":	{"JJ"},
"income-producing":	{"JJ"},
"income-support":	{"NN"},
"income-tax":	{"NN"},
"incomes":	{"NNS"},
"incoming":	{"JJ"},
"incommensurable":	{"JJ"},
"incommensurate":	{"JJ"},
"incommode":	{"VB","VBP"},
"incommoded":	{"VBD","VBN"},
"incommodes":	{"VBZ"},
"incommoding":	{"VBG"},
"incommodious":	{"JJ"},
"incommodiously":	{"RB"},
"incommodiousness":	{"NN"},
"incommunicado":	{"JJ"},
"incommunicative":	{"JJ"},
"incommutability":	{"NN"},
"incommutable":	{"JJ"},
"incomparable":	{"JJ"},
"incomparably":	{"RB"},
"incompatibility":	{"NN"},
"incompatible":	{"JJ"},
"incompatibles":	{"NNS"},
"incompatibly":	{"RB"},
"incompetence":	{"NN"},
"incompetency":	{"NN"},
"incompetent":	{"JJ","NN"},
"incompetently":	{"RB"},
"incompetents":	{"NNS"},
"incomplete":	{"JJ","NN"},
"incompletely":	{"RB"},
"incompleteness":	{"NN"},
"incompletes":	{"NNS"},
"incomprehensibility":	{"NN"},
"incomprehensible":	{"JJ"},
"incomprehension":	{"NN"},
"incomprehensive":	{"JJ"},
"incompressibility":	{"NN"},
"incompressible":	{"JJ"},
"incomputable":	{"JJ"},
"inconceivability":	{"NN"},
"inconceivable":	{"JJ"},
"inconceivableness":	{"NN"},
"inconceivably":	{"RB"},
"inconclusive":	{"JJ"},
"inconclusively":	{"RB"},
"inconclusiveness":	{"NN"},
"inconel":	{"NN"},
"incongruent":	{"JJ"},
"incongruities":	{"NNS"},
"incongruity":	{"NN"},
"incongruous":	{"JJ"},
"incongruously":	{"RB"},
"incongruousness":	{"NN"},
"inconsequence":	{"NN"},
"inconsequent":	{"JJ"},
"inconsequential":	{"JJ"},
"inconsequentially":	{"RB"},
"inconsequently":	{"RB"},
"inconsiderable":	{"JJ"},
"inconsiderate":	{"JJ"},
"inconsiderately":	{"RB"},
"inconsiderateness":	{"NN"},
"inconsideration":	{"NN"},
"inconsistencies":	{"NNS"},
"inconsistency":	{"NN"},
"inconsistent":	{"JJ"},
"inconsistently":	{"RB"},
"inconsolable":	{"JJ"},
"inconspicuous":	{"JJ"},
"inconspicuously":	{"RB"},
"inconspicuousness":	{"NN"},
"inconstancy":	{"NN"},
"inconstant":	{"JJ"},
"incontestable":	{"JJ"},
"incontestible":	{"JJ"},
"incontinence":	{"NN"},
"incontinency":	{"NN"},
"incontinent":	{"JJ"},
"incontrovertibility":	{"NN"},
"incontrovertible":	{"JJ"},
"incontrovertibleness":	{"NN"},
"incontrovertibly":	{"RB"},
"inconvenience":	{"NN","VBP","VB"},
"inconvenienced":	{"VBD","VBN"},
"inconveniences":	{"VBZ","NNS"},
"inconveniencing":	{"VBG"},
"inconvenient":	{"JJ"},
"inconveniently":	{"RB"},
"inconvertibility":	{"NN"},
"inconvertible":	{"JJ"},
"incoordination":	{"NN"},
"incorporate":	{"VB","VBP","JJ"},
"incorporated":	{"JJ","VBD","VBN"},
"incorporates":	{"VBZ"},
"incorporating":	{"VBG"},
"incorporation":	{"NN"},
"incorporative":	{"JJ"},
"incorporeal":	{"JJ"},
"incorporeality":	{"NN"},
"incorrect":	{"JJ"},
"incorrectly":	{"RB"},
"incorrectness":	{"NN"},
"incorrigibility":	{"NN"},
"incorrigible":	{"JJ"},
"incorrigibly":	{"RB"},
"incorrupt":	{"JJ"},
"incorruptibility":	{"NN"},
"incorruptible":	{"JJ"},
"incorruption":	{"NN"},
"incorruptness":	{"NN"},
"increase":	{"NN","VB","VBP"},
"increase-results":	{"NNS"},
"increased":	{"VBD","VBN","JJ"},
"increases":	{"NNS","VBZ"},
"increasing":	{"VBG","JJ"},
"increasing-rate":	{"JJ"},
"increasingly":	{"RB"},
"incredibility":	{"NN"},
"incredible":	{"JJ"},
"incredibleness":	{"NN"},
"incredibly":	{"RB"},
"incredulity":	{"NN"},
"incredulous":	{"JJ"},
"incredulously":	{"RB"},
"increment":	{"NN"},
"incremental":	{"JJ"},
"incrementally":	{"RB"},
"increments":	{"NNS"},
"incriminate":	{"VB","VBP"},
"incriminated":	{"VBD","VBN"},
"incriminates":	{"VBZ"},
"incriminating":	{"VBG","JJ"},
"incriminatingly":	{"RB"},
"incrimination":	{"NN"},
"incriminatory":	{"JJ"},
"incrust":	{"VB","VBP"},
"incrustation":	{"NN"},
"incrusted":	{"VBD","VBN"},
"incrusting":	{"VBG"},
"incrusts":	{"VBZ"},
"incubate":	{"VB","VBP"},
"incubated":	{"VBD","VBN"},
"incubates":	{"VBZ"},
"incubating":	{"VBG"},
"incubation":	{"NN"},
"incubator":	{"NN"},
"incubators":	{"NNS"},
"incubi":	{"NNS"},
"incubus":	{"NN"},
"incubuses":	{"NNS"},
"inculcate":	{"VB","VBP"},
"inculcated":	{"VBD","VBN"},
"inculcates":	{"VBZ"},
"inculcating":	{"VBG"},
"inculcation":	{"NN"},
"inculpability":	{"NN"},
"inculpable":	{"JJ"},
"inculpableness":	{"NN"},
"inculpate":	{"VB","VBP"},
"inculpated":	{"VBD","VBN"},
"inculpates":	{"VBZ"},
"inculpating":	{"VBG"},
"inculpation":	{"NN"},
"inculpative":	{"JJ"},
"inculpatory":	{"JJ"},
"incumbencies":	{"NNS"},
"incumbency":	{"NN"},
"incumbent":	{"JJ","NN"},
"incumbent-protection":	{"JJ"},
"incumbents":	{"NNS"},
"incumbrance":	{"NN"},
"incur":	{"VB","VBP"},
"incurability":	{"NN"},
"incurable":	{"JJ","NN"},
"incurableness":	{"NN"},
"incurables":	{"NNS"},
"incurably":	{"RB"},
"incurious":	{"JJ"},
"incurred":	{"VBD","VBN"},
"incurrence":	{"NN"},
"incurring":	{"VBG"},
"incurs":	{"VBZ"},
"incursion":	{"NN"},
"incursions":	{"NNS"},
"incursive":	{"JJ"},
"incurvate":	{"JJ","VB","VBP"},
"incurvated":	{"VBD","VBN"},
"incurvates":	{"VBZ"},
"incurvating":	{"VBG"},
"incurvation":	{"NN"},
"incurvature":	{"NN"},
"incurved":	{"JJ"},
"incus":	{"NN"},
"indaba":	{"NN"},
"indapamide":	{"NN"},
"indebted":	{"JJ"},
"indebtedness":	{"NN"},
"indecency":	{"NN"},
"indecent":	{"JJ"},
"indecently":	{"RB"},
"indecipherable":	{"JJ"},
"indecision":	{"NN"},
"indecisive":	{"JJ"},
"indecisively":	{"RB"},
"indecisiveness":	{"NN"},
"indecorous":	{"JJ"},
"indecorously":	{"RB"},
"indecorousness":	{"NN"},
"indecorum":	{"NN"},
"indeed":	{"RB"},
"indefatigability":	{"NN"},
"indefatigable":	{"JJ"},
"indefatigableness":	{"NN"},
"indefatigably":	{"RB"},
"indefeasible":	{"JJ"},
"indefensible":	{"JJ","NN"},
"indefensibly":	{"RB"},
"indefinable":	{"JJ"},
"indefinably":	{"RB"},
"indefinite":	{"JJ"},
"indefinitely":	{"RB"},
"indefiniteness":	{"NN"},
"indefinity":	{"NN"},
"indehiscent":	{"JJ"},
"indelible":	{"JJ"},
"indelibly":	{"RB"},
"indelicacy":	{"NN"},
"indelicate":	{"JJ"},
"indemnification":	{"NN"},
"indemnified":	{"VBD","VBN"},
"indemnifies":	{"VBZ"},
"indemnify":	{"VB","VBP"},
"indemnifying":	{"VBG"},
"indemnity":	{"NN"},
"indene":	{"NN"},
"indent":	{"VB","VBP","NN"},
"indentation":	{"NN"},
"indentations":	{"NNS"},
"indented":	{"VBD","VBN","JJ"},
"indentical":	{"JJ"},
"indenting":	{"VBG"},
"indention":	{"NN"},
"indents":	{"VBZ","NNS"},
"indenture":	{"NN","VB","VBP"},
"indentured":	{"VBD","VBN","JJ"},
"indentures":	{"VBZ","NNS"},
"indenturing":	{"VBG"},
"independant":	{"JJ"},
"independence":	{"NN"},
"independency":	{"NN"},
"independent":	{"JJ","NN"},
"independent-contractor":	{"JJ"},
"independent-minded":	{"JJ"},
"independently":	{"RB"},
"independents":	{"NNS"},
"inderal":	{"NN"},
"indescribable":	{"JJ"},
"indescribably":	{"RB"},
"indestructibility":	{"NN"},
"indestructible":	{"JJ"},
"indeterminable":	{"JJ"},
"indeterminably":	{"RB"},
"indeterminacy":	{"NN"},
"indeterminate":	{"JJ"},
"indeterminateness":	{"NN"},
"indetermination":	{"NN"},
"index":	{"NN","VBP","VB"},
"index-arbitrage":	{"NN","JJ"},
"index-arbitrage-related":	{"JJ"},
"index-fund":	{"JJ","NN"},
"index-futures":	{"JJ","NNS"},
"index-linked":	{"JJ"},
"index-options":	{"NNS"},
"index-related":	{"JJ"},
"index-trading":	{"NN"},
"indexation":	{"NN"},
"indexed":	{"VBN","JJ","VBD"},
"indexer":	{"NN"},
"indexers":	{"NNS"},
"indexes":	{"NNS","VBZ"},
"indexical":	{"JJ"},
"indexing":	{"VBG"},
"indexless":	{"JJ"},
"indi":	{"NN","IN"},
"india-born":	{"JJ"},
"indiaman":	{"NN"},
"indianan":	{"NN"},
"indianapolis-based":	{"JJ"},
"indicant":	{"NN"},
"indicate":	{"VB","VBP"},
"indicated":	{"VBD","VBN"},
"indicates":	{"VBZ"},
"indicating":	{"VBG"},
"indication":	{"NN"},
"indications":	{"NNS"},
"indicative":	{"JJ","NN"},
"indicator":	{"NN"},
"indicatoridae":	{"NN"},
"indicators":	{"NNS"},
"indicatory":	{"JJ"},
"indices":	{"NNS"},
"indict":	{"VB","VBP"},
"indictability":	{"NN"},
"indictable":	{"JJ"},
"indicted":	{"VBN","VBD"},
"indicting":	{"VBG"},
"indiction":	{"NN"},
"indictment":	{"NN"},
"indictments":	{"NNS"},
"indicts":	{"VBZ"},
"indie":	{"JJ","NN"},
"indies":	{"NN"},
"indifference":	{"NN"},
"indifferent":	{"JJ"},
"indifferently":	{"RB"},
"indigation":	{"NN"},
"indigen":	{"NN"},
"indigence":	{"NN"},
"indigene":	{"NN"},
"indigenous":	{"JJ"},
"indigenously":	{"RB"},
"indigenousness":	{"NN"},
"indigent":	{"JJ"},
"indigestibility":	{"NN"},
"indigestible":	{"JJ"},
"indigestibleness":	{"NN"},
"indigestion":	{"NN"},
"indigirka":	{"NN"},
"indignant":	{"JJ"},
"indignantly":	{"RB"},
"indignation":	{"NN"},
"indignities":	{"NNS"},
"indignity":	{"NN"},
"indigo":	{"NN","JJ"},
"indigofera":	{"NN"},
"indigotin":	{"NN"},
"indinavir":	{"NN"},
"indirect":	{"JJ"},
"indirection":	{"NN"},
"indirectly":	{"RB"},
"indirectness":	{"NN"},
"indiscernible":	{"JJ"},
"indiscipline":	{"NN"},
"indiscreet":	{"JJ"},
"indiscreetly":	{"RB"},
"indiscreetness":	{"NN"},
"indiscrete":	{"JJ"},
"indiscretion":	{"NN"},
"indiscretions":	{"NNS"},
"indiscriminantly":	{"RB"},
"indiscriminate":	{"JJ"},
"indiscriminately":	{"RB"},
"indiscriminating":	{"JJ"},
"indispensability":	{"NN"},
"indispensable":	{"JJ"},
"indispensableness":	{"NN"},
"indispensible":	{"JJ"},
"indispose":	{"VB","VBP"},
"indisposed":	{"JJ","VBD","VBN"},
"indisposes":	{"VBZ"},
"indisposing":	{"VBG"},
"indisposition":	{"NN"},
"indisputability":	{"NN"},
"indisputable":	{"JJ"},
"indisputably":	{"RB"},
"indissoluble":	{"JJ"},
"indistinct":	{"JJ"},
"indistinctly":	{"RB"},
"indistinctness":	{"NN"},
"indistinguishability":	{"NN"},
"indistinguishable":	{"JJ"},
"indite":	{"VB","VBP"},
"indium":	{"NN"},
"individual":	{"JJ","NN"},
"individual-contributor":	{"NN"},
"individual-investor":	{"NN","JJ"},
"individual-retirement-account":	{"NN"},
"individual-type":	{"JJ"},
"individualisation":	{"NN"},
"individualise":	{"VB","VBP"},
"individualised":	{"JJ","VBD","VBN"},
"individualises":	{"VBZ"},
"individualising":	{"VBG"},
"individualism":	{"NN"},
"individualist":	{"NN"},
"individualistic":	{"JJ"},
"individualistically":	{"RB"},
"individualists":	{"NNS"},
"individuality":	{"NN"},
"individualization":	{"NN"},
"individualize":	{"VB","VBP"},
"individualized":	{"VBD","VBN","JJ"},
"individualizes":	{"VBZ"},
"individualizing":	{"VBG"},
"individually":	{"RB"},
"individuals":	{"NNS"},
"individuate":	{"VB","VBP"},
"individuated":	{"VBD","VBN"},
"individuates":	{"VBZ"},
"individuating":	{"VBG"},
"individuation":	{"NN"},
"indivisibility":	{"NN"},
"indivisible":	{"JJ"},
"indo-aryan":	{"JJ","NN"},
"indo-germanic":	{"JJ"},
"indo-hittite":	{"NN"},
"indo-iranian":	{"NN"},
"indocile":	{"JJ"},
"indocin":	{"NN"},
"indoctrinate":	{"VB","VBP"},
"indoctrinated":	{"VBD","VBN"},
"indoctrinates":	{"VBZ"},
"indoctrinating":	{"VBG"},
"indoctrination":	{"NN"},
"indolence":	{"NN"},
"indolent":	{"JJ"},
"indolently":	{"RB"},
"indomethacin":	{"NN"},
"indomitability":	{"NN"},
"indomitable":	{"JJ"},
"indoor":	{"JJ"},
"indoors":	{"RB"},
"indoorsies":	{"NNS"},
"indoorsman":	{"NN"},
"indoorsmen":	{"NNS"},
"indoorsy":	{"JJ"},
"indorse":	{"VB","VBP"},
"indorsed":	{"VBD","VBN"},
"indorsement":	{"NN"},
"indorser":	{"NN"},
"indorses":	{"VBZ"},
"indorsing":	{"VBG"},
"indpendent":	{"JJ"},
"indra":	{"NN"},
"indrawn":	{"JJ"},
"indri":	{"NN"},
"indriidae":	{"NN"},
"indris":	{"NN"},
"indubitability":	{"NN"},
"indubitable":	{"JJ"},
"indubitably":	{"RB"},
"induce":	{"VB","VBP"},
"induced":	{"VBD","VBN"},
"inducement":	{"NN"},
"inducements":	{"NNS"},
"inducer":	{"NN"},
"induces":	{"VBZ","NNS"},
"inducible":	{"JJ"},
"inducing":	{"VBG"},
"inducive":	{"JJ"},
"induct":	{"VB","VBP"},
"inductance":	{"NN"},
"inducted":	{"VBD","VBN"},
"inductee":	{"NN"},
"inductees":	{"NNS"},
"inducting":	{"VBG"},
"induction":	{"NN"},
"inductions":	{"NNS"},
"inductive":	{"JJ"},
"inductor":	{"NN"},
"inducts":	{"VBZ"},
"indue":	{"VB"},
"indulge":	{"VB","VBP"},
"indulged":	{"VBD","VBN"},
"indulgence":	{"NN","VB","VBP"},
"indulgenced":	{"VBD","VBN"},
"indulgences":	{"NNS","VBZ"},
"indulgencing":	{"VBG"},
"indulgent":	{"JJ"},
"indulgently":	{"RB"},
"indulgers":	{"NNS"},
"indulges":	{"VBZ"},
"indulging":	{"VBG"},
"indument":	{"NN"},
"indumentum":	{"NN"},
"indurate":	{"JJ","VB","VBP"},
"indurated":	{"VBD","VBN"},
"indurates":	{"VBZ"},
"indurating":	{"VBG"},
"induration":	{"NN"},
"indurative":	{"JJ"},
"indus":	{"NN"},
"indusial":	{"JJ"},
"indusium":	{"NN"},
"industralization":	{"NN"},
"industrial":	{"JJ"},
"industrial-automation":	{"NN"},
"industrial-equipment":	{"NN"},
"industrial-gas":	{"JJ"},
"industrial-gases":	{"JJ"},
"industrial-product":	{"NN"},
"industrial-production":	{"JJ"},
"industrial-property":	{"NN"},
"industrial-services":	{"JJ"},
"industrial-strength":	{"JJ"},
"industrial-vehicle":	{"NN"},
"industrialisation":	{"NN"},
"industrialise":	{"VB","VBP"},
"industrialised":	{"JJ","VBD","VBN"},
"industrialises":	{"VBZ"},
"industrialising":	{"VBG"},
"industrialism":	{"NN"},
"industrialist":	{"NN"},
"industrialists":	{"NNS"},
"industrialization":	{"NN"},
"industrialize":	{"VB","VBP"},
"industrialized":	{"JJ","VBN","VBD"},
"industrializes":	{"VBZ"},
"industrializing":	{"VBG"},
"industrially":	{"RB"},
"industrials":	{"NNS"},
"industries":	{"NNS"},
"industrious":	{"JJ"},
"industriously":	{"RB"},
"industriousness":	{"NN"},
"industry":	{"NN"},
"industry-financed":	{"JJ"},
"industry-funded":	{"JJ"},
"industry-government":	{"JJ","NN"},
"industry-specific":	{"JJ"},
"industry-standard":	{"JJ"},
"industry-supported":	{"JJ"},
"industry-wide":	{"JJ"},
"industryas":	{"NNS"},
"industrywide":	{"JJ","RB"},
"industy":	{"NN"},
"indwell":	{"VB","VBP"},
"indweller":	{"NN"},
"indwelling":	{"VBG"},
"indwells":	{"VBZ"},
"indwelt":	{"VBD","VBN"},
"indyref":	{"NN"},
"inebriant":	{"NN","JJ"},
"inebriate":	{"NN","JJ","VB","VBP"},
"inebriated":	{"JJ","VBD","VBN"},
"inebriates":	{"VBZ","NNS"},
"inebriating":	{"VBG"},
"inebriation":	{"NN"},
"inebriety":	{"NN"},
"inedible":	{"JJ"},
"ineffable":	{"JJ"},
"ineffably":	{"RB"},
"ineffective":	{"JJ"},
"ineffectively":	{"RB"},
"ineffectiveness":	{"NN"},
"ineffectual":	{"JJ"},
"ineffectuality":	{"NN"},
"ineffectually":	{"RB"},
"ineffectualness":	{"NN"},
"inefficacious":	{"JJ"},
"inefficaciously":	{"RB"},
"inefficaciousness":	{"NN"},
"inefficacy":	{"NN"},
"inefficiencies":	{"NNS"},
"inefficiency":	{"NN"},
"inefficient":	{"JJ"},
"inefficiently":	{"RB"},
"inelaborate":	{"JJ"},
"inelastic":	{"JJ"},
"inelasticity":	{"NN"},
"inelegance":	{"NN"},
"inelegant":	{"JJ"},
"inelegantly":	{"RB"},
"ineligibility":	{"NN"},
"ineligible":	{"JJ"},
"ineloquently":	{"RB"},
"ineluctability":	{"NN"},
"ineluctable":	{"JJ"},
"ineluctably":	{"RB"},
"inept":	{"JJ"},
"ineptitude":	{"NN"},
"ineptly":	{"RB"},
"ineptness":	{"NN"},
"inequalities":	{"NNS"},
"inequality":	{"NN"},
"inequitable":	{"JJ"},
"inequitably":	{"RB"},
"inequities":	{"NNS"},
"inequity":	{"NN"},
"ineradicable":	{"JJ"},
"inerrable":	{"JJ"},
"inerrancy":	{"NN"},
"inerrant":	{"JJ"},
"inert":	{"JJ"},
"inertia":	{"NN"},
"inertial":	{"JJ"},
"inertness":	{"NN"},
"inescapable":	{"JJ"},
"inescapably":	{"RB"},
"inessential":	{"JJ"},
"inessentiality":	{"NN"},
"inessentials":	{"NNS"},
"inestimable":	{"JJ"},
"inevasible":	{"JJ"},
"inevitabilities":	{"NNS"},
"inevitability":	{"NN"},
"inevitable":	{"JJ"},
"inevitableness":	{"NN"},
"inevitably":	{"RB"},
"inexact":	{"JJ"},
"inexactitude":	{"NN"},
"inexactly":	{"RB"},
"inexactness":	{"NN"},
"inexcusable":	{"JJ"},
"inexcusably":	{"RB"},
"inexertion":	{"NN"},
"inexhaustible":	{"JJ"},
"inexhaustibly":	{"RB"},
"inexorability":	{"NN"},
"inexorable":	{"JJ"},
"inexorableness":	{"NN"},
"inexorably":	{"RB"},
"inexpedience":	{"NN"},
"inexpediency":	{"NN"},
"inexpedient":	{"JJ"},
"inexpediently":	{"RB"},
"inexpensive":	{"JJ"},
"inexpensively":	{"RB"},
"inexpensiveness":	{"NN"},
"inexperience":	{"NN"},
"inexperienced":	{"JJ"},
"inexperient":	{"JJ"},
"inexpert":	{"JJ"},
"inexpertly":	{"RB"},
"inexpiable":	{"JJ"},
"inexplicable":	{"JJ"},
"inexplicably":	{"RB"},
"inexplicit":	{"JJ"},
"inexplicitness":	{"NN"},
"inexpressible":	{"JJ"},
"inexpressibly":	{"RB"},
"inexpressive":	{"JJ"},
"inexpressively":	{"RB"},
"inexpugnable":	{"JJ"},
"inexpungeable":	{"JJ"},
"inexpungible":	{"JJ"},
"inextensible":	{"JJ"},
"inexterminable":	{"JJ"},
"inextinguishable":	{"JJ"},
"inextirpable":	{"JJ"},
"inextricable":	{"JJ"},
"inextricably":	{"RB"},
"infallibility":	{"NN"},
"infallible":	{"JJ"},
"infamous":	{"JJ"},
"infamy":	{"NN"},
"infancy":	{"NN"},
"infant":	{"NN","JJ"},
"infant's-breath":	{"NN"},
"infant-formula":	{"NN"},
"infant-mortality":	{"JJ","NN"},
"infanticide":	{"NN"},
"infantile":	{"JJ"},
"infantilisation":	{"NN"},
"infantilise":	{"VB","VBP"},
"infantilised":	{"VBD","VBN"},
"infantilises":	{"VBZ"},
"infantilising":	{"VBG"},
"infantilism":	{"NN"},
"infantilization":	{"NN"},
"infantilize":	{"VB","VBP"},
"infantilized":	{"VBD","VBN"},
"infantilizes":	{"VBZ"},
"infantilizing":	{"VBG"},
"infantry":	{"NN"},
"infantryman":	{"NN"},
"infantrymen":	{"NNS"},
"infants":	{"NNS"},
"infarct":	{"NN"},
"infarction":	{"NN"},
"infatuate":	{"VB","VBP","JJ","NN"},
"infatuated":	{"JJ","VBD","VBN"},
"infatuates":	{"VBZ","NNS"},
"infatuating":	{"VBG"},
"infatuation":	{"NN"},
"infatuations":	{"NNS"},
"infeasibility":	{"NN"},
"infeasible":	{"JJ"},
"infect":	{"VB","VBP"},
"infected":	{"VBN","JJ","VBD"},
"infecting":	{"VBG"},
"infection":	{"NN"},
"infection-fighting":	{"JJ"},
"infection-screening":	{"JJ"},
"infections":	{"NNS"},
"infectious":	{"JJ"},
"infectiously":	{"RB"},
"infective":	{"JJ"},
"infects":	{"VBZ"},
"infelicitous":	{"JJ"},
"infelicitously":	{"RB"},
"infelicity":	{"NN"},
"infer":	{"VB","VBP"},
"inferable":	{"JJ"},
"inference":	{"NN"},
"inferences":	{"NNS"},
"inferential":	{"JJ"},
"inferior":	{"JJ","NN"},
"inferiority":	{"NN"},
"inferiors":	{"NNS"},
"infernal":	{"JJ"},
"infernally":	{"RB"},
"inferno":	{"NN"},
"inferred":	{"VBD","VBN"},
"inferring":	{"VBG"},
"infers":	{"VBZ"},
"infertile":	{"JJ"},
"infertility":	{"NN"},
"infest":	{"VB","VBP"},
"infestation":	{"NN"},
"infestations":	{"NNS"},
"infested":	{"VBD","VBN","JJ"},
"infesting":	{"VBG"},
"infests":	{"VBZ"},
"infidel":	{"NN","JJ"},
"infidelities":	{"NNS"},
"infidelity":	{"NN"},
"infidels":	{"NNS"},
"infield":	{"NN"},
"infielder":	{"NN"},
"infielders":	{"NNS"},
"infighting":	{"NN"},
"infiltrate":	{"VB","VBP"},
"infiltrated":	{"VBD","VBN"},
"infiltrates":	{"VBZ"},
"infiltrating":	{"VBG"},
"infiltration":	{"NN"},
"infiltrator":	{"NN"},
"infiltrators":	{"NNS"},
"infinite":	{"JJ","NN"},
"infinitely":	{"RB"},
"infiniteness":	{"NN"},
"infinitesimal":	{"JJ","NN"},
"infinitesimally":	{"RB"},
"infinitival":	{"JJ"},
"infinitive":	{"NN"},
"infinitives":	{"NNS"},
"infinitude":	{"NN"},
"infinitum":	{"NN"},
"infinity":	{"NN"},
"infirm":	{"JJ"},
"infirmaries":	{"NNS"},
"infirmary":	{"NN"},
"infirmities":	{"NNS"},
"infirmity":	{"NN"},
"infix":	{"NN","VB","VBP"},
"infixed":	{"VBD","VBN"},
"infixes":	{"NNS","VBZ"},
"infixing":	{"VBG"},
"inflame":	{"VB","VBP"},
"inflamed":	{"JJ","VBD","VBN"},
"inflames":	{"VBZ"},
"inflaming":	{"VBG"},
"inflammability":	{"NN"},
"inflammable":	{"JJ"},
"inflammation":	{"NN"},
"inflammations":	{"NNS"},
"inflammatory":	{"JJ"},
"inflatable":	{"JJ","NN"},
"inflate":	{"VB","VBP"},
"inflated":	{"JJ","VBD","VBN"},
"inflater":	{"NN"},
"inflates":	{"VBZ"},
"inflating":	{"VBG"},
"inflation":	{"NN"},
"inflation-adjusted":	{"JJ"},
"inflation-created":	{"JJ"},
"inflation-fighting":	{"JJ","NN"},
"inflation-free":	{"JJ"},
"inflation-fuels-growth":	{"JJ"},
"inflation-growth":	{"NN"},
"inflation-hedge":	{"JJ"},
"inflation-induced":	{"JJ"},
"inflation-offsetting":	{"JJ"},
"inflation-wary":	{"JJ"},
"inflationary":	{"JJ"},
"inflator":	{"NN"},
"inflect":	{"VB","VBP"},
"inflected":	{"VBD","VBN","JJ"},
"inflecting":	{"VBG"},
"inflection":	{"NN"},
"inflectional":	{"JJ"},
"inflections":	{"NNS"},
"inflects":	{"VBZ"},
"inflexibility":	{"NN"},
"inflexible":	{"JJ"},
"inflexibleness":	{"NN"},
"inflexibly":	{"RB"},
"inflexion":	{"NN"},
"inflict":	{"VB","VBP"},
"inflicted":	{"VBD","VBN"},
"inflicting":	{"VBG"},
"infliction":	{"NN"},
"inflicts":	{"VBZ"},
"inflight":	{"JJ"},
"infliximab":	{"NN"},
"inflorescence":	{"NN"},
"inflow":	{"NN"},
"inflowing":	{"JJ"},
"inflows":	{"NNS"},
"influence":	{"NN","VB","VBP"},
"influence-peddling":	{"NN","JJ"},
"influenced":	{"VBN","VBD"},
"influences":	{"NNS","VBZ"},
"influencing":	{"VBG"},
"influent":	{"JJ","NN"},
"influential":	{"JJ"},
"influentially":	{"RB"},
"influenza":	{"NN"},
"influenza-pneumonia":	{"JJ"},
"influx":	{"NN"},
"influxes":	{"NNS"},
"info":	{"NN"},
"infographic":	{"NN"},
"infographics":	{"NNS"},
"infold":	{"VB","VBP"},
"infolded":	{"VBD","VBN"},
"infolding":	{"VBD","VBN"},
"infolds":	{"VBZ"},
"infomercial":	{"NN"},
"infomercials":	{"NNS"},
"inform":	{"VB","VBP"},
"informal":	{"JJ"},
"informalities":	{"NNS"},
"informality":	{"NN"},
"informalization":	{"NN"},
"informalize":	{"VB","VBP"},
"informalized":	{"VBD","VBN"},
"informalizes":	{"VBZ"},
"informalizing":	{"VBG"},
"informally":	{"RB"},
"informant":	{"NN"},
"informants":	{"NNS"},
"informatics":	{"NN"},
"information":	{"NN"},
"information-cell":	{"NN"},
"information-delivery":	{"NN"},
"information-display":	{"JJ","NN"},
"information-gathering":	{"JJ"},
"information-processing":	{"NN"},
"information-products":	{"NNS"},
"information-seeking":	{"NN"},
"information-service":	{"NN"},
"information-services":	{"JJ","NNS"},
"information-system":	{"JJ"},
"information-systems":	{"NNS","JJ"},
"information-technology":	{"JJ"},
"informational":	{"JJ"},
"informationalized":	{"JJ"},
"informative":	{"JJ"},
"informatively":	{"RB"},
"informatory":	{"JJ"},
"informed":	{"VBN","VBD","JJ"},
"informer":	{"NN"},
"informercial":	{"NN"},
"informers":	{"NNS"},
"informing":	{"VBG"},
"informs":	{"VBZ","NNS"},
"infotainment":	{"NN"},
"infra":	{"RB"},
"infract":	{"VB","VBP"},
"infracted":	{"VBD","VBN"},
"infracting":	{"VBG"},
"infraction":	{"NN"},
"infractions":	{"NNS"},
"infracts":	{"VBZ"},
"infrahuman":	{"JJ"},
"inframaxillary":	{"JJ"},
"infrangible":	{"JJ"},
"infrared":	{"JJ"},
"infrasonic":	{"JJ"},
"infrastructural":	{"JJ"},
"infrastructure":	{"NN"},
"infrastructures":	{"NNS"},
"infrequency":	{"NN"},
"infrequent":	{"JJ"},
"infrequently":	{"RB"},
"infrigidation":	{"NN"},
"infringe":	{"VB","VBP"},
"infringed":	{"VBD","VBN"},
"infringement":	{"NN"},
"infringements":	{"NNS"},
"infringes":	{"VBZ"},
"infringing":	{"VBG"},
"infructescence":	{"NN"},
"infundibulum":	{"NN"},
"infuriate":	{"VB","VBP"},
"infuriated":	{"JJ","VBD","VBN"},
"infuriates":	{"VBZ"},
"infuriating":	{"JJ","VBG"},
"infuriatingly":	{"RB"},
"infuriation":	{"NN"},
"infuscate":	{"JJ"},
"infuse":	{"VB","VBP"},
"infused":	{"VBD","VBN"},
"infuses":	{"VBZ"},
"infusing":	{"VBG"},
"infusion":	{"NN"},
"infusion-therapy":	{"JJ"},
"infusions":	{"NNS"},
"infusoria":	{"NN"},
"infusorian":	{"NN"},
"inga":	{"NN"},
"ingathering":	{"NN"},
"inge":	{"NN"},
"ingeminate":	{"VB","VBP"},
"ingeminated":	{"VBD","VBN"},
"ingeminates":	{"VBZ"},
"ingeminating":	{"VBG"},
"ingenious":	{"JJ"},
"ingeniously":	{"RB"},
"ingeniousness":	{"NN"},
"ingenue":	{"NN"},
"ingenues":	{"NNS"},
"ingenuity":	{"NN"},
"ingenuous":	{"JJ"},
"ingenuously":	{"RB"},
"ingenuousness":	{"NN"},
"inger":	{"NN"},
"ingerman":	{"NN"},
"ingest":	{"VB","VBP"},
"ingesta":	{"NN"},
"ingested":	{"VBD","VBN"},
"ingesting":	{"VBG"},
"ingestion":	{"NN"},
"ingests":	{"VBZ"},
"inglenook":	{"NN"},
"inglorious":	{"JJ"},
"ingloriously":	{"RB"},
"ingot":	{"NN"},
"ingots":	{"NNS"},
"ingraft":	{"VB","VBP"},
"ingrafted":	{"VBD","VBN"},
"ingrafting":	{"VBG"},
"ingrafts":	{"VBZ"},
"ingrain":	{"NN","JJ","VB","VBP"},
"ingrained":	{"JJ","VBD","VBN"},
"ingraining":	{"VBG"},
"ingrains":	{"NNS","VBZ"},
"ingram":	{"NN","JJ"},
"ingrate":	{"NN","JJ"},
"ingrates":	{"NNS"},
"ingratiate":	{"VB","VBP"},
"ingratiated":	{"VBD","VBN"},
"ingratiates":	{"VBZ"},
"ingratiating":	{"JJ","VBG"},
"ingratiatingly":	{"RB"},
"ingratiation":	{"NN"},
"ingratiatory":	{"JJ"},
"ingratitoode":	{"NN"},
"ingratitude":	{"NN"},
"ingredient":	{"NN"},
"ingredients":	{"NNS"},
"ingress":	{"NN"},
"ingrian":	{"NN"},
"ingrid":	{"NN"},
"ingroup":	{"NN"},
"ingrowing":	{"JJ"},
"ingrown":	{"JJ"},
"ingrowth":	{"NN"},
"inguen":	{"NN"},
"inguinal":	{"JJ"},
"ingurgitate":	{"VB","VBP"},
"ingurgitated":	{"VBD","VBN"},
"ingurgitates":	{"VBZ"},
"ingurgitating":	{"VBG"},
"inh":	{"NN"},
"inhabit":	{"VB","VBP"},
"inhabitable":	{"JJ"},
"inhabitancy":	{"NN"},
"inhabitant":	{"NN"},
"inhabitants":	{"NNS"},
"inhabitation":	{"NN"},
"inhabited":	{"JJ","VBD","VBN"},
"inhabiting":	{"VBG"},
"inhabits":	{"VBZ"},
"inhalable":	{"JJ"},
"inhalant":	{"JJ","NN"},
"inhalation":	{"NN"},
"inhalations":	{"NNS"},
"inhalator":	{"NN"},
"inhale":	{"VB","VBP"},
"inhaled":	{"VBN","VBD"},
"inhaler":	{"NN"},
"inhalers":	{"NNS"},
"inhales":	{"VBZ"},
"inhaling":	{"VBG"},
"inharmonic":	{"JJ"},
"inharmonious":	{"JJ"},
"inharmoniousness":	{"NN"},
"inhere":	{"VB","VBP"},
"inhered":	{"VBD","VBN"},
"inherence":	{"NN"},
"inherency":	{"NN"},
"inherent":	{"JJ"},
"inherently":	{"RB"},
"inheres":	{"VBZ"},
"inhering":	{"VBG"},
"inherit":	{"VB","VBP"},
"inheritable":	{"JJ"},
"inheritance":	{"NN"},
"inherited":	{"VBD","VBN","JJ"},
"inheriting":	{"VBG"},
"inheritor":	{"NN"},
"inheritors":	{"NNS"},
"inheritress":	{"NN"},
"inheritrix":	{"NN"},
"inherits":	{"VBZ"},
"inhibit":	{"VB","VBP"},
"inhibited":	{"VBN","JJ","VBD"},
"inhibiting":	{"VBG"},
"inhibition":	{"NN"},
"inhibitions":	{"NNS"},
"inhibitor":	{"NN"},
"inhibitors":	{"NNS"},
"inhibitory":	{"JJ"},
"inhibits":	{"VBZ"},
"inholdings":	{"NNS"},
"inhomogeneity":	{"NN"},
"inhomogeneous":	{"JJ"},
"inhospitable":	{"JJ"},
"inhospitableness":	{"NN"},
"inhospitably":	{"RB"},
"inhospitality":	{"NN"},
"inhouse":	{"JJ"},
"inhuman":	{"JJ"},
"inhumane":	{"JJ"},
"inhumanely":	{"RB"},
"inhumaneness":	{"NN"},
"inhumanities":	{"NNS"},
"inhumanity":	{"NN"},
"inhumation":	{"NN"},
"inhume":	{"VB","VBP"},
"inhumed":	{"VBD","VBN"},
"inhumes":	{"VBZ"},
"inhuming":	{"VBG"},
"inimical":	{"JJ"},
"inimitable":	{"JJ"},
"inimitably":	{"RB"},
"inion":	{"NN"},
"iniquities":	{"NNS"},
"iniquitous":	{"JJ"},
"iniquitously":	{"RB"},
"iniquity":	{"NN"},
"initial":	{"JJ","NN","VB","VBP"},
"initialed":	{"VBD","VBN"},
"initialing":	{"VBG"},
"initialisation":	{"NN"},
"initialise":	{"VB","VBP"},
"initialised":	{"VBD","VBN"},
"initialises":	{"VBZ"},
"initialising":	{"VBG"},
"initialisms":	{"NNS"},
"initialization":	{"NN"},
"initialize":	{"VB","VBP"},
"initialized":	{"VBD","VBN"},
"initializes":	{"VBZ"},
"initializing":	{"VBG"},
"initialled":	{"VBD","VBN"},
"initialling":	{"VBG"},
"initially":	{"RB"},
"initials":	{"NNS","VBZ"},
"initiate":	{"VB","NN","VBP"},
"initiated":	{"VBD","VBN","NNS"},
"initiates":	{"VBZ","NNS"},
"initiating":	{"VBG"},
"initiation":	{"NN"},
"initiations":	{"NNS"},
"initiative":	{"NN"},
"initiatives":	{"NNS"},
"initiator":	{"NN"},
"initiators":	{"NNS"},
"initiatory":	{"JJ"},
"inject":	{"VB","VBP"},
"injectable":	{"JJ"},
"injectant":	{"NN"},
"injected":	{"VBD","VBN"},
"injecting":	{"VBG"},
"injection":	{"NN"},
"injection-molded":	{"JJ"},
"injections":	{"NNS"},
"injector":	{"NN"},
"injects":	{"VBZ"},
"injudicious":	{"JJ"},
"injudiciously":	{"RB"},
"injudiciousness":	{"NN"},
"injun":	{"NN"},
"injunction":	{"NN"},
"injunctions":	{"NNS"},
"injunctive":	{"JJ"},
"injure":	{"VB","VBP"},
"injured":	{"VBN","JJ","VBD"},
"injures":	{"VBZ"},
"injuries":	{"NNS"},
"injuring":	{"VBG"},
"injurious":	{"JJ"},
"injuriously":	{"RB"},
"injuriousness":	{"NN"},
"injury":	{"NN"},
"injury-prone":	{"JJ"},
"injustice":	{"NN"},
"injustices":	{"NNS"},
"ink":	{"NN","VB","VBP"},
"ink-black":	{"JJ"},
"ink-jet":	{"JJ"},
"ink-jetting":	{"JJ"},
"inka":	{"NN"},
"inkberry":	{"NN"},
"inkblot":	{"NN"},
"inkblots":	{"NNS"},
"inked":	{"VBD","VBN"},
"inkiness":	{"NN"},
"inking":	{"VBG"},
"inkle":	{"NN"},
"inkling":	{"NN"},
"inklings":	{"NNS"},
"inkpad":	{"NN"},
"inkpot":	{"NN"},
"inks":	{"NNS","VBZ"},
"inkstand":	{"NN"},
"inkwell":	{"NN"},
"inkwells":	{"NNS"},
"inky":	{"JJ"},
"inky-black":	{"JJ"},
"inky-brown":	{"JJ"},
"inla":	{"NN"},
"inlaid":	{"JJ","VBD","VBN"},
"inland":	{"JJ","RB"},
"inlay":	{"VB","VBP","NN"},
"inlaying":	{"VBG"},
"inlays":	{"VBZ","NNS"},
"inlet":	{"NN"},
"inlets":	{"NNS"},
"inman":	{"NN"},
"inmarriage":	{"NN"},
"inmarry":	{"VB"},
"inmate":	{"NN"},
"inmates":	{"NNS"},
"inmost":	{"JJ"},
"inn":	{"NN"},
"innards":	{"NNS"},
"innate":	{"JJ"},
"innately":	{"RB"},
"innateness":	{"NN"},
"inner":	{"JJ"},
"inner-cities":	{"NNS"},
"inner-city":	{"JJ","NN"},
"inner-ear":	{"JJ"},
"innermost":	{"JJ"},
"innersole":	{"NN"},
"innervate":	{"VB","VBP"},
"innervated":	{"VBD","VBN"},
"innervates":	{"VBZ"},
"innervating":	{"VBG"},
"innervation":	{"NN"},
"inning":	{"NN"},
"innings":	{"NN","NNS"},
"innkeeper":	{"NN"},
"innkeepers":	{"NNS"},
"innocence":	{"NN"},
"innocency":	{"NN"},
"innocense":	{"NN"},
"innocent":	{"JJ","NN"},
"innocently":	{"RB"},
"innocents":	{"NNS"},
"innoculation":	{"NN"},
"innocuous":	{"JJ"},
"innovate":	{"VB","VBP"},
"innovated":	{"VBD","VBN"},
"innovates":	{"VBZ"},
"innovating":	{"VBG"},
"innovation":	{"NN"},
"innovational":	{"JJ"},
"innovations":	{"NNS"},
"innovative":	{"JJ"},
"innovatively":	{"RB"},
"innovativeness":	{"NN"},
"innovator":	{"NN"},
"innovators":	{"NNS"},
"innovatory":	{"JJ"},
"innoxious":	{"JJ"},
"inns":	{"NNS"},
"innsbruck":	{"NN"},
"innuendo":	{"NN"},
"innuendoes":	{"NNS"},
"innuendos":	{"NNS"},
"innumerable":	{"JJ"},
"innumerableness":	{"NN"},
"innumerate":	{"JJ"},
"innumerous":	{"JJ"},
"inocor":	{"NN"},
"inoculant":	{"NN"},
"inoculate":	{"VB","VBP"},
"inoculated":	{"VBD","VBN"},
"inoculates":	{"VBZ"},
"inoculating":	{"VBG"},
"inoculation":	{"NN"},
"inoculations":	{"NNS"},
"inoculator":	{"NN"},
"inoculum":	{"NN"},
"inodorous":	{"JJ"},
"inoffensive":	{"JJ"},
"inoffensively":	{"RB"},
"inoperable":	{"JJ"},
"inoperative":	{"JJ"},
"inopportune":	{"JJ"},
"inopportunely":	{"RB"},
"inopportuneness":	{"NN"},
"inordinate":	{"JJ"},
"inordinately":	{"RB"},
"inordinateness":	{"NN"},
"inorganic":	{"JJ"},
"inorganically":	{"RB"},
"inosculate":	{"VB","VBP"},
"inosculated":	{"VBD","VBN"},
"inosculates":	{"VBZ"},
"inosculating":	{"VBG"},
"inosculation":	{"NN"},
"inosine":	{"NN"},
"inositol":	{"NN"},
"inoue":	{"NN"},
"inpatient":	{"NN"},
"inpatients":	{"NNS"},
"inpenetrable":	{"JJ"},
"inplace":	{"NN"},
"inpost":	{"NN"},
"inpour":	{"NN"},
"inpouring":	{"JJ","NN"},
"input":	{"NN","VB","VBP","VBD","VBN"},
"inputs":	{"NNS","VBZ"},
"inputted":	{"VBD","VBN"},
"inputting":	{"VBG"},
"inquest":	{"NN"},
"inquests":	{"NNS"},
"inquietude":	{"NN"},
"inquire":	{"VB","VBP"},
"inquired":	{"VBD","VBN"},
"inquirer":	{"NN"},
"inquirers":	{"NNS"},
"inquires":	{"VBZ"},
"inquiries":	{"NNS"},
"inquiring":	{"JJ","VBG"},
"inquiringly":	{"RB"},
"inquiry":	{"NN"},
"inquisition":	{"NN"},
"inquisitions":	{"NNS"},
"inquisitive":	{"JJ"},
"inquisitively":	{"RB"},
"inquisitiveness":	{"NN"},
"inquisitor":	{"NN"},
"inquisitorial":	{"JJ"},
"inquisitorially":	{"RB"},
"inquisitors":	{"NNS"},
"inquisitory":	{"JJ"},
"inr":	{"NN"},
"inroad":	{"NN"},
"inroads":	{"NNS"},
"inrush":	{"NN"},
"ins":	{"NN"},
"insalubrious":	{"JJ"},
"insalubriousness":	{"NN"},
"insalubrity":	{"NN"},
"insane":	{"JJ"},
"insanely":	{"RB"},
"insaneness":	{"NN"},
"insanitary":	{"JJ"},
"insanity":	{"NN"},
"insatiable":	{"JJ"},
"insatiably":	{"RB"},
"insatiate":	{"JJ"},
"inscribe":	{"VB","VBP"},
"inscribed":	{"JJ","VBD","VBN"},
"inscribes":	{"VBZ"},
"inscribing":	{"VBG"},
"inscription":	{"NN"},
"inscriptions":	{"NNS"},
"inscriptive":	{"JJ"},
"inscriptively":	{"RB"},
"inscrutability":	{"NN"},
"inscrutable":	{"JJ"},
"inscrutably":	{"RB"},
"insect":	{"NN"},
"insecta":	{"NN"},
"insectan":	{"JJ"},
"insecticidal":	{"JJ"},
"insecticidally":	{"RB"},
"insecticide":	{"NN"},
"insecticides":	{"NNS"},
"insectifuge":	{"NN"},
"insectivora":	{"NN"},
"insectivore":	{"NN"},
"insectivorous":	{"JJ"},
"insects":	{"NNS"},
"insecure":	{"JJ"},
"insecurely":	{"RB"},
"insecureness":	{"NN"},
"insecurities":	{"NNS"},
"insecurity":	{"NN"},
"inseminate":	{"VB","VBP"},
"inseminated":	{"VBD","VBN"},
"inseminates":	{"VBZ"},
"inseminating":	{"VBG"},
"insemination":	{"NN"},
"insensate":	{"JJ"},
"insensately":	{"RB"},
"insensibility":	{"NN"},
"insensible":	{"JJ"},
"insensibly":	{"RB"},
"insensitive":	{"JJ"},
"insensitively":	{"RB"},
"insensitiveness":	{"NN"},
"insensitivity":	{"NN"},
"insentience":	{"NN"},
"insentient":	{"JJ"},
"inseparable":	{"JJ"},
"inseparably":	{"RB"},
"insert":	{"VB","VBP","NN"},
"inserted":	{"VBN","VBD"},
"inserting":	{"NN","VBG"},
"insertion":	{"NN"},
"insertions":	{"NNS"},
"inserts":	{"NNS","VBZ"},
"insessores":	{"NNS"},
"inset":	{"NN","VBP","VB","VBD","VBN"},
"insets":	{"NNS","VBZ"},
"insetting":	{"VBG"},
"inshore":	{"JJ","RB"},
"inside":	{"IN","RB","NN","JJ"},
"inside-out":	{"JJ"},
"insider":	{"NN"},
"insider-selling":	{"NN"},
"insider-trading":	{"NN","JJ"},
"insiders":	{"NNS"},
"insides":	{"NNS"},
"insidious":	{"JJ"},
"insidiously":	{"RB"},
"insidiousness":	{"NN"},
"insight":	{"NN"},
"insightful":	{"JJ"},
"insightfully":	{"RB"},
"insightfulness":	{"NN"},
"insights":	{"NNS"},
"insignia":	{"NN","NNS"},
"insignificance":	{"NN"},
"insignificances":	{"NNS"},
"insignificant":	{"JJ"},
"insignificantly":	{"RB"},
"insincere":	{"JJ"},
"insincerely":	{"RB"},
"insincerity":	{"NN"},
"insinuate":	{"VB","VBP"},
"insinuated":	{"VBD","VBN"},
"insinuates":	{"VBZ"},
"insinuating":	{"JJ","VBG"},
"insinuatingly":	{"RB"},
"insinuation":	{"NN"},
"insinuations":	{"NNS"},
"insinuendo":	{"NN"},
"insipid":	{"JJ"},
"insipidity":	{"NN"},
"insipidly":	{"RB"},
"insipidness":	{"NN"},
"insist":	{"VB","VBP"},
"insisted":	{"VBD","VBN"},
"insistence":	{"NN"},
"insistency":	{"NN"},
"insistent":	{"JJ"},
"insistently":	{"RB"},
"insisting":	{"VBG"},
"insists":	{"VBZ"},
"insitutional":	{"JJ"},
"insobriety":	{"NN"},
"insofar":	{"RB"},
"insolate":	{"VB","VBP"},
"insolated":	{"VBD","VBN"},
"insolates":	{"VBZ"},
"insolating":	{"VBG"},
"insolation":	{"NN"},
"insole":	{"NN"},
"insolence":	{"NN"},
"insolent":	{"JJ"},
"insolently":	{"RB"},
"insoles":	{"NNS"},
"insolubility":	{"NN"},
"insoluble":	{"JJ"},
"insolvable":	{"JJ"},
"insolvencies":	{"NNS"},
"insolvency":	{"NN"},
"insolvent":	{"JJ"},
"insomma":	{"FW"},
"insomnia":	{"NN"},
"insomniac":	{"JJ","NN"},
"insomniacs":	{"NNS"},
"insomnic":	{"JJ"},
"insomuch":	{"RB"},
"insouciance":	{"NN"},
"insouciant":	{"JJ"},
"inspan":	{"VB","VBP"},
"inspanned":	{"VBD","VBN"},
"inspanning":	{"VBG"},
"inspans":	{"VBZ"},
"inspect":	{"VB","VBP"},
"inspected":	{"VBD","VBN"},
"inspecting":	{"VBG"},
"inspection":	{"NN"},
"inspections":	{"NNS"},
"inspector":	{"NN"},
"inspector-general":	{"JJ"},
"inspectorate":	{"NN"},
"inspectors":	{"NNS"},
"inspectorship":	{"NN"},
"inspects":	{"VBZ"},
"inspiration":	{"NN"},
"inspirational":	{"JJ"},
"inspirationally":	{"RB"},
"inspirations":	{"NNS"},
"inspiratory":	{"JJ"},
"inspire":	{"VB","VBP"},
"inspired":	{"JJ","VBN","VBD"},
"inspirer":	{"NN"},
"inspires":	{"VBZ"},
"inspiring":	{"JJ","VBG"},
"inspirit":	{"VB","VBP"},
"inspirited":	{"VBD","VBN"},
"inspiriting":	{"VBG"},
"inspirits":	{"VBZ"},
"inspissate":	{"VB","VBP"},
"inspissated":	{"VBD","VBN"},
"inspissates":	{"VBZ"},
"inspissating":	{"VBG"},
"inspissation":	{"NN"},
"inst":	{"JJ"},
"insta-book":	{"NN"},
"instability":	{"NN"},
"instagram":	{"VB","VBP"},
"instagrammed":	{"VBD","VBN"},
"instagramming":	{"VBG"},
"instagrams":	{"VBZ"},
"instal":	{"VB","VBP"},
"install":	{"VB","VBP"},
"installation":	{"NN"},
"installations":	{"NNS"},
"installed":	{"VBN","VBD"},
"installer":	{"NN"},
"installing":	{"VBG"},
"installment":	{"NN"},
"installment-loan":	{"JJ"},
"installments":	{"NNS"},
"installs":	{"VBZ"},
"instalment":	{"NN"},
"instalments":	{"NNS"},
"instance":	{"NN","VBP","VB"},
"instanced":	{"VBD","VBN"},
"instances":	{"NNS","VBZ"},
"instancing":	{"VBG"},
"instancy":	{"NN"},
"instant":	{"NN","JJ"},
"instant-camera":	{"NN"},
"instant-credit":	{"NN"},
"instant-replay":	{"NN"},
"instantaneous":	{"JJ"},
"instantaneously":	{"RB"},
"instantaneousness":	{"NN"},
"instantiate":	{"VB","VBP"},
"instantiated":	{"VBD","VBN"},
"instantiates":	{"VBZ"},
"instantiating":	{"VBG"},
"instantiation":	{"NN"},
"instantly":	{"RB"},
"instar":	{"NN"},
"instate":	{"VB","VBP"},
"instated":	{"VBD","VBN"},
"instates":	{"VBZ"},
"instating":	{"VBG"},
"instauration":	{"NN"},
"instead":	{"RB"},
"instep":	{"NN"},
"insteps":	{"NNS"},
"instigant":	{"NN"},
"instigate":	{"VB","VBP"},
"instigated":	{"VBD","VBN"},
"instigates":	{"VBZ"},
"instigating":	{"VBG"},
"instigation":	{"NN"},
"instigative":	{"JJ"},
"instigator":	{"NN"},
"instigators":	{"NNS"},
"instil":	{"VB","VBP"},
"instill":	{"VB","VBP"},
"instillation":	{"NN"},
"instillator":	{"NN"},
"instilled":	{"VBD","VBN"},
"instilling":	{"VBG"},
"instillment":	{"NN"},
"instills":	{"VBZ"},
"instilment":	{"NN"},
"instils":	{"VBZ"},
"instinct":	{"NN"},
"instinctive":	{"JJ"},
"instinctively":	{"RB"},
"instincts":	{"NNS"},
"instinctual":	{"JJ"},
"institute":	{"NN","VB","VBP"},
"institute-sponsored":	{"JJ"},
"instituted":	{"VBN","VBD"},
"institutes":	{"NNS","VBZ"},
"instituting":	{"VBG"},
"institution":	{"NN"},
"institution-wide":	{"JJ"},
"institutional":	{"JJ"},
"institutional-type":	{"JJ"},
"institutionalise":	{"VB","VBP"},
"institutionalised":	{"JJ","VBD","VBN"},
"institutionalises":	{"VBZ"},
"institutionalising":	{"VBG"},
"institutionalization":	{"NN"},
"institutionalize":	{"VB","VBP"},
"institutionalized":	{"JJ","VBD","VBN"},
"institutionalizes":	{"VBZ"},
"institutionalizing":	{"VBG"},
"institutionally":	{"RB"},
"institutions":	{"NNS"},
"instroke":	{"NN"},
"instruct":	{"VB","VBP"},
"instructed":	{"VBN","VBD"},
"instructing":	{"VBG"},
"instruction":	{"NN"},
"instruction-set":	{"JJ","NN"},
"instructional":	{"JJ"},
"instructions":	{"NNS"},
"instructive":	{"JJ"},
"instructively":	{"RB"},
"instructor":	{"NN"},
"instructors":	{"NNS"},
"instructorship":	{"NN"},
"instructress":	{"NN"},
"instructs":	{"VBZ"},
"instrument":	{"NN","VB","VBP"},
"instrument-jammed":	{"JJ"},
"instrumental":	{"JJ","NN"},
"instrumental-reward":	{"JJ"},
"instrumentalism":	{"NN"},
"instrumentalist":	{"NN"},
"instrumentalists":	{"NNS"},
"instrumentalities":	{"NNS"},
"instrumentality":	{"NN"},
"instrumentally":	{"RB"},
"instrumentals":	{"NNS"},
"instrumentation":	{"NN"},
"instrumented":	{"VBD","VBN"},
"instrumenting":	{"VBG"},
"instruments":	{"NNS","VBZ"},
"insubordinate":	{"JJ"},
"insubordination":	{"NN"},
"insubstantial":	{"JJ"},
"insubstantiality":	{"NN"},
"insubstantially":	{"RB"},
"insufferable":	{"JJ"},
"insufferably":	{"RB"},
"insufficiency":	{"NN"},
"insufficient":	{"JJ"},
"insufficiently":	{"RB"},
"insufflate":	{"VB","VBP"},
"insufflated":	{"VBD","VBN"},
"insufflates":	{"VBZ"},
"insufflating":	{"VBG"},
"insufflation":	{"NN"},
"insulant":	{"NN"},
"insular":	{"JJ"},
"insularism":	{"NN"},
"insularity":	{"NN"},
"insulate":	{"VB","VBP"},
"insulated":	{"VBN","JJ","VBD"},
"insulates":	{"VBZ"},
"insulating":	{"JJ","VBG"},
"insulation":	{"NN"},
"insulator":	{"NN"},
"insulators":	{"NNS"},
"insulin":	{"NN"},
"insulin-dependent":	{"JJ"},
"insulins":	{"NNS"},
"insult":	{"NN","VB","VBP"},
"insulted":	{"VBD","VBN"},
"insulting":	{"JJ","VBG"},
"insultingly":	{"RB"},
"insults":	{"VBZ","NNS"},
"insuperable":	{"JJ"},
"insuperably":	{"RB"},
"insupportable":	{"JJ"},
"insurability":	{"NN"},
"insurable":	{"JJ"},
"insurance":	{"NN"},
"insurance-claims":	{"NNS"},
"insurance-company":	{"NN"},
"insurance-cost":	{"JJ"},
"insurance-holding":	{"JJ"},
"insurance-industry":	{"NN"},
"insurance-policy":	{"NN"},
"insurance-premium-finance":	{"JJ"},
"insurance-rate":	{"JJ"},
"insurance-reform":	{"JJ","NN"},
"insurance-related":	{"JJ"},
"insure":	{"VB","VBP"},
"insured":	{"VBN","VBD","JJ","NN"},
"insurer":	{"NN"},
"insureres":	{"NNS"},
"insurers":	{"NNS"},
"insures":	{"VBZ"},
"insurgence":	{"NN"},
"insurgency":	{"NN"},
"insurgent":	{"NN","JJ"},
"insurgents":	{"NNS"},
"insuring":	{"VBG"},
"insurmountable":	{"JJ"},
"insurrection":	{"NN"},
"insurrectional":	{"JJ"},
"insurrectionary":	{"JJ"},
"insurrectionism":	{"NN"},
"insurrectionist":	{"NN"},
"insurrectionists":	{"NNS"},
"insurrections":	{"NNS"},
"insusceptible":	{"JJ"},
"inswinger":	{"NN"},
"inswingers":	{"NNS"},
"intact":	{"JJ"},
"intactible":	{"JJ"},
"intactness":	{"NN"},
"intaglio":	{"NN"},
"intaglios":	{"NNS"},
"intake":	{"NN"},
"intakes":	{"NNS"},
"intangibility":	{"NN"},
"intangible":	{"JJ","NN"},
"intangibleness":	{"NN"},
"intangibles":	{"NNS"},
"integer":	{"NN"},
"integers":	{"NNS"},
"integral":	{"JJ"},
"integrality":	{"NN"},
"integrally":	{"RB"},
"integrals":	{"NNS"},
"integrate":	{"VB","VBP"},
"integrated":	{"JJ","VBN","VBD"},
"integrated-circuit":	{"JJ"},
"integrated-steel":	{"NN"},
"integrated-technologies":	{"NNS"},
"integrates":	{"VBZ"},
"integrating":	{"VBG"},
"integration":	{"NN"},
"integrative":	{"JJ"},
"integrator":	{"NN"},
"integrators":	{"NNS"},
"integrity":	{"NN"},
"integument":	{"NN"},
"integumental":	{"JJ"},
"integumentary":	{"JJ"},
"intel":	{"NN"},
"intellect":	{"NN"},
"intellection":	{"NN"},
"intellects":	{"NNS"},
"intellectual":	{"JJ","NN"},
"intellectual-literary":	{"JJ"},
"intellectual-property":	{"JJ"},
"intellectualisation":	{"NN"},
"intellectualise":	{"VB","VBP"},
"intellectualised":	{"VBD","VBN"},
"intellectualises":	{"VBZ"},
"intellectualising":	{"VBG"},
"intellectuality":	{"NN"},
"intellectualization":	{"NN"},
"intellectualize":	{"VB","VBP"},
"intellectualized":	{"VBD","VBN"},
"intellectualizes":	{"VBZ"},
"intellectualizing":	{"VBG"},
"intellectually":	{"RB"},
"intellectuals":	{"NNS"},
"intellectus":	{"FW"},
"intelligence":	{"NN"},
"intelligence-briefing":	{"NN"},
"intelligence-sharing":	{"NN"},
"intelligences":	{"NNS"},
"intelligent":	{"JJ"},
"intelligently":	{"RB"},
"intelligentsia":	{"NNS"},
"intelligibility":	{"NN"},
"intelligible":	{"JJ"},
"intelligibly":	{"RB"},
"intelnet":	{"NN"},
"intemperance":	{"NN"},
"intemperate":	{"JJ"},
"intemperately":	{"RB"},
"intemperateness":	{"NN"},
"intend":	{"VB","VBP"},
"intendant":	{"NN"},
"intendants":	{"NNS"},
"intended":	{"VBN","VBD","JJ"},
"intending":	{"VBG"},
"intends":	{"VBZ"},
"intense":	{"JJ"},
"intensely":	{"RB"},
"intenser":	{"JJR"},
"intensest":	{"JJS"},
"intensification":	{"NN"},
"intensified":	{"VBD","VBN"},
"intensifier":	{"NN"},
"intensifiers":	{"NNS"},
"intensifies":	{"VBZ"},
"intensify":	{"VB","VBP"},
"intensifying":	{"VBG"},
"intension":	{"NN"},
"intensional":	{"JJ"},
"intensities":	{"NNS"},
"intensity":	{"NN"},
"intensive":	{"JJ","NN"},
"intensive-care":	{"JJ","NN"},
"intensively":	{"RB"},
"intensiveness":	{"NN"},
"intent":	{"NN","JJ"},
"intention":	{"NN"},
"intentional":	{"JJ"},
"intentionality":	{"NN"},
"intentionally":	{"RB"},
"intentioned":	{"JJ"},
"intentions":	{"NNS"},
"intently":	{"RB"},
"intentness":	{"NN"},
"intents":	{"NNS"},
"inter":	{"VB","VBP"},
"inter-American":	{"JJ"},
"inter-Arab":	{"JJ"},
"inter-German":	{"JJ"},
"inter-agency":	{"JJ"},
"inter-arab":	{"JJ"},
"inter-bank":	{"JJ"},
"inter-city":	{"JJ"},
"inter-company":	{"JJ"},
"inter-exchange":	{"JJ"},
"inter-german":	{"JJ"},
"inter-governmental":	{"JJ"},
"inter-industry":	{"JJ"},
"inter-office":	{"JJ"},
"inter-plant":	{"JJ"},
"inter-relation":	{"NN"},
"inter-relationships":	{"NNS"},
"inter-species":	{"JJ"},
"inter-town":	{"JJ"},
"inter-tribal":	{"JJ"},
"interact":	{"VB","VBP"},
"interacted":	{"VBD","VBN"},
"interacting":	{"VBG"},
"interaction":	{"NN"},
"interactional":	{"JJ"},
"interactionist":	{"NN","JJ"},
"interactionists":	{"NNS"},
"interactions":	{"NNS"},
"interactive":	{"JJ"},
"interacts":	{"VBZ"},
"interagency":	{"JJ"},
"interahamwe":	{"NN"},
"interaxial":	{"JJ"},
"interbank":	{"JJ"},
"interbrain":	{"NN"},
"interbred":	{"VBD","VBN"},
"interbreed":	{"VB","VBP"},
"interbreeding":	{"VBG"},
"interbreeds":	{"VBZ"},
"intercalary":	{"JJ"},
"intercalate":	{"VB","VBP"},
"intercalated":	{"VBD","VBN"},
"intercalates":	{"VBZ"},
"intercalating":	{"VBG"},
"intercalation":	{"NN"},
"intercede":	{"VB","VBP"},
"interceded":	{"VBD","VBN"},
"intercedes":	{"VBZ"},
"interceding":	{"VBG"},
"intercellular":	{"JJ"},
"intercept":	{"VB","VBP"},
"intercepted":	{"VBD","VBN"},
"intercepting":	{"VBG"},
"interception":	{"NN"},
"interceptions":	{"NNS"},
"interceptor":	{"NN"},
"interceptors":	{"NNS"},
"intercepts":	{"VBZ"},
"intercession":	{"NN"},
"intercessions":	{"NNS"},
"intercessor":	{"NN"},
"interchangable":	{"JJ"},
"interchange":	{"NN","VB","VBP"},
"interchangeability":	{"NN"},
"interchangeable":	{"JJ","NN"},
"interchangeableness":	{"NN"},
"interchangeably":	{"RB"},
"interchanged":	{"VBD","VBN"},
"interchanges":	{"NNS","VBZ"},
"interchanging":	{"VBG"},
"interchurch":	{"JJ"},
"intercity":	{"JJ"},
"interclass":	{"JJ"},
"intercollegiate":	{"JJ"},
"intercom":	{"NN"},
"intercommunicate":	{"VB","VBP"},
"intercommunicated":	{"VBD","VBN"},
"intercommunicates":	{"VBZ"},
"intercommunicating":	{"VBG"},
"intercommunication":	{"NN"},
"intercommunion":	{"NN"},
"intercompany":	{"NN"},
"intercoms":	{"NNS"},
"interconnect":	{"VB","VBP"},
"interconnected":	{"VBD","VBN","JJ"},
"interconnectedness":	{"NN"},
"interconnecting":	{"VBG","JJ"},
"interconnection":	{"NN"},
"interconnections":	{"NNS"},
"interconnectivity":	{"NN"},
"interconnects":	{"VBZ"},
"intercontinental":	{"JJ"},
"intercorporate":	{"JJ"},
"intercostal":	{"NN","JJ"},
"intercourse":	{"NN"},
"intercrisis":	{"NN"},
"intercross":	{"VB","VBP","NN"},
"intercrossed":	{"VBD","VBN"},
"intercrosses":	{"VBZ","NNS"},
"intercrossing":	{"VBG"},
"interdenominational":	{"JJ"},
"interdepartmental":	{"JJ"},
"interdepend":	{"VB","VBP"},
"interdepended":	{"VBD","VBN"},
"interdependence":	{"NN"},
"interdependency":	{"NN"},
"interdependent":	{"JJ"},
"interdependently":	{"RB"},
"interdepending":	{"VBG"},
"interdepends":	{"VBZ"},
"interdict":	{"VB","VBP","NN"},
"interdicted":	{"VBD","VBN"},
"interdicting":	{"VBG"},
"interdiction":	{"NN"},
"interdicts":	{"VBZ","NNS"},
"interdisciplinary":	{"JJ"},
"intereference":	{"NN"},
"interessant":	{"FW"},
"interest":	{"NN","VB","VBP"},
"interest-bearing":	{"JJ"},
"interest-deferred":	{"JJ"},
"interest-free":	{"JJ","RB"},
"interest-only":	{"JJ"},
"interest-rate":	{"NN","JJ"},
"interest-rate-sensitive":	{"JJ"},
"interest-rate-type":	{"JJ"},
"interest-sensitive":	{"JJ"},
"interest-subsidy":	{"NN"},
"interested":	{"JJ","VBN","VBD"},
"interestedly":	{"RB"},
"interestedness":	{"NN"},
"interesting":	{"JJ","VBG"},
"interestingly":	{"RB"},
"interestingness":	{"NN"},
"interestrate":	{"NN"},
"interests":	{"NNS","VBZ"},
"interface":	{"NN","VB","VBP"},
"interfaced":	{"VBD","VBN"},
"interfaces":	{"NNS","VBZ"},
"interfacial":	{"JJ"},
"interfacing":	{"VBG"},
"interfaith":	{"JJ"},
"interfere":	{"VB","VBP"},
"interfered":	{"VBD","VBN"},
"interference":	{"NN"},
"interference-like":	{"JJ"},
"interferes":	{"VBZ"},
"interfering":	{"JJ","VBG"},
"interferometer":	{"NN"},
"interferometers":	{"NNS"},
"interferon":	{"NN"},
"intergalactic":	{"JJ"},
"intergenerational":	{"JJ"},
"interglacial":	{"JJ"},
"intergovernmental":	{"JJ"},
"intergrated-steel":	{"NN"},
"intergroup":	{"JJ"},
"interim":	{"JJ","NN"},
"interim-dividend":	{"NN"},
"interior":	{"NN","JJ"},
"interior-construction":	{"NN"},
"interior-decorating":	{"JJ"},
"interior-furnishings":	{"NNS"},
"interiorise":	{"VB","VBP"},
"interiorised":	{"VBD","VBN"},
"interiorises":	{"VBZ"},
"interiorising":	{"VBG"},
"interiorize":	{"VB","VBP"},
"interiorized":	{"VBD","VBN"},
"interiorizes":	{"VBZ"},
"interiorizing":	{"VBG"},
"interiors":	{"NNS"},
"interject":	{"VB","VBP"},
"interjected":	{"VBD","VBN"},
"interjecting":	{"VBG"},
"interjection":	{"NN"},
"interjections":	{"NNS"},
"interjects":	{"VBZ"},
"interlace":	{"VB","VBP"},
"interlaced":	{"JJ","VBD","VBN"},
"interlaces":	{"VBZ"},
"interlacing":	{"NN","VBG"},
"interlaken":	{"NN"},
"interlanguage":	{"NN"},
"interlard":	{"VB","VBP"},
"interlarded":	{"VBD","VBN"},
"interlarding":	{"VBG"},
"interlards":	{"VBZ"},
"interlayer":	{"NN"},
"interleaf":	{"NN"},
"interleave":	{"VB","VBP"},
"interleaved":	{"VBD","VBN"},
"interleaves":	{"VBZ","NNS"},
"interleaving":	{"VBG"},
"interleukin":	{"NN"},
"interleukin-1":	{"NN"},
"interleukin-2":	{"NN"},
"interleukin-3":	{"NN"},
"interleukin-4":	{"NN"},
"interleukins":	{"NNS"},
"interlibrary":	{"JJ"},
"interline":	{"VB","VBP"},
"interlineal":	{"JJ"},
"interlinear":	{"JJ"},
"interlineate":	{"VB","VBP"},
"interlineated":	{"VBD","VBN"},
"interlineates":	{"VBZ"},
"interlineating":	{"VBG"},
"interlined":	{"VBD","VBN"},
"interlines":	{"VBZ"},
"interlingua":	{"NN"},
"interlining":	{"NN","VBG"},
"interlink":	{"VB","VBP"},
"interlinked":	{"VBN","VBD"},
"interlinking":	{"VBG"},
"interlinks":	{"VBZ"},
"interlobular":	{"JJ"},
"interlock":	{"VB","VBP","NN"},
"interlocked":	{"VBD","VBN"},
"interlocking":	{"VBG"},
"interlocks":	{"VBZ"},
"interlocutor":	{"NN"},
"interlocutors":	{"NNS"},
"interlocutory":	{"JJ"},
"interlope":	{"VB","VBP"},
"interloped":	{"VBD","VBN"},
"interloper":	{"NN"},
"interlopers":	{"NNS"},
"interlopes":	{"VBZ"},
"interloping":	{"VBG"},
"interlude":	{"NN"},
"interludes":	{"NNS"},
"intermarket":	{"JJ","NN"},
"intermarriage":	{"NN"},
"intermarried":	{"VBD","VBN"},
"intermarries":	{"VBZ"},
"intermarry":	{"VB","VBP"},
"intermarrying":	{"VBG"},
"intermediaries":	{"NNS"},
"intermediary":	{"JJ","NN"},
"intermediate":	{"JJ","VB","VBP","NN"},
"intermediate-range":	{"JJ"},
"intermediate-term":	{"JJ"},
"intermediated":	{"VBD","VBN"},
"intermediately":	{"RB"},
"intermediates":	{"NNS","VBZ"},
"intermediating":	{"VBG"},
"intermediation":	{"NN"},
"intermediator":	{"NN"},
"interment":	{"NN"},
"interments":	{"NNS"},
"intermesh":	{"VB","VBP"},
"intermeshed":	{"VBD","VBN"},
"intermeshes":	{"VBZ"},
"intermeshing":	{"VBG"},
"intermezzi":	{"NNS"},
"intermezzo":	{"NN"},
"intermezzos":	{"NNS"},
"interminable":	{"JJ"},
"interminably":	{"RB"},
"intermingle":	{"VB","VBP"},
"intermingled":	{"VBD","VBN","JJ"},
"intermingles":	{"VBZ"},
"intermingling":	{"VBG"},
"interministerial":	{"JJ"},
"intermission":	{"NN"},
"intermissions":	{"NNS"},
"intermit":	{"VB","VBP"},
"intermits":	{"VBZ"},
"intermitted":	{"VBD","VBN"},
"intermittence":	{"NN"},
"intermittency":	{"NN"},
"intermittent":	{"JJ"},
"intermittently":	{"RB"},
"intermitter":	{"NN"},
"intermitting":	{"VBG"},
"intermittingly":	{"RB"},
"intermittor":	{"NN"},
"intermix":	{"VB","VBP"},
"intermixed":	{"VBD","VBN"},
"intermixes":	{"VBZ"},
"intermixing":	{"VBG"},
"intermixture":	{"NN"},
"intermodal":	{"JJ"},
"intermolecular":	{"JJ"},
"intermural":	{"JJ"},
"intern":	{"VB","VBP","NN"},
"internal":	{"JJ"},
"internal-external":	{"JJ"},
"internal-security":	{"NN"},
"internalisation":	{"NN"},
"internalise":	{"VB","VBP"},
"internalised":	{"VBD","VBN"},
"internalises":	{"VBZ"},
"internalising":	{"VBG"},
"internality":	{"NN"},
"internalization":	{"NN"},
"internalize":	{"VB","VBP"},
"internalized":	{"VBD","VBN"},
"internalizes":	{"VBZ"},
"internalizing":	{"VBG"},
"internally":	{"RB"},
"international":	{"JJ","NN"},
"international-capital":	{"JJ"},
"international-defense":	{"NN"},
"international-leasing":	{"JJ"},
"international-money-markets":	{"NNS"},
"international-operations":	{"NNS"},
"international-payments":	{"NNS"},
"international-share":	{"JJ"},
"internationale":	{"NN"},
"internationalisation":	{"NN"},
"internationalise":	{"VB","VBP"},
"internationalised":	{"VBD","VBN"},
"internationalises":	{"VBZ"},
"internationalising":	{"VBG"},
"internationalism":	{"NN"},
"internationalist":	{"NN","JJ"},
"internationalistic":	{"JJ"},
"internationalists":	{"NNS"},
"internationality":	{"NN"},
"internationalization":	{"NN"},
"internationalize":	{"VB","VBP"},
"internationalized":	{"VBD","VBN"},
"internationalizes":	{"VBZ"},
"internationalizing":	{"VBG"},
"internationally":	{"RB"},
"internationals":	{"NNS"},
"interne":	{"NN"},
"internecine":	{"JJ"},
"interned":	{"VBN","VBD"},
"internee":	{"NN"},
"internees":	{"NNS"},
"interning":	{"VBG"},
"internist":	{"NN"},
"internists":	{"NNS"},
"internment":	{"NN"},
"internode":	{"NN"},
"interns":	{"VBZ","NNS"},
"internship":	{"NN"},
"internships":	{"NNS"},
"internuncio":	{"NN"},
"interoception":	{"NN"},
"interoceptive":	{"JJ"},
"interoceptor":	{"NN"},
"interoffice":	{"JJ"},
"interoperability":	{"NN"},
"interoperable":	{"JJ"},
"interparty":	{"NN"},
"interpellate":	{"VB","VBP"},
"interpellated":	{"VBD","VBN"},
"interpellates":	{"VBZ"},
"interpellating":	{"VBG"},
"interpellation":	{"NN"},
"interpenetrate":	{"VB","VBP"},
"interpenetrated":	{"VBD","VBN"},
"interpenetrates":	{"VBZ"},
"interpenetrating":	{"VBG"},
"interpenetration":	{"NN"},
"interpenetrations":	{"NNS"},
"interpeople":	{"JJ"},
"interpersonal":	{"JJ"},
"interphone":	{"NN"},
"interplanetary":	{"JJ"},
"interplay":	{"NN","VB","VBP"},
"interplayed":	{"VBD","VBN"},
"interplaying":	{"VBG"},
"interplays":	{"VBZ"},
"interpolate":	{"VB","VBP"},
"interpolated":	{"VBD","VBN"},
"interpolates":	{"VBZ"},
"interpolating":	{"VBG"},
"interpolation":	{"NN"},
"interpolations":	{"NNS"},
"interpose":	{"VB","VBP"},
"interposed":	{"VBD","VBN"},
"interposes":	{"VBZ"},
"interposing":	{"VBG"},
"interposition":	{"NN"},
"interpret":	{"VB","VBP"},
"interpretable":	{"JJ"},
"interpretation":	{"NN"},
"interpretations":	{"NNS"},
"interpretative":	{"JJ"},
"interpreted":	{"VBD","VBN"},
"interpreter":	{"NN"},
"interpreters":	{"NNS"},
"interpreting":	{"NN","VBG"},
"interpretive":	{"JJ"},
"interpretor":	{"NN"},
"interprets":	{"VBZ"},
"interprovincial":	{"JJ"},
"interracial":	{"JJ"},
"interracially":	{"RB"},
"interred":	{"VBD","VBN"},
"interreflection":	{"NN"},
"interregna":	{"NNS"},
"interregnum":	{"NN"},
"interregnums":	{"NNS"},
"interrelate":	{"VB","VBP"},
"interrelated":	{"JJ","VBD","VBN"},
"interrelatedness":	{"NN"},
"interrelates":	{"VBZ"},
"interrelating":	{"VBG"},
"interrelation":	{"NN"},
"interrelations":	{"NNS"},
"interrelationship":	{"NN"},
"interrelationships":	{"NNS"},
"interring":	{"VBG"},
"interrogate":	{"VB","VBP"},
"interrogated":	{"VBD","VBN"},
"interrogates":	{"VBZ"},
"interrogating":	{"VBG"},
"interrogation":	{"NN"},
"interrogations":	{"NNS"},
"interrogative":	{"JJ","NN"},
"interrogatively":	{"RB"},
"interrogatives":	{"NNS"},
"interrogator":	{"NN"},
"interrogators":	{"NNS"},
"interrogatory":	{"NN","JJ"},
"interrupt":	{"VB","VBP"},
"interrupted":	{"VBD","VBN","JJ"},
"interrupter":	{"NN"},
"interrupters":	{"NNS"},
"interruptible":	{"JJ"},
"interrupting":	{"VBG"},
"interruption":	{"NN"},
"interruptions":	{"NNS"},
"interruptive":	{"JJ"},
"interruptively":	{"RB"},
"interruptless":	{"JJ"},
"interrupts":	{"VBZ"},
"inters":	{"VBZ"},
"interscholastic":	{"JJ"},
"interschool":	{"JJ"},
"intersect":	{"VB","VBP"},
"intersectant":	{"JJ"},
"intersected":	{"VBD","VBN"},
"intersecting":	{"JJ","VBG"},
"intersection":	{"NN"},
"intersectionalities":	{"NNS"},
"intersectionality":	{"NN"},
"intersections":	{"NNS"},
"intersects":	{"VBZ"},
"intersex":	{"NN"},
"intersexual":	{"JJ"},
"interspecies":	{"JJ"},
"interspecific":	{"JJ"},
"interspersal":	{"NN"},
"intersperse":	{"VB","VBP"},
"interspersed":	{"VBD","VBN"},
"intersperses":	{"VBZ"},
"interspersing":	{"VBG"},
"interspersion":	{"NN"},
"interst":	{"NN"},
"interstage":	{"NN"},
"interstate":	{"JJ","NN"},
"interstates":	{"NNS"},
"interstellar":	{"JJ"},
"interstice":	{"NN"},
"interstices":	{"NNS"},
"interstitial":	{"JJ"},
"interstratified":	{"VBD","VBN"},
"interstratifies":	{"VBZ"},
"interstratify":	{"VB","VBP"},
"interstratifying":	{"VBG"},
"intertidal":	{"JJ"},
"intertitles":	{"NNS"},
"intertribal":	{"JJ"},
"intertrigo":	{"NN"},
"intertwine":	{"VB","VBP"},
"intertwined":	{"VBD","VBN"},
"intertwines":	{"VBZ"},
"intertwining":	{"VBG"},
"interval":	{"NN"},
"intervals":	{"NNS"},
"intervene":	{"VB","VBP"},
"intervened":	{"VBD","VBN"},
"intervenes":	{"VBZ"},
"intervening":	{"JJ","VBG"},
"intervenor":	{"NN"},
"intervenors":	{"NNS"},
"intervention":	{"NN"},
"intervention-speeded":	{"JJ"},
"interventionist":	{"JJ","NN"},
"interventionists":	{"NNS"},
"interventions":	{"NNS"},
"intervertebral":	{"JJ"},
"interview":	{"NN","VB","VBP"},
"interviewed":	{"VBN","VBD"},
"interviewee":	{"NN"},
"interviewees":	{"NNS"},
"interviewer":	{"NN"},
"interviewers":	{"NNS"},
"interviewing":	{"NN","VBG"},
"interviews":	{"NNS","VBZ"},
"interwar":	{"JJ"},
"interweave":	{"VB","VBP"},
"interweaves":	{"VBZ"},
"interweaving":	{"VBG","NN"},
"interwove":	{"VBD"},
"interwoven":	{"VBN"},
"intestacy":	{"NN"},
"intestate":	{"JJ"},
"intestinal":	{"JJ"},
"intestine":	{"NN"},
"intestines":	{"NNS"},
"inti":	{"NN"},
"intial":	{"JJ"},
"intifada":	{"NN"},
"intifadah":	{"NN"},
"intima":	{"NN"},
"intimacies":	{"NNS"},
"intimacy":	{"NN"},
"intimal":	{"JJ"},
"intimate":	{"JJ","NN","VB","VBP"},
"intimated":	{"VBD","VBN"},
"intimately":	{"RB"},
"intimates":	{"VBZ"},
"intimating":	{"VBG"},
"intimation":	{"NN"},
"intimations":	{"NNS"},
"intimidate":	{"VB","VBP"},
"intimidated":	{"VBD","VBN","JJ"},
"intimidates":	{"VBZ"},
"intimidating":	{"JJ","VBG"},
"intimidation":	{"NN"},
"intimidations":	{"NNS"},
"intitiative":	{"NN"},
"into":	{"IN"},
"intolerable":	{"JJ"},
"intolerably":	{"RB"},
"intolerance":	{"NN"},
"intolerant":	{"JJ"},
"intolerantly":	{"RB"},
"intonaco":	{"NN"},
"intonate":	{"VB","VBP"},
"intonated":	{"VBD","VBN"},
"intonates":	{"VBZ"},
"intonating":	{"VBG"},
"intonation":	{"NN"},
"intonations":	{"NNS"},
"intone":	{"VB","VBP"},
"intoned":	{"VBD","VBN"},
"intones":	{"VBZ"},
"intoning":	{"VBG"},
"intoxicant":	{"JJ","NN"},
"intoxicate":	{"VB","VBP"},
"intoxicated":	{"VBD","VBN","JJ"},
"intoxicates":	{"VBZ"},
"intoxicating":	{"JJ","VBG"},
"intoxication":	{"NN"},
"intra-Community":	{"JJ"},
"intra-EC":	{"JJ"},
"intra-administration":	{"JJ"},
"intra-city":	{"NN"},
"intra-community":	{"JJ"},
"intra-company":	{"JJ"},
"intra-ec":	{"JJ"},
"intra-european":	{"JJ"},
"intra-governmental":	{"JJ"},
"intra-mural":	{"JJ"},
"intra-party":	{"JJ"},
"intra-state":	{"JJ"},
"intra-stellar":	{"NN"},
"intra-uterine":	{"JJ"},
"intraabdominal":	{"JJ"},
"intrabony":	{"JJ"},
"intracellular":	{"JJ"},
"intracerebral":	{"JJ"},
"intracompany":	{"JJ"},
"intracranial":	{"JJ"},
"intractability":	{"NN"},
"intractable":	{"JJ"},
"intractableness":	{"NN"},
"intractably":	{"RB"},
"intracutaneous":	{"JJ"},
"intraday":	{"JJ","NN"},
"intradepartmental":	{"JJ"},
"intradermal":	{"JJ"},
"intradermally":	{"RB"},
"intradermic":	{"JJ"},
"intrados":	{"NN"},
"intraepithelial":	{"JJ"},
"intragovernment":	{"JJ"},
"intragroup":	{"JJ"},
"intralinguistic":	{"JJ"},
"intralobular":	{"JJ"},
"intramolecular":	{"JJ"},
"intramural":	{"JJ"},
"intramuscular":	{"JJ"},
"intramuscularly":	{"RB"},
"intranasal":	{"JJ"},
"intranet":	{"NN"},
"intranets":	{"NNS"},
"intransigence":	{"NN"},
"intransigency":	{"NN"},
"intransigent":	{"JJ","NN"},
"intransigents":	{"NNS"},
"intransitive":	{"JJ"},
"intransitively":	{"RB"},
"intransitiveness":	{"NN"},
"intransitivity":	{"NN"},
"intraocular":	{"JJ"},
"intraoperative":	{"JJ"},
"intraparty":	{"JJ"},
"intrapreneurship":	{"NN"},
"intrapulmonary":	{"JJ"},
"intrasentential":	{"JJ"},
"intraspecies":	{"JJ"},
"intraspecific":	{"JJ"},
"intrastate":	{"JJ"},
"intratissue":	{"NN"},
"intrauterine":	{"JJ"},
"intravasation":	{"NN"},
"intravenous":	{"JJ"},
"intravenously":	{"RB"},
"intraventricular":	{"JJ"},
"intravitreal":	{"JJ"},
"intrench":	{"VB","VBP"},
"intrenchment":	{"NN"},
"intrepid":	{"JJ"},
"intrepidity":	{"NN"},
"intrepidly":	{"RB"},
"intricacies":	{"NNS"},
"intricacy":	{"NN"},
"intricate":	{"JJ"},
"intricately":	{"RB"},
"intrigue":	{"VB","VBP","NN"},
"intrigued":	{"JJ","VBD","VBN"},
"intriguer":	{"NN"},
"intrigues":	{"VBZ","NNS"},
"intriguing":	{"JJ","VBG"},
"intriguingly":	{"RB"},
"intrinsic":	{"JJ"},
"intrinsical":	{"JJ"},
"intrinsically":	{"RB"},
"intro":	{"NN"},
"introduce":	{"VB","VBP"},
"introduced":	{"VBN","VBD"},
"introduces":	{"VBZ"},
"introducing":	{"VBG"},
"introduction":	{"NN"},
"introductions":	{"NNS"},
"introductory":	{"JJ"},
"introit":	{"NN"},
"introitus":	{"NN"},
"introject":	{"VB","VBP"},
"introjected":	{"VBD","VBN"},
"introjecting":	{"VBG"},
"introjection":	{"NN"},
"introjects":	{"VBZ"},
"intromissible":	{"JJ"},
"intromissiblity":	{"NN"},
"intromission":	{"NN"},
"intromit":	{"VB","VBP"},
"intromits":	{"VBZ"},
"intromitted":	{"VBD","VBN"},
"intromittent":	{"JJ"},
"intromitter":	{"NN"},
"intromitting":	{"VBG"},
"intron":	{"NN"},
"intropin":	{"NN"},
"intros":	{"NNS"},
"introspect":	{"VB","VBP"},
"introspected":	{"VBD","VBN"},
"introspecting":	{"VBG"},
"introspection":	{"NN"},
"introspective":	{"JJ"},
"introspectively":	{"RB"},
"introspectiveness":	{"NN"},
"introspects":	{"VBZ"},
"introuvable":	{"JJ"},
"introversion":	{"NN"},
"introversive":	{"JJ"},
"introvert":	{"VB","VBP","NN","JJ"},
"introverted":	{"JJ","VBD","VBN"},
"introverting":	{"VBG"},
"introvertish":	{"JJ"},
"introvertive":	{"JJ"},
"introvertly":	{"RB"},
"introverts":	{"VBZ","NNS"},
"intrude":	{"VB","VBP"},
"intruded":	{"VBN","VBD"},
"intruder":	{"NN"},
"intruders":	{"NNS"},
"intrudes":	{"VBZ"},
"intruding":	{"VBG"},
"intrusion":	{"NN"},
"intrusions":	{"NNS"},
"intrusive":	{"JJ"},
"intrusiveness":	{"NN"},
"intrust":	{"VB","VBP"},
"intrusted":	{"VBD","VBN"},
"intrusting":	{"VBG"},
"intrusts":	{"VBZ"},
"intubate":	{"VB","VBP"},
"intubated":	{"VBD","VBN"},
"intubates":	{"VBZ"},
"intubating":	{"VBG"},
"intubation":	{"NN"},
"intuit":	{"VB","VBP"},
"intuited":	{"VBD","VBN"},
"intuiting":	{"VBG"},
"intuition":	{"NN"},
"intuitionism":	{"NN"},
"intuitionist":	{"JJ"},
"intuitions":	{"NNS"},
"intuitive":	{"JJ"},
"intuitively":	{"RB"},
"intuits":	{"VBZ"},
"intumesce":	{"VB","VBP"},
"intumesced":	{"VBD","VBN"},
"intumescence":	{"NN"},
"intumescences":	{"NNS"},
"intumescency":	{"NN"},
"intumescent":	{"JJ"},
"intumesces":	{"VBZ"},
"intumescing":	{"VBG"},
"intussuscept":	{"VB","VBP"},
"intussuscepted":	{"VBD","VBN"},
"intussuscepting":	{"VBG"},
"intussusception":	{"NN"},
"intussuscepts":	{"VBZ"},
"inula":	{"NN"},
"inulin":	{"NN"},
"inunct":	{"VB","VBP"},
"inuncted":	{"VBD","VBN"},
"inuncting":	{"VBG"},
"inunction":	{"NN"},
"inuncts":	{"VBZ"},
"inundate":	{"VB","VBP"},
"inundated":	{"VBD","VBN"},
"inundates":	{"VBZ"},
"inundating":	{"VBG"},
"inundation":	{"NN"},
"inundations":	{"NNS"},
"inure":	{"VB","VBP"},
"inured":	{"JJ","VBD","VBN"},
"inures":	{"VBZ"},
"inuring":	{"VBG"},
"inutile":	{"JJ"},
"inutility":	{"NN"},
"invade":	{"VB","VBP"},
"invaded":	{"VBD","VBN"},
"invader":	{"NN"},
"invaders":	{"NNS"},
"invades":	{"VBZ"},
"invading":	{"VBG"},
"invaginate":	{"VB","VBP"},
"invaginated":	{"VBD","VBN"},
"invaginates":	{"VBZ"},
"invaginating":	{"VBG"},
"invagination":	{"NN"},
"invalid":	{"JJ","VB","VBP","NN"},
"invalidate":	{"VB","NN"},
"invalidated":	{"VBD","VBN"},
"invalidates":	{"VBZ"},
"invalidating":	{"VBG"},
"invalidation":	{"NN"},
"invalidator":	{"NN"},
"invalided":	{"VBD","VBN"},
"invaliding":	{"VBG"},
"invalidism":	{"NN"},
"invalidity":	{"NN"},
"invalidness":	{"NN"},
"invalids":	{"NNS","VBZ"},
"invaluable":	{"JJ"},
"invaluableness":	{"NN"},
"invar":	{"NN"},
"invariability":	{"NN"},
"invariable":	{"JJ"},
"invariableness":	{"NN"},
"invariably":	{"RB"},
"invariance":	{"NN"},
"invariant":	{"JJ","NN"},
"invasion":	{"NN"},
"invasion-theory":	{"NN"},
"invasions":	{"NNS"},
"invasive":	{"JJ"},
"invective":	{"NN"},
"inveigh":	{"VB","VBP"},
"inveighed":	{"VBD","VBN"},
"inveighing":	{"VBG"},
"inveighs":	{"VBZ"},
"inveigle":	{"VB","VBP"},
"inveigled":	{"VBD","VBN"},
"inveigles":	{"VBZ"},
"inveigling":	{"VBG"},
"invent":	{"VB","VBP"},
"invented":	{"VBD","VBN"},
"inventing":	{"VBG"},
"invention":	{"NN"},
"inventions":	{"NNS"},
"inventive":	{"JJ"},
"inventively":	{"RB"},
"inventiveness":	{"NN"},
"inventor":	{"NN"},
"inventoried":	{"VBD","VBN"},
"inventories":	{"NNS","VBZ"},
"inventors":	{"NNS"},
"inventory":	{"NN","VB","VBP"},
"inventorying":	{"VBG"},
"invents":	{"VBZ"},
"inveracious":	{"JJ"},
"inverse":	{"NN","JJ"},
"inversely":	{"RB"},
"inversion":	{"NN"},
"inversions":	{"NNS"},
"invert":	{"VB","VBP"},
"invertase":	{"NN"},
"invertebrate":	{"NN","JJ"},
"invertebrates":	{"NNS"},
"inverted":	{"JJ","VBD","VBN"},
"inverter":	{"NN"},
"invertible":	{"JJ"},
"inverting":	{"VBG"},
"inverts":	{"VBZ"},
"invest":	{"VB","VBP"},
"investable":	{"JJ"},
"invested":	{"VBN","VBD"},
"investigate":	{"VB","VBP"},
"investigated":	{"VBN","VBD"},
"investigates":	{"VBZ"},
"investigating":	{"VBG"},
"investigation":	{"NN"},
"investigational":	{"JJ"},
"investigations":	{"NNS"},
"investigative":	{"JJ"},
"investigative-reporting":	{"NN"},
"investigator":	{"NN"},
"investigators":	{"NNS"},
"investigatory":	{"JJ","NN"},
"investing":	{"VBG","NN","JJ"},
"investiture":	{"NN"},
"investitures":	{"NNS"},
"investment":	{"NN"},
"investment-advisory":	{"NN"},
"investment-area":	{"JJ"},
"investment-bank":	{"NN"},
"investment-banker":	{"NN"},
"investment-bankers":	{"NNS"},
"investment-banking":	{"NN"},
"investment-banks":	{"NNS"},
"investment-counseling":	{"JJ"},
"investment-grade":	{"JJ","NN"},
"investment-holding":	{"JJ"},
"investment-house":	{"NN"},
"investment-insurance":	{"NN"},
"investment-linked":	{"JJ"},
"investment-management":	{"NN","JJ"},
"investment-newsletter":	{"NN"},
"investment-oriented":	{"JJ"},
"investment-promotion":	{"NN"},
"investment-recovery":	{"NN"},
"investment-tax":	{"JJ"},
"investments":	{"NNS"},
"investor":	{"NN"},
"investor-owned":	{"JJ"},
"investor-relations":	{"NNS","JJ"},
"investors":	{"NNS"},
"invests":	{"VBZ"},
"inveterate":	{"JJ"},
"invidia":	{"NN"},
"invidious":	{"JJ"},
"invidiously":	{"RB"},
"invigilate":	{"VB"},
"invigilation":	{"NN"},
"invigilator":	{"NN"},
"invigilators":	{"NNS"},
"invigorate":	{"VB","VBP"},
"invigorated":	{"VBD","VBN"},
"invigorates":	{"VBZ"},
"invigorating":	{"JJ","VBG"},
"invigoration":	{"NN"},
"invigorator":	{"NN"},
"invincibility":	{"NN"},
"invincible":	{"JJ"},
"invincibly":	{"RB"},
"inviolability":	{"NN"},
"inviolable":	{"JJ"},
"inviolate":	{"JJ"},
"invirase":	{"NN"},
"invisibility":	{"NN"},
"invisible":	{"JJ"},
"invisibleness":	{"NN"},
"invisibles":	{"NNS"},
"invisibly":	{"RB"},
"invitation":	{"NN"},
"invitational":	{"JJ"},
"invitations":	{"NNS"},
"invitatory":	{"JJ"},
"invite":	{"VB","NN","VBP"},
"invited":	{"VBN","VBD"},
"invitee":	{"NN"},
"invitees":	{"NNS"},
"invites":	{"VBZ","NNS"},
"inviting":	{"VBG","JJ"},
"invitingly":	{"RB"},
"invocation":	{"NN"},
"invocations":	{"NNS"},
"invoice":	{"NN","VB","VBP"},
"invoiced":	{"VBD","VBN"},
"invoices":	{"NNS","VBZ"},
"invoicing":	{"VBG","NN"},
"invoke":	{"VB","VBP"},
"invoked":	{"VBD","VBN"},
"invokes":	{"VBZ"},
"invoking":	{"VBG"},
"involucrate":	{"JJ"},
"involucre":	{"NN"},
"involuntarily":	{"RB"},
"involuntariness":	{"NN"},
"involuntary":	{"JJ"},
"involuntary-control":	{"JJ"},
"involute":	{"JJ"},
"involution":	{"NN"},
"involutions":	{"NNS"},
"involutorial":	{"JJ"},
"involve":	{"VB","VBP"},
"involved":	{"VBN","VBD","JJ"},
"involvement":	{"NN"},
"involvements":	{"NNS"},
"involves":	{"VBZ"},
"involving":	{"VBG"},
"invulnerability":	{"NN"},
"invulnerable":	{"JJ"},
"inward":	{"RB","JJ"},
"inward-developing":	{"JJ"},
"inward-looking":	{"JJ"},
"inward-moving":	{"JJ"},
"inwardly":	{"RB"},
"inwardness":	{"NN"},
"inwards":	{"RB"},
"inweave":	{"VB","VBP"},
"inweaved":	{"VBD","VBN"},
"inweaves":	{"VBZ"},
"inweaving":	{"VBG"},
"inwove":	{"VBD"},
"inwoven":	{"VBN"},
"inwrought":	{"JJ"},
"io":	{"NN"},
"iocs":	{"NN"},
"iocsixf":	{"NN"},
"iocsixg":	{"NN"},
"iodide":	{"NN"},
"iodide-concentrating":	{"JJ"},
"iodin":	{"NN"},
"iodinate":	{"VB","VBP"},
"iodinated":	{"VBD","VBN"},
"iodinates":	{"VBZ"},
"iodinating":	{"VBG"},
"iodination":	{"NN"},
"iodine":	{"NN"},
"iodine-125":	{"NN"},
"iodine-131":	{"NN"},
"iodise":	{"VB","VBP"},
"iodised":	{"VBD","VBN"},
"iodises":	{"VBZ"},
"iodising":	{"VBG"},
"iodize":	{"VB","VBP"},
"iodized":	{"VBD","VBN"},
"iodizes":	{"VBZ"},
"iodizing":	{"VBG"},
"iodoamino":	{"NN"},
"iodochlorhydroxyquin":	{"NN"},
"iodocompound":	{"NN"},
"iodocompounds":	{"NNS"},
"iodoform":	{"NN"},
"iodoprotein":	{"NN"},
"iodopsin":	{"NN"},
"iodothyronine":	{"NN"},
"iodothyronines":	{"NNS"},
"iodotyrosine":	{"NN"},
"iodotyrosines":	{"NNS"},
"iol":	{"NN"},
"ion":	{"NN"},
"ionate":	{"VB"},
"ionesco":	{"NN"},
"ionia":	{"NN"},
"ionian":	{"JJ","NN"},
"ionic":	{"JJ","NN"},
"ionisation":	{"NN"},
"ionise":	{"VB","VBP"},
"ionised":	{"VBD","VBN"},
"ionises":	{"VBZ"},
"ionising":	{"VBG"},
"ionization":	{"NN"},
"ionize":	{"VB","VBP"},
"ionized":	{"VBD","VBN"},
"ionizes":	{"VBZ"},
"ionizing":	{"VBG"},
"ionophoresis":	{"NN"},
"ionosphere":	{"NN"},
"ions":	{"NNS"},
"iontophoresis":	{"NN"},
"iontotherapy":	{"NN"},
"iop":	{"NN"},
"iota":	{"NN"},
"iowa-based":	{"JJ"},
"ioway":	{"NN"},
"ip":	{"NN"},
"ipecac":	{"NN"},
"iphigenia":	{"NN"},
"ipidae":	{"NN"},
"ipilimumab":	{"NN"},
"ipod":	{"NN"},
"ipomoea":	{"NN"},
"iproclozide":	{"NN"},
"ipsedixitism":	{"NN"},
"ipsilateral":	{"JJ"},
"ipso":	{"RB"},
"ipsus":	{"NNS"},
"ipv":	{"NN"},
"ir":	{"NN"},
"ira-plus":	{"NNS"},
"irak":	{"NN"},
"iraki":	{"JJ","NN"},
"irani":	{"NN"},
"iranian-backed":	{"JJ"},
"irascibility":	{"NN"},
"irascible":	{"JJ"},
"irate":	{"JJ"},
"irately":	{"RB"},
"ire":	{"NN"},
"ireful":	{"JJ"},
"irelander":	{"NN"},
"irena":	{"NN"},
"irenaeus":	{"NNS"},
"irene":	{"NN"},
"irenic":	{"JJ"},
"irenidae":	{"NN"},
"iresine":	{"NN"},
"iridaceae":	{"NN"},
"iridaceous":	{"JJ"},
"iridectomy":	{"NN"},
"iridesce":	{"VB","VBP"},
"iridesced":	{"VBD","VBN"},
"iridescence":	{"NN"},
"iridescent":	{"JJ"},
"iridesces":	{"VBZ"},
"iridescing":	{"VBG"},
"iridic":	{"JJ"},
"iridium":	{"NN"},
"iridocyclitis":	{"NNS"},
"iridokeratitis":	{"NNS"},
"iridoncus":	{"NN"},
"iridoprocne":	{"NN"},
"iridosmine":	{"NN"},
"iridotomy":	{"NN"},
"iris":	{"NN"},
"irises":	{"NNS"},
"irish-made":	{"JJ"},
"irish-soviet":	{"JJ"},
"iritic":	{"JJ"},
"iritis":	{"NN"},
"irk":	{"VB","VBP"},
"irked":	{"VBD","VBN","JJ"},
"irking":	{"VBG"},
"irks":	{"VBZ"},
"irksome":	{"JJ"},
"iron":	{"JJ","NN","VB","VBP"},
"iron-casting":	{"JJ"},
"iron-clad":	{"JJ"},
"iron-gray":	{"JJ"},
"iron-grey":	{"JJ"},
"iron-handed":	{"JJ"},
"iron-ore":	{"NN"},
"iron-poor":	{"JJ"},
"iron-rod":	{"JJ"},
"iron-shod":	{"JJ"},
"iron-tree":	{"NN"},
"iron-willed":	{"JJ"},
"ironclad":	{"JJ","NN"},
"ironed":	{"VBD","VBN"},
"ironfist":	{"NN"},
"ironic":	{"JJ"},
"ironical":	{"JJ"},
"ironically":	{"RB"},
"ironies":	{"NNS"},
"ironing":	{"NN","VBG"},
"ironist":	{"NN"},
"ironlike":	{"JJ"},
"ironman":	{"NN"},
"ironmonger":	{"NN"},
"ironmongers":	{"NNS"},
"ironmongery":	{"NN"},
"irons":	{"NNS","VBZ"},
"ironshod":	{"JJ"},
"ironside":	{"NN"},
"ironsides":	{"NNS"},
"ironware":	{"NN"},
"ironweed":	{"NN"},
"ironwood":	{"NN"},
"ironwork":	{"NN"},
"ironworker":	{"NN"},
"ironworks":	{"NN"},
"irony":	{"NN"},
"irradiate":	{"VB","VBP"},
"irradiated":	{"VBD","VBN"},
"irradiates":	{"VBZ"},
"irradiating":	{"VBG"},
"irradiation":	{"NN"},
"irrational":	{"JJ"},
"irrationality":	{"NN"},
"irrationally":	{"RB"},
"irrawaddy":	{"NN"},
"irreality":	{"NN"},
"irreclaimable":	{"JJ"},
"irreconcilable":	{"JJ"},
"irrecoverable":	{"JJ"},
"irredeemable":	{"JJ"},
"irredeemably":	{"RB"},
"irredenta":	{"NN"},
"irredentism":	{"NN"},
"irredentist":	{"NN"},
"irreducible":	{"JJ"},
"irrefutable":	{"JJ"},
"irregardless":	{"RB"},
"irregular":	{"JJ","NN"},
"irregularities":	{"NNS"},
"irregularity":	{"NN"},
"irregularly":	{"RB"},
"irregulars":	{"NNS"},
"irrelevance":	{"NN"},
"irrelevances":	{"NNS"},
"irrelevancies":	{"NNS"},
"irrelevancy":	{"NN"},
"irrelevant":	{"JJ"},
"irrelevantly":	{"RB"},
"irreligion":	{"NN"},
"irreligionist":	{"NN"},
"irreligious":	{"JJ"},
"irreligiousness":	{"NN"},
"irremediable":	{"JJ"},
"irremovable":	{"JJ"},
"irreparable":	{"JJ"},
"irreparably":	{"RB"},
"irreplaceable":	{"JJ"},
"irreplaceableness":	{"NN"},
"irrepressibility":	{"NN"},
"irrepressible":	{"JJ"},
"irreproachable":	{"JJ"},
"irreproachably":	{"RB"},
"irreproducibility":	{"NN"},
"irreproducible":	{"JJ"},
"irresistable":	{"JJ"},
"irresistibility":	{"NN"},
"irresistible":	{"JJ"},
"irresistibleness":	{"NN"},
"irresistibly":	{"RB"},
"irresolute":	{"JJ"},
"irresolutely":	{"RB"},
"irresoluteness":	{"NN"},
"irresolution":	{"NN"},
"irresolvable":	{"JJ"},
"irrespective":	{"RB"},
"irresponsibility":	{"NN"},
"irresponsible":	{"JJ"},
"irresponsibleness":	{"NN"},
"irresponsibly":	{"RB"},
"irretrievable":	{"JJ"},
"irretrievably":	{"RB"},
"irreverence":	{"NN"},
"irreverent":	{"JJ"},
"irreverently":	{"RB"},
"irreversibility":	{"NN"},
"irreversible":	{"JJ"},
"irreversibly":	{"RB"},
"irrevocable":	{"JJ"},
"irrevocably":	{"RB"},
"irrevokable":	{"JJ"},
"irridenta":	{"NN"},
"irridentism":	{"NN"},
"irridentist":	{"NN"},
"irrigate":	{"VB","VBP"},
"irrigated":	{"VBD","VBN"},
"irrigates":	{"VBZ"},
"irrigating":	{"VBG"},
"irrigation":	{"NN"},
"irritability":	{"NN"},
"irritable":	{"JJ"},
"irritably":	{"RB"},
"irritant":	{"NN","JJ"},
"irritants":	{"NNS"},
"irritate":	{"VB","VBP"},
"irritated":	{"JJ","VBD","VBN"},
"irritates":	{"VBZ"},
"irritating":	{"JJ","VBG"},
"irritatingly":	{"RB"},
"irritation":	{"NN"},
"irritations":	{"NNS"},
"irritative":	{"JJ"},
"irrupt":	{"VB","VBP"},
"irrupted":	{"VBD","VBN"},
"irrupting":	{"VBG"},
"irruption":	{"NN"},
"irruptions":	{"NNS"},
"irruptive":	{"JJ"},
"irrupts":	{"VBZ"},
"irs-hhs":	{"JJ"},
"irtish":	{"NN"},
"irtysh":	{"NN"},
"irula":	{"NN"},
"irv":	{"NN"},
"irvingia":	{"NN"},
"irwin":	{"NN"},
"is":	{"VBZ"},
"isabel":	{"NN"},
"isabella":	{"NN"},
"isabelle":	{"NN"},
"isarithm":	{"NN"},
"isatis":	{"NNS"},
"ischaemia":	{"NN"},
"ischaemic":	{"JJ"},
"ischemia":	{"NN"},
"ischemic":	{"JJ"},
"ischia":	{"NN"},
"ischigualastia":	{"NN"},
"ischium":	{"NN"},
"iself":	{"NN"},
"isentropic":	{"JJ"},
"isere":	{"NN"},
"iseult":	{"NN"},
"isfahan":	{"NN"},
"isherwood":	{"NN"},
"ishtar":	{"NN"},
"isi":	{"NN"},
"isinglass":	{"NN"},
"iskcon":	{"NN"},
"islamism":	{"NN"},
"islamophobia":	{"NN"},
"island":	{"NN","VB","VBP"},
"island-based":	{"JJ"},
"island-dweller":	{"NN"},
"island-fantasy":	{"JJ"},
"island-hopping":	{"NN"},
"islanded":	{"VBD","VBN"},
"islander":	{"NN"},
"islanders":	{"NNS"},
"islandia":	{"NN"},
"islanding":	{"VBG"},
"islands":	{"NNS","VBZ"},
"isle":	{"NN"},
"isles":	{"NNS"},
"islet":	{"NN"},
"islets":	{"NNS"},
"ism":	{"NN"},
"ismail":	{"NN"},
"ismaili":	{"JJ","NN"},
"ismailian":	{"NN"},
"ismailism":	{"NN"},
"isms":	{"NNS"},
"isn":	{"NN"},
"isoagglutination":	{"NN"},
"isoagglutinin":	{"NN"},
"isoagglutinogen":	{"NN"},
"isoantibody":	{"NN"},
"isobar":	{"NN"},
"isobars":	{"NNS"},
"isobilateral":	{"JJ"},
"isobutylene":	{"NN"},
"isocarboxazid":	{"NN"},
"isochronal":	{"JJ"},
"isochrone":	{"NN"},
"isochronous":	{"JJ"},
"isoclinal":	{"JJ","NN"},
"isoclinic":	{"JJ"},
"isocrates":	{"NNS"},
"isocyanate":	{"NN"},
"isocyanate-labeled":	{"NN"},
"isocyclic":	{"JJ"},
"isoetaceae":	{"NN"},
"isoetales":	{"NNS"},
"isoetes":	{"NNS"},
"isoflurane":	{"NN"},
"isogamete":	{"NN"},
"isogamy":	{"NN"},
"isogon":	{"NN"},
"isogone":	{"NN"},
"isogonic":	{"JJ"},
"isogram":	{"NN"},
"isohel":	{"NN"},
"isolable":	{"JJ"},
"isolate":	{"VB","VBP"},
"isolated":	{"VBN","JJ","VBD"},
"isolates":	{"VBZ"},
"isolating":	{"VBG"},
"isolation":	{"NN"},
"isolationism":	{"NN"},
"isolationist":	{"NN","JJ"},
"isolationistic":	{"JJ"},
"isolationists":	{"NNS"},
"isoleucine":	{"NN"},
"isomer":	{"NN"},
"isomerase":	{"NN"},
"isomeric":	{"JJ"},
"isomerisation":	{"NN"},
"isomerise":	{"VB","VBP"},
"isomerised":	{"VBD","VBN"},
"isomerises":	{"VBZ"},
"isomerising":	{"VBG"},
"isomerism":	{"NN"},
"isomerization":	{"NN"},
"isomerize":	{"VB","VBP"},
"isomerized":	{"VBD","VBN"},
"isomerizes":	{"VBZ"},
"isomerizing":	{"VBG"},
"isomers":	{"NNS"},
"isometric":	{"JJ"},
"isometrical":	{"JJ"},
"isometrics":	{"NNS"},
"isometropia":	{"NN"},
"isometry":	{"NN"},
"isomorphic":	{"JJ"},
"isomorphism":	{"NN"},
"isomorphous":	{"JJ"},
"isomorphy":	{"NN"},
"isoniazid":	{"NN"},
"isopleth":	{"NN"},
"isopleths":	{"NNS"},
"isopod":	{"NN"},
"isopoda":	{"NN"},
"isopropanol":	{"NN"},
"isoproterenol":	{"NN"},
"isoptera":	{"NN"},
"isopteran":	{"JJ"},
"isoptin":	{"NN"},
"isopyrum":	{"NN"},
"isordil":	{"NN"},
"isosceles":	{"JJ"},
"isosmotic":	{"JJ"},
"isosorbide":	{"NN"},
"isospondyli":	{"NN"},
"isostasy":	{"NN"},
"isotherm":	{"NN"},
"isothermal":	{"JJ"},
"isothermally":	{"RB"},
"isothermic":	{"JJ"},
"isotherms":	{"NNS"},
"isothiocyanate":	{"NN"},
"isotonic":	{"JJ"},
"isotope":	{"NN"},
"isotopes":	{"NNS"},
"isotopic":	{"JJ","NN"},
"isotropic":	{"JJ"},
"isotropically":	{"RB"},
"isotropous":	{"JJ"},
"isotropy":	{"NN"},
"israeli-born":	{"JJ"},
"israeli-occupied":	{"JJ"},
"issachar":	{"NN"},
"issuable":	{"JJ"},
"issuance":	{"NN"},
"issuances":	{"NNS"},
"issue":	{"NN","VB","VBP"},
"issued":	{"VBN","VBD"},
"issuer":	{"NN"},
"issuers":	{"NNS"},
"issues":	{"NNS","VBZ"},
"issues-such":	{"JJ"},
"issuing":	{"VBG"},
"issus":	{"NN"},
"ist":	{"FW"},
"istel-type":	{"JJ"},
"isthmian":	{"JJ","NN"},
"isthmus":	{"NN"},
"isthmuses":	{"NNS"},
"istiophoridae":	{"NN"},
"istiophorus":	{"NN"},
"istiqlal-sponsored":	{"JJ"},
"isuprel":	{"NN"},
"isuridae":	{"NN"},
"isurus":	{"NN"},
"it":	{"PRP"},
"it-wit":	{"NN"},
"ital":	{"NN"},
"italian-based":	{"JJ"},
"italian-cut":	{"JJ"},
"italian-led":	{"JJ"},
"italian-made":	{"JJ"},
"italian-speaking":	{"JJ"},
"italian-style":	{"JJ"},
"italic":	{"JJ"},
"italicise":	{"VB","VBP"},
"italicised":	{"VBD","VBN","JJ"},
"italicises":	{"VBZ"},
"italicising":	{"VBG"},
"italicize":	{"VB","VBP"},
"italicized":	{"VBD","VBN","JJ"},
"italicizes":	{"VBZ"},
"italicizing":	{"VBG"},
"italics":	{"NNS"},
"italtel":	{"NN"},
"itch":	{"NN","VB","VBP"},
"itched":	{"VBD","VBN"},
"itches":	{"NNS","VBZ"},
"itchiness":	{"NN"},
"itching":	{"NN","JJ","VBG"},
"itchy":	{"JJ"},
"item":	{"NN","RB"},
"item-by-item":	{"JJ"},
"item-processing":	{"JJ"},
"itemisation":	{"NN"},
"itemise":	{"VB","VBP"},
"itemised":	{"VBD","VBN"},
"itemises":	{"VBZ"},
"itemising":	{"VBG"},
"itemization":	{"NN"},
"itemize":	{"VB","VBP"},
"itemized":	{"VBD","VBN"},
"itemizes":	{"VBZ"},
"itemizing":	{"VBG"},
"items":	{"NNS"},
"iterate":	{"VB","VBP"},
"iterated":	{"VBD","VBN"},
"iterates":	{"VBZ"},
"iterating":	{"VBG"},
"iteration":	{"NN"},
"iterations":	{"NNS"},
"iterative":	{"JJ"},
"ithaki":	{"NN"},
"ithunn":	{"NN"},
"itinerant":	{"JJ","NN"},
"itinerants":	{"NNS"},
"itineraries":	{"NNS"},
"itinerary":	{"NN"},
"itinerate":	{"VB","VBP"},
"itinerated":	{"VBD","VBN"},
"itinerates":	{"VBZ"},
"itinerating":	{"VBG"},
"itineration":	{"NN"},
"itraconazole":	{"NN"},
"its":	{"PRP$","PRP"},
"itself":	{"PRP"},
"itsy-bitsy":	{"JJ"},
"itty-bitty":	{"JJ"},
"ity":	{"NN"},
"iuvabit":	{"FW"},
"iv":	{"SYM"},
"iv-drug-free":	{"JJ"},
"iva":	{"NN"},
"ivanov":	{"NN"},
"ivied":	{"JJ"},
"ivories":	{"NNS"},
"ivory":	{"NN"},
"ivory-inlay":	{"NN"},
"ivory-tower":	{"NN"},
"ivorybill":	{"NN"},
"ivp":	{"NN"},
"ivry":	{"NN"},
"ivy":	{"NN"},
"ivy-covered":	{"JJ"},
"iw":	{"NN"},
"iwo":	{"NN"},
"iww":	{"NN"},
"ix":	{"JJ","NN"},
"ixc":	{"JJ"},
"ixia":	{"NN"},
"ixl":	{"JJ"},
"ixobrychus":	{"NNS"},
"ixodes":	{"NNS"},
"ixodid":	{"NN"},
"ixodidae":	{"NN"},
"iyar":	{"NN"},
"iyyar":	{"NN"},
"izanagi":	{"NN"},
"izanami":	{"NN"},
"izar":	{"NN"},
"izard":	{"NN"},
"izmir":	{"NN"},
"izzard":	{"NN"},
"j":	{"NN","SYM","LS"},
"jab":	{"NN","VB","VBP"},
"jabalpur":	{"NN"},
"jabbed":	{"VBD","VBN"},
"jabber":	{"VB","VBP","NN"},
"jabbered":	{"VBD","VBN"},
"jabberer":	{"NN"},
"jabbering":	{"VBG"},
"jabberings":	{"NNS"},
"jabbers":	{"VBZ"},
"jabberwocky":	{"NN"},
"jabbing":	{"VBG"},
"jabiru":	{"NN"},
"jaboncillo":	{"NN"},
"jabot":	{"NN"},
"jaboticaba":	{"NN"},
"jabs":	{"NNS","VBZ"},
"jacamar":	{"NN"},
"jacaranda":	{"NN"},
"jacinth":	{"NN"},
"jack":	{"NN","VB","VBP"},
"jack-a-lantern":	{"NN"},
"jack-an-apes":	{"NNS"},
"jack-by-the-hedge":	{"NN"},
"jack-in-the-box":	{"NN"},
"jack-in-the-boxes":	{"NNS"},
"jack-in-the-pulpit":	{"NN"},
"jack-o'-lantern":	{"NN"},
"jack-o-lantern":	{"NN"},
"jack-of-all-trades":	{"NN"},
"jack-tar":	{"NN"},
"jackal":	{"NN"},
"jackals":	{"NNS"},
"jackanapes":	{"NN","NNS"},
"jackass":	{"NN"},
"jackasses":	{"NNS"},
"jackboot":	{"NN"},
"jackbooted":	{"JJ"},
"jackboots":	{"NNS"},
"jackdaw":	{"NN"},
"jackdaws":	{"NNS"},
"jacked":	{"VBD","VBN"},
"jacket":	{"NN","VB","VBP"},
"jacketed":	{"VBN","VBD"},
"jacketing":	{"VBG"},
"jackets":	{"NNS","VBZ"},
"jackfruit":	{"NN"},
"jackhammer":	{"NN"},
"jackhammers":	{"NNS"},
"jacking":	{"VBG"},
"jackknife":	{"NN"},
"jackknife-fish":	{"NN"},
"jacklight":	{"NN","VB","VBP"},
"jackpot":	{"NN"},
"jackpots":	{"NNS"},
"jackrabbit":	{"NN"},
"jackrabbits":	{"NNS"},
"jacks":	{"NNS","VBZ"},
"jacks-of-all-trades":	{"NNS"},
"jackscrew":	{"NN"},
"jacksmelt":	{"NN"},
"jacksnipe":	{"NN"},
"jackson-vanick":	{"JJ"},
"jacksonia":	{"NN"},
"jackstone":	{"NN"},
"jackstones":	{"NNS"},
"jackstraw":	{"NN"},
"jackstraws":	{"NNS"},
"jacobi":	{"NN"},
"jacobinic":	{"JJ"},
"jacobinical":	{"JJ"},
"jaconet":	{"NN"},
"jacquard":	{"NN"},
"jacquelyn":	{"NN"},
"jacquinia":	{"NN"},
"jactation":	{"NN"},
"jactitation":	{"NN"},
"jaculus":	{"NN"},
"jade":	{"NN","VB","VBP"},
"jade-green":	{"JJ"},
"jade-handled":	{"JJ"},
"jaded":	{"JJ","VBD","VBN"},
"jadeite":	{"NN"},
"jades":	{"VBZ"},
"jadestone":	{"NN"},
"jading":	{"VBG"},
"jaeger":	{"NN"},
"jafar":	{"NN"},
"jaffa":	{"NN"},
"jaffar":	{"NN"},
"jag":	{"NN","VB","VBP"},
"jagannath":	{"NN"},
"jagannatha":	{"NN"},
"jagatai":	{"NN"},
"jagganath":	{"NN"},
"jaggary":	{"NN"},
"jagged":	{"JJ","VBD","VBN"},
"jaggedly":	{"RB"},
"jaggedness":	{"NN"},
"jagger":	{"NN"},
"jaggery":	{"NN"},
"jagghery":	{"NN"},
"jagging":	{"VBG"},
"jaggy":	{"JJ"},
"jaghatai":	{"NN"},
"jags":	{"VBZ","NNS"},
"jagua":	{"NN"},
"jaguar":	{"NN"},
"jaguarondi":	{"NN"},
"jaguars":	{"NNS"},
"jaguarundi":	{"NN"},
"jahvey":	{"NN"},
"jahweh":	{"NN"},
"jai":	{"UH"},
"jail":	{"NN","VB","VBP"},
"jailbird":	{"NN"},
"jailbirds":	{"NNS"},
"jailbreak":	{"NN"},
"jailbreaks":	{"NNS"},
"jailed":	{"VBD","VBN"},
"jailer":	{"NN"},
"jailers":	{"NNS"},
"jailhouse":	{"NN"},
"jailhouses":	{"NNS"},
"jailing":	{"VBG"},
"jailor":	{"NN"},
"jails":	{"VBZ","NNS"},
"jain":	{"JJ"},
"jainist":	{"JJ","NN"},
"jaish-e-muhammad":	{"NN"},
"jaish-i-mohammed":	{"NN"},
"jak":	{"NN"},
"jakes":	{"NNS"},
"jakobson":	{"NN"},
"jalapeno":	{"NN"},
"jalapenos":	{"NNS"},
"jalopies":	{"NNS"},
"jalopy":	{"NN"},
"jalousie":	{"NN"},
"jam":	{"NN","VB","VBP"},
"jam-pack":	{"VB","VBP"},
"jam-packed":	{"JJ","VBD","VBN"},
"jam-packing":	{"VBG"},
"jam-packs":	{"VBZ"},
"jamb":	{"NN"},
"jambalaya":	{"NN"},
"jambeau":	{"NN"},
"jamberry":	{"NN"},
"jambon":	{"NN"},
"jamboree":	{"NN"},
"jamborees":	{"NNS"},
"jambos":	{"NN"},
"jambosa":	{"NN"},
"jambs":	{"NNS"},
"jamesonia":	{"NN"},
"jamison":	{"NN"},
"jamjar":	{"NN"},
"jammed":	{"JJ","VBD","VBN"},
"jammed-together":	{"JJ"},
"jammer":	{"NN"},
"jammies":	{"NNS"},
"jamming":	{"VBG","NN"},
"jampack":	{"VB","VBP"},
"jampacked":	{"JJ","VBD","VBN"},
"jampacking":	{"VBG"},
"jampacks":	{"VBZ"},
"jampan":	{"NN"},
"jampot":	{"NN"},
"jams":	{"NNS","VBZ"},
"jangle":	{"VB","VBP","NN"},
"jangled":	{"VBD","VBN"},
"janglers":	{"NNS"},
"jangles":	{"VBZ"},
"jangling":	{"VBG"},
"jangly":	{"JJ"},
"janissaries":	{"NNS"},
"janissary":	{"NN"},
"janitor":	{"NN"},
"janitors":	{"NNS"},
"jansen":	{"NN"},
"jansenism":	{"NN"},
"jansenist":	{"NN"},
"japan":	{"NN","VB","VBP"},
"japan-made":	{"JJ"},
"japanese-american":	{"JJ"},
"japanese-based":	{"JJ"},
"japanese-financed":	{"JJ"},
"japanese-made":	{"JJ"},
"japanese-managed":	{"JJ"},
"japanese-owned":	{"JJ"},
"japanese-speaking":	{"JJ"},
"japanese-style":	{"JJ"},
"japanese-supplied":	{"JJ"},
"japanese-type":	{"JJ"},
"japanned":	{"VBD","VBN"},
"japanning":	{"VBG"},
"japans":	{"VBZ"},
"jape":	{"NN"},
"japery":	{"NN"},
"japheth":	{"NN"},
"japonica":	{"NN"},
"jar":	{"NN","VB","VBP"},
"jardine":	{"NN"},
"jarful":	{"NN"},
"jargon":	{"NN","VB","VBP"},
"jargoned":	{"VBD","VBN"},
"jargoning":	{"VBG"},
"jargons":	{"VBZ"},
"jargoon":	{"NN"},
"jarred":	{"VBD","VBN"},
"jarrell":	{"NN"},
"jarring":	{"JJ","VBG"},
"jarringly":	{"RB"},
"jars":	{"VBZ","NNS"},
"jasmine":	{"NN"},
"jasmines":	{"NNS"},
"jasminum":	{"NN"},
"jasper":	{"NN"},
"jaspers":	{"NNS"},
"jassid":	{"NN"},
"jassidae":	{"NN"},
"jat":	{"NN"},
"jati":	{"NN"},
"jatropha":	{"NN"},
"jaundice":	{"NN","VB","VBP"},
"jaundiced":	{"JJ","VBD","VBN"},
"jaundices":	{"VBZ"},
"jaundicing":	{"VBG"},
"jaunt":	{"NN","VB","VBP"},
"jaunted":	{"VBD","VBN"},
"jauntier":	{"JJR"},
"jauntiest":	{"JJS"},
"jauntily":	{"RB"},
"jauntiness":	{"NN"},
"jaunting":	{"VBG"},
"jaunts":	{"VBZ","NNS"},
"jaunty":	{"JJ"},
"java":	{"NN"},
"javan":	{"JJ","NN"},
"javanthropus":	{"NNS"},
"javelin":	{"NN"},
"javelina":	{"NN"},
"javelins":	{"NNS"},
"javier":	{"NN"},
"jaw":	{"NN","VB","VBP"},
"jawan":	{"NN"},
"jawbone":	{"NN","VB","VBP"},
"jawboned":	{"VBD","VBN"},
"jawbones":	{"NNS","VBZ"},
"jawboning":	{"VBG"},
"jawbreaker":	{"NN"},
"jawbreakers":	{"NNS"},
"jawed":	{"VBD","VBN"},
"jawfish":	{"NN"},
"jawing":	{"VBG"},
"jawless":	{"JJ"},
"jaws":	{"NNS","VBZ"},
"jay":	{"NN"},
"jaybird":	{"NN"},
"jays":	{"NNS"},
"jayshullah":	{"NN"},
"jaywalk":	{"VB","VBP"},
"jaywalked":	{"VBD","VBN"},
"jaywalker":	{"NN"},
"jaywalkers":	{"NNS"},
"jaywalking":	{"NN","VBG"},
"jaywalks":	{"VBZ"},
"jazz":	{"NN","VB","VBP"},
"jazzed":	{"VBD","VBN"},
"jazzes":	{"VBZ"},
"jazzier":	{"JJR"},
"jazziest":	{"JJS"},
"jazzing":	{"VBG"},
"jazzman":	{"NN"},
"jazzmen":	{"NNS"},
"jazzy":	{"JJ"},
"jdam":	{"NN"},
"je":	{"NN"},
"jealous":	{"JJ"},
"jealousies":	{"NNS"},
"jealously":	{"RB"},
"jealousy":	{"NN"},
"jean":	{"NN"},
"jeans":	{"NNS"},
"jed'dah":	{"NN"},
"jeddah":	{"NN"},
"jedec":	{"NN"},
"jeep":	{"NN"},
"jeep-brand":	{"JJ"},
"jeep-like":	{"JJ"},
"jeeps":	{"NNS"},
"jeer":	{"VB","VBP","NN"},
"jeered":	{"VBD","VBN"},
"jeerer":	{"NN"},
"jeering":	{"JJ","NN","VBG"},
"jeeringly":	{"RB"},
"jeers":	{"NNS","VBZ"},
"jeffers":	{"NNS"},
"jehad":	{"NN"},
"jejune":	{"JJ"},
"jejunely":	{"RB"},
"jejuneness":	{"NN"},
"jejunitis":	{"NNS"},
"jejunity":	{"NN"},
"jejunoileitis":	{"NNS"},
"jejunostomy":	{"NN"},
"jejunum":	{"NN"},
"jell":	{"VB","VBP"},
"jellaba":	{"NN"},
"jelled":	{"VBD","VBN"},
"jellied":	{"JJ","VBD","VBN"},
"jellies":	{"NNS","VBZ"},
"jellified":	{"VBD","VBN"},
"jellifies":	{"VBZ"},
"jellify":	{"VB","VBP"},
"jellifying":	{"VBG"},
"jelling":	{"VBG"},
"jells":	{"VBZ"},
"jelly":	{"NN","VB","VBP"},
"jellyfish":	{"NN","NNS"},
"jellying":	{"VBG"},
"jellyleaf":	{"NN"},
"jellylike":	{"JJ"},
"jellyroll":	{"NN"},
"jem":	{"NN"},
"jemmied":	{"VBD","VBN"},
"jemmies":	{"NNS","VBZ"},
"jemmy":	{"NN","VB","VBP"},
"jemmying":	{"VBG"},
"jena":	{"NN"},
"jennet":	{"NN"},
"jenny":	{"NN"},
"jensen":	{"NN"},
"jeopardise":	{"VB","VBP"},
"jeopardised":	{"VBD","VBN"},
"jeopardises":	{"VBZ"},
"jeopardising":	{"VBG"},
"jeopardize":	{"VB","VBP"},
"jeopardized":	{"VBD","VBN"},
"jeopardizes":	{"VBZ"},
"jeopardizing":	{"VBG"},
"jeopardy":	{"NN"},
"jerboa":	{"NN"},
"jeremiad":	{"NN"},
"jerevan":	{"NN"},
"jerez":	{"NN"},
"jerk":	{"NN","VB","VBP"},
"jerk-off":	{"NN"},
"jerked":	{"VBD","VBN"},
"jerker":	{"NN"},
"jerkier":	{"JJR"},
"jerkiest":	{"JJS"},
"jerkily":	{"RB"},
"jerkin":	{"NN"},
"jerkiness":	{"NN"},
"jerking":	{"VBG"},
"jerkings":	{"NNS"},
"jerkins":	{"NNS"},
"jerks":	{"NNS","VBZ"},
"jerkwater":	{"JJ"},
"jerky":	{"JJ","NN"},
"jeroboam":	{"NN"},
"jerry":	{"NN"},
"jerry-build":	{"VB","VBP"},
"jerry-builder":	{"NN"},
"jerry-building":	{"NN","VBG"},
"jerry-builds":	{"VBZ"},
"jerry-built":	{"JJ","VBD","VBN"},
"jersey":	{"NN"},
"jersey-based":	{"JJ"},
"jerseys":	{"NNS"},
"jespersen":	{"NN"},
"jess":	{"NN","VB","VBP"},
"jessamine":	{"NN"},
"jessed":	{"VBD","VBN","JJ"},
"jesses":	{"NNS","VBZ"},
"jessing":	{"VBG"},
"jest":	{"NN","VB","VBP"},
"jested":	{"VBD","VBN"},
"jester":	{"NN"},
"jesting":	{"NN","JJ","VBG"},
"jestingly":	{"RB"},
"jests":	{"NNS","VBZ"},
"jesuitical":	{"JJ"},
"jesuitism":	{"NN"},
"jesuitry":	{"NN"},
"jet":	{"NN","VBP","VB"},
"jet-black":	{"JJ","NN"},
"jet-engine":	{"NN"},
"jet-engines":	{"NNS"},
"jet-propelled":	{"JJ"},
"jet-setter":	{"NN"},
"jet-setters":	{"NNS"},
"jeth":	{"NN"},
"jetliner":	{"NN"},
"jetliners":	{"NNS"},
"jetplane":	{"NN"},
"jets":	{"NNS","VBZ"},
"jetsam":	{"NN"},
"jetted":	{"VBD","VBN"},
"jetties":	{"NNS"},
"jetting":	{"VBG"},
"jettison":	{"VB","NN","VBP"},
"jettisoned":	{"VBD","VBN"},
"jettisoning":	{"VBG"},
"jettisons":	{"VBZ"},
"jetty":	{"NN"},
"jetway":	{"NN"},
"jeunes":	{"FW"},
"jevons":	{"NNS"},
"jew's-ear":	{"NN"},
"jew's-ears":	{"NNS"},
"jew-as-enemy":	{"NN"},
"jew-baiter":	{"NN"},
"jew-bush":	{"NN"},
"jew-haters":	{"NNS"},
"jewboy":	{"NN"},
"jewbush":	{"NN"},
"jewel":	{"NN","VB","VBP"},
"jewel-bright":	{"RB"},
"jeweled":	{"JJ","VBD","VBN"},
"jeweler":	{"NN"},
"jewelers":	{"NNS"},
"jewelery-related":	{"JJ"},
"jeweling":	{"VBG"},
"jewelled":	{"JJ","VBD","VBN"},
"jeweller":	{"NN"},
"jewellers":	{"NNS"},
"jewellery":	{"NN"},
"jewelling":	{"VBG"},
"jewelry":	{"NN"},
"jewels":	{"NNS","VBZ"},
"jewels-of-opar":	{"NN"},
"jewelweed":	{"NN"},
"jewess":	{"NN"},
"jewfish":	{"NN"},
"jewish-orthodox":	{"JJ"},
"jewison":	{"NN"},
"jhvh":	{"NN"},
"ji":	{"NN"},
"jiao":	{"NN"},
"jib":	{"NN","VBP","VB"},
"jibbed":	{"VBD","VBN"},
"jibbing":	{"VBG"},
"jibboom":	{"NN"},
"jibe":	{"NN","VB","VBP"},
"jibed":	{"VBD","VBN"},
"jibes":	{"VBZ","NNS"},
"jibing":	{"VBG"},
"jibs":	{"NNS","VBZ"},
"jidda":	{"NN"},
"jiddah":	{"NN"},
"jiffies":	{"NNS"},
"jiffy":	{"NN"},
"jig":	{"NN","VB","VBP"},
"jigaboo":	{"NN"},
"jigged":	{"VBD","VBN"},
"jigger":	{"NN"},
"jiggered":	{"JJ"},
"jiggermast":	{"NN"},
"jiggers":	{"NNS"},
"jiggery-pokery":	{"NN"},
"jigging":	{"VBG"},
"jiggle":	{"VB","VBP"},
"jiggled":	{"VBD","VBN"},
"jiggles":	{"VBZ"},
"jiggling":	{"VBG"},
"jigs":	{"NNS","VBZ"},
"jigsaw":	{"NN"},
"jigsaws":	{"NNS"},
"jihad":	{"NN"},
"jihadi":	{"JJ"},
"jihadist":	{"NN"},
"jill":	{"NN"},
"jillion":	{"NN","JJ"},
"jillions":	{"NNS"},
"jilt":	{"VB","VBP"},
"jilted":	{"VBD","VBN"},
"jilting":	{"VBG"},
"jilts":	{"VBZ"},
"jimdandy":	{"NN"},
"jimenez":	{"NN"},
"jimhickey":	{"NN"},
"jimmied":	{"VBD","VBN"},
"jimmies":	{"NNS","VBZ"},
"jimmy":	{"NN","VB","VBP"},
"jimmying":	{"VBG"},
"jimsonweed":	{"NN"},
"jin":	{"NN"},
"jinghpaw":	{"NN"},
"jinghpo":	{"NN"},
"jingle":	{"NN","VB","VBP"},
"jingled":	{"VBD","VBN"},
"jingles":	{"NNS","VBZ"},
"jingling":	{"VBG"},
"jingly":	{"JJ"},
"jingo":	{"NN"},
"jingoism":	{"NN"},
"jingoist":	{"NN"},
"jingoistic":	{"JJ"},
"jinja":	{"NN"},
"jink":	{"VB","VBP","NN"},
"jinked":	{"VBD","VBN"},
"jinking":	{"VBG"},
"jinks":	{"NNS","VBZ"},
"jinn":	{"NNS"},
"jinnee":	{"NN"},
"jinni":	{"NN"},
"jinrikisha":	{"NN"},
"jinx":	{"NN","VB","VBP"},
"jinxed":	{"JJ","VBD","VBN"},
"jinxes":	{"VBZ","NNS"},
"jinxing":	{"VBG"},
"jiqui":	{"NN"},
"jird":	{"NN"},
"jirga":	{"NN"},
"jirrbal":	{"NN"},
"jist":	{"RB"},
"jitney":	{"NN"},
"jitter":	{"VB","VBP"},
"jitterbug":	{"NN","VB","VBP"},
"jitterbuged":	{"VBD","VBN"},
"jitterbuging":	{"VBG"},
"jitterbugs":	{"VBZ"},
"jittered":	{"VBD","VBN"},
"jitteriness":	{"NN"},
"jittering":	{"VBG"},
"jitters":	{"NNS","VBZ"},
"jittery":	{"JJ"},
"jiu-jitsu":	{"FW"},
"jiujitsu":	{"NN"},
"jive":	{"NN","VB","VBP"},
"jived":	{"VBD","VBN"},
"jives":	{"VBZ"},
"jiving":	{"VBG"},
"jnd":	{"NN"},
"joachim":	{"NN"},
"job":	{"NN","VB","VBP"},
"job-bias":	{"JJ"},
"job-boosters":	{"NNS"},
"job-classification":	{"NN"},
"job-destroying":	{"JJ"},
"job-hunters":	{"NNS"},
"job-hunting":	{"JJ"},
"job-rating":	{"JJ"},
"job-seekers":	{"NNS"},
"job-training":	{"NN"},
"jobbed":	{"VBD","VBN"},
"jobber":	{"NN"},
"jobbers":	{"NNS"},
"jobbery":	{"NN"},
"jobbing":	{"VBG","JJ"},
"jobcentre":	{"NN"},
"jobholder":	{"NN"},
"jobless":	{"JJ"},
"joblessness":	{"NN"},
"joblot":	{"NN"},
"jobs":	{"NNS","VBZ"},
"jobs-tears":	{"NNS"},
"jobseeker":	{"NN"},
"jobseekers":	{"NNS"},
"jocasta":	{"NN"},
"jock":	{"NN"},
"jockey":	{"VB","VBP","NN"},
"jockeyed":	{"VBD","VBN"},
"jockeying":	{"VBG","NN"},
"jockeys":	{"NNS","VBZ"},
"jocks":	{"NNS"},
"jockstrap":	{"NN"},
"jockstraps":	{"NNS"},
"jocose":	{"JJ"},
"jocosely":	{"RB"},
"jocoseness":	{"NN"},
"jocosity":	{"NN"},
"jocote":	{"NN"},
"jocular":	{"JJ"},
"jocularity":	{"NN"},
"jocularly":	{"RB"},
"jocund":	{"JJ"},
"jocundity":	{"NN"},
"jodhpur":	{"NN"},
"jodhpurs":	{"NNS"},
"joes":	{"NNS"},
"joewood":	{"NN"},
"joffre":	{"NN"},
"joffrey":	{"NN"},
"jog":	{"VB","VBP","NN"},
"jogged":	{"VBD","VBN"},
"jogger":	{"NN"},
"joggers":	{"NNS"},
"jogging":	{"NN","VBG"},
"joggle":	{"NN","VB","VBP"},
"joggled":	{"VBD","VBN"},
"joggles":	{"VBZ"},
"joggling":	{"VBG"},
"jogjakarta":	{"NN"},
"jogs":	{"VBZ","NNS"},
"john":	{"NN"},
"johnnies":	{"NNS"},
"johnny":	{"NN"},
"johnny-jump-up":	{"NN"},
"johnnycake":	{"NN"},
"johns":	{"NNS"},
"johnson-era":	{"NN"},
"joie":	{"NN"},
"join":	{"VB","NN","VBP"},
"joined":	{"VBD","VBN"},
"joiner":	{"NN"},
"joiners":	{"NNS"},
"joinery":	{"NN"},
"joining":	{"VBG"},
"joins":	{"VBZ","NNS"},
"joint":	{"JJ","NN","VB","VBP"},
"joint-implants":	{"NNS"},
"joint-production":	{"JJ"},
"joint-research":	{"JJ"},
"joint-return":	{"JJ"},
"joint-venture":	{"JJ","NN"},
"joint-venturing":	{"NN"},
"jointed":	{"JJ","VBD","VBN"},
"jointer":	{"NN"},
"jointing":	{"VBG"},
"jointly":	{"RB"},
"joints":	{"VBZ","NNS"},
"jointure":	{"NN"},
"jointworm":	{"NN"},
"joist":	{"NN"},
"joists":	{"NNS"},
"joke":	{"NN","VBP","VB"},
"joked":	{"VBD","VBN"},
"joker":	{"NN"},
"jokers":	{"NNS"},
"jokes":	{"NNS","VBZ"},
"jokester":	{"NN"},
"joking":	{"VBG"},
"jokingly":	{"RB"},
"joliot":	{"NN"},
"joliot-curie":	{"NN"},
"jollied":	{"VBD","VBN"},
"jollier":	{"JJR"},
"jollies":	{"VBZ"},
"jolliest":	{"JJS"},
"jolliet":	{"NN"},
"jollification":	{"NN"},
"jollified":	{"VBD","VBN"},
"jollifies":	{"VBZ"},
"jollify":	{"VB","VBP"},
"jollifying":	{"VBG"},
"jolliness":	{"NN"},
"jollity":	{"NN"},
"jolly":	{"JJ","RB","VB","VBP"},
"jollying":	{"VBG"},
"jolt":	{"NN","VB","VBP"},
"jolted":	{"VBD","VBN"},
"jolting":	{"JJ","VBG"},
"jolts":	{"VBZ","NNS"},
"jolty":	{"JJ"},
"jonesboro":	{"NN"},
"jong":	{"NN"},
"jongleur":	{"NN"},
"jonquil":	{"NN"},
"jonquils":	{"NNS"},
"jonron":	{"FW"},
"jook":	{"NN"},
"joppa":	{"NN"},
"jordan":	{"NN"},
"jordanella":	{"NN"},
"jorum":	{"NN"},
"josephus":	{"NN"},
"josh":	{"NN","VB","VBP"},
"joshed":	{"VBD","VBN"},
"joshes":	{"VBZ"},
"joshing":	{"VBG"},
"joss":	{"NN"},
"jostle":	{"VB","VBP"},
"jostled":	{"VBD","VBN"},
"jostles":	{"VBZ"},
"jostling":	{"VBG"},
"josue":	{"NN"},
"jot":	{"VB","VBP","NN"},
"jots":	{"VBZ"},
"jotted":	{"VBD","VBN"},
"jotter":	{"NN"},
"jotting":	{"NN","VBG"},
"jottings":	{"NNS"},
"jotun":	{"NN"},
"jotunn":	{"NN"},
"joule":	{"NN"},
"joules":	{"NNS"},
"jounce":	{"NN","VB","VBP"},
"jounced":	{"VBD","VBN"},
"jounces":	{"VBZ"},
"jouncing":	{"VBG"},
"journal":	{"NN"},
"journalese":	{"NN"},
"journaling":	{"NN"},
"journalism":	{"NN"},
"journalist":	{"NN"},
"journalistic":	{"JJ"},
"journalistically":	{"RB"},
"journalists":	{"NNS"},
"journals":	{"NNS"},
"journey":	{"NN","VB","VBP"},
"journeyed":	{"VBD","VBN"},
"journeyer":	{"NN"},
"journeying":	{"VBG"},
"journeyman":	{"NN"},
"journeymen":	{"NNS"},
"journeys":	{"NNS","VBZ"},
"joust":	{"VB","VBP","NN"},
"jousted":	{"VBD","VBN"},
"jousting":	{"VBG","NN"},
"jousts":	{"VBZ","NNS"},
"jovial":	{"JJ"},
"joviality":	{"NN"},
"jovially":	{"RB"},
"jovian":	{"JJ"},
"jowett":	{"NN"},
"jowl":	{"NN"},
"jowls":	{"NNS"},
"jowly":	{"JJ"},
"joy":	{"NN","VBP","VB"},
"joyed":	{"VBD","VBN"},
"joyful":	{"JJ"},
"joyfully":	{"RB"},
"joyfulness":	{"NN"},
"joying":	{"VBG"},
"joyless":	{"JJ"},
"joylessly":	{"RB"},
"joylessness":	{"NN"},
"joyous":	{"JJ"},
"joyously":	{"RB"},
"joyousness":	{"NN"},
"joyride":	{"NN","VB","VBP"},
"joyrided":	{"VBD","VBN"},
"joyrider":	{"NN"},
"joyriders":	{"NNS"},
"joyrides":	{"VBZ"},
"joyriding":	{"VBG"},
"joys":	{"NNS","VBZ"},
"joystick":	{"NN"},
"joysticks":	{"NNS"},
"jra":	{"NN"},
"jsp-supported":	{"JJ"},
"jua":	{"FW"},
"juarez":	{"NN"},
"juarez-area":	{"NN"},
"jubbulpore":	{"NN"},
"jubilance":	{"NN"},
"jubilancy":	{"NN"},
"jubilant":	{"JJ"},
"jubilantly":	{"RB"},
"jubilate":	{"VB","VBP"},
"jubilated":	{"VBD","VBN"},
"jubilates":	{"VBZ"},
"jubilating":	{"VBG"},
"jubilation":	{"NN"},
"jubilee":	{"NN"},
"jubilees":	{"NNS"},
"juda":	{"NN"},
"judaea":	{"NN"},
"judaical":	{"JJ"},
"judder":	{"VB","VBP","NN"},
"juddered":	{"VBD","VBN"},
"juddering":	{"VBG"},
"judders":	{"VBZ","NNS"},
"judeo-christian":	{"JJ"},
"judeo-spanish":	{"NN"},
"judge":	{"NN","VB","VBP"},
"judge-made":	{"JJ"},
"judged":	{"VBN","VBD"},
"judgement":	{"NN"},
"judgements":	{"NNS"},
"judges":	{"NNS","VBZ"},
"judgeship":	{"NN"},
"judgeships":	{"NNS"},
"judging":	{"VBG","NN"},
"judgment":	{"NN"},
"judgment-proof":	{"JJ"},
"judgmental":	{"JJ"},
"judgments":	{"NNS"},
"judicable":	{"JJ"},
"judicata":	{"FW"},
"judicatory":	{"NN","JJ"},
"judicature":	{"NN"},
"judicial":	{"JJ"},
"judicial-bypass":	{"JJ"},
"judicial-conduct":	{"NN"},
"judicially":	{"RB"},
"judiciaries":	{"NNS"},
"judiciary":	{"NN"},
"judicious":	{"JJ"},
"judiciously":	{"RB"},
"judiciousness":	{"NN"},
"judo":	{"NN"},
"jug":	{"NN","VB","VBP"},
"jugale":	{"NN"},
"jugful":	{"NN"},
"jugged":	{"VBD","VBN"},
"juggernaut":	{"NN"},
"juggernauts":	{"NNS"},
"jugging":	{"VBG"},
"juggle":	{"VB","VBP"},
"juggled":	{"VBD","VBN"},
"juggler":	{"NN"},
"jugglers":	{"NNS"},
"jugglery":	{"NN"},
"juggles":	{"VBZ"},
"juggling":	{"NN","VBG"},
"juglandaceae":	{"NN"},
"juglandales":	{"NNS"},
"juglans":	{"NNS"},
"jugoslav":	{"NN"},
"jugoslavian":	{"NN"},
"jugoslavija":	{"NN"},
"jugs":	{"NNS","VBZ"},
"jugular":	{"JJ","NN"},
"jugulars":	{"NNS"},
"juice":	{"NN","VB","VBP"},
"juice-storage":	{"JJ"},
"juiced":	{"JJ","VBD","VBN"},
"juiceless":	{"JJ"},
"juicer":	{"NN"},
"juices":	{"VBZ","NNS"},
"juicier":	{"JJR"},
"juiciest":	{"JJS"},
"juiciness":	{"NN"},
"juicing":	{"VBG"},
"juicy":	{"JJ"},
"jujitsu":	{"NN"},
"juju":	{"NN"},
"jujube":	{"NN"},
"jujutsu":	{"NN"},
"juke":	{"NN"},
"juke-box":	{"NN"},
"jukebox":	{"NN"},
"jukeboxes":	{"NNS"},
"julep":	{"NN"},
"juleps":	{"NNS"},
"julienne":	{"NN","JJ"},
"july-september":	{"JJ"},
"jumbal":	{"NN"},
"jumble":	{"VB","VBP","NN"},
"jumbled":	{"JJ","VBD","VBN"},
"jumbles":	{"VBZ"},
"jumbling":	{"VBG"},
"jumbo":	{"JJ","NN"},
"jumbojet":	{"NN"},
"jumbos":	{"NNS"},
"jument":	{"NN"},
"jumentous":	{"JJ"},
"jump":	{"NN","VB","VBP"},
"jump-start":	{"VB","VBP"},
"jump-started":	{"VBD","VBN"},
"jump-starting":	{"VBG"},
"jump-starts":	{"VBZ"},
"jumped":	{"VBD","VBN"},
"jumped-up":	{"JJ"},
"jumper":	{"NN"},
"jumpers":	{"NNS"},
"jumpier":	{"JJR"},
"jumpiest":	{"JJS"},
"jumpiness":	{"NN"},
"jumping":	{"VBG"},
"jumping-off":	{"JJ"},
"jumps":	{"VBZ","NNS"},
"jumpstart":	{"VB","VBP"},
"jumpstarted":	{"VBD","VBN"},
"jumpstarting":	{"VBG"},
"jumpstarts":	{"VBZ"},
"jumpsuit":	{"NN"},
"jumpsuits":	{"NNS"},
"jumpy":	{"JJ"},
"juncaceae":	{"NN"},
"juncaginaceae":	{"NN"},
"junco":	{"NN"},
"junction":	{"NN"},
"junctions":	{"NNS"},
"juncture":	{"NN"},
"junctures":	{"NNS"},
"juncus":	{"NN"},
"jund-ul-islam":	{"NN"},
"juneberry":	{"NN"},
"jungermanniaceae":	{"NN"},
"jungermanniales":	{"NNS"},
"jungle":	{"NN"},
"jungles":	{"NNS"},
"jungly":	{"JJ"},
"junior":	{"JJ","NN"},
"junior-grade":	{"JJ"},
"junior-high":	{"JJ"},
"junior-philosophical":	{"JJ"},
"junior-senior":	{"JJ"},
"junior-year-abroad":	{"JJ"},
"juniors":	{"NNS"},
"juniper":	{"NN"},
"junipers":	{"NNS"},
"juniperus":	{"NN"},
"junk":	{"NN","VB","VBP"},
"junk-LBO":	{"JJ"},
"junk-bond":	{"NN"},
"junk-bond-financed":	{"JJ"},
"junk-bonds":	{"NNS"},
"junk-financed":	{"JJ"},
"junk-fund":	{"NN"},
"junk-holders":	{"NNS"},
"junk-lbo":	{"JJ"},
"junk-mail":	{"NN"},
"junk-market":	{"JJ","NN"},
"junk-portfolio":	{"NN"},
"junk-yard":	{"NN"},
"junkbond":	{"NN"},
"junkbond-financed":	{"JJ"},
"junked":	{"VBD","VBN"},
"junket":	{"NN","VB","VBP"},
"junketed":	{"VBD","VBN"},
"junketeer":	{"NN"},
"junketeering":	{"NN"},
"junketing":	{"NN","VBG"},
"junkets":	{"NNS","VBZ"},
"junkholders":	{"NNS"},
"junkie":	{"NN"},
"junkies":	{"NNS"},
"junkification":	{"NN"},
"junking":	{"VBG"},
"junkless":	{"JJ"},
"junkloads":	{"NNS"},
"junks":	{"VBZ","NNS"},
"junky":	{"NN"},
"junkyard":	{"NN"},
"junkyards":	{"NNS"},
"junta":	{"NN"},
"juntas":	{"NNS"},
"junto":	{"NN"},
"jupati":	{"NN"},
"jupaty":	{"NN"},
"jupiter-bound":	{"JJ"},
"jural":	{"JJ"},
"jure":	{"NN"},
"juridic":	{"JJ"},
"juridical":	{"JJ"},
"juries":	{"NNS"},
"jurisconsult":	{"NN"},
"jurisconsults":	{"NNS"},
"jurisdiction":	{"NN"},
"jurisdictional":	{"JJ"},
"jurisdictions":	{"NNS"},
"jurisprudence":	{"NN"},
"jurisprudential":	{"JJ"},
"jurisprudentially":	{"RB"},
"jurist":	{"NN"},
"juristic":	{"JJ"},
"jurists":	{"NNS"},
"juror":	{"NN"},
"jurors":	{"NNS"},
"jury":	{"NN"},
"jury-box":	{"NN"},
"jury-duty":	{"NN"},
"jury-rig":	{"VB","VBP","NN"},
"jury-rigged":	{"JJ","VBD","VBN"},
"jury-rigging":	{"VBG","NN"},
"jury-rigs":	{"VBZ","NNS"},
"jury-tampering":	{"JJ"},
"juryman":	{"NN"},
"jurywoman":	{"NN"},
"jussieu":	{"NN"},
"just":	{"RB","JJ"},
"just-announced":	{"JJ"},
"just-completed":	{"JJ"},
"just-concluded":	{"JJ"},
"just-departed":	{"JJ"},
"just-ended":	{"JJ"},
"just-in-time":	{"JJ"},
"just-picked":	{"JJ"},
"just-published":	{"JJ"},
"just-rejuvenated":	{"JJ"},
"just-revised":	{"JJ"},
"just-say-no":	{"JJ"},
"juste":	{"NN"},
"justice":	{"NN"},
"justices":	{"NNS"},
"justiciable":	{"JJ"},
"justicial":	{"JJ"},
"justiciar":	{"NN"},
"justiciary":	{"NN","JJ"},
"justifiable":	{"JJ"},
"justifiably":	{"RB"},
"justification":	{"NN"},
"justifications":	{"NNS"},
"justificative":	{"JJ"},
"justificatory":	{"JJ"},
"justified":	{"JJ","VBN","VBD"},
"justifiedly":	{"RB"},
"justifier":	{"NN"},
"justifies":	{"VBZ"},
"justify":	{"VB","VBP"},
"justifying":	{"VBG"},
"justitia":	{"NN"},
"justly":	{"RB"},
"justness":	{"NN"},
"jut":	{"VB","VBP","NN"},
"jute":	{"NN"},
"jutish":	{"NN"},
"juts":	{"VBZ"},
"jutted":	{"VBD","VBN"},
"jutting":	{"VBG","JJ"},
"juvenal":	{"NN"},
"juvenescence":	{"NN"},
"juvenile":	{"JJ","NN"},
"juveniles":	{"NNS"},
"juvenility":	{"NN"},
"juxtapose":	{"VB","VBP"},
"juxtaposed":	{"VBD","VBN"},
"juxtaposes":	{"VBZ"},
"juxtaposing":	{"VBG"},
"juxtaposition":	{"NN"},
"juxtapositions":	{"NNS"},
"jv":	{"NN"},
"jyaistha":	{"NN"},
"jylland":	{"NN"},
"jynx":	{"NN"},
"k":	{"NN","SYM","LS"},
"k-lor":	{"NN"},
"k-lyte":	{"NN"},
"k-meson":	{"NN"},
"k-resin":	{"NN"},
"k.e.":	{"NN"},
"k2":	{"NN"},
"kHz":	{"NN"},
"kNg":	{"NN"},
"kWh":	{"NN","NNS"},
"ka":	{"NN"},
"kaaba":	{"NN"},
"kabala":	{"NN"},
"kabbala":	{"NN"},
"kabbalah":	{"NN"},
"kabbalism":	{"NN"},
"kabbalist":	{"NN"},
"kabbalistic":	{"JJ"},
"kablooey":	{"UH"},
"kablooie":	{"UH"},
"kabob":	{"NN"},
"kabolin":	{"NN"},
"kaboom":	{"NN"},
"kach":	{"NN"},
"kachaturian":	{"NN"},
"kachin":	{"NN"},
"kachina":	{"NN"},
"kachinic":	{"NN"},
"kadai":	{"NN"},
"kadikoy":	{"NN"},
"kaffeeklatsch":	{"FW"},
"kaffir":	{"NN"},
"kaffiyeh":	{"NN"},
"kafir":	{"NN"},
"kafiri":	{"NN"},
"kafkaesque":	{"JJ"},
"kafocin":	{"NN"},
"kaftan":	{"NN"},
"kahikatea":	{"NN"},
"kahlua":	{"NN"},
"kahn":	{"NN"},
"kahoolawe":	{"NN"},
"kail":	{"NN"},
"kainite":	{"NN"},
"kainogenesis":	{"NN"},
"kakadu":	{"NN"},
"kakatoe":	{"NN"},
"kakemono":	{"NN"},
"kaki":	{"NN"},
"kal":	{"NN"},
"kala-azar":	{"NN"},
"kalamazoo":	{"NN"},
"kalansuwa":	{"NN"},
"kalantas":	{"NN"},
"kalapooia":	{"NN"},
"kalapooian":	{"NN"},
"kalapuya":	{"NN"},
"kalapuyan":	{"NN"},
"kale":	{"NN"},
"kalega":	{"NN"},
"kaleidoscope":	{"NN"},
"kaleidoscopes":	{"NNS"},
"kaleidoscopic":	{"JJ"},
"kaleidoscopical":	{"JJ"},
"kaleidoscopically":	{"RB"},
"kalemia":	{"NN"},
"kalian":	{"NN"},
"kalif":	{"NN"},
"kalimantan":	{"NN"},
"kalinin":	{"NN"},
"kaliph":	{"NN"},
"kaliuresis":	{"NN"},
"kalka":	{"NN"},
"kalki":	{"NN"},
"kalmia":	{"NN"},
"kalotermes":	{"NNS"},
"kalotermitidae":	{"NN"},
"kalpac":	{"NN"},
"kaluga":	{"NN"},
"kalumpang":	{"NN"},
"kaluresis":	{"NN"},
"kam-sui":	{"NN"},
"kam-tai":	{"NN"},
"kama":	{"NN"},
"kamarupan":	{"NN"},
"kamasutra":	{"NN"},
"kamba":	{"NN"},
"kameez":	{"NN"},
"kamet":	{"NN"},
"kami":	{"NN"},
"kamia":	{"NN"},
"kamikaze":	{"NN","JJ"},
"kampong":	{"NN"},
"kampuchean":	{"JJ","NN"},
"kan":	{"NN"},
"kanaf":	{"NN"},
"kanamycin":	{"NN"},
"kananga":	{"NN"},
"kanara":	{"NN"},
"kanarese":	{"NN"},
"kanawha":	{"NN"},
"kanchanjanga":	{"NN"},
"kanchil":	{"NN"},
"kandahar":	{"NN"},
"kandinski":	{"NN"},
"kandy":	{"NN"},
"kangaroo":	{"NN"},
"kangaroo's-foot":	{"NN"},
"kangaroo-committee":	{"NN"},
"kangaroos":	{"NNS"},
"kanji":	{"NN","NNS"},
"kannada":	{"NN"},
"kannada-speaking":	{"JJ"},
"kansa":	{"NN"},
"kansu":	{"NN"},
"kantrex":	{"NN"},
"kanzu":	{"NN"},
"kaochlor":	{"NN"},
"kaoliang":	{"NN"},
"kaolin":	{"NN"},
"kaoline":	{"NN"},
"kaolinite":	{"NN"},
"kaon":	{"NN"},
"kaopectate":	{"NN"},
"kapeika":	{"NN"},
"kaph":	{"NN"},
"kapok":	{"NN"},
"kapok-filled":	{"JJ"},
"kappa":	{"NN"},
"kappa-meson":	{"NN"},
"kapsiki":	{"NN"},
"kapuka":	{"NN"},
"kaput":	{"JJ"},
"karabiner":	{"NN"},
"karakalpak":	{"NN"},
"karakoram":	{"NN"},
"karakul":	{"NN"},
"karaoke":	{"NN"},
"karat":	{"NN"},
"karate":	{"NN"},
"karbala":	{"NN"},
"karelia":	{"NN"},
"karelian":	{"NN"},
"karen":	{"NN"},
"karenic":	{"NN"},
"karl-marx-stadt":	{"NN"},
"karlfeldt":	{"NN"},
"karma":	{"NN"},
"karmic":	{"JJ"},
"karnataka":	{"NN"},
"karok":	{"NN"},
"karol":	{"NN"},
"karpov":	{"NN"},
"karsavina":	{"NN"},
"kartik":	{"NN"},
"kartikeya":	{"NN"},
"karttika":	{"NN"},
"karttikeya":	{"NN"},
"karyokinesis":	{"NN"},
"karyokinetic":	{"JJ"},
"karyolymph":	{"NN"},
"karyolysis":	{"NN"},
"karyon":	{"NN"},
"karyoplasm":	{"NN"},
"karyotype":	{"NN"},
"kasai":	{"NN"},
"kasbah":	{"NN"},
"kasha":	{"NN"},
"kashag":	{"NN"},
"kasparov":	{"NN"},
"kassite":	{"NN"},
"kastler":	{"NN"},
"kat":	{"NN"},
"katabatic":	{"JJ"},
"katabolic":	{"JJ"},
"katabolism":	{"NN"},
"kataluma":	{"NN"},
"katamorphism":	{"NN"},
"katangan":	{"JJ"},
"katar":	{"NN"},
"katari":	{"JJ","NN"},
"katharevusa":	{"NN"},
"katharobe":	{"NN"},
"katharobic":	{"JJ"},
"katharometer":	{"NN"},
"katharsis":	{"NN"},
"katherine":	{"NN"},
"katniss":	{"NN"},
"kato":	{"NN"},
"katowice":	{"NN"},
"katsina":	{"NN"},
"katsuwonidae":	{"NN"},
"katsuwonus":	{"NN"},
"kattegatt":	{"NN"},
"katy":	{"NN"},
"katydid":	{"NN"},
"katzenjammer":	{"NN"},
"kauai":	{"NN"},
"kaufman":	{"NN"},
"kaunas":	{"NNS"},
"kaunda":	{"NN"},
"kauri":	{"NN"},
"kaury":	{"NN"},
"kava":	{"NN"},
"kavakava":	{"NN"},
"kavrin":	{"NN"},
"kawaka":	{"NN"},
"kayak":	{"NN"},
"kayaks":	{"NNS"},
"kaye":	{"NN"},
"kayo":	{"NN","VB","VBP"},
"kayoed":	{"VBD","VBN"},
"kayoing":	{"VBG"},
"kayos":	{"VBZ"},
"kazak":	{"NN"},
"kazakh":	{"NN"},
"kazakhstani":	{"JJ","NN"},
"kazan":	{"NN"},
"kazoo":	{"NN"},
"kazoos":	{"NNS"},
"kb":	{"NN"},
"kbit":	{"NN"},
"kbo":	{"NN"},
"kc.":	{"NN"},
"kea":	{"NN"},
"kean":	{"NN"},
"keb":	{"NN"},
"kebab":	{"NN"},
"kebabs":	{"NNS"},
"keble":	{"NN"},
"kebob":	{"NN"},
"kechua":	{"NN"},
"kechuan":	{"JJ","NN"},
"keddah":	{"FW"},
"kedgeree":	{"NN"},
"keel":	{"NN","VB","VBP"},
"keel-shaped":	{"JJ"},
"keelboat":	{"NN"},
"keeled":	{"VBD","VBN"},
"keeling":	{"VBG"},
"keels":	{"NNS","VBZ"},
"keelson":	{"NN"},
"keen":	{"JJ","VB","VBP","NN"},
"keen-eyed":	{"JJ"},
"keen-sighted":	{"JJ"},
"keened":	{"VBD","VBN"},
"keener":	{"JJR"},
"keenest":	{"JJS"},
"keening":	{"VBG"},
"keenly":	{"RB"},
"keenness":	{"NN"},
"keens":	{"VBZ"},
"keep":	{"VB","VBP","NN"},
"keeper":	{"NN"},
"keepers":	{"NNS"},
"keeping":	{"VBG","NN"},
"keeps":	{"VBZ","NNS"},
"keepsake":	{"NN"},
"keepsakes":	{"NNS"},
"keeshond":	{"NN"},
"keflex":	{"NN"},
"keflin":	{"NN"},
"keftab":	{"NN"},
"keg":	{"NN"},
"kegful":	{"NN"},
"kegs":	{"NNS"},
"keine":	{"FW"},
"keisenn":	{"FW"},
"keister":	{"NN"},
"kekchi":	{"NN"},
"kekule":	{"NN"},
"kellogg":	{"NN"},
"keloid":	{"NN"},
"kelp":	{"NN"},
"kelpie":	{"NN"},
"kelpwort":	{"NN"},
"kelpy":	{"NN"},
"kelsey":	{"NN"},
"kelter":	{"NN"},
"kelvin":	{"NN","JJ"},
"kemadrin":	{"NN"},
"kempt":	{"JJ"},
"ken":	{"NN","VB","VBP"},
"kenaf":	{"NN"},
"kenalog":	{"NN"},
"kendal":	{"NN"},
"kendall":	{"NN"},
"kendrew":	{"NN"},
"kennan":	{"NN"},
"kenned":	{"VBD","VBN"},
"kennedia":	{"NN"},
"kennedya":	{"NN"},
"kennedyesque":	{"JJ"},
"kennel":	{"NN","VB","VBP"},
"kenneled":	{"VBD","VBN"},
"kenneling":	{"VBG"},
"kennelled":	{"VBD","VBN"},
"kennelling":	{"VBG"},
"kennels":	{"NNS","VBZ"},
"kennewick":	{"NN"},
"kenney":	{"NN"},
"kenning":	{"VBG","NN"},
"kennings":	{"NNS"},
"keno":	{"NN"},
"kenogenesis":	{"NN"},
"kens":	{"VBZ"},
"kent":	{"VBD"},
"kentan":	{"NN"},
"kentish":	{"NN"},
"kenyapithecus":	{"NN"},
"kenyata":	{"NN"},
"keokuk":	{"NN"},
"kepi":	{"NN"},
"kept":	{"VBD","VBN"},
"kera":	{"NN"},
"keratalgia":	{"NN"},
"keratectasia":	{"NN"},
"keratin":	{"NN"},
"keratinisation":	{"NN"},
"keratinise":	{"VB","VBP"},
"keratinised":	{"VBD","VBN"},
"keratinises":	{"VBZ"},
"keratinising":	{"VBG"},
"keratinization":	{"NN"},
"keratinize":	{"VB","VBP"},
"keratinized":	{"VBD","VBN"},
"keratinizes":	{"VBZ"},
"keratinizing":	{"VBG"},
"keratitis":	{"NN"},
"keratoacanthoma":	{"NN"},
"keratocele":	{"NN"},
"keratoconjunctivitis":	{"NN"},
"keratoconus":	{"NN"},
"keratoderma":	{"NN"},
"keratodermia":	{"NN"},
"keratohyalin":	{"NN"},
"keratoiritis":	{"NN"},
"keratomalacia":	{"NN"},
"keratomycosis":	{"NN"},
"keratonosis":	{"NN"},
"keratonosus":	{"NNS"},
"keratoplasty":	{"NN"},
"keratoscleritis":	{"NN"},
"keratoscope":	{"NN"},
"keratoscopy":	{"NN"},
"keratosis":	{"NN"},
"keratotomy":	{"NN"},
"kerb":	{"NN"},
"kerb-crawling":	{"NN"},
"kerbala":	{"NN"},
"kerbela":	{"NN"},
"kerbs":	{"NNS"},
"kerbstone":	{"NN"},
"kerchief":	{"NN"},
"kerchiefed":	{"JJ"},
"kerchiefs":	{"NNS"},
"kerensky":	{"NN"},
"kerfuffle":	{"NN"},
"kerion":	{"NN"},
"kerkorian":	{"NN"},
"kerkorian-owned":	{"JJ"},
"kern":	{"NN","VB","VBP"},
"kerned":	{"VBD","VBN"},
"kernel":	{"NN"},
"kernels":	{"NNS"},
"kernicterus":	{"NN"},
"kerning":	{"VBG"},
"kernite":	{"NN"},
"kerns":	{"VBZ"},
"kerosene":	{"NN"},
"kerosine":	{"NN"},
"kerugma":	{"NN"},
"kerygma":	{"NN"},
"kesey":	{"NN"},
"kestrel":	{"NN"},
"kestrels":	{"NNS"},
"ketalar":	{"NN"},
"ketamine":	{"NN"},
"ketch":	{"NN"},
"ketches":	{"NNS"},
"ketchup":	{"NN"},
"keteleeria":	{"NN"},
"ketembilla":	{"NN"},
"ketoacidosis":	{"NN"},
"ketoaciduria":	{"NN"},
"ketohexose":	{"NN"},
"ketone":	{"NN"},
"ketonemia":	{"NN"},
"ketonuria":	{"NN"},
"ketoprofen":	{"NN"},
"ketorolac":	{"NN"},
"ketose":	{"NN"},
"ketosis":	{"NN"},
"ketosteroid":	{"NN"},
"kettering":	{"NN"},
"kettle":	{"NN"},
"kettledrum":	{"NN"},
"kettledrums":	{"NNS"},
"kettleful":	{"NN"},
"kettles":	{"NNS"},
"ketubim":	{"NN"},
"keurboom":	{"NN"},
"key":	{"JJ","NN","VB","VBP"},
"key-financial":	{"JJ"},
"key-punched":	{"JJ"},
"key-someone":	{"NN"},
"keyboard":	{"NN","VB","VBP"},
"keyboarded":	{"VBD","VBN"},
"keyboarding":	{"NN","VBG"},
"keyboardist":	{"NN"},
"keyboardists":	{"NNS"},
"keyboards":	{"NNS","VBZ"},
"keycard":	{"NN"},
"keychain":	{"NN"},
"keyed":	{"JJ","VBD","VBN"},
"keyhole":	{"NN"},
"keyholes":	{"NNS"},
"keying":	{"VBG"},
"keyless":	{"JJ"},
"keynesianism":	{"NN"},
"keynote":	{"NN","VBP","VB","JJ"},
"keynoted":	{"VBD","VBN"},
"keynotes":	{"NNS","VBZ"},
"keynoting":	{"VBG"},
"keypad":	{"NN"},
"keypads":	{"NNS"},
"keys":	{"NNS","VBZ"},
"keystone":	{"NN"},
"keystones":	{"NNS"},
"keystroke":	{"NN"},
"keystrokes":	{"NNS"},
"keyword":	{"NN"},
"keywords":	{"NNS"},
"kfc":	{"NN"},
"kg":	{"NN"},
"khabarovsk":	{"NN"},
"khachaturian":	{"NN"},
"khadafy":	{"NN"},
"khaddar":	{"NN"},
"khadi":	{"NN"},
"khaki":	{"NN","JJ"},
"khaki-bound":	{"JJ"},
"khakis":	{"NNS"},
"khalif":	{"NN"},
"khalifah":	{"NN"},
"khalka":	{"NN"},
"khalkha":	{"NN"},
"khalsa":	{"NN"},
"khama":	{"NN"},
"khamsin":	{"NN"},
"khamti":	{"NN"},
"khan":	{"NN"},
"khanate":	{"NN"},
"khaneh":	{"FW"},
"khanty":	{"NN"},
"kharkiv":	{"NN"},
"kharkov":	{"NN"},
"khat":	{"NN"},
"khaya":	{"NN"},
"khedive":	{"NN"},
"khepera":	{"NN"},
"khesari":	{"NN"},
"khi":	{"NN"},
"khimar":	{"NN"},
"khios":	{"NN"},
"khirghiz":	{"NN"},
"khmer":	{"NN"},
"khoikhoi":	{"NN"},
"khoikhoin":	{"NN"},
"khoisan":	{"NN"},
"khomeini":	{"NN"},
"khoum":	{"NN"},
"khowar":	{"NN"},
"khuen":	{"NN"},
"khufu":	{"NN"},
"khukuri":	{"NN"},
"ki":	{"NN"},
"kiaat":	{"NN"},
"kiang":	{"NN"},
"kib":	{"NN"},
"kibble":	{"NN"},
"kibbutz":	{"NN"},
"kibbutz-made":	{"JJ"},
"kibbutzim":	{"NNS"},
"kibbutznik":	{"NN"},
"kibbutzniks":	{"NNS"},
"kibe":	{"NN"},
"kibibit":	{"NN"},
"kibibyte":	{"NN"},
"kibit":	{"NN"},
"kibitz":	{"VB","VBP"},
"kibitzed":	{"VBD","VBN"},
"kibitzer":	{"NN"},
"kibitzers":	{"NNS"},
"kibitzing":	{"VBG"},
"kibitzs":	{"VBZ"},
"kibosh":	{"NN"},
"kichaga":	{"NN"},
"kichai":	{"NN"},
"kick":	{"NN","VB","VBP"},
"kick-off":	{"NN"},
"kick-offs":	{"NNS"},
"kick-start":	{"VBP","NN","VB"},
"kick-started":	{"VBD","VBN"},
"kick-starter":	{"NN"},
"kick-starting":	{"VBG"},
"kick-starts":	{"VBZ","NNS"},
"kick-up":	{"NN"},
"kickapoo":	{"NN"},
"kickback":	{"NN"},
"kickbacks":	{"NNS"},
"kicked":	{"VBD","VBN"},
"kicker":	{"NN"},
"kickers":	{"NNS"},
"kicking":	{"VBG","JJ"},
"kickoff":	{"NN"},
"kickoffs":	{"NNS"},
"kicks":	{"VBZ","NNS"},
"kickshaw":	{"NN"},
"kicksorter":	{"NN"},
"kickstand":	{"NN"},
"kickstands":	{"NNS"},
"kid":	{"NN","VB","VBP"},
"kid-glove":	{"JJ"},
"kid-gloved":	{"JJ"},
"kidded":	{"VBD","VBN"},
"kiddie":	{"NN","JJ"},
"kiddies":	{"NNS"},
"kidding":	{"VBG","NN"},
"kiddy":	{"NN","JJ"},
"kidnap":	{"VB","VBP","NN"},
"kidnaped":	{"VBN","VBD"},
"kidnaper":	{"NN"},
"kidnaping":	{"VBG"},
"kidnapped":	{"VBN","VBD"},
"kidnapper":	{"NN"},
"kidnappers":	{"NNS"},
"kidnapping":	{"NN","VBG"},
"kidnappings":	{"NNS"},
"kidnaps":	{"VBZ","VBZ"},
"kidney":	{"NN"},
"kidney-shaped":	{"JJ"},
"kidney-stone":	{"NN"},
"kidneys":	{"NNS"},
"kids":	{"NNS","VBZ"},
"kidskin":	{"NN"},
"kieselguhr":	{"NN"},
"kieserite":	{"NN"},
"kieslowski":	{"NN"},
"kif":	{"NN"},
"kiggelaria":	{"NN"},
"kike":	{"NN"},
"kikladhes":	{"NNS"},
"kikuyu":	{"NN"},
"kildeer":	{"NN"},
"kilderkin":	{"NN"},
"kiley":	{"NN"},
"kiliwa":	{"NN"},
"kiliwi":	{"NN"},
"kill":	{"VB","VBP","NN"},
"killable":	{"JJ"},
"killdeer":	{"NN"},
"killed":	{"VBN","VBD"},
"killer":	{"NN","JJ"},
"killers":	{"NNS"},
"killifish":	{"NN"},
"killing":	{"VBG","NN","JJ"},
"killingly":	{"RB"},
"killings":	{"NNS"},
"killjoy":	{"NN"},
"killjoys":	{"NNS"},
"kills":	{"VBZ","NNS"},
"kiln":	{"NN","VB","VBP"},
"kiln-dried":	{"JJ"},
"kilned":	{"VBD","VBN"},
"kilning":	{"VBG"},
"kilns":	{"NNS","VBZ"},
"kilo":	{"NN"},
"kilobase":	{"NN"},
"kilobases":	{"NNS"},
"kilobit":	{"NN"},
"kilobyte":	{"NN"},
"kilobytes":	{"NNS"},
"kilocalorie":	{"NN"},
"kilocycle":	{"NN"},
"kilogram":	{"NN"},
"kilogram-meter":	{"NN"},
"kilograms":	{"NNS"},
"kilohertz":	{"NN","NNS"},
"kiloliter":	{"NN"},
"kilolitre":	{"NN"},
"kilometer":	{"NN"},
"kilometers":	{"NNS"},
"kilometre":	{"NN"},
"kilometres":	{"NNS"},
"kilos":	{"NNS"},
"kiloton":	{"NN"},
"kilovolt":	{"NN"},
"kilovolt-ampere":	{"NN"},
"kilowatt":	{"NN"},
"kilowatt-hour":	{"NN"},
"kilowatt-hours":	{"NNS"},
"kilowatts":	{"NNS"},
"kilroy":	{"NN"},
"kilt":	{"NN","VB","VBP"},
"kilted":	{"VBD","VBN","JJ"},
"kilter":	{"NN"},
"kilting":	{"VBG"},
"kilts":	{"NNS","VBZ"},
"kimberlite":	{"NN"},
"kimchi":	{"NN"},
"kimono":	{"NN"},
"kimonos":	{"NNS"},
"kimpap":	{"FW"},
"kin":	{"NNS"},
"kina":	{"NN"},
"kinaesthesia":	{"NN"},
"kinaesthesis":	{"NN"},
"kinaesthetic":	{"JJ"},
"kinaesthetically":	{"RB"},
"kinanesthesia":	{"NN"},
"kinase":	{"NN"},
"kinchinjunga":	{"NN"},
"kind":	{"NN","JJ"},
"kind-hearted":	{"JJ"},
"kind-heartedly":	{"RB"},
"kind-heartedness":	{"NN"},
"kinda":	{"RB"},
"kinder":	{"JJR"},
"kindergarener":	{"NN"},
"kindergarten":	{"NN"},
"kindergartener":	{"NN"},
"kindergartens":	{"NNS"},
"kindergartner":	{"NN"},
"kindest":	{"JJS"},
"kindhearted":	{"JJ"},
"kindheartedness":	{"NN"},
"kindle":	{"VB","VBP"},
"kindled":	{"VBD","VBN"},
"kindles":	{"VBZ"},
"kindliness":	{"NN"},
"kindling":	{"NN","VBG"},
"kindly":	{"JJ","RB"},
"kindness":	{"NN"},
"kindnesses":	{"NNS"},
"kindred":	{"JJ","NN","NNS"},
"kinds":	{"NNS"},
"kine":	{"NN"},
"kinematics":	{"NN"},
"kinescope":	{"NN"},
"kinesics":	{"NN"},
"kinesiology":	{"NN"},
"kinesis":	{"NN"},
"kinesthesia":	{"NN"},
"kinesthesis":	{"NN"},
"kinesthetic":	{"JJ"},
"kinesthetically":	{"RB"},
"kinesthetics":	{"NN"},
"kinetic":	{"JJ"},
"kinetically":	{"RB"},
"kinetics":	{"NN"},
"kinetochore":	{"NN"},
"kinetoscope":	{"NN"},
"kinetosis":	{"NN"},
"kinfolk":	{"NNS"},
"king":	{"NN","VB","VBP"},
"king-size":	{"JJ"},
"king-sized":	{"JJ"},
"kingbird":	{"NN"},
"kingbolt":	{"NN"},
"kingcup":	{"NN"},
"kingdom":	{"NN"},
"kingdom-based":	{"JJ"},
"kingdom-wide":	{"JJ"},
"kingdoms":	{"NNS"},
"kinged":	{"VBD","VBN"},
"kingfish":	{"NN"},
"kingfisher":	{"NN"},
"kingfishers":	{"NNS"},
"kinging":	{"VBG"},
"kinglet":	{"NN"},
"kinglike":	{"JJ"},
"kingliness":	{"NN"},
"kingly":	{"JJ"},
"kingmaker":	{"NN"},
"kingmakers":	{"NNS"},
"kingpin":	{"NN"},
"kingpins":	{"NNS"},
"kings":	{"NNS","VBZ"},
"kingship":	{"NN"},
"kingside":	{"NN"},
"kingsnake":	{"NN"},
"kingstown":	{"NN"},
"kingwood":	{"NN"},
"kinin":	{"NN"},
"kink":	{"NN","VB","VBP"},
"kinkajou":	{"NN"},
"kinked":	{"VBD","VBN"},
"kinkier":	{"JJR"},
"kinkiest":	{"JJS"},
"kinkily":	{"RB"},
"kinkiness":	{"NN"},
"kinking":	{"VBG"},
"kinks":	{"NNS","VBZ"},
"kinky":	{"JJ"},
"kinnear":	{"NN"},
"kino":	{"NN"},
"kinosternidae":	{"NN"},
"kinosternon":	{"NN"},
"kinsfolk":	{"NNS"},
"kinship":	{"NN"},
"kinsman":	{"NN"},
"kinsmen":	{"NNS"},
"kinsperson":	{"NN"},
"kinswoman":	{"NN"},
"kinswomen":	{"NNS"},
"kinyarwanda":	{"NN"},
"kiosk":	{"NN"},
"kiosks":	{"NNS"},
"kip":	{"NN","VB","VBP"},
"kipah":	{"NN"},
"kiplingesque":	{"JJ"},
"kippa":	{"NN"},
"kippah":	{"NN"},
"kipped":	{"VBD","VBN"},
"kipper":	{"NN"},
"kippered":	{"JJ"},
"kippers":	{"NNS"},
"kipping":	{"VBG"},
"kippot":	{"NNS"},
"kips":	{"VBZ"},
"kirchhoff":	{"NN"},
"kirchner":	{"NN"},
"kirghiz":	{"NN"},
"kirgiz":	{"NN"},
"kirgizia":	{"NN"},
"kirgizstan":	{"NN"},
"kirk":	{"NN"},
"kirkia":	{"NN"},
"kirks":	{"NNS"},
"kirkuk":	{"NN"},
"kirpan":	{"NN"},
"kirsch":	{"NN"},
"kirtle":	{"NN"},
"kisha":	{"FW"},
"kisha-club":	{"JJ"},
"kishar":	{"NN"},
"kishke":	{"NN"},
"kislev":	{"NN"},
"kismat":	{"NN"},
"kismet":	{"NN"},
"kiss":	{"VB","VBP","NN"},
"kiss-me-over-the-garden-gate":	{"NN"},
"kissed":	{"VBD","VBN"},
"kisser":	{"NN"},
"kissers":	{"NNS"},
"kisses":	{"VBZ","NNS"},
"kissimmee":	{"NN"},
"kissing":	{"JJ","VBG"},
"kisumu":	{"NN"},
"kiswahili":	{"NN"},
"kit":	{"NN","VB","VBP"},
"kitakyushu":	{"NN"},
"kitambilla":	{"NN"},
"kitbag":	{"NN"},
"kitbags":	{"NNS"},
"kitchen":	{"NN"},
"kitchen-sink":	{"JJ"},
"kitchen-table":	{"JJ"},
"kitchener":	{"NN"},
"kitchenette":	{"NN"},
"kitchenettes":	{"NNS"},
"kitchens":	{"NNS"},
"kitchenware":	{"NN"},
"kite":	{"NN","VB","VBP"},
"kited":	{"VBD","VBN"},
"kitembilla":	{"NN"},
"kites":	{"VBZ","NNS"},
"kith":	{"NN"},
"kiting":	{"VBG"},
"kits":	{"NNS","VBZ"},
"kitsch":	{"NN","JJ"},
"kitschy":	{"JJ"},
"kitted":	{"VBD","VBN"},
"kittee":	{"NN"},
"kitten":	{"NN","VB","VBP"},
"kitten-tails":	{"NNS"},
"kittened":	{"VBD","VBN"},
"kittening":	{"VBG"},
"kittenish":	{"JJ"},
"kittens":	{"NNS","VBZ"},
"kitties":	{"NNS"},
"kitting":	{"VBG"},
"kittiwake":	{"NN"},
"kittul":	{"NN"},
"kitty":	{"NN"},
"kitty-cat":	{"NN"},
"kitty-corner":	{"RB"},
"kitty-cornered":	{"JJ"},
"kitul":	{"NN"},
"kivu":	{"NN"},
"kiwi":	{"NN"},
"kiwi-sized":	{"JJ"},
"kiwifruit":	{"NN"},
"kiwis":	{"NNS"},
"klaipeda":	{"NN"},
"klamath":	{"NN"},
"klansman":	{"NN"},
"klansmen":	{"NNS"},
"klaproth":	{"NN"},
"klaus":	{"NNS"},
"klavern":	{"NN"},
"klavier":	{"NN"},
"klaxon":	{"NN"},
"klebsiella":	{"NN"},
"kleenex":	{"NN"},
"kleenexes":	{"NNS"},
"klein":	{"NN"},
"kleist":	{"NN"},
"kleptocracies":	{"NNS"},
"kleptocracy":	{"NN"},
"kleptocrat":	{"NN"},
"kleptocratic":	{"JJ"},
"kleptocrats":	{"NNS"},
"kleptomania":	{"NN"},
"kleptomaniac":	{"NN","JJ"},
"kleptomaniacs":	{"NNS"},
"klick":	{"NN"},
"klieg":	{"NN"},
"kline":	{"NN"},
"klinefelter":	{"NN"},
"klm-controlled":	{"JJ"},
"klopstock":	{"NN"},
"klorvess":	{"NN"},
"klotho":	{"NN"},
"kludge":	{"NN","VB","VBP"},
"kludged":	{"VBD","VBN"},
"kludges":	{"NNS","VBZ"},
"kludging":	{"VBG"},
"kluge":	{"NN"},
"klutz":	{"NN"},
"klutzes":	{"NNS"},
"klutzy":	{"JJ"},
"kluxer":	{"NN"},
"klystron":	{"NN"},
"klyuchevskaya":	{"NN"},
"km":	{"NN","NNS"},
"kms":	{"NNS"},
"knack":	{"NN"},
"knacker":	{"NN","VB","VBP"},
"knackered":	{"JJ","VBD","VBN"},
"knackering":	{"VBG"},
"knackers":	{"NNS","VBZ"},
"knackwurst":	{"NN"},
"knap":	{"VB","VBP","NN"},
"knapped":	{"VBD","VBN"},
"knapper":	{"NN"},
"knapping":	{"VBG"},
"knaps":	{"VBZ","NNS"},
"knapsack":	{"NN"},
"knapsacks":	{"NNS"},
"knapweed":	{"NN"},
"knave":	{"NN"},
"knavery":	{"NN"},
"knaves":	{"NNS"},
"knavish":	{"JJ"},
"knavishly":	{"RB"},
"knawe":	{"NN"},
"knawel":	{"NN"},
"knead":	{"VB","VBP"},
"kneaded":	{"VBN","VBD"},
"kneading":	{"VBG","NN"},
"kneads":	{"VBZ"},
"knee":	{"NN","VB","VBP"},
"knee-deep":	{"JJ"},
"knee-hi":	{"NN"},
"knee-high":	{"JJ"},
"knee-jerk":	{"JJ"},
"knee-length":	{"JJ"},
"knee-socked":	{"JJ"},
"knee-type":	{"JJ"},
"kneebreeches":	{"NNS"},
"kneecap":	{"NN","VB","VBP"},
"kneecapped":	{"VBD","VBN"},
"kneecapping":	{"VBG"},
"kneecaps":	{"NNS","VBZ"},
"kneed":	{"VBD","VBN"},
"kneeing":	{"VBG"},
"kneel":	{"VB","VBP"},
"kneeled":	{"VBD","VBN"},
"kneeler":	{"NN"},
"kneeling":	{"VBG"},
"kneels":	{"VBZ"},
"kneepan":	{"NN"},
"knees":	{"NNS","VBZ"},
"knell":	{"NN","VB","VBP"},
"knelled":	{"VBD","VBN"},
"knelling":	{"VBG"},
"knells":	{"NNS","VBZ"},
"knelt":	{"VBD","VBN"},
"knesseth":	{"NN"},
"knew":	{"VBD"},
"knick-knacks":	{"NNS"},
"knickerbockers":	{"NNS"},
"knickers":	{"NNS"},
"knickknack":	{"NN"},
"knickknackery":	{"NN"},
"knickknacks":	{"NNS"},
"knife":	{"NN","VB","VBP"},
"knife-edge":	{"NN","JJ"},
"knife-handle":	{"NN"},
"knife-men":	{"NNS"},
"knifed":	{"VBD","VBN"},
"knifelike":	{"JJ"},
"knifes":	{"VBZ"},
"knifing":	{"VBG","NN"},
"knifings":	{"NNS"},
"knight":	{"NN","VB","VBP"},
"knight-errant":	{"NN"},
"knight-errantry":	{"NN"},
"knighted":	{"VBD","VBN"},
"knighthood":	{"NN"},
"knighthoods":	{"NNS"},
"knightia":	{"NN"},
"knighting":	{"VBG"},
"knightliness":	{"NN"},
"knightly":	{"JJ"},
"knights":	{"NNS","VBZ"},
"kniphofia":	{"NN"},
"knish":	{"NN"},
"knit":	{"VB","VBP","NN","VBD","VBN"},
"knite":	{"NN"},
"knits":	{"VBZ"},
"knitted":	{"VBD","VBN"},
"knitter":	{"NN"},
"knitters":	{"NNS"},
"knitting":	{"NN","VBG"},
"knitwear":	{"NN"},
"knitwork":	{"NN"},
"knives":	{"NNS"},
"knob":	{"NN"},
"knobble":	{"NN"},
"knobbly":	{"JJ"},
"knobby":	{"JJ"},
"knobby-knuckled":	{"JJ"},
"knobkerrie":	{"NN"},
"knobkerry":	{"NN"},
"knobs":	{"NNS"},
"knock":	{"VB","NN","VBP"},
"knock-down":	{"JJ"},
"knock-down-and-drag-out":	{"JJ"},
"knock-knee":	{"NN"},
"knock-kneed":	{"JJ"},
"knock-off":	{"NN","JJ"},
"knock-offs":	{"NNS"},
"knock-on":	{"NN"},
"knock-out":	{"NN","JJ"},
"knock-up":	{"NN"},
"knockabout":	{"JJ"},
"knockdown":	{"JJ","NN"},
"knockdown-dragout":	{"JJ"},
"knockdowns":	{"NNS"},
"knocked":	{"VBD","VBN"},
"knocked-out":	{"JJ"},
"knocker":	{"NN"},
"knockers":	{"NNS"},
"knocking":	{"VBG"},
"knockoff":	{"NN"},
"knockoffs":	{"NNS"},
"knockout":	{"NN","JJ"},
"knockouts":	{"NNS"},
"knocks":	{"VBZ","NNS"},
"knockwurst":	{"NN"},
"knoll":	{"NN"},
"knolls":	{"NNS"},
"knossos":	{"NN"},
"knot":	{"NN","VB","VBP"},
"knot-tying":	{"JJ"},
"knotgrass":	{"NN"},
"knothole":	{"NN"},
"knots":	{"NNS","VBZ"},
"knott":	{"NN"},
"knotted":	{"JJ","VBD","VBN"},
"knottier":	{"JJR"},
"knottiest":	{"JJS"},
"knottiness":	{"NN"},
"knotting":	{"VBG"},
"knotty":	{"JJ"},
"knout":	{"NN"},
"know":	{"VB","VBP","NN"},
"know-all":	{"NN"},
"know-alls":	{"NNS"},
"know-how":	{"NN"},
"know-it-all":	{"NN"},
"know-it-alls":	{"NNS"},
"know-nothing":	{"NN"},
"know-nothings":	{"NNS"},
"knowable":	{"JJ"},
"knower":	{"NN"},
"knowhow":	{"NN"},
"knowing":	{"VBG","JJ"},
"knowingly":	{"RB"},
"knowingness":	{"NN"},
"knowledge":	{"NN"},
"knowledgeability":	{"NN"},
"knowledgeable":	{"JJ"},
"knowledgeableness":	{"NN"},
"knowledges":	{"NNS"},
"known":	{"JJ","VBN"},
"knows":	{"VBZ"},
"knox-like":	{"JJ"},
"knoxville":	{"NN"},
"knuckle":	{"NN","VB","VBP"},
"knuckle-duster":	{"NN"},
"knuckle-dusters":	{"NNS"},
"knuckleball":	{"NN"},
"knucklebone":	{"NN"},
"knucklebones":	{"NNS"},
"knuckled":	{"VBD","VBN"},
"knuckleduster":	{"NN"},
"knuckledusters":	{"NNS"},
"knucklehead":	{"NN"},
"knuckleheads":	{"NNS"},
"knuckler":	{"NN"},
"knuckles":	{"NNS","VBZ"},
"knuckling":	{"VBG"},
"koala":	{"NN"},
"koalas":	{"NNS"},
"koan":	{"NN"},
"koasati":	{"NN"},
"kob":	{"NN"},
"kobe":	{"NN"},
"kobenhavn":	{"NN"},
"kobo":	{"NN","NNS"},
"kobus":	{"NN"},
"koch":	{"NN"},
"kochia":	{"NN"},
"koellia":	{"NN"},
"koestler":	{"NN"},
"kofanes":	{"NNS"},
"kogia":	{"NN"},
"kohl":	{"NN"},
"kohleria":	{"NN"},
"kohlrabi":	{"NN"},
"kohnstamm-negative":	{"JJ"},
"koine":	{"NN"},
"koinonia":	{"NN"},
"kok-saghyz":	{"NN"},
"kok-sagyz":	{"NN"},
"kokka":	{"JJ","NN"},
"kola":	{"NN"},
"kolam":	{"NN"},
"kolami":	{"NN"},
"kolkata":	{"NN"},
"kolkhoz":	{"NN"},
"kolkhozes":	{"NNS"},
"kolkhoznik":	{"NN"},
"kolkwitzia":	{"NN"},
"koln":	{"NN"},
"kolonia":	{"NN"},
"komi":	{"NN"},
"komondor":	{"NN"},
"kompromat":	{"NN"},
"konakri":	{"NN"},
"kong-dollar":	{"NN"},
"konga":	{"NN"},
"kongfu":	{"FW"},
"kongfuze":	{"NN"},
"kongo":	{"NN"},
"konini":	{"NN"},
"konoe":	{"NN"},
"konoye":	{"NN"},
"konqueror":	{"NN"},
"koodoo":	{"NN"},
"kook":	{"NN"},
"kookaburra":	{"NN"},
"kookie":	{"JJ"},
"kooks":	{"NNS"},
"kooky":	{"JJ"},
"koop":	{"NN"},
"koopmans":	{"NNS"},
"kopeck":	{"NN"},
"kopek":	{"NN"},
"kopiyka":	{"NN"},
"kopje":	{"NN"},
"koppel":	{"NN"},
"koppie":	{"NN"},
"kor":	{"NN"},
"korbut":	{"NN"},
"korchnoi":	{"NN"},
"korda":	{"NN"},
"kordofan":	{"NN"},
"kordofanian":	{"NN"},
"kore":	{"NN"},
"korea-basher":	{"NN"},
"korinthos":	{"NNS"},
"korn":	{"NN"},
"korobytsins":	{"NNS"},
"koruna":	{"NN"},
"korzybski":	{"NN"},
"kosciusko":	{"NN"},
"kosciuszko":	{"NN"},
"kosher":	{"JJ"},
"kosteletzya":	{"NN"},
"kota":	{"NN"},
"kotar":	{"NN"},
"koto":	{"NN"},
"kotoko":	{"NN"},
"kotowaza":	{"FW"},
"koudou":	{"NN"},
"koumiss":	{"NN"},
"koussevitzky":	{"NN"},
"kovna":	{"NN"},
"kovno":	{"NN"},
"koweit":	{"NN"},
"kowhai":	{"NN"},
"kowtow":	{"VB","VBP"},
"kowtowed":	{"VBD","VBN"},
"kowtowing":	{"VBG"},
"kowtows":	{"VBZ"},
"kp":	{"NN"},
"kph":	{"NN"},
"kr":	{"NN"},
"kraal":	{"NN"},
"kraals":	{"NNS"},
"kraemer":	{"NN"},
"krafft-ebing":	{"NN"},
"kraft":	{"NN"},
"kraft-pulp":	{"JJ"},
"krait":	{"NN"},
"krakatao":	{"NN"},
"krakatau":	{"NN"},
"krakau":	{"NN"},
"krakow":	{"NN"},
"krasner":	{"NN"},
"krater":	{"NN"},
"kraurosis":	{"NN"},
"krause":	{"NN"},
"kraut":	{"NN"},
"krauthead":	{"NN"},
"krautheads":	{"NNS"},
"krauts":	{"NNS"},
"krebs":	{"NNS"},
"kreisler":	{"NN"},
"kretek":	{"NN"},
"kreteks":	{"NNS"},
"krigia":	{"NN"},
"krill":	{"NN"},
"kris":	{"NN"},
"krishnaism":	{"NN"},
"krishnaists":	{"NNS"},
"kriti":	{"NN"},
"kroeber":	{"NN"},
"krona":	{"NN"},
"krone":	{"NN"},
"kronecker":	{"NN"},
"kroner":	{"NNS"},
"kronor":	{"NNS"},
"kroon":	{"NN"},
"kropotkin":	{"NN"},
"kroto":	{"NN"},
"krubi":	{"NN"},
"krummhorn":	{"NN"},
"krupp":	{"NN"},
"krypterophaneron":	{"NN"},
"krypton":	{"NN"},
"krysha":	{"NN"},
"krzysztof":	{"NN"},
"ks":	{"NN"},
"kshatriya":	{"NN"},
"kt":	{"NN"},
"ku-chiku":	{"NN"},
"kuangchou":	{"NN"},
"kuchean":	{"NN"},
"kudos":	{"NN"},
"kudu":	{"NN"},
"kudzu":	{"NN"},
"kuenlun":	{"NN"},
"kui":	{"NN"},
"kuiper":	{"NN"},
"kukenaam":	{"NN"},
"kuki":	{"NN"},
"kuki-chin":	{"NN"},
"kulanapan":	{"NN"},
"kulun":	{"NN"},
"kumasi":	{"NN"},
"kumis":	{"NN"},
"kumiss":	{"NN"},
"kummel":	{"NN"},
"kumquat":	{"NN"},
"kumquats":	{"NNS"},
"kung":	{"NN"},
"kung-fu":	{"NN"},
"kunlun":	{"NN"},
"kunzite":	{"NN"},
"kuomintang":	{"NN"},
"kura":	{"NN"},
"kurakkan":	{"NN"},
"kurchee":	{"NN"},
"kurchi":	{"NN"},
"kuri-chiku":	{"NN"},
"kuroshio":	{"NN"},
"kurrajong":	{"NN"},
"kurrat":	{"NN"},
"kurta":	{"NN"},
"kuru":	{"NN"},
"kurus":	{"NN"},
"kurux":	{"NN"},
"kusan":	{"NN"},
"kutch":	{"NN"},
"kutuzov":	{"NN"},
"kuvasz":	{"NN"},
"kuvi":	{"NN"},
"kv":	{"NN"},
"kvass":	{"NN"},
"kvetch":	{"NN","VB","VBP"},
"kvetched":	{"VBD","VBN"},
"kvetches":	{"VBZ","NNS"},
"kvetching":	{"VBG"},
"kw":	{"NN"},
"kw-hr":	{"NN"},
"kwa":	{"NN"},
"kwacha":	{"NN"},
"kwai":	{"NN"},
"kwajalein":	{"NN"},
"kwakiutl":	{"NN"},
"kwan-yin":	{"NN"},
"kwangchow":	{"NN"},
"kwangju":	{"NN"},
"kwangtung":	{"NN"},
"kwannon":	{"NN"},
"kwanza":	{"NN"},
"kwashiorkor":	{"NN"},
"kwazulu-natal":	{"NN"},
"kweek":	{"NN"},
"kwela":	{"NN"},
"kwell":	{"NN"},
"kwhr":	{"NN"},
"kwon":	{"FW"},
"kyanite":	{"NN"},
"kyat":	{"NN"},
"kyd":	{"NN"},
"kylie":	{"NN"},
"kylix":	{"NN"},
"kymograph":	{"NN"},
"kyo-chiku":	{"NN"},
"kyo-zan":	{"NN"},
"kyphosidae":	{"NN"},
"kyphosis":	{"NN"},
"kyphosus":	{"NNS"},
"kyphotic":	{"JJ"},
"kyrgyzstani":	{"JJ"},
"kyyiv":	{"NN"},
"l":	{"NN","SYM","LS"},
"l'aquila":	{"NN"},
"l'enfant":	{"NN"},
"l-dopa":	{"NN"},
"l-p":	{"NN"},
"l-plate":	{"NN"},
"l-shaped":	{"JJ"},
"l.":	{"DT","NN"},
"la-di-da":	{"JJ"},
"la-la":	{"JJ"},
"la-la-landers":	{"NNS"},
"laager":	{"NN"},
"lab":	{"NN"},
"laban":	{"NN"},
"labanotation":	{"NN"},
"labdanum":	{"NN"},
"label":	{"NN","VB","VBP"},
"labeled":	{"VBN","VBD"},
"labeling":	{"VBG"},
"labelled":	{"VBD","VBN"},
"labelling":	{"VBG"},
"labels":	{"NNS","VBZ"},
"labetalol":	{"NN"},
"labial":	{"JJ","NN"},
"labialisation":	{"NN"},
"labialise":	{"VB","VBP"},
"labialised":	{"VBD","VBN"},
"labialises":	{"VBZ"},
"labialising":	{"VBG"},
"labialism":	{"NN"},
"labialization":	{"NN"},
"labialize":	{"VB","VBP"},
"labialized":	{"VBD","VBN"},
"labializes":	{"VBZ"},
"labializing":	{"VBG"},
"labiatae":	{"NN"},
"labiate":	{"JJ","NN"},
"labile":	{"JJ"},
"labiodental":	{"NN","JJ"},
"labium":	{"NN"},
"lablab":	{"NN"},
"lablink":	{"NN"},
"labor":	{"NN","VB","VBP"},
"labor-backed":	{"JJ"},
"labor-based":	{"JJ"},
"labor-force":	{"NN"},
"labor-funded":	{"JJ"},
"labor-intensive":	{"JJ"},
"labor-management":	{"JJ","NN"},
"labor-saving":	{"JJ"},
"labor-shortage":	{"NN"},
"laboratories":	{"NNS"},
"laboratory":	{"NN"},
"laboratory-services":	{"JJ","NNS"},
"laboratory-supply":	{"JJ"},
"labored":	{"JJ","VBD","VBN"},
"laborer":	{"NN"},
"laborers":	{"NNS"},
"laboring":	{"JJ","VBG"},
"laborious":	{"JJ"},
"laboriously":	{"RB"},
"laboriousness":	{"NN"},
"labors":	{"NNS","VBZ"},
"laborsaving":	{"JJ"},
"labour":	{"NN","VB","VBP"},
"labour-intensive":	{"JJ"},
"laboured":	{"JJ","VBD","VBN"},
"labourer":	{"NN"},
"labourers":	{"NNS"},
"labouring":	{"JJ","VBG"},
"labourite":	{"NN"},
"labours":	{"VBZ","NNS"},
"laboursaving":	{"JJ"},
"labrador":	{"NN"},
"labradors":	{"NNS"},
"labridae":	{"NN"},
"labrocyte":	{"NN"},
"labrouste":	{"NN"},
"labs":	{"NNS"},
"laburnum":	{"NN"},
"laburnums":	{"NNS"},
"labyrinth":	{"NN"},
"labyrinthian":	{"JJ"},
"labyrinthine":	{"JJ"},
"labyrinthitis":	{"NN"},
"labyrinthodont":	{"NN"},
"labyrinthodonta":	{"NN"},
"labyrinthodontia":	{"NN"},
"labyrinths":	{"NNS"},
"lac":	{"NN"},
"laccopetalum":	{"NN"},
"lace":	{"NN","VB","VBP"},
"lace-drawn":	{"JJ"},
"lacebark":	{"NN"},
"laced":	{"VBD","VBN"},
"lacelike":	{"JJ"},
"lacepod":	{"NN"},
"lacer":	{"NN"},
"lacerate":	{"VB","VBP"},
"lacerated":	{"JJ","VBD","VBN"},
"lacerates":	{"VBZ"},
"lacerating":	{"VBG"},
"laceration":	{"NN"},
"lacerations":	{"NNS"},
"lacerta":	{"NN"},
"lacertid":	{"NN"},
"lacertidae":	{"NN"},
"lacertilia":	{"NN"},
"lacertilian":	{"JJ","NN"},
"laces":	{"NNS","VBZ"},
"lacewing":	{"NN"},
"lacewood":	{"NN"},
"lacework":	{"NN"},
"lacey":	{"JJ","NN"},
"lachaise":	{"NN"},
"lacheln":	{"FW"},
"laches":	{"NN"},
"lachesis":	{"NN"},
"lachnolaimus":	{"NN"},
"lachrymal":	{"JJ","NN"},
"lachrymation":	{"NN"},
"lachrymator":	{"NN"},
"lachrymatory":	{"JJ","NN"},
"lachrymose":	{"JJ"},
"lacier":	{"JJR"},
"laciest":	{"JJS"},
"lacing":	{"NN","VBG"},
"laciniate":	{"JJ"},
"lack":	{"NN","VBP","VB"},
"lack-lustre":	{"JJ"},
"lackadaisical":	{"JJ"},
"lackadaisically":	{"RB"},
"lacked":	{"VBD","VBN"},
"lackey":	{"NN","VB","VBP"},
"lackeyed":	{"VBD","VBN"},
"lackeying":	{"VBG"},
"lackeys":	{"NNS","VBZ"},
"lacking":	{"JJ","VBG"},
"lackluster":	{"JJ","NN"},
"lacklustre":	{"JJ","NN"},
"lacks":	{"VBZ"},
"laconia":	{"NN"},
"laconian":	{"NN"},
"laconic":	{"JJ"},
"laconically":	{"RB"},
"laconicism":	{"NN"},
"laconism":	{"NN"},
"lacquer":	{"VB","VBP","NN"},
"lacquered":	{"VBD","VBN"},
"lacquering":	{"VBG"},
"lacquers":	{"VBZ","NNS"},
"lacquerware":	{"NN"},
"lacrimal":	{"JJ"},
"lacrimation":	{"NN"},
"lacrimator":	{"NN"},
"lacrimatory":	{"JJ","NN"},
"lacrosse":	{"NN"},
"lactaid":	{"NN"},
"lactalbumin":	{"NN"},
"lactarius":	{"NN"},
"lactase":	{"NN"},
"lactate":	{"VB","VBP","NN"},
"lactated":	{"VBD","VBN"},
"lactates":	{"VBZ"},
"lactating":	{"VBG"},
"lactation":	{"NN"},
"lacteal":	{"JJ","NN"},
"lactic":	{"JJ"},
"lactifuge":	{"NN"},
"lactobacillaceae":	{"NN"},
"lactobacillus":	{"NN"},
"lactobacteriaceae":	{"NN"},
"lactoflavin":	{"NN"},
"lactogen":	{"NN"},
"lactogenic":	{"JJ"},
"lactophrys":	{"NNS"},
"lactose":	{"NN"},
"lactosuria":	{"NN"},
"lactuca":	{"NN"},
"lacuna":	{"NN"},
"lacunae":	{"NNS"},
"lacunas":	{"NNS"},
"lacustrine":	{"JJ"},
"lacy":	{"JJ"},
"lad":	{"NN"},
"ladanum":	{"NN"},
"ladder":	{"NN","VB","VBP"},
"ladder-back":	{"NN"},
"ladder-proof":	{"JJ"},
"laddered":	{"VBD","VBN"},
"laddering":	{"VBG"},
"ladders":	{"NNS","VBZ"},
"laddie":	{"NN"},
"laddies":	{"NNS"},
"laddy":	{"NN"},
"lade":	{"VB","VBP"},
"laded":	{"VBD","VBN"},
"laden":	{"JJ","VBN"},
"lades":	{"VBZ"},
"ladies":	{"NNS"},
"ladies'-eardrop":	{"NN"},
"ladies'-eardrops":	{"NNS"},
"ladies-in-waiting":	{"NNS"},
"ladin":	{"NN"},
"lading":	{"NN","VBG"},
"ladino":	{"NN"},
"ladle":	{"NN","VB","VBP"},
"ladled":	{"VBD","VBN"},
"ladles":	{"VBZ","NNS"},
"ladling":	{"VBG"},
"ladoga":	{"NN"},
"lads":	{"NNS"},
"lady":	{"NN"},
"lady's-eardrop":	{"NN"},
"lady's-eardrops":	{"NNS"},
"lady's-finger":	{"NN"},
"lady-bug":	{"NN"},
"lady-bugs":	{"NNS"},
"lady-in-waiting":	{"NN"},
"lady-of-the-night":	{"NN"},
"lady-slipper":	{"NN"},
"ladybeetle":	{"NN"},
"ladybird":	{"NN"},
"ladybirds":	{"NNS"},
"ladybro":	{"NN"},
"ladybug":	{"NN"},
"ladybugs":	{"NNS"},
"ladyfinger":	{"NN"},
"ladyfish":	{"NN"},
"ladylike":	{"JJ"},
"ladylikeness":	{"NN"},
"ladylove":	{"NN"},
"ladyship":	{"NN"},
"laelia":	{"NN"},
"laendler":	{"JJ"},
"laertes":	{"NNS"},
"laetrile":	{"NN"},
"laevulose":	{"NN"},
"lafayette":	{"NN"},
"laffer":	{"NN"},
"laffite":	{"NN"},
"lafitte":	{"NN"},
"lag":	{"NN","VB","VBP"},
"lagan":	{"NN"},
"lagarostrobus":	{"NN"},
"lagenaria":	{"NN"},
"lagend":	{"NN"},
"lagenophera":	{"NN"},
"lager":	{"NN"},
"lagerphone":	{"NN"},
"lagers":	{"NNS"},
"lagerstroemia":	{"NN"},
"laggard":	{"NN","JJ"},
"laggardly":	{"JJ"},
"laggardness":	{"NN"},
"laggards":	{"NNS"},
"lagged":	{"VBD","VBN"},
"lagger":	{"NN"},
"lagging":	{"NN","VBG"},
"lagidium":	{"NN"},
"lagniappe":	{"NN"},
"lagodon":	{"NN"},
"lagomorph":	{"NN"},
"lagomorpha":	{"NN"},
"lagoon":	{"NN"},
"lagoons":	{"NNS"},
"lagophthalmos":	{"NNS"},
"lagopus":	{"NN"},
"lagorchestes":	{"NNS"},
"lagostomus":	{"NNS"},
"lagothrix":	{"NN"},
"lags":	{"VBZ","NNS"},
"laguna":	{"NN"},
"laguncularia":	{"NN"},
"lagune":	{"NN"},
"lah":	{"NN"},
"lahar":	{"NN"},
"lahk":	{"IN"},
"lahu":	{"NN"},
"laic":	{"JJ","NN"},
"laicisation":	{"NN"},
"laicise":	{"VB","VBP"},
"laicised":	{"VBD","VBN"},
"laicises":	{"VBZ"},
"laicising":	{"VBG"},
"laicization":	{"NN"},
"laicize":	{"VB","VBP"},
"laicized":	{"VBD","VBN"},
"laicizes":	{"VBZ"},
"laicizing":	{"VBG"},
"laid":	{"VBN","VBD"},
"laid-back":	{"JJ"},
"laid-off":	{"JJ"},
"lain":	{"VBN"},
"lair":	{"NN"},
"laird":	{"NN"},
"lairds":	{"NNS"},
"lairs":	{"NNS"},
"laissez-faire":	{"NN","JJ"},
"laity":	{"NN"},
"laius":	{"NN"},
"lak":	{"NN"},
"lake":	{"NN"},
"lakefront":	{"NN"},
"lakeland":	{"NN"},
"lakes":	{"NNS"},
"lakeshore":	{"NN"},
"lakeside":	{"NN","JJ"},
"lakh":	{"NN"},
"lakota":	{"NN"},
"lakshmi":	{"NN"},
"lal":	{"NN"},
"lallans":	{"NNS"},
"lallation":	{"NN"},
"lally":	{"NN"},
"lallygag":	{"VB","VBP"},
"lallygagged":	{"VBD","VBN"},
"lallygagging":	{"VBG"},
"lallygags":	{"VBZ"},
"lam":	{"NN","VB","VBP"},
"lama":	{"NN"},
"lamaism":	{"NN"},
"lamaist":	{"NN"},
"lamarck":	{"NN"},
"lamas":	{"NNS"},
"lamasery":	{"NN"},
"lamb":	{"NN","VB","VBP"},
"lamb's-quarter":	{"NN"},
"lamb's-quarters":	{"NNS"},
"lamb-chop":	{"NN"},
"lambast":	{"VB","VBP"},
"lambaste":	{"VB","VBP"},
"lambasted":	{"VBD","VBN"},
"lambastes":	{"VBZ"},
"lambasting":	{"VBG"},
"lambchop":	{"NN"},
"lambda":	{"NN"},
"lambdacism":	{"NN"},
"lambed":	{"VBD","VBN"},
"lambency":	{"NN"},
"lambent":	{"JJ"},
"lambert":	{"NN"},
"lambertia":	{"NN"},
"lambing":	{"VBG","NN"},
"lambis":	{"NN"},
"lambkill":	{"NN"},
"lambkin":	{"NN"},
"lamblike":	{"JJ"},
"lambrequin":	{"NN"},
"lambs":	{"VBZ","NNS"},
"lambskin":	{"NN"},
"lame":	{"JJ","VB","VBP"},
"lame-duck":	{"NN"},
"lamechian":	{"JJ"},
"lamechians":	{"NNS"},
"lamed":	{"VBD","VBN"},
"lamedh":	{"NN"},
"lamella":	{"NN"},
"lamellibranch":	{"JJ","NN"},
"lamellibranchia":	{"NN"},
"lamellicornia":	{"NN"},
"lamely":	{"RB"},
"lameness":	{"NN"},
"lament":	{"VB","VBP","NN"},
"lamentable":	{"JJ"},
"lamentableners":	{"NN"},
"lamentably":	{"RB"},
"lamentation":	{"NN"},
"lamentations":	{"NNS"},
"lamented":	{"JJ","VBD","VBN"},
"lamenter":	{"NN"},
"lamenting":	{"VBG"},
"laments":	{"VBZ","NNS"},
"lamer":	{"JJR"},
"lames":	{"VBZ"},
"lamest":	{"JJS"},
"lamia":	{"NN"},
"lamiaceae":	{"NN"},
"lamina":	{"NN"},
"laminal":	{"JJ"},
"laminar":	{"JJ"},
"laminaria":	{"NN"},
"laminariaceae":	{"NN"},
"laminariales":	{"NNS"},
"laminate":	{"VBP","NN","VB"},
"laminated":	{"VBD","VBN","JJ"},
"laminates":	{"VBZ","NNS"},
"laminating":	{"VBG"},
"lamination":	{"NN"},
"laminator":	{"NN"},
"laminectomy":	{"NN"},
"laming":	{"VBG"},
"laminitis":	{"NN"},
"lamisil":	{"NN"},
"lamium":	{"NN"},
"lamivudine":	{"NN"},
"lammastide":	{"NN"},
"lammed":	{"VBD","VBN"},
"lammergeier":	{"NN"},
"lammergeyer":	{"NN"},
"lamming":	{"VBG"},
"lamna":	{"NN"},
"lamnidae":	{"NN"},
"lamp":	{"NN"},
"lampblack":	{"NN"},
"lamphouse":	{"NN"},
"lamplight":	{"NN"},
"lamplighter":	{"NN"},
"lamplit":	{"JJ"},
"lampoon":	{"VB","VBP","NN"},
"lampooned":	{"VBD","VBN"},
"lampooner":	{"NN"},
"lampooning":	{"VBG"},
"lampoons":	{"VBZ","NNS"},
"lamppost":	{"NN"},
"lampposts":	{"NNS"},
"lamprey":	{"NN"},
"lampridae":	{"NN"},
"lampris":	{"NN"},
"lampropeltis":	{"NNS"},
"lamps":	{"NNS"},
"lampshade":	{"NN"},
"lampshades":	{"NNS"},
"lampshell":	{"NN"},
"lampyridae":	{"NN"},
"lams":	{"VBZ"},
"lamy":	{"NN"},
"lan":	{"NN"},
"lana":	{"NN"},
"lanai":	{"NN"},
"lanate":	{"JJ"},
"lancaster":	{"NN"},
"lancastrian":	{"JJ","NN"},
"lance":	{"NN","VB","VBP"},
"lance-shaped":	{"JJ"},
"lanced":	{"VBD","VBN"},
"lancelet":	{"NN"},
"lancelike":	{"JJ"},
"lanceolate":	{"JJ"},
"lancer":	{"NN"},
"lancers":	{"NNS"},
"lances":	{"NNS","VBZ"},
"lancet":	{"NN"},
"lancet-shaped":	{"JJ"},
"lancetfish":	{"NN"},
"lancets":	{"NNS"},
"lancewood":	{"NN"},
"lanchou":	{"NN"},
"lanchow":	{"NN"},
"lancinate":	{"JJ"},
"lancinating":	{"JJ"},
"lancing":	{"VBG"},
"land":	{"NN","VB","VBP"},
"land-based":	{"JJ"},
"land-disposal":	{"NN"},
"land-idling":	{"JJ"},
"land-locked":	{"JJ"},
"land-ownership":	{"NN"},
"land-owning":	{"JJ"},
"land-rich":	{"JJ"},
"land-use":	{"NN"},
"landau":	{"NN"},
"landaus":	{"NNS"},
"landed":	{"JJ","VBD","VBN"},
"lander":	{"NN"},
"landers":	{"NNS"},
"landfall":	{"NN"},
"landfalls":	{"NNS"},
"landfill":	{"NN"},
"landfills":	{"NNS"},
"landgrab":	{"NN"},
"landgrabs":	{"NNS"},
"landgrave":	{"NN"},
"landholder":	{"NN"},
"landholding":	{"NN"},
"landholdings":	{"NNS"},
"landing":	{"NN","VBG"},
"landings":	{"NNS"},
"landladies":	{"NNS"},
"landlady":	{"NN"},
"landler":	{"NN"},
"landless":	{"JJ"},
"landline":	{"NN"},
"landlocked":	{"JJ"},
"landlord":	{"NN"},
"landlord-tenant":	{"JJ"},
"landlords":	{"NNS"},
"landlubber":	{"NN"},
"landlubberly":	{"JJ"},
"landlubbers":	{"NNS"},
"landman":	{"NN"},
"landmark":	{"NN","VB","VBP"},
"landmarked":	{"VBD","VBN"},
"landmarking":	{"VBG","NN"},
"landmarks":	{"NNS","VBZ"},
"landmass":	{"NN"},
"landowner":	{"NN"},
"landowners":	{"NNS"},
"landowska":	{"NN"},
"landro":	{"NN"},
"landrover":	{"NN"},
"lands":	{"NNS","VBZ"},
"landscape":	{"NN","VBP","VB"},
"landscaped":	{"VBD","VBN"},
"landscaper":	{"NN"},
"landscapers":	{"NNS"},
"landscapes":	{"NNS","VBZ"},
"landscaping":	{"NN","VBG"},
"landscapist":	{"NN"},
"landside":	{"NN"},
"landslide":	{"NN"},
"landslides":	{"NNS"},
"landslip":	{"NN"},
"landslips":	{"NNS"},
"landsmaal":	{"NN"},
"landsmal":	{"NN"},
"landsman":	{"NN"},
"landsteiner":	{"NN"},
"landward":	{"JJ"},
"landwards":	{"RB"},
"lane":	{"NN"},
"lanes":	{"NNS"},
"lanesmanship":	{"NN"},
"laney":	{"NN"},
"lang":	{"FW"},
"langbeinite":	{"NN"},
"langlaufer":	{"NN"},
"langley":	{"NN"},
"langmuir":	{"NN"},
"langobard":	{"NN"},
"langouste":	{"NN"},
"langoustine":	{"NN"},
"langsat":	{"NN"},
"langset":	{"NN"},
"langside":	{"NN"},
"langsyne":	{"RB"},
"langtry":	{"NN"},
"language":	{"NN"},
"language-housekeeper":	{"JJ"},
"languages":	{"NNS"},
"languedoc-roussillon":	{"NN"},
"languid":	{"JJ"},
"languidly":	{"RB"},
"languish":	{"VB","VBP"},
"languished":	{"VBD","VBN"},
"languisher":	{"NN"},
"languishes":	{"VBZ","NNS"},
"languishing":	{"VBG","JJ"},
"languor":	{"NN"},
"languorous":	{"JJ"},
"languorously":	{"RB"},
"langur":	{"NN"},
"laniard":	{"NN"},
"laniary":	{"JJ"},
"laniidae":	{"NN"},
"lanius":	{"NN"},
"lank":	{"JJ"},
"lankier":	{"JJR"},
"lankiest":	{"JJS"},
"lankiness":	{"NN"},
"lankmark":	{"NN"},
"lanky":	{"JJ"},
"lanolin":	{"NN"},
"lanoxin":	{"NN"},
"lansa":	{"NN"},
"lansat":	{"NN"},
"lanseh":	{"NN"},
"lanset":	{"NN"},
"lansoprazole":	{"NN"},
"lantana":	{"NN"},
"lantern":	{"NN"},
"lantern-fly":	{"NN"},
"lantern-jawed":	{"JJ"},
"lanternfish":	{"NN"},
"lanterns":	{"NNS"},
"lanthanide":	{"NN"},
"lanthanoid":	{"NN"},
"lanthanon":	{"NN"},
"lanthanotidae":	{"NN"},
"lanthanotus":	{"NNS"},
"lanthanum":	{"NN"},
"lanugo":	{"NN"},
"lanvin-owned":	{"JJ"},
"lanyard":	{"NN"},
"lanzador":	{"FW"},
"lanzhou":	{"NN"},
"lao":	{"NN","JJ"},
"lao-zi":	{"NN"},
"laocoon":	{"NN"},
"laotians":	{"NNS"},
"lap":	{"NN","VBP","VB"},
"lap-jointed":	{"JJ"},
"lap-shoulder":	{"JJ"},
"lap-strake":	{"JJ"},
"lap-straked":	{"JJ"},
"lap-streak":	{"JJ"},
"lap-streaked":	{"JJ"},
"lap-top":	{"JJ"},
"laparocele":	{"NN"},
"laparoscope":	{"NN"},
"laparoscopes":	{"NNS"},
"laparoscopy":	{"NN"},
"laparotomy":	{"NN"},
"lapboard":	{"NN"},
"lapdog":	{"NN"},
"lapel":	{"NN"},
"lapels":	{"NNS"},
"lapful":	{"NN"},
"lapidarian":	{"JJ"},
"lapidarist":	{"NN"},
"lapidary":	{"JJ","NN"},
"lapidate":	{"VB","VBP"},
"lapidated":	{"VBD","VBN"},
"lapidates":	{"VBZ"},
"lapidating":	{"VBG"},
"lapidation":	{"NN"},
"lapidator":	{"NN"},
"lapidified":	{"VBD","VBN"},
"lapidifies":	{"VBZ"},
"lapidify":	{"VB","VBP"},
"lapidifying":	{"VBG"},
"lapidist":	{"NN"},
"lapin":	{"NN"},
"laplace":	{"NN"},
"laportea":	{"NN"},
"lapped":	{"VBD","VBN"},
"lappet":	{"NN"},
"lappets":	{"NNS"},
"lappic":	{"NN"},
"lapping":	{"NN","VBG"},
"lappula":	{"NN"},
"laps":	{"NNS","VBZ"},
"lapse":	{"VB","VBP","NN"},
"lapsed":	{"VBD","VBN","JJ"},
"lapses":	{"VBZ","NNS"},
"lapsing":	{"VBG"},
"laptop":	{"NN"},
"laptops":	{"NNS"},
"laputan":	{"JJ"},
"lapwing":	{"NN"},
"lapwings":	{"NNS"},
"laramie":	{"NN"},
"larboard":	{"NN"},
"larcener":	{"NN"},
"larcenies":	{"NNS"},
"larcenist":	{"NN"},
"larcenous":	{"JJ"},
"larceny":	{"NN"},
"larch":	{"NN"},
"larches":	{"NNS"},
"lard":	{"NN","VBP","VB"},
"larded":	{"VBD","VBN"},
"larder":	{"NN"},
"larders":	{"NNS"},
"larding":	{"VBG"},
"lardizabala":	{"NN"},
"lardizabalaceae":	{"NN"},
"lardner":	{"NN"},
"lardon":	{"NN"},
"lardons":	{"NNS"},
"lardoon":	{"NN"},
"lardoons":	{"NNS"},
"lards":	{"VBZ"},
"laredo":	{"NN"},
"large":	{"JJ","NN","VB","VBP"},
"large-cap":	{"JJ"},
"large-format":	{"JJ"},
"large-handed":	{"JJ"},
"large-hearted":	{"JJ"},
"large-heartedness":	{"NN"},
"large-heath":	{"NN"},
"large-heaths":	{"NNS"},
"large-leaved":	{"JJ"},
"large-minded":	{"JJ"},
"large-print":	{"JJ"},
"large-scale":	{"JJ"},
"large-size":	{"JJ"},
"large-souled":	{"JJ"},
"larged":	{"VBD","VBN"},
"largehearted":	{"JJ"},
"largeish":	{"JJ"},
"largely":	{"RB"},
"largemouth":	{"NN"},
"largemouths":	{"NNS"},
"largen":	{"VB","VBP"},
"largened":	{"VBD","VBN"},
"largeness":	{"NN"},
"largening":	{"VBG"},
"largenose":	{"NN"},
"largens":	{"VBZ"},
"larger":	{"JJR"},
"larges":	{"VBZ"},
"largess":	{"NN"},
"largesse":	{"NN"},
"largest":	{"JJS"},
"larghetto":	{"JJ","NN"},
"larghissimo":	{"JJ"},
"larging":	{"VBG"},
"largish":	{"JJ"},
"largo":	{"NN","JJ","RB"},
"largos":	{"NNS"},
"lari":	{"NN"},
"lariat":	{"NN"},
"lariats":	{"NNS"},
"laricariidae":	{"NN"},
"larid":	{"NN"},
"laridae":	{"NN"},
"larium":	{"NN"},
"larix":	{"NN"},
"lark":	{"NN","VB","VBP"},
"larked":	{"VBD","VBN"},
"larking":	{"VBG"},
"larks":	{"NNS","VBZ"},
"larkspur":	{"NN"},
"larn":	{"VB","VBP"},
"larned":	{"VBD","VBN"},
"larning":	{"VBG"},
"larns":	{"VBZ"},
"larodopa":	{"NN"},
"larotid":	{"NN"},
"larousse":	{"NN"},
"larrea":	{"NN"},
"larrup":	{"VB","VBP"},
"larruped":	{"VBD","VBN"},
"larruping":	{"VBG"},
"larrups":	{"VBZ"},
"larus":	{"NN"},
"larva":	{"NN"},
"larvacea":	{"NN"},
"larvacean":	{"NN"},
"larvacide":	{"NN"},
"larvae":	{"NNS"},
"larval":	{"JJ"},
"larvicide":	{"NN"},
"laryngeal":	{"JJ","NN"},
"laryngectomy":	{"NN"},
"larynges":	{"NNS"},
"laryngismus":	{"NN"},
"laryngitis":	{"NN"},
"laryngopharyngeal":	{"JJ"},
"laryngopharyngitis":	{"NN"},
"laryngopharynx":	{"NN"},
"laryngoscope":	{"NN"},
"laryngospasm":	{"NN"},
"laryngostenosis":	{"NN"},
"laryngotracheobronchitis":	{"NN"},
"larynx":	{"NN"},
"larynxes":	{"NNS"},
"lasagna":	{"NN"},
"lasagne":	{"NN"},
"lasagnes":	{"NNS"},
"lasalle":	{"NN"},
"lascar":	{"NN"},
"lascivious":	{"JJ"},
"lasciviously":	{"RB"},
"lasciviousness":	{"NN"},
"lasek":	{"NN"},
"laser":	{"NN"},
"laser-beam-printer":	{"NN"},
"laser-read":	{"JJ"},
"laser-resistant":	{"JJ"},
"laser-surgery":	{"NN"},
"laser-treatment":	{"NN"},
"laser-type":	{"JJ"},
"lasers":	{"NNS"},
"lash":	{"NN","VB","VBP"},
"lash-like":	{"JJ"},
"lash-up":	{"NN"},
"lashed":	{"VBD","VBN"},
"lasher":	{"NN"},
"lashes":	{"VBZ","NNS"},
"lashing":	{"NN","VBG"},
"lashings":	{"NNS"},
"lashkar-e-jhangvi":	{"NN"},
"lashkar-e-omar":	{"NN"},
"lashkar-e-taiba":	{"NN"},
"lashkar-e-tayyiba":	{"NN"},
"lashkar-e-toiba":	{"NN"},
"lasik":	{"NN"},
"lasiocampa":	{"NN"},
"lasiocampid":	{"NN"},
"lasiocampidae":	{"NN"},
"lasiurus":	{"NN"},
"lasix":	{"NN"},
"lass":	{"NN"},
"lassa":	{"NN"},
"lasses":	{"NNS"},
"lassie":	{"NN"},
"lassitude":	{"NN"},
"lasso":	{"NN","VB","VBP"},
"lassoed":	{"VBD","VBN"},
"lassoes":	{"NNS","VBZ"},
"lassoing":	{"VBG"},
"lassos":	{"NNS","VBZ"},
"last":	{"JJ","VB","RB","NN","VBP"},
"last-ditch":	{"JJ"},
"last-gasp":	{"JJ"},
"last-minute":	{"JJ"},
"lasted":	{"VBD","VBN"},
"lastex":	{"NN"},
"lasthenia":	{"NN"},
"lasting":	{"JJ","VBG"},
"lastingly":	{"RB"},
"lastingness":	{"NN"},
"lastly":	{"RB"},
"lastreopsis":	{"NN"},
"lasts":	{"VBZ"},
"lat":	{"NN"},
"latanier":	{"NN"},
"latch":	{"NN","VB","VBP"},
"latched":	{"VBD","VBN"},
"latches":	{"VBZ","NNS"},
"latchet":	{"NN"},
"latching":	{"VBG"},
"latchkey":	{"NN","JJ"},
"latchstring":	{"NN"},
"late":	{"JJ","RB"},
"late-afternoon":	{"JJ"},
"late-blooming":	{"JJ"},
"late-breaking":	{"JJ"},
"late-comers":	{"NNS"},
"late-day":	{"JJ"},
"late-flowering":	{"JJ"},
"late-in-the-day":	{"JJ"},
"late-night":	{"JJ"},
"late-payment":	{"NN","JJ"},
"late-ripening":	{"JJ"},
"late-season":	{"JJ","RB","NN"},
"late-spring-blooming":	{"JJ"},
"late-summer":	{"JJ"},
"late-term":	{"JJ"},
"latecomer":	{"NN"},
"latecomers":	{"NNS"},
"lateen":	{"JJ"},
"lateen-rig":	{"NN"},
"lateen-rigged":	{"JJ"},
"lately":	{"RB"},
"latency":	{"NN"},
"lateness":	{"NN"},
"latent":	{"JJ"},
"later":	{"JJR","RBR"},
"lateral":	{"JJ"},
"lateralisation":	{"NN"},
"lateralise":	{"VB","VBP"},
"lateralised":	{"VBD","VBN"},
"lateralises":	{"VBZ"},
"lateralising":	{"VBG"},
"laterality":	{"NN"},
"lateralization":	{"NN"},
"lateralize":	{"VB","VBP"},
"lateralized":	{"VBD","VBN"},
"lateralizes":	{"VBZ"},
"lateralizing":	{"VBG"},
"laterally":	{"RB"},
"laterite":	{"NN"},
"latermaturing":	{"JJ"},
"latest":	{"JJS","RBS","NN"},
"latest-quarter":	{"JJ"},
"latex":	{"NN"},
"lath":	{"NN","VB","VBP"},
"lathe":	{"VB","VBP","NN"},
"lathed":	{"VBD","VBN"},
"lathee":	{"NN"},
"lather":	{"NN","VB","VBP"},
"lathered":	{"VBD","VBN"},
"lathering":	{"VBG"},
"lathers":	{"VBZ"},
"lathery":	{"JJ"},
"lathes":	{"NNS","VBZ"},
"lathi":	{"NN"},
"lathing":	{"VBG"},
"laths":	{"NNS","VBZ"},
"lathyrus":	{"NN"},
"laticifer":	{"NN"},
"latimeria":	{"NN"},
"latimeridae":	{"NN"},
"latinae":	{"NN"},
"latinate":	{"JJ"},
"latinesce":	{"NN"},
"latinoamericanos":	{"FW"},
"latish":	{"JJ"},
"latitude":	{"NN"},
"latitudes":	{"NNS"},
"latitudinal":	{"JJ"},
"latitudinarian":	{"NN","JJ"},
"latium":	{"NN"},
"latke":	{"NN"},
"latona":	{"NN"},
"latria":	{"NN"},
"latrine":	{"NN"},
"latrines":	{"NNS"},
"latrobe":	{"NN"},
"latrodectus":	{"NN"},
"lats":	{"NNS"},
"latte":	{"NN"},
"latten":	{"NN"},
"latter":	{"NN","JJ"},
"latter-day":	{"JJ"},
"latterly":	{"RB"},
"lattes":	{"NNS"},
"lattice":	{"NN","VB","VBP"},
"lattice-work":	{"NN"},
"latticed":	{"JJ","VBD","VBN"},
"latticelike":	{"JJ"},
"lattices":	{"NNS","VBZ"},
"latticework":	{"NN"},
"latticing":	{"VBG","NN"},
"laud":	{"VB","VBP"},
"laudability":	{"NN"},
"laudable":	{"JJ"},
"laudableness":	{"NN"},
"laudably":	{"RB"},
"laudanum":	{"NN"},
"laudator":	{"NN"},
"laudatory":	{"JJ"},
"lauded":	{"VBD","VBN"},
"lauder":	{"NN"},
"lauding":	{"VBG"},
"laudo":	{"NN"},
"lauds":	{"VBZ"},
"laugh":	{"NN","VB","VBP"},
"laughable":	{"JJ"},
"laughably":	{"RB"},
"laughed":	{"VBD","VBN"},
"laugher":	{"NN"},
"laughing":	{"VBG","NN","JJ"},
"laughingly":	{"RB"},
"laughingstock":	{"NN"},
"laughs":	{"VBZ","NNS"},
"laughter":	{"NN"},
"laughton":	{"NN"},
"lauhala":	{"NN"},
"launce":	{"NN"},
"launch":	{"VB","NN","VBP"},
"launch-control":	{"NN"},
"launch-pad":	{"NN"},
"launch-vehicle":	{"NN"},
"launched":	{"VBD","VBN"},
"launcher":	{"NN"},
"launchers":	{"NNS"},
"launches":	{"VBZ","NNS"},
"launching":	{"VBG","NN"},
"launchings":	{"NNS"},
"launchpad":	{"NN"},
"launder":	{"VB","VBP"},
"laundered":	{"VBN","VBD"},
"launderer":	{"NN"},
"launderers":	{"NNS"},
"launderette":	{"NN"},
"launderettes":	{"NNS"},
"laundering":	{"NN","VBG"},
"launderings":	{"NNS"},
"launders":	{"VBZ"},
"laundress":	{"NN"},
"laundries":	{"NNS"},
"laundromat":	{"NN"},
"laundromats":	{"NNS"},
"laundry":	{"NN"},
"laundry-type":	{"JJ"},
"laundryman":	{"NN"},
"laundrywoman":	{"NN"},
"lauraceae":	{"NN"},
"laureate":	{"NN","JJ"},
"laureates":	{"NNS"},
"laurel":	{"NN"},
"laurel-tree":	{"NN"},
"laureled":	{"JJ"},
"laurelled":	{"JJ"},
"laurels":	{"NNS"},
"laurelwood":	{"NN"},
"laurens":	{"NN"},
"laurentius":	{"NNS"},
"laurus":	{"NN"},
"lausanne":	{"NN"},
"lav":	{"NN"},
"lava":	{"NN"},
"lava-rocks":	{"NNS"},
"lavabo":	{"NN"},
"lavage":	{"NN"},
"lavalava":	{"NN"},
"lavalier":	{"NN"},
"lavaliere":	{"NN"},
"lavalliere":	{"NN"},
"lavandula":	{"NN"},
"lavaro":	{"NN"},
"lavas":	{"NNS"},
"lavatera":	{"NN"},
"lavation":	{"NN"},
"lavatories":	{"NNS"},
"lavatory":	{"NN"},
"lave":	{"VB","VBP"},
"laved":	{"VBD","VBN"},
"lavender":	{"NN"},
"lavender-pink":	{"JJ"},
"lavender-tinged":	{"JJ"},
"lavenders":	{"NNS"},
"laver":	{"NN"},
"laverne":	{"JJ"},
"laves":	{"VBZ"},
"laving":	{"VBG"},
"lavish":	{"JJ","VBP","VB"},
"lavished":	{"VBD","VBN"},
"lavishes":	{"VBZ"},
"lavishing":	{"VBG"},
"lavishly":	{"RB"},
"lavishness":	{"NN"},
"lavoisier":	{"NN"},
"law":	{"NN"},
"law-abiding":	{"JJ"},
"law-and-order":	{"NN"},
"law-based":	{"JJ"},
"law-breaking":	{"NN"},
"law-enforcement":	{"NN"},
"law-governed":	{"JJ"},
"law-makers":	{"NNS"},
"law-making":	{"JJ","NN"},
"law-school":	{"NN"},
"law-unto-itself":	{"JJ"},
"lawbreaker":	{"NN"},
"lawbreakers":	{"NNS"},
"lawcourt":	{"NN"},
"lawcourts":	{"NNS"},
"lawful":	{"JJ"},
"lawfully":	{"RB"},
"lawfully-begotten":	{"JJ"},
"lawfulness":	{"NN"},
"lawgiver":	{"NN"},
"lawless":	{"JJ"},
"lawlessly":	{"RB"},
"lawlessness":	{"NN"},
"lawmaker":	{"NN"},
"lawmakers":	{"NNS"},
"lawmaking":	{"JJ","NN"},
"lawman":	{"NN"},
"lawmen":	{"NNS"},
"lawn":	{"NN"},
"lawn-feeding":	{"JJ"},
"lawn-mower":	{"NN"},
"lawnmower":	{"NN"},
"lawnmowers":	{"NNS"},
"lawns":	{"NNS"},
"lawrencium":	{"NN"},
"laws":	{"NNS"},
"lawsuit":	{"NN"},
"lawsuits":	{"NNS"},
"lawton":	{"NN"},
"lawyer":	{"NN"},
"lawyerbush":	{"NN"},
"lawyering":	{"NN"},
"lawyers":	{"NNS"},
"lax":	{"JJ"},
"laxation":	{"NN"},
"laxative":	{"NN","JJ"},
"laxatives":	{"NNS"},
"laxer":	{"JJR"},
"laxest":	{"JJS"},
"laxity":	{"NN"},
"laxly":	{"RB"},
"laxness":	{"NN"},
"lay":	{"VB","VBP","JJ","NN","VBD"},
"lay-by":	{"NN"},
"lay-bys":	{"NNS"},
"lay-sisters":	{"NNS"},
"lay-up":	{"NN"},
"lay-ups":	{"NNS"},
"layabout":	{"NN"},
"layabouts":	{"NNS"},
"layby":	{"NN"},
"layer":	{"NN","VB","VBP"},
"layered":	{"VBD","VBN","JJ"},
"layering":	{"VBG"},
"layers":	{"NNS","VBZ"},
"layette":	{"NN"},
"layettes":	{"NNS"},
"layia":	{"NN"},
"laying":	{"VBG","NN"},
"layman":	{"NN"},
"laymen":	{"NNS"},
"layoff":	{"NN"},
"layoffs":	{"NNS"},
"layout":	{"NN"},
"layouts":	{"NNS"},
"layover":	{"NN"},
"layovers":	{"NNS"},
"laypeople":	{"NNS"},
"layperson":	{"NN"},
"laypersons":	{"NNS"},
"lays":	{"VBZ","NNS"},
"layup":	{"NN"},
"layups":	{"NNS"},
"lazar":	{"NN"},
"lazaret":	{"NN"},
"lazarette":	{"NN"},
"lazaretto":	{"NN"},
"laze":	{"VB","VBP","NN"},
"lazed":	{"VBD","VBN"},
"lazes":	{"VBZ"},
"lazier":	{"JJR"},
"laziest":	{"JJS"},
"lazily":	{"RB"},
"laziness":	{"NN"},
"lazing":	{"VBG"},
"lazuli":	{"NN"},
"lazuline":	{"JJ"},
"lazy":	{"JJ"},
"lazybones":	{"NN","NNS"},
"lb":	{"NN","NNS"},
"lb-plus":	{"JJ"},
"lbf.":	{"NN"},
"lbj":	{"NN"},
"lbo-related":	{"JJ"},
"lbs":	{"NNS"},
"lcm":	{"NN"},
"ld":	{"NN"},
"ld.":	{"NN"},
"ldl":	{"NN"},
"le":	{"FW"},
"lea":	{"NN"},
"leach":	{"NN","VB","VBP"},
"leached":	{"VBD","VBN"},
"leaches":	{"NNS","VBZ"},
"leaching":	{"VBG"},
"leacock":	{"NN"},
"lead":	{"NN","VB","JJ","VBP"},
"lead-colored":	{"JJ"},
"lead-coloured":	{"JJ"},
"lead-exposure":	{"JJ"},
"lead-free":	{"JJ"},
"lead-in":	{"NN"},
"lead-zinc":	{"JJ"},
"leadbelly":	{"NN"},
"leaded":	{"JJ"},
"leaded-glass":	{"JJ"},
"leaden":	{"JJ"},
"leader":	{"NN"},
"leaderless":	{"JJ"},
"leaders":	{"NNS"},
"leadership":	{"NN"},
"leadership-sanctioned":	{"JJ"},
"leaderships":	{"NNS"},
"leading":	{"VBG","JJ","NN"},
"leading-edge":	{"JJ"},
"leadings":	{"NNS"},
"leadless":	{"JJ"},
"leadoff":	{"NN"},
"leadplant":	{"NN"},
"leads":	{"VBZ","NNS"},
"leadsman":	{"NN"},
"leadwort":	{"NN"},
"leaf":	{"NN","VBP","VB"},
"leaf-book":	{"NN"},
"leaf-cutter":	{"NN"},
"leaf-like":	{"JJ"},
"leaf-miner":	{"NN"},
"leaf-roller":	{"NN"},
"leafage":	{"NN"},
"leafed":	{"JJ","VBD","VBN"},
"leafhopper":	{"NN"},
"leafier":	{"JJR"},
"leafiest":	{"JJS"},
"leafing":	{"VBG"},
"leafless":	{"JJ"},
"leaflet":	{"NN","VB","VBP"},
"leafleted":	{"VBD","VBN"},
"leafleting":	{"VBG"},
"leaflets":	{"NNS","VBZ"},
"leaflike":	{"JJ"},
"leafmold":	{"NN"},
"leafs":	{"VBZ"},
"leafstalk":	{"NN"},
"leafy":	{"JJ"},
"leafy-stemmed":	{"JJ"},
"league":	{"NN","VB","VBP"},
"leagued":	{"VBN","VBD"},
"leaguer":	{"NN","VB","VBP"},
"leaguered":	{"VBD","VBN"},
"leaguering":	{"VBG"},
"leaguers":	{"NNS","VBZ"},
"leagues":	{"NNS","VBZ"},
"leaguing":	{"VBG"},
"leak":	{"NN","VB","VBP"},
"leakage":	{"NN"},
"leakages":	{"NNS"},
"leaked":	{"VBD","VBN"},
"leaker":	{"NN"},
"leakers":	{"NNS"},
"leakier":	{"JJR"},
"leakiest":	{"JJS"},
"leakiness":	{"NN"},
"leaking":	{"VBG"},
"leakproof":	{"JJ"},
"leaks":	{"NNS","VBZ"},
"leaky":	{"JJ"},
"leal":	{"NN","JJ"},
"lean":	{"JJ","VB","VBP","NN"},
"lean-to":	{"NN"},
"lean-tos":	{"NNS"},
"leander":	{"NN"},
"leaned":	{"VBD","VBN"},
"leaner":	{"JJR"},
"leanest":	{"JJS"},
"leaning":	{"VBG","NN"},
"leanings":	{"NNS"},
"leanness":	{"NN"},
"leans":	{"VBZ"},
"leant":	{"VBD","VBN"},
"leap":	{"NN","VB","VBP"},
"leaped":	{"VBD","VBN"},
"leaper":	{"NN"},
"leapfrog":	{"VB","VBP","NN"},
"leapfrogged":	{"VBD","VBN"},
"leapfrogging":	{"VBG"},
"leapfrogs":	{"VBZ"},
"leaping":	{"NN","VBG"},
"leaps":	{"NNS","VBZ"},
"leapt":	{"VBD","VBN"},
"learier":	{"JJR"},
"leariest":	{"JJS"},
"learn":	{"VB","VBP"},
"learned":	{"VBD","VBN","JJ"},
"learnedly":	{"RB"},
"learnedness":	{"NN"},
"learner":	{"NN"},
"learners":	{"NNS"},
"learning":	{"VBG","NN"},
"learning-curve":	{"JJ"},
"learns":	{"VBZ"},
"learnt":	{"VBD","VBN"},
"leary":	{"JJ"},
"leasable":	{"JJ"},
"lease":	{"NN","VB","VBP"},
"lease-back":	{"NN"},
"lease-funded":	{"JJ"},
"lease-lend":	{"NN"},
"lease-rental":	{"JJ"},
"leaseback":	{"NN"},
"leasebacks":	{"NNS"},
"leased":	{"VBD","VBN"},
"leasehold":	{"JJ","RB","NN"},
"leaseholder":	{"NN"},
"leaseholders":	{"NNS"},
"leaseholds":	{"NNS"},
"leases":	{"VBZ","NNS"},
"leash":	{"NN","VBP","VB"},
"leashed":	{"VBD","VBN"},
"leashes":	{"NNS","VBZ"},
"leashing":	{"VBG"},
"leasing":	{"NN","VBG"},
"least":	{"JJS","RBS","RB","NN","DT"},
"least-cost":	{"JJ"},
"least-developed-nation":	{"JJ"},
"leastways":	{"RB"},
"leastwise":	{"RB"},
"leasure":	{"NN"},
"leather":	{"NN","VB","VBP"},
"leather-bound":	{"JJ"},
"leather-hard":	{"JJ"},
"leather-leafed":	{"JJ"},
"leather-leaved":	{"JJ"},
"leather-men":	{"NNS"},
"leatherback":	{"NN"},
"leatherbound":	{"JJ"},
"leathered":	{"VBD","VBN"},
"leatherette":	{"NN"},
"leatherfish":	{"NN"},
"leathering":	{"VBG"},
"leatherjack":	{"NN"},
"leatherjacket":	{"NN"},
"leatherleaf":	{"NN"},
"leatherlike":	{"JJ"},
"leatherneck":	{"NN"},
"leathers":	{"NNS","VBZ"},
"leatherwood":	{"NN"},
"leatherwork":	{"NN"},
"leathery":	{"JJ"},
"leave":	{"VB","VBP","NN"},
"leave-taking":	{"NN"},
"leaved":	{"JJ"},
"leaven":	{"VB","VBP","NN"},
"leavened":	{"VBD","VBN","JJ"},
"leavening":	{"NN","VBG"},
"leavens":	{"VBZ"},
"leaver":	{"NN"},
"leaves":	{"NNS","VBZ"},
"leaving":	{"VBG","NN"},
"leavings":	{"NNS"},
"leavitt":	{"NN"},
"lebanese-controlled":	{"JJ"},
"lebensraum":	{"NN"},
"lebistes":	{"NNS"},
"lebrun":	{"NN"},
"lecanopteris":	{"NNS"},
"lecanora":	{"NN"},
"lecanoraceae":	{"NN"},
"leccinum":	{"NN"},
"lech":	{"VB","VBP","NN"},
"lechanorales":	{"NNS"},
"lechatelierite":	{"NN"},
"leched":	{"VBD","VBN"},
"lecher":	{"NN"},
"lecherous":	{"JJ"},
"lecherously":	{"RB"},
"lecherousness":	{"NN"},
"lechers":	{"NNS"},
"lechery":	{"NN"},
"leches":	{"VBZ"},
"leching":	{"VBG"},
"lechwe":	{"NN"},
"lecithin":	{"NN"},
"lectern":	{"NN"},
"lecterns":	{"NNS"},
"lectin":	{"NN"},
"lector":	{"NN"},
"lecture":	{"NN","VB","VBP"},
"lectured":	{"VBD","VBN"},
"lecturer":	{"NN"},
"lecturers":	{"NNS"},
"lectures":	{"NNS","VBZ"},
"lectureship":	{"NN"},
"lectureships":	{"NNS"},
"lecturing":	{"VBG"},
"lecythidaceae":	{"NN"},
"led":	{"VBD","VBN"},
"ledbetter":	{"NN"},
"lede":	{"NN"},
"lederer":	{"NN"},
"lederhosen":	{"NNS"},
"ledge":	{"NN"},
"ledgeman":	{"NN"},
"ledger":	{"NN"},
"ledgers":	{"NNS"},
"ledges":	{"NNS"},
"ledum":	{"NN"},
"lee":	{"NN","JJ"},
"lee-based":	{"JJ"},
"leech":	{"NN"},
"leechee":	{"NN"},
"leeches":	{"NNS"},
"leechlike":	{"JJ"},
"leek":	{"NN"},
"leeks":	{"NNS"},
"leer":	{"NN","VB","VBP"},
"leered":	{"VBD","VBN"},
"leering":	{"VBG"},
"leers":	{"VBZ","NNS"},
"leery":	{"JJ"},
"lees":	{"NNS"},
"leeuwenhoek":	{"NN"},
"leeward":	{"JJ","NN","RB"},
"leeway":	{"NN"},
"leflunomide":	{"NN"},
"left":	{"VBD","VBN","JJ","NN","RB"},
"left-center":	{"JJ","NN"},
"left-centerfield":	{"JJ"},
"left-eyed":	{"JJ"},
"left-field":	{"JJ"},
"left-front":	{"JJ"},
"left-hand":	{"JJ"},
"left-handed":	{"JJ"},
"left-handedness":	{"NN"},
"left-hander":	{"NN"},
"left-handers":	{"NNS"},
"left-justified":	{"JJ"},
"left-leaning":	{"JJ","NN"},
"left-of-center":	{"JJ"},
"left-right":	{"JJ"},
"left-slanting":	{"JJ"},
"left-stream":	{"JJ"},
"left-wing":	{"JJ","NN"},
"left-winger":	{"JJ","NN"},
"left-wingers":	{"NNS"},
"leftfield":	{"NN"},
"lefthander":	{"NN"},
"lefthanders":	{"NNS"},
"lefties":	{"NNS"},
"leftish":	{"JJ","NN"},
"leftism":	{"NN"},
"leftist":	{"JJ","NN"},
"leftists":	{"NNS"},
"leftmost":	{"JJ"},
"leftover":	{"JJ","NN"},
"leftovers":	{"NNS"},
"leftward":	{"RB","JJ"},
"leftwards":	{"RB"},
"lefty":	{"NN","JJ"},
"leg":	{"NN","VB","VBP"},
"leg-pull":	{"NN"},
"leg-pulling":	{"NN"},
"leg-split":	{"JJ"},
"legacies":	{"NNS"},
"legacy":	{"NN"},
"legal":	{"JJ"},
"legal-ethics":	{"NNS"},
"legal-lending":	{"JJ"},
"legal-services":	{"NNS","JJ"},
"legalese":	{"NN"},
"legalisation":	{"NN"},
"legalise":	{"VB","VBP"},
"legalised":	{"VBD","VBN"},
"legalises":	{"VBZ"},
"legalising":	{"VBG"},
"legalism":	{"NN"},
"legalistic":	{"JJ"},
"legality":	{"NN"},
"legalization":	{"NN"},
"legalize":	{"VB","VBP"},
"legalized":	{"VBD","VBN"},
"legalizes":	{"VBZ"},
"legalizing":	{"VBG"},
"legally":	{"RB"},
"legate":	{"NN"},
"legatee":	{"NN"},
"legatees":	{"NNS"},
"legates":	{"NNS"},
"legateship":	{"NN"},
"legation":	{"NN"},
"legations":	{"NNS"},
"legato":	{"JJ","RB"},
"legend":	{"NN"},
"legendary":	{"JJ"},
"legends":	{"NNS"},
"leger":	{"NN"},
"legerdemain":	{"NN"},
"legerity":	{"NN"},
"legged":	{"JJ","VBD","VBN"},
"legging":	{"NN","VBG"},
"leggings":	{"NNS"},
"leggy":	{"JJ"},
"leghorn":	{"NN"},
"legibility":	{"NN"},
"legible":	{"JJ"},
"legibly":	{"RB"},
"legion":	{"NN","JJ"},
"legionaries":	{"NNS"},
"legionary":	{"NN"},
"legionella":	{"NN"},
"legionnaire":	{"NN"},
"legionnaires":	{"NNS"},
"legions":	{"NNS"},
"legislate":	{"VB","VBP"},
"legislated":	{"VBD","VBN"},
"legislates":	{"VBZ"},
"legislating":	{"VBG"},
"legislation":	{"NN"},
"legislation-delaying":	{"JJ"},
"legislative":	{"JJ"},
"legislatively":	{"RB"},
"legislator":	{"NN"},
"legislators":	{"NNS"},
"legislatorship":	{"NN"},
"legislature":	{"NN"},
"legislatures":	{"NNS"},
"legitimacy":	{"NN"},
"legitimate":	{"JJ","VB","VBP"},
"legitimated":	{"VBD","VBN"},
"legitimately":	{"RB"},
"legitimates":	{"VBZ"},
"legitimating":	{"VBG"},
"legitimation":	{"NN"},
"legitimatise":	{"VB","VBP"},
"legitimatised":	{"VBD","VBN"},
"legitimatises":	{"VBZ"},
"legitimatising":	{"VBG"},
"legitimatize":	{"VB","VBP"},
"legitimatized":	{"VBD","VBN"},
"legitimatizes":	{"VBZ"},
"legitimatizing":	{"VBG"},
"legitimise":	{"VB","VBP"},
"legitimised":	{"VBD","VBN"},
"legitimises":	{"VBZ"},
"legitimising":	{"VBG"},
"legitimize":	{"VB","VBP"},
"legitimized":	{"VBD","VBN"},
"legitimizes":	{"VBZ"},
"legitimizing":	{"VBG"},
"legless":	{"JJ"},
"leglike":	{"JJ"},
"lego":	{"NN"},
"legs":	{"NNS","VBZ"},
"legume":	{"NN"},
"legumes":	{"NNS"},
"leguminosae":	{"NN"},
"leguminous":	{"JJ"},
"lehar":	{"NN"},
"lehigh":	{"NN"},
"lei":	{"NN"},
"leibnitz":	{"NN"},
"leibnitzian":	{"JJ"},
"leibnizian":	{"JJ"},
"leiden":	{"NN"},
"leiomyoma":	{"NN"},
"leiomyosarcoma":	{"NN"},
"leiopelma":	{"NN"},
"leiopelmatidae":	{"NN"},
"leiophyllum":	{"NN"},
"leipoa":	{"NN"},
"leishmania":	{"NN"},
"leishmaniasis":	{"NN"},
"leishmaniosis":	{"NN"},
"leister":	{"NN"},
"leisure":	{"NN"},
"leisure-oriented":	{"JJ"},
"leisure-related":	{"JJ"},
"leisure-services":	{"JJ"},
"leisured":	{"JJ"},
"leisureliness":	{"NN"},
"leisurely":	{"JJ","RB"},
"leitmotif":	{"NN"},
"leitmotifs":	{"NNS"},
"leitmotiv":	{"NN"},
"leitneria":	{"NN"},
"leitneriaceae":	{"NN"},
"lek":	{"NN"},
"lekvar":	{"NN"},
"lem":	{"NN"},
"lemaireocereus":	{"NNS"},
"lemaitre":	{"NN"},
"lemanderin":	{"NN"},
"lemma":	{"NN"},
"lemmas":	{"NNS"},
"lemme":	{"MD"},
"lemming":	{"NN"},
"lemmings":	{"NNS"},
"lemmon":	{"NN"},
"lemmus":	{"NN"},
"lemna":	{"NN"},
"lemnaceae":	{"NN"},
"lemniscus":	{"NN"},
"lemnos":	{"NNS"},
"lemon":	{"NN","JJ"},
"lemon-lime":	{"JJ"},
"lemon-meringue":	{"NN"},
"lemon-scented":	{"JJ"},
"lemon-wood":	{"NN"},
"lemonade":	{"NN"},
"lemonades":	{"NNS"},
"lemongrass":	{"NN"},
"lemonlike":	{"JJ"},
"lemons":	{"NNS"},
"lemonwood":	{"NN"},
"lemony":	{"JJ"},
"lempira":	{"NN"},
"lemur":	{"NN"},
"lemuridae":	{"NN"},
"lemuroidea":	{"NN"},
"lemurs":	{"NNS"},
"len":	{"NN"},
"lenard":	{"NN"},
"lend":	{"VB","VBP"},
"lend-lease":	{"NN","VB","VBP"},
"lend-leased":	{"VBD","VBN"},
"lend-leases":	{"VBZ"},
"lend-leasing":	{"VBG"},
"lendable":	{"JJ"},
"lender":	{"NN"},
"lenders":	{"NNS"},
"lending":	{"NN","VBG"},
"lendl":	{"NN"},
"lends":	{"VBZ"},
"length":	{"NN"},
"lengthen":	{"VB","VBP"},
"lengthened":	{"VBD","VBN"},
"lengthening":	{"VBG"},
"lengthens":	{"VBZ"},
"lengthier":	{"JJR"},
"lengthiest":	{"JJS"},
"lengthily":	{"RB"},
"lengthiness":	{"NN"},
"lengths":	{"NNS"},
"lengthways":	{"RB"},
"lengthwise":	{"RB"},
"lengthy":	{"JJ"},
"lenience":	{"NN"},
"leniency":	{"NN"},
"lenient":	{"JJ"},
"leniently":	{"RB"},
"lenified":	{"VBD","VBN"},
"lenifies":	{"VBZ"},
"lenify":	{"VB","VBP"},
"lenifying":	{"VBG"},
"leninism":	{"NN"},
"leninist":	{"NN"},
"lenitive":	{"JJ","NN"},
"lenity":	{"NN"},
"lennoaceae":	{"NN"},
"lennox":	{"NN"},
"leno":	{"NN"},
"lens":	{"NN"},
"lensed":	{"JJ"},
"lenses":	{"NNS"},
"lensing":	{"NN"},
"lensman":	{"NN"},
"lent":	{"VBD","VBN"},
"lententide":	{"NN"},
"lentia":	{"NN"},
"lentibulariaceae":	{"NN"},
"lentic":	{"JJ"},
"lenticel":	{"NN"},
"lenticular":	{"JJ"},
"lentiform":	{"JJ"},
"lentiginose":	{"JJ"},
"lentiginous":	{"JJ"},
"lentigo":	{"NN"},
"lentil":	{"NN"},
"lentils":	{"NNS"},
"lentinus":	{"NN"},
"lentisk":	{"NN"},
"lentissimo":	{"JJ"},
"lento":	{"JJ","RB"},
"leonardesque":	{"JJ"},
"leonardo":	{"NN"},
"leonberg":	{"NN"},
"leoncita":	{"NN"},
"leonine":	{"JJ"},
"leonotis":	{"NNS"},
"leontief":	{"NN"},
"leontocebus":	{"NNS"},
"leontodon":	{"NN"},
"leontopodium":	{"NN"},
"leonurus":	{"NN"},
"leopard":	{"NN"},
"leopard's-bane":	{"NN"},
"leopard-trimmed":	{"JJ"},
"leopardbane":	{"NN"},
"leopardess":	{"NN"},
"leopards":	{"NNS"},
"leopoldville":	{"NN"},
"leotard":	{"NN"},
"leotards":	{"NNS"},
"lepadidae":	{"NN"},
"lepanto":	{"NN"},
"lepas":	{"NNS"},
"lepechinia":	{"NN"},
"leper":	{"NN"},
"lepers":	{"NNS"},
"lepidium":	{"NN"},
"lepidobotryaceae":	{"NN"},
"lepidobotrys":	{"NNS"},
"lepidochelys":	{"NNS"},
"lepidocrocite":	{"NN"},
"lepidocybium":	{"NN"},
"lepidodendraceae":	{"NN"},
"lepidodendrales":	{"NNS"},
"lepidolite":	{"NN"},
"lepidomelane":	{"NN"},
"lepidophobia":	{"NN"},
"lepidoptera":	{"NNS"},
"lepidopteran":	{"JJ"},
"lepidopterist":	{"NN"},
"lepidopterologist":	{"NN"},
"lepidopterology":	{"NN"},
"lepidopteron":	{"NN"},
"lepidoptery":	{"NN"},
"lepidosauria":	{"NN"},
"lepidote":	{"JJ"},
"lepidothamnus":	{"NN"},
"lepiota":	{"NN"},
"lepiotaceae":	{"NN"},
"lepisma":	{"NN"},
"lepismatidae":	{"NN"},
"lepisosteidae":	{"NN"},
"lepisosteus":	{"NNS"},
"lepomis":	{"NN"},
"leporid":	{"NN"},
"leporidae":	{"NN"},
"leporide":	{"NN"},
"leppy":	{"NN"},
"leprae":	{"NNS"},
"leprechaun":	{"NN"},
"leprose":	{"JJ"},
"leprosy":	{"NN"},
"leprous":	{"JJ"},
"leptarrhena":	{"NN"},
"leptinotarsa":	{"NN"},
"leptocephalus":	{"NNS"},
"leptodactylid":	{"NN"},
"leptodactylidae":	{"NN"},
"leptodactylus":	{"NNS"},
"leptoglossus":	{"NNS"},
"leptomeninges":	{"NNS"},
"leptomeningitis":	{"NNS"},
"lepton":	{"NN"},
"leptopteris":	{"NNS"},
"leptoptilus":	{"NNS"},
"leptorhine":	{"JJ"},
"leptorrhine":	{"JJ"},
"leptorrhinian":	{"JJ"},
"leptorrhinic":	{"JJ"},
"leptospira":	{"NN"},
"leptospirosis":	{"NN"},
"leptosporangiate":	{"JJ"},
"leptosporangium":	{"NN"},
"leptotene":	{"NN"},
"leptotyphlopidae":	{"NN"},
"leptotyphlops":	{"NNS"},
"lepus":	{"NN"},
"ler":	{"NN"},
"leresis":	{"NN"},
"lermontov":	{"NN"},
"lerner":	{"NN"},
"lerot":	{"NN"},
"leroy":	{"NN"},
"les":	{"FW"},
"lesbian":	{"JJ","NN"},
"lesbianism":	{"NN"},
"lesbians":	{"NNS"},
"lesbos":	{"NNS"},
"lescol":	{"NN"},
"lesion":	{"NN"},
"lesions":	{"NNS"},
"lespedeza":	{"NN"},
"lesquerella":	{"NN"},
"less":	{"JJR","RBR","NN","IN"},
"less-advanced":	{"JJ"},
"less-aggressive":	{"JJ"},
"less-ambitious":	{"JJ"},
"less-binding":	{"JJ"},
"less-complicated":	{"JJ"},
"less-conservative":	{"JJ"},
"less-creditworthy":	{"JJ"},
"less-cyclical":	{"JJ"},
"less-developed":	{"JJ"},
"less-developed-country":	{"JJ"},
"less-dramatic":	{"JJ"},
"less-educated":	{"JJ"},
"less-effective":	{"JJ"},
"less-established":	{"JJ"},
"less-expensive":	{"JJ"},
"less-experienced":	{"JJ"},
"less-hurried":	{"JJ"},
"less-indomitable":	{"JJ"},
"less-influential":	{"JJ"},
"less-intrusive":	{"JJ"},
"less-obvious":	{"JJ"},
"less-polluting":	{"JJ"},
"less-popular":	{"JJ"},
"less-profitable":	{"JJ"},
"less-restrictive":	{"JJ"},
"less-risky":	{"JJ"},
"less-self-confident":	{"JJ"},
"less-serious":	{"JJ"},
"less-sweeping":	{"JJ"},
"less-than-alarming":	{"JJ"},
"less-than-altruistic":	{"JJ"},
"less-than-amicable":	{"JJ"},
"less-than-brilliant":	{"JJ"},
"less-than-carload":	{"JJ"},
"less-than-dazzling":	{"JJ"},
"less-than-diffident":	{"JJ"},
"less-than-exacting":	{"JJ"},
"less-than-expected":	{"JJ"},
"less-than-half-time":	{"JJ"},
"less-than-perfect":	{"JJ"},
"less-than-robust":	{"JJ"},
"less-than-successful":	{"JJ"},
"less-than-truckload":	{"JJ"},
"less-toxic":	{"JJ"},
"less-traveled":	{"JJ"},
"less-visible":	{"JJ"},
"lessee":	{"NN"},
"lessees":	{"NNS"},
"lessen":	{"VB","VBP"},
"lessened":	{"VBD","VBN"},
"lessening":	{"VBG","NN"},
"lessens":	{"VBZ"},
"lesseps":	{"NNS"},
"lesser":	{"JJ","RB"},
"lesser-developed":	{"JJ"},
"lesser-developed-country":	{"JJ"},
"lesser-known":	{"JJ"},
"lesson":	{"NN","VB","VBP"},
"lesson-learning":	{"NN"},
"lessoned":	{"VBD","VBN"},
"lessoning":	{"VBG"},
"lessons":	{"NNS","VBZ"},
"lessor":	{"NN"},
"lessors":	{"NNS"},
"lest":	{"IN"},
"lesvos":	{"NNS"},
"let":	{"VB","VBD","VBP","VBN","NN"},
"let-down":	{"NN"},
"let-downs":	{"NNS"},
"let-the-locals-decide":	{"JJ"},
"letch":	{"NN"},
"letdown":	{"NN"},
"lethal":	{"JJ"},
"lethality":	{"NN"},
"lethargic":	{"JJ"},
"lethargically":	{"RB"},
"lethargies":	{"NNS"},
"lethargy":	{"NN"},
"leto":	{"NN"},
"lets":	{"VBZ","NNS"},
"lett":	{"NN"},
"letter":	{"NN","VB","VBP"},
"letter-perfect":	{"JJ"},
"letter-writing":	{"JJ"},
"lettercard":	{"NN"},
"lettered":	{"JJ","VBD","VBN"},
"letterer":	{"NN"},
"letterhead":	{"NN"},
"letterheads":	{"NNS"},
"lettering":	{"NN","VBG"},
"letterman":	{"NN"},
"lettermen":	{"NNS"},
"letterpress":	{"NN"},
"letters":	{"NNS","VBZ"},
"letting":	{"VBG","NN"},
"lettings":	{"NNS"},
"lettish":	{"NN"},
"lettuce":	{"NN"},
"lettuces":	{"NNS"},
"letup":	{"NN"},
"leu":	{"NN"},
"leucadendron":	{"NN"},
"leucaemia":	{"NN"},
"leucaena":	{"NN"},
"leucanthemum":	{"NN"},
"leucine":	{"NN"},
"leuciscus":	{"NNS"},
"leucocyte":	{"NN"},
"leucocytosis":	{"NN"},
"leucocytozoan":	{"NN"},
"leucocytozoon":	{"NN"},
"leucogenes":	{"NNS"},
"leucoma":	{"NN"},
"leucopenia":	{"NN"},
"leucorrhea":	{"NN"},
"leucothoe":	{"NN"},
"leucotomy":	{"NN"},
"leuctra":	{"NN"},
"leukaemia":	{"NN"},
"leukemia":	{"NN"},
"leukeran":	{"NN"},
"leukocyte":	{"NN"},
"leukocytosis":	{"NN"},
"leukoderma":	{"NN"},
"leukoencephalitis":	{"NN"},
"leukoma":	{"NN"},
"leukopenia":	{"NN"},
"leukorrhea":	{"NN"},
"leukotomy":	{"NN"},
"leuwenhoek":	{"NN"},
"lev":	{"NN"},
"leva":	{"NNS"},
"levallorphan":	{"NN"},
"levamisole":	{"NN"},
"levant":	{"VB","VBP"},
"levanted":	{"VBD","VBN"},
"levanter":	{"NN"},
"levanting":	{"VBG"},
"levants":	{"VBZ"},
"levator":	{"NN"},
"levee":	{"NN"},
"levees":	{"NNS"},
"level":	{"NN","VB","JJ","VBP"},
"level-headed":	{"JJ"},
"leveled":	{"VBD","VBN"},
"leveler":	{"NN"},
"levelers":	{"NNS"},
"levelheaded":	{"JJ"},
"levelheadedness":	{"NN"},
"leveling":	{"NN","VBG"},
"levelled":	{"VBD","VBN"},
"leveller":	{"NN"},
"levellers":	{"NNS"},
"levelling":	{"VBG","NN"},
"levels":	{"NNS","VBZ"},
"lever":	{"NN","VB","VBP"},
"lever-action":	{"JJ"},
"leverage":	{"NN","VB","VBP"},
"leveraged":	{"VBD","VBN","JJ"},
"leveraged-buy-out":	{"JJ","NN"},
"leveraged-takeover":	{"NN"},
"leverages":	{"VBZ"},
"leveraging":	{"VBG"},
"levered":	{"VBD","VBN"},
"leveret":	{"NN"},
"levering":	{"VBG"},
"levers":	{"NNS","VBZ"},
"levi-clad":	{"JJ"},
"levi-strauss":	{"NNS"},
"leviathan":	{"NN"},
"leviathans":	{"NNS"},
"levied":	{"VBD","VBN"},
"levies":	{"VBZ","NNS"},
"levirate":	{"NN"},
"levisticum":	{"NN"},
"levitate":	{"VB","VBP"},
"levitated":	{"VBD","VBN"},
"levitates":	{"VBZ"},
"levitating":	{"VBG"},
"levitation":	{"NN"},
"levitra":	{"NN"},
"levity":	{"NN"},
"levodopa":	{"NN"},
"levorotary":	{"JJ"},
"levorotation":	{"NN"},
"levorotatory":	{"JJ"},
"levulose":	{"NN"},
"levy":	{"VB","VBP","NN"},
"levying":	{"VBG"},
"lewd":	{"JJ"},
"lewdly":	{"RB"},
"lewdness":	{"NN"},
"lewisia":	{"NN"},
"lewiston":	{"NN"},
"lex":	{"NN"},
"lexeme":	{"NN"},
"lexemes":	{"NNS"},
"lexical":	{"JJ"},
"lexicalisation":	{"NN"},
"lexicalise":	{"VB","VBP"},
"lexicalised":	{"VBD","VBN"},
"lexicalises":	{"VBZ"},
"lexicalising":	{"VBG"},
"lexicalization":	{"NN"},
"lexicalize":	{"VB","VBP"},
"lexicalized":	{"VBD","VBN"},
"lexicalizes":	{"VBZ"},
"lexicalizing":	{"VBG"},
"lexically":	{"RB"},
"lexicographer":	{"NN"},
"lexicographers":	{"NNS"},
"lexicographic":	{"JJ"},
"lexicographical":	{"JJ"},
"lexicography":	{"NN"},
"lexicologist":	{"NN"},
"lexicology":	{"NN"},
"lexicon":	{"NN"},
"lexicons":	{"NNS"},
"lexicostatistic":	{"JJ"},
"lexicostatistics":	{"NN"},
"lexington-based":	{"JJ"},
"lexis":	{"NN"},
"ley":	{"NN"},
"leycesteria":	{"NN"},
"leyden":	{"NN"},
"leymus":	{"NN"},
"leyte":	{"NN"},
"lgb":	{"NN"},
"lgv":	{"NN"},
"lh":	{"NN"},
"lhasa":	{"NN"},
"lhotse":	{"NN"},
"li":	{"NN","NNS"},
"liabilities":	{"NNS"},
"liability":	{"NN"},
"liable":	{"JJ"},
"liaise":	{"VB","VBP"},
"liaised":	{"VBD","VBN"},
"liaises":	{"VBZ"},
"liaising":	{"VBG"},
"liaison":	{"NN"},
"liaisons":	{"NNS"},
"liakoura":	{"NN"},
"liana":	{"NN"},
"liao":	{"NN"},
"liar":	{"NN"},
"liars":	{"NNS"},
"liatris":	{"NN"},
"libation":	{"NN"},
"libations":	{"NNS"},
"libber":	{"NN"},
"libby":	{"NN"},
"libel":	{"NN","VB","VBP"},
"libeled":	{"VBD","VBN"},
"libeler":	{"NN"},
"libeling":	{"VBG"},
"libelled":	{"VBD","VBN"},
"libelling":	{"VBG"},
"libellous":	{"JJ"},
"libelous":	{"JJ"},
"libels":	{"VBZ","NNS"},
"liberal":	{"JJ","NN"},
"liberal-arts":	{"NNS"},
"liberal-conservative":	{"JJ"},
"liberal-democratic":	{"JJ"},
"liberal-led":	{"JJ"},
"liberalisation":	{"NN"},
"liberalise":	{"VB","VBP"},
"liberalised":	{"VBD","VBN"},
"liberalises":	{"VBZ"},
"liberalising":	{"VBG"},
"liberalism":	{"NN"},
"liberalist":	{"NN"},
"liberalistic":	{"JJ"},
"liberality":	{"NN"},
"liberalization":	{"NN"},
"liberalize":	{"VB","VBP"},
"liberalized":	{"VBD","VBN"},
"liberalizes":	{"VBZ"},
"liberalizing":	{"VBG"},
"liberally":	{"RB"},
"liberalness":	{"NN"},
"liberals":	{"NNS"},
"liberate":	{"VB","VBP"},
"liberated":	{"VBD","VBN","JJ"},
"liberates":	{"VBZ"},
"liberating":	{"VBG","JJ"},
"liberation":	{"NN"},
"liberator":	{"NN"},
"liberators":	{"NNS"},
"libertarian":	{"NN","JJ"},
"libertarianism":	{"NN"},
"libertarians":	{"NNS"},
"liberties":	{"NNS"},
"libertine":	{"NN","JJ"},
"libertines":	{"NNS"},
"liberty":	{"NN"},
"libidinal":	{"JJ"},
"libidinous":	{"JJ"},
"libido":	{"NN"},
"libidos":	{"NNS"},
"libocedrus":	{"NN"},
"libra":	{"NN"},
"librarian":	{"NN"},
"librarian-board":	{"NN"},
"librarians":	{"NNS"},
"librarianship":	{"NN"},
"libraries":	{"NNS"},
"library":	{"NN"},
"librate":	{"VB","VBP"},
"librated":	{"VBD","VBN"},
"librates":	{"VBZ"},
"librating":	{"VBG"},
"libration":	{"NN"},
"libretti":	{"NNS"},
"librettist":	{"NN"},
"librettists":	{"NNS"},
"libretto":	{"NN"},
"librettos":	{"NNS"},
"libritabs":	{"NNS"},
"librium":	{"NN"},
"lice":	{"NNS"},
"licence":	{"NN","VB","VBP"},
"licenced":	{"JJ","VBD","VBN"},
"licences":	{"NNS","VBZ"},
"licencing":	{"VBG"},
"license":	{"NN","VB","VBP"},
"licensed":	{"VBN","JJ","VBD"},
"licensee":	{"NN"},
"licensees":	{"NNS"},
"licenser":	{"NN"},
"licenses":	{"NNS","VBZ"},
"licensing":	{"VBG","JJ"},
"licentiate":	{"NN"},
"licentiates":	{"NNS"},
"licentious":	{"JJ"},
"licentiously":	{"RB"},
"licentiousness":	{"NN"},
"lichanura":	{"NN"},
"lichee":	{"NN"},
"lichees":	{"NNS"},
"lichen":	{"NN","VB","VBP"},
"lichen-like":	{"JJ"},
"lichenales":	{"NNS"},
"lichened":	{"VBD","VBN","JJ"},
"lichening":	{"VBG"},
"lichenoid":	{"JJ"},
"lichenose":	{"JJ"},
"lichenous":	{"JJ"},
"lichens":	{"NNS","VBZ"},
"lichgate":	{"NN"},
"lichi":	{"NN"},
"licit":	{"JJ"},
"licitly":	{"RB"},
"licitness":	{"NN"},
"lick":	{"VB","VBP","NN"},
"licked":	{"VBD","VBN"},
"licking":	{"NN","VBG"},
"licks":	{"VBZ","NNS"},
"licorice":	{"NN"},
"lid":	{"NN"},
"lidar":	{"NN"},
"lidded":	{"JJ"},
"lidless":	{"JJ"},
"lido":	{"NN"},
"lidocaine":	{"NN"},
"lidos":	{"NNS"},
"lids":	{"NNS"},
"lie":	{"VB","VBP","NN"},
"lie-abed":	{"VBD","VBN"},
"lie-down":	{"NN"},
"lie-in":	{"NN"},
"lied":	{"VBD","VBN","NN"},
"lieder":	{"NNS"},
"liederkranz":	{"NN"},
"lief":	{"RB"},
"liege":	{"NN","JJ"},
"liegeman":	{"NN"},
"lieges":	{"NNS"},
"lien":	{"NN"},
"lienal":	{"JJ"},
"liens":	{"NNS"},
"liepaja":	{"NN"},
"lies":	{"VBZ","NNS"},
"lietuva":	{"NN"},
"lieu":	{"NN"},
"lieutenancy":	{"NN"},
"lieutenant":	{"NN"},
"lieutenant-governor":	{"NN"},
"lieutenants":	{"NNS"},
"life":	{"NN"},
"life-and-death":	{"JJ"},
"life-bettering":	{"JJ"},
"life-blood":	{"NN"},
"life-changing":	{"JJ"},
"life-contracts":	{"JJ"},
"life-cycle":	{"NN"},
"life-death":	{"JJ"},
"life-enhancement":	{"NN"},
"life-giving":	{"JJ"},
"life-guard":	{"NN"},
"life-guards":	{"NNS"},
"life-health":	{"NN"},
"life-insurance":	{"NN"},
"life-jacket":	{"NN"},
"life-jackets":	{"NNS"},
"life-like":	{"JJ"},
"life-long":	{"JJ"},
"life-of-contract":	{"JJ"},
"life-of-man":	{"NN"},
"life-or-death":	{"JJ"},
"life-preserver":	{"NN"},
"life-preservers":	{"NNS"},
"life-raft":	{"NN"},
"life-rafts":	{"NNS"},
"life-saver":	{"NN"},
"life-savers":	{"NNS"},
"life-saving":	{"JJ","NN"},
"life-size":	{"JJ"},
"life-sized":	{"JJ"},
"life-span":	{"NN"},
"life-style":	{"NN"},
"life-support":	{"JJ"},
"life-supporting":	{"JJ"},
"life-sustaining":	{"JJ"},
"life-threatening":	{"JJ"},
"life-time":	{"NN"},
"life-work":	{"NN"},
"lifebelt":	{"NN"},
"lifebelts":	{"NNS"},
"lifeblood":	{"NN"},
"lifeboat":	{"NN"},
"lifeboats":	{"NNS"},
"lifebuoy":	{"NN"},
"lifeguard":	{"NN","VB","VBP"},
"lifeguarded":	{"VBD","VBN"},
"lifeguarding":	{"VBG"},
"lifeguards":	{"NNS","VBZ"},
"lifehack":	{"NN","VB","VBP"},
"lifehacked":	{"VBD","VBN"},
"lifehacker":	{"NN"},
"lifehacking":	{"VBG"},
"lifehacks":	{"NNS","VBZ"},
"lifeless":	{"JJ"},
"lifelessly":	{"RB"},
"lifelessness":	{"NN"},
"lifelike":	{"JJ"},
"lifeline":	{"NN"},
"lifelines":	{"NNS"},
"lifelong":	{"JJ"},
"lifer":	{"NN"},
"lifes":	{"NNS"},
"lifesaver":	{"NN"},
"lifesavers":	{"NNS"},
"lifesaving":	{"NN","JJ"},
"lifesize":	{"JJ"},
"lifespan":	{"NN"},
"lifespans":	{"NNS"},
"lifestyle":	{"NN"},
"lifestyles":	{"NNS"},
"lifetime":	{"NN"},
"lifetimes":	{"NNS"},
"lifework":	{"NN"},
"lifo":	{"NN"},
"lift":	{"VB","NN","VBP"},
"lift-attendant":	{"NN"},
"lift-attendants":	{"NNS"},
"lift-off":	{"NN"},
"lift-offs":	{"NNS"},
"lift-ticket":	{"JJ","NN"},
"lifted":	{"VBN","VBD"},
"lifter":	{"NN"},
"lifters":	{"NNS"},
"lifting":	{"VBG","NN"},
"liftman":	{"NN"},
"liftoff":	{"NN"},
"liftoffs":	{"NNS"},
"lifts":	{"VBZ","NNS"},
"ligament":	{"NN"},
"ligaments":	{"NNS"},
"ligan":	{"NN"},
"ligand":	{"NN"},
"ligands":	{"NNS"},
"ligate":	{"VB","VBP"},
"ligated":	{"VBD","VBN"},
"ligates":	{"VBZ"},
"ligating":	{"VBG"},
"ligation":	{"NN"},
"ligative":	{"JJ"},
"ligature":	{"NN"},
"liger":	{"NN"},
"light":	{"NN","JJ","VB","RB","VBP"},
"light-activated":	{"JJ"},
"light-armed":	{"JJ"},
"light-blue":	{"JJ"},
"light-boned":	{"JJ"},
"light-bulb":	{"NN"},
"light-bulbs":	{"NNS"},
"light-colored":	{"JJ"},
"light-crude":	{"NN"},
"light-duty":	{"JJ","NN"},
"light-fingered":	{"JJ"},
"light-flared":	{"JJ"},
"light-footed":	{"JJ"},
"light-green":	{"JJ"},
"light-haired":	{"JJ"},
"light-handed":	{"JJ"},
"light-handedly":	{"RB"},
"light-headed":	{"JJ"},
"light-headedly":	{"RB"},
"light-headedness":	{"NN"},
"light-hearted":	{"JJ"},
"light-heartedly":	{"RB"},
"light-heartedness":	{"NN"},
"light-heavyweight":	{"NN"},
"light-heavyweights":	{"NNS"},
"light-industrial":	{"JJ"},
"light-minded":	{"JJ"},
"light-mindedness":	{"NN"},
"light-o'-love":	{"NN"},
"light-of-love":	{"NN"},
"light-rail":	{"JJ"},
"light-reflecting":	{"JJ"},
"light-sensitive":	{"JJ"},
"light-skinned":	{"JJ"},
"light-tight":	{"JJ"},
"light-transmitting":	{"JJ"},
"light-truck":	{"JJ","NN"},
"light-water":	{"JJ"},
"light-wave":	{"NN"},
"light-weight":	{"JJ"},
"light-year":	{"NN"},
"light-years":	{"NNS"},
"lightbulb":	{"NN"},
"lighted":	{"JJ","VBD","VBN"},
"lighten":	{"VB","VBP"},
"lightened":	{"VBD","VBN"},
"lightening":	{"VBG"},
"lightens":	{"VBZ"},
"lighter":	{"JJR","NN","VB","VBP"},
"lighter-than-air":	{"JJ"},
"lighter-than-normal":	{"JJ"},
"lighterage":	{"NN"},
"lightered":	{"VBD","VBN"},
"lightering":	{"VBG"},
"lighterman":	{"NN"},
"lightermen":	{"NNS"},
"lighters":	{"NNS","VBZ"},
"lightest":	{"JJS"},
"lightheaded":	{"JJ"},
"lightheadedness":	{"NN"},
"lighthearted":	{"JJ"},
"lightheartedly":	{"RB"},
"lightheartedness":	{"NN"},
"lighthouse":	{"NN"},
"lighthouses":	{"NNS"},
"lighting":	{"NN","VBG"},
"lighting-up":	{"JJ"},
"lightless":	{"JJ"},
"lightlessness":	{"NN"},
"lightly":	{"RB"},
"lightly-armed":	{"JJ"},
"lightness":	{"NN"},
"lightning":	{"NN","JJ"},
"lightning-fast":	{"JJ"},
"lightning-like":	{"JJ"},
"lightning-occurrence":	{"JJ"},
"lightning-quick":	{"JJ"},
"lightproof":	{"JJ"},
"lights":	{"NNS","VBZ"},
"lights-out":	{"NN"},
"lightship":	{"NN"},
"lightships":	{"NNS"},
"lightsome":	{"JJ"},
"lightsomely":	{"RB"},
"lightsomeness":	{"NN"},
"lightweight":	{"JJ","NN"},
"lightweights":	{"NNS"},
"lightwood":	{"NN"},
"lightyears":	{"NNS"},
"ligne":	{"NN"},
"ligneous":	{"JJ"},
"lignified":	{"VBD","VBN"},
"lignifies":	{"VBZ"},
"lignify":	{"VB","VBP"},
"lignifying":	{"VBG"},
"lignin":	{"NN"},
"lignite":	{"NN"},
"lignosae":	{"NN"},
"lignum":	{"NN"},
"ligularia":	{"NN"},
"ligule":	{"NN"},
"liguria":	{"NN"},
"ligustrum":	{"NN"},
"likable":	{"JJ"},
"like":	{"IN","VB","VBP","JJ","NN","RB"},
"like-minded":	{"JJ"},
"like-mindedness":	{"NN"},
"likeable":	{"JJ"},
"liked":	{"VBD","VBN"},
"likelier":	{"JJR"},
"likeliest":	{"JJS"},
"likelihood":	{"NN"},
"likeliness":	{"NN"},
"likely":	{"JJ","RB"},
"liken":	{"VB","VBP"},
"likened":	{"VBD","VBN"},
"likeness":	{"NN"},
"likening":	{"VBG"},
"likens":	{"VBZ"},
"likes":	{"VBZ","NNS"},
"likewise":	{"RB"},
"liking":	{"NN","VBG"},
"likuta":	{"NN"},
"lilac":	{"NN","JJ"},
"lilac-blue":	{"JJ"},
"lilac-colored":	{"JJ"},
"lilac-pink":	{"JJ"},
"lilac-purple":	{"JJ"},
"lilacs":	{"NNS"},
"lilangeni":	{"NN"},
"liliaceae":	{"NN"},
"liliaceous":	{"JJ"},
"liliales":	{"NNS"},
"lilies":	{"NNS"},
"liliidae":	{"NN"},
"liliopsid":	{"NN"},
"liliopsida":	{"NN"},
"lilium":	{"NN"},
"liliuokalani":	{"NN"},
"lille":	{"NN"},
"lillian":	{"NN"},
"lillie":	{"NN"},
"lilo":	{"NN"},
"lilongwe":	{"NN"},
"lilos":	{"NNS"},
"lilt":	{"NN","VB","VBP"},
"lilted":	{"VBD","VBN"},
"lilting":	{"JJ","VBG"},
"lilts":	{"VBZ"},
"lily":	{"NN"},
"lily-livered":	{"JJ"},
"lily-white":	{"JJ"},
"lilyturf":	{"NN"},
"limacidae":	{"NN"},
"limacine":	{"JJ"},
"limacoid":	{"JJ"},
"liman":	{"NN"},
"limanda":	{"NN"},
"limax":	{"NN"},
"limb":	{"NN","VB","VBP"},
"limbal":	{"JJ"},
"limbed":	{"JJ","VBD","VBN"},
"limber":	{"VB","JJ","VBP"},
"limbered":	{"VBD","VBN"},
"limbering":	{"VBG"},
"limbers":	{"VBZ"},
"limbic":	{"JJ"},
"limbing":	{"VBG"},
"limbless":	{"JJ"},
"limbo":	{"NN"},
"limbs":	{"NNS"},
"limbus":	{"NN"},
"lime":	{"VB","NN","VBP"},
"limeade":	{"NN"},
"limed":	{"VBD","VBN"},
"limeira":	{"NN"},
"limekiln":	{"NN"},
"limelight":	{"NN"},
"limen":	{"NN"},
"limenitis":	{"NN"},
"limerick":	{"NN"},
"limericks":	{"NNS"},
"limes":	{"VBZ","NNS"},
"limestone":	{"NN"},
"limestones":	{"NNS"},
"limewater":	{"NN"},
"limey":	{"NN"},
"limeys":	{"NNS"},
"limicolae":	{"NN"},
"liming":	{"NN","VBG"},
"limit":	{"NN","VB","VBP"},
"limitation":	{"NN"},
"limitations":	{"NNS"},
"limited":	{"JJ","VBN","VBD"},
"limited-edition":	{"NN"},
"limited-editions":	{"NNS"},
"limited-growth":	{"NN"},
"limited-partner":	{"JJ"},
"limited-partnership":	{"NN","JJ"},
"limited-production":	{"JJ"},
"limited-scale":	{"JJ"},
"limited-substitution":	{"JJ"},
"limited-time":	{"JJ"},
"limitedly":	{"RB"},
"limiter":	{"NN"},
"limiting":	{"VBG","JJ"},
"limitless":	{"JJ"},
"limitlessness":	{"NN"},
"limits":	{"NNS","VBZ"},
"limn":	{"VB","VBP"},
"limned":	{"VBD","VBN"},
"limner":	{"NN"},
"limning":	{"NN","VBG"},
"limnobium":	{"NN"},
"limnocryptes":	{"NNS"},
"limnodromus":	{"NNS"},
"limnological":	{"JJ"},
"limnologically":	{"RB"},
"limnologist":	{"NN"},
"limnology":	{"NN"},
"limnos":	{"NN"},
"limns":	{"VBZ"},
"limo":	{"NN"},
"limonene":	{"NN"},
"limonite":	{"NN"},
"limonium":	{"NN"},
"limos":	{"NNS"},
"limosa":	{"NN"},
"limousin":	{"NN"},
"limousine":	{"NN"},
"limousines":	{"NNS"},
"limp":	{"VB","VBP","JJ","NN"},
"limp-looking":	{"JJ"},
"limpa":	{"NN"},
"limped":	{"VBD","VBN"},
"limper":	{"JJR"},
"limpest":	{"JJS"},
"limpet":	{"NN"},
"limpets":	{"NNS"},
"limpid":	{"JJ"},
"limpidity":	{"NN"},
"limpidly":	{"RB"},
"limping":	{"VBG"},
"limpkin":	{"NN"},
"limply":	{"RB"},
"limpness":	{"NN"},
"limps":	{"VBZ","NNS"},
"limulidae":	{"NN"},
"limulus":	{"NNS"},
"lin":	{"NN"},
"linac":	{"NN"},
"linaceae":	{"NN"},
"linage":	{"NN"},
"linalool":	{"NN"},
"linanthus":	{"NNS"},
"linaria":	{"NN"},
"linchpin":	{"NN"},
"linchpins":	{"NNS"},
"lincocin":	{"NN"},
"lincolnesque":	{"JJ"},
"lincolnian":	{"JJ"},
"lincomycin":	{"NN"},
"lindane":	{"NN"},
"linden":	{"NN"},
"lindens":	{"NNS"},
"lindera":	{"NN"},
"lindesnes":	{"NNS"},
"lindheimera":	{"NN"},
"lindner":	{"NN"},
"lindsay":	{"NN"},
"line":	{"NN","VB","VBP"},
"line-centered":	{"NN"},
"line-density":	{"NN"},
"line-drawing":	{"NN"},
"line-drawings":	{"NNS"},
"line-driven":	{"NN"},
"line-drying":	{"JJ"},
"line-fragments":	{"NNS"},
"line-hand-wired":	{"JJ"},
"line-item":	{"JJ"},
"line-item-veto":	{"JJ"},
"line-pairs":	{"NNS"},
"line-shooter":	{"NN"},
"line-shooting":	{"NN"},
"line-up":	{"NN"},
"linea":	{"NN"},
"lineage":	{"NN"},
"lineages":	{"NNS"},
"lineal":	{"JJ"},
"lineally":	{"RB"},
"lineament":	{"NN"},
"lineaments":	{"NNS"},
"linear":	{"JJ"},
"linearisation":	{"NN"},
"linearise":	{"VB","VBP"},
"linearised":	{"VBD","VBN"},
"linearises":	{"VBZ"},
"linearising":	{"VBG"},
"linearity":	{"NN"},
"linearization":	{"NN"},
"linearize":	{"VB","VBP"},
"linearized":	{"VBD","VBN"},
"linearizes":	{"VBZ"},
"linearizing":	{"VBG"},
"linearly":	{"RB"},
"lineation":	{"NN"},
"lineback":	{"NN"},
"linebacker":	{"NN"},
"linebackers":	{"NNS"},
"linecut":	{"NN"},
"lined":	{"JJ","VBD","VBN"},
"linelike":	{"JJ"},
"lineman":	{"NN"},
"linemen":	{"NNS"},
"linen":	{"NN","JJ"},
"linen-covered":	{"JJ"},
"linendraper":	{"NN"},
"linens":	{"NNS"},
"liner":	{"NN"},
"liners":	{"NNS"},
"lines":	{"NNS","VBZ"},
"linesman":	{"NN"},
"linesmen":	{"NNS"},
"lineup":	{"NN"},
"lineups":	{"NNS"},
"ling":	{"NN","VB","VBP"},
"ling-pao":	{"NN"},
"lingam":	{"NN"},
"lingberry":	{"NN"},
"lingcod":	{"NN"},
"lingenberry":	{"NN"},
"linger":	{"VB","VBP"},
"lingered":	{"VBD","VBN"},
"lingerer":	{"NN"},
"lingerie":	{"NN"},
"lingering":	{"VBG","JJ"},
"lingeringly":	{"RB"},
"lingers":	{"VBZ"},
"lingo":	{"NN"},
"lingoes":	{"NNS"},
"lingonberry":	{"NN"},
"lingos":	{"NNS"},
"lingua":	{"NN"},
"lingual":	{"JJ","NN"},
"lingually":	{"RB"},
"lingualumina":	{"NN"},
"linguica":	{"NN"},
"linguine":	{"NN"},
"linguini":	{"NNS"},
"linguist":	{"NN"},
"linguist-anthropologist":	{"NN"},
"linguistic":	{"JJ"},
"linguistically":	{"RB"},
"linguistics":	{"NN"},
"linguists":	{"NNS"},
"lingulate":	{"JJ"},
"liniment":	{"NN"},
"liniments":	{"NNS"},
"linin":	{"NN"},
"lining":	{"VBG","NN"},
"linings":	{"NNS"},
"link":	{"NN","VB","VBP"},
"link-up":	{"NN"},
"link-ups":	{"NNS"},
"linkage":	{"NN"},
"linkages":	{"NNS"},
"linkboy":	{"NN"},
"linked":	{"VBN","VBD"},
"linking":	{"VBG"},
"linkman":	{"NN"},
"linkmen":	{"NNS"},
"links":	{"NNS","VBZ","NN"},
"linkup":	{"NN"},
"linkups":	{"NNS"},
"linnaea":	{"NN"},
"linnaean":	{"JJ"},
"linnean":	{"JJ"},
"linnet":	{"NN"},
"linnets":	{"NNS"},
"lino":	{"NN"},
"linocut":	{"NN"},
"linocuts":	{"NNS"},
"linoleum":	{"NN"},
"linotype":	{"NN"},
"linseed":	{"NN"},
"linsey-woolsey":	{"NN"},
"linstock":	{"NN"},
"lint":	{"NN"},
"lintel":	{"NN"},
"lintels":	{"NNS"},
"lintwhite":	{"NN"},
"linum":	{"NN"},
"linuron":	{"NN"},
"linux":	{"NN"},
"linz":	{"NN"},
"liomys":	{"NNS"},
"lion":	{"NN"},
"lion's-ear":	{"NN"},
"lion-hunter":	{"NN"},
"lioness":	{"NN"},
"lionesses":	{"NNS"},
"lionet":	{"NN"},
"lionfish":	{"NN"},
"lionhearted":	{"JJ"},
"lionise":	{"VB","VBP"},
"lionised":	{"VBD","VBN"},
"lionises":	{"VBZ"},
"lionising":	{"VBG"},
"lionize":	{"VB","VBP"},
"lionized":	{"VBD","VBN"},
"lionizes":	{"VBZ"},
"lionizing":	{"VBG"},
"lions":	{"NNS"},
"liopelma":	{"NN"},
"liopelmidae":	{"NN"},
"liothyronine":	{"NN"},
"lip":	{"NN","VB","VBP"},
"lip-gloss":	{"NN"},
"lip-glosses":	{"NNS"},
"lip-read":	{"VB","VBP","VBD","VBN"},
"lip-reads":	{"VBZ"},
"lip-shaped":	{"JJ"},
"lip-sucking":	{"NN"},
"lip-sync":	{"VB","VBP","NN"},
"lip-synced":	{"VBD","VBN"},
"lip-synch":	{"VB","VBP"},
"lip-synched":	{"VBD","VBN"},
"lip-synching":	{"VBG"},
"lip-synchs":	{"VBZ"},
"lip-syncing":	{"VBG"},
"lip-syncs":	{"VBZ"},
"lipaemia":	{"NN"},
"liparidae":	{"NN"},
"liparididae":	{"NN"},
"liparis":	{"NNS"},
"lipase":	{"NN"},
"lipases":	{"NNS"},
"lipchitz":	{"NN"},
"lipectomy":	{"NN"},
"lipemia":	{"NN"},
"lipfern":	{"NN"},
"lipid":	{"NN"},
"lipidaemia":	{"NN"},
"lipide":	{"NN"},
"lipidemia":	{"NN"},
"lipidosis":	{"NN"},
"lipids":	{"NNS"},
"lipitor":	{"NN"},
"lipizzan":	{"NN"},
"lipless":	{"JJ"},
"liplike":	{"JJ"},
"lipman":	{"NN"},
"lipmann":	{"NN"},
"lipo-hepin":	{"NN"},
"lipo-lutin":	{"NN"},
"lipochondrodystrophy":	{"NN"},
"lipogram":	{"NN"},
"lipoid":	{"NN","JJ"},
"lipoidaemia":	{"NN"},
"lipoidemia":	{"NN"},
"lipoma":	{"NN"},
"lipomatosis":	{"NN"},
"lipophilic":	{"JJ"},
"lipoprotein":	{"NN"},
"lipoproteins":	{"NNS"},
"liposarcoma":	{"NN"},
"liposcelis":	{"NNS"},
"liposome":	{"NN"},
"liposomes":	{"NNS"},
"liposuction":	{"NN"},
"lipotropic":	{"JJ"},
"lipotyphla":	{"NN"},
"lipped":	{"JJ","VBD","VBN"},
"lippi":	{"NN"},
"lipping":	{"VBG"},
"lippizan":	{"NN"},
"lippizaner":	{"NN"},
"lippmann":	{"NN"},
"lipreading":	{"NN","VBG"},
"lips":	{"NNS","VBZ"},
"lipscomb":	{"NN"},
"lipstick":	{"NN"},
"lipsticks":	{"NNS"},
"liquaemin":	{"NN"},
"liquefaction":	{"NN"},
"liquefactive":	{"JJ"},
"liquefiable":	{"JJ"},
"liquefied":	{"VBD","VBN"},
"liquefier":	{"NN"},
"liquefies":	{"VBZ"},
"liquefy":	{"VB","VBP"},
"liquefying":	{"VBG"},
"liquescent":	{"JJ"},
"liqueur":	{"NN"},
"liqueurs":	{"NNS"},
"liquid":	{"NN","JJ"},
"liquid-chromatography":	{"NN"},
"liquid-crystal":	{"NN"},
"liquid-crystals":	{"NNS"},
"liquid-drug":	{"JJ"},
"liquid-fuel":	{"NN"},
"liquid-fueled":	{"JJ"},
"liquid-glass":	{"NN"},
"liquid-nitrogen":	{"NN"},
"liquidambar":	{"NN"},
"liquidate":	{"VB","VBP"},
"liquidated":	{"VBN","VBD"},
"liquidates":	{"VBZ"},
"liquidating":	{"VBG"},
"liquidation":	{"NN"},
"liquidations":	{"NNS"},
"liquidator":	{"NN"},
"liquidators":	{"NNS"},
"liquidise":	{"VB","VBP"},
"liquidised":	{"VBD","VBN"},
"liquidiser":	{"NN"},
"liquidisers":	{"NNS"},
"liquidises":	{"VBZ"},
"liquidising":	{"VBG"},
"liquidity":	{"NN"},
"liquidity-enhancing":	{"JJ"},
"liquidity-short-selling":	{"NN"},
"liquidize":	{"VB","VBP"},
"liquidized":	{"VBD","VBN"},
"liquidizer":	{"NN"},
"liquidizers":	{"NNS"},
"liquidizes":	{"VBZ"},
"liquidizing":	{"VBG"},
"liquidness":	{"NN"},
"liquids":	{"NNS"},
"liquifaction":	{"NN"},
"liquifactive":	{"JJ"},
"liquifiable":	{"JJ"},
"liquified":	{"VBD","VBN","JJ"},
"liquifier":	{"NN"},
"liquifies":	{"VBZ"},
"liquify":	{"VB","VBP"},
"liquifying":	{"VBG"},
"liquor":	{"NN","VB","VBP"},
"liquor-crazed":	{"JJ"},
"liquored":	{"VBD","VBN"},
"liquorice":	{"NN"},
"liquoring":	{"VBG"},
"liquors":	{"VBZ","NNS"},
"lir":	{"NN"},
"lira":	{"NN"},
"liras":	{"NNS"},
"lire":	{"NNS"},
"liriodendron":	{"NN"},
"liriope":	{"NN"},
"lisboa":	{"NN"},
"lisente":	{"NNS"},
"lisinopril":	{"NN"},
"lisle":	{"NN"},
"lisp":	{"NN","VB","VBP"},
"lisped":	{"VBD","VBN"},
"lisper":	{"NN"},
"lisping":	{"VBG"},
"lispingly":	{"RB"},
"lisps":	{"NNS","VBZ"},
"lissom":	{"JJ"},
"lissome":	{"JJ"},
"lissomeness":	{"NN"},
"list":	{"NN","VB","VBP"},
"liste":	{"FW"},
"listed":	{"VBN","VBD","JJ"},
"listen":	{"VBP","NN","VB"},
"listened":	{"VBD","VBN"},
"listener":	{"NN"},
"listener-supported":	{"JJ"},
"listeners":	{"NNS"},
"listening":	{"VBG","NN"},
"listens":	{"VBZ"},
"lister":	{"NN"},
"listera":	{"NN"},
"listeria":	{"NN"},
"listeriosis":	{"NN"},
"listicle":	{"NN"},
"listicles":	{"NNS"},
"listing":	{"NN","VBG"},
"listings":	{"NNS"},
"listless":	{"JJ"},
"listlessly":	{"RB"},
"listlessness":	{"NN"},
"liston":	{"NN"},
"lists":	{"NNS","VBZ"},
"lisu":	{"NN"},
"lit":	{"VBD","VBN"},
"litanies":	{"NNS"},
"litany":	{"NN"},
"litas":	{"NN"},
"litchee":	{"NN"},
"litchi":	{"NN"},
"lite":	{"JJ"},
"liter":	{"NN"},
"literacy":	{"NN"},
"literal":	{"JJ","NN"},
"literal-minded":	{"JJ"},
"literalisation":	{"NN"},
"literalise":	{"VB","VBP"},
"literalised":	{"VBD","VBN"},
"literalises":	{"VBZ"},
"literalising":	{"VBG"},
"literalism":	{"NN"},
"literalization":	{"NN"},
"literalize":	{"VB","VBP"},
"literalized":	{"VBD","VBN"},
"literalizes":	{"VBZ"},
"literalizing":	{"VBG"},
"literally":	{"RB"},
"literalness":	{"NN"},
"literary":	{"JJ"},
"literate":	{"JJ","NN"},
"literati":	{"NNS"},
"literatim":	{"RB"},
"literature":	{"NN"},
"literatures":	{"NNS"},
"literatus":	{"NN"},
"liters":	{"NNS"},
"lithane":	{"NN"},
"lithe":	{"JJ"},
"lithe-bodied":	{"JJ"},
"litheness":	{"NN"},
"lithesome":	{"JJ"},
"lithiasis":	{"NN"},
"lithic":	{"JJ"},
"lithium":	{"NN"},
"litho":	{"NN"},
"lithocarpus":	{"NNS"},
"lithodidae":	{"NN"},
"lithoglyptics":	{"NN"},
"lithograph":	{"NN","VB","VBP"},
"lithographed":	{"VBD","VBN"},
"lithographer":	{"NN"},
"lithographic":	{"JJ"},
"lithographing":	{"VBG"},
"lithographs":	{"NNS","VBZ"},
"lithography":	{"NN"},
"lithology":	{"NN"},
"lithomancer":	{"NN"},
"lithomancy":	{"NN"},
"lithomantic":	{"JJ"},
"lithonate":	{"NN"},
"lithophragma":	{"NN"},
"lithophyte":	{"NN"},
"lithophytic":	{"JJ"},
"lithops":	{"NNS"},
"lithospermum":	{"NN"},
"lithosphere":	{"NN"},
"lithotomy":	{"NN"},
"lithotripsy":	{"NN"},
"lithotripter":	{"NN"},
"lithuresis":	{"NN"},
"litigant":	{"NN"},
"litigants":	{"NNS"},
"litigate":	{"VB","VBP"},
"litigated":	{"VBD","VBN"},
"litigates":	{"VBZ"},
"litigating":	{"VBG"},
"litigation":	{"NN"},
"litigation-support":	{"JJ"},
"litigator":	{"NN"},
"litigators":	{"NNS"},
"litigious":	{"JJ"},
"litigiousness":	{"NN"},
"litmus":	{"NN"},
"litocranius":	{"NNS"},
"litoral":	{"NN"},
"litorigin":	{"NN"},
"litotes":	{"NN"},
"litre":	{"NN"},
"litres":	{"NNS"},
"litter":	{"NN","VB","VBP"},
"litter-basket":	{"NN"},
"litter-baskets":	{"NNS"},
"litter-bearer":	{"NN"},
"litter-bin":	{"NN"},
"litter-bins":	{"NNS"},
"litter-bug":	{"NN"},
"litter-strewn":	{"JJ"},
"litterateur":	{"NN"},
"litterbin":	{"NN"},
"litterbug":	{"NN"},
"litterbugs":	{"NNS"},
"littered":	{"JJ","VBD","VBN"},
"litterer":	{"NN"},
"littering":	{"VBG"},
"litters":	{"NNS","VBZ"},
"little":	{"JJ","RB","PRP","DT"},
"little-feared":	{"JJ"},
"little-girl":	{"JJ"},
"little-known":	{"JJ"},
"little-noted":	{"JJ"},
"little-noticed":	{"JJ"},
"little-publicized":	{"JJ"},
"little-town":	{"JJ"},
"little-understood":	{"JJ"},
"littleneck":	{"NN"},
"littleness":	{"NN"},
"littler":	{"JJR"},
"littlest":	{"JJS"},
"littleton":	{"NN"},
"littoral":	{"JJ","NN"},
"littorals":	{"NNS"},
"littorina":	{"NN"},
"littorinidae":	{"NN"},
"liturgical":	{"JJ"},
"liturgically":	{"RB"},
"liturgics":	{"NN"},
"liturgies":	{"NNS"},
"liturgiology":	{"NN"},
"liturgist":	{"NN"},
"liturgy":	{"NN"},
"liv":	{"JJ"},
"livability":	{"NN"},
"livable":	{"JJ"},
"livableness":	{"NN"},
"live":	{"VB","VBP","JJ","RB"},
"live-action":	{"NN","JJ"},
"live-and-die":	{"NN"},
"live-bearer":	{"NN"},
"live-bearing":	{"JJ"},
"live-forever":	{"NN"},
"live-haulers":	{"NNS"},
"live-in":	{"JJ"},
"live-oak":	{"NN"},
"liveability":	{"NN"},
"liveable":	{"JJ"},
"liveable-in":	{"JJ"},
"liveable-with":	{"JJ"},
"liveableness":	{"NN"},
"liveborn":	{"JJ"},
"lived":	{"VBD","VBN","JJ"},
"livedo":	{"NN"},
"livelier":	{"JJR"},
"liveliest":	{"JJS"},
"livelihood":	{"NN"},
"livelihoods":	{"NNS"},
"liveliness":	{"NN"},
"livelong":	{"JJ"},
"lively":	{"JJ"},
"liven":	{"VB","VBP"},
"livened":	{"VBD","VBN"},
"liveness":	{"NN"},
"livening":	{"VBG"},
"livens":	{"VBZ"},
"liver":	{"NN"},
"liver-colored":	{"JJ"},
"liveried":	{"JJ"},
"liveries":	{"NNS"},
"liverish":	{"JJ"},
"liverleaf":	{"NN"},
"livermore":	{"NN"},
"livers":	{"NNS"},
"liverwort":	{"NN"},
"liverwurst":	{"NN"},
"livery":	{"NN"},
"liveryman":	{"NN"},
"liverymen":	{"NNS"},
"lives":	{"NNS","VBZ"},
"livestock":	{"NN"},
"livestock-dealing":	{"JJ"},
"livestream":	{"VB","VBP","NN"},
"livestreamed":	{"VBD","VBN"},
"livestreaming":	{"VBG"},
"livestreams":	{"VBZ","NNS"},
"livid":	{"JJ"},
"lividity":	{"NN"},
"lividly":	{"RB"},
"lividness":	{"NN"},
"living":	{"VBG","NN","JJ"},
"living-benefits":	{"JJ"},
"living-room":	{"NN"},
"living-rooms":	{"NNS"},
"livings":	{"NNS"},
"livistona":	{"NN"},
"livonia":	{"NN"},
"livonian":	{"NN"},
"livonian-speaking":	{"JJ"},
"livre":	{"NN"},
"livres":	{"NNS"},
"liza":	{"NN"},
"lizard":	{"NN"},
"lizard's-tail":	{"NN"},
"lizardfish":	{"NN","NNS"},
"lizardfishes":	{"NNS"},
"lizards":	{"NNS"},
"llama":	{"NN"},
"llamas":	{"NNS"},
"llano":	{"NN"},
"llb":	{"NN"},
"lld":	{"NN"},
"llm":	{"NN"},
"lloyd":	{"NN"},
"llud":	{"NN"},
"llullaillaco":	{"NN"},
"llyr":	{"NN"},
"lm":	{"NN"},
"lo":	{"UH"},
"loach":	{"NN"},
"load":	{"NN","VB","VBP"},
"load-bearing":	{"JJ"},
"load-shedding":	{"NN"},
"loaded":	{"VBN","VBD","JJ"},
"loader":	{"NN"},
"loaders":	{"NNS"},
"loading":	{"NN","VBG"},
"loadings":	{"NNS"},
"loads":	{"VBZ","NNS"},
"loadstar":	{"NN"},
"loadstone":	{"NN"},
"loadstones":	{"NNS"},
"loaf":	{"NN","VB","VBP"},
"loafed":	{"VBD","VBN"},
"loafer":	{"NN"},
"loafers":	{"NNS"},
"loafing":	{"VBG","NN"},
"loafs":	{"VBZ"},
"loam":	{"NN"},
"loamless":	{"JJ"},
"loamy":	{"JJ"},
"loan":	{"NN","VB","VBP"},
"loan-blend":	{"NN"},
"loan-by-phone":	{"JJ"},
"loan-collection":	{"NN"},
"loan-defaulters":	{"NNS"},
"loan-forgiveness":	{"NN"},
"loan-guarantee":	{"NN"},
"loan-management":	{"NN"},
"loan-officer":	{"NN"},
"loan-production":	{"NN"},
"loan-repayment":	{"NN"},
"loan-restructuring":	{"JJ"},
"loan-to-value":	{"NN"},
"loan-word":	{"NN"},
"loan-words":	{"NNS"},
"loanblend":	{"NN"},
"loaned":	{"VBD","VBN"},
"loaner":	{"NN"},
"loaning":	{"VBG"},
"loans":	{"NNS","VBZ"},
"loanword":	{"NN"},
"loanwords":	{"NNS"},
"loasa":	{"NN"},
"loasaceae":	{"NN"},
"loath":	{"JJ"},
"loathe":	{"VB","VBP"},
"loathed":	{"VBD","VBN"},
"loather":	{"NN"},
"loathes":	{"VBZ"},
"loathing":	{"NN","VBG"},
"loathly":	{"JJ"},
"loathsome":	{"JJ"},
"loathsomeness":	{"NN"},
"loaves":	{"NNS"},
"lob":	{"VB","VBP","NN"},
"lob-scuse":	{"NN"},
"lobachevsky":	{"NN"},
"lobar":	{"JJ"},
"lobata":	{"NN"},
"lobate":	{"JJ"},
"lobated":	{"JJ"},
"lobbed":	{"VBD","VBN"},
"lobbied":	{"VBD","VBN"},
"lobbies":	{"NNS","VBZ"},
"lobbing":	{"VBG"},
"lobby":	{"NN","VB","VBP"},
"lobbying":	{"VBG","NN"},
"lobbyism":	{"NN"},
"lobbyist":	{"NN"},
"lobbyists":	{"NNS"},
"lobe":	{"NN"},
"lobectomy":	{"NN"},
"lobed":	{"JJ"},
"lobefin":	{"NN"},
"lobelia":	{"NN"},
"lobeliaceae":	{"NN"},
"lobeliaceous":	{"JJ"},
"lobes":	{"NNS"},
"lobiped":	{"JJ"},
"lobito":	{"NN"},
"loblolly":	{"NN"},
"lobo":	{"NN"},
"lobotes":	{"NNS"},
"lobotidae":	{"NN"},
"lobotomies":	{"NNS"},
"lobotomize":	{"VB","VBP"},
"lobotomized":	{"VBD","VBN"},
"lobotomizes":	{"VBZ"},
"lobotomizing":	{"VBG"},
"lobotomy":	{"NN"},
"lobs":	{"VBZ","NNS"},
"lobscouse":	{"NN"},
"lobscuse":	{"NN"},
"lobster":	{"NN"},
"lobster-backed":	{"JJ"},
"lobster-pot":	{"NN"},
"lobster-pots":	{"NNS"},
"lobsterback":	{"NN"},
"lobsterman":	{"NN"},
"lobstermen":	{"NNS"},
"lobsters":	{"NNS"},
"lobular":	{"JJ"},
"lobularia":	{"NN"},
"lobularity":	{"NN"},
"lobule":	{"NN"},
"lobules":	{"NNS"},
"lobworm":	{"NN"},
"local":	{"JJ","NN"},
"local-content":	{"JJ","NN"},
"local-control":	{"JJ"},
"local-exchange":	{"JJ"},
"local-government":	{"NN"},
"local-governments":	{"NNS"},
"local-money":	{"NN"},
"local-news":	{"NN"},
"local-service":	{"JJ"},
"locale":	{"NN"},
"locales":	{"NNS"},
"localisation":	{"NN"},
"localise":	{"VB","VBP"},
"localised":	{"VBD","VBN","JJ"},
"localises":	{"VBZ"},
"localising":	{"VBG"},
"localism":	{"NN"},
"localisms":	{"NNS"},
"localities":	{"NNS"},
"locality":	{"NN"},
"localization":	{"NN"},
"localize":	{"VB","VBP"},
"localized":	{"JJ","VBD","VBN"},
"localizes":	{"VBZ"},
"localizing":	{"VBG"},
"locally":	{"RB"},
"locals":	{"NNS"},
"locate":	{"VB","VBP"},
"located":	{"VBN","VBD","JJ"},
"locater":	{"NN"},
"locates":	{"VBZ"},
"locating":	{"VBG"},
"location":	{"NN"},
"location-minded":	{"JJ"},
"locations":	{"NNS"},
"locative":	{"NN","JJ"},
"locator":	{"NN"},
"locavore":	{"NN"},
"locavores":	{"NNS"},
"locavorism":	{"NN"},
"loch":	{"NN"},
"lochia":	{"NN"},
"lochs":	{"NNS"},
"loci":	{"NNS"},
"lock":	{"NN","VB","VBP"},
"lock-gate":	{"NN"},
"lock-keeper":	{"NN"},
"lock-keepers":	{"NNS"},
"lock-nut":	{"NN"},
"lock-out":	{"NN"},
"lock-outs":	{"NNS"},
"lock-up":	{"NN","JJ"},
"lock-ups":	{"NNS"},
"lockable":	{"JJ"},
"lockage":	{"NN"},
"lockbox":	{"NN"},
"lockdown":	{"NN"},
"locked":	{"VBN","VBD","JJ"},
"locker":	{"NN"},
"locker-room":	{"JJ"},
"lockers":	{"NNS"},
"locket":	{"NN"},
"lockets":	{"NNS"},
"lockhart":	{"NN"},
"lockhold":	{"NN"},
"lockian":	{"JJ"},
"locking":	{"VBG"},
"locking-in":	{"NN"},
"lockjaw":	{"NN"},
"lockkeeper":	{"NN"},
"lockkeepers":	{"NNS"},
"lockman":	{"NN"},
"lockmaster":	{"NN"},
"locknut":	{"NN"},
"locknuts":	{"NNS"},
"lockout":	{"NN"},
"lockouts":	{"NNS"},
"lockpick":	{"NN","VB","VBP"},
"lockpicked":	{"VBD","VBN"},
"lockpicking":	{"NN","VBG"},
"lockpicks":	{"NNS","VBZ"},
"lockring":	{"NN"},
"locks":	{"NNS","VBZ"},
"locksmith":	{"NN"},
"locksmiths":	{"NNS"},
"lockstep":	{"NN"},
"lockstitch":	{"NN"},
"lockup":	{"NN"},
"loco":	{"NN","JJ","VB","VBP"},
"locoed":	{"VBD","VBN"},
"locoing":	{"VBG"},
"locoism":	{"NN"},
"locomote":	{"VB","VBP"},
"locomoted":	{"VBD","VBN"},
"locomotes":	{"VBZ"},
"locomoting":	{"VBG"},
"locomotion":	{"NN"},
"locomotive":	{"NN","JJ"},
"locomotives":	{"NNS"},
"locomotor":	{"JJ"},
"locos":	{"VBZ","NNS"},
"locoweed":	{"NN"},
"locoweeds":	{"NNS"},
"locule":	{"NN"},
"loculus":	{"NNS"},
"locum":	{"NN"},
"locums":	{"NNS"},
"locus":	{"NN"},
"locust":	{"NN"},
"locusta":	{"NN"},
"locustidae":	{"NN"},
"locusts":	{"NNS"},
"locution":	{"NN"},
"locutions":	{"NNS"},
"lode":	{"NN"},
"lodes":	{"NNS"},
"lodestar":	{"NN"},
"lodestone":	{"NN"},
"lodestones":	{"NNS"},
"lodge":	{"NN","VB","VBP"},
"lodged":	{"VBD","VBN"},
"lodgement":	{"NN"},
"lodgepole":	{"NN"},
"lodger":	{"NN"},
"lodgers":	{"NNS"},
"lodges":	{"VBZ","NNS"},
"lodging":	{"NN","VBG"},
"lodgings":	{"NNS"},
"lodgment":	{"NN"},
"lodine":	{"NN"},
"lodz":	{"NN"},
"loeb":	{"NN"},
"loess":	{"NN"},
"loessland":	{"NN"},
"loestrin":	{"NN"},
"loewe":	{"NN"},
"loewi":	{"NN"},
"lofortyx":	{"NN"},
"lofoten":	{"NN"},
"loft":	{"NN","VBP","VB"},
"lofted":	{"VBD","VBN","JJ"},
"loftier":	{"JJR"},
"loftiest":	{"JJS"},
"loftily":	{"RB"},
"loftiness":	{"NN"},
"lofting":	{"VBG"},
"lofts":	{"NNS","VBZ"},
"lofty":	{"JJ"},
"log":	{"NN","VB","VBP"},
"log-book":	{"NN"},
"log-books":	{"NNS"},
"log-house":	{"NN"},
"log-in":	{"JJ"},
"log-jam":	{"NN"},
"log-rolled":	{"VBD"},
"logagraphia":	{"NN"},
"loganberries":	{"NNS"},
"loganberry":	{"NN"},
"logania":	{"NN"},
"loganiaceae":	{"NN"},
"logarithm":	{"NN"},
"logarithmic":	{"JJ"},
"logarithmically":	{"RB"},
"logarithms":	{"NNS"},
"logbook":	{"NN"},
"logbooks":	{"NNS"},
"loge":	{"NN"},
"logged":	{"VBD","VBN"},
"logger":	{"NN"},
"loggerhead":	{"NN"},
"loggerheaded":	{"JJ"},
"loggerheads":	{"NN"},
"loggers":	{"NNS"},
"loggia":	{"NN"},
"loggias":	{"NNS"},
"logginess":	{"NN"},
"logging":	{"NN","VBG"},
"logic":	{"NN"},
"logic-rhetoric":	{"NN"},
"logical":	{"JJ"},
"logicality":	{"NN"},
"logically":	{"RB"},
"logicalness":	{"NN"},
"logician":	{"NN"},
"logicians":	{"NNS"},
"logicism":	{"NN"},
"loginess":	{"NN"},
"logion":	{"NN"},
"logistic":	{"JJ"},
"logistical":	{"JJ"},
"logistically":	{"RB"},
"logistician":	{"NN"},
"logistics":	{"NN","NNS"},
"logistics-computer":	{"NN"},
"logjam":	{"NN"},
"logjams":	{"NNS"},
"logo":	{"NN"},
"logogram":	{"NN"},
"logogrammatic":	{"JJ"},
"logogrammatically":	{"RB"},
"logograph":	{"NN"},
"logographic":	{"JJ"},
"logomach":	{"NN"},
"logomachist":	{"NN"},
"logomachy":	{"NN"},
"logomania":	{"NN"},
"logorrhea":	{"NN"},
"logos":	{"NNS"},
"logotype":	{"NN"},
"logroll":	{"VB","VBP"},
"logrolled":	{"VBD","VBN"},
"logroller":	{"NN"},
"logrolling":	{"NN","VBG"},
"logrolls":	{"VBZ"},
"logrono":	{"NN"},
"logs":	{"NNS","VBZ"},
"logwood":	{"NN"},
"logy":	{"JJ"},
"lohan":	{"NN"},
"loin":	{"NN"},
"loincloth":	{"NN"},
"loincloths":	{"NNS"},
"loins":	{"NNS"},
"loir":	{"NN"},
"loiseleuria":	{"NN"},
"loiter":	{"VB","VBP"},
"loitered":	{"VBD","VBN"},
"loiterer":	{"NN"},
"loitering":	{"VBG","NN"},
"loiters":	{"VBZ"},
"loligo":	{"NN"},
"lolium":	{"NN"},
"loll":	{"VB","VBP"},
"lolled":	{"VBD","VBN"},
"lollies":	{"NNS"},
"lolling":	{"VBG","NN"},
"lollipop":	{"NN"},
"lollipops":	{"NNS"},
"lollop":	{"VB","VBP"},
"lolloped":	{"VBD","VBN"},
"lolloping":	{"VBG"},
"lollops":	{"VBZ"},
"lolls":	{"VBZ"},
"lolly":	{"NN"},
"lollygag":	{"VB","VBP"},
"lollygagged":	{"VBD","VBN"},
"lollygagging":	{"VBG"},
"lollygags":	{"VBZ"},
"lolo":	{"NN"},
"lolo-burmese":	{"NN"},
"loloish":	{"NN"},
"lomariopsidaceae":	{"NN"},
"lomatia":	{"NN"},
"lombard":	{"NN"},
"lombardia":	{"NN"},
"lombardy":	{"NN"},
"loment":	{"NN"},
"lomogramma":	{"NN"},
"lomotil":	{"NN"},
"lomustine":	{"NN"},
"lonas":	{"NNS"},
"lonchocarpus":	{"NNS"},
"london-bred":	{"JJ"},
"lone":	{"JJ"},
"lonelier":	{"JJR"},
"loneliest":	{"JJS"},
"loneliness":	{"NN"},
"lonely":	{"JJ"},
"lonely-hearts":	{"JJ"},
"loner":	{"NN"},
"loners":	{"NNS"},
"lonesome":	{"JJ"},
"lonesomeness":	{"NN"},
"long":	{"JJ","NN","RB","VB","VBP"},
"long-acting":	{"JJ"},
"long-ago":	{"JJ"},
"long-armed":	{"JJ"},
"long-arranged":	{"JJ"},
"long-awaited":	{"JJ"},
"long-banned":	{"JJ"},
"long-beard":	{"NN"},
"long-bodied":	{"JJ"},
"long-branched":	{"JJ"},
"long-bubbling":	{"JJ"},
"long-canceled":	{"JJ"},
"long-chain":	{"JJ"},
"long-cherished":	{"JJ"},
"long-considered":	{"JJ"},
"long-cruise":	{"JJ"},
"long-dated":	{"JJ"},
"long-debated":	{"JJ"},
"long-deferred":	{"JJ"},
"long-delayed":	{"JJ"},
"long-depressed":	{"JJ"},
"long-deprived":	{"JJ"},
"long-distance":	{"JJ","RB"},
"long-dollar":	{"JJ"},
"long-dominant":	{"JJ"},
"long-dormant":	{"JJ"},
"long-drawn-out":	{"JJ"},
"long-endurance":	{"JJ"},
"long-established":	{"JJ"},
"long-faced":	{"JJ"},
"long-familiar":	{"JJ"},
"long-far":	{"NN"},
"long-format":	{"JJ"},
"long-hair":	{"JJ"},
"long-haired":	{"JJ"},
"long-handled":	{"JJ"},
"long-haul":	{"JJ"},
"long-headed":	{"JJ"},
"long-held":	{"JJ"},
"long-hoped-for":	{"JJ"},
"long-jawed":	{"JJ"},
"long-keeping":	{"JJ"},
"long-known":	{"JJ"},
"long-lasting":	{"JJ"},
"long-legged":	{"JJ"},
"long-legs":	{"NNS"},
"long-lens":	{"NN"},
"long-lenses":	{"NNS"},
"long-life":	{"JJ"},
"long-line":	{"JJ"},
"long-lived":	{"JJ"},
"long-lost":	{"JJ"},
"long-opposed":	{"JJ"},
"long-overdue":	{"JJ"},
"long-planned":	{"JJ"},
"long-play":	{"JJ"},
"long-player":	{"NN"},
"long-playing":	{"JJ"},
"long-range":	{"JJ"},
"long-rumored":	{"JJ"},
"long-run":	{"JJ"},
"long-running":	{"JJ"},
"long-settled":	{"JJ"},
"long-shanked":	{"JJ"},
"long-shelf-life":	{"JJ"},
"long-sighted":	{"JJ"},
"long-simmering":	{"JJ"},
"long-sleeved":	{"JJ"},
"long-snouted":	{"JJ"},
"long-sought":	{"JJ"},
"long-spurred":	{"JJ"},
"long-stalked":	{"JJ"},
"long-standing":	{"JJ"},
"long-staple":	{"JJ"},
"long-stemmed":	{"JJ"},
"long-studied":	{"JJ"},
"long-successful":	{"JJ"},
"long-sufferance":	{"NN"},
"long-suffering":	{"JJ"},
"long-suspected":	{"JJ"},
"long-tenured":	{"JJ"},
"long-term":	{"JJ","NN"},
"long-term-oriented":	{"JJ"},
"long-termers":	{"NNS"},
"long-time":	{"JJ"},
"long-troubled":	{"JJ"},
"long-vanished":	{"JJ"},
"long-view":	{"JJ"},
"long-wearing":	{"JJ"},
"long-winded":	{"JJ"},
"long-windedly":	{"RB"},
"long-windedness":	{"NN"},
"long-wool":	{"JJ"},
"long-wooled":	{"JJ"},
"long-yardage":	{"JJ"},
"longan":	{"NN"},
"longanberry":	{"NN"},
"longanimity":	{"NN"},
"longanimous":	{"JJ"},
"longbeard":	{"NN"},
"longboat":	{"NN"},
"longbow":	{"NN"},
"longbowman":	{"NN"},
"longbows":	{"NNS"},
"longed":	{"VBD","VBN"},
"longed-for":	{"JJ"},
"longer":	{"JJR","RBR"},
"longer-established":	{"JJ"},
"longer-lived":	{"JJ"},
"longer-range":	{"JJ"},
"longer-run":	{"JJ"},
"longer-term":	{"JJR"},
"longerterm":	{"JJ"},
"longest":	{"JJS","RBS"},
"longest-running":	{"JJ","NN"},
"longevity":	{"NN"},
"longhaired":	{"JJ","NN"},
"longhand":	{"NN"},
"longhaul":	{"NN"},
"longhorn":	{"NN"},
"longhorns":	{"NNS"},
"longicorn":	{"NN"},
"longing":	{"NN","JJ","VBG"},
"longingly":	{"RB"},
"longings":	{"NNS"},
"longish":	{"JJ"},
"longitude":	{"NN"},
"longitudes":	{"NNS"},
"longitudinal":	{"JJ"},
"longitudinally":	{"RB"},
"longlegs":	{"NNS"},
"longneck":	{"NN"},
"longness":	{"NN"},
"longrange":	{"JJ"},
"longroot":	{"NN"},
"longrun":	{"JJ"},
"longs":	{"NNS","VBZ"},
"longshoreman":	{"NN"},
"longshoremen":	{"NNS"},
"longshot":	{"NN"},
"longsighted":	{"JJ"},
"longsightedness":	{"NN"},
"longstanding":	{"JJ"},
"longstop":	{"NN"},
"longsuffering":	{"JJ"},
"longterm":	{"JJ","NN"},
"longtime":	{"JJ"},
"longue":	{"FW"},
"longueur":	{"NN"},
"longview":	{"NN"},
"longways":	{"RB"},
"longwise":	{"RB"},
"longwool":	{"NN"},
"longyi":	{"NN"},
"lonicera":	{"NN"},
"loniten":	{"NN"},
"lontar":	{"NN"},
"loo":	{"NN"},
"loofa":	{"NN"},
"loofah":	{"NN"},
"loofahs":	{"NNS"},
"look":	{"VB","NN","VBP","UH"},
"look-alike":	{"NN"},
"look-alikes":	{"NNS"},
"look-over":	{"NN"},
"look-see":	{"NN"},
"lookalike":	{"NN"},
"lookalikes":	{"NNS"},
"lookdown":	{"NN"},
"looked":	{"VBD","VBN"},
"lookee":	{"UH"},
"lookee-loos":	{"NNS"},
"looker":	{"NN"},
"looker-on":	{"NN"},
"lookers":	{"NNS"},
"looking":	{"VBG"},
"lookout":	{"NN"},
"lookouts":	{"NNS"},
"lookover":	{"NN"},
"looks":	{"VBZ","NNS"},
"lookup":	{"NN"},
"looky":	{"UH"},
"loom":	{"VB","VBP","NN"},
"loomed":	{"VBD","VBN"},
"looming":	{"VBG"},
"looms":	{"VBZ","NNS"},
"loon":	{"NN"},
"looney":	{"NN"},
"loonie":	{"NN"},
"loonier":	{"JJR"},
"loonies":	{"NNS"},
"looniest":	{"JJS"},
"loons":	{"NNS"},
"loony":	{"JJ","NN"},
"loony-bin":	{"NN"},
"loony-bins":	{"NNS"},
"loop":	{"VB","VBP","NN"},
"loop-line":	{"NN"},
"loop-the-loop":	{"NN"},
"looped":	{"VBD","VBN"},
"looper":	{"NN"},
"loophole":	{"NN"},
"loopholes":	{"NNS"},
"looping":	{"NN","VBG"},
"loops":	{"VBZ","NNS"},
"loopy":	{"JJ"},
"loos":	{"NNS"},
"loose":	{"JJ","NN","VB","VBP"},
"loose-fitting":	{"JJ"},
"loose-jointed":	{"JJ"},
"loose-jowled":	{"JJ"},
"loose-knit":	{"JJ"},
"loose-leaf":	{"JJ"},
"loose-loaded":	{"JJ"},
"loosed":	{"VBD","VBN"},
"looseleaf":	{"NN"},
"loosely":	{"RB"},
"loosely-taped":	{"JJ"},
"loosen":	{"VB","VBP"},
"loosened":	{"VBD","VBN"},
"looseness":	{"NN"},
"loosening":	{"VBG","NN"},
"loosens":	{"VBZ"},
"looser":	{"JJR"},
"looses":	{"VBZ"},
"loosest":	{"JJS"},
"loosestrife":	{"NN"},
"loosing":	{"VBG"},
"loot":	{"NN","VB","VBP"},
"looted":	{"VBD","VBN"},
"looter":	{"NN"},
"looters":	{"NNS"},
"looting":	{"NN","VBG"},
"loots":	{"VBZ"},
"lop":	{"VB","VBP"},
"lop-eared":	{"JJ"},
"lope":	{"VB","VBP","NN"},
"loped":	{"VBD","VBN"},
"lopes":	{"VBZ"},
"lophiidae":	{"NN"},
"lophius":	{"NN"},
"lophodytes":	{"NNS"},
"lopholatilus":	{"NN"},
"lophophora":	{"NN"},
"lophophorus":	{"NN"},
"lophosoria":	{"NN"},
"lophosoriaceae":	{"NN"},
"lopid":	{"NN"},
"loping":	{"JJ","VBG"},
"lopped":	{"VBD","VBN"},
"lopper":	{"NN"},
"lopping":	{"NN","VBG"},
"lopressor":	{"NN"},
"lops":	{"VBZ"},
"lopsided":	{"JJ"},
"lopsidedly":	{"RB"},
"lopsidedness":	{"NN"},
"loquacious":	{"JJ"},
"loquaciously":	{"RB"},
"loquaciousness":	{"NN"},
"loquacity":	{"NN"},
"loquat":	{"NN"},
"loquats":	{"NNS"},
"loranthaceae":	{"NN"},
"loranthus":	{"NN"},
"lorazapam":	{"NN"},
"lorazepam":	{"NN"},
"lorchel":	{"NN"},
"lord":	{"NN","VB","VBP"},
"lorded":	{"VBD","VBN"},
"lording":	{"VBG"},
"lordless":	{"JJ"},
"lordlier":	{"JJR"},
"lordliest":	{"JJS"},
"lordliness":	{"NN"},
"lordly":	{"JJ"},
"lordolatry":	{"NN"},
"lordosis":	{"NN"},
"lordotic":	{"JJ"},
"lords":	{"NNS","VBZ"},
"lords-and-ladies":	{"NN"},
"lordship":	{"NN"},
"lordships":	{"NNS"},
"lore":	{"NN"},
"lorelei":	{"NN"},
"loren":	{"NN"},
"lorentz":	{"NN"},
"lorenz":	{"NN"},
"lorfan":	{"NN"},
"lorgnette":	{"NN"},
"lorica":	{"NN"},
"loricata":	{"NN"},
"loriinae":	{"NN"},
"lorikeet":	{"NN"},
"lorisidae":	{"NN"},
"lorraine":	{"NN"},
"lorre":	{"NN"},
"lorries":	{"NNS"},
"lorry":	{"NN"},
"lory":	{"NN"},
"lose":	{"VB","VBP"},
"loser":	{"NN"},
"losers":	{"NNS"},
"loses":	{"VBZ"},
"losing":	{"VBG","NN","JJ"},
"losings":	{"NNS"},
"loss":	{"NN"},
"loss-expense":	{"JJ"},
"loss-leader":	{"NN"},
"loss-leaders":	{"NNS"},
"loss-making":	{"JJ"},
"loss-plagued":	{"JJ"},
"loss-recovery":	{"JJ"},
"losses":	{"NNS"},
"lossless":	{"JJ"},
"lossy":	{"NN"},
"lost":	{"VBD","VBN","JJ"},
"lost-and-found":	{"NN","JJ"},
"lost-profits":	{"JJ"},
"lot":	{"NN","RB","PRP","VB","VBP"},
"lota":	{"NN"},
"loth":	{"JJ"},
"lothario":	{"NN"},
"lothringen":	{"NN"},
"loti":	{"NN"},
"lotic":	{"JJ"},
"lotion":	{"NN"},
"lotions":	{"NNS"},
"lots":	{"NNS","RB","PRP","VBZ"},
"lotte":	{"NN"},
"lotted":	{"VBD","VBN"},
"lotter":	{"NN"},
"lotteries":	{"NNS"},
"lottery":	{"NN"},
"lotting":	{"VBG"},
"lotto":	{"NN"},
"lotus":	{"NN"},
"lotus-eater":	{"NN"},
"lotuses":	{"NNS"},
"lotusland":	{"NN"},
"louche":	{"JJ"},
"loud":	{"JJ","RB"},
"loud-hailer":	{"NN"},
"loud-mouthed":	{"JJ"},
"loud-voiced":	{"JJ"},
"louden":	{"VB","VBP"},
"loudened":	{"VBD","VBN"},
"loudening":	{"VBG"},
"loudens":	{"VBZ"},
"louder":	{"JJR","RBR"},
"loudest":	{"JJS","RBS"},
"loudly":	{"RB"},
"loudmouth":	{"NN"},
"loudmouthed":	{"JJ"},
"loudmouths":	{"NNS"},
"loudness":	{"NN"},
"loudspeaker":	{"NN"},
"loudspeakers":	{"NNS"},
"lough":	{"NN"},
"loughs":	{"NNS"},
"louis-based":	{"JJ"},
"lounge":	{"NN","VBP","VB"},
"lounge-suit":	{"NN"},
"lounge-suits":	{"NNS"},
"lounged":	{"VBD","VBN"},
"lounger":	{"NN"},
"loungers":	{"NNS"},
"lounges":	{"NNS","VBZ"},
"loungewear":	{"NN"},
"lounging":	{"VBG"},
"loup-garou":	{"NN"},
"loupe":	{"NN"},
"lour":	{"VB","VBP"},
"loured":	{"VBD","VBN"},
"louring":	{"VBG"},
"lours":	{"VBZ"},
"louse":	{"NN","VB","VBP"},
"loused":	{"VBD","VBN"},
"louses":	{"VBZ","NNS"},
"lousier":	{"JJR"},
"lousiest":	{"JJS"},
"lousiness":	{"NN"},
"lousing":	{"VBG"},
"lousy":	{"JJ"},
"lout":	{"NN"},
"loutish":	{"JJ"},
"loutishly":	{"RB"},
"loutishness":	{"NN"},
"louts":	{"NNS"},
"louvar":	{"NN"},
"louver":	{"NN"},
"louvered":	{"JJ"},
"louvers":	{"NNS"},
"louvre":	{"NN"},
"louvred":	{"JJ"},
"louvres":	{"NNS"},
"lovable":	{"JJ"},
"lovage":	{"NN"},
"lovastatin":	{"NN"},
"love":	{"NN","VBP","VB"},
"love-hate":	{"JJ"},
"love-in-a-mist":	{"NN"},
"love-in-action":	{"NN"},
"love-in-idleness":	{"NN"},
"love-in-winter":	{"NN"},
"love-lies-bleeding":	{"NN"},
"love-making":	{"NN"},
"love-philter":	{"NN"},
"love-philtre":	{"NN"},
"love-potion":	{"NN"},
"love-song":	{"NN"},
"love-token":	{"NN"},
"loveable":	{"JJ"},
"lovebird":	{"NN"},
"lovebirds":	{"NNS"},
"loved":	{"VBD","VBN","JJ"},
"lovejoy":	{"NN"},
"lovelace":	{"NN"},
"loveless":	{"JJ"},
"lovelier":	{"JJR"},
"lovelier-than-life":	{"JJ"},
"lovelies":	{"NNS"},
"loveliest":	{"JJS"},
"loveliness":	{"NN"},
"lovelorn":	{"JJ"},
"lovely":	{"JJ"},
"lovemaking":	{"NN"},
"lover":	{"NN"},
"lovered":	{"JJ"},
"loverlike":	{"JJ"},
"loverly":	{"JJ"},
"lovers":	{"NNS"},
"loves":	{"VBZ","NNS"},
"loveseat":	{"NN"},
"lovesick":	{"JJ"},
"lovesickness":	{"NN"},
"lovesome":	{"JJ"},
"lovett":	{"NN"},
"loving":	{"JJ","VBG"},
"loving-kindness":	{"NN"},
"lovingly":	{"RB"},
"lovingness":	{"NN"},
"lovoa":	{"NN"},
"low":	{"JJ","NN","RB","VBP","VB"},
"low-VAT":	{"JJ"},
"low-ability":	{"JJ"},
"low-acid":	{"JJ"},
"low-altitude":	{"NN"},
"low-back":	{"JJ"},
"low-back-pain":	{"JJ"},
"low-backed":	{"JJ"},
"low-base-price":	{"JJ"},
"low-beam":	{"JJ"},
"low-boiling":	{"JJ"},
"low-brow":	{"NN","JJ"},
"low-brows":	{"NNS"},
"low-budget":	{"JJ"},
"low-cal":	{"JJ"},
"low-caliber":	{"NN"},
"low-calorie":	{"JJ"},
"low-ceilinged":	{"JJ"},
"low-cholesterol":	{"JJ"},
"low-class":	{"JJ"},
"low-concept":	{"JJ"},
"low-cost":	{"JJ"},
"low-crime":	{"JJ"},
"low-cut":	{"JJ"},
"low-density":	{"NN"},
"low-down":	{"JJ","NN"},
"low-duty":	{"JJ"},
"low-end":	{"JJ"},
"low-fat":	{"JJ"},
"low-flying":	{"JJ"},
"low-foam":	{"NN"},
"low-frequency":	{"JJ"},
"low-grade":	{"JJ"},
"low-grossing":	{"JJ"},
"low-growing":	{"JJ"},
"low-growth":	{"JJ"},
"low-heeled":	{"JJ"},
"low-interest":	{"JJ"},
"low-interest-rate":	{"JJ"},
"low-key":	{"JJ"},
"low-keyed":	{"JJ"},
"low-level":	{"JJ"},
"low-life":	{"NN"},
"low-lifes":	{"NNS"},
"low-load":	{"JJ"},
"low-loss":	{"JJ","NN"},
"low-lying":	{"JJ"},
"low-maintenance":	{"JJ"},
"low-margin":	{"JJ"},
"low-moisture":	{"JJ"},
"low-necked":	{"JJ"},
"low-paid":	{"JJ"},
"low-pass":	{"JJ"},
"low-paying":	{"JJ"},
"low-pitched":	{"JJ"},
"low-polluting":	{"JJ"},
"low-power":	{"JJ"},
"low-powered":	{"JJ"},
"low-pressure":	{"JJ","NN"},
"low-price":	{"JJ"},
"low-priced":	{"JJ"},
"low-profile":	{"JJ"},
"low-profit":	{"JJ","NN"},
"low-profitmargin":	{"NN"},
"low-quality":	{"JJ"},
"low-rate":	{"JJ"},
"low-rated":	{"JJ"},
"low-resolution":	{"JJ","NN"},
"low-rise":	{"JJ","NN"},
"low-risk":	{"JJ"},
"low-set":	{"JJ"},
"low-slung":	{"JJ"},
"low-smoke":	{"JJ"},
"low-speed":	{"JJ"},
"low-spirited":	{"JJ"},
"low-spiritedness":	{"NN"},
"low-stress":	{"JJ"},
"low-sudsing":	{"JJ"},
"low-sugar":	{"JJ"},
"low-sulfur":	{"JJ"},
"low-sulphur":	{"JJ"},
"low-tax":	{"NN"},
"low-tech":	{"JJ"},
"low-temperature":	{"JJ","NN"},
"low-tension":	{"JJ"},
"low-to-no-fat":	{"JJ"},
"low-toned":	{"JJ"},
"low-value":	{"JJ"},
"low-vat":	{"JJ"},
"low-voltage":	{"JJ"},
"low-volume":	{"JJ","NN"},
"low-wage":	{"JJ","NN"},
"low-warp-loom":	{"NN"},
"low-water":	{"NN","JJ"},
"low-yielding":	{"JJ"},
"lowan":	{"NN"},
"lowball":	{"VB","VBP","NN","JJ"},
"lowballed":	{"VBD","VBN"},
"lowballing":	{"VBG","NN"},
"lowballs":	{"VBZ"},
"lowborn":	{"JJ"},
"lowboy":	{"NN"},
"lowbred":	{"JJ"},
"lowbrow":	{"NN","JJ"},
"lowbrowed":	{"JJ"},
"lowbrows":	{"NNS"},
"lowdown":	{"NN"},
"lowed":	{"VBD","VBN"},
"lower":	{"JJR","RBR","VB","VBP","JJ"},
"lower-class":	{"JJ","NN"},
"lower-classes":	{"NNS"},
"lower-cost":	{"JJ"},
"lower-court":	{"JJ","NN"},
"lower-cut":	{"JJ"},
"lower-emission":	{"NN"},
"lower-growth":	{"JJ"},
"lower-house":	{"NN"},
"lower-income":	{"JJ"},
"lower-level":	{"JJ","NN"},
"lower-middle":	{"JJ"},
"lower-middle-class":	{"JJ"},
"lower-normandy":	{"NN"},
"lower-paid":	{"JJ"},
"lower-priced":	{"JJ"},
"lower-priority":	{"JJ"},
"lower-ranking":	{"JJ"},
"lower-rated":	{"JJ"},
"lower-status":	{"JJ","NN"},
"lower-tech":	{"JJ"},
"lower-than-anticipated":	{"JJ"},
"lower-than-expected":	{"JJ"},
"lower-than-forecast":	{"JJ"},
"lower-than-planned":	{"JJ"},
"lower-volume":	{"JJ"},
"lower-wage":	{"JJ"},
"lowercase":	{"JJ"},
"lowerclassman":	{"NN"},
"lowered":	{"VBD","VBN","JJ"},
"lowering":	{"VBG","JJ","NN"},
"loweringly":	{"RB"},
"lowermost":	{"JJ"},
"lowers":	{"VBZ"},
"lowest":	{"JJS","RBS"},
"lowest-cost":	{"JJ"},
"lowest-paying":	{"JJ"},
"lowest-priced":	{"JJ"},
"lowest-rated":	{"JJ"},
"lowincome":	{"JJ"},
"lowing":	{"VBG"},
"lowland":	{"JJ","NN"},
"lowlander":	{"NN"},
"lowlanders":	{"NNS"},
"lowlands":	{"NNS"},
"lowlier":	{"JJR"},
"lowliest":	{"JJS"},
"lowlife":	{"NN","JJ"},
"lowlifes":	{"NNS"},
"lowliness":	{"NN"},
"lowly":	{"JJ","RB"},
"lowness":	{"NN"},
"lowprofile":	{"JJ"},
"lows":	{"NNS","VBZ"},
"lowset":	{"JJ"},
"lox":	{"NN"},
"loxapine":	{"NN"},
"loxia":	{"NN"},
"loxitane":	{"NN"},
"loxodonta":	{"NN"},
"loxodrome":	{"NN"},
"loxoma":	{"NN"},
"loxomataceae":	{"NN"},
"loxostege":	{"NN"},
"loyal":	{"JJ"},
"loyalist":	{"NN","JJ"},
"loyalists":	{"NNS"},
"loyally":	{"RB"},
"loyalties":	{"NNS"},
"loyalty":	{"NN"},
"loyang":	{"NN"},
"lozal":	{"NN"},
"lozenge":	{"NN"},
"lozenges":	{"NNS"},
"lpn":	{"NN"},
"lr":	{"NN"},
"lsd":	{"NN"},
"ltm":	{"NN"},
"ltte":	{"NN"},
"luau":	{"NN"},
"luba":	{"NN"},
"lubavitch":	{"NN"},
"lubavitcher":	{"NN"},
"lubber":	{"NN"},
"lubberlanders":	{"NNS"},
"lubberly":	{"JJ","RB"},
"lube":	{"NN"},
"lubeck":	{"NN"},
"lubitsch":	{"NN"},
"lublin":	{"NN"},
"lubra":	{"NN"},
"lubricant":	{"NN"},
"lubricants":	{"NNS"},
"lubricate":	{"VB","VBP"},
"lubricated":	{"VBD","VBN"},
"lubricates":	{"VBZ"},
"lubricating":	{"VBG"},
"lubricating-oil":	{"NN"},
"lubrication":	{"NN"},
"lubricator":	{"NN"},
"lubricious":	{"JJ"},
"lubriciously":	{"RB"},
"lubricity":	{"NN"},
"lubumbashi":	{"NN"},
"lucania":	{"NN"},
"lucanidae":	{"NN"},
"luce":	{"NN"},
"lucent":	{"JJ"},
"lucerne":	{"NN"},
"lucid":	{"JJ"},
"lucidity":	{"NN"},
"lucidly":	{"RB"},
"lucidness":	{"NN"},
"luciferin":	{"NN"},
"lucifugal":	{"JJ"},
"lucifugous":	{"JJ"},
"lucilia":	{"NN"},
"luck":	{"NN","VB","VBP"},
"lucked":	{"VBD","VBN"},
"luckier":	{"JJR"},
"luckiest":	{"JJS"},
"luckily":	{"RB"},
"luckiness":	{"NN"},
"lucking":	{"VBG"},
"luckless":	{"JJ"},
"lucknow":	{"NN"},
"lucks":	{"NNS","VBZ"},
"lucky":	{"JJ"},
"lucrative":	{"JJ"},
"lucratively":	{"RB"},
"lucrativeness":	{"NN"},
"lucre":	{"NN"},
"lucubrate":	{"VB","VBP"},
"lucubrated":	{"VBD","VBN"},
"lucubrates":	{"VBZ"},
"lucubrating":	{"VBG"},
"lucubration":	{"NN"},
"lucubrator":	{"NN"},
"luculent":	{"JJ"},
"lucullan":	{"JJ"},
"lucullus":	{"NN"},
"luculus":	{"NN"},
"luda":	{"NN"},
"ludian":	{"NN"},
"ludicrous":	{"JJ"},
"ludicrously":	{"RB"},
"ludicrousness":	{"NN"},
"ludlow":	{"NN"},
"ludo":	{"NN"},
"lues":	{"NN"},
"lufengpithecus":	{"NNS"},
"luff":	{"NN","VB","VBP"},
"luffa":	{"NN"},
"luffed":	{"VBD","VBN"},
"luffing":	{"VBG"},
"luffs":	{"VBZ"},
"lufthansa":	{"NN"},
"lug":	{"VB","VBP","NN"},
"luganda":	{"NN"},
"lugar":	{"NN"},
"luge":	{"NN"},
"luger":	{"NN"},
"luges":	{"NNS"},
"luggage":	{"NN"},
"luggage-rack":	{"NN"},
"luggage-racks":	{"NNS"},
"luggage-van":	{"NN"},
"luggage-vans":	{"NNS"},
"lugged":	{"VBD","VBN"},
"lugger":	{"NN"},
"luggers":	{"NNS"},
"lugging":	{"VBG"},
"lugh":	{"NN"},
"lugs":	{"NNS","VBZ"},
"lugsail":	{"NN"},
"lugubrious":	{"JJ"},
"lugubriously":	{"RB"},
"lugubriousness":	{"NN"},
"lugworm":	{"NN"},
"lui":	{"FW"},
"luik":	{"NN"},
"luisa":	{"NN"},
"lukewarm":	{"JJ"},
"lukewarmly":	{"RB"},
"lukewarmness":	{"NN"},
"lull":	{"NN","VB","VBP"},
"lullabied":	{"VBD","VBN"},
"lullabies":	{"NNS","VBZ"},
"lullaby":	{"NN","VB","VBP"},
"lullabying":	{"VBG"},
"lulled":	{"VBD","VBN"},
"lulling":	{"VBG"},
"lulls":	{"NNS","VBZ"},
"lulu":	{"NN"},
"luluabourg":	{"NN"},
"lumbago":	{"NN"},
"lumbar":	{"JJ","NN"},
"lumber":	{"NN","VBP","VB"},
"lumber-jacket":	{"NN"},
"lumber-like":	{"JJ"},
"lumber-room":	{"NN"},
"lumber-rooms":	{"NNS"},
"lumbered":	{"VBD","VBN"},
"lumbering":	{"NN","VBG"},
"lumberjack":	{"NN"},
"lumberjacks":	{"NNS"},
"lumberman":	{"NN"},
"lumbermen":	{"NNS"},
"lumbermill":	{"NN"},
"lumbermills":	{"NNS"},
"lumbers":	{"VBZ"},
"lumberyard":	{"NN"},
"lumberyards":	{"NNS"},
"lumbosacral":	{"JJ"},
"lumbus":	{"NN"},
"lumen":	{"NN"},
"luminal":	{"NN"},
"luminance":	{"NN"},
"luminaries":	{"NNS"},
"luminary":	{"NN"},
"luminesce":	{"VB","VBP"},
"luminesced":	{"VBD","VBN"},
"luminescence":	{"NN"},
"luminescent":	{"JJ"},
"luminesces":	{"VBZ"},
"luminescing":	{"VBG"},
"luminiferous":	{"JJ"},
"luminism":	{"NN"},
"luminosity":	{"NN"},
"luminous":	{"JJ"},
"luminously":	{"RB"},
"luminousness":	{"NN"},
"lummox":	{"NN"},
"lump":	{"NN","VB","VBP"},
"lump-sum":	{"NN"},
"lump-sums":	{"NNS"},
"lumpectomies":	{"NNS"},
"lumpectomy":	{"NN"},
"lumped":	{"VBN","VBD"},
"lumpen":	{"JJ"},
"lumpen-intellectual":	{"JJ"},
"lumpenproletariat":	{"NN"},
"lumpenus":	{"NN"},
"lumper":	{"NN"},
"lumpfish":	{"NN","NNS"},
"lumpfishes":	{"NNS"},
"lumpier":	{"JJR"},
"lumpiest":	{"JJS"},
"lumping":	{"VBG"},
"lumpish":	{"JJ"},
"lumps":	{"NNS","VBZ"},
"lumpsucker":	{"NN"},
"lumpy":	{"JJ"},
"lunacy":	{"NN"},
"lunar":	{"JJ"},
"lunaria":	{"NN"},
"lunate":	{"NN","JJ"},
"lunatic":	{"NN","JJ"},
"lunatic-fringe":	{"JJ"},
"lunatics":	{"NNS"},
"lunation":	{"NN"},
"lunch":	{"NN","VB","VBP"},
"lunch-box":	{"NN"},
"lunch-boxes":	{"NNS"},
"lunch-hour":	{"NN"},
"lunch-time":	{"NN"},
"lunch-times":	{"NNS"},
"lunched":	{"VBD","VBN"},
"luncheon":	{"NN"},
"luncheon-meat":	{"NN"},
"luncheon-table":	{"JJ"},
"luncheon-voucher":	{"NN"},
"luncheons":	{"NNS"},
"luncher":	{"NN"},
"lunches":	{"NNS","VBZ"},
"lunching":	{"VBG"},
"lunchroom":	{"NN"},
"lunchrooms":	{"NNS"},
"lunchtime":	{"NN"},
"lunchtimes":	{"NNS"},
"lund":	{"NN"},
"lunda":	{"NN"},
"lunette":	{"NN"},
"lung":	{"NN"},
"lung-cancer":	{"NN"},
"lung-function":	{"JJ"},
"lung-like":	{"JJ"},
"lung-power":	{"NN"},
"lung-tissue":	{"JJ"},
"lunge":	{"NN","VB","VBP"},
"lunged":	{"VBD","VBN"},
"lungen":	{"NN"},
"lunger":	{"NN"},
"lunges":	{"NNS","VBZ"},
"lungfish":	{"NN"},
"lungi":	{"NN"},
"lunging":	{"VBG"},
"lungs":	{"NNS"},
"lungyi":	{"NN"},
"lunisolar":	{"JJ"},
"lunkhead":	{"NN"},
"lunt":	{"NN"},
"lunula":	{"NN"},
"lunule":	{"NN"},
"luo":	{"NN"},
"luoyang":	{"NN"},
"lupin":	{"NN"},
"lupine":	{"JJ","NN"},
"lupinus":	{"NN"},
"lupus":	{"NN"},
"lurch":	{"NN","VB","VBP"},
"lurched":	{"VBD","VBN"},
"lurcher":	{"NN"},
"lurches":	{"NNS","VBZ"},
"lurching":	{"VBG"},
"lure":	{"VB","VBP","NN"},
"lured":	{"VBD","VBN"},
"lures":	{"VBZ","NNS"},
"lurid":	{"JJ"},
"luridly":	{"RB"},
"luridness":	{"NN"},
"luring":	{"VBG"},
"lurk":	{"VB","VBP","NN"},
"lurked":	{"VBD","VBN"},
"lurker":	{"NN"},
"lurking":	{"NN","VBG"},
"lurks":	{"VBZ","NNS"},
"lusatian":	{"NN"},
"luscinia":	{"NN"},
"luscious":	{"JJ"},
"lusciously":	{"RB"},
"lusciousness":	{"NN"},
"lush":	{"JJ","NN","VB","VBP"},
"lushed":	{"VBD","VBN"},
"lusher":	{"JJR"},
"lushes":	{"NNS","VBZ"},
"lushest":	{"JJS"},
"lushing":	{"VBG"},
"lushly":	{"RB"},
"lushness":	{"NN"},
"lushun":	{"NN"},
"lusitanian":	{"JJ"},
"lust":	{"NN","VB","VBP"},
"lusted":	{"VBD","VBN"},
"luster":	{"NN","VB","VBP"},
"lustered":	{"VBD","VBN"},
"lustering":	{"VBG"},
"lusterless":	{"JJ"},
"lusterlessness":	{"NN"},
"lusters":	{"VBZ"},
"lusterware":	{"NN"},
"lustful":	{"JJ"},
"lustfully":	{"RB"},
"lustfulness":	{"NN"},
"lustier":	{"JJR"},
"lustiest":	{"JJS"},
"lustily":	{"RB"},
"lustiness":	{"NN"},
"lusting":	{"VBG"},
"lustrate":	{"VB","VBP"},
"lustrated":	{"VBD","VBN"},
"lustrates":	{"VBZ"},
"lustrating":	{"VBG"},
"lustration":	{"NN"},
"lustrative":	{"JJ"},
"lustre":	{"NN"},
"lustreless":	{"JJ"},
"lustrelessness":	{"NN"},
"lustrous":	{"JJ"},
"lustrously":	{"RB"},
"lustrum":	{"NN"},
"lusts":	{"NNS","VBZ"},
"lusty":	{"JJ"},
"luta":	{"NN"},
"lutanist":	{"NN"},
"lute":	{"VB","VBP","NN"},
"luteal":	{"JJ"},
"lutecium":	{"NN"},
"luted":	{"VBD","VBN"},
"lutefisk":	{"NN"},
"lutein":	{"NN"},
"lutenist":	{"NN"},
"lutenists":	{"NNS"},
"luteotropin":	{"NN"},
"lutes":	{"VBZ","NNS"},
"lutetium":	{"NN"},
"lutfisk":	{"NN"},
"luthier":	{"NN"},
"lutihaw":	{"FW"},
"luting":	{"VBG"},
"lutist":	{"NN"},
"lutjanidae":	{"NN"},
"lutjanus":	{"NN"},
"lutra":	{"NN"},
"lutrinae":	{"NN"},
"lutyens":	{"NN"},
"lutz":	{"NN"},
"lutzen":	{"NN"},
"luvaridae":	{"NN"},
"luvarus":	{"NN"},
"luvian":	{"NN"},
"luwian":	{"NN"},
"lux":	{"NN"},
"luxate":	{"VB","VBP"},
"luxated":	{"VBD","VBN"},
"luxates":	{"VBZ"},
"luxating":	{"VBG"},
"luxation":	{"NN"},
"luxe":	{"JJ","NN"},
"luxembourg-based":	{"JJ"},
"luxembourg-registered":	{"JJ"},
"luxembourg-ville":	{"NN"},
"luxembourgian":	{"JJ"},
"luxuria":	{"NN"},
"luxuriance":	{"NN"},
"luxuriant":	{"JJ"},
"luxuriantly":	{"RB"},
"luxuriate":	{"VB","VBP"},
"luxuriated":	{"VBD","VBN"},
"luxuriates":	{"VBZ"},
"luxuriating":	{"VBG"},
"luxuriation":	{"NN"},
"luxuries":	{"NNS"},
"luxuriosly-upholstered":	{"JJ"},
"luxurious":	{"JJ"},
"luxuriously":	{"RB"},
"luxuriousness":	{"NN"},
"luxury":	{"NN","JJ"},
"luxury-car":	{"NN","JJ"},
"luxury-goods":	{"NNS"},
"luxury-suite":	{"NN"},
"luyia":	{"NN"},
"luzon":	{"NN"},
"lvi":	{"JJ"},
"lvii":	{"JJ"},
"lviii":	{"JJ"},
"lvy":	{"NN"},
"lwei":	{"NN"},
"lweis":	{"NNS"},
"lx":	{"NN"},
"lxi":	{"JJ"},
"lxii":	{"JJ"},
"lxiii":	{"JJ"},
"lxiv":	{"JJ"},
"lxv":	{"JJ"},
"lxvi":	{"JJ"},
"lxvii":	{"JJ"},
"lxviii":	{"JJ"},
"lxx":	{"JJ","NN"},
"lxxi":	{"JJ"},
"lxxii":	{"JJ"},
"lxxiii":	{"JJ"},
"lxxiv":	{"JJ"},
"lxxv":	{"JJ"},
"lxxvi":	{"JJ"},
"lxxvii":	{"JJ"},
"lxxviii":	{"JJ","NN"},
"lxxx":	{"JJ","NN"},
"lxxxi":	{"JJ"},
"lxxxii":	{"JJ"},
"lxxxiii":	{"JJ"},
"lxxxiv":	{"JJ"},
"lxxxv":	{"JJ"},
"lxxxvi":	{"JJ"},
"lxxxvii":	{"JJ"},
"lxxxviii":	{"JJ"},
"lyallpur":	{"NN"},
"lycaena":	{"NN"},
"lycaenid":	{"NN"},
"lycaenidae":	{"NN"},
"lycaeon":	{"NN"},
"lycanthrope":	{"NN"},
"lycanthropy":	{"NN"},
"lycee":	{"NN"},
"lyceum":	{"NN"},
"lyceums":	{"NNS"},
"lychee":	{"NN"},
"lychees":	{"NNS"},
"lychgate":	{"NN"},
"lychgates":	{"NNS"},
"lychnis":	{"NN"},
"lycia":	{"NN"},
"lycian":	{"NN"},
"lycium":	{"NN"},
"lycopene":	{"NN"},
"lycoperdaceae":	{"NN"},
"lycoperdales":	{"NN"},
"lycoperdon":	{"NN"},
"lycopersicon":	{"NN"},
"lycopersicum":	{"NN"},
"lycophyta":	{"NN"},
"lycopod":	{"NN"},
"lycopodiaceae":	{"NN"},
"lycopodiales":	{"NN"},
"lycopodiate":	{"NN"},
"lycopodineae":	{"NN"},
"lycopodium":	{"NN"},
"lycopsida":	{"NN"},
"lycopus":	{"NN"},
"lycosa":	{"NN"},
"lycosidae":	{"NN"},
"lydia":	{"NN"},
"lydian":	{"NN"},
"lye":	{"NN"},
"lygaeid":	{"NN"},
"lygaeidae":	{"NN"},
"lyginopteridales":	{"NN"},
"lyginopteris":	{"NN"},
"lygodium":	{"NN"},
"lygus":	{"NN"},
"lyin":	{"NN"},
"lying":	{"VBG","NN"},
"lying-in":	{"NN"},
"lymantria":	{"NN"},
"lymantriid":	{"NN"},
"lymantriidae":	{"NN"},
"lyme-disease":	{"JJ"},
"lymph":	{"NN"},
"lymphadenitis":	{"NN"},
"lymphadenoma":	{"NN"},
"lymphadenopathy":	{"NN"},
"lymphangiectasia":	{"NN"},
"lymphangiectasis":	{"NN"},
"lymphangiogram":	{"NN"},
"lymphangiography":	{"NN"},
"lymphangioma":	{"NN"},
"lymphangitis":	{"NN"},
"lymphatic":	{"JJ"},
"lymphedema":	{"NN"},
"lymphoblast":	{"NN"},
"lymphoblast-like":	{"JJ"},
"lymphocyte":	{"NN"},
"lymphocytes":	{"NNS"},
"lymphocytic":	{"JJ"},
"lymphocytopenia":	{"NN"},
"lymphocytosis":	{"NN"},
"lymphogranuloma":	{"NN"},
"lymphography":	{"NN"},
"lymphoid":	{"JJ"},
"lymphokine":	{"NN"},
"lymphoma":	{"NN"},
"lymphopenia":	{"NN"},
"lymphopoiesis":	{"NN"},
"lymphuria":	{"NN"},
"lynch":	{"VB","VBP"},
"lynch-led":	{"JJ"},
"lynch-mob":	{"JJ"},
"lynch-mobs":	{"NNS"},
"lynchburg":	{"NN"},
"lynched":	{"VBD","VBN"},
"lynches":	{"VBZ"},
"lynching":	{"NN","VBG"},
"lynchings":	{"NNS"},
"lynchpin":	{"NN"},
"lynx":	{"NN","NNS"},
"lynx-eyed":	{"JJ"},
"lynxes":	{"NNS"},
"lyonia":	{"NN"},
"lyonnaise":	{"JJ"},
"lyophilisation":	{"NN"},
"lyophilise":	{"VB","VBP"},
"lyophilised":	{"VBD","VBN"},
"lyophilises":	{"VBZ"},
"lyophilising":	{"VBG"},
"lyophilization":	{"NN"},
"lyophilize":	{"VB","VBP"},
"lyophilized":	{"VBD","VBN"},
"lyophilizes":	{"VBZ"},
"lyophilizing":	{"VBG"},
"lypressin":	{"NN"},
"lyrate":	{"JJ"},
"lyre":	{"NN"},
"lyre-flower":	{"NN"},
"lyre-shaped":	{"JJ"},
"lyrebird":	{"NN"},
"lyreflower":	{"NN"},
"lyres":	{"NNS"},
"lyric":	{"NN","JJ"},
"lyrical":	{"JJ"},
"lyricality":	{"NN"},
"lyrically":	{"RB"},
"lyricism":	{"NN"},
"lyricist":	{"NN"},
"lyricists":	{"NNS"},
"lyrics":	{"NNS"},
"lyrist":	{"NN"},
"lyrurus":	{"NN"},
"lysander":	{"NN"},
"lysee":	{"NN"},
"lysenko":	{"NN"},
"lysichiton":	{"NN"},
"lysichitum":	{"NN"},
"lysiloma":	{"NN"},
"lysimachia":	{"NN"},
"lysimachus":	{"NN"},
"lysin":	{"NN"},
"lysine":	{"NN"},
"lysinemia":	{"NN"},
"lysippus":	{"NN"},
"lysis":	{"NN"},
"lysogenic":	{"JJ"},
"lysogenicity":	{"NN"},
"lysogenisation":	{"NN"},
"lysogenise":	{"VB","VBP"},
"lysogenised":	{"VBD","VBN"},
"lysogenises":	{"VBZ"},
"lysogenising":	{"VBG"},
"lysogenization":	{"NN"},
"lysogenize":	{"VB","VBP"},
"lysogenized":	{"VBD","VBN"},
"lysogenizes":	{"VBZ"},
"lysogenizing":	{"VBG"},
"lysogeny":	{"NN"},
"lysol":	{"NN"},
"lysosome":	{"NN"},
"lysozyme":	{"NN"},
"lyssa":	{"NN"},
"lyssavirus":	{"NN"},
"lythraceae":	{"NN"},
"lythrum":	{"NN"},
"m":	{"NN","SYM","LS"},
"m-1":	{"NN"},
"m-theory":	{"NN"},
"m.m.":	{"NN"},
"m.p.h":	{"NN","RB"},
"m.p.h.":	{"NN"},
"m1":	{"NN"},
"m2":	{"NN"},
"m3":	{"NN"},
"mSv":	{"NN"},
"ma":	{"NN"},
"ma'am":	{"NN"},
"maalox":	{"NN"},
"maar":	{"NN"},
"maarianhamina":	{"NN"},
"mac":	{"NN"},
"macabre":	{"JJ"},
"macaca":	{"NN"},
"macadam":	{"NN"},
"macadamia":	{"NN"},
"macadamias":	{"NNS"},
"macadamise":	{"VB","VBP"},
"macadamised":	{"VBD","VBN"},
"macadamises":	{"VBZ"},
"macadamising":	{"VBG"},
"macadamize":	{"VB","VBP"},
"macadamized":	{"VBD","VBN"},
"macadamizes":	{"VBZ"},
"macadamizing":	{"VBG"},
"macamba":	{"NN"},
"macaque":	{"NN"},
"macaron":	{"NN"},
"macaroni":	{"NN"},
"macaroni-and-cheese":	{"NN"},
"macaronic":	{"JJ"},
"macarons":	{"NNS"},
"macaroon":	{"NN"},
"macaroons":	{"NNS"},
"macau":	{"NN"},
"macaulay":	{"NN"},
"macaw":	{"NN"},
"macaws":	{"NNS"},
"macdowell":	{"NN"},
"mace":	{"NN"},
"mace-bearer":	{"NN"},
"macebearer":	{"NN"},
"macebearers":	{"NNS"},
"macedoine":	{"NN"},
"macedon":	{"NN"},
"macer":	{"NN"},
"macerate":	{"VB","VBP"},
"macerated":	{"VBD","VBN"},
"macerates":	{"VBZ"},
"macerating":	{"VBG"},
"maceration":	{"NN"},
"macerative":	{"JJ"},
"maces":	{"NNS"},
"macgregor":	{"NN"},
"macguffin":	{"NN"},
"mach":	{"NN"},
"machaeranthera":	{"NN"},
"machete":	{"NN"},
"machetes":	{"NNS"},
"machiavellian":	{"JJ","NN"},
"machiavellianism":	{"NN"},
"machicolate":	{"VB","VBP"},
"machicolated":	{"VBD","VBN"},
"machicolates":	{"VBZ"},
"machicolating":	{"VBG"},
"machicolation":	{"NN"},
"machikin":	{"FW"},
"machilid":	{"NN"},
"machilidae":	{"NN"},
"machinate":	{"VB","VBP"},
"machinated":	{"VBD","VBN"},
"machinates":	{"VBZ"},
"machinating":	{"VBG"},
"machination":	{"NN"},
"machinations":	{"NNS"},
"machinator":	{"NN"},
"machine":	{"NN","VBP","VB"},
"machine-accessible":	{"JJ"},
"machine-controlled":	{"JJ"},
"machine-driven":	{"JJ"},
"machine-family":	{"NN"},
"machine-gun":	{"NN","VBP","VB"},
"machine-gun-toting":	{"JJ"},
"machine-gunned":	{"VBD","VBN"},
"machine-gunner":	{"NN"},
"machine-gunners":	{"NNS"},
"machine-guns":	{"VBZ","NNS"},
"machine-made":	{"JJ"},
"machine-masters":	{"NNS"},
"machine-tool":	{"NN"},
"machine-tools":	{"NNS"},
"machine-vision":	{"NN"},
"machine-wash":	{"VB","VBP"},
"machine-washable":	{"JJ"},
"machine-washed":	{"VBD","VBN"},
"machine-washes":	{"VBZ"},
"machine-washing":	{"VBG"},
"machined":	{"VBD","VBN"},
"machinegun":	{"NN"},
"machinegunning":	{"VBG"},
"machinelike":	{"JJ"},
"machinery":	{"NN"},
"machinery-trading":	{"JJ"},
"machines":	{"NNS","VBZ"},
"machining":	{"VBG","NN"},
"machinist":	{"NN"},
"machinists":	{"NNS"},
"machismo":	{"NN"},
"machmeter":	{"NN"},
"macho":	{"JJ","NN"},
"macho-man":	{"NN"},
"machos":	{"NNS"},
"mack":	{"NN"},
"mackem":	{"NN"},
"mackenzie":	{"NN"},
"mackerel":	{"NN","NNS"},
"mackinaw":	{"NN"},
"mackintosh":	{"NN"},
"mackintoshes":	{"NNS"},
"mackle":	{"NN"},
"macks":	{"NNS"},
"macleaya":	{"NN"},
"macleish":	{"NN"},
"macleod":	{"NN"},
"maclura":	{"NN"},
"macon":	{"NN"},
"maconnais":	{"NN"},
"macoun":	{"NN"},
"macowanites":	{"NN"},
"macrame":	{"NN"},
"macrencephalic":	{"JJ"},
"macrencephalous":	{"JJ"},
"macrencephaly":	{"NN"},
"macro":	{"JJ","NN"},
"macro-astrology":	{"NN"},
"macro-instructions":	{"NNS"},
"macrobiotic":	{"JJ"},
"macrobiotics":	{"NN"},
"macrocephalic":	{"JJ"},
"macrocephalon":	{"NN"},
"macrocephalous":	{"JJ"},
"macrocephaly":	{"NN"},
"macrocheira":	{"NN"},
"macroclemys":	{"NN"},
"macrocosm":	{"NN"},
"macrocosmic":	{"JJ"},
"macrocrystal":	{"NN"},
"macrocrystalline":	{"NN"},
"macrocrystals":	{"NNS"},
"macrocyte":	{"NN"},
"macrocytosis":	{"NN"},
"macrodactylus":	{"NN"},
"macrodantin":	{"NN"},
"macroeconomic":	{"JJ"},
"macroeconomics":	{"NN"},
"macroeconomist":	{"NN"},
"macroevolution":	{"NN"},
"macroglia":	{"NN"},
"macroglossia":	{"NN"},
"macromolecular":	{"JJ"},
"macromolecule":	{"NN"},
"macromolecules":	{"NNS"},
"macron":	{"NN"},
"macronectes":	{"NNS"},
"macropathological":	{"JJ"},
"macropathology":	{"NN"},
"macrophage":	{"NN"},
"macrophages":	{"NNS"},
"macropodidae":	{"NN"},
"macropus":	{"NN"},
"macrorhamphosidae":	{"NN"},
"macros":	{"NNS"},
"macroscopic":	{"JJ"},
"macroscopical":	{"JJ"},
"macroscopically":	{"RB"},
"macrosporangium":	{"NN"},
"macrospore":	{"NN"},
"macrothelypteris":	{"NNS"},
"macrotis":	{"NN"},
"macrotus":	{"NN"},
"macrotyloma":	{"NN"},
"macrouridae":	{"NN"},
"macrozamia":	{"NN"},
"macrozoarces":	{"NN"},
"macruridae":	{"NN"},
"macs":	{"NNS"},
"macula":	{"NN"},
"maculate":	{"VB","VBP"},
"maculated":	{"VBD","VBN"},
"maculates":	{"VBZ"},
"maculating":	{"VBG"},
"maculation":	{"NN"},
"macule":	{"NN"},
"macumba":	{"NN"},
"macushla":	{"NN"},
"mad":	{"JJ"},
"madake":	{"NN"},
"madam":	{"NN"},
"madams":	{"NNS"},
"madcap":	{"JJ","NN"},
"madden":	{"VB","VBP"},
"maddened":	{"VBD","VBN"},
"maddening":	{"JJ","VBG"},
"maddeningly":	{"RB"},
"maddens":	{"VBZ"},
"madder":	{"NN","JJR"},
"madderwort":	{"NN"},
"maddest":	{"JJS"},
"made":	{"VBD","VBN","JJ"},
"made-for-TV":	{"JJ"},
"made-for-television":	{"JJ"},
"made-for-tv":	{"JJ"},
"made-to-order":	{"JJ"},
"made-up":	{"JJ"},
"madhouse":	{"NN"},
"madhouses":	{"NNS"},
"madia":	{"NN"},
"madly":	{"RB"},
"madman":	{"NN"},
"madmen":	{"NNS"},
"madnep":	{"NN"},
"madness":	{"NN"},
"madoqua":	{"NN"},
"madrasa":	{"NN"},
"madrasah":	{"NN"},
"madrasahs":	{"NNS"},
"madrassa":	{"NN"},
"madrassas":	{"NNS"},
"madreporaria":	{"NN"},
"madrepore":	{"NN"},
"madrid-based":	{"JJ"},
"madrigal":	{"NN"},
"madrigaling":	{"NN"},
"madrigalist":	{"NN"},
"madrigals":	{"NNS"},
"madrilene":	{"NN"},
"madrona":	{"NN"},
"madrono":	{"NN"},
"madstone":	{"NN"},
"madstones":	{"NNS"},
"madwoman":	{"NN"},
"madwomen":	{"NNS"},
"madwort":	{"NN"},
"mae-backed":	{"JJ"},
"maeandra":	{"NN"},
"maelstrom":	{"NN"},
"maelstroms":	{"NNS"},
"maenad":	{"NN"},
"maestri":	{"NNS"},
"maestro":	{"NN"},
"maestros":	{"NNS"},
"maeterlinck":	{"NN"},
"mafa":	{"NN"},
"maffia":	{"NN"},
"mafia":	{"NN"},
"mafia-tainted":	{"JJ"},
"mafias":	{"NNS"},
"mafiosi":	{"NNS"},
"mafioso":	{"NN"},
"mag":	{"NN"},
"magadhan":	{"NN"},
"magazine":	{"NN"},
"magazines":	{"NNS"},
"magdalen":	{"NN"},
"magdalena":	{"NN"},
"magenta":	{"NN","JJ"},
"maget":	{"NN"},
"maggot":	{"NN"},
"maggot-covered":	{"JJ"},
"maggots":	{"NNS"},
"maggoty":	{"JJ"},
"magi":	{"NNS"},
"magic":	{"NN","JJ","VB","VBP"},
"magic-practicing":	{"JJ"},
"magical":	{"JJ"},
"magically":	{"RB"},
"magician":	{"NN"},
"magicians":	{"NNS"},
"magicicada":	{"NN"},
"magicked":	{"VBD","VBN"},
"magicking":	{"VBG"},
"magics":	{"VBZ"},
"magilp":	{"NN"},
"maginot":	{"NN"},
"magisterial":	{"JJ"},
"magisterially":	{"RB"},
"magistracy":	{"NN"},
"magistrate":	{"NN"},
"magistrates":	{"NNS"},
"magistrature":	{"NN"},
"maglev":	{"JJ","NN"},
"magma":	{"NN"},
"magnanimity":	{"NN"},
"magnanimous":	{"JJ"},
"magnanimously":	{"RB"},
"magnanimousness":	{"NN"},
"magnate":	{"NN"},
"magnates":	{"NNS"},
"magnesia":	{"NN"},
"magnesite":	{"NN"},
"magnesium":	{"NN"},
"magnet":	{"NN"},
"magnetic":	{"JJ"},
"magnetic-tape":	{"NN"},
"magnetic-tape-coating":	{"JJ"},
"magnetic-tapes":	{"NNS"},
"magnetically":	{"RB"},
"magnetics":	{"NN"},
"magnetisation":	{"NN"},
"magnetise":	{"VB","VBP"},
"magnetised":	{"VBD","VBN"},
"magnetises":	{"VBZ"},
"magnetising":	{"VBG"},
"magnetism":	{"NN"},
"magnetite":	{"NN"},
"magnetization":	{"NN"},
"magnetize":	{"VB","NN"},
"magnetized":	{"VBD","VBN"},
"magnetizes":	{"VBZ"},
"magnetizing":	{"VBG"},
"magneto":	{"NN"},
"magnetograph":	{"NN"},
"magnetohydrodynamics":	{"NN"},
"magnetometer":	{"NN"},
"magneton":	{"NN"},
"magnetos":	{"NNS"},
"magnetosomes":	{"NNS"},
"magnetosphere":	{"NN"},
"magnetron":	{"NN"},
"magnets":	{"NNS"},
"magnification":	{"NN"},
"magnifications":	{"NNS"},
"magnificence":	{"NN"},
"magnificent":	{"JJ"},
"magnificently":	{"RB"},
"magnifico":	{"NN"},
"magnified":	{"VBD","VBN"},
"magnifier":	{"NN"},
"magnifiers":	{"NNS"},
"magnifies":	{"VBZ"},
"magnify":	{"VB","VBP"},
"magnifying":	{"VBG"},
"magnilo-quently":	{"RB"},
"magniloquence":	{"NN"},
"magniloquent":	{"JJ"},
"magnitude":	{"NN"},
"magnitudes":	{"NNS"},
"magnolia":	{"NN","JJ"},
"magnoliaceae":	{"NN"},
"magnolias":	{"NNS"},
"magnoliidae":	{"NN"},
"magnoliophyta":	{"NN"},
"magnoliopsid":	{"NN"},
"magnoliopsida":	{"NN"},
"magnum":	{"NN"},
"magnums":	{"NNS"},
"magnus":	{"JJ"},
"magpie":	{"NN"},
"magpies":	{"NNS"},
"mags":	{"NNS"},
"maguey":	{"NN"},
"magus":	{"NN"},
"magyarorszag":	{"NN"},
"mah":	{"NN"},
"maha":	{"NN"},
"mahabharata":	{"NN"},
"mahabharatam":	{"NN"},
"mahabharatum":	{"NN"},
"mahagua":	{"NN"},
"mahan":	{"NN"},
"maharaja":	{"NN"},
"maharajah":	{"NN"},
"maharajahs":	{"NNS"},
"maharajas":	{"NNS"},
"maharanee":	{"NN"},
"maharanees":	{"NNS"},
"maharani":	{"NN"},
"maharanis":	{"NNS"},
"maharashtra":	{"NN"},
"mahatma":	{"NN"},
"mahatmas":	{"NNS"},
"mahayanism":	{"NN"},
"mahayanist":	{"NN"},
"mahdism":	{"NN"},
"mahdist":	{"NN"},
"maher":	{"NN"},
"mahgrib":	{"NN"},
"mahican":	{"NN"},
"mahimahi":	{"NN"},
"mahjong":	{"NN"},
"mahjongg":	{"NN"},
"mahlstick":	{"NN"},
"mahoe":	{"NN"},
"mahoganies":	{"NNS"},
"mahogany":	{"NN","JJ"},
"mahogany-red":	{"JJ"},
"mahonia":	{"NN"},
"mahound":	{"NN"},
"mahout":	{"NN"},
"mahouts":	{"NNS"},
"mahratta":	{"NN"},
"mahratti":	{"NN"},
"mahua":	{"NN"},
"mahuang":	{"NN"},
"mai":	{"NN"},
"maia":	{"NN"},
"maianthemum":	{"NN"},
"maid":	{"NN"},
"maiden":	{"NN","JJ"},
"maidenhair":	{"NN"},
"maidenhead":	{"NN"},
"maidenheads":	{"NNS"},
"maidenhood":	{"NN"},
"maidenlike":	{"JJ"},
"maidenliness":	{"NN"},
"maidenly":	{"JJ"},
"maidens":	{"NNS"},
"maidhood":	{"NN"},
"maidism":	{"NN"},
"maids":	{"NNS"},
"maidservant":	{"NN"},
"maidservants":	{"NNS"},
"maidu":	{"NN"},
"maiduguri":	{"NN"},
"maiestie":	{"NN"},
"maiger":	{"NN"},
"maigre":	{"JJ"},
"maikoa":	{"NN"},
"mail":	{"NN","VB","VBP"},
"mail-cheeked":	{"JJ"},
"mail-clad":	{"JJ"},
"mail-fraud":	{"NN"},
"mail-order":	{"NN"},
"mail-processing":	{"JJ"},
"mail-room":	{"NN"},
"mail-sorting":	{"JJ"},
"mailbag":	{"NN"},
"mailbags":	{"NNS"},
"mailboat":	{"NN"},
"mailbox":	{"NN"},
"mailboxes":	{"NNS"},
"maildrop":	{"NN"},
"maildrops":	{"NNS"},
"mailed":	{"VBD","VBN"},
"mailed-fist-in-velvet-glove":	{"JJ"},
"mailer":	{"NN"},
"mailers":	{"NNS"},
"mailgram":	{"NN"},
"mailgrams":	{"NNS"},
"mailing":	{"NN","VBG"},
"mailing-card":	{"NN"},
"mailings":	{"NNS"},
"maillot":	{"NN"},
"maillots":	{"NNS"},
"mailman":	{"NN"},
"mailmen":	{"NNS"},
"mailroom":	{"NN"},
"mailrooms":	{"NNS"},
"mails":	{"NNS","VBZ"},
"mailsorter":	{"NN"},
"maim":	{"VB","VBP"},
"maimed":	{"VBD","VBN"},
"maimer":	{"NN"},
"maiming":	{"VBG"},
"maims":	{"VBZ"},
"main":	{"JJ","NN"},
"main-topmast":	{"NN"},
"main-topsail":	{"NN"},
"mainframe":	{"NN"},
"mainframe-class":	{"JJ","NN"},
"mainframe-manufacturing":	{"NN"},
"mainframes":	{"NNS"},
"mainland":	{"NN","JJ"},
"mainlander":	{"NN"},
"mainline":	{"JJ","VB","VBP"},
"mainlined":	{"VBD","VBN"},
"mainlines":	{"VBZ"},
"mainlining":	{"VBG"},
"mainly":	{"RB"},
"mainmast":	{"NN"},
"mainmasts":	{"NNS"},
"mains":	{"NNS"},
"mainsail":	{"NN"},
"mainsails":	{"NNS"},
"mainsheet":	{"NN"},
"mainsheets":	{"NNS"},
"mainspring":	{"NN"},
"mainsprings":	{"NNS"},
"mainstay":	{"NN"},
"mainstays":	{"NNS"},
"mainstream":	{"NN","JJ","VB","VBP"},
"mainstreamed":	{"JJ","VBD","VBN"},
"mainstreaming":	{"VBG"},
"mainstreams":	{"NNS","VBZ"},
"maintain":	{"VB","VBP"},
"maintainable":	{"JJ"},
"maintained":	{"VBN","VBD"},
"maintainence":	{"NN"},
"maintainer":	{"NN"},
"maintaining":	{"VBG"},
"maintains":	{"VBZ"},
"maintenance":	{"NN"},
"maiolica":	{"NN"},
"mais":	{"FW"},
"maisonette":	{"NN"},
"maisonettes":	{"NNS"},
"maisonnette":	{"NN"},
"maisonnettes":	{"NNS"},
"maitres":	{"FW"},
"maitreya":	{"NN"},
"maize":	{"NN"},
"majagua":	{"NN"},
"majesterial":	{"JJ"},
"majestic":	{"JJ"},
"majestically":	{"RB"},
"majesties":	{"NNS"},
"majesty":	{"NN"},
"majeure":	{"NN"},
"majidae":	{"NN"},
"majolica":	{"NN"},
"major":	{"JJ","NN","VBP","VB"},
"major-burden-to-the-planet":	{"NN"},
"major-domo":	{"NN"},
"major-general":	{"NN"},
"major-league":	{"JJ"},
"major-market":	{"JJ"},
"major-medical":	{"JJ"},
"major-party":	{"JJ"},
"majordomo":	{"NN"},
"majordomos":	{"NNS"},
"majored":	{"VBD","VBN"},
"majorette":	{"NN"},
"majorettes":	{"NNS"},
"majoring":	{"VBG"},
"majoritarian":	{"JJ","NN"},
"majoritarians":	{"NNS"},
"majorities":	{"NNS"},
"majority":	{"NN"},
"majority-held":	{"JJ"},
"majority-owned":	{"JJ"},
"majority-party":	{"JJ"},
"majors":	{"NNS","VBZ"},
"majuscular":	{"JJ"},
"majuscule":	{"JJ","NN"},
"mak":	{"VB","VBP"},
"makaira":	{"NN"},
"makalu":	{"NN"},
"makataimeshekiakiak":	{"NN"},
"make":	{"VB","VBP","NN"},
"make-believe":	{"JJ","NN"},
"make-do":	{"NN"},
"make-peace":	{"NN"},
"make-ready":	{"NN"},
"make-up":	{"NN"},
"make-work":	{"NN"},
"makedonija":	{"NN"},
"makeout":	{"JJ"},
"makeover":	{"NN"},
"makeovers":	{"NNS"},
"maker":	{"NN"},
"makeready":	{"NN"},
"makers":	{"NNS"},
"makes":	{"VBZ","NNS"},
"makeshift":	{"JJ","NN"},
"makeshifts":	{"NNS"},
"maketh":	{"VBZ"},
"makeup":	{"NN"},
"makeweight":	{"NN"},
"makeweights":	{"NNS"},
"making":	{"VBG","NN"},
"mako":	{"NN"},
"makomako":	{"NN"},
"makomakos":	{"NNS"},
"maku":	{"FW"},
"mal":	{"NN"},
"malabo":	{"NN"},
"malabsorption":	{"NN"},
"malacanthidae":	{"NN"},
"malacca":	{"NN"},
"malachias":	{"NN"},
"malachite":	{"NN"},
"malacia":	{"NN"},
"malaclemys":	{"NNS"},
"malacologist":	{"NN"},
"malacology":	{"NN"},
"malaconotinae":	{"NN"},
"malacopterygian":	{"NN"},
"malacopterygii":	{"NN"},
"malacosoma":	{"NN"},
"malacostraca":	{"NN"},
"malacothamnus":	{"NN"},
"maladaptive":	{"JJ"},
"maladies":	{"NNS"},
"maladjusted":	{"JJ"},
"maladjustive":	{"JJ"},
"maladjustment":	{"NN"},
"maladjustments":	{"NNS"},
"maladroit":	{"JJ"},
"maladroitly":	{"RB"},
"maladroitness":	{"NN"},
"malady":	{"NN"},
"malahini":	{"NN"},
"malaise":	{"NN"},
"malamute":	{"NN"},
"malanga":	{"NN"},
"malapropism":	{"NN"},
"malapropisms":	{"NNS"},
"malapropos":	{"JJ","RB","NN"},
"malar":	{"NN","JJ"},
"malaria":	{"NN"},
"malarial":	{"JJ"},
"malarkey":	{"NN"},
"malarky":	{"NN"},
"malathion":	{"NN"},
"malaxis":	{"NN"},
"malaxis-unifolia":	{"NN"},
"malay-based":	{"JJ"},
"malayo-polynesian":	{"JJ","NN"},
"malaysian-based":	{"JJ"},
"malcolmia":	{"NN"},
"malcontent":	{"NN","JJ"},
"malcontents":	{"NNS"},
"maldivan":	{"NN"},
"maldon":	{"NN"},
"male":	{"JJ","NN"},
"male-dominated":	{"JJ"},
"male-fertile":	{"JJ"},
"male-headed":	{"JJ"},
"male-only":	{"JJ"},
"male-sterile":	{"JJ"},
"maleate":	{"NN"},
"maleberry":	{"NN"},
"malebranche":	{"NN"},
"malecite":	{"NN"},
"maledict":	{"JJ","VB","VBP"},
"maledicted":	{"VBD","VBN"},
"maledicting":	{"VBG"},
"malediction":	{"NN"},
"maledicts":	{"VBZ"},
"malefactor":	{"NN"},
"malefactors":	{"NNS"},
"malefic":	{"JJ"},
"maleficence":	{"NN"},
"maleficent":	{"JJ"},
"malemute":	{"NN"},
"maleness":	{"NN"},
"maleo":	{"NN"},
"males":	{"NNS"},
"maleseet":	{"NN"},
"malevich":	{"NN"},
"malevolence":	{"NN"},
"malevolencies":	{"NNS"},
"malevolency":	{"NN"},
"malevolent":	{"JJ"},
"malevolently":	{"RB"},
"malfeasance":	{"NN"},
"malfeasant":	{"NN"},
"malformation":	{"NN"},
"malformations":	{"NNS"},
"malformed":	{"JJ"},
"malfunction":	{"NN","VB","VBP"},
"malfunctioned":	{"VBD","VBN"},
"malfunctioning":	{"VBG"},
"malfunctions":	{"NNS","VBZ"},
"malice":	{"NN"},
"malicious":	{"JJ"},
"maliciously":	{"RB"},
"maliciousness":	{"NN"},
"malign":	{"VB","VBP","JJ"},
"malignance":	{"NN"},
"malignancies":	{"NNS"},
"malignancy":	{"NN"},
"malignant":	{"JJ"},
"malignantly":	{"RB"},
"maligned":	{"VBD","VBN"},
"maligner":	{"NN"},
"maligning":	{"VBG"},
"malignity":	{"NN"},
"malignly":	{"RB"},
"malignment":	{"NN"},
"maligns":	{"VBZ"},
"malik":	{"NN"},
"malinger":	{"VB","VBP"},
"malingered":	{"VBD","VBN"},
"malingerer":	{"NN"},
"malingerers":	{"NNS"},
"malingering":	{"VBG"},
"malingers":	{"VBZ"},
"malinois":	{"NN"},
"mall":	{"NN"},
"mallard":	{"NN","NNS"},
"mallards":	{"NNS"},
"mallarme":	{"NN"},
"malleability":	{"NN"},
"malleable":	{"JJ"},
"mallee":	{"NN"},
"mallet":	{"NN"},
"mallets":	{"NNS"},
"malleus":	{"NN"},
"mallon":	{"NN"},
"mallophaga":	{"NN"},
"mallotus":	{"NN"},
"mallow":	{"NN"},
"mallows":	{"NNS"},
"malls":	{"NNS"},
"malmo":	{"NN"},
"malmsey":	{"NN"},
"malnourished":	{"JJ"},
"malnourishment":	{"NN"},
"malnutrition":	{"NN"},
"malocclusion":	{"NN"},
"malodor":	{"NN"},
"malodorous":	{"JJ"},
"malodorousness":	{"NN"},
"malodour":	{"NN"},
"malodourous":	{"JJ"},
"malone":	{"NN"},
"malonylurea":	{"NN"},
"malope":	{"NN"},
"malopterurus":	{"NN"},
"malosma":	{"NN"},
"malpighi":	{"NN"},
"malpighia":	{"NN"},
"malpighiaceae":	{"NN"},
"malposed":	{"JJ"},
"malposition":	{"NN"},
"malpractice":	{"NN"},
"malpractices":	{"NNS"},
"malraux":	{"NN"},
"mals":	{"NNS"},
"malt":	{"NN","VB","VBP"},
"malted":	{"JJ","VBD","VBN"},
"maltha":	{"NN"},
"malthusianism":	{"NN"},
"malti":	{"NN"},
"malting":	{"VBG"},
"maltman":	{"NN"},
"malto":	{"NN"},
"maltose":	{"NN"},
"maltreat":	{"VB","VBP"},
"maltreated":	{"VBD","VBN"},
"maltreater":	{"NN"},
"maltreating":	{"VBG"},
"maltreatment":	{"NN"},
"maltreats":	{"VBZ"},
"malts":	{"NNS","VBZ"},
"maltster":	{"NN"},
"malunya":	{"NN"},
"malus":	{"NN"},
"malva":	{"NN"},
"malvaceae":	{"NN"},
"malvales":	{"NN"},
"malvasia":	{"NN"},
"malvastrum":	{"NN"},
"malvaviscus":	{"NN"},
"malversate":	{"VB","VBP"},
"malversation":	{"NN"},
"mam":	{"NN"},
"mama":	{"NN"},
"mamalian":	{"JJ"},
"mamas":	{"NNS"},
"mamba":	{"NN"},
"mambas":	{"NNS"},
"mambo":	{"NN","VB","VBP"},
"mamboed":	{"VBD","VBN"},
"mamboing":	{"VBG"},
"mambos":	{"NNS","VBZ"},
"mamet":	{"NN"},
"mamey":	{"NN"},
"mamilla":	{"NN"},
"mamma":	{"NN"},
"mammal":	{"NN"},
"mammalia":	{"NN"},
"mammalian":	{"JJ"},
"mammalogist":	{"NN"},
"mammalogy":	{"NN"},
"mammals":	{"NNS"},
"mammary":	{"JJ"},
"mammas":	{"NNS"},
"mammea":	{"NN"},
"mammee":	{"NN"},
"mammies":	{"NNS"},
"mammilla":	{"NN"},
"mammillaria":	{"NN"},
"mammogram":	{"NN"},
"mammograms":	{"NNS"},
"mammography":	{"NN"},
"mammon":	{"NN"},
"mammoth":	{"NN","JJ"},
"mammothermography":	{"NN"},
"mammoths":	{"NNS"},
"mammut":	{"NN"},
"mammuthus":	{"NN"},
"mammutidae":	{"NN"},
"mammy":	{"NN"},
"mamo":	{"NN"},
"mamoncillo":	{"NN"},
"mams":	{"NNS"},
"man":	{"NN","UH","VBP","VB"},
"man-about-town":	{"NN"},
"man-at-arms":	{"NN"},
"man-bites-dog":	{"JJ"},
"man-child":	{"NN"},
"man-eater":	{"NN"},
"man-eaters":	{"NNS"},
"man-eating":	{"JJ"},
"man-hour":	{"NN"},
"man-hours":	{"NNS"},
"man-in-the-european-street":	{"NN"},
"man-in-the-moon":	{"JJ"},
"man-made":	{"JJ"},
"man-of-the-earth":	{"NN"},
"man-of-war":	{"NN"},
"man-on-a-horse":	{"NN"},
"man-portable":	{"JJ"},
"man-size":	{"JJ"},
"man-sized":	{"JJ"},
"man-to-man":	{"JJ","RB"},
"mana":	{"NN"},
"manacle":	{"VB","VBP","NN"},
"manacled":	{"VBD","VBN","JJ"},
"manacles":	{"NNS","VBZ"},
"manacling":	{"VBG"},
"manage":	{"VB","VBP"},
"manageability":	{"NN"},
"manageable":	{"JJ"},
"manageableness":	{"NN"},
"manageably":	{"RB"},
"managed":	{"VBD","VBN"},
"managed-care":	{"JJ","NN"},
"management":	{"NN"},
"management-by-objective":	{"NN"},
"management-consultant":	{"NN"},
"management-consulting":	{"JJ"},
"management-controlled":	{"JJ"},
"management-employee":	{"NN"},
"management-incentive":	{"JJ"},
"management-information":	{"JJ","NN"},
"management-labor":	{"JJ"},
"management-led":	{"JJ","NN"},
"management-pilot":	{"JJ","NN"},
"management-pilots":	{"JJ"},
"management-research":	{"NN"},
"management-services":	{"NNS","JJ"},
"management-trained":	{"JJ"},
"management-union":	{"JJ","NN"},
"managements":	{"NNS"},
"manager":	{"NN"},
"manageress":	{"NN"},
"manageresses":	{"NNS"},
"managerial":	{"JJ"},
"managerially":	{"RB"},
"managers":	{"NNS"},
"managership":	{"NN"},
"manages":	{"VBZ"},
"managing":	{"VBG","JJ"},
"manakin":	{"NN"},
"manama":	{"NN"},
"manana":	{"JJ","RB"},
"manannan":	{"NN"},
"manat":	{"NN"},
"manatee":	{"NN"},
"manatees":	{"NNS"},
"manawydan":	{"NN"},
"manawyddan":	{"NN"},
"manda":	{"NN"},
"mandaean":	{"JJ","NN"},
"mandaeanism":	{"NN"},
"mandala":	{"NN"},
"mandalas":	{"NNS"},
"mandamus":	{"NN"},
"mandamuses":	{"NNS"},
"mandara":	{"NN"},
"mandarin":	{"NN"},
"mandarins":	{"NNS"},
"mandatary":	{"NN"},
"mandate":	{"NN","VB","VBP"},
"mandated":	{"JJ","VBN","VBD"},
"mandates":	{"NNS","VBZ"},
"mandating":	{"VBG"},
"mandator":	{"NN"},
"mandatorily":	{"RB"},
"mandatory":	{"JJ"},
"mandatory-retirement":	{"JJ"},
"mande":	{"NN"},
"mandean":	{"JJ","NN"},
"mandeanism":	{"NN"},
"mandelamine":	{"NN"},
"mandelbrot":	{"NN"},
"mandelshtam":	{"NN"},
"mandelstam":	{"NN"},
"mandevilla":	{"NN"},
"mandible":	{"NN"},
"mandibles":	{"NNS"},
"mandibula":	{"FW"},
"mandibular":	{"JJ"},
"mandibulate":	{"JJ"},
"mandibulofacial":	{"JJ"},
"mandioc":	{"NN"},
"mandioca":	{"NN"},
"mandola":	{"NN"},
"mandolin":	{"NN"},
"mandolins":	{"NNS"},
"mandragora":	{"NN"},
"mandrake":	{"NN"},
"mandrakes":	{"NNS"},
"mandrel":	{"NN"},
"mandril":	{"NN"},
"mandrill":	{"NN"},
"mandrills":	{"NNS"},
"mandrillus":	{"NN"},
"manduca":	{"NN"},
"manducate":	{"VB","VBP"},
"manducated":	{"VBD","VBN"},
"manducates":	{"VBZ"},
"manducating":	{"VBG"},
"manduction":	{"NN"},
"mandy":	{"NN"},
"mane":	{"NN"},
"manes":	{"NNS"},
"maneuver":	{"NN","VB","VBP"},
"maneuverability":	{"NN"},
"maneuverable":	{"JJ"},
"maneuvered":	{"VBD","VBN"},
"maneuverer":	{"NN"},
"maneuvering":	{"NN","VBG"},
"maneuverings":	{"NNS"},
"maneuvers":	{"VBZ","NNS"},
"manfred":	{"NN"},
"manful":	{"JJ"},
"manfully":	{"RB"},
"manfulness":	{"NN"},
"mangabey":	{"NN"},
"manganate":	{"NN"},
"manganese":	{"NN"},
"manganite":	{"NN"},
"mange":	{"NN"},
"mangel-wurzel":	{"NN"},
"manger":	{"NN"},
"mangers":	{"NNS"},
"mangey":	{"JJ"},
"mangier":	{"JJR"},
"mangiest":	{"JJS"},
"mangifera":	{"NN"},
"mangily":	{"RB"},
"manginess":	{"NN"},
"mangle":	{"VB","VBP","NN"},
"mangled":	{"VBD","VBN","JJ"},
"mangler":	{"NN"},
"mangles":	{"VBZ"},
"manglietia":	{"NN"},
"mangling":	{"VBG"},
"mango":	{"NN"},
"mangoes":	{"NNS"},
"mangold":	{"NN"},
"mangold-wurzel":	{"NN"},
"mangonel":	{"NN"},
"mangos":	{"NNS"},
"mangosteen":	{"NN"},
"mangrove":	{"NN"},
"mangroves":	{"NNS"},
"mangy":	{"JJ"},
"manhandle":	{"VB","VBP"},
"manhandled":	{"VBD","VBN"},
"manhandles":	{"VBZ"},
"manhandling":	{"VBG"},
"manhattan-based":	{"JJ"},
"manhole":	{"NN"},
"manholes":	{"NNS"},
"manhood":	{"NN"},
"manhunt":	{"NN"},
"manhunts":	{"NNS"},
"mania":	{"NN"},
"maniac":	{"NN"},
"maniacal":	{"JJ"},
"maniacally":	{"RB"},
"maniacs":	{"NNS"},
"manias":	{"NNS"},
"manic":	{"JJ"},
"manic-depressive":	{"NN","JJ"},
"manic-depressives":	{"NNS"},
"manichaeism":	{"NN"},
"manichean":	{"JJ","NN"},
"manichee":	{"JJ","NN"},
"maniclike":	{"JJ"},
"manicotti":	{"NN"},
"manicure":	{"VB","VBP","NN"},
"manicured":	{"JJ","VBD","VBN"},
"manicures":	{"VBZ","NNS"},
"manicuring":	{"VBG"},
"manicurist":	{"NN"},
"manicurists":	{"NNS"},
"manidae":	{"NN"},
"manifest":	{"VB","JJ","NN","VBP"},
"manifestation":	{"NN"},
"manifestations":	{"NNS"},
"manifested":	{"VBD","VBN"},
"manifesting":	{"VBG"},
"manifestly":	{"RB"},
"manifesto":	{"NN"},
"manifestoes":	{"NNS"},
"manifestos":	{"NNS"},
"manifests":	{"VBZ","NNS"},
"manifold":	{"NN","JJ","VB","VBP"},
"manifolded":	{"VBD","VBN"},
"manifolding":	{"VBG"},
"manifolds":	{"NNS","VBZ"},
"manihot":	{"NN"},
"manikin":	{"NN"},
"manikins":	{"NNS"},
"manila-based":	{"JJ"},
"manilkara":	{"NN"},
"manilla":	{"NN"},
"manioc":	{"NN"},
"manioca":	{"NN"},
"manipulability":	{"NN"},
"manipulable":	{"JJ"},
"manipulate":	{"VB","VBP"},
"manipulated":	{"VBD","VBN"},
"manipulates":	{"VBZ"},
"manipulating":	{"VBG"},
"manipulation":	{"NN"},
"manipulations":	{"NNS"},
"manipulative":	{"JJ"},
"manipulatively":	{"RB"},
"manipulator":	{"NN"},
"manipulators":	{"NNS"},
"manipur":	{"NN"},
"maniraptor":	{"NN"},
"maniraptora":	{"NN"},
"manis":	{"NN"},
"manitoba-based":	{"JJ"},
"mankato":	{"NN"},
"mankind":	{"NN"},
"manky":	{"JJ"},
"manlier":	{"JJR"},
"manliest":	{"JJS"},
"manlike":	{"JJ"},
"manliness":	{"NN"},
"manly":	{"JJ","RB"},
"manna":	{"NN"},
"manned":	{"JJ","VBD","VBN"},
"mannequin":	{"NN"},
"mannequins":	{"NNS"},
"manner":	{"NN"},
"mannered":	{"JJ"},
"mannerism":	{"NN"},
"mannerisms":	{"NNS"},
"mannerly":	{"RB","JJ"},
"manners":	{"NNS"},
"mannheim":	{"NN"},
"mannikin":	{"NN"},
"mannikins":	{"NNS"},
"manning":	{"VBG"},
"mannish":	{"JJ"},
"mannishly":	{"RB"},
"mannishness":	{"NN"},
"mannitol":	{"NN"},
"manny":	{"NN"},
"mano":	{"NN"},
"manoeuvrability":	{"NN"},
"manoeuvrable":	{"JJ"},
"manoeuvre":	{"NN","VB","VBP"},
"manoeuvred":	{"VBD","VBN"},
"manoeuvrer":	{"NN"},
"manoeuvres":	{"NNS","VBZ"},
"manoeuvring":	{"NN","VBG"},
"manoeuvrings":	{"NNS"},
"manometer":	{"NN"},
"manor":	{"NN"},
"manorial":	{"JJ"},
"manors":	{"NNS"},
"manpad":	{"NN"},
"manpower":	{"NN"},
"manque":	{"JJ"},
"manroot":	{"NN"},
"mans":	{"VBZ"},
"mansard":	{"JJ","NN"},
"mansart":	{"NN"},
"manse":	{"NN"},
"manservant":	{"NN"},
"manservants":	{"NNS"},
"manses":	{"NNS"},
"mansi":	{"NN"},
"mansion":	{"NN"},
"mansions":	{"NNS"},
"manslaughter":	{"NN"},
"manslayer":	{"NN"},
"mansplain":	{"VB","VBP"},
"mansplained":	{"VBD","VBN"},
"mansplainer":	{"NN"},
"mansplainers":	{"NNS"},
"mansplaining":	{"VBG"},
"mansplains":	{"VBZ"},
"manta":	{"NN"},
"mantegna":	{"NN"},
"manteidae":	{"NN"},
"mantel":	{"NN"},
"mantelet":	{"NN"},
"mantell":	{"NN"},
"mantelpiece":	{"NN"},
"mantelpieces":	{"NNS"},
"mantels":	{"NNS"},
"manteodea":	{"NN"},
"mantic":	{"JJ"},
"mantichora":	{"NN"},
"manticora":	{"NN"},
"manticore":	{"NN"},
"mantid":	{"NN"},
"mantidae":	{"NN"},
"mantids":	{"NNS"},
"mantiger":	{"NN"},
"mantilla":	{"NN"},
"mantinea":	{"NN"},
"mantineia":	{"NN"},
"mantis":	{"NN"},
"mantises":	{"NNS"},
"mantispid":	{"NN"},
"mantispidae":	{"NN"},
"mantissa":	{"NN"},
"mantle":	{"NN","VB","VBP"},
"mantled":	{"VBD","VBN"},
"mantles":	{"VBZ","NNS"},
"mantlet":	{"NN"},
"mantling":	{"VBG"},
"mantophasmatodea":	{"NN"},
"mantra":	{"NN"},
"mantrap":	{"NN"},
"mantras":	{"NNS"},
"mantua":	{"NN"},
"manual":	{"NN","JJ"},
"manually":	{"RB"},
"manuals":	{"NNS"},
"manubria":	{"NNS"},
"manubrial":	{"JJ"},
"manubrium":	{"NN"},
"manubriums":	{"NNS"},
"manufactories":	{"NNS"},
"manufactory":	{"NN"},
"manufacture":	{"VB","NN","VBP"},
"manufactured":	{"VBD","VBN"},
"manufacturer":	{"NN"},
"manufacturers":	{"NNS"},
"manufactures":	{"VBZ","NNS"},
"manufacturing":	{"NN","VBG"},
"manufacturing-automation":	{"NN"},
"manufacturing-cost":	{"NN"},
"manufacturing-sector":	{"NN"},
"manul":	{"NN"},
"manumission":	{"NN"},
"manumit":	{"VB","VBP"},
"manumits":	{"VBZ"},
"manumitted":	{"VBD","VBN"},
"manumitter":	{"NN"},
"manumitting":	{"VBG"},
"manure":	{"NN","VB","VBP"},
"manure-scented":	{"JJ"},
"manured":	{"VBD","VBN"},
"manures":	{"VBZ"},
"manuring":	{"VBG"},
"manus":	{"NN"},
"manuscript":	{"NN"},
"manuscripts":	{"NNS"},
"many":	{"JJ","DT","PDT","NN"},
"many-bodied":	{"JJ"},
"many-chambered":	{"JJ"},
"many-faced":	{"JJ"},
"many-fold":	{"RB"},
"many-lobed":	{"JJ"},
"many-much":	{"NN"},
"many-sided":	{"JJ"},
"many-times":	{"RB"},
"manye":	{"JJ"},
"manzanilla":	{"NN"},
"manzanita":	{"NN"},
"manzoni":	{"NN"},
"mao":	{"NN"},
"maoi":	{"NN"},
"maoist-style":	{"JJ"},
"map":	{"NN","VBP","VB"},
"map-reader":	{"NN"},
"map-readers":	{"NNS"},
"map-reading":	{"NN"},
"mapinguari":	{"NN"},
"maple":	{"NN"},
"maple-leaf":	{"NN"},
"maple-like":	{"JJ"},
"maplelike":	{"JJ"},
"maples":	{"NNS"},
"mapmaking":	{"NN"},
"mapped":	{"VBN","VBD"},
"mapper":	{"NN"},
"mapping":	{"NN","VBG"},
"maps":	{"NNS","VBZ"},
"maquette":	{"NN"},
"maquila":	{"NN"},
"maquiladora":	{"NN"},
"maquiladoras":	{"NNS"},
"maquilas":	{"NNS"},
"maquillage":	{"NN"},
"maquis":	{"NN"},
"maquisard":	{"NN"},
"mar":	{"VB","VBP","NN"},
"mara":	{"NN"},
"marabou":	{"NN"},
"marabous":	{"NNS"},
"marabout":	{"NN"},
"marabouts":	{"NNS"},
"maraca":	{"NN"},
"maracaibo":	{"NN"},
"maracay":	{"NN"},
"maraco":	{"NN"},
"marang":	{"NN"},
"maranta":	{"NN"},
"marantaceae":	{"NN"},
"marasca":	{"NN"},
"maraschino":	{"NN"},
"maraschinos":	{"NNS"},
"marasmius":	{"NN"},
"marasmus":	{"NN"},
"marat":	{"NN"},
"maratha":	{"NN"},
"marathi":	{"NN"},
"marathon":	{"NN","JJ"},
"marathoner":	{"NN"},
"marathoners":	{"NNS"},
"marathons":	{"NNS"},
"marattia":	{"NN"},
"marattiaceae":	{"NN"},
"marattiales":	{"NN"},
"maraud":	{"VB","VBP"},
"marauded":	{"VBD","VBN"},
"marauder":	{"NN"},
"marauders":	{"NNS"},
"marauding":	{"JJ","VBG"},
"marauds":	{"VBZ"},
"maravilla":	{"NN"},
"marble":	{"NN","JJ","VB","VBP"},
"marble-columned":	{"JJ"},
"marble-encased":	{"JJ"},
"marble-wood":	{"NN"},
"marbled":	{"JJ","VBD","VBN"},
"marbleisation":	{"NN"},
"marbleise":	{"VB","VBP"},
"marbleised":	{"VBD","VBN"},
"marbleises":	{"VBZ"},
"marbleising":	{"VBG"},
"marbleization":	{"NN"},
"marbleize":	{"VB","VBP"},
"marbleized":	{"VBD","VBN"},
"marbleizes":	{"VBZ"},
"marbleizing":	{"VBG"},
"marbles":	{"VBZ","NNS"},
"marblewood":	{"NN"},
"marbling":	{"NN","VBG"},
"marc":	{"NN"},
"marcato":	{"FW"},
"marceau":	{"NN"},
"marcel":	{"NN","VB","VBP"},
"marcelled":	{"VBD","VBN"},
"marceller":	{"NN"},
"marcelling":	{"VBG"},
"marcels":	{"VBZ"},
"march":	{"NN","VB","VBP"},
"marchantia":	{"NN"},
"marchantiaceae":	{"NN"},
"marchantiales":	{"NNS"},
"marched":	{"VBD","VBN"},
"marcher":	{"NN"},
"marchers":	{"NNS"},
"marches":	{"NNS","VBZ"},
"marching":	{"VBG"},
"marchioness":	{"NN"},
"marchionesses":	{"NNS"},
"marchland":	{"NN"},
"marchpane":	{"NN"},
"marcionism":	{"NN"},
"marco":	{"NN"},
"marduk":	{"NN"},
"mare":	{"NN"},
"marengo":	{"NN"},
"mares":	{"NNS"},
"margaretville":	{"NN"},
"margarin":	{"NN"},
"margarine":	{"NN"},
"margarita":	{"NN"},
"margaritas":	{"NNS"},
"margasivsa":	{"NN"},
"margay":	{"NN"},
"marge":	{"NN"},
"margie":	{"NN"},
"margin":	{"NN","VB","VBP"},
"margin-calls":	{"NNS"},
"margin-the":	{"NN","DT"},
"marginal":	{"JJ"},
"marginal-rate":	{"NN"},
"marginalia":	{"NNS"},
"marginalisation":	{"NN"},
"marginalise":	{"VB","VBP"},
"marginalised":	{"VBD","VBN","JJ"},
"marginalises":	{"VBZ"},
"marginalising":	{"VBG"},
"marginality":	{"NN"},
"marginalization":	{"NN"},
"marginalize":	{"VB","VBP"},
"marginalized":	{"VBD","VBN","JJ"},
"marginalizes":	{"VBZ"},
"marginalizing":	{"VBG"},
"marginally":	{"RB"},
"margined":	{"VBD","VBN"},
"margining":	{"VBG"},
"marginocephalia":	{"NN"},
"marginocephalian":	{"NN"},
"margins":	{"NNS","VBZ"},
"margo":	{"NN"},
"margosa":	{"NN"},
"margrave":	{"NN"},
"margret":	{"NN"},
"marguerite":	{"NN"},
"mari":	{"NN"},
"maria":	{"NNS"},
"mariachi":	{"NN"},
"marianas":	{"NN"},
"maricopa":	{"NN"},
"mariehamn":	{"NN"},
"marigold":	{"NN"},
"marigolds":	{"NNS"},
"marihuana":	{"NN"},
"marijuana":	{"NN"},
"marijuana-smuggling":	{"JJ"},
"marimba":	{"NN"},
"marimbas":	{"NNS"},
"marina":	{"NN"},
"marinade":	{"NN","VB","VBP"},
"marinaded":	{"VBD","VBN"},
"marinades":	{"NNS","VBZ"},
"marinading":	{"VBG"},
"marinara":	{"NN","JJ"},
"marinas":	{"NNS"},
"marinate":	{"VB","VBP"},
"marinated":	{"VBD","VBN"},
"marinates":	{"VBZ"},
"marinating":	{"VBG"},
"marine":	{"JJ","NN"},
"marine-products":	{"NNS"},
"marine-related":	{"JJ"},
"marine-research":	{"NN"},
"marine-shipping":	{"JJ"},
"marine-transport":	{"NN"},
"marineland":	{"NN"},
"mariner":	{"NN"},
"mariners":	{"NNS"},
"marines":	{"NNS"},
"marini":	{"NN"},
"marino":	{"NN"},
"marionette":	{"NN"},
"marionettes":	{"NNS"},
"mariposa":	{"NN"},
"mariposan":	{"NN"},
"marital":	{"JJ"},
"mariticide":	{"NN"},
"maritime":	{"JJ"},
"marjoram":	{"NN"},
"mark":	{"NN","VBP","VB"},
"mark-denominated":	{"JJ"},
"mark-down":	{"NN"},
"mark-up":	{"NN"},
"mark-ups":	{"NNS"},
"mark-yen":	{"JJ"},
"markaz-ud-dawa-wal-irshad":	{"NN"},
"markdown":	{"NN"},
"markdowns":	{"NNS"},
"marked":	{"VBN","VBD","JJ"},
"marked-up":	{"JJ"},
"markedly":	{"RB"},
"marker":	{"NN"},
"markers":	{"NNS"},
"market":	{"NN","VB","VBP"},
"market-affecting":	{"JJ"},
"market-allocation":	{"JJ"},
"market-based":	{"JJ"},
"market-basket":	{"JJ"},
"market-by-market":	{"JJ"},
"market-corporate":	{"JJ"},
"market-day":	{"NN"},
"market-days":	{"NNS"},
"market-driven":	{"JJ"},
"market-hog":	{"JJ"},
"market-if-touched":	{"NN"},
"market-inspired":	{"JJ"},
"market-jarring":	{"JJ"},
"market-leader":	{"NN"},
"market-maker":	{"NN"},
"market-makers":	{"NNS"},
"market-making":	{"NN","JJ"},
"market-monitoring":	{"JJ"},
"market-moving":	{"JJ"},
"market-on-close":	{"JJ"},
"market-opening":	{"JJ"},
"market-oriented":	{"JJ"},
"market-place":	{"NN"},
"market-places":	{"NNS"},
"market-ready":	{"JJ"},
"market-reform":	{"JJ"},
"market-related":	{"JJ"},
"market-research":	{"NN","JJ"},
"market-revision":	{"NN"},
"market-sensitive":	{"JJ"},
"market-share":	{"JJ","NN"},
"market-sharing":	{"JJ"},
"market-specific":	{"JJ"},
"market-square":	{"NN"},
"market-squares":	{"NNS"},
"market-stabilizing":	{"JJ"},
"market-style":	{"JJ"},
"market-system":	{"NN"},
"market-timing":	{"JJ"},
"market-watchers":	{"NNS"},
"market-weighted":	{"JJ"},
"marketability":	{"NN"},
"marketable":	{"JJ"},
"marketed":	{"VBN","VBD"},
"marketeer":	{"NN"},
"marketeering":	{"NN"},
"marketeers":	{"NNS"},
"marketer":	{"NN"},
"marketers":	{"NNS"},
"marketing":	{"NN","VBG"},
"marketing-and-distribution":	{"JJ"},
"marketing-communications":	{"NNS"},
"marketing-data":	{"NNS"},
"marketing-wise":	{"JJ"},
"marketization":	{"NN"},
"marketmaking":	{"NN"},
"marketplace":	{"NN"},
"marketplaces":	{"NNS"},
"markets":	{"NNS","VBZ"},
"marketshare":	{"NN"},
"marketwide":	{"JJ"},
"marketwise":	{"RB"},
"markhoor":	{"NN","NNS"},
"markhoors":	{"NNS"},
"markhor":	{"NN","NNS"},
"markhors":	{"NNS"},
"marking":	{"VBG","NN"},
"marking-ink":	{"NN"},
"marking-inks":	{"NNS"},
"markings":	{"NNS"},
"markka":	{"NN"},
"markkaa":	{"NNS"},
"markoff":	{"NN"},
"markov":	{"NN"},
"markova":	{"NN"},
"markovian":	{"JJ"},
"marks":	{"NNS","VBZ"},
"marksman":	{"NN"},
"marksmanship":	{"NN"},
"marksmen":	{"NNS"},
"markup":	{"NN"},
"markups":	{"NNS"},
"markweed":	{"NN"},
"marl":	{"NN"},
"marlberry":	{"NN"},
"marlin":	{"NN","NNS"},
"marline":	{"NN"},
"marlinespike":	{"NN"},
"marlingspike":	{"NN"},
"marlinspike":	{"NN"},
"marlite":	{"NN"},
"marlon":	{"NN"},
"marlstone":	{"NN"},
"marly":	{"JJ"},
"marmalade":	{"NN"},
"marmalades":	{"NNS"},
"marmora":	{"NN"},
"marmoreal":	{"JJ"},
"marmorean":	{"JJ"},
"marmoset":	{"NN"},
"marmosets":	{"NNS"},
"marmot":	{"NN"},
"marmota":	{"NN"},
"marmots":	{"NNS"},
"marne":	{"NN"},
"maroc":	{"JJ","NN"},
"marocain":	{"NN"},
"maroon":	{"JJ","NN","VB","VBP"},
"maroon-purple":	{"JJ"},
"maroon-spotted":	{"JJ"},
"marooned":	{"VBD","VBN","JJ"},
"marooning":	{"VBG"},
"maroons":	{"VBZ","NNS"},
"marplan":	{"NN"},
"marquand":	{"NN"},
"marque":	{"NN"},
"marquee":	{"NN"},
"marquees":	{"NNS"},
"marques":	{"NNS"},
"marquess":	{"NN"},
"marqueterie":	{"NN"},
"marquetry":	{"NN"},
"marquis":	{"NN"},
"marquise":	{"NN"},
"marquises":	{"NNS"},
"marrano":	{"NN"},
"marred":	{"VBD","VBN"},
"marri":	{"NN"},
"marriage":	{"NN"},
"marriageability":	{"NN"},
"marriageable":	{"JJ"},
"marriages":	{"NNS"},
"married":	{"VBN","VBD","JJ"},
"married-couple":	{"JJ","NN"},
"married-put":	{"JJ"},
"marries":	{"VBZ"},
"marring":	{"VBG"},
"marrow":	{"NN"},
"marrowbone":	{"NN"},
"marrowbones":	{"NNS"},
"marrows":	{"NNS"},
"marrubium":	{"NN"},
"marry":	{"VB","VBP"},
"marrying":	{"VBG"},
"mars":	{"NNS","VBZ"},
"marsh":	{"NN"},
"marshal":	{"NN","VB","VBP"},
"marshaled":	{"VBD","VBN"},
"marshaling":	{"VBG"},
"marshalled":	{"VBD","VBN"},
"marshalling":	{"VBG"},
"marshals":	{"NNS","VBZ"},
"marshalship":	{"NN"},
"marshes":	{"NNS"},
"marshland":	{"NN"},
"marshmallow":	{"NN"},
"marshmallows":	{"NNS"},
"marshy":	{"JJ"},
"marsilea":	{"NN"},
"marsileaceae":	{"NN"},
"marstan":	{"NN"},
"marsupial":	{"NN","JJ"},
"marsupialia":	{"NN"},
"marsupials":	{"NNS"},
"marsupium":	{"NN"},
"mart":	{"NN"},
"martagon":	{"NN"},
"marten":	{"NN"},
"martensite":	{"NN"},
"martes":	{"NNS"},
"marti":	{"NN"},
"martial":	{"JJ"},
"martially":	{"RB"},
"martin":	{"NN"},
"martin-type":	{"JJ"},
"martinet":	{"NN"},
"martinets":	{"NNS"},
"martingale":	{"NN"},
"martini":	{"NN"},
"martinis":	{"NNS"},
"martinmas":	{"NN"},
"martins":	{"NNS"},
"marts":	{"NNS"},
"martynia":	{"NN"},
"martyniaceae":	{"NN"},
"martyr":	{"NN","VB","VBP"},
"martyrdom":	{"NN"},
"martyred":	{"VBD","VBN","JJ"},
"martyring":	{"VBG"},
"martyrisation":	{"NN"},
"martyrise":	{"VB","VBP"},
"martyrised":	{"VBD","VBN"},
"martyrises":	{"VBZ"},
"martyrising":	{"VBG"},
"martyrization":	{"NN"},
"martyrize":	{"VB","VBP"},
"martyrized":	{"VBD","VBN"},
"martyrizes":	{"VBZ"},
"martyrizing":	{"VBG"},
"martyrs":	{"NNS","VBZ"},
"marum":	{"NN"},
"marumi":	{"NN"},
"marupa":	{"NN"},
"marut":	{"NN"},
"marvel":	{"VB","VBP","NN"},
"marvel-of-peru":	{"NN"},
"marveled":	{"VBD","VBN"},
"marveling":	{"VBG"},
"marvell":	{"NN"},
"marvelled":	{"VBD","VBN"},
"marveller":	{"NN"},
"marvelling":	{"VBG"},
"marvellous":	{"JJ"},
"marvellously":	{"RB"},
"marvelous":	{"JJ"},
"marvelously":	{"RB"},
"marvels":	{"VBZ","NNS"},
"marxist-dominated":	{"JJ"},
"marzipan":	{"NN"},
"mas":	{"NNS"},
"masa":	{"NN"},
"masai":	{"NN"},
"mascara":	{"NN"},
"mascaras":	{"NNS"},
"mascarpone":	{"NN"},
"mascot":	{"NN"},
"mascots":	{"NNS"},
"masculine":	{"JJ","NN"},
"masculinisation":	{"NN"},
"masculinise":	{"VB","VBP"},
"masculinised":	{"VBD","VBN"},
"masculinises":	{"VBZ"},
"masculinising":	{"VBG"},
"masculinity":	{"NN"},
"masculinization":	{"NN"},
"masculinize":	{"VB","VBP"},
"masculinized":	{"VBD","VBN"},
"masculinizes":	{"VBZ"},
"masculinizing":	{"VBG"},
"masdevallia":	{"NN"},
"maser":	{"NN"},
"masers":	{"NNS"},
"maseru":	{"NN"},
"mash":	{"NN","VB","VBP"},
"mash-up":	{"NN"},
"mashed":	{"VBN","JJ","VBD"},
"masher":	{"NN"},
"mashers":	{"NNS"},
"mashes":	{"VBZ"},
"mashhad":	{"NN"},
"mashi":	{"NN"},
"mashie":	{"NN"},
"mashing":	{"VBG"},
"mashriq":	{"NN"},
"mashup":	{"NN"},
"mashups":	{"NNS"},
"masjid":	{"NN"},
"mask":	{"NN","VB","VBP"},
"masked":	{"JJ","VBN","VBD"},
"masker":	{"NN"},
"maskers":	{"NNS"},
"masking":	{"NN","VBG"},
"masks":	{"NNS","VBZ"},
"masochism":	{"NN"},
"masochist":	{"NN"},
"masochistic":	{"JJ"},
"masochistically":	{"RB"},
"masochists":	{"NNS"},
"mason":	{"NN","VB","VBP"},
"masoned":	{"VBD","VBN"},
"masonic":	{"JJ"},
"masoning":	{"VBG"},
"masonite":	{"NN"},
"masonry":	{"NN"},
"masons":	{"NNS","VBZ"},
"masorete":	{"NN"},
"masoretic":	{"JJ"},
"masorite":	{"NN"},
"masoud":	{"NN"},
"masqat":	{"NN"},
"masque":	{"NN"},
"masquer":	{"NN"},
"masquerade":	{"NN","VB","VBP"},
"masqueraded":	{"VBD","VBN"},
"masquerader":	{"NN"},
"masquerades":	{"NNS","VBZ"},
"masquerading":	{"VBG"},
"masquers":	{"NNS"},
"masques":	{"NNS"},
"mass":	{"NN","JJ","VB","VBP"},
"mass-audience":	{"JJ"},
"mass-building":	{"JJ"},
"mass-circulation":	{"JJ"},
"mass-distribution":	{"JJ","NN"},
"mass-faxing":	{"JJ"},
"mass-market":	{"JJ","NN"},
"mass-marketers":	{"NNS"},
"mass-media":	{"NN","NNS"},
"mass-merchandise":	{"NN"},
"mass-murderer":	{"NN"},
"mass-produce":	{"VB","VBP"},
"mass-produced":	{"JJ","VBD","VBN"},
"mass-produces":	{"VBZ"},
"mass-producing":	{"VBG"},
"mass-production":	{"NN"},
"mass-reproduced":	{"JJ"},
"mass-spectrometric":	{"JJ"},
"mass-transit":	{"NN"},
"massacre":	{"NN","VB","VBP"},
"massacred":	{"VBD","VBN"},
"massacres":	{"NNS","VBZ"},
"massacring":	{"VBG"},
"massage":	{"NN","VB","VBP"},
"massaged":	{"VBD","VBN"},
"massager":	{"NN"},
"massages":	{"NNS","VBZ"},
"massaging":	{"NN","VBG"},
"massasauga":	{"NN"},
"massasoit":	{"NN"},
"massawa":	{"NN"},
"masse":	{"FW"},
"massed":	{"JJ","VBD","VBN"},
"massenet":	{"NN"},
"masses":	{"NNS","VBZ"},
"masseter":	{"NN"},
"masseur":	{"NN"},
"masseurs":	{"NNS"},
"masseuse":	{"NN"},
"masseuses":	{"NNS"},
"massicot":	{"NN"},
"massicotite":	{"NN"},
"massif":	{"NN"},
"massifs":	{"NNS"},
"massine":	{"NN"},
"massing":	{"VBG"},
"massive":	{"JJ"},
"massively":	{"RB"},
"massiveness":	{"NN"},
"massorete":	{"NN"},
"massuh":	{"NN"},
"mast":	{"NN"},
"mastaba":	{"NN"},
"mastabah":	{"NN"},
"mastalgia":	{"NN"},
"mastectomies":	{"NNS"},
"mastectomy":	{"NN"},
"masted":	{"JJ"},
"master":	{"NN","VB","JJ","VBP"},
"master-at-arms":	{"NN"},
"master-race":	{"NN"},
"mastered":	{"VBD","VBN"},
"masterful":	{"JJ"},
"masterfully":	{"RB"},
"mastering":	{"VBG"},
"masterless":	{"JJ"},
"masterly":	{"JJ","RB"},
"mastermind":	{"NN","VB","VBP"},
"masterminded":	{"VBD","VBN"},
"masterminding":	{"VBG"},
"masterminds":	{"NNS","VBZ"},
"masterpiece":	{"NN"},
"masterpieces":	{"NNS"},
"masters":	{"NNS","VBZ"},
"masters-at-arms":	{"NNS"},
"mastership":	{"NN"},
"masterstroke":	{"NN"},
"masterstrokes":	{"NNS"},
"masterwork":	{"NN"},
"masterworks":	{"NNS"},
"masterwort":	{"NN"},
"mastery":	{"NN"},
"masthead":	{"NN"},
"mastheads":	{"NNS"},
"mastic":	{"NN"},
"masticate":	{"VB","VBP"},
"masticated":	{"VBD","VBN"},
"masticates":	{"VBZ"},
"masticating":	{"VBG"},
"mastication":	{"NN"},
"masticophis":	{"NN"},
"mastiff":	{"NN"},
"mastiffs":	{"NNS"},
"mastigomycota":	{"NN"},
"mastigomycotina":	{"NN"},
"mastigophora":	{"NN"},
"mastigophoran":	{"NN"},
"mastigophore":	{"NN"},
"mastigoproctus":	{"NN"},
"mastitis":	{"NN"},
"mastocyte":	{"NN"},
"mastodon":	{"NN"},
"mastodons":	{"NNS"},
"mastodont":	{"NN"},
"mastoid":	{"JJ","NN"},
"mastoidal":	{"JJ","NN"},
"mastoidale":	{"NN"},
"mastoidectomy":	{"NN"},
"mastoideus":	{"NNS"},
"mastoiditis":	{"NN"},
"mastopathy":	{"NN"},
"mastopexy":	{"NN"},
"mastotermes":	{"NNS"},
"mastotermitidae":	{"NN"},
"masts":	{"NNS"},
"masturbate":	{"VB","VBP"},
"masturbated":	{"VBD","VBN"},
"masturbates":	{"VBZ"},
"masturbating":	{"VBG"},
"masturbation":	{"NN"},
"masturbator":	{"NN"},
"mat":	{"NN","VB","VBP","JJ"},
"matabele":	{"NN"},
"matador":	{"NN"},
"matai":	{"NN"},
"matakam":	{"NN"},
"matamoros":	{"NNS"},
"match":	{"NN","VB","VBP"},
"match-up":	{"NN"},
"match-width":	{"NN"},
"matcha":	{"NN"},
"matchboard":	{"NN"},
"matchbook":	{"NN"},
"matchbook-sized":	{"JJ"},
"matchbox":	{"NN"},
"matchbush":	{"NN"},
"matchday":	{"NN"},
"matchdays":	{"NNS"},
"matched":	{"VBN","VBD"},
"matcher":	{"NN"},
"matches":	{"NNS","VBZ"},
"matchet":	{"NN"},
"matching":	{"VBG","NN","JJ"},
"matching-fund":	{"JJ"},
"matchless":	{"JJ"},
"matchlock":	{"NN"},
"matchmaker":	{"NN"},
"matchmakers":	{"NNS"},
"matchmaking":	{"NN"},
"matchstick":	{"NN"},
"matchup":	{"NN","VB","VBP","JJ"},
"matchups":	{"NNS","VBZ"},
"matchweed":	{"NN"},
"matchwood":	{"NN"},
"mate":	{"NN","VB","VBP"},
"mated":	{"JJ","VBD","VBN"},
"mateless":	{"JJ"},
"matelote":	{"NN"},
"mater":	{"NN"},
"materals":	{"NNS"},
"materfamilias":	{"NN"},
"material":	{"NN","JJ"},
"material-formal":	{"JJ"},
"material-management":	{"NN"},
"materialisation":	{"NN"},
"materialise":	{"VB","VBP"},
"materialised":	{"VBD","VBN"},
"materialises":	{"VBZ"},
"materialising":	{"VBG"},
"materialism":	{"NN"},
"materialist":	{"NN","JJ"},
"materialistic":	{"JJ"},
"materialistically":	{"RB"},
"materialists":	{"NNS"},
"materiality":	{"NN"},
"materialization":	{"NN"},
"materialize":	{"VB","VBP"},
"materialized":	{"VBD","VBN"},
"materializes":	{"VBZ"},
"materializing":	{"VBG"},
"materially":	{"RB"},
"materials":	{"NNS"},
"materials-handling":	{"JJ"},
"materials-related":	{"JJ"},
"materiel":	{"NN"},
"maternal":	{"JJ"},
"maternalism":	{"NN"},
"maternalistic":	{"JJ"},
"maternally":	{"RB"},
"maternity":	{"NN","JJ"},
"mates":	{"VBZ","NNS"},
"matey":	{"JJ","NN"},
"math":	{"NN"},
"mathematical":	{"JJ"},
"mathematically":	{"RB"},
"mathematician":	{"NN"},
"mathematicians":	{"NNS"},
"mathematics":	{"NN","NNS"},
"matheson":	{"NN"},
"mathias":	{"NN"},
"maths":	{"NN"},
"matinals":	{"FW"},
"matinee":	{"NN"},
"matinees":	{"NNS"},
"mating":	{"NN","VBG"},
"matins":	{"NN"},
"matisse":	{"NN"},
"matman":	{"NN"},
"matoaka":	{"NN"},
"matriarch":	{"NN"},
"matriarchal":	{"JJ","NN"},
"matriarchate":	{"NN"},
"matriarchic":	{"JJ"},
"matriarchy":	{"NN"},
"matric":	{"NN","JJ"},
"matricaria":	{"NN"},
"matricentric":	{"JJ"},
"matricide":	{"NN"},
"matriculate":	{"VB","VBP"},
"matriculated":	{"VBD","VBN"},
"matriculates":	{"VBZ"},
"matriculating":	{"VBG"},
"matriculation":	{"NN"},
"matrikin":	{"NN"},
"matrilineage":	{"NN"},
"matrilineal":	{"JJ","NN"},
"matrilineally":	{"RB"},
"matrilinear":	{"JJ"},
"matrimonial":	{"JJ","NN"},
"matrimony":	{"NN"},
"matrisib":	{"NN"},
"matrix":	{"NN"},
"matron":	{"NN"},
"matronly":	{"JJ","RB"},
"matronymic":	{"NN"},
"matryoshka":	{"FW"},
"mats":	{"NNS","VBZ"},
"matsushita-made":	{"JJ"},
"matsushita-owned":	{"JJ"},
"matsyendra":	{"NN"},
"matt":	{"JJ"},
"matte":	{"JJ"},
"matted":	{"JJ","VBD","VBN"},
"matter":	{"NN","VB","VBP"},
"matter-of-course":	{"JJ"},
"matter-of-fact":	{"JJ"},
"matter-of-factly":	{"RB"},
"matter-of-factness":	{"NN"},
"mattered":	{"VBD","VBN"},
"mattering":	{"VBG"},
"matters":	{"NNS","VBZ"},
"matteuccia":	{"NN"},
"matthiola":	{"NN"},
"matting":	{"NN","VBG"},
"mattock":	{"NN"},
"mattocks":	{"NNS"},
"mattole":	{"NN"},
"mattress":	{"NN"},
"mattresses":	{"NNS"},
"maturate":	{"VB","VBP"},
"maturated":	{"VBD","VBN"},
"maturates":	{"VBZ"},
"maturating":	{"VBG"},
"maturation":	{"NN"},
"maturational":	{"JJ"},
"mature":	{"JJ","VB","VBP"},
"matured":	{"VBD","VBN"},
"maturely":	{"RB"},
"maturement":	{"NN"},
"matureness":	{"NN"},
"matures":	{"VBZ"},
"maturing":	{"VBG"},
"maturities":	{"NNS"},
"maturity":	{"NN"},
"matutinal":	{"JJ"},
"matza":	{"NN"},
"matzah":	{"NN"},
"matzahs":	{"NNS"},
"matzas":	{"NNS"},
"matzo":	{"NN"},
"matzoh":	{"NN"},
"matzohs":	{"NNS"},
"matzos":	{"NNS"},
"maudlin":	{"JJ"},
"maul":	{"VB","VBP"},
"mauldin":	{"NN"},
"mauled":	{"VBD","VBN"},
"mauler":	{"NN"},
"maulers":	{"NNS"},
"mauling":	{"VBG","NN"},
"mauls":	{"VBZ"},
"maulstick":	{"NN"},
"maund":	{"NN"},
"maunder":	{"VB","VBP"},
"maundered":	{"VBD","VBN"},
"maundering":	{"VBG"},
"maunders":	{"VBZ"},
"maundy":	{"NN"},
"maureen":	{"NN"},
"mauritanie":	{"NN"},
"maurois":	{"NN"},
"mauser":	{"NN"},
"mausoleum":	{"NN"},
"mausoleums":	{"NNS"},
"mauve":	{"NN","JJ"},
"mauve-blue":	{"JJ"},
"mauve-colored":	{"JJ"},
"mauve-pink":	{"JJ"},
"maven":	{"NN"},
"mavens":	{"NNS"},
"maverick":	{"NN","JJ"},
"mavericks":	{"NNS"},
"mavik":	{"NN"},
"mavin":	{"NN"},
"mavis":	{"NN"},
"maw":	{"NN"},
"mawkish":	{"JJ"},
"mawkishly":	{"RB"},
"mawkishness":	{"NN"},
"mawlamyine":	{"NN"},
"maws":	{"NNS"},
"max":	{"NN","JJ","RB","VB","VBP"},
"maxed":	{"VBD","VBN"},
"maxes":	{"VBZ","NNS"},
"maxi":	{"NN"},
"maxilla":	{"NN"},
"maxillaria":	{"NN"},
"maxillary":	{"JJ"},
"maxillodental":	{"JJ"},
"maxillofacial":	{"JJ"},
"maxillomandibular":	{"JJ"},
"maxim":	{"NN"},
"maxima":	{"NNS"},
"maximal":	{"JJ"},
"maximally":	{"RB"},
"maximation":	{"NN"},
"maximian":	{"NN"},
"maximisation":	{"NN"},
"maximise":	{"VB","VBP"},
"maximised":	{"VBD","VBN"},
"maximises":	{"VBZ"},
"maximising":	{"VBG"},
"maximization":	{"NN"},
"maximize":	{"VB","VBP"},
"maximized":	{"VBD","VBN"},
"maximizes":	{"VBZ"},
"maximizing":	{"VBG"},
"maxims":	{"NNS"},
"maximum":	{"JJ","NN","RB"},
"maximum-security":	{"JJ"},
"maximums":	{"NNS"},
"maxing":	{"VBG"},
"maxostoma":	{"NN"},
"maxzide":	{"NN"},
"may":	{"MD"},
"maya":	{"NN"},
"mayaca":	{"NN"},
"mayacaceae":	{"NN"},
"mayakovski":	{"NN"},
"mayapple":	{"NN"},
"maybe":	{"RB"},
"mayday":	{"NN"},
"maydays":	{"NNS"},
"mayeng":	{"NN"},
"mayenne":	{"NN"},
"mayer":	{"NN"},
"mayetiola":	{"NN"},
"mayfish":	{"NN"},
"mayflies":	{"NNS"},
"mayfly":	{"NN"},
"mayhap":	{"RB"},
"mayhaw":	{"NN"},
"mayhem":	{"NN"},
"mayidism":	{"NN"},
"maying":	{"NN"},
"mayo":	{"NN"},
"mayonnaise":	{"NN"},
"mayor":	{"NN"},
"mayoral":	{"JJ"},
"mayoralty":	{"NN"},
"mayoress":	{"NN"},
"mayoresses":	{"NNS"},
"mayors":	{"NNS"},
"mayorship":	{"NN"},
"maypole":	{"NN"},
"maypoles":	{"NNS"},
"maypop":	{"NN"},
"mayst":	{"MD"},
"mayweed":	{"NN"},
"mazama":	{"NN"},
"mazar-i-sharif":	{"NN"},
"mazatlan":	{"NN"},
"mazdaism":	{"NN"},
"maze":	{"NN","VB","VBP"},
"mazed":	{"VBD","VBN"},
"mazer":	{"NN"},
"mazes":	{"NNS","VBZ"},
"mazing":	{"VBG"},
"mazopathy":	{"NN"},
"mazurka":	{"NN"},
"mazy":	{"JJ"},
"mazzard":	{"NN"},
"mazzini":	{"NN"},
"mb":	{"NN"},
"mbd":	{"NN"},
"mbeya":	{"NN"},
"mbit":	{"NN"},
"mbundu":	{"NN"},
"mc.":	{"NN"},
"mcalester":	{"NN"},
"mcallen":	{"NN"},
"mcallister":	{"NN"},
"mccarthy-era":	{"JJ"},
"mccauley":	{"NN"},
"mccormick":	{"NN"},
"mcfadden":	{"NN"},
"mcfeely":	{"RB"},
"mcg":	{"NN"},
"mcgovern":	{"NN"},
"mcgraw":	{"NN"},
"mcguffey":	{"NN"},
"mcguffin":	{"NN"},
"mcguire":	{"NN"},
"mcia":	{"NN"},
"mcintosh":	{"NN"},
"mckim":	{"NN"},
"mcknight":	{"NN"},
"mcmaster":	{"NN"},
"mcnair":	{"NN"},
"mdi":	{"NN"},
"mdiv":	{"NN"},
"mdma":	{"NN"},
"me":	{"PRP"},
"mea":	{"NN"},
"mead":	{"NN"},
"meade":	{"NN"},
"meadow":	{"NN"},
"meadowgrass":	{"NN"},
"meadowlark":	{"NN"},
"meadowlarks":	{"NNS"},
"meadows":	{"NNS"},
"meager":	{"JJ"},
"meagerly":	{"RB"},
"meagerness":	{"NN"},
"meagre":	{"JJ"},
"meagrely":	{"RB"},
"meagreness":	{"NN"},
"meal":	{"NN"},
"meal-ticket":	{"NN"},
"meal-tickets":	{"NNS"},
"meal-to-meal":	{"JJ"},
"mealberry":	{"NN"},
"mealie":	{"NN"},
"mealie-meal":	{"NN"},
"mealier":	{"JJR"},
"mealies":	{"NNS"},
"mealiest":	{"JJS"},
"meals":	{"NNS"},
"meals-on-wheels":	{"NN"},
"mealtime":	{"NN"},
"mealtimes":	{"NNS"},
"mealworm":	{"NN"},
"mealy":	{"JJ"},
"mealy-mouthed":	{"JJ"},
"mealybug":	{"NN"},
"mealymouthed":	{"JJ"},
"mealynose":	{"NN"},
"mealynosed":	{"JJ"},
"mean":	{"VB","VBP","JJ","NN"},
"mean-spirited":	{"JJ"},
"mean-square":	{"JJ"},
"meander":	{"VB","VBP","NN"},
"meandered":	{"VBD","VBN"},
"meandering":	{"VBG"},
"meanderingly":	{"RB"},
"meanderings":	{"NNS"},
"meanders":	{"VBZ","NNS"},
"meaner":	{"JJR"},
"meanest":	{"JJS"},
"meanie":	{"NN"},
"meanies":	{"NNS"},
"meaning":	{"NN","JJ","VBG"},
"meaningful":	{"JJ"},
"meaningfully":	{"RB"},
"meaningfulness":	{"NN"},
"meaningless":	{"JJ"},
"meaninglessness":	{"NN"},
"meanings":	{"NNS"},
"meanly":	{"RB"},
"meanness":	{"NN"},
"means":	{"VBZ","NNS","NN"},
"meanspirited":	{"JJ"},
"meanspiritedly":	{"RB"},
"meant":	{"VBD","VBN"},
"meantime":	{"NN","RB"},
"meanwhile":	{"RB"},
"meany":	{"NN"},
"mearstone":	{"NN"},
"measles":	{"NN"},
"measly":	{"JJ"},
"measurability":	{"NN"},
"measurable":	{"JJ"},
"measurably":	{"RB"},
"measure":	{"NN","VB","VBP"},
"measured":	{"VBN","VBD","JJ"},
"measuredly":	{"RB"},
"measureless":	{"JJ"},
"measurement":	{"NN"},
"measurements":	{"NNS"},
"measurer":	{"NN"},
"measures":	{"NNS","VBZ"},
"measuring":	{"VBG","NN"},
"meat":	{"NN"},
"meat-eating":	{"JJ"},
"meat-hungry":	{"JJ"},
"meat-packer":	{"NN"},
"meat-packers":	{"NNS"},
"meat-packing":	{"NN"},
"meat-processing":	{"JJ"},
"meat-wagon":	{"NN"},
"meatball":	{"NN"},
"meatballs":	{"NNS"},
"meathead":	{"NN"},
"meatheads":	{"NNS"},
"meatier":	{"JJR"},
"meatiest":	{"JJS"},
"meatless":	{"JJ"},
"meatloaf":	{"NN"},
"meatloaves":	{"NNS"},
"meatman":	{"NN"},
"meatmen":	{"NNS"},
"meatpacker":	{"NN"},
"meatpackers":	{"NNS"},
"meatpacking":	{"NN"},
"meats":	{"NNS"},
"meatus":	{"NN","NNS"},
"meatuses":	{"NNS"},
"meaty":	{"JJ"},
"mebaral":	{"NN"},
"mebendazole":	{"NN"},
"mebibit":	{"NN"},
"mebibyte":	{"NN"},
"mecca":	{"NN"},
"meccas":	{"NNS"},
"mechanic":	{"NN"},
"mechanical":	{"JJ"},
"mechanically":	{"RB"},
"mechanics":	{"NN","NNS"},
"mechanisation":	{"NN"},
"mechanise":	{"VB","VBP"},
"mechanised":	{"JJ","VBD","VBN"},
"mechanises":	{"VBZ"},
"mechanising":	{"VBG"},
"mechanism":	{"NN"},
"mechanisms":	{"NNS"},
"mechanist":	{"NN"},
"mechanistic":	{"JJ"},
"mechanistically":	{"RB"},
"mechanists":	{"NNS"},
"mechanization":	{"NN"},
"mechanize":	{"VB","VBP"},
"mechanized":	{"JJ","VBD","VBN"},
"mechanizes":	{"VBZ"},
"mechanizing":	{"VBG"},
"mechanochemically":	{"RB"},
"mecholyl":	{"NN"},
"meclizine":	{"NN"},
"meclofenamate":	{"NN"},
"meclomen":	{"NN"},
"meconium":	{"NN"},
"meconopsis":	{"NN"},
"mecoptera":	{"NN"},
"mecopteran":	{"NN"},
"mecopterous":	{"JJ"},
"mecum":	{"NN"},
"med":	{"JJ"},
"medal":	{"NN","VB","VBP"},
"medaled":	{"VBD","VBN"},
"medaling":	{"VBG"},
"medalist":	{"NN"},
"medalists":	{"NNS"},
"medalled":	{"VBD","VBN"},
"medalling":	{"VBG"},
"medallion":	{"NN"},
"medallions":	{"NNS"},
"medallist":	{"NN"},
"medallists":	{"NNS"},
"medals":	{"NNS","VBZ"},
"medan":	{"NN"},
"meddle":	{"VB","VBP"},
"meddled":	{"VBD","VBN"},
"meddler":	{"NN"},
"meddlers":	{"NNS"},
"meddles":	{"VBZ"},
"meddlesome":	{"JJ","NN"},
"meddlesomeness":	{"NN"},
"meddling":	{"VBG","NN","JJ"},
"medevac":	{"NN","VB","VBP"},
"medevacked":	{"VBD","VBN"},
"medevacking":	{"VBG"},
"medevacs":	{"NNS","VBZ"},
"medfly":	{"NN"},
"medford":	{"NN"},
"media":	{"NNS","NN"},
"media-buying":	{"JJ","NN"},
"media-conscious":	{"JJ"},
"media-linked":	{"JJ"},
"media-related":	{"JJ"},
"media-spending":	{"JJ"},
"media-stock":	{"JJ"},
"mediacy":	{"NN"},
"mediaeval":	{"JJ"},
"mediaevalist":	{"NN"},
"medial":	{"JJ","NN"},
"medially":	{"RB"},
"median":	{"JJ","NN"},
"median-family":	{"NN"},
"median-nerve":	{"JJ"},
"medians":	{"NNS"},
"mediant":	{"NN"},
"mediastinum":	{"NN"},
"mediate":	{"VB","VBP"},
"mediated":	{"VBD","VBN"},
"mediateness":	{"NN"},
"mediates":	{"VBZ"},
"mediating":	{"VBG"},
"mediation":	{"NN"},
"mediator":	{"NN"},
"mediatorial":	{"JJ"},
"mediators":	{"NNS"},
"mediatory":	{"JJ"},
"mediatrix":	{"NN"},
"medic":	{"NN"},
"medica":	{"NN"},
"medicago":	{"NN"},
"medicaid-covered":	{"JJ"},
"medicaid-paid":	{"JJ"},
"medical":	{"JJ","NN"},
"medical-airlift":	{"NN"},
"medical-assistance":	{"NN"},
"medical-benefits":	{"NNS"},
"medical-care":	{"NN"},
"medical-instrument":	{"JJ"},
"medical-leave":	{"JJ"},
"medical-practice":	{"NN"},
"medical-products":	{"NNS"},
"medical-school":	{"NN"},
"medical-supply":	{"JJ"},
"medical-support":	{"JJ"},
"medical-test":	{"JJ"},
"medicalisation":	{"NN"},
"medicalise":	{"VB","VBP"},
"medicalised":	{"VBD","VBN"},
"medicalises":	{"VBZ"},
"medicalising":	{"VBG"},
"medicalization":	{"NN"},
"medicalize":	{"VB","VBP"},
"medicalized":	{"VBD","VBN"},
"medicalizes":	{"VBZ"},
"medicalizing":	{"VBG"},
"medically":	{"RB"},
"medicals":	{"NNS"},
"medicament":	{"NN"},
"medicaments":	{"NNS"},
"medicare-approved":	{"JJ"},
"medicare-catastrophic-care":	{"JJ"},
"medicare-eligible":	{"JJ"},
"medicate":	{"VB","VBP"},
"medicated":	{"VBD","VBN","JJ"},
"medicates":	{"VBZ"},
"medicating":	{"VBG"},
"medication":	{"NN"},
"medication-dispensing":	{"JJ"},
"medications":	{"NNS"},
"medicative":	{"JJ"},
"medicinal":	{"JJ"},
"medicinalis":	{"FW"},
"medicinally":	{"RB"},
"medicine":	{"NN"},
"medicine-man":	{"NN"},
"medicines":	{"NNS"},
"medick":	{"NN"},
"medico":	{"NN"},
"medico-military":	{"NN","JJ"},
"medicolegal":	{"JJ"},
"medicos":	{"NNS"},
"medics":	{"NNS"},
"mediety":	{"NN"},
"medieval":	{"JJ"},
"medinilla":	{"NN"},
"mediocre":	{"JJ"},
"mediocrities":	{"NNS"},
"mediocrity":	{"NN"},
"meditate":	{"VB","VBP"},
"meditated":	{"VBD","VBN"},
"meditates":	{"VBZ"},
"meditating":	{"NN","VBG"},
"meditation":	{"NN"},
"meditations":	{"NNS"},
"meditative":	{"JJ"},
"meditatively":	{"RB"},
"meditativeness":	{"NN"},
"medium":	{"NN","JJ"},
"medium-distance":	{"JJ"},
"medium-dry":	{"JJ"},
"medium-duty":	{"JJ"},
"medium-grade":	{"JJ"},
"medium-haul":	{"JJ"},
"medium-high":	{"JJ"},
"medium-large":	{"JJ"},
"medium-size":	{"JJ"},
"medium-sized":	{"JJ"},
"medium-term":	{"NN"},
"medium-to-long-range":	{"JJ"},
"mediumistic":	{"JJ"},
"mediums":	{"NNS"},
"mediumship":	{"NN"},
"medivac":	{"NN","VB","VBP"},
"medivacked":	{"VBD","VBN"},
"medivacking":	{"VBG"},
"medivacs":	{"NNS","VBZ"},
"medlar":	{"NN"},
"medlars":	{"NNS"},
"medley":	{"NN"},
"medleys":	{"NNS"},
"medline":	{"NN"},
"medoc":	{"NN"},
"medroxyprogesterone":	{"NN"},
"medulla":	{"NN"},
"medullary":	{"JJ"},
"medullated":	{"JJ"},
"medusan":	{"NN"},
"medusoid":	{"JJ","NN"},
"mee":	{"NN"},
"meed":	{"NN"},
"meek":	{"JJ"},
"meek-mannered":	{"JJ"},
"meeker":	{"JJR"},
"meekest":	{"JJS"},
"meekly":	{"RB"},
"meekness":	{"NN"},
"meerestone":	{"NN"},
"meerkat":	{"NN"},
"meerschaum":	{"NN"},
"meet":	{"VB","VBP","NN","JJ"},
"meeter":	{"NN"},
"meeting":	{"NN","VBG"},
"meeting-house":	{"NN"},
"meeting-houses":	{"NNS"},
"meeting-place":	{"NN"},
"meeting-places":	{"NNS"},
"meetinghouse":	{"NN"},
"meetings":	{"NNS"},
"meets":	{"VBZ","NNS"},
"mefloquine":	{"NN"},
"mefoxin":	{"NN"},
"meg":	{"NN"},
"mega":	{"JJ","RB"},
"mega-crash":	{"NN"},
"mega-crashes":	{"NNS"},
"mega-deal":	{"NN"},
"mega-deals":	{"NNS"},
"mega-hit":	{"JJ","NN"},
"mega-hits":	{"NNS"},
"mega-issues":	{"NNS"},
"mega-lawyer":	{"NN"},
"mega-mergers":	{"NNS"},
"mega-problems":	{"NNS"},
"mega-projects":	{"NNS"},
"mega-resort":	{"NN"},
"mega-resorts":	{"NNS"},
"mega-stadium":	{"NN"},
"mega-stardom":	{"NN"},
"mega-welfare":	{"JJ"},
"megabat":	{"NN"},
"megabillion":	{"NN"},
"megabit":	{"NN"},
"megabucks":	{"NNS"},
"megabyte":	{"NN"},
"megabytes":	{"NNS"},
"megacardia":	{"NN"},
"megacephaly":	{"NN"},
"megachile":	{"NN"},
"megachilidae":	{"NN"},
"megachiroptera":	{"NN"},
"megacolon":	{"NN"},
"megacycle":	{"NN"},
"megadeath":	{"NN"},
"megaderma":	{"NN"},
"megadermatidae":	{"NN"},
"megadrop":	{"NN"},
"megaera":	{"NN"},
"megaflop":	{"NN"},
"megagametophyte":	{"NN"},
"megahertz":	{"NN","NNS"},
"megahit":	{"NN"},
"megakaryocyte":	{"NN"},
"megakaryocytic":	{"JJ"},
"megalith":	{"NN"},
"megalithic":	{"JJ"},
"megaliths":	{"NNS"},
"megalobatrachus":	{"NN"},
"megaloblast":	{"NN"},
"megaloblastic":	{"JJ"},
"megalocardia":	{"NN"},
"megalocephaly":	{"NN"},
"megalocyte":	{"NN"},
"megalohepatia":	{"NN"},
"megalomania":	{"NN"},
"megalomaniac":	{"NN","JJ"},
"megalomaniacal":	{"JJ"},
"megalomaniacally":	{"RB"},
"megalomaniacs":	{"NNS"},
"megalomanic":	{"JJ"},
"megalonychidae":	{"NN"},
"megalopolis":	{"NN"},
"megalopolises":	{"NNS"},
"megaloptera":	{"NN"},
"megalosaur":	{"NN"},
"megalosauridae":	{"NN"},
"megalosaurus":	{"NN"},
"megamarketing":	{"NN"},
"megaphone":	{"NN"},
"megaphones":	{"NNS"},
"megapode":	{"NN"},
"megapodiidae":	{"NN"},
"megapodius":	{"NN"},
"megaptera":	{"NN"},
"megaquestions":	{"NNS"},
"megascopic":	{"JJ"},
"megasporangium":	{"NN"},
"megaspore":	{"NN"},
"megasporophyll":	{"NN"},
"megathere":	{"NN"},
"megatherian":	{"NN"},
"megatheriid":	{"NN"},
"megatheriidae":	{"NN"},
"megatherium":	{"NN"},
"megaton":	{"NN"},
"megatons":	{"NNS"},
"megawatt":	{"NN"},
"megawatts":	{"NNS"},
"megestrol":	{"NN"},
"megillah":	{"NN"},
"megilp":	{"NN"},
"megohm":	{"NN"},
"megrim":	{"NN"},
"megrims":	{"NNS"},
"mehta":	{"NN"},
"mei":	{"NN"},
"meioses":	{"NNS"},
"meiosis":	{"NN"},
"meiotic":	{"JJ"},
"meissner":	{"NN"},
"meister":	{"NN"},
"meitner":	{"NN"},
"meitnerium":	{"NN"},
"mek":	{"NN"},
"melaena":	{"NN"},
"melagra":	{"NN"},
"melamine":	{"NN"},
"melampodium":	{"NN"},
"melampsora":	{"NN"},
"melampsoraceae":	{"NN"},
"melancholia":	{"NN"},
"melancholiac":	{"NN"},
"melancholic":	{"JJ","NN"},
"melancholics":	{"NNS"},
"melancholy":	{"NN","JJ"},
"melanchthon":	{"NN"},
"melanderi":	{"NN"},
"melanerpes":	{"NN"},
"melange":	{"NN"},
"melanges":	{"NNS"},
"melanin":	{"NN"},
"melanise":	{"VB","VBP"},
"melanised":	{"VBD","VBN"},
"melanises":	{"VBZ"},
"melanising":	{"VBG"},
"melanism":	{"NN"},
"melanitta":	{"NN"},
"melanize":	{"VB","VBP"},
"melanized":	{"VBD","VBN"},
"melanizes":	{"VBZ"},
"melanizing":	{"VBG"},
"melanoblast":	{"NN"},
"melanocyte":	{"NN"},
"melanoderma":	{"NN"},
"melanogrammus":	{"NN"},
"melanoma":	{"NN"},
"melanomas":	{"NNS"},
"melanoplus":	{"NN"},
"melanosis":	{"NN"},
"melanotis":	{"NN"},
"melanthiaceae":	{"NN"},
"melasma":	{"NN"},
"melastoma":	{"NN"},
"melastomaceae":	{"NN"},
"melastomataceae":	{"NN"},
"melatonin":	{"NN"},
"melba":	{"NN"},
"melchior":	{"NN"},
"melchite":	{"NN"},
"meld":	{"VB","VBP","NN"},
"melded":	{"VBD","VBN"},
"melding":	{"VBG"},
"melds":	{"VBZ","NNS"},
"meleagrididae":	{"NN"},
"meleagris":	{"NN"},
"melee":	{"NN"},
"melees":	{"NNS"},
"melena":	{"NN"},
"meles":	{"NN"},
"melia":	{"NN"},
"meliaceae":	{"NN"},
"melicocca":	{"NN"},
"melicoccus":	{"NN"},
"melicytus":	{"NN"},
"melilot":	{"NN"},
"melilotus":	{"NN"},
"melinae":	{"NN"},
"meliorate":	{"VB","VBP"},
"meliorated":	{"VBD","VBN"},
"meliorates":	{"VBZ"},
"meliorating":	{"VBG"},
"melioration":	{"NN"},
"meliorative":	{"JJ"},
"meliorism":	{"NN"},
"meliorist":	{"NN"},
"meliphagidae":	{"NN"},
"melkite":	{"NN"},
"mellaril":	{"NN"},
"mellifluence":	{"NN"},
"mellifluent":	{"JJ"},
"mellifluently":	{"RB"},
"mellifluous":	{"JJ"},
"mellifluously":	{"RB"},
"mellisonant":	{"JJ"},
"mellitus":	{"NN"},
"mellivora":	{"NN"},
"mellon":	{"NN"},
"mellow":	{"JJ","VB","VBP"},
"mellowed":	{"VBD","VBN"},
"mellower":	{"JJR"},
"mellowest":	{"JJS"},
"mellowing":	{"VBG"},
"mellowly":	{"RB"},
"mellowness":	{"NN"},
"mellows":	{"VBZ"},
"melocactus":	{"NN"},
"melodic":	{"JJ"},
"melodically":	{"RB"},
"melodies":	{"NNS"},
"melodious":	{"JJ"},
"melodiously":	{"RB"},
"melodiousness":	{"NN"},
"melodise":	{"VB","VBP"},
"melodised":	{"VBD","VBN"},
"melodiser":	{"NN"},
"melodises":	{"VBZ"},
"melodising":	{"VBG"},
"melodize":	{"VB","VBP"},
"melodized":	{"VBD","VBN"},
"melodizer":	{"NN"},
"melodizes":	{"VBZ"},
"melodizing":	{"VBG"},
"melodrama":	{"NN"},
"melodramas":	{"NNS"},
"melodramatic":	{"JJ"},
"melodramatically":	{"RB"},
"melody":	{"NN"},
"melogale":	{"NN"},
"meloid":	{"NN"},
"meloidae":	{"NN"},
"melolontha":	{"NN"},
"melolonthidae":	{"NN"},
"melon":	{"NN"},
"melon-like":	{"JJ"},
"melons":	{"NNS"},
"melophagus":	{"NN"},
"melopsittacus":	{"NN"},
"melosa":	{"NN"},
"melospiza":	{"NN"},
"melphalan":	{"NN"},
"melpomene":	{"NN"},
"melrose":	{"NN"},
"melt":	{"VB","VBP"},
"melt-textured":	{"JJ"},
"meltable":	{"JJ"},
"meltdown":	{"NN"},
"meltdowns":	{"NNS"},
"melted":	{"VBN","VBD"},
"melter":	{"NN"},
"melting":	{"JJ","VBG"},
"melting-point":	{"NN"},
"melting-points":	{"NNS"},
"melting-pot":	{"NN"},
"melting-pots":	{"NNS"},
"meltingly":	{"RB"},
"melts":	{"VBZ"},
"meltwater":	{"NN"},
"melursus":	{"NN"},
"mem":	{"NN"},
"member":	{"NN"},
"membered":	{"JJ"},
"memberless":	{"JJ"},
"members":	{"NNS"},
"membership":	{"NN"},
"memberships":	{"NNS"},
"membracidae":	{"NN"},
"membrane":	{"NN"},
"membrane-forming":	{"JJ"},
"membranes":	{"NNS"},
"membranophone":	{"NN"},
"membranophones":	{"NNS"},
"membranous":	{"JJ"},
"meme":	{"NN"},
"memeable":	{"JJ"},
"memento":	{"NN"},
"mementoes":	{"NNS"},
"mementos":	{"NNS"},
"memes":	{"NNS"},
"memetic":	{"JJ"},
"meminisse":	{"FW"},
"memo":	{"NN"},
"memoir":	{"NN"},
"memoirs":	{"NNS"},
"memorabilia":	{"NNS"},
"memorability":	{"NN"},
"memorable":	{"JJ"},
"memorableness":	{"NN"},
"memorably":	{"RB"},
"memoranda":	{"NNS"},
"memorandum":	{"NN"},
"memorandums":	{"NNS"},
"memorial":	{"NN","JJ"},
"memorialisation":	{"NN"},
"memorialise":	{"VB","VBP"},
"memorialised":	{"VBD","VBN"},
"memorialises":	{"VBZ"},
"memorialising":	{"VBG"},
"memorialist":	{"NN"},
"memorialists":	{"NNS"},
"memorialization":	{"NN"},
"memorialize":	{"VB","VBP"},
"memorialized":	{"VBD","VBN"},
"memorializes":	{"VBZ"},
"memorializing":	{"VBG"},
"memorials":	{"NNS"},
"memoriam":	{"NN"},
"memories":	{"NNS"},
"memorisable":	{"JJ"},
"memorisation":	{"NN"},
"memorise":	{"VB","VBP"},
"memorised":	{"VBD","VBN"},
"memoriser":	{"NN"},
"memorisers":	{"NNS"},
"memorises":	{"VBZ"},
"memorising":	{"VBG"},
"memorizable":	{"JJ"},
"memorization":	{"NN"},
"memorize":	{"VB","VBP"},
"memorized":	{"VBD","VBN"},
"memorizer":	{"NN"},
"memorizers":	{"NNS"},
"memorizes":	{"VBZ"},
"memorizing":	{"VBG"},
"memory":	{"NN"},
"memory-chip":	{"NN"},
"memory-expansion":	{"JJ"},
"memory-images":	{"NNS"},
"memory-picture":	{"NN"},
"memory-pictures":	{"NNS"},
"memos":	{"NNS"},
"memsahib":	{"NN"},
"memsahibs":	{"NNS"},
"men":	{"NNS"},
"men-at-arms":	{"NNS"},
"men-folk":	{"NNS"},
"men-of-war":	{"NNS"},
"menace":	{"NN","VB","VBP"},
"menaced":	{"VBD","VBN"},
"menaces":	{"NNS","VBZ"},
"menacing":	{"JJ","VBG"},
"menacingly":	{"RB"},
"menadione":	{"NN"},
"menage":	{"NN"},
"menagerie":	{"NN"},
"menageries":	{"NNS"},
"menander":	{"NN"},
"menarche":	{"NN"},
"menarches":	{"NNS"},
"mencken":	{"NN"},
"mend":	{"VB","VBP","NN"},
"mendacious":	{"JJ"},
"mendaciously":	{"RB"},
"mendacity":	{"NN"},
"mended":	{"VBD","VBN"},
"mendeleev":	{"NN"},
"mendelevium":	{"NN"},
"mendelianism":	{"NN"},
"mendelism":	{"NN"},
"mendelsohn":	{"NN"},
"mender":	{"NN"},
"menders":	{"NNS"},
"mendicancy":	{"NN"},
"mendicant":	{"NN","JJ"},
"mendicants":	{"NNS"},
"mendicity":	{"NN"},
"mending":	{"VBG","NN"},
"mendoza":	{"NN"},
"mends":	{"VBZ","NNS"},
"menfolk":	{"NNS"},
"menhaden":	{"NN","NNS"},
"menhadens":	{"NNS"},
"menhir":	{"NN"},
"menial":	{"JJ","NN"},
"menially":	{"RB"},
"menials":	{"NNS"},
"meniere":	{"NN"},
"meningeal":	{"JJ"},
"meninges":	{"NN"},
"meningioma":	{"NN"},
"meningism":	{"NN"},
"meningitis":	{"NN"},
"meningocele":	{"NN"},
"meningoencephalitis":	{"NN"},
"meninx":	{"NN"},
"menippe":	{"NN"},
"meniscectomy":	{"NN"},
"menisci":	{"NNS"},
"meniscium":	{"NN"},
"meniscus":	{"NN"},
"meniscuses":	{"NNS"},
"menispermaceae":	{"NN"},
"menispermum":	{"NN"},
"menninger":	{"NN"},
"mennonitism":	{"NN"},
"menominee":	{"NN"},
"menomini":	{"NN"},
"menopausal":	{"JJ"},
"menopause":	{"NN"},
"menopon":	{"NN"},
"menorah":	{"NN"},
"menorahs":	{"NNS"},
"menorrhagia":	{"NN"},
"menorrhea":	{"NN"},
"menos":	{"FW"},
"menotti":	{"NN"},
"menotyphla":	{"NN"},
"mensa":	{"NN"},
"mensal":	{"JJ"},
"mensch":	{"NN"},
"menschen":	{"NNS"},
"menses":	{"NNS"},
"mensh":	{"VB","VBP"},
"menshevik":	{"NN"},
"menstrual":	{"JJ"},
"menstruate":	{"VB","VBP"},
"menstruated":	{"VBD","VBN"},
"menstruates":	{"VBZ"},
"menstruating":	{"VBG"},
"menstruation":	{"NN"},
"menstruations":	{"NNS"},
"menstruum":	{"NN"},
"mensurable":	{"JJ"},
"mensural":	{"JJ"},
"mensurate":	{"VB","VBP"},
"mensurated":	{"VBD","VBN"},
"mensurates":	{"VBZ"},
"mensurating":	{"VBG"},
"mensuration":	{"NN"},
"menswear":	{"NN"},
"mental":	{"JJ"},
"mental-health":	{"NN"},
"mental-illness":	{"NN"},
"mentalese":	{"NN"},
"mentalism":	{"NN"},
"mentalities":	{"NNS"},
"mentality":	{"NN"},
"mentally":	{"RB"},
"mentation":	{"NN"},
"mentha":	{"NN"},
"menthol":	{"NN"},
"mentholated":	{"JJ"},
"menticirrhus":	{"NN"},
"mention":	{"VB","NN","VBP"},
"mentioned":	{"VBN","VBD"},
"mentioner":	{"NN"},
"mentioning":	{"VBG"},
"mentions":	{"VBZ","NNS"},
"mentor":	{"NN","VB","VBP"},
"mentored":	{"VBD","VBN"},
"mentoring":	{"VBG","NN"},
"mentors":	{"NNS","VBZ"},
"mentum":	{"NN"},
"mentzelia":	{"NN"},
"menu":	{"NN"},
"menura":	{"NN"},
"menurae":	{"NN"},
"menuridae":	{"NN"},
"menus":	{"NNS"},
"menyanthaceae":	{"NN"},
"menyanthes":	{"NN"},
"menziesia":	{"NN"},
"meow":	{"NN","VB","VBP"},
"meowed":	{"VBD","VBN"},
"meowing":	{"VBG"},
"meows":	{"VBZ","NNS"},
"mepacrine":	{"NN"},
"meperidine":	{"NN"},
"mephaquine":	{"NN"},
"mephenytoin":	{"NN"},
"mephistophelean":	{"JJ"},
"mephistophelian":	{"JJ"},
"mephitic":	{"JJ"},
"mephitinae":	{"NN"},
"mephitis":	{"NN"},
"mephobarbital":	{"NN"},
"meprin":	{"NN"},
"meprobamate":	{"NN"},
"meq":	{"NN"},
"meralgia":	{"NN"},
"merbromine":	{"NN"},
"mercado":	{"FW"},
"mercantile":	{"JJ"},
"mercantilism":	{"NN"},
"mercantilist":	{"NN","JJ"},
"mercantilistic":	{"JJ"},
"mercantilists":	{"NNS"},
"mercaptopurine":	{"NN"},
"mercator":	{"NN"},
"mercedario":	{"NN"},
"mercenaria":	{"NN"},
"mercenaries":	{"NNS"},
"mercenary":	{"JJ","NN"},
"mercer":	{"NN"},
"mercerise":	{"VB","VBP"},
"mercerised":	{"JJ","VBD","VBN"},
"mercerises":	{"VBZ"},
"mercerising":	{"VBG"},
"mercerize":	{"VB","VBP"},
"mercerized":	{"JJ","VBD","VBN"},
"mercerizes":	{"VBZ"},
"mercerizing":	{"VBG"},
"merchandise":	{"NN","VBP","VB"},
"merchandise-trade":	{"JJ"},
"merchandised":	{"VBN","VBD"},
"merchandiser":	{"NN"},
"merchandisers":	{"NNS"},
"merchandises":	{"VBZ"},
"merchandising":	{"NN","VBG"},
"merchant":	{"NN"},
"merchant-banking":	{"JJ","NN"},
"merchant-venturer":	{"NN"},
"merchantability":	{"NN"},
"merchantable":	{"JJ"},
"merchantbanking":	{"NN"},
"merchantman":	{"NN"},
"merchantmen":	{"NNS"},
"merchants":	{"NNS"},
"merciful":	{"JJ"},
"mercifully":	{"RB"},
"mercifulness":	{"NN"},
"merciless":	{"JJ"},
"mercilessly":	{"RB"},
"mercilessness":	{"NN"},
"mercouri":	{"NN"},
"mercurial":	{"JJ"},
"mercurialisation":	{"NN"},
"mercurialise":	{"VB","VBP"},
"mercurialised":	{"VBD","VBN"},
"mercurialises":	{"VBZ"},
"mercurialising":	{"VBG"},
"mercurialization":	{"NN"},
"mercurialize":	{"VB","VBP"},
"mercurialized":	{"VBD","VBN"},
"mercurializes":	{"VBZ"},
"mercurializing":	{"VBG"},
"mercuric":	{"JJ"},
"mercurochrome":	{"NN"},
"mercurous":	{"JJ"},
"mercury":	{"NN"},
"mercury-contaminated":	{"JJ"},
"mercy":	{"NN","UH"},
"mere":	{"JJ","NN"},
"merely":	{"RB"},
"meres":	{"NNS"},
"merest":	{"JJS"},
"merestone":	{"NN"},
"meretricious":	{"JJ"},
"meretriciously":	{"RB"},
"meretriciousness":	{"NN"},
"merganser":	{"NN","NNS"},
"mergansers":	{"NNS"},
"merge":	{"VB","VBP"},
"merged":	{"VBD","VBN"},
"mergenthaler":	{"NN"},
"merger":	{"NN"},
"merger-acquisition":	{"JJ"},
"merger-law":	{"NN"},
"merger-related":	{"JJ"},
"mergers":	{"NNS"},
"mergers-advisory":	{"JJ"},
"mergers-and-acquisitions":	{"NNS","JJ"},
"merges":	{"VBZ"},
"merginae":	{"NN"},
"merging":	{"VBG"},
"mergus":	{"NN"},
"mericarp":	{"NN"},
"merida":	{"NN"},
"meridian":	{"NN","JJ"},
"meridians":	{"NNS"},
"meridional":	{"JJ"},
"meringue":	{"NN"},
"meringues":	{"NNS"},
"merino":	{"NN"},
"merinos":	{"NNS"},
"meriones":	{"NN"},
"meristem":	{"NN"},
"merit":	{"NN","VB","VBP"},
"meritable":	{"JJ"},
"merited":	{"VBD","VBN"},
"meriting":	{"VBG"},
"meritless":	{"JJ"},
"meritocracies":	{"NNS"},
"meritocracy":	{"NN"},
"meritocratic":	{"JJ"},
"meritorious":	{"JJ"},
"meritoriously":	{"RB"},
"meritoriousness":	{"NN"},
"merits":	{"NNS","VBZ"},
"merkel":	{"NN"},
"merl":	{"NN"},
"merlangus":	{"NN"},
"merle":	{"NN"},
"merlin":	{"NN"},
"merlon":	{"NN"},
"merlot":	{"NN"},
"merluccius":	{"NN"},
"mermaid":	{"NN"},
"mermaids":	{"NNS"},
"merman":	{"NN"},
"mermen":	{"NNS"},
"merodach":	{"NN"},
"meromelia":	{"NN"},
"meronym":	{"NN"},
"meronymy":	{"NN"},
"meropidae":	{"NN"},
"merops":	{"NN"},
"merostomata":	{"NN"},
"merovingian":	{"JJ"},
"merozoite":	{"NN"},
"merrier":	{"JJR"},
"merriest":	{"JJS"},
"merrily":	{"RB"},
"merrimac":	{"NN"},
"merrimack":	{"NN"},
"merriment":	{"NN"},
"merriness":	{"NN"},
"merry":	{"JJ"},
"merry-go-round":	{"NN"},
"merry-go-rounds":	{"NNS"},
"merrymaker":	{"NN"},
"merrymaking":	{"NN"},
"mers":	{"FW"},
"mertensia":	{"NN"},
"merthiolate":	{"NN"},
"merton":	{"NN"},
"merveilleux":	{"FW"},
"meryta":	{"NN"},
"mesa":	{"NN"},
"mesalliance":	{"NN"},
"mesantoin":	{"NN"},
"mesas":	{"NNS"},
"mesasamkranti":	{"NN"},
"mescal":	{"NN"},
"mescaline":	{"NN"},
"mesembryanthemum":	{"NN"},
"mesencephalon":	{"NN"},
"mesenchyme":	{"NN"},
"mesenteric":	{"JJ"},
"mesentery":	{"NN"},
"mesh":	{"VB","VBP","NN"},
"meshed":	{"VBD","VBN"},
"meshes":	{"VBZ"},
"meshing":	{"VBG"},
"meshuga":	{"JJ"},
"meshugaas":	{"NN"},
"meshugga":	{"JJ"},
"meshugge":	{"JJ"},
"meshuggeneh":	{"JJ","NN"},
"meshuggener":	{"JJ","NN"},
"meshwork":	{"NN"},
"mesial":	{"JJ"},
"mesic":	{"JJ"},
"mesmer":	{"NN"},
"mesmeric":	{"JJ"},
"mesmerise":	{"VB","VBP"},
"mesmerised":	{"VBD","VBN","JJ"},
"mesmeriser":	{"NN"},
"mesmerisers":	{"NNS"},
"mesmerises":	{"VBZ"},
"mesmerising":	{"VBG","JJ"},
"mesmerisingly":	{"RB"},
"mesmerism":	{"NN"},
"mesmerist":	{"NN"},
"mesmerists":	{"NNS"},
"mesmerize":	{"VB","VBP"},
"mesmerized":	{"VBD","VBN","JJ"},
"mesmerizer":	{"NN"},
"mesmerizers":	{"NNS"},
"mesmerizes":	{"VBZ"},
"mesmerizing":	{"VBG","JJ"},
"mesmerizingly":	{"RB"},
"mesoamerica":	{"NN"},
"mesoamerican":	{"JJ","NN"},
"mesoblast":	{"NN"},
"mesoblastic":	{"JJ"},
"mesocarp":	{"NN"},
"mesocolon":	{"NN"},
"mesocricetus":	{"NN"},
"mesoderm":	{"NN"},
"mesodermal":	{"JJ"},
"mesohippus":	{"NN"},
"mesolithic":	{"NN","JJ"},
"mesomorph":	{"NN"},
"mesomorphic":	{"JJ"},
"mesomorphy":	{"NN"},
"meson":	{"NN"},
"mesonic":	{"JJ"},
"mesophyron":	{"NN"},
"mesophyte":	{"NN"},
"mesophytic":	{"JJ"},
"mesosphere":	{"NN"},
"mesothelioma":	{"NN"},
"mesothelium":	{"NN"},
"mesotron":	{"NN"},
"mesozoic":	{"JJ","NN"},
"mespilus":	{"NN"},
"mesquit":	{"NN"},
"mesquite":	{"NN"},
"mess":	{"NN","VB","VBP"},
"mess-up":	{"NN"},
"message":	{"NN","VB","VBP"},
"messaged":	{"VBD","VBN"},
"messages":	{"NNS","VBZ"},
"messaging":	{"NN","VBG"},
"messed":	{"VBD","VBN"},
"messenger":	{"NN","VB","VBP"},
"messengered":	{"VBD","VBN"},
"messengering":	{"VBG"},
"messengers":	{"NNS","VBZ"},
"messes":	{"NNS","VBZ"},
"messhall":	{"NN"},
"messiah":	{"NN"},
"messiahs":	{"NNS"},
"messiahship":	{"NN"},
"messianic":	{"JJ"},
"messidor":	{"NN"},
"messier":	{"JJR"},
"messiest":	{"JJS"},
"messieurs":	{"NNS"},
"messily":	{"RB"},
"messiness":	{"NN"},
"messing":	{"VBG"},
"messmate":	{"NN"},
"messuage":	{"NN"},
"messy":	{"JJ"},
"mestiza":	{"NN"},
"mestizo":	{"NN"},
"mestizos":	{"NNS"},
"mestranol":	{"NN"},
"mesua":	{"NN"},
"met":	{"VBD","VBN"},
"metabola":	{"NN"},
"metabolic":	{"JJ"},
"metabolically":	{"RB"},
"metabolise":	{"VB","VBP"},
"metabolised":	{"VBD","VBN"},
"metabolises":	{"VBZ"},
"metabolising":	{"VBG"},
"metabolism":	{"NN"},
"metabolisms":	{"NNS"},
"metabolite":	{"NN"},
"metabolites":	{"NNS"},
"metabolize":	{"VB","VBP"},
"metabolized":	{"VBD","VBN"},
"metabolizes":	{"VBZ"},
"metabolizing":	{"VBG"},
"metabolous":	{"JJ"},
"metacarpal":	{"JJ","NN"},
"metacarpi":	{"NNS"},
"metacarpus":	{"NN"},
"metacenter":	{"NN"},
"metacentre":	{"NN"},
"metacentric":	{"JJ"},
"metacyesis":	{"NN"},
"metadata":	{"NNS"},
"metadiscourse":	{"NN"},
"metagenesis":	{"NN"},
"metagenomic":	{"JJ"},
"metagenomics":	{"NN"},
"metagrabolise":	{"VB","VBP"},
"metagrabolised":	{"VBD","VBN","JJ"},
"metagrabolises":	{"VBZ"},
"metagrabolising":	{"VBG"},
"metagrabolize":	{"VB","VBP"},
"metagrabolized":	{"VBD","VBN","JJ"},
"metagrabolizes":	{"VBZ"},
"metagrabolizing":	{"VBG"},
"metagrobolise":	{"VB","VBP"},
"metagrobolised":	{"VBD","VBN"},
"metagrobolises":	{"VBZ"},
"metagrobolising":	{"VBG"},
"metagrobolize":	{"VB","VBP"},
"metagrobolized":	{"VBD","VBN"},
"metagrobolizes":	{"VBZ"},
"metagrobolizing":	{"VBG"},
"metaknowledge":	{"NN"},
"metal":	{"NN","VB","VBP"},
"metal-benders":	{"NNS"},
"metal-cleaning":	{"JJ"},
"metal-coil":	{"JJ"},
"metal-colored":	{"JJ"},
"metal-coloured":	{"JJ"},
"metal-cutting":	{"JJ"},
"metal-forming":	{"JJ"},
"metal-hydrido":	{"NN"},
"metal-looking":	{"JJ"},
"metal-processing":	{"JJ"},
"metal-products":	{"NNS"},
"metal-tasting":	{"JJ"},
"metal-workers":	{"NNS"},
"metal-working":	{"JJ"},
"metalanguage":	{"NN"},
"metalanguages":	{"NNS"},
"metaled":	{"VBD","VBN","JJ"},
"metalepsis":	{"NN"},
"metalhead":	{"NN"},
"metaling":	{"VBG"},
"metalingual":	{"NN"},
"metalization":	{"NN"},
"metalize":	{"VB","VBP"},
"metalized":	{"VBD","VBN"},
"metalizes":	{"VBZ"},
"metalizing":	{"VBG"},
"metalled":	{"VBD","VBN","JJ"},
"metallic":	{"JJ"},
"metallic-colored":	{"JJ"},
"metallic-coloured":	{"JJ"},
"metallic-looking":	{"JJ"},
"metallike":	{"JJ"},
"metalling":	{"VBG"},
"metallisation":	{"NN"},
"metallise":	{"VB","VBP"},
"metallised":	{"VBD","VBN"},
"metallises":	{"VBZ"},
"metallising":	{"VBG"},
"metallization":	{"NN"},
"metallize":	{"VB","VBP"},
"metallized":	{"VBD","VBN"},
"metallizes":	{"VBZ"},
"metallizing":	{"VBG"},
"metalloid":	{"JJ","NN"},
"metallurgic":	{"JJ"},
"metallurgical":	{"JJ"},
"metallurgist":	{"NN"},
"metallurgists":	{"NNS"},
"metallurgy":	{"NN"},
"metals":	{"NNS","VBZ"},
"metals-stock":	{"NN"},
"metalsmith":	{"NN"},
"metalsmiths":	{"NNS"},
"metalware":	{"NN"},
"metalwork":	{"NN"},
"metalworker":	{"NN"},
"metalworkers":	{"NNS"},
"metalworking":	{"NN"},
"metamathematics":	{"NN"},
"metamere":	{"NN"},
"metameric":	{"JJ"},
"metamidophos":	{"NN"},
"metamorphic":	{"JJ"},
"metamorphism":	{"NN"},
"metamorphopsia":	{"NN"},
"metamorphose":	{"VB","VBP"},
"metamorphosed":	{"VBD","VBN"},
"metamorphoses":	{"VBZ","NNS"},
"metamorphosing":	{"VBG"},
"metamorphosis":	{"NN"},
"metamorphous":	{"JJ"},
"metaphase":	{"NN"},
"metaphor":	{"NN"},
"metaphoric":	{"NN"},
"metaphorical":	{"JJ"},
"metaphorically":	{"RB"},
"metaphorise":	{"VB","VBP"},
"metaphorised":	{"VBD","VBN"},
"metaphorises":	{"VBZ"},
"metaphorising":	{"VBG"},
"metaphorist":	{"NN"},
"metaphorists":	{"NNS"},
"metaphorize":	{"VB","VBP"},
"metaphorized":	{"VBD","VBN"},
"metaphorizes":	{"VBZ"},
"metaphorizing":	{"VBG"},
"metaphors":	{"NNS"},
"metaphosphate":	{"NN"},
"metaphysic":	{"NN","JJ"},
"metaphysical":	{"JJ"},
"metaphysically":	{"RB"},
"metaphysics":	{"NN"},
"metaphysis":	{"NN"},
"metapopulation":	{"NN"},
"metapopulations":	{"NNS"},
"metaproterenol":	{"NN"},
"metarule":	{"NN"},
"metasequoia":	{"NN"},
"metastability":	{"NN"},
"metastable":	{"JJ"},
"metastasis":	{"NN"},
"metastasise":	{"VB","VBP"},
"metastasised":	{"VBD","VBN"},
"metastasises":	{"VBZ"},
"metastasising":	{"VBG"},
"metastasize":	{"VB","VBP"},
"metastasized":	{"VBD","VBN"},
"metastasizes":	{"VBZ"},
"metastasizing":	{"VBG"},
"metastatic":	{"JJ"},
"metatarsal":	{"JJ","NN"},
"metatarsi":	{"NNS"},
"metatarsus":	{"NN"},
"metatheria":	{"NN"},
"metatherian":	{"NN"},
"metathesis":	{"NN"},
"metazoa":	{"NN"},
"metazoan":	{"NN"},
"metcalf":	{"NN"},
"metchnikoff":	{"NN"},
"metchnikov":	{"NN"},
"mete":	{"VB","VBP","NN"},
"meted":	{"VBD","VBN"},
"metempsychoses":	{"NNS"},
"metempsychosis":	{"NN"},
"metempsychosist":	{"NN"},
"metencephalon":	{"NN"},
"meteor":	{"NN"},
"meteoric":	{"JJ"},
"meteorically":	{"RB"},
"meteorite":	{"NN"},
"meteorites":	{"NNS"},
"meteoritic":	{"JJ"},
"meteoritical":	{"JJ"},
"meteoroid":	{"NN"},
"meteorologic":	{"JJ"},
"meteorological":	{"JJ"},
"meteorologically":	{"RB"},
"meteorologist":	{"NN"},
"meteorologists":	{"NNS"},
"meteorology":	{"NN"},
"meteors":	{"NNS"},
"meteortropism":	{"NN"},
"meter":	{"NN","VB","VBP"},
"metered":	{"VBN","VBD"},
"metering":	{"VBG"},
"meterological":	{"JJ"},
"meters":	{"NNS","VBZ"},
"meterstick":	{"NN"},
"metes":	{"VBZ"},
"metformin":	{"NN"},
"meth":	{"NN"},
"methacholine":	{"NN"},
"methacrylate":	{"NN"},
"methadon":	{"NN"},
"methadone":	{"NN"},
"methamphetamine":	{"NN"},
"methanal":	{"NN"},
"methane":	{"NN"},
"methanogen":	{"NN"},
"methanol":	{"NN"},
"methanol-gasoline":	{"JJ"},
"methanol-powered":	{"JJ"},
"methapyrilene":	{"NN"},
"methaqualone":	{"NN"},
"metharbital":	{"NN"},
"methedrine":	{"NN"},
"metheglin":	{"NN"},
"methenamine":	{"NN"},
"methicillin":	{"NN"},
"methionine":	{"NN"},
"methocarbamol":	{"NN"},
"method":	{"NN"},
"methodical":	{"JJ"},
"methodically":	{"RB"},
"methodicalness":	{"NN"},
"methodism":	{"NN"},
"methodists":	{"NNS"},
"methodological":	{"JJ"},
"methodologically":	{"RB"},
"methodologies":	{"NNS"},
"methodology":	{"NN"},
"methods":	{"NNS"},
"methotrexate":	{"NN"},
"methyl":	{"NN"},
"methylate":	{"VB","VBP"},
"methylated":	{"VBD","VBN"},
"methylates":	{"VBZ"},
"methylating":	{"VBG"},
"methylation":	{"NN"},
"methylator":	{"NN"},
"methylbenzene":	{"NN"},
"methyldopa":	{"NN"},
"methylene":	{"NN"},
"methylenedioxymethamphetamine":	{"NN"},
"methylglyoxal":	{"NN"},
"methylphenidate":	{"NN"},
"methyltestosterone":	{"NN"},
"metic":	{"NN"},
"metical":	{"NN"},
"meticorten":	{"NN"},
"meticulosity":	{"NN"},
"meticulous":	{"JJ"},
"meticulously":	{"RB"},
"meticulousness":	{"NN"},
"metier":	{"NN"},
"metiers":	{"NNS"},
"meting":	{"VBG"},
"metis":	{"NN"},
"metonym":	{"NN"},
"metonymic":	{"JJ"},
"metonymical":	{"JJ"},
"metonymically":	{"RB"},
"metonymy":	{"NN"},
"metopion":	{"NN"},
"metoprolol":	{"NN"},
"metralgia":	{"NN"},
"metrazol":	{"NN"},
"metre":	{"NN"},
"metres":	{"NNS"},
"metrestick":	{"NN"},
"metric":	{"JJ"},
"metrical":	{"JJ"},
"metrically":	{"RB"},
"metricate":	{"VB","VBP"},
"metricated":	{"VBD","VBN"},
"metricates":	{"VBZ"},
"metricating":	{"VBG"},
"metrication":	{"NN"},
"metricise":	{"VB","VBP"},
"metricize":	{"VB","VBP"},
"metrics":	{"NN"},
"metrification":	{"NN"},
"metrified":	{"VBD","VBN"},
"metrifies":	{"VBZ"},
"metrify":	{"VB","VBP"},
"metrifying":	{"VBG"},
"metritis":	{"NN"},
"metro":	{"NN"},
"metrological":	{"JJ"},
"metrology":	{"NN"},
"metronidazole":	{"NN"},
"metronome":	{"NN"},
"metronomes":	{"NNS"},
"metronymic":	{"NN"},
"metropolis":	{"NN"},
"metropolises":	{"NNS"},
"metropolitan":	{"JJ"},
"metropolitanization":	{"NN"},
"metroptosis":	{"NN"},
"metrorrhagia":	{"NN"},
"metros":	{"NNS"},
"metroxylon":	{"NN"},
"metternich":	{"NN"},
"mettle":	{"NN"},
"mettlesome":	{"JJ"},
"mettlesomeness":	{"NN"},
"mettwurst":	{"NN"},
"metycaine":	{"NN"},
"meuron":	{"FW"},
"meuse":	{"NN"},
"meuse-argonne":	{"NN"},
"mevacor":	{"NN"},
"mevalotin":	{"NN"},
"mew":	{"NN","VB","VBP"},
"mewed":	{"VBD","VBN"},
"mewing":	{"VBG"},
"mewl":	{"VB","VBP","NN"},
"mewled":	{"VBD","VBN"},
"mewler":	{"NN"},
"mewling":	{"VBG"},
"mewls":	{"VBZ"},
"mews":	{"NNS","VBZ"},
"mexicali":	{"NN"},
"mexican-american":	{"NN"},
"mexican-food":	{"JJ"},
"mexicano":	{"NN"},
"mexico-based":	{"JJ"},
"mexico-watchers":	{"NNS"},
"mexiletine":	{"NN"},
"mexitil":	{"NN"},
"meyerbeer":	{"NN"},
"meyerhof":	{"NN"},
"mezcal":	{"NN"},
"mezereon":	{"NN"},
"mezereum":	{"NN"},
"mezuza":	{"NN"},
"mezuzah":	{"NN"},
"mezzanine":	{"NN"},
"mezzanines":	{"NNS"},
"mezzo":	{"RB","NN"},
"mezzo-relievo":	{"NN"},
"mezzo-rilievo":	{"NN"},
"mezzo-soprano":	{"NN"},
"mezzo-sopranos":	{"NNS"},
"mezzos":	{"NNS"},
"mezzotint":	{"NN"},
"mezzotints":	{"NNS"},
"mflop":	{"NN"},
"mg":	{"NN","NNS"},
"mgs":	{"NNS"},
"mho":	{"NN"},
"mhz":	{"NN"},
"mi":	{"NN"},
"miami-based":	{"JJ"},
"miao":	{"NN"},
"miaou":	{"VB","VBP","UH"},
"miaow":	{"NN","VB","VBP"},
"miaowed":	{"VBD","VBN"},
"miaowing":	{"VBG"},
"miaows":	{"NNS","VBZ"},
"miasm":	{"NN"},
"miasma":	{"NN"},
"miasmal":	{"JJ"},
"miasmas":	{"NNS"},
"miasmic":	{"JJ"},
"miaul":	{"NN"},
"mib":	{"NN"},
"mibit":	{"NN"},
"mica":	{"NN"},
"micaceous":	{"JJ"},
"mice":	{"NNS"},
"micelle":	{"NN"},
"micelles":	{"NNS"},
"michaelmastide":	{"NN"},
"micheas":	{"NN"},
"michelangelesque":	{"JJ"},
"michele":	{"NN"},
"michelin":	{"NN"},
"michelson":	{"NN"},
"michener":	{"NN"},
"michigan-based":	{"JJ"},
"mick":	{"NN"},
"mickey":	{"NN"},
"mickle":	{"NN","JJ","RB"},
"micks":	{"NNS"},
"micmac":	{"NN"},
"miconazole":	{"NN"},
"micro":	{"JJ","NN"},
"micro-blog":	{"NN"},
"micro-cook":	{"VB","VBP"},
"micro-electronic":	{"JJ"},
"micro-liquidity":	{"NN"},
"micro-microcurie":	{"NN"},
"micro-organism":	{"NN"},
"micro-organisms":	{"NNS"},
"microaggression":	{"NN"},
"microaggressions":	{"NNS"},
"microanalysis":	{"NN"},
"microbalance":	{"NN"},
"microbar":	{"NN"},
"microbat":	{"NN"},
"microbe":	{"NN"},
"microbes":	{"NNS"},
"microbial":	{"JJ"},
"microbic":	{"JJ"},
"microbiological":	{"JJ"},
"microbiologist":	{"NN"},
"microbiologists":	{"NNS"},
"microbiology":	{"NN"},
"microbiome":	{"NN"},
"microbiomes":	{"NNS"},
"microblog":	{"NN"},
"microblogger":	{"NN"},
"microblogging":	{"NN"},
"microbrachia":	{"NN"},
"microbreweries":	{"NNS"},
"microbrewery":	{"NN"},
"microcassette":	{"NN"},
"microcentrum":	{"NN"},
"microcephalic":	{"JJ"},
"microcephalous":	{"JJ"},
"microcephalus":	{"NN"},
"microcephaly":	{"NN"},
"microchannel":	{"JJ"},
"microchemistry":	{"NN"},
"microchip":	{"NN"},
"microchips":	{"NNS"},
"microchiroptera":	{"NN"},
"microcircuit":	{"NN"},
"microcircuits":	{"NNS"},
"micrococcaceae":	{"NN"},
"micrococcus":	{"NN"},
"microcode":	{"NN"},
"microcomputer":	{"NN"},
"microcomputer-systems":	{"JJ"},
"microcomputers":	{"NNS"},
"microcontroller":	{"NN"},
"microcopies":	{"NNS"},
"microcopy":	{"NN"},
"microcosm":	{"NN"},
"microcosmic":	{"JJ"},
"microcosms":	{"NNS"},
"microcredit":	{"NN"},
"microcrystalline":	{"JJ"},
"microcyte":	{"NN"},
"microcytochemistry":	{"NN"},
"microcytosis":	{"NN"},
"microdesmidae":	{"NN"},
"microdipodops":	{"NN"},
"microdot":	{"NN"},
"microdots":	{"NNS"},
"microeconomic":	{"JJ"},
"microeconomics":	{"NN"},
"microeconomist":	{"NN"},
"microeconomy":	{"NN"},
"microelectronic":	{"JJ"},
"microelectronics":	{"NN"},
"microenvironment":	{"NN"},
"microenvironments":	{"NNS"},
"microevolution":	{"NN"},
"microfarad":	{"NN"},
"microfiche":	{"NN"},
"microfiches":	{"NNS"},
"microfilm":	{"NN","VB","VBP"},
"microfilmed":	{"VBD","VBN"},
"microfilming":	{"VBG"},
"microfilms":	{"NNS","VBZ"},
"microfinance":	{"NN"},
"microflora":	{"NN"},
"microfossil":	{"NN"},
"microfossils":	{"NNS"},
"microgametophyte":	{"NN"},
"microgauss":	{"NN"},
"microglia":	{"NN"},
"microgliacyte":	{"NN"},
"microglial":	{"JJ"},
"microgram":	{"NN"},
"microgramma":	{"NN"},
"microgramma-piloselloides":	{"NNS"},
"micrograms":	{"NNS"},
"micrographics":	{"NN"},
"microgrid":	{"NN"},
"microhistories":	{"NNS"},
"microhistory":	{"NN"},
"microhylidae":	{"NN"},
"microinjection":	{"NN"},
"micromanage":	{"VB","VBP"},
"micromanaged":	{"VBD","VBN"},
"micromanagement":	{"NN"},
"micromanages":	{"VBZ"},
"micromanaging":	{"VBG"},
"micromeria":	{"NN"},
"micrometeor":	{"NN"},
"micrometeoric":	{"JJ"},
"micrometeorite":	{"NN"},
"micrometeorites":	{"NNS"},
"micrometeoritic":	{"JJ"},
"micrometeoroid":	{"NN"},
"micrometer":	{"NN"},
"micrometers":	{"NNS"},
"micrometry":	{"NN"},
"micromicron":	{"NN"},
"micromillimeter":	{"NN"},
"micromillimetre":	{"NN"},
"micromyx":	{"NN"},
"micron":	{"NN"},
"micronase":	{"NN"},
"micronite":	{"NN"},
"micronor":	{"NN"},
"microns":	{"NNS"},
"micronutrient":	{"NN"},
"microorganism":	{"NN"},
"microorganisms":	{"NNS"},
"micropaleontology":	{"NN"},
"micropenis":	{"NN"},
"microphage":	{"NN"},
"microphallus":	{"NN"},
"microphone":	{"NN"},
"microphones":	{"NNS"},
"microphoning":	{"NN"},
"microphotometer":	{"NN"},
"microplastic":	{"NN"},
"micropogonias":	{"NN"},
"microprocessor":	{"NN"},
"microprocessor-based":	{"JJ"},
"microprocessors":	{"NNS"},
"micropterus":	{"NN"},
"micropylar":	{"JJ"},
"micropyle":	{"NN"},
"microradian":	{"NN"},
"micros":	{"NNS"},
"microscope":	{"NN"},
"microscopes":	{"NNS"},
"microscopic":	{"JJ"},
"microscopical":	{"JJ"},
"microscopically":	{"RB"},
"microscopist":	{"NN"},
"microscopists":	{"NNS"},
"microscopium":	{"NN"},
"microscopy":	{"NN"},
"microsecond":	{"NN"},
"microseconds":	{"NNS"},
"microseism":	{"NN"},
"microsomal":	{"JJ"},
"microsome":	{"NN"},
"microsorium":	{"NN"},
"microsphere":	{"NN"},
"microspheres":	{"NNS"},
"microsporangium":	{"NN"},
"microspore":	{"NN"},
"microsporidian":	{"NN"},
"microsporophyll":	{"NN"},
"microsporum":	{"NN"},
"microstomus":	{"NN"},
"microstrobos":	{"NN"},
"microsurgery":	{"NN"},
"microtaggant":	{"NN"},
"microtome":	{"NN"},
"microtonal":	{"JJ"},
"microtubule":	{"NN"},
"microtus":	{"NN"},
"microunit":	{"NN"},
"microunits":	{"NNS"},
"microvan":	{"NN"},
"microvolt":	{"NN"},
"microwaevable":	{"JJ"},
"microwavable":	{"JJ"},
"microwave":	{"NN","VB","VBP"},
"microwaved":	{"VBD","VBN"},
"microwaves":	{"NNS","VBZ"},
"microwaving":	{"VBG"},
"microzide":	{"NN"},
"micruroides":	{"NN"},
"micrurus":	{"NN"},
"micturate":	{"VB","VBP"},
"micturated":	{"VBD","VBN"},
"micturates":	{"VBZ"},
"micturating":	{"VBG"},
"micturition":	{"NN"},
"mid":	{"JJ","IN"},
"mid-April":	{"NN"},
"mid-Atlantic":	{"JJ"},
"mid-July":	{"NN"},
"mid-air":	{"NN"},
"mid-april":	{"NN"},
"mid-autumn":	{"NN","JJ","RB"},
"mid-autumns":	{"NNS"},
"mid-calf":	{"NN"},
"mid-century":	{"JJ"},
"mid-conversation":	{"NN"},
"mid-december":	{"NN"},
"mid-eighties":	{"NN"},
"mid-engine":	{"JJ"},
"mid-february":	{"NN"},
"mid-fifties":	{"NN"},
"mid-flight":	{"JJ","RB","NN"},
"mid-forties":	{"NN"},
"mid-january":	{"NN"},
"mid-july":	{"NN"},
"mid-june":	{"NN"},
"mid-market":	{"JJ"},
"mid-may":	{"NN"},
"mid-morning":	{"NN"},
"mid-nineties":	{"NN"},
"mid-november":	{"NN"},
"mid-october":	{"NN"},
"mid-off":	{"NN"},
"mid-on":	{"NN"},
"mid-priced":	{"JJ"},
"mid-range":	{"JJ","NN"},
"mid-ranges":	{"NNS"},
"mid-season":	{"NN","JJ","RB"},
"mid-section":	{"NN"},
"mid-september":	{"NN"},
"mid-seventies":	{"NN"},
"mid-shimmy":	{"NN"},
"mid-sixties":	{"NN"},
"mid-size":	{"JJ"},
"mid-sized":	{"JJ"},
"mid-term":	{"JJ"},
"mid-thirties":	{"NN"},
"mid-to-high":	{"JJ"},
"mid-to-late":	{"JJ"},
"mid-twenties":	{"NN"},
"mid-twentieth":	{"JJ"},
"mid-twentieth-century":	{"JJ"},
"mid-watch":	{"JJ"},
"mid-water":	{"NN"},
"mid-way":	{"NN","RB","JJ"},
"mid-week":	{"JJ","NN"},
"midafternoon":	{"NN"},
"midair":	{"NN","JJ"},
"midazolam":	{"NN"},
"midbrain":	{"NN"},
"midcapitalization":	{"NN"},
"midcontinent":	{"JJ"},
"midcourt":	{"NN"},
"midday":	{"NN"},
"midden":	{"NN"},
"middens":	{"NNS"},
"middle":	{"NN","JJ","VB","VBP"},
"middle-Gaelic":	{"JJ"},
"middle-age":	{"JJ","NN"},
"middle-aged":	{"JJ","NNS"},
"middle-brow":	{"JJ"},
"middle-class":	{"JJ","NN"},
"middle-eastern":	{"JJ"},
"middle-gaelic":	{"JJ"},
"middle-ground":	{"JJ"},
"middle-income":	{"JJ","NN"},
"middle-level":	{"JJ"},
"middle-management":	{"JJ"},
"middle-market":	{"JJ"},
"middle-of-the-road":	{"JJ"},
"middle-of-the-roaders":	{"NNS"},
"middle-priced":	{"JJ"},
"middle-range":	{"JJ"},
"middle-school":	{"JJ","NN"},
"middle-sized":	{"JJ"},
"middlebreaker":	{"NN"},
"middlebrow":	{"NN","JJ"},
"middled":	{"VBD","VBN"},
"middleman":	{"NN"},
"middlemen":	{"NNS"},
"middlemost":	{"JJ"},
"middleness":	{"NN"},
"middles":	{"NNS","VBZ"},
"middleweight":	{"NN"},
"middleweights":	{"NNS"},
"middling":	{"JJ","RB","NN","VBG"},
"middy":	{"NN"},
"midfield":	{"NN"},
"midfielder":	{"NN"},
"midfielders":	{"NNS"},
"midgard":	{"NN"},
"midge":	{"NN"},
"midges":	{"NNS"},
"midget":	{"NN","JJ"},
"midgets":	{"NNS"},
"midgrass":	{"NN"},
"midi":	{"JJ","NN"},
"midi-pyrenees":	{"NNS"},
"midinette":	{"NN"},
"midiron":	{"NN"},
"midlevel":	{"JJ"},
"midlife":	{"NN","JJ"},
"midline":	{"NN"},
"midmonth":	{"RB"},
"midmorning":	{"NN"},
"midmost":	{"JJ","RB"},
"midnight":	{"NN"},
"midocean":	{"NN"},
"midplane":	{"NN"},
"midpoint":	{"NN"},
"midpriced":	{"JJ"},
"midrange":	{"NN","JJ"},
"midranges":	{"NNS"},
"midrash":	{"NN"},
"midrib":	{"NN"},
"midriff":	{"NN"},
"midriffs":	{"NNS"},
"midseason":	{"NN","JJ","RB"},
"midsection":	{"NN"},
"midsemester":	{"NN"},
"midsession":	{"NN"},
"midshipman":	{"NN"},
"midshipmen":	{"NNS"},
"midships":	{"RB"},
"midsize":	{"JJ"},
"midsized":	{"JJ"},
"midsized-car":	{"JJ","NN"},
"midst":	{"NN","IN"},
"midstream":	{"NN","RB"},
"midsummer":	{"NN"},
"midsummer-men":	{"NN"},
"midterm":	{"JJ","NN"},
"midterms":	{"NNS"},
"midtown":	{"NN","JJ","RB"},
"midvein":	{"NN"},
"midwatch":	{"NN"},
"midway":	{"NN","RB","JJ"},
"midweek":	{"NN","JJ","RB"},
"midweekly":	{"JJ"},
"midwife":	{"NN","VB","VBP"},
"midwifed":	{"VBD","VBN"},
"midwifery":	{"NN"},
"midwifes":	{"VBZ"},
"midwifing":	{"VBG"},
"midwinter":	{"NN"},
"midwived":	{"VBD","VBN"},
"midwives":	{"VBZ","NNS"},
"midwiving":	{"VBG"},
"midyear":	{"NN","JJ"},
"mien":	{"NN"},
"mierkat":	{"NN"},
"miert":	{"NN"},
"mifepristone":	{"NN"},
"miff":	{"NN","VB","VBP"},
"miffed":	{"VBD","VBN","JJ"},
"miffing":	{"VBG"},
"miffs":	{"NNS","VBZ"},
"might":	{"MD","NN"},
"might-have-been":	{"NN"},
"mightier":	{"JJR"},
"mightiest":	{"JJS"},
"mightily":	{"RB"},
"mightiness":	{"NN"},
"mighty":	{"JJ","RB"},
"migi":	{"FW"},
"mignon":	{"JJ","NN"},
"mignonette":	{"NN","JJ"},
"migraine":	{"NN"},
"migraines":	{"NNS"},
"migrant":	{"JJ","NN"},
"migrants":	{"NNS"},
"migrate":	{"VB","VBP"},
"migrated":	{"VBD","VBN"},
"migrates":	{"VBZ"},
"migrating":	{"VBG"},
"migration":	{"NN"},
"migrational":	{"JJ"},
"migrations":	{"NNS"},
"migrator":	{"NN"},
"migratory":	{"JJ"},
"mihrab":	{"NN"},
"mikado":	{"NN"},
"mikados":	{"NNS"},
"mikania":	{"NN"},
"mike":	{"NN","VB","VBP"},
"miked":	{"VBD","VBN"},
"mikes":	{"NNS","VBZ"},
"miking":	{"VBG"},
"mikir-meithei":	{"NN"},
"mikmaq":	{"NN"},
"mikvah":	{"NN"},
"mil":	{"NN"},
"milady":	{"NN"},
"milage":	{"NN"},
"milan-based":	{"JJ"},
"milano":	{"NN"},
"milch":	{"JJ"},
"milcher":	{"NN"},
"mild":	{"JJ","NN"},
"mild-mannered":	{"JJ"},
"mild-tasting":	{"JJ"},
"mild-voiced":	{"JJ"},
"mild-winter":	{"JJ"},
"milder":	{"JJR"},
"mildest":	{"JJS"},
"mildew":	{"NN","VB","VBP"},
"mildewed":	{"VBD","VBN","JJ"},
"mildewing":	{"VBG"},
"mildews":	{"VBZ"},
"mildewy":	{"JJ"},
"mildly":	{"RB"},
"mildness":	{"NN"},
"mile":	{"NN"},
"mile-long":	{"JJ"},
"mileage":	{"NN"},
"mileage-based":	{"JJ"},
"mileometer":	{"NN"},
"mileometers":	{"NNS"},
"milepost":	{"NN"},
"mileposts":	{"NNS"},
"miler":	{"NN"},
"milers":	{"NNS"},
"miles":	{"NNS"},
"miles-per-hour":	{"JJ"},
"milestone":	{"NN"},
"milestones":	{"NNS"},
"milfoil":	{"NN"},
"milhaud":	{"NN"},
"miliaria":	{"NN"},
"miliaris":	{"NN"},
"milieu":	{"NN"},
"milieus":	{"NNS"},
"milieux":	{"NNS"},
"milion":	{"NN"},
"militainment":	{"NN"},
"militance":	{"NN"},
"militancy":	{"NN"},
"militant":	{"JJ","NN"},
"militantly":	{"RB"},
"militants":	{"NNS"},
"militarily":	{"RB"},
"militarisation":	{"NN"},
"militarise":	{"VB","VBP"},
"militarised":	{"JJ","VBD","VBN"},
"militarises":	{"VBZ"},
"militarising":	{"VBG"},
"militarism":	{"NN"},
"militarist":	{"NN","JJ"},
"militaristic":	{"JJ"},
"militarists":	{"NNS"},
"militarization":	{"NN"},
"militarize":	{"VB","VBP"},
"militarized":	{"VBD","VBN","JJ"},
"militarizes":	{"VBZ"},
"militarizing":	{"VBG"},
"military":	{"JJ","NN"},
"military-electronics":	{"NNS"},
"military-medical":	{"JJ"},
"military-service":	{"JJ"},
"military-spending":	{"NN"},
"military-style":	{"JJ"},
"militate":	{"VB","VBP"},
"militated":	{"VBD","VBN"},
"militates":	{"VBZ"},
"militating":	{"VBG"},
"militia":	{"NN"},
"militiaman":	{"NN"},
"militiamen":	{"NNS"},
"militias":	{"NNS"},
"milium":	{"NN"},
"milk":	{"NN","VB","VBP"},
"milk-chocolate":	{"JJ"},
"milk-float":	{"NN"},
"milk-loaf":	{"NN"},
"milk-loaves":	{"NNS"},
"milk-sick":	{"JJ"},
"milk-supply":	{"NN"},
"milk-teeth":	{"NNS"},
"milk-tooth":	{"NN"},
"milk-vetch":	{"NN"},
"milk-white":	{"JJ"},
"milkcap":	{"NN"},
"milked":	{"VBD","VBN"},
"milker":	{"NN"},
"milkers":	{"NNS"},
"milkier":	{"JJR"},
"milkiest":	{"JJS"},
"milking":	{"NN","VBG"},
"milkless":	{"JJ"},
"milklike":	{"JJ"},
"milkmaid":	{"NN"},
"milkmaids":	{"NNS"},
"milkman":	{"NN"},
"milkmen":	{"NNS"},
"milks":	{"NNS","VBZ"},
"milkshake":	{"NN"},
"milkshakes":	{"NNS"},
"milksop":	{"NN"},
"milkwagon":	{"NN"},
"milkweed":	{"NN"},
"milkwort":	{"NN"},
"milky":	{"JJ"},
"mill":	{"NN","VB","VBP"},
"mill-dam":	{"NN"},
"mill-girl":	{"NN"},
"mill-hand":	{"NN"},
"mill-pond":	{"NN"},
"mill-race":	{"NN"},
"mill-wheel":	{"NN"},
"millage":	{"NN","JJ"},
"millay":	{"NN"},
"millboard":	{"NN"},
"millboards":	{"NNS"},
"milldam":	{"NN"},
"milldams":	{"NNS"},
"milled":	{"JJ","VBD","VBN"},
"millenarian":	{"JJ","NN"},
"millenarianism":	{"NN"},
"millenarians":	{"NNS"},
"millenarism":	{"NN"},
"millenarist":	{"NN"},
"millenary":	{"NN","JJ"},
"millennia":	{"NNS"},
"millennial":	{"JJ"},
"millennian":	{"JJ"},
"millennium":	{"NN"},
"millenniumism":	{"NN"},
"millenniums":	{"NNS"},
"millepede":	{"NN"},
"miller":	{"NN"},
"miller's-thumb":	{"NN"},
"millerite":	{"NN"},
"millers":	{"NNS"},
"millet":	{"NN"},
"millets":	{"NNS"},
"millettia":	{"NN"},
"milliammeter":	{"NN"},
"milliampere":	{"NN"},
"milliamperes":	{"NNS"},
"milliard":	{"NN"},
"millibar":	{"NN"},
"millicurie":	{"NN"},
"millidegree":	{"NN"},
"millidegrees":	{"NNS"},
"milliequivalent":	{"NN"},
"millifarad":	{"NN"},
"milligram":	{"NN"},
"milligrams":	{"NNS"},
"millihenry":	{"NN"},
"millikan":	{"NN"},
"milliliter":	{"NN"},
"milliliters":	{"NNS"},
"millilitre":	{"NN"},
"millilitres":	{"NNS"},
"millilon":	{"NN"},
"millime":	{"NN"},
"millimeter":	{"NN"},
"millimeters":	{"NNS"},
"millimetre":	{"NN"},
"millimetres":	{"NNS"},
"millimicron":	{"NN"},
"milline":	{"NN"},
"milliner":	{"NN"},
"milliners":	{"NNS"},
"millinery":	{"NN"},
"milling":	{"NN","VBG"},
"million":	{"NN","CD"},
"million-and-counting":	{"JJ"},
"million-asset":	{"JJ"},
"million-common":	{"NN"},
"million-dollar":	{"JJ"},
"million-dollar-plus":	{"JJ"},
"million-franc":	{"JJ"},
"million-gallon":	{"JJ"},
"million-mark":	{"JJ"},
"million-member":	{"JJ"},
"million-plus":	{"JJ","NNS","NN"},
"million-pound":	{"JJ","NN"},
"million-share":	{"JJ","NN"},
"million-square-foot":	{"JJ"},
"million-ton":	{"JJ"},
"million-unit":	{"JJ"},
"millionaire":	{"NN"},
"millionaires":	{"NNS"},
"millionairess":	{"NN"},
"millionairesses":	{"NNS"},
"millionfold":	{"JJ","RB"},
"millions":	{"NNS"},
"millionth":	{"NN","JJ"},
"millionths-of-a-second":	{"JJ"},
"milliped":	{"NN"},
"millipede":	{"NN"},
"millipedes":	{"NNS"},
"milliradian":	{"NN"},
"millisecond":	{"NN"},
"milliseconds":	{"NNS"},
"millisievert":	{"NN"},
"millisieverts":	{"NNS"},
"millivolt":	{"NN"},
"millivoltmeter":	{"NN"},
"milliwatt":	{"NN"},
"millon":	{"FW"},
"millones":	{"FW"},
"millpond":	{"NN"},
"millponds":	{"NNS"},
"millrace":	{"NN"},
"millrun":	{"NN"},
"mills":	{"NNS","VBZ"},
"millstone":	{"NN"},
"millstones":	{"NNS"},
"millwheel":	{"NN"},
"millwheels":	{"NNS"},
"millwork":	{"NN"},
"millwright":	{"NN"},
"milo":	{"NN"},
"milometer":	{"NN"},
"milontin":	{"NN"},
"milord":	{"NN"},
"milquetoast":	{"NN"},
"milquetoasts":	{"NNS"},
"milt":	{"NN","VB","VBP"},
"milted":	{"VBD","VBN"},
"milting":	{"VBG"},
"miltomate":	{"NN"},
"miltonia":	{"NN"},
"miltonic":	{"JJ"},
"miltown":	{"NN"},
"milts":	{"NNS","VBZ"},
"milvus":	{"NN"},
"milwaukee-based":	{"JJ"},
"mimamsa":	{"NN"},
"mime":	{"NN","VB","VBP"},
"mimed":	{"VBD","VBN"},
"mimeo":	{"NN","VB","VBP"},
"mimeoed":	{"VBD","VBN"},
"mimeograph":	{"NN","VB","VBP"},
"mimeographed":	{"VBD","VBN"},
"mimeographing":	{"VBG"},
"mimeographs":	{"NNS","VBZ"},
"mimeoing":	{"VBG"},
"mimeos":	{"NNS","VBZ"},
"mimer":	{"NN"},
"mimes":	{"NNS","VBZ"},
"mimesis":	{"NN"},
"mimetic":	{"JJ"},
"mimetically":	{"RB"},
"mimic":	{"VB","VBP","NN","JJ"},
"mimicked":	{"VBN","VBD"},
"mimicker":	{"NN"},
"mimicking":	{"NN","VBG"},
"mimicry":	{"NN"},
"mimics":	{"VBZ","NNS"},
"mimidae":	{"NN"},
"mimimum":	{"NN"},
"miming":	{"VBG"},
"mimir":	{"NN"},
"mimosa":	{"NN"},
"mimosaceae":	{"NN"},
"mimosas":	{"NNS"},
"mimosoideae":	{"NN"},
"mimus":	{"NN"},
"min":	{"NN","NNS"},
"min.":	{"NN","NNS"},
"mina":	{"NN"},
"minaces":	{"FW"},
"minacious":	{"JJ"},
"minah":	{"NN"},
"minaret":	{"NN"},
"minarets":	{"NNS"},
"minatory":	{"JJ"},
"minber":	{"NN"},
"mince":	{"VB","VBP","NN"},
"minced":	{"VBD","VBN"},
"mincemeat":	{"NN"},
"mincer":	{"NN"},
"mincers":	{"NNS"},
"minces":	{"VBZ"},
"mincing":	{"JJ","VBG"},
"mincingly":	{"RB"},
"mind":	{"NN","VB","VBP"},
"mind-altering":	{"JJ"},
"mind-bending":	{"JJ"},
"mind-blowing":	{"JJ"},
"mind-boggling":	{"JJ"},
"mind-bogglingly":	{"RB"},
"mind-expanding":	{"JJ"},
"mind-numbing":	{"JJ"},
"mind-numbingly":	{"RB"},
"mind-reader":	{"NN"},
"mind-readers":	{"NNS"},
"mind-reading":	{"NN"},
"mind-set":	{"NN"},
"mind-sets":	{"NNS"},
"mindanao":	{"NN"},
"minded":	{"JJ","VBD","VBN"},
"minden":	{"NN"},
"minder":	{"NN"},
"minders":	{"NNS"},
"mindful":	{"JJ"},
"mindfully":	{"RB"},
"mindfulness":	{"NN"},
"minding":	{"VBG"},
"mindless":	{"JJ"},
"mindlessly":	{"RB"},
"mindlessness":	{"NN"},
"mindoro":	{"NN"},
"minds":	{"NNS","VBZ"},
"mindset":	{"NN"},
"mindsets":	{"NNS"},
"mine":	{"NN","PRP","VBP","VB"},
"mine-hunting":	{"JJ"},
"mine-safety":	{"JJ"},
"mined":	{"JJ","VBD","VBN"},
"minefield":	{"NN"},
"minefields":	{"NNS"},
"minehunter":	{"NN"},
"minelayer":	{"NN"},
"minelaying":	{"NN"},
"miner":	{"NN"},
"mineral":	{"NN"},
"mineral-rich":	{"JJ"},
"mineralisation":	{"NN"},
"mineralise":	{"VB","VBP"},
"mineralised":	{"VBD","VBN","JJ"},
"mineralises":	{"VBZ"},
"mineralising":	{"VBG"},
"mineralization":	{"NN"},
"mineralize":	{"VB","VBP"},
"mineralized":	{"VBD","VBN","JJ"},
"mineralizes":	{"VBZ"},
"mineralizing":	{"VBG"},
"mineralocorticoid":	{"NN"},
"mineralogical":	{"JJ"},
"mineralogist":	{"NN"},
"mineralogists":	{"NNS"},
"mineralogy":	{"NN"},
"minerals":	{"NNS"},
"miners":	{"NNS"},
"minerva":	{"NN"},
"mines":	{"NNS","VBZ"},
"mineshaft":	{"NN"},
"mineshafts":	{"NNS"},
"minestrone":	{"NN"},
"minesweeper":	{"NN"},
"minesweepers":	{"NNS"},
"minesweeping":	{"NN"},
"mineworker":	{"NN"},
"mineworkers":	{"NNS"},
"minge":	{"NN"},
"mingier":	{"JJR"},
"mingiest":	{"JJS"},
"minginess":	{"NN"},
"mingle":	{"VB","VBP"},
"mingle-mangle":	{"NN"},
"mingled":	{"VBD","VBN"},
"mingles":	{"VBZ"},
"mingling":	{"VBG"},
"mingy":	{"JJ"},
"mini":	{"NN"},
"mini-cars":	{"NNS"},
"mini-component":	{"JJ"},
"mini-doll":	{"NN"},
"mini-empire":	{"NN"},
"mini-fiestas":	{"NNS"},
"mini-flap":	{"NN"},
"mini-mafia":	{"NN"},
"mini-mill":	{"NN"},
"mini-post":	{"JJ"},
"mini-revolution":	{"NN"},
"mini-saga":	{"NN"},
"mini-series":	{"NN","NNS"},
"mini-slip":	{"NN"},
"mini-studio":	{"NN"},
"mini-supercomputers":	{"NNS"},
"mini-vans":	{"NNS"},
"miniate":	{"VB","VBP"},
"miniature":	{"JJ","NN"},
"miniatures":	{"NNS"},
"miniaturisation":	{"NN"},
"miniaturise":	{"VB","VBP"},
"miniaturised":	{"VBD","VBN","JJ"},
"miniaturises":	{"VBZ"},
"miniaturising":	{"VBG"},
"miniaturist":	{"NN"},
"miniaturists":	{"NNS"},
"miniaturization":	{"NN"},
"miniaturize":	{"VB","VBP"},
"miniaturized":	{"VBD","VBN","JJ"},
"miniaturizes":	{"VBZ"},
"miniaturizing":	{"VBG"},
"minibar":	{"NN"},
"minibars":	{"NNS"},
"minibike":	{"NN"},
"minibus":	{"NN"},
"minibuses":	{"NNS"},
"minicab":	{"NN"},
"minicabs":	{"NNS"},
"minicamp":	{"NN"},
"minicar":	{"NN"},
"minicars":	{"NNS"},
"minicomputer":	{"NN"},
"minicomputers":	{"NNS"},
"miniconju":	{"NN"},
"minicrash":	{"NN"},
"minification":	{"NN"},
"minified":	{"VBD","VBN"},
"minifies":	{"VBZ"},
"minify":	{"VB","VBP"},
"minifying":	{"VBG"},
"minim":	{"NN"},
"minima":	{"NNS"},
"minimal":	{"JJ"},
"minimalism":	{"NN"},
"minimalist":	{"NN","JJ"},
"minimalists":	{"NNS"},
"minimally":	{"RB"},
"minimi":	{"NNS"},
"minimill":	{"NN"},
"minimills":	{"NNS"},
"minimisation":	{"NN"},
"minimise":	{"VB","VBP"},
"minimised":	{"VBD","VBN"},
"minimises":	{"VBZ"},
"minimising":	{"VBG"},
"minimization":	{"NN"},
"minimize":	{"VB","VBP"},
"minimized":	{"VBD","VBN"},
"minimizes":	{"VBZ"},
"minimizing":	{"VBG"},
"minims":	{"NNS"},
"minimum":	{"NN","JJ","RB"},
"minimum-capital":	{"JJ"},
"minimum-fee":	{"JJ"},
"minimum-tax":	{"NN"},
"minimum-wage":	{"NN"},
"minimums":	{"NNS"},
"minimun":	{"NN"},
"minimus":	{"NN","JJ"},
"mining":	{"NN","VBG"},
"mininum-wage":	{"NN"},
"minion":	{"NN"},
"minions":	{"NNS"},
"minipress":	{"NN"},
"minis":	{"NNS"},
"miniscule":	{"JJ"},
"miniseries":	{"NN","NNS"},
"miniskirt":	{"NN"},
"miniskirts":	{"NNS"},
"minister":	{"NN","VB","VBP"},
"ministered":	{"VBD","VBN"},
"ministerial":	{"JJ"},
"ministerially":	{"RB"},
"ministering":	{"VBG"},
"ministers":	{"NNS","VBZ"},
"ministrant":	{"JJ","NN"},
"ministration":	{"NN"},
"ministrations":	{"NNS"},
"ministries":	{"NNS"},
"ministry":	{"NN"},
"minisub":	{"NN"},
"minisubmarine":	{"NN"},
"minisupercomputers":	{"NNS"},
"minitruck":	{"NN"},
"minium":	{"NN"},
"minivan":	{"NN"},
"minivans":	{"NNS"},
"miniver":	{"NN"},
"miniwelfare":	{"JJ"},
"mink":	{"NN","NNS"},
"minkowski":	{"NN"},
"minks":	{"NNS"},
"minneapolis-based":	{"JJ"},
"minnewit":	{"NN"},
"minniebush":	{"NN"},
"minnow":	{"NN","NNS"},
"minnows":	{"NNS"},
"minoan":	{"JJ","NN"},
"minocin":	{"NN"},
"minocycline":	{"NN"},
"minor":	{"JJ","NN","VBP","VB"},
"minor-league":	{"JJ"},
"minor-leaguer":	{"NN"},
"minor-sport":	{"NN"},
"minored":	{"VBD","VBN"},
"minoring":	{"VBG"},
"minorities":	{"NNS"},
"minority":	{"NN"},
"minority-internship":	{"JJ"},
"minority-owned":	{"JJ"},
"minors":	{"NNS","VBZ"},
"minoxidil":	{"NN"},
"minster":	{"NN"},
"minsters":	{"NNS"},
"minstrel":	{"NN"},
"minstrels":	{"NNS"},
"minstrelsy":	{"NN"},
"mint":	{"NN","VB","VBP"},
"mint-scented":	{"JJ"},
"mintage":	{"NN"},
"minted":	{"VBD","VBN","JJ"},
"minter":	{"NN"},
"minting":	{"VBG","NN"},
"mintmark":	{"NN"},
"mints":	{"VBZ","NNS"},
"minty":	{"JJ"},
"minuartia":	{"NN"},
"minuend":	{"NN"},
"minuet":	{"NN"},
"minuets":	{"NNS"},
"minuit":	{"NN"},
"minus":	{"IN","NN","JJ"},
"minuscular":	{"JJ"},
"minuscule":	{"JJ","NN"},
"minuscules":	{"NNS"},
"minuses":	{"NNS"},
"minute":	{"NN","VB","VBP","JJ"},
"minute-book":	{"NN"},
"minute-books":	{"NNS"},
"minute-gun":	{"NN"},
"minute-guns":	{"NNS"},
"minute-hand":	{"NN"},
"minute-hands":	{"NNS"},
"minute-man":	{"NN"},
"minute-men":	{"NNS"},
"minuted":	{"VBD","VBN"},
"minutely":	{"RB"},
"minuteman":	{"NN"},
"minutemen":	{"NNS"},
"minuteness":	{"NN"},
"minuter":	{"JJR"},
"minutes":	{"NNS","VBZ"},
"minutest":	{"JJS"},
"minutia":	{"NN"},
"minutiae":	{"NNS"},
"minuting":	{"VBG"},
"minx":	{"NN"},
"minxes":	{"NNS"},
"minxish":	{"JJ"},
"minyan":	{"NN"},
"mio":	{"FW"},
"miocene":	{"NN"},
"miosis":	{"NN"},
"miotic":	{"JJ"},
"mioxidil":	{"NN"},
"mips":	{"NN"},
"mips-based":	{"JJ"},
"mirabeau":	{"NN"},
"miracle":	{"NN"},
"miracle-worship":	{"NN"},
"miracles":	{"NNS"},
"miraculous":	{"JJ"},
"miraculously":	{"RB"},
"mirage":	{"NN"},
"mirages":	{"NNS"},
"mirasol":	{"NN"},
"mire":	{"NN","VB","VBP"},
"mired":	{"JJ","VBD","VBN"},
"mires":	{"VBZ"},
"miri":	{"NN"},
"mirid":	{"NN"},
"miridae":	{"NN"},
"miring":	{"VBG"},
"mirish":	{"NN"},
"mirky":	{"JJ"},
"mirounga":	{"NN"},
"mirror":	{"NN","VB","VBP"},
"mirrored":	{"VBD","VBN","JJ"},
"mirroring":	{"VBG"},
"mirrorlike":	{"JJ","NN"},
"mirrors":	{"VBZ","NNS"},
"mirth":	{"NN"},
"mirthful":	{"JJ"},
"mirthfully":	{"RB"},
"mirthfulness":	{"NN"},
"mirthless":	{"JJ"},
"miry":	{"JJ"},
"misact":	{"VB","VBP"},
"misaddress":	{"VB","VBP"},
"misaddressed":	{"VBD","VBN"},
"misaddresses":	{"VBZ"},
"misaddressing":	{"VBG"},
"misadjust":	{"VB","VBP"},
"misadjusted":	{"VBD","VBN"},
"misadjusting":	{"VBG"},
"misadjusts":	{"VBZ"},
"misadventure":	{"NN"},
"misadventures":	{"NNS"},
"misadvise":	{"VB","VBP"},
"misadvised":	{"VBD","VBN"},
"misadvises":	{"VBZ"},
"misadvising":	{"VBG"},
"misaim":	{"VB","VBP"},
"misaimed":	{"VBD","VBN"},
"misaiming":	{"VBG"},
"misaims":	{"VBZ"},
"misalign":	{"VB","VBP"},
"misaligned":	{"VBD","VBN"},
"misaligning":	{"VBG"},
"misalignment":	{"NN"},
"misaligns":	{"VBZ"},
"misalliance":	{"NN"},
"misalliances":	{"NNS"},
"misallied":	{"VBD","VBN"},
"misallies":	{"VBZ"},
"misallocate":	{"VB","VBP"},
"misallocated":	{"VBD","VBN"},
"misallocates":	{"VBZ"},
"misallocating":	{"VBG"},
"misally":	{"VB","VBP"},
"misallying":	{"VBG"},
"misanalyses":	{"NNS"},
"misanalysis":	{"NN"},
"misanthrope":	{"NN"},
"misanthropes":	{"NNS"},
"misanthropic":	{"JJ"},
"misanthropical":	{"JJ"},
"misanthropist":	{"NN"},
"misanthropists":	{"NNS"},
"misanthropy":	{"NN"},
"misapplication":	{"NN"},
"misapplications":	{"NNS"},
"misapplied":	{"VBN","VBD","JJ"},
"misapplies":	{"VBZ"},
"misapply":	{"VB","VBP"},
"misapplying":	{"VBG"},
"misappraisal":	{"NN"},
"misappraisals":	{"NNS"},
"misapprehend":	{"VB","VBP"},
"misapprehended":	{"VBD","VBN"},
"misapprehending":	{"VBG"},
"misapprehends":	{"VBZ"},
"misapprehension":	{"NN"},
"misapprehensions":	{"NNS"},
"misappropriate":	{"VB","VBP"},
"misappropriated":	{"VBD","VBN"},
"misappropriates":	{"VBZ"},
"misappropriating":	{"VBG"},
"misappropriation":	{"NN"},
"misarticulate":	{"VB","VBP"},
"misassemble":	{"VB","VBP"},
"misassumption":	{"NN"},
"misassumptions":	{"NNS"},
"misattribute":	{"VB","VBP"},
"misattributed":	{"VBD","VBN"},
"misattributes":	{"VBZ"},
"misattributing":	{"VBG"},
"misattribution":	{"NN"},
"misbalance":	{"NN"},
"misbegot":	{"JJ"},
"misbegotten":	{"JJ"},
"misbehave":	{"VB","VBP"},
"misbehaved":	{"VBD","VBN"},
"misbehaver":	{"NN"},
"misbehaves":	{"VBZ"},
"misbehaving":	{"VBG"},
"misbehavior":	{"NN"},
"misbehaviour":	{"NN"},
"misbelieve":	{"VB","VBP"},
"misbelieved":	{"VBD","VBN"},
"misbeliever":	{"NN"},
"misbelieves":	{"VBZ"},
"misbelieving":	{"VBG"},
"misbind":	{"VB","VBP"},
"misbinding":	{"VBG"},
"misbinds":	{"VBZ"},
"misbound":	{"VBD","VBN"},
"misbrand":	{"VB","VBP"},
"misbranded":	{"JJ","VBD","VBN"},
"misbranding":	{"VBG"},
"misbrands":	{"VBZ"},
"misbutton":	{"VB","VBP"},
"misbuttoned":	{"VBD","VBN"},
"misbuttoning":	{"VBG"},
"misbuttons":	{"VBZ"},
"miscalculate":	{"VB","VBP"},
"miscalculated":	{"VBD","VBN"},
"miscalculates":	{"VBZ"},
"miscalculating":	{"VBG"},
"miscalculation":	{"NN"},
"miscalculations":	{"NNS"},
"miscall":	{"VB","VBP"},
"miscalled":	{"VBD","VBN"},
"miscaller":	{"NN"},
"miscalling":	{"VBG"},
"miscalls":	{"VBZ"},
"miscaption":	{"VB","VBP"},
"miscarriage":	{"NN"},
"miscarriages":	{"NNS"},
"miscarried":	{"VBD","VBN"},
"miscarries":	{"VBZ"},
"miscarry":	{"VB","VBP"},
"miscarrying":	{"VBG"},
"miscast":	{"JJ","VB","VBP","VBD","VBN"},
"miscasting":	{"VBG"},
"miscasts":	{"VBZ"},
"miscatalog":	{"VB","VBP"},
"miscegenate":	{"VB","VBP","NN"},
"miscegenated":	{"VBD","VBN"},
"miscegenates":	{"VBZ","NNS"},
"miscegenating":	{"VBG"},
"miscegenation":	{"NN"},
"miscellanea":	{"NNS"},
"miscellaneous":	{"JJ"},
"miscellanies":	{"NNS"},
"miscellany":	{"NN"},
"mischance":	{"NN"},
"mischances":	{"NNS"},
"mischannel":	{"VB","VBP"},
"mischaracterization":	{"NN"},
"mischaracterizations":	{"NNS"},
"mischaracterize":	{"VB","VBP"},
"mischaracterized":	{"VBD","VBN"},
"mischaracterizes":	{"VBZ"},
"mischaracterizing":	{"VBG"},
"mischarge":	{"VB","VBP","NN"},
"mischarged":	{"VBD","VBN"},
"mischarges":	{"NNS"},
"mischarging":	{"VBG"},
"mischief":	{"NN"},
"mischief-maker":	{"NN"},
"mischief-makers":	{"NNS"},
"mischief-making":	{"NN"},
"mischievous":	{"JJ"},
"mischievously":	{"RB"},
"mischievousness":	{"NN"},
"mischoice":	{"NN"},
"mischoices":	{"NNS"},
"miscible":	{"JJ"},
"miscitation":	{"NN"},
"miscitations":	{"NNS"},
"misclassification":	{"NN"},
"misclassifications":	{"NNS"},
"misclassified":	{"VBD","VBN"},
"misclassifies":	{"VBZ"},
"misclassify":	{"VB","VBP"},
"misclassifying":	{"VBG"},
"miscode":	{"VB","VBP"},
"miscommunication":	{"NN"},
"miscomprehension":	{"NN"},
"miscomprehensions":	{"NNS"},
"miscomputation":	{"NN"},
"miscomputations":	{"NNS"},
"miscompute":	{"VB","VBP"},
"miscomputed":	{"VBD","VBN"},
"miscomputes":	{"VBZ"},
"miscomputing":	{"VBG"},
"misconceive":	{"VB","VBP"},
"misconceived":	{"VBD","VBN","JJ"},
"misconceiver":	{"NN"},
"misconceivers":	{"NNS"},
"misconceives":	{"VBZ"},
"misconceiving":	{"VBG"},
"misconception":	{"NN"},
"misconceptions":	{"NNS"},
"misconduct":	{"NN","VB","VBP"},
"misconducted":	{"VBD","VBN"},
"misconducting":	{"VBG"},
"misconducts":	{"VBZ"},
"misconnect":	{"VB","VBP","NN"},
"misconnected":	{"VBD","VBN"},
"misconnecting":	{"VBG"},
"misconnection":	{"NN"},
"misconnections":	{"NNS"},
"misconnects":	{"VBZ","NNS"},
"misconstrual":	{"NN"},
"misconstruction":	{"NN"},
"misconstructions":	{"NNS"},
"misconstrue":	{"VB","VBP"},
"misconstrued":	{"VBD","VBN"},
"misconstrues":	{"VBZ"},
"misconstruing":	{"VBG"},
"miscopied":	{"VBD","VBN"},
"miscopies":	{"NNS","VBZ"},
"miscopy":	{"NN","VB","VBP"},
"miscopying":	{"VBG"},
"miscorrelation":	{"NN"},
"miscorrelations":	{"NNS"},
"miscount":	{"VB","VBP","NN"},
"miscounted":	{"VBD","VBN"},
"miscounting":	{"VBG"},
"miscounts":	{"VBZ"},
"miscreant":	{"NN"},
"miscreants":	{"NNS"},
"miscreate":	{"VB","VBP","JJ"},
"miscreated":	{"VBD","VBN"},
"miscreates":	{"VBZ"},
"miscreating":	{"VBG"},
"miscreation":	{"NN"},
"miscreations":	{"NNS"},
"miscue":	{"VB","VBP","NN"},
"miscued":	{"VBD","VBN"},
"miscueing":	{"VBG"},
"miscues":	{"VBZ","NNS"},
"miscut":	{"JJ","VB","VBP","VBD","VBN"},
"miscuts":	{"VBZ"},
"miscutting":	{"VBG"},
"misdate":	{"VB","VBP"},
"misdated":	{"VBD","VBN"},
"misdates":	{"VBZ"},
"misdating":	{"VBG"},
"misdeal":	{"VB","VBP","NN"},
"misdealing":	{"VBG"},
"misdeals":	{"VBZ","NNS"},
"misdealt":	{"VBD","VBN"},
"misdeed":	{"NN"},
"misdeeds":	{"NNS"},
"misdeem":	{"VB","VBP"},
"misdeemed":	{"VBD","VBN"},
"misdeeming":	{"VBG"},
"misdeems":	{"VBZ"},
"misdefine":	{"VB","VBP"},
"misdefined":	{"VBD","VBN"},
"misdefines":	{"VBZ"},
"misdefining":	{"VBG"},
"misdeliver":	{"VB","VBP"},
"misdelivered":	{"VBD","VBN"},
"misdelivering":	{"VBG"},
"misdelivers":	{"VBZ"},
"misdemean":	{"VB","VBP"},
"misdemeanants":	{"NNS"},
"misdemeaned":	{"VBD","VBN"},
"misdemeaning":	{"VBG"},
"misdemeanor":	{"NN"},
"misdemeanors":	{"NNS"},
"misdemeanour":	{"NN"},
"misdemeans":	{"VBZ"},
"misdescribe":	{"VB","VBP"},
"misdescribed":	{"VBD","VBN"},
"misdescribes":	{"VBZ"},
"misdescribing":	{"VBG"},
"misdescription":	{"NN"},
"misdescriptions":	{"NNS"},
"misdevelop":	{"VB","VBP"},
"misdiagnose":	{"VB","VBP"},
"misdiagnosed":	{"VBD","VBN"},
"misdiagnoses":	{"VBZ","NNS"},
"misdiagnosing":	{"VBG"},
"misdiagnosis":	{"NN"},
"misdial":	{"VB","VBP"},
"misdialed":	{"VBD","VBN"},
"misdialing":	{"VBG"},
"misdialled":	{"VBD","VBN"},
"misdialling":	{"VBG"},
"misdials":	{"VBZ"},
"misdid":	{"VBD"},
"misdirect":	{"VB","VBP"},
"misdirected":	{"VBD","VBN","JJ"},
"misdirecting":	{"VBG"},
"misdirection":	{"NN"},
"misdirectors":	{"NNS"},
"misdirects":	{"VBZ"},
"misdistribution":	{"NN"},
"misdistributions":	{"NNS"},
"misdivision":	{"NN"},
"misdivisions":	{"NNS"},
"misdo":	{"VB","VBP"},
"misdoes":	{"VBZ"},
"misdoing":	{"VBG"},
"misdone":	{"VBN"},
"misdraw":	{"VB","VBP"},
"misdrawing":	{"VBG"},
"misdrawn":	{"VBN"},
"misdraws":	{"VBZ"},
"misdrew":	{"VBD"},
"miseducate":	{"VB","VBP"},
"miseducated":	{"VBD","VBN"},
"miseducates":	{"VBZ"},
"miseducating":	{"VBG"},
"miseducation":	{"NN"},
"misemphases":	{"NNS"},
"misemphasis":	{"NN"},
"misemphasise":	{"VB","VBP"},
"misemphasize":	{"VB","VBP"},
"misemploy":	{"VB","VBP"},
"misemployed":	{"VBD","VBN"},
"misemploying":	{"VBG"},
"misemployment":	{"NN"},
"misemploys":	{"VBZ"},
"miser":	{"NN"},
"miserable":	{"JJ"},
"miserableness":	{"NN"},
"miserably":	{"RB"},
"miseries":	{"NNS"},
"miserliness":	{"NN"},
"miserly":	{"JJ"},
"misers":	{"NNS"},
"misery":	{"NN"},
"misestimate":	{"VB","VBP","NN"},
"misestimated":	{"VBD","VBN"},
"misestimates":	{"VBZ","NNS"},
"misestimating":	{"VBG"},
"misestimation":	{"NN"},
"misevaluate":	{"VB","VBP"},
"misevaluated":	{"VBD","VBN"},
"misevaluates":	{"VBZ"},
"misevaluating":	{"VBG"},
"misevaluation":	{"NN"},
"misfeasance":	{"NN"},
"misfed":	{"VBD","VBN"},
"misfeed":	{"VB","VBP"},
"misfeeding":	{"VBG"},
"misfeeds":	{"VBZ"},
"misfield":	{"VB","VBP","NN"},
"misfielded":	{"VBD","VBN"},
"misfielding":	{"VBG"},
"misfields":	{"VBZ","NNS"},
"misfire":	{"NN","VB","VBP"},
"misfired":	{"VBD","VBN"},
"misfires":	{"VBZ"},
"misfiring":	{"VBG"},
"misfit":	{"NN"},
"misfits":	{"NNS"},
"misfocus":	{"NN","VB","VBP"},
"misfocused":	{"VBD","VBN"},
"misfocuses":	{"NNS","VBZ"},
"misfocusing":	{"VBG"},
"misfocussed":	{"VBD","VBN"},
"misfocusses":	{"VBZ"},
"misfocussing":	{"VBG"},
"misfortunate":	{"JJ"},
"misfortune":	{"NN"},
"misfortunes":	{"NNS"},
"misfunction":	{"VB","VBP"},
"misfunctioned":	{"VBD","VBN"},
"misfunctioning":	{"VBG"},
"misfunctions":	{"VBZ"},
"misgauge":	{"VB","VBP"},
"misgauged":	{"VBD","VBN"},
"misgauges":	{"VBZ"},
"misgauging":	{"VBG"},
"misgave":	{"VBD"},
"misgive":	{"VB","VBP"},
"misgiven":	{"VBN"},
"misgives":	{"VBZ"},
"misgiving":	{"NN","VBG"},
"misgivings":	{"NNS"},
"misgovern":	{"VB","VBP"},
"misgoverned":	{"VBD","VBN"},
"misgoverning":	{"VBG"},
"misgovernment":	{"NN"},
"misgoverns":	{"VBZ"},
"misgrade":	{"VB","VBP"},
"misgraded":	{"VBD","VBN"},
"misgrades":	{"VBZ"},
"misgrading":	{"VBG"},
"misguide":	{"VB","VBP"},
"misguided":	{"JJ","VBD","VBN"},
"misguidedly":	{"RB"},
"misguides":	{"VBZ"},
"misguiding":	{"VBG"},
"mish-mash":	{"NN","VB","VBP"},
"mish-mashed":	{"VBD","VBN"},
"mish-mashes":	{"NNS","VBZ"},
"mish-mashing":	{"VBG"},
"mishandle":	{"VB","VBP"},
"mishandled":	{"VBD","VBN"},
"mishandles":	{"VBZ"},
"mishandling":	{"VBG","NN"},
"mishap":	{"NN"},
"mishaps":	{"NNS"},
"mishear":	{"VB","VBP"},
"misheard":	{"VBD","VBN"},
"mishearing":	{"VBG"},
"mishears":	{"VBZ"},
"mishegaas":	{"NN"},
"mishegoss":	{"NN"},
"mishmash":	{"NN","VB","VBP"},
"mishmashed":	{"VBD","VBN"},
"mishmashes":	{"NNS","VBZ"},
"mishmashing":	{"VBG"},
"mishna":	{"NN"},
"mishnaic":	{"JJ"},
"mishpachah":	{"NN"},
"mishpocha":	{"NN"},
"mishugaas":	{"NN"},
"misidentification":	{"NN"},
"misidentifications":	{"NNS"},
"misidentified":	{"VBD","VBN"},
"misidentifies":	{"VBZ"},
"misidentify":	{"VB","VBP"},
"misidentifying":	{"VBG"},
"misimpression":	{"NN"},
"misimpressions":	{"NNS"},
"misinform":	{"VB","VBP"},
"misinformation":	{"NN"},
"misinformed":	{"VBD","VBN"},
"misinforming":	{"VBG"},
"misinforms":	{"VBZ"},
"misinterpret":	{"VB","VBP"},
"misinterpretation":	{"NN"},
"misinterpretations":	{"NNS"},
"misinterpreted":	{"VBD","VBN"},
"misinterpreters":	{"NNS"},
"misinterpreting":	{"VBG"},
"misinterprets":	{"VBZ"},
"misjudge":	{"VB","VBP"},
"misjudged":	{"VBD","VBN"},
"misjudgement":	{"NN"},
"misjudgements":	{"NNS"},
"misjudges":	{"VBZ"},
"misjudging":	{"VBG"},
"misjudgment":	{"NN"},
"misjudgments":	{"NNS"},
"miskick":	{"VB","VBP","NN"},
"miskicked":	{"VBD","VBN"},
"miskicking":	{"VBG"},
"miskicks":	{"VBZ","NNS"},
"mislabel":	{"VB","VBP"},
"mislabeled":	{"VBD","VBN"},
"mislabeling":	{"VBG"},
"mislabelled":	{"VBD","VBN"},
"mislabelling":	{"VBG"},
"mislabels":	{"VBZ"},
"mislaid":	{"VBD","VBN"},
"mislay":	{"VB","VBP"},
"mislaying":	{"VBG"},
"mislays":	{"VBZ"},
"mislead":	{"VB","NN","VBP"},
"misleader":	{"NN"},
"misleading":	{"JJ","VBG"},
"misleadingly":	{"RB"},
"misleads":	{"VBZ"},
"mislearn":	{"VB","VBP"},
"mislearned":	{"VBD","VBN"},
"mislearning":	{"VBG"},
"mislearns":	{"VBZ"},
"mislearnt":	{"VBD","VBN"},
"misled":	{"VBD","VBN"},
"mislocate":	{"VB","VBP"},
"mislocated":	{"VBD","VBN"},
"mislocates":	{"VBZ"},
"mislocating":	{"VBG"},
"mislocation":	{"NN"},
"mislocations":	{"NNS"},
"mismanage":	{"VB","VBP"},
"mismanaged":	{"VBD","VBN"},
"mismanagement":	{"NN"},
"mismanages":	{"VBZ"},
"mismanaging":	{"VBG"},
"mismark":	{"VB","VBP"},
"mismarked":	{"VBD","VBN"},
"mismarking":	{"VBG"},
"mismarks":	{"VBZ"},
"mismarriage":	{"NN"},
"mismarried":	{"VBD","VBN"},
"mismarries":	{"VBZ"},
"mismarry":	{"VB","VBP"},
"mismarrying":	{"VBG"},
"mismatch":	{"NN","VB","VBP"},
"mismatched":	{"VBD","VBN","JJ"},
"mismatches":	{"NNS","VBZ"},
"mismatching":	{"VBG"},
"mismate":	{"VB","VBP"},
"mismated":	{"VBD","VBN"},
"mismates":	{"VBZ"},
"mismating":	{"VBG"},
"mismeasure":	{"VB","VBP"},
"mismeasured":	{"VBD","VBN"},
"mismeasurement":	{"NN"},
"mismeasurements":	{"NNS"},
"mismeasures":	{"VBZ"},
"mismeasuring":	{"VBG"},
"mismo":	{"JJ"},
"misname":	{"VB","VBP"},
"misnamed":	{"VBN","VBD"},
"misnames":	{"VBZ"},
"misnaming":	{"VBG"},
"misnomer":	{"NN"},
"misnomers":	{"NNS"},
"miso":	{"NN"},
"misocainea":	{"NN"},
"misogamist":	{"NN"},
"misogamy":	{"NN"},
"misogynic":	{"JJ"},
"misogynism":	{"NN"},
"misogynist":	{"NN"},
"misogynistic":	{"JJ"},
"misogynists":	{"NNS"},
"misogynous":	{"JJ"},
"misogyny":	{"NN"},
"misology":	{"NN"},
"misoneism":	{"NN"},
"misopedia":	{"NN"},
"misorder":	{"NN","VB","VBP"},
"misordered":	{"VBD","VBN"},
"misordering":	{"VBG"},
"misorders":	{"NNS","VBZ"},
"misorient":	{"VB","VBP"},
"misorientation":	{"NN"},
"misorientations":	{"NNS"},
"misoriented":	{"VBD","VBN"},
"misorienting":	{"VBG"},
"misorients":	{"VBZ"},
"mispackage":	{"VB","VBP"},
"misperceive":	{"VB","VBP"},
"misperceived":	{"VBD","VBN"},
"misperceives":	{"VBZ"},
"misperceiving":	{"VBG"},
"misperception":	{"NN"},
"misperceptions":	{"NNS"},
"mispickel":	{"NN"},
"misplace":	{"VB","VBP"},
"misplaced":	{"VBD","VBN","JJ"},
"misplacement":	{"NN"},
"misplacements":	{"NNS"},
"misplaces":	{"VBZ"},
"misplacing":	{"VBG"},
"misplan":	{"VB","VBP"},
"misplanned":	{"VBD","VBN"},
"misplanning":	{"VBG"},
"misplans":	{"VBZ"},
"misplay":	{"VB","VBP","NN"},
"misplayed":	{"VBD","VBN"},
"misplaying":	{"VBG"},
"misplays":	{"VBZ","NNS"},
"misposition":	{"NN"},
"misprice":	{"VB","VBP"},
"mispriced":	{"VBD","VBN"},
"misprices":	{"VBZ"},
"mispricing":	{"VBG"},
"misprint":	{"NN","VB","VBP"},
"misprinted":	{"VBD","VBN"},
"misprinting":	{"VBG"},
"misprints":	{"NNS","VBZ"},
"misprogram":	{"VB","VBP"},
"misprogrammed":	{"VBD","VBN"},
"misprogramming":	{"VBG"},
"misprograms":	{"VBZ"},
"mispronounce":	{"VB","VBP"},
"mispronounced":	{"VBD","VBN"},
"mispronounces":	{"VBZ"},
"mispronouncing":	{"VBG"},
"mispronunciation":	{"NN"},
"mispronunciations":	{"NNS"},
"misquotation":	{"NN"},
"misquote":	{"VB","VBP"},
"misquoted":	{"VBD","VBN"},
"misquotes":	{"VBZ"},
"misquoting":	{"VBG"},
"misread":	{"VB","VBP","VBD","VBN"},
"misreading":	{"NN","VBG"},
"misreadings":	{"NNS"},
"misreads":	{"VBZ"},
"misreckon":	{"VB","VBP"},
"misreckoned":	{"VBD","VBN"},
"misreckoning":	{"VBG"},
"misreckons":	{"VBZ"},
"misrecollection":	{"NN"},
"misrecollections":	{"NNS"},
"misrecord":	{"VB","VBP"},
"misrecorded":	{"VBD","VBN"},
"misrecording":	{"VBG"},
"misrecords":	{"VBZ"},
"misreference":	{"NN"},
"misreferences":	{"NNS"},
"misregister":	{"VB","VBP","NN"},
"misregistration":	{"NN"},
"misregistrations":	{"NNS"},
"misrelate":	{"VB","VBP"},
"misrelated":	{"VBD","VBN"},
"misrelates":	{"VBZ"},
"misrelating":	{"VBG"},
"misremember":	{"VB","VBP"},
"misremembered":	{"VBD","VBN"},
"misremembering":	{"VBG"},
"misremembers":	{"VBZ"},
"misrender":	{"VB","VBP"},
"misrendered":	{"VBD","VBN"},
"misrendering":	{"VBG"},
"misrenders":	{"VBZ"},
"misreport":	{"VB","VBP","NN"},
"misreported":	{"VBD","VBN"},
"misreporter":	{"NN"},
"misreporting":	{"VBG"},
"misreports":	{"VBZ","NNS"},
"misrepresent":	{"VB","VBP"},
"misrepresentation":	{"NN"},
"misrepresentations":	{"NNS"},
"misrepresented":	{"VBD","VBN"},
"misrepresenting":	{"VBG"},
"misrepresents":	{"VBZ"},
"misroute":	{"VB","VBP"},
"misrouted":	{"VBD","VBN"},
"misroutes":	{"VBZ"},
"misrouting":	{"VBG"},
"misrule":	{"NN","VB","VBP"},
"misruled":	{"VBD","VBN"},
"misrules":	{"VBZ"},
"misruling":	{"VBG"},
"miss":	{"VB","VBP","NN"},
"missal":	{"NN"},
"missals":	{"NNS"},
"missed":	{"VBD","VBN"},
"misses":	{"VBZ","NNS"},
"misset":	{"VB","VBP","VBD","VBN","JJ"},
"missets":	{"VBZ"},
"missetting":	{"VBG"},
"misshape":	{"VB","VBP","NN"},
"misshaped":	{"VBD","VBN"},
"misshapen":	{"JJ"},
"misshapenly":	{"RB"},
"misshapenness":	{"NN"},
"misshaper":	{"NN"},
"misshapes":	{"VBZ","NNS"},
"misshaping":	{"VBG"},
"missile":	{"NN"},
"missile-defense":	{"JJ"},
"missile-engineering":	{"JJ"},
"missile-guidance":	{"JJ"},
"missile-launch":	{"JJ"},
"missile-range":	{"JJ"},
"missile-transporter":	{"NN"},
"missile-type":	{"JJ"},
"missiles":	{"NNS"},
"missing":	{"VBG","JJ"},
"mission":	{"NN","VB","VBP"},
"missional":	{"JJ"},
"missionaries":	{"NNS"},
"missionary":	{"NN","JJ"},
"missioned":	{"VBD","VBN"},
"missioner":	{"NN"},
"missioning":	{"VBG"},
"missions":	{"NNS","VBZ"},
"missis":	{"NN"},
"missive":	{"NN"},
"missives":	{"NNS"},
"missort":	{"VB","VBP"},
"missorted":	{"VBD","VBN"},
"missorting":	{"VBG"},
"missorts":	{"VBZ"},
"missoula":	{"NN"},
"missourian":	{"NN"},
"misspeak":	{"VB","VBP"},
"misspeaking":	{"VBG"},
"misspeaks":	{"VBZ"},
"misspell":	{"VB","VBP"},
"misspelled":	{"VBD","VBN"},
"misspelling":	{"NN","VBG"},
"misspellings":	{"NNS"},
"misspells":	{"VBZ"},
"misspelt":	{"VBD","VBN"},
"misspend":	{"VB","VBP"},
"misspending":	{"VBG"},
"misspends":	{"VBZ"},
"misspent":	{"VBN","VBD"},
"misspoke":	{"VBD"},
"misspoken":	{"VBN"},
"misstate":	{"VB","VBP"},
"misstated":	{"VBD","VBN"},
"misstatement":	{"NN"},
"misstatements":	{"NNS"},
"misstates":	{"VBZ"},
"misstating":	{"VBG"},
"misstep":	{"NN"},
"missteps":	{"NNS"},
"misstrike":	{"NN"},
"missus":	{"NN"},
"missy":	{"NN"},
"mist":	{"NN","VB","VBP"},
"mist-flower":	{"NN"},
"mist-like":	{"JJ"},
"mistakable":	{"JJ"},
"mistake":	{"NN","VB","VBP"},
"mistaken":	{"JJ","VBN"},
"mistakenly":	{"RB"},
"mistakes":	{"NNS","VBZ"},
"mistaking":	{"VBG"},
"misted":	{"VBD","VBN"},
"mister":	{"NN"},
"mistflower":	{"NN"},
"misthrew":	{"VBD"},
"misthrow":	{"VB","VBP","NN"},
"misthrowing":	{"VBG"},
"misthrown":	{"VBN"},
"misthrows":	{"VBZ","NNS"},
"mistily":	{"RB"},
"mistime":	{"VB","VBP"},
"mistimed":	{"VBD","VBN"},
"mistimes":	{"VBZ"},
"mistiming":	{"VBG","NN"},
"mistimings":	{"NNS"},
"mistiness":	{"NN"},
"misting":	{"VBG"},
"mistitle":	{"VB","VBP"},
"mistitled":	{"VBD","VBN"},
"mistitles":	{"VBZ"},
"mistitling":	{"VBG"},
"mistletoe":	{"NN"},
"mistook":	{"VBD"},
"mistrain":	{"VB","VBP"},
"mistrained":	{"VBD","VBN"},
"mistraining":	{"VBG"},
"mistrains":	{"VBZ"},
"mistral":	{"NN"},
"mistranscribe":	{"VB","VBP"},
"mistranscribed":	{"VBD","VBN"},
"mistranscribes":	{"VBZ"},
"mistranscribing":	{"VBG"},
"mistranscription":	{"NN"},
"mistranscriptions":	{"NNS"},
"mistranslate":	{"VB","VBP"},
"mistranslated":	{"VBD","VBN"},
"mistranslates":	{"VBZ"},
"mistranslating":	{"VBG"},
"mistranslation":	{"NN"},
"mistranslations":	{"NNS"},
"mistreat":	{"VB","VBP"},
"mistreated":	{"VBD","VBN"},
"mistreating":	{"VBG"},
"mistreatment":	{"NN"},
"mistreats":	{"VBZ"},
"mistress":	{"NN"},
"mistresses":	{"NNS"},
"mistrial":	{"NN"},
"mistrials":	{"NNS"},
"mistrust":	{"NN","VB","VBP"},
"mistrusted":	{"VBD","VBN"},
"mistrustful":	{"JJ"},
"mistrustfully":	{"RB"},
"mistrusting":	{"VBG"},
"mistrusts":	{"VBZ"},
"mistruth":	{"NN"},
"mistruths":	{"NNS"},
"mists":	{"NNS","VBZ"},
"mistune":	{"VB","VBP"},
"mistuned":	{"VBD","VBN"},
"mistunes":	{"VBZ"},
"mistuning":	{"VBG"},
"misty":	{"JJ"},
"misty-eyed":	{"JJ"},
"mistype":	{"VB","VBP"},
"mistyped":	{"VBD","VBN"},
"mistypes":	{"VBZ"},
"mistyping":	{"VBG"},
"misunderestimate":	{"VB","VBP"},
"misunderestimated":	{"VBD","VBN"},
"misunderestimates":	{"VBZ"},
"misunderestimating":	{"VBG"},
"misunderstand":	{"VB","VBP","NN"},
"misunderstander":	{"NN"},
"misunderstanders":	{"NNS"},
"misunderstanding":	{"NN","VBG"},
"misunderstandings":	{"NNS"},
"misunderstands":	{"VBZ","NNS"},
"misunderstood":	{"JJ","VBD","VBN"},
"misuse":	{"VB","VBP","NN"},
"misused":	{"VBD","VBN"},
"misuses":	{"VBZ","NNS"},
"misusing":	{"VBG"},
"misutilization":	{"NN"},
"misvocalization":	{"NN"},
"miswrite":	{"VB","VBP"},
"miswrites":	{"VBZ"},
"miswriting":	{"VBG"},
"miswritten":	{"VBN"},
"miswrote":	{"VBD"},
"mitchella":	{"NN"},
"mitchum":	{"NN"},
"mite":	{"NN"},
"mite-box":	{"NN"},
"mitella":	{"NN"},
"miter":	{"NN","VB","VBP"},
"mitered":	{"VBD","VBN"},
"mitering":	{"VBG"},
"miters":	{"VBZ","NNS"},
"miterwort":	{"NN"},
"miterworts":	{"NNS"},
"mites":	{"NNS"},
"mithan":	{"NN"},
"mithra":	{"NN"},
"mithracin":	{"NN"},
"mithraic":	{"JJ"},
"mithraicism":	{"NN"},
"mithraism":	{"NN"},
"mithraist":	{"NN"},
"mithraistic":	{"JJ"},
"mithramycin":	{"NN"},
"mithridate":	{"NN"},
"mithridates":	{"NNS"},
"mitigable":	{"JJ"},
"mitigate":	{"VB","VBP"},
"mitigated":	{"VBD","VBN"},
"mitigates":	{"VBZ"},
"mitigating":	{"VBG","JJ"},
"mitigation":	{"NN"},
"mitigative":	{"JJ"},
"mitigatory":	{"JJ"},
"mitochondrion":	{"NN"},
"mitogen":	{"NN"},
"mitomycin":	{"NN"},
"mitosis":	{"NN"},
"mitotic":	{"JJ"},
"mitra":	{"NN"},
"mitral":	{"JJ"},
"mitre":	{"NN","VB","VBP"},
"mitred":	{"VBD","VBN"},
"mitres":	{"NNS","VBZ"},
"mitrewort":	{"NN"},
"mitring":	{"VBG"},
"mitsvah":	{"NN"},
"mitt":	{"NN"},
"mittelschmerz":	{"NN"},
"mitten":	{"NN"},
"mittens":	{"NNS"},
"mitterrand":	{"NN"},
"mitts":	{"NNS"},
"mitzvah":	{"NN"},
"miuchi":	{"FW"},
"miwok":	{"NN"},
"mix":	{"NN","VB","VBP"},
"mix-up":	{"NN"},
"mix-ups":	{"NNS"},
"mixable":	{"JJ"},
"mixed":	{"JJ","VBN","VBD"},
"mixed-blood":	{"NN"},
"mixed-up":	{"JJ"},
"mixer":	{"NN"},
"mixers":	{"NNS"},
"mixes":	{"VBZ","NNS"},
"mixing":	{"VBG","NN","JJ"},
"mixologist":	{"NN"},
"mixologists":	{"NNS"},
"mixology":	{"NN"},
"mixtec":	{"JJ"},
"mixture":	{"NN"},
"mixtures":	{"NNS"},
"mizen":	{"NN"},
"mizenmast":	{"NN"},
"mizenmasts":	{"NNS"},
"mizens":	{"NNS"},
"mizzen":	{"NN","JJ"},
"mizzenmast":	{"NN"},
"mizzenmasts":	{"NNS"},
"mizzens":	{"NNS"},
"mizzle":	{"VB","VBP","NN"},
"mizzled":	{"VBD","VBN"},
"mizzles":	{"VBZ"},
"mizzling":	{"VBG"},
"mizzly":	{"RB"},
"mko":	{"NN"},
"mkt":	{"NN"},
"ml":	{"NN","NNS"},
"mls":	{"NNS"},
"mlss":	{"NN"},
"mm":	{"NN","NNS"},
"mmpi":	{"NN"},
"mms":	{"NNS"},
"mnemonic":	{"JJ","NN"},
"mnemonics":	{"NNS"},
"mnemonist":	{"NN"},
"mnemonists":	{"NNS"},
"mnemotechnic":	{"JJ"},
"mnemotechnical":	{"JJ"},
"mniaceae":	{"NN"},
"mnium":	{"NN"},
"mo":	{"NN"},
"moa":	{"NN"},
"moai":	{"NN","NNS"},
"moan":	{"VBP","NN","VB"},
"moaned":	{"VBD","VBN"},
"moaner":	{"NN"},
"moaners":	{"NNS"},
"moaning":	{"VBG"},
"moans":	{"VBZ","NNS"},
"moat":	{"NN","VB","VBP"},
"moated":	{"JJ","VBD","VBN"},
"moating":	{"VBG"},
"moats":	{"NNS","VBZ"},
"mob":	{"NN","VBP","VB"},
"moban":	{"NN"},
"mobbed":	{"VBD","VBN"},
"mobbing":	{"VBG"},
"mobbish":	{"JJ"},
"mobcap":	{"NN"},
"mobcaps":	{"NNS"},
"mobike":	{"NN"},
"mobile":	{"JJ","NN"},
"mobile-home":	{"NN"},
"mobilisation":	{"NN"},
"mobilisations":	{"NNS"},
"mobilise":	{"VB","VBP"},
"mobilised":	{"VBD","VBN"},
"mobilises":	{"VBZ"},
"mobilising":	{"VBG"},
"mobility":	{"NN"},
"mobilization":	{"NN"},
"mobilizations":	{"NNS"},
"mobilize":	{"VB","VBP"},
"mobilized":	{"VBD","VBN"},
"mobilizes":	{"VBZ"},
"mobilizing":	{"VBG"},
"mobius":	{"NN"},
"moblike":	{"JJ"},
"mobocracy":	{"NN"},
"mobs":	{"NNS","VBZ"},
"mobster":	{"NN"},
"mobsters":	{"NNS"},
"mobula":	{"NN"},
"mobulidae":	{"NN"},
"mobutu":	{"NN"},
"mocambique":	{"NN"},
"mocassin":	{"NN"},
"moccasin":	{"NN"},
"moccasins":	{"NNS"},
"mocha":	{"NN"},
"mock":	{"JJ","VB","VBP","NN"},
"mock-heroic":	{"JJ","NN"},
"mock-up":	{"NN"},
"mock-ups":	{"NNS"},
"mocked":	{"JJ","VBD","VBN"},
"mocker":	{"NN"},
"mockeries":	{"NNS"},
"mockernut":	{"NN"},
"mockers":	{"NNS"},
"mockery":	{"NN"},
"mocking":	{"JJ","VBG"},
"mockingbird":	{"NN"},
"mockingbirds":	{"NNS"},
"mockingly":	{"RB"},
"mocks":	{"VBZ","NNS"},
"mockup":	{"NN"},
"mockups":	{"NNS"},
"mod":	{"JJ","NN"},
"modafinil":	{"NN"},
"modal":	{"JJ","NN"},
"modality":	{"NN"},
"modals":	{"NNS"},
"mode":	{"NN"},
"model":	{"NN","VB","VBP","JJ"},
"model-year":	{"JJ"},
"modeled":	{"VBD","VBN"},
"modeler":	{"NN"},
"modelers":	{"NNS"},
"modeling":	{"NN","VBG"},
"modelled":	{"VBD","VBN"},
"modeller":	{"NN"},
"modellers":	{"NNS"},
"modelling":	{"NN","VBG"},
"models":	{"NNS","VBZ"},
"models-on-the-way-up":	{"JJ"},
"modem":	{"NN"},
"modems":	{"NNS"},
"moderate":	{"JJ","VB","VBP","NN"},
"moderate-income":	{"JJ","NN"},
"moderate-rehabilitation":	{"NN"},
"moderate-size":	{"JJ"},
"moderate-sized":	{"JJ"},
"moderated":	{"VBN","VBD"},
"moderately":	{"RB"},
"moderateness":	{"NN"},
"moderates":	{"NNS","VBZ"},
"moderating":	{"VBG"},
"moderation":	{"NN"},
"moderationism":	{"NN"},
"moderationist":	{"NN"},
"moderatism":	{"NN"},
"moderato":	{"JJ","RB"},
"moderator":	{"NN"},
"moderators":	{"NNS"},
"moderatorship":	{"NN"},
"modern":	{"JJ","NN"},
"modern-dance":	{"NN"},
"modern-day":	{"JJ"},
"moderne":	{"JJ"},
"modernisation":	{"NN"},
"modernisations":	{"NNS"},
"modernise":	{"VB","VBP"},
"modernised":	{"VBD","VBN"},
"moderniser":	{"NN"},
"modernisers":	{"NNS"},
"modernises":	{"VBZ"},
"modernising":	{"VBG","JJ"},
"modernism":	{"NN"},
"modernist":	{"NN","JJ"},
"modernistic":	{"JJ"},
"modernists":	{"NNS"},
"modernity":	{"NN"},
"modernization":	{"NN"},
"modernizations":	{"NNS"},
"modernize":	{"VB","VBP"},
"modernized":	{"VBD","VBN"},
"modernizer":	{"NN"},
"modernizers":	{"NNS"},
"modernizes":	{"VBZ"},
"modernizing":	{"VBG","JJ"},
"modernness":	{"NN"},
"moderns":	{"NNS"},
"modes":	{"NNS"},
"modest":	{"JJ"},
"modestly":	{"RB"},
"modestness":	{"NN"},
"modesty":	{"NN"},
"modicon":	{"NN"},
"modicum":	{"NN"},
"modifiable":	{"JJ"},
"modification":	{"NN"},
"modifications":	{"NNS"},
"modified":	{"VBN","VBD"},
"modifier":	{"NN"},
"modifiers":	{"NNS"},
"modifies":	{"VBZ"},
"modify":	{"VB","VBP"},
"modifying":	{"VBG"},
"modillion":	{"NN"},
"modiolus":	{"NN"},
"modish":	{"JJ"},
"modishly":	{"RB"},
"modishness":	{"NN"},
"modiste":	{"NN"},
"modistes":	{"NNS"},
"mods":	{"NNS"},
"modular":	{"JJ"},
"modulate":	{"VB","VBP"},
"modulated":	{"JJ","VBD","VBN"},
"modulates":	{"VBZ"},
"modulating":	{"VBG"},
"modulation":	{"NN"},
"modulations":	{"NNS"},
"module":	{"NN"},
"modules":	{"NNS"},
"moduli":	{"NNS"},
"modulus":	{"NN"},
"modus":	{"NN"},
"moehringia":	{"NN"},
"mogul":	{"NN"},
"moguls":	{"NNS"},
"mohair":	{"NN"},
"mohammad":	{"NN"},
"moharram":	{"NN"},
"mohave":	{"NN"},
"moho":	{"NN"},
"mohorovicic":	{"NN"},
"mohria":	{"NN"},
"moi":	{"PRP"},
"moieties":	{"NNS"},
"moiety":	{"NN"},
"moil":	{"NN","VB","VBP"},
"moiled":	{"VBD","VBN"},
"moiler":	{"NN"},
"moiling":	{"VBG"},
"moils":	{"VBZ"},
"moines-based":	{"JJ"},
"moira":	{"NN"},
"moirae":	{"NN"},
"moirai":	{"NN"},
"moire":	{"JJ","NN"},
"moist":	{"JJ"},
"moisten":	{"VB","VBP"},
"moistened":	{"VBD","VBN"},
"moistener":	{"NN"},
"moistening":	{"VBG"},
"moistens":	{"VBZ"},
"moister":	{"JJR"},
"moistest":	{"JJS"},
"moistly":	{"RB"},
"moistness":	{"NN"},
"moisture":	{"NN"},
"moisturise":	{"VB","VBP"},
"moisturised":	{"VBD","VBN"},
"moisturiser":	{"NN"},
"moisturisers":	{"NNS"},
"moisturises":	{"VBZ"},
"moisturising":	{"VBG"},
"moisturize":	{"VB","VBP"},
"moisturized":	{"VBD","VBN"},
"moisturizer":	{"NN"},
"moisturizers":	{"NNS"},
"moisturizes":	{"VBZ"},
"moisturizing":	{"VBG"},
"mojarra":	{"NN"},
"mojave":	{"NN"},
"mojo":	{"NN"},
"moke":	{"NN"},
"moksa":	{"NN"},
"mokulu":	{"NN"},
"mol":	{"NN"},
"mola":	{"NN"},
"molal":	{"JJ"},
"molality":	{"NN"},
"molar":	{"NN","JJ"},
"molarity":	{"NN"},
"molars":	{"NNS"},
"molasses":	{"NN"},
"mold":	{"NN","VB","VBP"},
"moldable":	{"JJ"},
"moldavia":	{"NN"},
"moldboard":	{"NN"},
"molded":	{"JJ","VBD","VBN"},
"molder":	{"VB","VBP","NN"},
"moldered":	{"VBD","VBN"},
"moldering":	{"VBG"},
"molders":	{"VBZ","NNS"},
"moldiness":	{"NN"},
"molding":	{"NN","VBG"},
"moldings":	{"NNS"},
"molds":	{"VBZ","NNS"},
"moldy":	{"JJ"},
"mole":	{"NN"},
"molech":	{"NN"},
"molecular":	{"JJ"},
"molecularly":	{"RB"},
"molecule":	{"NN"},
"molecules":	{"NNS"},
"molehill":	{"NN"},
"molehills":	{"NNS"},
"moles":	{"NNS"},
"moleskin":	{"NN"},
"molest":	{"VB","VBP"},
"molestation":	{"NN"},
"molested":	{"VBN","VBD","JJ"},
"molester":	{"NN"},
"molesters":	{"NNS"},
"molesting":	{"VBG","NN"},
"molests":	{"VBZ"},
"molidae":	{"NN"},
"molindone":	{"NN"},
"moline":	{"NN"},
"molise":	{"NN"},
"moll":	{"NN"},
"mollah":	{"NN"},
"molle":	{"NN"},
"mollie":	{"NN"},
"mollienesia":	{"NN"},
"mollies":	{"NNS"},
"mollification":	{"NN"},
"mollified":	{"VBD","VBN"},
"mollifies":	{"VBZ"},
"mollify":	{"VB","VBP"},
"mollifying":	{"VBG"},
"molls":	{"NNS"},
"molluga":	{"NN"},
"mollusc":	{"NN"},
"mollusca":	{"NN"},
"molluscan":	{"JJ"},
"molluscs":	{"NNS"},
"molluscum":	{"NN"},
"mollusk":	{"NN"},
"mollusks":	{"NNS"},
"molly":	{"NN"},
"mollycoddle":	{"NN","VB","VBP"},
"mollycoddled":	{"VBD","VBN"},
"mollycoddler":	{"NN"},
"mollycoddles":	{"VBZ","NNS"},
"mollycoddling":	{"VBG"},
"mollymawk":	{"NN"},
"molnar":	{"NN"},
"molokai":	{"NN"},
"molossidae":	{"NN"},
"molothrus":	{"NN"},
"molt":	{"NN","VB","VBP"},
"molted":	{"VBD","VBN"},
"molten":	{"JJ"},
"molter":	{"NN"},
"molting":	{"VBG"},
"molto":	{"RB"},
"molton":	{"NN"},
"molts":	{"VBZ","NNS"},
"moluccas":	{"NN"},
"molucella":	{"NN"},
"molva":	{"NN"},
"molybdenite":	{"NN"},
"molybdenum":	{"NN"},
"mom":	{"NN"},
"mom-and-pop":	{"JJ"},
"momager":	{"NN"},
"momagers":	{"NNS"},
"mombasa":	{"NN"},
"mombin":	{"NN"},
"moment":	{"NN"},
"momentaneous":	{"JJ"},
"momentarily":	{"RB"},
"momentary":	{"JJ"},
"momently":	{"RB"},
"momento":	{"NN"},
"momentoes":	{"NNS"},
"momentos":	{"NNS"},
"momentous":	{"JJ"},
"momentously":	{"RB"},
"momentousness":	{"NN"},
"moments":	{"NNS"},
"momentum":	{"NN"},
"momism":	{"NN"},
"momma":	{"NN"},
"mommas":	{"NNS"},
"mommies":	{"NNS"},
"mommsen":	{"NN"},
"mommy":	{"NN"},
"momo":	{"NN"},
"momordica":	{"NN"},
"momos":	{"NNS"},
"momot":	{"NN"},
"momotidae":	{"NN"},
"momotus":	{"NN"},
"moms":	{"NNS"},
"mon-khmer":	{"NN"},
"mona":	{"NN"},
"monacan":	{"JJ","NN"},
"monacle":	{"NN"},
"monaco-ville":	{"NN"},
"monad":	{"NN"},
"monal":	{"NN"},
"monandrous":	{"JJ"},
"monandry":	{"NN"},
"monarch":	{"NN"},
"monarchal":	{"JJ"},
"monarchic":	{"JJ"},
"monarchical":	{"JJ"},
"monarchies":	{"NNS"},
"monarchism":	{"NN"},
"monarchist":	{"NN"},
"monarchists":	{"NNS"},
"monarchs":	{"NNS"},
"monarchy":	{"NN"},
"monarda":	{"NN"},
"monardella":	{"NN"},
"monario":	{"NN"},
"monas":	{"NNS"},
"monasteries":	{"NNS"},
"monastery":	{"NN"},
"monastic":	{"JJ"},
"monastical":	{"JJ"},
"monasticism":	{"NN"},
"monatomic":	{"JJ"},
"monaul":	{"NN"},
"monaural":	{"JJ"},
"monaurally":	{"RB"},
"monazite":	{"NN"},
"monday-morning":	{"JJ"},
"monde":	{"NN"},
"monecious":	{"JJ"},
"monegasque":	{"JJ","NN"},
"monei":	{"NN","NNS"},
"moneies":	{"NNS"},
"monera":	{"NN"},
"moneran":	{"JJ","NN"},
"moneron":	{"NN"},
"moneses":	{"NN"},
"monestrous":	{"JJ"},
"monetarism":	{"NN"},
"monetarist":	{"NN","JJ"},
"monetarists":	{"NNS"},
"monetary":	{"JJ"},
"monetary-damage":	{"NN","JJ"},
"monetary-policy":	{"NN"},
"monetary-stroke-military":	{"JJ"},
"monetisation":	{"NN"},
"monetise":	{"VB","VBP"},
"monetised":	{"VBD","VBN"},
"monetises":	{"VBZ"},
"monetising":	{"VBG"},
"monetization":	{"NN"},
"monetize":	{"VB","VBP"},
"monetized":	{"VBD","VBN"},
"monetizes":	{"VBZ"},
"monetizing":	{"VBG"},
"money":	{"NN"},
"money-back":	{"JJ"},
"money-bags":	{"NN","NNS"},
"money-box":	{"NN"},
"money-boxes":	{"NNS"},
"money-broking":	{"JJ"},
"money-center":	{"JJ"},
"money-changer":	{"NN"},
"money-changers":	{"NNS"},
"money-fed":	{"JJ"},
"money-fund":	{"JJ","NN"},
"money-granting":	{"NN"},
"money-grubber":	{"NN"},
"money-grubbers":	{"NNS"},
"money-grubbing":	{"JJ"},
"money-handling":	{"NN"},
"money-hungry":	{"NN"},
"money-laundering":	{"NN"},
"money-lender":	{"NN"},
"money-lenders":	{"NNS"},
"money-lending":	{"JJ"},
"money-losing":	{"JJ"},
"money-maker":	{"NN"},
"money-makers":	{"NNS"},
"money-making":	{"JJ"},
"money-management":	{"NN","JJ"},
"money-manager":	{"NN"},
"money-market":	{"NN"},
"money-minded":	{"JJ"},
"money-retirees":	{"NNS"},
"money-spinner":	{"NN"},
"money-spinners":	{"NNS"},
"money-strapped":	{"JJ"},
"money-supply":	{"JJ","NN"},
"money-transfer":	{"JJ","NN"},
"money-winner":	{"NN"},
"money-wise":	{"JJ"},
"moneybag":	{"NN"},
"moneyed":	{"JJ"},
"moneyer":	{"NN"},
"moneygrubber":	{"NN"},
"moneylender":	{"NN"},
"moneylenders":	{"NNS"},
"moneyless":	{"JJ"},
"moneymaker":	{"NN"},
"moneymakers":	{"NNS"},
"moneymaking":	{"JJ"},
"moneyman":	{"NN"},
"moneys":	{"NNS"},
"moneywort":	{"NN"},
"mongo":	{"NN"},
"mongol":	{"NN"},
"mongolianism":	{"NN"},
"mongolic":	{"NN"},
"mongolism":	{"NN"},
"mongols":	{"NNS"},
"mongoose":	{"NN"},
"mongooses":	{"NNS"},
"mongrel":	{"NN","JJ"},
"mongrelisation":	{"NN"},
"mongrelise":	{"VB","VBP"},
"mongrelised":	{"VBD","VBN"},
"mongrelises":	{"VBZ"},
"mongrelising":	{"VBG"},
"mongrelization":	{"NN"},
"mongrelize":	{"VB","VBP"},
"mongrelized":	{"VBD","VBN"},
"mongrelizes":	{"VBZ"},
"mongrelizing":	{"VBG"},
"mongrels":	{"NNS"},
"monic":	{"JJ"},
"monicker":	{"NN"},
"monied":	{"JJ"},
"monies":	{"NNS"},
"moniker":	{"NN"},
"monikers":	{"NNS"},
"monilia":	{"NN"},
"moniliaceae":	{"NN"},
"moniliales":	{"NN"},
"moniliasis":	{"NN"},
"monish":	{"VB","VBP"},
"monished":	{"VBD","VBN"},
"monishes":	{"VBZ"},
"monishing":	{"VBG"},
"monism":	{"NN"},
"monistat":	{"NN"},
"monistic":	{"JJ"},
"monition":	{"NN"},
"monitor":	{"VB","NN","VBP"},
"monitored":	{"VBN","VBD"},
"monitoring":	{"NN","VBG"},
"monitors":	{"NNS","VBZ"},
"monitory":	{"NN","JJ"},
"monitrice":	{"NN"},
"monk":	{"NN"},
"monkey":	{"NN","VB","VBP"},
"monkey-gland":	{"NN"},
"monkey-nut":	{"NN"},
"monkey-nuts":	{"NNS"},
"monkey-puzzle":	{"NN"},
"monkey-wrench":	{"NN"},
"monkeyed":	{"VBD","VBN"},
"monkeying":	{"VBG"},
"monkeypod":	{"NN"},
"monkeypox":	{"NN"},
"monkeys":	{"NNS","VBZ"},
"monkfish":	{"NN"},
"monkish":	{"JJ"},
"monks":	{"NNS"},
"monkshood":	{"NN"},
"monnet":	{"NN"},
"mono":	{"JJ","NN"},
"mono-iodotyrosine":	{"NN"},
"mono-unsaturated":	{"JJ"},
"monoamine":	{"NN"},
"monoatomic":	{"JJ"},
"monoblast":	{"NN"},
"monocanthidae":	{"NN"},
"monocanthus":	{"NN"},
"monocarboxylic":	{"JJ"},
"monocarp":	{"NN"},
"monocarpic":	{"JJ"},
"monochamus":	{"NN"},
"monochromacy":	{"NN"},
"monochromasy":	{"NN"},
"monochromat":	{"NN"},
"monochromatic":	{"JJ"},
"monochromatism":	{"NN"},
"monochrome":	{"JJ","NN"},
"monochromes":	{"NNS"},
"monochromia":	{"NN"},
"monochromic":	{"JJ"},
"monochromous":	{"JJ"},
"monochronic":	{"JJ"},
"monocle":	{"NN"},
"monocled":	{"JJ"},
"monocles":	{"NNS"},
"monoclinal":	{"JJ"},
"monocline":	{"NN"},
"monoclinic":	{"JJ"},
"monoclinous":	{"JJ"},
"monoclonal":	{"NN","JJ"},
"monoclonal-antibody":	{"NN"},
"monocot":	{"NN"},
"monocotyledon":	{"NN"},
"monocotyledonae":	{"NN"},
"monocotyledonous":	{"JJ"},
"monocotyledons":	{"NNS"},
"monocracy":	{"NN"},
"monocrotophos":	{"NN"},
"monoculture":	{"NN"},
"monocycle":	{"NN"},
"monocyte":	{"NN"},
"monocytogenes":	{"FW"},
"monocytosis":	{"NN"},
"monod":	{"NN"},
"monodic":	{"JJ"},
"monodical":	{"JJ"},
"monodisperse":	{"JJ"},
"monodon":	{"NN"},
"monodontidae":	{"NN"},
"monody":	{"NN"},
"monoecious":	{"JJ"},
"monoestrous":	{"JJ"},
"monogamist":	{"NN"},
"monogamous":	{"JJ"},
"monogamously":	{"RB"},
"monogamousness":	{"NN"},
"monogamy":	{"NN"},
"monogenesis":	{"NN"},
"monogenic":	{"JJ"},
"monogram":	{"NN","VB","VBP"},
"monogramed":	{"VBD","VBN","JJ"},
"monograming":	{"VBG"},
"monogrammed":	{"JJ","VBD","VBN"},
"monogramming":	{"VBG"},
"monograms":	{"VBZ","NNS"},
"monograph":	{"NN"},
"monographs":	{"NNS"},
"monogynic":	{"JJ"},
"monogynist":	{"NN"},
"monogynous":	{"JJ"},
"monogyny":	{"NN"},
"monohull":	{"NN"},
"monohybrid":	{"NN"},
"monohydrate":	{"NN"},
"monoicous":	{"JJ"},
"monolatry":	{"NN"},
"monolingual":	{"JJ"},
"monolingually":	{"RB"},
"monolith":	{"NN"},
"monolithic":	{"JJ"},
"monolithically":	{"RB"},
"monoliths":	{"NNS"},
"monolog":	{"NN","VB","VBP"},
"monologged":	{"VBD","VBN"},
"monologging":	{"VBG"},
"monologic":	{"JJ"},
"monological":	{"JJ"},
"monologist":	{"NN"},
"monologs":	{"NNS","VBZ"},
"monologue":	{"NN","VB","VBP"},
"monologued":	{"VBD","VBN"},
"monologues":	{"NNS","VBZ"},
"monologuing":	{"VBG"},
"monologuise":	{"VB","VBP"},
"monologuised":	{"VBD","VBN"},
"monologuises":	{"VBZ"},
"monologuising":	{"VBG"},
"monologuize":	{"VB","VBP"},
"monologuized":	{"VBD","VBN"},
"monologuizes":	{"VBZ"},
"monologuizing":	{"VBG"},
"monology":	{"NN"},
"monomania":	{"NN"},
"monomaniac":	{"NN","JJ"},
"monomaniacal":	{"JJ"},
"monomaniacally":	{"RB"},
"monomaniacs":	{"NNS"},
"monomer":	{"NN"},
"monomers":	{"NNS"},
"monometallic":	{"JJ"},
"monomethylamine":	{"NN"},
"monomorium":	{"NN"},
"monomorphemic":	{"JJ"},
"mononeuropathy":	{"NN"},
"monongahela":	{"NN"},
"mononuclear":	{"JJ"},
"mononucleate":	{"JJ"},
"mononucleosis":	{"NN"},
"monophonic":	{"JJ"},
"monophony":	{"NN"},
"monophthalmos":	{"NN"},
"monophysite":	{"JJ","NN"},
"monophysitic":	{"JJ"},
"monophysitism":	{"NN"},
"monoplane":	{"NN"},
"monoplanes":	{"NNS"},
"monoplegia":	{"NN"},
"monoploid":	{"JJ"},
"monopolies":	{"NNS"},
"monopolisation":	{"NN"},
"monopolise":	{"VB","VBP"},
"monopolised":	{"VBD","VBN"},
"monopoliser":	{"NN"},
"monopolisers":	{"NNS"},
"monopolises":	{"VBZ"},
"monopolising":	{"VBG"},
"monopolist":	{"NN"},
"monopolistic":	{"JJ"},
"monopolists":	{"NNS"},
"monopolization":	{"NN"},
"monopolize":	{"VB","VBP"},
"monopolized":	{"VBD","VBN"},
"monopolizer":	{"NN"},
"monopolizers":	{"NNS"},
"monopolizes":	{"VBZ"},
"monopolizing":	{"VBG"},
"monopoly":	{"NN"},
"monopsony":	{"NN"},
"monopteral":	{"JJ"},
"monorail":	{"NN"},
"monorails":	{"NNS"},
"monorchidism":	{"NN"},
"monorchism":	{"NN"},
"monosaccharide":	{"NN"},
"monosaccharose":	{"NN"},
"monosemous":	{"JJ"},
"monosemy":	{"NN"},
"monosodium":	{"NN"},
"monosomy":	{"NN"},
"monosyllabic":	{"JJ"},
"monosyllabically":	{"RB"},
"monosyllable":	{"NN"},
"monosyllables":	{"NNS"},
"monotheism":	{"NN"},
"monotheist":	{"NN"},
"monotheistic":	{"JJ"},
"monotheists":	{"NNS"},
"monothelitism":	{"NN"},
"monotone":	{"NN","JJ","VB","VBP"},
"monotoned":	{"VBD","VBN"},
"monotones":	{"NNS","VBZ"},
"monotonic":	{"JJ"},
"monotoning":	{"VBG"},
"monotonous":	{"JJ"},
"monotonously":	{"RB"},
"monotony":	{"NN"},
"monotremata":	{"NN"},
"monotreme":	{"NN"},
"monotropa":	{"NN"},
"monotropaceae":	{"NN"},
"monotype":	{"NN"},
"monotypic":	{"JJ"},
"monounsaturated":	{"JJ"},
"monovalent":	{"JJ"},
"monovular":	{"JJ"},
"monoxide":	{"NN"},
"monozygotic":	{"JJ"},
"monsieur":	{"NN"},
"monsieurs":	{"NNS"},
"monsignor":	{"NN"},
"monsoon":	{"NN"},
"monsoon-shrouded":	{"JJ"},
"monsoons":	{"NNS"},
"monster":	{"NN","JJ"},
"monstera":	{"NN"},
"monsters":	{"NNS"},
"monstrance":	{"NN"},
"monstrosities":	{"NNS"},
"monstrosity":	{"NN"},
"monstrous":	{"JJ"},
"monstrously":	{"RB"},
"montage":	{"NN"},
"montages":	{"NNS"},
"montagu":	{"NN"},
"montane":	{"JJ","NN"},
"montanic":	{"JJ"},
"monte":	{"NN"},
"montedision":	{"NN"},
"monterey":	{"NN"},
"monterrey-based":	{"JJ"},
"montespan":	{"NN"},
"montesquieu":	{"NN"},
"monteverdi":	{"NN"},
"montez":	{"NN"},
"montfort":	{"NN"},
"montgolfier":	{"NN"},
"montgolfiere":	{"FW"},
"montgolfing":	{"NN"},
"month":	{"NN"},
"month-earlier":	{"JJ"},
"month-end":	{"JJ","NN"},
"month-long":	{"JJ"},
"month-old":	{"JJ"},
"month-to-month":	{"JJ"},
"monthlies":	{"NNS"},
"monthlong":	{"JJ","NN"},
"monthly":	{"JJ","RB","NN"},
"months":	{"NNS"},
"months-long":	{"JJ"},
"monthsit":	{"NN"},
"montia":	{"NN"},
"montmorillonites":	{"NNS"},
"montrachet":	{"NN"},
"montreal-based":	{"JJ"},
"montreal-toronto":	{"JJ"},
"monument":	{"NN"},
"monumental":	{"JJ"},
"monumentalise":	{"VB","VBP"},
"monumentalised":	{"VBD","VBN"},
"monumentalises":	{"VBZ"},
"monumentalising":	{"VBG"},
"monumentalism":	{"NN"},
"monumentality":	{"NN"},
"monumentalize":	{"VB","VBP"},
"monumentalized":	{"VBD","VBN"},
"monumentalizes":	{"VBZ"},
"monumentalizing":	{"VBG"},
"monumentally":	{"RB"},
"monuments":	{"NNS"},
"moo":	{"NN","VB","VBP"},
"moo-cow":	{"NN"},
"mooch":	{"VB","VBP"},
"mooched":	{"VBD","VBN"},
"moocher":	{"NN"},
"mooches":	{"VBZ"},
"mooching":	{"VBG"},
"mood":	{"NN"},
"moodier":	{"JJR"},
"moodiest":	{"JJS"},
"moodily":	{"RB"},
"moodiness":	{"NN"},
"moods":	{"NNS"},
"moody":	{"JJ","NN"},
"mooed":	{"VBD","VBN"},
"moog":	{"NN"},
"mooing":	{"VBG"},
"moola":	{"NN"},
"moolah":	{"NN"},
"moon":	{"NN","VBP","VB"},
"moon-curser":	{"NN"},
"moon-drenched":	{"JJ"},
"moon-faced":	{"JJ"},
"moon-ray":	{"NN"},
"moon-round":	{"JJ"},
"moon-shot":	{"NN"},
"moon-splashed":	{"JJ"},
"moon-washed":	{"JJ"},
"moon-worship":	{"NN"},
"moonbeam":	{"NN"},
"moonbeams":	{"NNS"},
"mooncake":	{"NN"},
"mooncakes":	{"NNS"},
"mooncursers":	{"NNS"},
"mooned":	{"VBD","VBN"},
"mooneye":	{"NN"},
"moonfish":	{"NN"},
"moonflower":	{"NN"},
"moonier":	{"JJR"},
"mooniest":	{"JJS"},
"moonily":	{"RB"},
"mooniness":	{"NN"},
"mooning":	{"VBG"},
"moonless":	{"JJ"},
"moonlight":	{"NN","VB","VBP"},
"moonlighted":	{"VBD","VBN"},
"moonlighter":	{"NN"},
"moonlighters":	{"NNS"},
"moonlighting":	{"NN","VBG"},
"moonlights":	{"VBZ"},
"moonlike":	{"JJ"},
"moonlit":	{"JJ"},
"moons":	{"NNS","VBZ"},
"moonseed":	{"NN"},
"moonshell":	{"NN"},
"moonshine":	{"NN","VB","VBP"},
"moonshined":	{"VBD","VBN"},
"moonshiner":	{"NN"},
"moonshines":	{"VBZ"},
"moonshining":	{"VBG"},
"moonstone":	{"NN"},
"moonstones":	{"NNS"},
"moonstruck":	{"JJ"},
"moontrack":	{"NN"},
"moonwalk":	{"NN","VB","VBP"},
"moonwalked":	{"VBD","VBN"},
"moonwalking":	{"VBG"},
"moonwalks":	{"NNS","VBZ"},
"moonwort":	{"NN"},
"moony":	{"JJ"},
"moor":	{"NN","VB","VBP"},
"moor-bird":	{"NN"},
"moorage":	{"NN"},
"moorbird":	{"NN"},
"moorcock":	{"NN"},
"moored":	{"VBD","VBN"},
"moorfowl":	{"NN"},
"moorgame":	{"NN"},
"moorhen":	{"NN"},
"moorhens":	{"NNS"},
"mooring":	{"NN","VBG"},
"moorings":	{"NNS"},
"moorish":	{"JJ"},
"moorland":	{"NN","JJ"},
"moorlands":	{"NNS"},
"moors":	{"NNS","VBZ"},
"moorwort":	{"NN"},
"moos":	{"VBZ","NNS"},
"moose":	{"NN","NNS"},
"moose-wood":	{"NN"},
"moosewood":	{"NN"},
"moot":	{"JJ","VB","VBP"},
"mooted":	{"VBD","VBN"},
"mooting":	{"VBG"},
"moots":	{"VBZ"},
"mop":	{"NN","VB","VBP"},
"mop-headed":	{"JJ"},
"mop-up":	{"NN"},
"mopboard":	{"NN"},
"mope":	{"VB","VBP","NN"},
"moped":	{"VBD","VBN","NN"},
"mopeds":	{"NNS"},
"mopes":	{"VBZ","NNS"},
"moping":	{"VBG"},
"mopped":	{"VBD","VBN"},
"mopper":	{"NN"},
"moppet":	{"NN"},
"moppets":	{"NNS"},
"mopping":	{"VBG","NN"},
"mops":	{"VBZ","NNS"},
"moquelumnan":	{"NN"},
"moquette":	{"NN"},
"mor":	{"NN"},
"moraceae":	{"NN"},
"moraceous":	{"JJ"},
"moraine":	{"NN"},
"moraines":	{"NNS"},
"moral":	{"JJ","NN"},
"morale":	{"NN"},
"morale-damaging":	{"JJ"},
"morale-enhancing":	{"JJ"},
"moralisation":	{"NN"},
"moralise":	{"VB","VBP"},
"moralised":	{"VBD","VBN"},
"moralises":	{"VBZ"},
"moralising":	{"VBG","NN"},
"moralism":	{"NN"},
"moralist":	{"NN"},
"moralistic":	{"JJ"},
"moralists":	{"NNS"},
"moralities":	{"NNS"},
"morality":	{"NN"},
"moralization":	{"NN"},
"moralize":	{"VB","VBP"},
"moralized":	{"VBD","VBN"},
"moralizer":	{"NN"},
"moralizers":	{"NNS"},
"moralizes":	{"VBZ"},
"moralizing":	{"NN","VBG"},
"morally":	{"RB"},
"morals":	{"NNS"},
"moran":	{"NN"},
"morass":	{"NN"},
"morasses":	{"NNS"},
"moratoria":	{"NNS"},
"moratorium":	{"NN"},
"moratoriums":	{"NNS"},
"moravia":	{"NN"},
"moravian":	{"JJ"},
"moray":	{"NN"},
"morays":	{"NNS"},
"morbid":	{"JJ"},
"morbid-minded":	{"JJ"},
"morbidity":	{"NN"},
"morbidly":	{"RB"},
"morbidness":	{"NN"},
"morbific":	{"JJ"},
"morbilli":	{"NN"},
"morbilliform":	{"JJ"},
"morceau":	{"NN"},
"morchella":	{"NN"},
"morchellaceae":	{"NN"},
"mordacious":	{"JJ"},
"mordaciously":	{"RB"},
"mordacity":	{"NN"},
"mordant":	{"JJ","NN"},
"mordva":	{"NN"},
"mordvin":	{"NN"},
"mordvinian":	{"NN"},
"more":	{"JJR","RB","DT"},
"more-active":	{"JJ"},
"more-advanced":	{"JJ"},
"more-affordable":	{"JJ"},
"more-attractive":	{"JJ"},
"more-conventional":	{"JJ"},
"more-detailed":	{"JJ"},
"more-discriminating":	{"JJ"},
"more-distinctive":	{"JJ"},
"more-efficient":	{"JJ"},
"more-entrenched":	{"JJ"},
"more-established":	{"JJ"},
"more-favored":	{"JJ"},
"more-general":	{"JJ"},
"more-generic":	{"JJ"},
"more-hazardous":	{"JJ"},
"more-informed":	{"JJ"},
"more-level":	{"JJ"},
"more-mainstream":	{"JJ"},
"more-mundane":	{"JJ"},
"more-muscular":	{"JJ"},
"more-natural":	{"JJ"},
"more-open":	{"JJ"},
"more-or-less":	{"RB"},
"more-personal":	{"JJ"},
"more-powerful":	{"JJ"},
"more-pressing":	{"JJ"},
"more-realistic":	{"JJ"},
"more-selective":	{"JJ"},
"more-senior":	{"JJ"},
"more-sophisticated":	{"JJ"},
"more-spontaneous":	{"JJ"},
"more-stringent":	{"JJ"},
"more-than-average":	{"RB"},
"more-than-ordinary":	{"JJ"},
"more-than-terrible":	{"JJ"},
"moreau":	{"NN"},
"moreen":	{"NN"},
"morel":	{"NN"},
"morello":	{"NN"},
"moreno":	{"NN"},
"moreover":	{"RB"},
"mores":	{"NNS"},
"moresque":	{"JJ"},
"morever":	{"RB"},
"morey":	{"NN"},
"morganatic":	{"JJ"},
"morganatically":	{"RB"},
"morganite":	{"NN"},
"morgantown":	{"NN"},
"morgen":	{"NN"},
"morgue":	{"NN"},
"morgues":	{"NNS"},
"moribund":	{"JJ"},
"morion":	{"NN"},
"morley":	{"NN"},
"morn":	{"NN"},
"morning":	{"NN","UH"},
"morning-frightened":	{"JJ"},
"morning-glory":	{"NN"},
"morning-session":	{"NN"},
"mornings":	{"NNS","RB"},
"morocco-bound":	{"JJ"},
"moron":	{"NN"},
"morone":	{"NN"},
"moronic":	{"JJ"},
"moronity":	{"NN"},
"morons":	{"NNS"},
"morose":	{"JJ"},
"morosely":	{"RB"},
"moroseness":	{"NN"},
"morosoph":	{"NN"},
"morph":	{"VB","VBP","NN"},
"morphallaxis":	{"NN"},
"morphea":	{"NN"},
"morphed":	{"VBD","VBN"},
"morpheme":	{"NN"},
"morphemes":	{"NNS"},
"morphemic":	{"JJ"},
"morphia":	{"NN"},
"morphine":	{"NN"},
"morphing":	{"VBG","NN"},
"morphogenesis":	{"NN"},
"morphogenetic":	{"JJ"},
"morphologic":	{"JJ"},
"morphological":	{"JJ"},
"morphologically":	{"RB"},
"morphology":	{"NN"},
"morphophoneme":	{"NN"},
"morphophonemic":	{"JJ"},
"morphophonemics":	{"NN"},
"morphophysiology":	{"NN"},
"morphs":	{"VBZ"},
"morrigan":	{"NN"},
"morrigu":	{"NN"},
"morrissey":	{"NN"},
"morristown":	{"NN"},
"morrow":	{"NN"},
"mors":	{"NNS"},
"morsel":	{"NN"},
"morsels":	{"NNS"},
"mortages":	{"NNS"},
"mortal":	{"JJ","NN"},
"mortalities":	{"NNS"},
"mortality":	{"NN"},
"mortally":	{"RB"},
"mortals":	{"NNS"},
"mortar":	{"NN","VB","VBP"},
"mortarboard":	{"NN"},
"mortarboards":	{"NNS"},
"mortared":	{"VBD","VBN"},
"mortaring":	{"VBG"},
"mortars":	{"NNS","VBZ"},
"mortgage":	{"NN","VB","VBP"},
"mortgage-backed-securities":	{"NNS"},
"mortgage-banking":	{"NN"},
"mortgage-based":	{"JJ"},
"mortgage-industry":	{"NN"},
"mortgage-insurance":	{"JJ","NN"},
"mortgage-interest":	{"JJ"},
"mortgage-lending":	{"JJ","NN"},
"mortgage-securities":	{"JJ"},
"mortgage-servicing":	{"NN"},
"mortgagebacked":	{"JJ"},
"mortgaged":	{"VBD","VBN"},
"mortgaged-backed":	{"JJ"},
"mortgagee":	{"NN"},
"mortgagees":	{"NNS"},
"mortgager":	{"NN"},
"mortgagers":	{"NNS"},
"mortgages":	{"NNS","VBZ"},
"mortgaging":	{"VBG"},
"mortgagor":	{"NN"},
"mortgagors":	{"NNS"},
"mortice":	{"NN","VB","VBP"},
"morticed":	{"VBD","VBN"},
"mortices":	{"VBZ"},
"mortician":	{"NN"},
"morticians":	{"NNS"},
"morticing":	{"VBG"},
"mortification":	{"NN"},
"mortified":	{"VBD","VBN","JJ"},
"mortifies":	{"VBZ"},
"mortify":	{"VB","VBP"},
"mortifying":	{"JJ","VBG"},
"mortimer":	{"NN"},
"mortis":	{"NN"},
"mortise":	{"NN","VB","VBP"},
"mortised":	{"VBD","VBN"},
"mortises":	{"VBZ","NNS"},
"mortising":	{"VBG"},
"mortmain":	{"NN"},
"mortuaries":	{"NNS"},
"mortuary":	{"NN","JJ"},
"morula":	{"NN"},
"morus":	{"NN"},
"mos":	{"NNS"},
"mosaic":	{"NN","JJ","VB","VBP"},
"mosaic-like":	{"JJ"},
"mosaicism":	{"NN"},
"mosaicked":	{"VBD","VBN"},
"mosaicking":	{"VBG"},
"mosaics":	{"NNS","VBZ"},
"mosan":	{"NN"},
"mosander":	{"NN"},
"moschus":	{"NN"},
"moscow-allied":	{"JJ"},
"moscow-based":	{"JJ"},
"moscow-shannon":	{"JJ"},
"moselle":	{"NN"},
"mosey":	{"VB","VBP","NN"},
"moseyed":	{"VBD","VBN"},
"moseying":	{"VBG"},
"moseys":	{"VBZ"},
"mosh":	{"VB","VBP","NN"},
"moshav":	{"NN"},
"moshe":	{"NN"},
"moshed":	{"VBD","VBN"},
"moshes":	{"VBZ"},
"moshing":	{"VBG"},
"mosnier":	{"NN"},
"mosque":	{"NN"},
"mosques":	{"NNS"},
"mosquito":	{"NN"},
"mosquito-plagued":	{"JJ"},
"mosquitoes":	{"NNS"},
"mosquitofish":	{"NN"},
"mosquitos":	{"NNS"},
"moss":	{"NN","VB","VBP"},
"moss-covered":	{"JJ"},
"moss-grown":	{"JJ"},
"moss-trooper":	{"NN"},
"mossad":	{"NN"},
"mossback":	{"NN"},
"mossbauer":	{"NN"},
"mossed":	{"VBD","VBN"},
"mosses":	{"VBZ","NNS"},
"mossiness":	{"NN"},
"mossing":	{"VBG"},
"mosslike":	{"JJ"},
"mosstone":	{"JJ"},
"mossy":	{"JJ"},
"most":	{"JJS","RB","DT"},
"most-active":	{"JJ"},
"most-actives":	{"JJ"},
"most-admired":	{"JJ"},
"most-contentious":	{"JJ"},
"most-dangerous":	{"JJ"},
"most-desired":	{"JJ"},
"most-favored":	{"JJ"},
"most-favored-nation":	{"JJ"},
"most-hazardous":	{"JJ"},
"most-indebted":	{"JJ"},
"most-influential":	{"JJ"},
"most-jingoistic":	{"JJ"},
"most-likely":	{"JJ"},
"most-likely-successor":	{"JJ"},
"most-livable":	{"JJ"},
"most-obvious":	{"JJ"},
"most-owned":	{"JJ"},
"most-polluted":	{"JJ"},
"most-prestigious":	{"JJ"},
"most-recent":	{"JJ"},
"most-recommended":	{"JJ"},
"most-recommended-issues":	{"JJ"},
"most-remarkable":	{"JJ"},
"most-respected":	{"JJ"},
"most-sold":	{"JJ"},
"most-strident":	{"JJ"},
"most-used":	{"JJ"},
"most-valuable":	{"JJ"},
"most-valuable-player":	{"NN"},
"most-watched":	{"JJ"},
"mostaccioli":	{"NN"},
"mostly":	{"RB"},
"mosul":	{"NN"},
"mot":	{"NN"},
"motacilla":	{"NN"},
"motacillidae":	{"NN"},
"mote":	{"NN"},
"motel":	{"NN"},
"motel-keepers":	{"NNS"},
"motel-keeping":	{"NN"},
"motels":	{"NNS"},
"motes":	{"NNS"},
"motet":	{"NN"},
"motets":	{"NNS"},
"moth":	{"NN","VB","VBP"},
"moth-eaten":	{"JJ"},
"moth-like":	{"JJ"},
"moth-resistant":	{"JJ"},
"mothball":	{"NN","VB","VBP"},
"mothballed":	{"VBD","VBN"},
"mothballing":	{"VBG"},
"mothballs":	{"NNS","VBZ"},
"mothed":	{"VBD","VBN"},
"mother":	{"NN","VBP","JJ","VB"},
"mother-in-law":	{"NN"},
"mother-introject":	{"NN"},
"mother-naked":	{"JJ"},
"mother-of-pearl":	{"NN"},
"mother-of-thousands":	{"NNS"},
"mother-only":	{"JJ"},
"mothered":	{"VBD","VBN"},
"motherese":	{"NN"},
"motherfucker":	{"NN"},
"motherfuckers":	{"NNS"},
"motherfucking":	{"JJ"},
"motherhood":	{"NN"},
"mothering":	{"VBG","NN"},
"motherland":	{"NN"},
"motherless":	{"JJ"},
"motherlike":	{"JJ"},
"motherliness":	{"NN"},
"motherly":	{"JJ"},
"mothers":	{"NNS","VBZ"},
"mothers-in-law":	{"NNS"},
"mothership":	{"NN"},
"motherships":	{"NNS"},
"motherwell":	{"NN"},
"motherwort":	{"NN"},
"mothier":	{"JJR"},
"mothiest":	{"JJS"},
"mothing":	{"VBG"},
"mothproof":	{"JJ","VB","VBP"},
"mothproofed":	{"VBD","VBN"},
"mothproofing":	{"VBG"},
"mothproofs":	{"VBZ"},
"moths":	{"NNS","VBZ"},
"mothy":	{"JJ"},
"motif":	{"NN"},
"motifs":	{"NNS"},
"motile":	{"JJ","NN"},
"motilin":	{"NN"},
"motility":	{"NN"},
"motion":	{"NN","VBP","VB"},
"motion-control":	{"NN"},
"motion-pattern":	{"NN"},
"motion-picture":	{"NN"},
"motional":	{"JJ"},
"motional-modified":	{"JJ"},
"motioned":	{"VBD","VBN"},
"motioning":	{"VBG"},
"motionless":	{"JJ"},
"motionlessly":	{"RB"},
"motionlessness":	{"NN"},
"motions":	{"NNS","VBZ"},
"motivate":	{"VB","VBP"},
"motivated":	{"VBN","JJ","VBD"},
"motivates":	{"VBZ"},
"motivating":	{"VBG"},
"motivation":	{"NN"},
"motivational":	{"JJ"},
"motivations":	{"NNS"},
"motivative":	{"JJ"},
"motivator":	{"NN"},
"motivators":	{"NNS"},
"motive":	{"NN","JJ"},
"motiveless":	{"JJ"},
"motives":	{"NNS"},
"motivity":	{"NN"},
"motley":	{"NN","JJ"},
"motmot":	{"NN"},
"motoneuron":	{"NN"},
"motor":	{"NN","JJ","VB","VBP"},
"motor-assisted":	{"JJ"},
"motor-car":	{"NN"},
"motor-control":	{"JJ"},
"motor-drive":	{"JJ"},
"motor-home":	{"NN"},
"motor-industry":	{"NN"},
"motor-operated":	{"JJ"},
"motor-scooter":	{"NN"},
"motor-vehicle":	{"NN"},
"motorbike":	{"NN"},
"motorbikes":	{"NNS"},
"motorboat":	{"NN"},
"motorboats":	{"NNS"},
"motorbus":	{"NN"},
"motorcade":	{"NN"},
"motorcades":	{"NNS"},
"motorcar":	{"NN"},
"motorcoach":	{"NN"},
"motorcycle":	{"NN","VB","VBP"},
"motorcycled":	{"VBD","VBN"},
"motorcycles":	{"NNS","VBZ"},
"motorcycling":	{"NN","VBG"},
"motorcyclist":	{"NN"},
"motorcyclists":	{"NNS"},
"motored":	{"JJ","VBD","VBN"},
"motorial":	{"JJ"},
"motoring":	{"NN","JJ","VBG"},
"motorisation":	{"NN"},
"motorise":	{"VB","VBP"},
"motorised":	{"VBD","VBN","JJ"},
"motorises":	{"VBZ"},
"motorising":	{"VBG"},
"motorist":	{"NN"},
"motorists":	{"NNS"},
"motorization":	{"NN"},
"motorize":	{"VB","VBP"},
"motorized":	{"JJ","VBD","VBN"},
"motorizes":	{"VBZ"},
"motorizing":	{"VBG"},
"motorless":	{"JJ"},
"motorman":	{"NN"},
"motormouth":	{"NN"},
"motors":	{"NNS","VBZ"},
"motorscooters":	{"NNS"},
"motortruck":	{"NN"},
"motorway":	{"NN"},
"motorways":	{"NNS"},
"motrin":	{"NN"},
"mots":	{"NNS"},
"mott":	{"NN"},
"mottle":	{"NN","VB","VBP"},
"mottled":	{"JJ","VBD","VBN"},
"mottles":	{"NNS","VBZ"},
"mottling":	{"VBG"},
"motto":	{"NN"},
"mottoes":	{"NNS"},
"mottos":	{"NNS"},
"moue":	{"NN"},
"moufflon":	{"NN"},
"mouflon":	{"NN"},
"mough":	{"NN"},
"moujik":	{"NN"},
"moukden":	{"NN"},
"mould":	{"NN","VB","VBP"},
"mouldboard":	{"NN"},
"moulded":	{"VBD","VBN"},
"moulder":	{"VB","VBP","NN"},
"mouldered":	{"VBD","VBN"},
"mouldering":	{"VBG"},
"moulders":	{"VBZ","NNS"},
"moulding":	{"NN","VBG"},
"mouldings":	{"NNS"},
"moulds":	{"NNS","VBZ"},
"mouldy":	{"JJ"},
"moulmein":	{"NN"},
"moult":	{"VB","VBP","NN"},
"moulted":	{"VBD","VBN"},
"moulter":	{"NN"},
"moulting":	{"VBG"},
"moults":	{"VBZ","NNS"},
"mound":	{"NN","VB","VBP"},
"mound-bird":	{"NN"},
"mounded":	{"VBD","VBN"},
"mounding":	{"VBG"},
"mounds":	{"NNS","VBZ"},
"mount":	{"VB","VBP","NN"},
"mountain":	{"NN"},
"mountain-bike":	{"NN"},
"mountaineer":	{"NN","VB","VBP"},
"mountaineered":	{"VBD","VBN"},
"mountaineering":	{"NN","VBG"},
"mountaineers":	{"NNS","VBZ"},
"mountainous":	{"JJ"},
"mountainously":	{"RB"},
"mountains":	{"NNS"},
"mountainside":	{"NN"},
"mountainsides":	{"NNS"},
"mountaintop":	{"NN"},
"mountaintops":	{"NNS"},
"mountebank":	{"NN"},
"mountebanks":	{"NNS"},
"mounted":	{"VBD","VBN","JJ"},
"mounter":	{"NN"},
"mounters":	{"NNS"},
"mountie":	{"NN"},
"mounties":	{"NNS"},
"mounting":	{"VBG","JJ","NN"},
"mountings":	{"NNS"},
"mounts":	{"VBZ","NNS"},
"mourn":	{"VB","VBP"},
"mourned":	{"VBD","VBN"},
"mourner":	{"NN"},
"mourners":	{"NNS"},
"mournful":	{"JJ"},
"mournfully":	{"RB"},
"mournfulness":	{"NN"},
"mourning":	{"NN","VBG"},
"mourns":	{"VBZ"},
"mouse":	{"NN","VB","VBP"},
"mouse-colored":	{"JJ"},
"mouse-eared":	{"JJ"},
"mouse-sized":	{"JJ"},
"mouseburger":	{"NN"},
"mouseburgers":	{"NNS"},
"moused":	{"VBD","VBN"},
"mouselike":	{"JJ"},
"mousepad":	{"NN"},
"mouser":	{"NN"},
"mousers":	{"NNS"},
"mouses":	{"VBZ"},
"mousetrap":	{"NN","VB","VBP"},
"mousetrapped":	{"VBD","VBN"},
"mousetrapping":	{"VBG"},
"mousetraps":	{"NNS","VBZ"},
"mousey":	{"JJ"},
"mousier":	{"JJR"},
"mousiest":	{"JJS"},
"mousing":	{"VBG"},
"moussaka":	{"NN"},
"moussakas":	{"NNS"},
"mousse":	{"NN"},
"mousseline":	{"NN"},
"mousses":	{"NNS"},
"moustache":	{"NN"},
"moustached":	{"JJ"},
"moustaches":	{"NNS"},
"moustachio":	{"NN"},
"mousy":	{"JJ"},
"mouth":	{"NN","VB","VBP"},
"mouth-to-mouth":	{"JJ"},
"mouth-up":	{"JJ"},
"mouth-watering":	{"JJ"},
"mouthbreeder":	{"NN"},
"mouthed":	{"VBD","VBN","JJ"},
"mouthful":	{"NN"},
"mouthfuls":	{"NNS"},
"mouthing":	{"VBG"},
"mouthless":	{"JJ"},
"mouthlike":	{"JJ"},
"mouthpart":	{"NN"},
"mouthpiece":	{"NN"},
"mouthpieces":	{"NNS"},
"mouths":	{"NNS","VBZ"},
"mouthwash":	{"NN"},
"mouthwashes":	{"NNS"},
"mouton":	{"NN"},
"movability":	{"NN"},
"movable":	{"JJ","NN"},
"movableness":	{"NN"},
"movables":	{"NNS"},
"move":	{"VB","NN","VBP"},
"move-up":	{"JJ"},
"moveable":	{"JJ","NN"},
"moveables":	{"NNS"},
"moved":	{"VBD","VBN"},
"movement":	{"NN"},
"movements":	{"NNS"},
"mover":	{"NN"},
"movers":	{"NNS"},
"moves":	{"NNS","VBZ"},
"movie":	{"NN"},
"movie-distribution":	{"NN"},
"movie-goer":	{"NN"},
"movie-goers":	{"NNS"},
"movie-like":	{"JJ"},
"movie-making":	{"NN"},
"movie-of-the-week":	{"NN"},
"movie-production":	{"NN","JJ"},
"movie-quality":	{"JJ"},
"movie-star":	{"NN"},
"movie-studio":	{"NN"},
"movie-themed":	{"JJ"},
"movie-to-be":	{"NN"},
"moviegoer":	{"NN"},
"moviegoers":	{"NNS"},
"moviegoing":	{"NN","JJ"},
"movieland":	{"NN"},
"moviemaker":	{"NN"},
"moviemakers":	{"NNS"},
"moviemaking":	{"NN","JJ"},
"movies":	{"NNS"},
"moviestar":	{"NN"},
"moving":	{"VBG","JJ"},
"movingly":	{"RB"},
"mow":	{"VB","VBP","NN"},
"mowed":	{"VBD","VBN"},
"mower":	{"NN"},
"mowers":	{"NNS"},
"mowing":	{"VBG","NN"},
"mown":	{"VBN"},
"mows":	{"VBZ","NNS"},
"moxie":	{"NN"},
"moynihan":	{"NN"},
"mozartean":	{"JJ"},
"mozartian":	{"JJ"},
"mozzarella":	{"NN"},
"mpeg":	{"NN"},
"mpg":	{"NN"},
"mph":	{"NN"},
"mr":	{"NN"},
"mr.":	{"NN"},
"mrad":	{"NN"},
"mrads":	{"NNS"},
"mrd":	{"NN"},
"mri":	{"NN"},
"mri-type":	{"JJ"},
"mrna":	{"NN"},
"mrs.":	{"NN"},
"mrta":	{"NN"},
"ms":	{"NN"},
"ms-dos":	{"NN"},
"ms.":	{"NN"},
"msasa":	{"NN"},
"msb":	{"NN"},
"msec":	{"NN"},
"msg":	{"NN"},
"msh":	{"NN"},
"mst":	{"NN"},
"msx-run":	{"JJ"},
"mu":	{"NN"},
"mu-meson":	{"NN"},
"muadhdhin":	{"NN"},
"muazzin":	{"NN"},
"mubarak":	{"NN"},
"much":	{"RB","DT","NN"},
"much-abused":	{"JJ"},
"much-anticipated":	{"JJ"},
"much-awaited":	{"JJ"},
"much-beloved":	{"JJ"},
"much-copied":	{"JJ"},
"much-coveted":	{"JJ"},
"much-craved":	{"JJ"},
"much-criticized":	{"JJ"},
"much-delayed":	{"JJ"},
"much-despised":	{"JJ"},
"much-discussed":	{"JJ"},
"much-heralded":	{"JJ"},
"much-larger":	{"JJ"},
"much-lauded":	{"JJ"},
"much-maligned":	{"JJ"},
"much-needed":	{"JJ"},
"much-publicized":	{"JJ"},
"much-respected":	{"JJ"},
"much-revised":	{"JJ"},
"much-smaller":	{"JJ"},
"much-talked-about":	{"JJ"},
"much-thumbed":	{"JJ"},
"much-watched":	{"JJ"},
"muchness":	{"NN"},
"muciferous":	{"JJ"},
"mucilage":	{"NN"},
"mucilaginous":	{"JJ"},
"mucin":	{"NN"},
"mucinoid":	{"JJ"},
"mucinous":	{"JJ"},
"muck":	{"NN","VB","VBP"},
"muck-a-muck":	{"NN"},
"muck-a-mucks":	{"NNS"},
"muck-raker":	{"NN"},
"muck-rakers":	{"NNS"},
"muck-raking":	{"NN"},
"muck-up":	{"NN"},
"mucked":	{"VBD","VBN"},
"mucker":	{"NN"},
"muckety-muck":	{"NN"},
"muckety-mucks":	{"NNS"},
"muckheap":	{"NN"},
"muckheaps":	{"NNS"},
"muckhill":	{"NN"},
"muckier":	{"JJR"},
"muckiest":	{"JJS"},
"mucking":	{"VBG"},
"muckle":	{"NN"},
"muckrake":	{"VB","VBP"},
"muckraked":	{"VBD","VBN"},
"muckraker":	{"NN"},
"muckrakers":	{"NNS"},
"muckrakes":	{"VBZ"},
"muckraking":	{"VBG","NN","JJ"},
"mucks":	{"VBZ"},
"mucky":	{"JJ"},
"mucky-muck":	{"NN"},
"mucky-mucks":	{"NNS"},
"mucocutaneous":	{"JJ"},
"mucoid":	{"JJ","NN"},
"mucoidal":	{"JJ"},
"mucopolysaccharide":	{"NN"},
"mucopolysaccharidosis":	{"NN"},
"mucopurulent":	{"JJ"},
"mucor":	{"NN"},
"mucoraceae":	{"NN"},
"mucorales":	{"NNS"},
"mucosa":	{"NN"},
"mucosal":	{"NN"},
"mucose":	{"JJ"},
"mucous":	{"JJ"},
"mucoviscidosis":	{"NN"},
"mucuna":	{"NN"},
"mucus":	{"NN"},
"mud":	{"NN","VB","VBP"},
"mud-bath":	{"NN"},
"mud-beplastered":	{"JJ"},
"mud-brick":	{"JJ"},
"mud-caked":	{"JJ"},
"mud-flat":	{"NN"},
"mud-flats":	{"NNS"},
"mud-logger":	{"NN"},
"mud-slinging":	{"NN"},
"mud-sweat-and-tears":	{"JJ"},
"mud-wrestle":	{"VB","VBP"},
"mud-wrestled":	{"VBD","VBN"},
"mud-wrestles":	{"VBZ"},
"mud-wrestling":	{"VBG"},
"mudcat":	{"NN"},
"mudded":	{"VBD","VBN"},
"mudder":	{"NN"},
"muddied":	{"VBD","VBN"},
"muddier":	{"JJR"},
"muddies":	{"VBZ"},
"muddiest":	{"JJS"},
"muddiness":	{"NN"},
"mudding":	{"VBG"},
"muddle":	{"NN","VB","VBP"},
"muddle-headed":	{"JJ"},
"muddle-headedness":	{"NN"},
"muddled":	{"VBD","VBN","JJ"},
"muddleheaded":	{"JJ"},
"muddles":	{"VBZ","NNS"},
"muddling":	{"VBG","JJ"},
"muddy":	{"JJ","VB","VBP"},
"muddy-tasting":	{"JJ"},
"muddying":	{"VBG"},
"mudguard":	{"NN"},
"mudguards":	{"NNS"},
"mudhif":	{"NN"},
"mudra":	{"NN"},
"muds":	{"VBZ"},
"mudskipper":	{"NN"},
"mudslide":	{"NN"},
"mudslides":	{"NNS"},
"mudslinger":	{"NN"},
"mudslingers":	{"NNS"},
"mudslinging":	{"NN"},
"mudspringer":	{"NN"},
"mudwagon":	{"NN"},
"mudwrestle":	{"VB","VBP"},
"mueller":	{"NN"},
"muenchen":	{"NN"},
"muesli":	{"NN"},
"muezzin":	{"NN"},
"muezzins":	{"NNS"},
"muff":	{"NN","VB","VBP"},
"muffed":	{"VBD","VBN"},
"muffin":	{"NN"},
"muffing":	{"VBG"},
"muffins":	{"NNS"},
"muffle":	{"VB","VBP","NN"},
"muffled":	{"JJ","VBD","VBN"},
"muffler":	{"NN"},
"mufflers":	{"NNS"},
"muffles":	{"VBZ"},
"muffling":	{"VBG"},
"muffs":	{"NNS","VBZ"},
"mufti":	{"NN"},
"mug":	{"NN","VB","VBP"},
"mug.":	{"NN"},
"mugabe":	{"NN"},
"mugful":	{"NN"},
"mugged":	{"VBD","VBN"},
"muggee":	{"NN"},
"mugger":	{"NN"},
"muggers":	{"NNS"},
"muggier":	{"JJR"},
"muggiest":	{"JJS"},
"mugginess":	{"NN"},
"mugging":	{"NN","VBG"},
"muggins":	{"NNS"},
"muggy":	{"JJ"},
"mugil":	{"NN"},
"mugilidae":	{"NN"},
"mugiloidea":	{"NN"},
"mugs":	{"NNS","VBZ"},
"mugshot":	{"NN"},
"mugshots":	{"NNS"},
"mugwort":	{"NN"},
"mugwump":	{"NN"},
"muharram":	{"NN"},
"muharrum":	{"NN"},
"muhlenbergia":	{"NN"},
"muir":	{"NN"},
"muishond":	{"NN"},
"mujahadeen":	{"NN"},
"mujahadein":	{"NN"},
"mujahadin":	{"NN"},
"mujaheddin":	{"NNS"},
"mujahedeen":	{"NN"},
"mujahedin":	{"NNS"},
"mujahid":	{"NN"},
"mujahideen":	{"NN"},
"mujahidin":	{"NN"},
"mujik":	{"NN"},
"mujtihad":	{"NN"},
"mukalla":	{"NN"},
"mukataa":	{"NN"},
"mukden":	{"NN"},
"mulatto":	{"NN"},
"mulattoes":	{"NNS"},
"mulattos":	{"NNS"},
"mulberries":	{"NNS"},
"mulberry":	{"NN"},
"mulch":	{"NN","VB","VBP"},
"mulched":	{"VBD","VBN"},
"mulches":	{"VBZ","NNS"},
"mulching":	{"VBG"},
"mulct":	{"VB","VBP","NN"},
"mulcted":	{"VBD","VBN"},
"mulcting":	{"VBG"},
"mulcts":	{"VBZ","NN"},
"mule":	{"NN"},
"mule-drawn":	{"JJ"},
"mules":	{"NNS"},
"muleteer":	{"NN"},
"muleteers":	{"NNS"},
"muliebrity":	{"NN"},
"mulish":	{"JJ"},
"mulishly":	{"RB"},
"mulishness":	{"NN"},
"mulitiplier":	{"JJ"},
"mull":	{"VB","VBP","NN"},
"mulla":	{"NN"},
"mullah":	{"NN"},
"mulled":	{"VBD","VBN"},
"mullein":	{"NN"},
"muller":	{"NN"},
"mullet":	{"NN","NNS"},
"mullets":	{"NNS"},
"mullidae":	{"NN"},
"mulligan":	{"NN"},
"mulligatawny":	{"NN"},
"mulling":	{"VBG"},
"mullion":	{"NN"},
"mullioned":	{"JJ"},
"mullions":	{"NNS"},
"mulloidichthys":	{"NNS"},
"mulloway":	{"NN"},
"mulls":	{"VBZ"},
"mullus":	{"NN"},
"mulroney":	{"NN"},
"multi-agency":	{"JJ","NN"},
"multi-authored":	{"JJ"},
"multi-billionaire":	{"NN"},
"multi-billionaires":	{"NNS"},
"multi-color":	{"JJ"},
"multi-colored":	{"JJ"},
"multi-colour":	{"JJ"},
"multi-coloured":	{"JJ"},
"multi-column":	{"JJ"},
"multi-crystal":	{"JJ"},
"multi-disciplinary":	{"JJ"},
"multi-employer":	{"JJ"},
"multi-ethnic":	{"JJ"},
"multi-family":	{"JJ"},
"multi-gear":	{"JJ"},
"multi-handicapped":	{"JJ"},
"multi-lingual":	{"JJ"},
"multi-media":	{"NNS"},
"multi-million":	{"JJ"},
"multi-millionaire":	{"NN"},
"multi-millionaires":	{"NNS"},
"multi-phase":	{"JJ"},
"multi-product":	{"JJ"},
"multi-purpose":	{"JJ"},
"multi-seeded":	{"JJ"},
"multi-spired":	{"JJ"},
"multi-state":	{"JJ"},
"multi-stemmed":	{"JJ"},
"multi-valued":	{"JJ"},
"multi-valve":	{"JJ"},
"multi-windowed":	{"JJ"},
"multi-year":	{"JJ"},
"multiage":	{"JJ"},
"multiarmed":	{"JJ"},
"multiatom":	{"JJ"},
"multiauthor":	{"JJ"},
"multiauthored":	{"JJ"},
"multiaxial":	{"JJ"},
"multiband":	{"JJ"},
"multibank":	{"JJ"},
"multibarrel":	{"JJ"},
"multibarreled":	{"JJ"},
"multibarrelled":	{"JJ"},
"multibeam":	{"JJ"},
"multibillion":	{"JJ","NN"},
"multibillionaire":	{"NN"},
"multibillionaires":	{"NNS"},
"multibladed":	{"JJ"},
"multibranched":	{"JJ"},
"multibuilding":	{"JJ"},
"multibutton":	{"JJ"},
"multicampus":	{"JJ"},
"multicandidate":	{"JJ"},
"multicar":	{"JJ"},
"multicarbon":	{"JJ"},
"multicausal":	{"JJ"},
"multicell":	{"JJ"},
"multicelled":	{"JJ"},
"multicellular":	{"JJ"},
"multicellularity":	{"NN"},
"multichain":	{"JJ"},
"multichambered":	{"JJ"},
"multichannel":	{"JJ"},
"multicharacter":	{"JJ"},
"multicircuit":	{"JJ"},
"multicity":	{"JJ"},
"multiclient":	{"JJ"},
"multicoated":	{"JJ"},
"multicollinearities":	{"NNS"},
"multicollinearity":	{"NN"},
"multicolor":	{"JJ","NN"},
"multicolored":	{"JJ"},
"multicolour":	{"JJ"},
"multicoloured":	{"JJ"},
"multicomponent":	{"JJ"},
"multiconductor":	{"JJ"},
"multicounty":	{"JJ"},
"multicourse":	{"JJ"},
"multicultural":	{"JJ"},
"multiculturalism":	{"NN"},
"multiculturalist":	{"NN"},
"multiculturalists":	{"NNS"},
"multicurrency":	{"JJ"},
"multicylinder":	{"JJ"},
"multiday":	{"JJ"},
"multidialectal":	{"JJ"},
"multidimensional":	{"JJ"},
"multidirectional":	{"JJ"},
"multidisc":	{"JJ"},
"multidivisional":	{"JJ"},
"multidrug":	{"JJ"},
"multielectrode":	{"JJ"},
"multielement":	{"JJ"},
"multiemployer":	{"JJ","NN"},
"multiemployers":	{"NNS"},
"multiengine":	{"JJ"},
"multiethnic":	{"JJ"},
"multifaceted":	{"JJ"},
"multifactorial":	{"JJ"},
"multifamilies":	{"NNS"},
"multifamily":	{"JJ","NN"},
"multifarious":	{"JJ"},
"multifariously":	{"RB"},
"multifariousness":	{"NN"},
"multifeatured":	{"JJ"},
"multifiber":	{"NN"},
"multifigure":	{"NN"},
"multifilament":	{"JJ","NN"},
"multifilaments":	{"NNS"},
"multiflash":	{"JJ"},
"multiflora":	{"NN"},
"multifocal":	{"JJ"},
"multifoliate":	{"JJ"},
"multiform":	{"JJ"},
"multifrequency":	{"JJ"},
"multifront":	{"JJ"},
"multifunction":	{"JJ"},
"multifunctional":	{"JJ"},
"multigenerational":	{"JJ"},
"multigenic":	{"JJ"},
"multigrade":	{"JJ"},
"multigrain":	{"JJ"},
"multigrid":	{"JJ","NN"},
"multigroup":	{"JJ","NN"},
"multiheaded":	{"JJ"},
"multihomer":	{"JJ"},
"multihospital":	{"JJ"},
"multihued":	{"JJ"},
"multihulled":	{"JJ"},
"multilane":	{"JJ"},
"multilateral":	{"JJ"},
"multilaterally":	{"RB"},
"multilayer":	{"JJ"},
"multilayered":	{"JJ"},
"multilevel":	{"JJ"},
"multileveled":	{"JJ"},
"multiline":	{"JJ"},
"multilinear":	{"JJ"},
"multilingual":	{"JJ"},
"multilingualism":	{"NN"},
"multilobate":	{"JJ"},
"multilobed":	{"JJ"},
"multilocation":	{"NN"},
"multimedia":	{"JJ","NN"},
"multimegaton":	{"JJ"},
"multimegawatt":	{"NN"},
"multimegawatts":	{"NNS"},
"multimember":	{"JJ"},
"multimetallic":	{"JJ"},
"multimillennial":	{"JJ"},
"multimillion":	{"JJ","NN"},
"multimillionaire":	{"NN"},
"multimillionaires":	{"NNS"},
"multimillions":	{"NNS"},
"multimode":	{"JJ"},
"multimolecular":	{"JJ"},
"multination":	{"JJ"},
"multinational":	{"JJ","NN"},
"multinationalism":	{"NN"},
"multinationals":	{"NNS"},
"multinomial":	{"JJ","NN"},
"multinuclear":	{"JJ"},
"multinucleate":	{"JJ"},
"multinucleated":	{"JJ"},
"multiorgasmic":	{"JJ"},
"multipactor":	{"NN"},
"multipage":	{"JJ"},
"multipaned":	{"JJ"},
"multiparameter":	{"JJ"},
"multiparous":	{"JJ"},
"multipart":	{"JJ"},
"multiparticle":	{"JJ"},
"multipartisan":	{"JJ"},
"multipartite":	{"JJ"},
"multiparty":	{"JJ","NN"},
"multipath":	{"JJ","NN"},
"multipennate":	{"JJ"},
"multiphase":	{"JJ"},
"multiphasic":	{"JJ"},
"multiphoton":	{"JJ"},
"multipicture":	{"JJ"},
"multipiece":	{"JJ"},
"multipinnate":	{"JJ"},
"multiplant":	{"JJ"},
"multiplayer":	{"JJ"},
"multiple":	{"JJ","NN"},
"multiple-choice":	{"JJ"},
"multiple-column":	{"JJ"},
"multiple-paged":	{"JJ"},
"multiple-purpose":	{"JJ"},
"multiple-state":	{"JJ"},
"multiple-use":	{"JJ"},
"multiple-year":	{"JJ"},
"multiples":	{"NNS"},
"multipleuser":	{"JJ"},
"multiplex":	{"JJ","NN","VB","VBP"},
"multiplexed":	{"VBD","VBN"},
"multiplexer":	{"NN"},
"multiplexers":	{"NNS"},
"multiplexes":	{"VBZ"},
"multiplexing":	{"NN","VBG"},
"multiplicand":	{"NN"},
"multiplication":	{"NN"},
"multiplicative":	{"JJ"},
"multiplicatively":	{"RB"},
"multiplicity":	{"NN"},
"multiplied":	{"VBD","VBN"},
"multiplier":	{"NN"},
"multipliers":	{"NNS"},
"multiplies":	{"VBZ"},
"multiply":	{"VB","VBP"},
"multiplying":	{"VBG"},
"multipolar":	{"JJ"},
"multipolarities":	{"NNS"},
"multipolarity":	{"NN"},
"multipole":	{"NN"},
"multipoles":	{"NNS"},
"multipotent":	{"JJ"},
"multipower":	{"JJ"},
"multiproblem":	{"JJ"},
"multiprocessing":	{"NN"},
"multiprocessor":	{"NN"},
"multiproduct":	{"JJ"},
"multiprogramming":	{"NN"},
"multipronged":	{"JJ"},
"multipurpose":	{"JJ"},
"multiracial":	{"JJ"},
"multirange":	{"JJ"},
"multiregional":	{"JJ"},
"multireligious":	{"JJ"},
"multiroom":	{"JJ"},
"multirotor":	{"JJ"},
"multiscreen":	{"JJ","NN"},
"multisegmented":	{"JJ"},
"multisided":	{"JJ"},
"multisite":	{"JJ"},
"multisize":	{"JJ"},
"multiskilled":	{"JJ"},
"multisource":	{"JJ"},
"multispecies":	{"JJ"},
"multispeed":	{"JJ"},
"multispiral":	{"JJ"},
"multisport":	{"JJ"},
"multistage":	{"JJ"},
"multistaminate":	{"JJ"},
"multistate":	{"JJ"},
"multistemmed":	{"JJ"},
"multistep":	{"JJ"},
"multistorey":	{"JJ"},
"multistoried":	{"JJ"},
"multistory":	{"JJ"},
"multistranded":	{"JJ"},
"multisyllabic":	{"JJ"},
"multisystem":	{"JJ"},
"multitalented":	{"JJ"},
"multitasking":	{"NN"},
"multiterminal":	{"JJ"},
"multitiered":	{"JJ"},
"multiton":	{"JJ","NN"},
"multitone":	{"JJ"},
"multitowered":	{"JJ"},
"multitrack":	{"JJ"},
"multitrillion":	{"JJ"},
"multitude":	{"NN"},
"multitudes":	{"NNS"},
"multitudinal":	{"JJ"},
"multitudinous":	{"JJ"},
"multitudinousness":	{"NN"},
"multiunion":	{"JJ"},
"multiunit":	{"JJ"},
"multiuse":	{"JJ"},
"multivalence":	{"NN"},
"multivalency":	{"NN"},
"multivalent":	{"JJ"},
"multivalve":	{"JJ"},
"multivariate":	{"JJ"},
"multiversity":	{"NN"},
"multivitamin":	{"NN","JJ"},
"multivitamins":	{"NNS"},
"multivoiced":	{"JJ"},
"multivolume":	{"JJ"},
"multiwall":	{"JJ"},
"multiwarhead":	{"JJ"},
"multiwavelength":	{"JJ"},
"multiweek":	{"JJ"},
"multiyear":	{"JJ"},
"multi–industry":	{"JJ"},
"multi–institutional":	{"JJ"},
"mulwi":	{"NN"},
"mum":	{"NN","JJ","VB","VBP"},
"mumbai":	{"NN"},
"mumble":	{"VB","VBP","NN"},
"mumble-the-peg":	{"NN"},
"mumbled":	{"VBD","VBN"},
"mumbler":	{"NN"},
"mumbles":	{"VBZ","NNS"},
"mumblety-peg":	{"NN"},
"mumbling":	{"VBG"},
"mumbo":	{"NN"},
"mumbo-jumbo":	{"NN"},
"mummed":	{"VBD","VBN"},
"mummer":	{"NN"},
"mummers":	{"NNS"},
"mummery":	{"NN"},
"mummichog":	{"NN"},
"mummies":	{"NNS"},
"mummification":	{"NN"},
"mummified":	{"VBN","VBD"},
"mummifies":	{"VBZ"},
"mummify":	{"VB","VBP"},
"mummifying":	{"VBG"},
"mumming":	{"VBG","NN"},
"mummy":	{"NN"},
"mummy-brown":	{"JJ"},
"mumps":	{"NN"},
"mumpsimus":	{"NN"},
"mums":	{"VBZ","NNS"},
"munch":	{"VB","VBP"},
"munched":	{"VBD","VBN"},
"munchener":	{"NN"},
"muncher":	{"NN"},
"munches":	{"VBZ"},
"munchhausen":	{"NN"},
"munching":	{"VBG"},
"munchkin":	{"NN"},
"muncie":	{"NN"},
"munda":	{"NN"},
"munda-mon-khmer":	{"NN"},
"mundane":	{"JJ"},
"mundanely":	{"RB"},
"mundaneness":	{"NN"},
"mundanity":	{"NN"},
"mundo":	{"FW"},
"mung":	{"NN"},
"mungus":	{"NN"},
"muni":	{"NN","JJ","NNS"},
"munich-based":	{"JJ"},
"municipal":	{"JJ"},
"municipal-bond":	{"JJ","NN"},
"municipalism":	{"NN"},
"municipalist":	{"NN"},
"municipalities":	{"NNS"},
"municipality":	{"NN"},
"municipally":	{"RB"},
"municipally-sponsored":	{"JJ"},
"municipals":	{"NNS"},
"munificence":	{"NN"},
"munificent":	{"JJ"},
"munificently":	{"RB"},
"muniments":	{"NNS"},
"munis":	{"NNS"},
"munition":	{"NN","VB","VBP","JJ"},
"munitioned":	{"VBD","VBN"},
"munitioning":	{"VBG"},
"munitions":	{"NNS","VBZ"},
"munj":	{"NN"},
"munja":	{"NN"},
"munjeet":	{"NN"},
"munjuk":	{"NN"},
"muntiacus":	{"NNS"},
"muntingia":	{"NN"},
"muntjac":	{"NN"},
"muon":	{"NN"},
"muppet":	{"NN"},
"muppets":	{"NNS"},
"muraenidae":	{"NN"},
"mural":	{"NN","JJ"},
"muralist":	{"NN"},
"murals":	{"NNS"},
"muramidase":	{"NN"},
"murder":	{"NN","VB","VBP"},
"murdered":	{"VBN","VBD"},
"murderee":	{"NN"},
"murderees":	{"NNS"},
"murderer":	{"NN"},
"murderers":	{"NNS"},
"murderess":	{"NN"},
"murderesses":	{"NNS"},
"murdering":	{"VBG"},
"murderous":	{"JJ"},
"murderously":	{"RB"},
"murderousness":	{"NN"},
"murders":	{"NNS","VBZ"},
"muridae":	{"NN"},
"murillo":	{"NN"},
"murine":	{"NN","JJ"},
"muritaniya":	{"NN"},
"murk":	{"NN"},
"murkier":	{"JJR"},
"murkiest":	{"JJS"},
"murkily":	{"RB"},
"murkiness":	{"NN"},
"murky":	{"JJ"},
"murmansk":	{"NN"},
"murmur":	{"NN","VB","VBP"},
"murmuration":	{"NN"},
"murmured":	{"VBD","VBN"},
"murmurer":	{"NN"},
"murmuring":	{"NN","VBG"},
"murmurings":	{"NNS"},
"murmurous":	{"JJ"},
"murmurs":	{"NNS","VBZ"},
"muroidea":	{"NN"},
"murrain":	{"NN"},
"murray":	{"NN"},
"murre":	{"NN"},
"murrow":	{"NN"},
"murrumbidgee":	{"NN"},
"mus":	{"NN"},
"musa":	{"NN"},
"musaceae":	{"NN"},
"musales":	{"NNS"},
"muscadel":	{"NN"},
"muscadelle":	{"NN"},
"muscadet":	{"NN"},
"muscadine":	{"NN"},
"muscardinus":	{"NN"},
"muscari":	{"NN"},
"muscat":	{"NN"},
"muscatel":	{"NN"},
"muscatels":	{"NNS"},
"musci":	{"NN"},
"muscicapa":	{"NN"},
"muscicapidae":	{"NN"},
"muscidae":	{"NN"},
"muscivora":	{"NN"},
"muscivora-forficata":	{"NN"},
"muscle":	{"NN","VB","VBP"},
"muscle-bound":	{"JJ"},
"muscle-builder":	{"NN"},
"muscle-flexing":	{"JJ"},
"muscle-meat":	{"NN"},
"muscle-shaping":	{"JJ"},
"musclebuilder":	{"NN"},
"musclebuilding":	{"NN"},
"muscled":	{"VBD","VBN","JJ"},
"muscleman":	{"NN"},
"musclemen":	{"NNS"},
"muscles":	{"NNS","VBZ"},
"muscling":	{"VBG"},
"muscoidea":	{"NN"},
"muscular":	{"JJ"},
"muscularity":	{"NN"},
"musculature":	{"NN"},
"musculoskeletal":	{"JJ"},
"musculus":	{"NN"},
"musd":	{"NN"},
"muse":	{"NN","VB","VBP"},
"mused":	{"VBD","VBN"},
"muser":	{"NN"},
"muses":	{"VBZ","NNS"},
"musette":	{"NN"},
"museum":	{"NN"},
"museums":	{"NNS"},
"musgoi":	{"NN"},
"musgu":	{"NN"},
"mush":	{"NN","VBP","VB","UH"},
"mushed":	{"VBD","VBN"},
"musher":	{"NN"},
"mushes":	{"VBZ"},
"mushiness":	{"NN"},
"mushing":	{"VBG"},
"mushr":	{"NN"},
"mushroom":	{"NN","VB","VBP"},
"mushroom-processing":	{"JJ"},
"mushroomed":	{"VBD","VBN"},
"mushrooming":	{"NN","VBG"},
"mushrooms":	{"NNS","VBZ"},
"mushy":	{"JJ"},
"musial":	{"NN"},
"music":	{"NN"},
"music-entertainment":	{"NN"},
"music-hall":	{"NN"},
"music-halls":	{"NNS"},
"music-loving":	{"JJ"},
"music-making":	{"NN"},
"music-publishing":	{"JJ"},
"music-stand":	{"NN"},
"music-stands":	{"NNS"},
"music-stool":	{"NN"},
"music-stools":	{"NNS"},
"musical":	{"JJ","NN"},
"musicale":	{"NN"},
"musicales":	{"NNS"},
"musicality":	{"NN"},
"musically":	{"RB"},
"musicalness":	{"NN"},
"musicals":	{"NNS"},
"musician":	{"NN"},
"musicians":	{"NNS"},
"musicianship":	{"NN"},
"musicological":	{"JJ"},
"musicologically":	{"RB"},
"musicologist":	{"NN"},
"musicologists":	{"NNS"},
"musicology":	{"NN"},
"musing":	{"NN","VBG"},
"musingly":	{"RB"},
"musings":	{"NNS"},
"musjid":	{"NN"},
"musk":	{"NN"},
"musk-deer":	{"NN"},
"musk-melon":	{"NN"},
"musk-rat":	{"NN"},
"musk-rose":	{"NN"},
"musk-scented":	{"JJ"},
"muskadell":	{"NN"},
"muskat":	{"NN"},
"muskellunge":	{"NN"},
"musket":	{"NN"},
"musketeer":	{"NN"},
"musketeers":	{"NNS"},
"musketry":	{"NN"},
"muskets":	{"NNS"},
"muskhogean":	{"NN"},
"muskiness":	{"NN"},
"muskmelon":	{"NN"},
"muskmelons":	{"NNS"},
"muskogean":	{"NN"},
"muskogee":	{"NN"},
"muskrat":	{"NN"},
"muskrats":	{"NNS"},
"muskwood":	{"NN"},
"musky":	{"JJ"},
"musky-scented":	{"JJ"},
"muslimah":	{"NN"},
"muslimism":	{"NN"},
"muslin":	{"NN"},
"muslins":	{"NNS"},
"musnud":	{"NN"},
"musophaga":	{"NN"},
"musophagidae":	{"NN"},
"musophobia":	{"NN"},
"musquash":	{"NN","NNS"},
"musquashes":	{"NNS"},
"muss":	{"VB","VBP","NN"},
"mussed":	{"VBD","VBN"},
"mussel":	{"NN"},
"mussels":	{"NNS"},
"musses":	{"VBZ"},
"musset":	{"NN"},
"mussiness":	{"NN"},
"mussing":	{"VBG"},
"mussitate":	{"VB","VBP"},
"mussitated":	{"VBD","VBN"},
"mussitates":	{"VBZ"},
"mussitating":	{"VBG"},
"mussitation":	{"NN"},
"mussolini-like":	{"JJ"},
"mussy":	{"JJ"},
"must":	{"MD","NN"},
"must-sign":	{"JJ"},
"musta":	{"MD"},
"mustache":	{"NN"},
"mustached":	{"JJ"},
"mustaches":	{"NNS"},
"mustachio":	{"NN"},
"mustachioed":	{"JJ"},
"mustachios":	{"NNS"},
"mustagh":	{"NN"},
"mustang":	{"NN"},
"mustangs":	{"NNS"},
"mustard":	{"NN"},
"mustards":	{"NNS"},
"mustela":	{"NN"},
"mustelid":	{"NN"},
"mustelidae":	{"NN"},
"musteline":	{"NN"},
"mustelus":	{"NN"},
"muster":	{"VB","VBP","NN"},
"mustered":	{"VBD","VBN"},
"mustering":	{"VBG"},
"musters":	{"VBZ","NNS"},
"musth":	{"NN"},
"mustier":	{"JJR"},
"mustiest":	{"JJS"},
"mustiness":	{"NN"},
"musting":	{"VBG"},
"musts":	{"NNS","VBZ"},
"musty":	{"JJ"},
"musuem":	{"NN"},
"mutability":	{"NN"},
"mutable":	{"JJ"},
"mutableness":	{"NN"},
"mutafacient":	{"JJ"},
"mutagen":	{"NN"},
"mutagenesis":	{"NN"},
"mutagenic":	{"JJ"},
"mutamycin":	{"NN"},
"mutant":	{"JJ","NN"},
"mutants":	{"NNS"},
"mutate":	{"VB","VBP"},
"mutated":	{"VBD","VBN"},
"mutates":	{"VBZ"},
"mutating":	{"VBG"},
"mutation":	{"NN"},
"mutational":	{"JJ"},
"mutations":	{"NNS"},
"mutative":	{"JJ"},
"mutawa":	{"NN"},
"mutawa'een":	{"NN"},
"mutchkin":	{"NN"},
"mute":	{"JJ","NN","VB","VBP"},
"muted":	{"VBD","VBN","JJ"},
"mutely":	{"RB"},
"muteness":	{"NN"},
"mutes":	{"VBZ"},
"mutilate":	{"VB","VBP"},
"mutilated":	{"VBD","VBN"},
"mutilates":	{"VBZ"},
"mutilating":	{"VBG"},
"mutilation":	{"NN"},
"mutilations":	{"NNS"},
"mutilator":	{"NN"},
"mutilators":	{"NNS"},
"mutillidae":	{"NN"},
"mutineer":	{"NN"},
"mutineers":	{"NNS"},
"muting":	{"VBG"},
"mutinied":	{"VBD","VBN"},
"mutinies":	{"NNS","VBZ"},
"mutinous":	{"JJ"},
"mutinously":	{"RB"},
"mutinus":	{"NN"},
"mutiny":	{"NN","VB","VBP"},
"mutinying":	{"VBG"},
"mutisia":	{"NN"},
"mutism":	{"NN"},
"muton":	{"NN"},
"mutsuhito":	{"NN"},
"mutt":	{"NN"},
"mutter":	{"VB","VBP","NN"},
"muttered":	{"VBD","VBN"},
"mutterer":	{"NN"},
"mutterers":	{"NNS"},
"muttering":	{"NN","VBG"},
"mutterings":	{"NNS"},
"mutters":	{"VBZ","NNS"},
"mutton":	{"NN"},
"mutton-head":	{"NN"},
"muttonfish":	{"NN"},
"muttonhead":	{"NN"},
"mutts":	{"NNS"},
"mutual":	{"JJ"},
"mutual-aid":	{"JJ"},
"mutual-assured":	{"JJ"},
"mutual-fund":	{"NN"},
"mutual-funds":	{"NNS"},
"mutualism":	{"NN"},
"mutualist":	{"JJ"},
"mutuality":	{"NN"},
"mutually":	{"RB"},
"mutualness":	{"NN"},
"muumuu":	{"NN"},
"muy":	{"NN"},
"muzhik":	{"NN"},
"muzjik":	{"NN"},
"muztag":	{"NN"},
"muztagh":	{"NN"},
"muzzier":	{"JJR"},
"muzziest":	{"JJS"},
"muzzle":	{"NN","VB","VBP"},
"muzzle-loading":	{"JJ"},
"muzzled":	{"VBD","VBN"},
"muzzler":	{"NN"},
"muzzles":	{"NNS","VBZ"},
"muzzling":	{"VBG","NN"},
"muzzlings":	{"NNS"},
"muzzy":	{"JJ"},
"mv":	{"NN"},
"mwanza":	{"NN"},
"mwera":	{"NN"},
"mx":	{"NN"},
"mx-missile":	{"NN"},
"my":	{"PRP$"},
"mya":	{"NN"},
"myaceae":	{"NN"},
"myacidae":	{"NN"},
"myadestes":	{"NNS"},
"myalgia":	{"NN"},
"myalgic":	{"JJ"},
"myasthenia":	{"NN"},
"mycelium":	{"NN"},
"mycenaen":	{"NN"},
"mycetophilidae":	{"NN"},
"mycobacteria":	{"NNS"},
"mycobacteriaceae":	{"NN"},
"mycobacterium":	{"NN"},
"mycologist":	{"NN"},
"mycology":	{"NN"},
"mycomycin":	{"NN"},
"mycophage":	{"NN"},
"mycophagist":	{"NN"},
"mycophagy":	{"NN"},
"mycoplasma":	{"NN"},
"mycoplasmataceae":	{"NN"},
"mycoplasmatales":	{"NNS"},
"mycosis":	{"NN"},
"mycostatin":	{"NN"},
"mycotoxin":	{"NN"},
"mycrosporidia":	{"NN"},
"mycteria":	{"NN"},
"mycteroperca":	{"NN"},
"myctophidae":	{"NN"},
"mydriasis":	{"NN"},
"mydriatic":	{"JJ"},
"myelatelia":	{"NN"},
"myelencephalon":	{"NN"},
"myelic":	{"JJ"},
"myelin":	{"NN"},
"myelinated":	{"JJ"},
"myeline":	{"NN"},
"myelinic":	{"JJ"},
"myelinisation":	{"NN"},
"myelinization":	{"NN"},
"myelitis":	{"NN"},
"myeloblast":	{"NN"},
"myelocyte":	{"NN"},
"myelodysplasia":	{"NN"},
"myelodysplasias":	{"NNS"},
"myelodysplastic":	{"JJ"},
"myelofibrosis":	{"NN"},
"myelogenous":	{"JJ"},
"myelogram":	{"NN"},
"myelography":	{"NN"},
"myeloid":	{"JJ"},
"myeloma":	{"NN"},
"myelomeningocele":	{"NN"},
"myg":	{"NN"},
"myiasis":	{"NN"},
"mylanta":	{"NN"},
"mylar":	{"NN"},
"myliobatidae":	{"NN"},
"mylitta":	{"NN"},
"mylodon":	{"NN"},
"mylodontid":	{"NN"},
"mylodontidae":	{"NN"},
"mym":	{"NN"},
"myn":	{"PRP$"},
"myna":	{"NN"},
"mynah":	{"NN"},
"myne":	{"PRP$"},
"myocardial":	{"JJ"},
"myocardiopathy":	{"NN"},
"myocarditis":	{"NN"},
"myocardium":	{"NN"},
"myocastor":	{"NN"},
"myoclonus":	{"NN"},
"myodynia":	{"NN"},
"myofibril":	{"NN"},
"myofibrilla":	{"NN"},
"myofibrillae":	{"NNS"},
"myofibrils":	{"NNS"},
"myoglobin":	{"NN"},
"myoglobinuria":	{"NN"},
"myogram":	{"NN"},
"myoid":	{"JJ"},
"myology":	{"NN"},
"myoma":	{"NN"},
"myometritis":	{"NN"},
"myometrium":	{"NN"},
"myomorpha":	{"NN"},
"myonecrosis":	{"NN"},
"myopathic":	{"JJ"},
"myopathy":	{"NN"},
"myope":	{"NN"},
"myopia":	{"NN"},
"myopic":	{"JJ"},
"myopically":	{"RB"},
"myopus":	{"NN"},
"myosarcoma":	{"NN"},
"myosin":	{"NN"},
"myosis":	{"NN"},
"myositis":	{"NN"},
"myosotis":	{"NN"},
"myotic":	{"JJ"},
"myotis":	{"NN"},
"myotomy":	{"NN"},
"myotonia":	{"NN"},
"myotonic":	{"JJ"},
"myrcia":	{"NN"},
"myrciaria":	{"NN"},
"myrdal":	{"NN"},
"myriad":	{"JJ","NN"},
"myriads":	{"NNS"},
"myriagram":	{"NN"},
"myriameter":	{"NN"},
"myriametre":	{"NN"},
"myriapod":	{"NN"},
"myriapoda":	{"NN"},
"myrica":	{"NN"},
"myricaceae":	{"NN"},
"myricales":	{"NNS"},
"myricaria":	{"NN"},
"myringa":	{"NN"},
"myringectomy":	{"NN"},
"myringoplasty":	{"NN"},
"myringotomy":	{"NN"},
"myriophyllum":	{"NN"},
"myristica":	{"NN"},
"myristicaceae":	{"NN"},
"myrmecia":	{"NN"},
"myrmecobius":	{"NN"},
"myrmecophaga":	{"NN"},
"myrmecophagidae":	{"NN"},
"myrmecophagous":	{"JJ"},
"myrmecophile":	{"NN"},
"myrmecophilous":	{"JJ"},
"myrmecophyte":	{"NN"},
"myrmecophytic":	{"JJ"},
"myrmeleon":	{"NN"},
"myrmeleontidae":	{"NN"},
"myrmidon":	{"NN"},
"myrobalan":	{"NN"},
"myroxylon":	{"NN"},
"myrrh":	{"NN"},
"myrrhis":	{"NN"},
"myrsinaceae":	{"NN"},
"myrsine":	{"NN"},
"myrtaceae":	{"NN"},
"myrtales":	{"NNS"},
"myrtillocactus":	{"NN"},
"myrtle":	{"NN"},
"myrtles":	{"NNS"},
"myrtus":	{"NN"},
"myself":	{"PRP"},
"mysidacea":	{"NN"},
"mysidae":	{"NN"},
"mysis":	{"NN"},
"mysoline":	{"NN"},
"mysophilia":	{"NN"},
"mysophobia":	{"NN"},
"mysophobic":	{"JJ"},
"mysore":	{"NN"},
"mysteries":	{"NNS"},
"mysterious":	{"JJ"},
"mysteriously":	{"RB"},
"mystery":	{"NN"},
"mystery-story":	{"JJ"},
"mystic":	{"JJ","NN"},
"mystical":	{"JJ"},
"mystically":	{"RB"},
"mysticeti":	{"NN"},
"mysticism":	{"NN"},
"mystics":	{"NNS"},
"mystification":	{"NN"},
"mystified":	{"VBD","VBN"},
"mystifier":	{"NN"},
"mystifies":	{"VBZ"},
"mystify":	{"VB","VBP"},
"mystifying":	{"VBG","JJ"},
"mystique":	{"NN"},
"myth":	{"NN"},
"myth-making":	{"NN"},
"mythic":	{"JJ"},
"mythical":	{"JJ"},
"mythicisation":	{"NN"},
"mythicise":	{"VB","VBP"},
"mythicised":	{"VBD","VBN"},
"mythiciser":	{"NN"},
"mythicises":	{"VBZ"},
"mythicising":	{"VBG"},
"mythicist":	{"NN"},
"mythicization":	{"NN"},
"mythicize":	{"VB","VBP"},
"mythicized":	{"VBD","VBN"},
"mythicizer":	{"NN"},
"mythicizes":	{"VBZ"},
"mythicizing":	{"VBG"},
"mythologer":	{"NN"},
"mythologic":	{"JJ"},
"mythological":	{"JJ"},
"mythologies":	{"NNS"},
"mythologisation":	{"NN"},
"mythologise":	{"VB","VBP"},
"mythologised":	{"VBD","VBN"},
"mythologiser":	{"NN"},
"mythologises":	{"VBZ"},
"mythologising":	{"VBG"},
"mythologist":	{"NN"},
"mythologization":	{"NN"},
"mythologize":	{"VB","VBP"},
"mythologized":	{"VBD","VBN"},
"mythologizer":	{"NN"},
"mythologizes":	{"VBZ"},
"mythologizing":	{"VBG"},
"mythology":	{"NN"},
"myths":	{"NNS"},
"mytilene":	{"NN"},
"mytilid":	{"NN"},
"mytilidae":	{"NN"},
"mytilus":	{"NN"},
"myxedema":	{"NN"},
"myxine":	{"NN"},
"myxinidae":	{"NN"},
"myxiniformes":	{"NNS"},
"myxinikela":	{"NN"},
"myxinoidea":	{"NN"},
"myxinoidei":	{"NN"},
"myxobacter":	{"NN"},
"myxobacterales":	{"NNS"},
"myxobacteria":	{"NN"},
"myxobacteriaceae":	{"NN"},
"myxobacteriales":	{"NNS"},
"myxobacterium":	{"NN"},
"myxocephalus":	{"NN"},
"myxoedema":	{"NN"},
"myxoma":	{"NN"},
"myxomatosis":	{"NN"},
"myxomycete":	{"NN"},
"myxomycetes":	{"NNS"},
"myxomycota":	{"NN"},
"myxophyceae":	{"NN"},
"myxosporidia":	{"NN"},
"myxosporidian":	{"NN"},
"myxovirus":	{"NN"},
"n":	{"NN","SYM","LS"},
"n'djamena":	{"NN"},
"n't":	{"RB"},
"n-dimensional":	{"JJ"},
"n-th":	{"JJ"},
"n-trial":	{"NN"},
"n.b.":	{"NN"},
"na":	{"TO"},
"na-dene":	{"NN"},
"naan":	{"NN"},
"naans":	{"NNS"},
"nab":	{"VB","VBP"},
"nabalus":	{"NN"},
"nabbed":	{"VBD","VBN"},
"nabbing":	{"VBG","NN"},
"nablus":	{"NN"},
"nabob":	{"NN"},
"naboom":	{"NN"},
"nabs":	{"VBZ"},
"nabu":	{"NN"},
"nabumetone":	{"NN"},
"nac":	{"NN"},
"nacelle":	{"NN"},
"nacho":	{"NN"},
"nacho-crunching":	{"JJ"},
"nacimiento":	{"NN"},
"nacre":	{"NN"},
"nacreous":	{"JJ"},
"naczelnik":	{"FW"},
"nad":	{"NN"},
"nada":	{"NN"},
"naderite":	{"NN"},
"naderites":	{"NNS"},
"nadir":	{"NN"},
"nadolol":	{"NN"},
"nadp":	{"NN"},
"naemorhedus":	{"NN"},
"nafcil":	{"NN"},
"nafcillin":	{"NN"},
"nafta":	{"NN"},
"nafud":	{"NN"},
"nag":	{"VB","VBP","NN"},
"naga":	{"NN"},
"nagami":	{"NN"},
"nagano":	{"NN"},
"nagari":	{"NN"},
"nageia":	{"NN"},
"nagged":	{"VBD","VBN"},
"nagger":	{"NN"},
"nagging":	{"JJ","VBG","NN"},
"naggings":	{"NNS"},
"nagi":	{"NN"},
"nagoya":	{"NN"},
"nags":	{"VBZ","NNS"},
"nagy":	{"NN"},
"nah":	{"RB","UH"},
"nahce":	{"JJ"},
"nahuatl":	{"NN"},
"naiad":	{"NN"},
"naiadaceae":	{"NN"},
"naiadales":	{"NNS"},
"naiades":	{"NNS"},
"naiads":	{"NNS"},
"naiant":	{"JJ"},
"naias":	{"NN"},
"naif":	{"NN","JJ"},
"naiki":	{"NN"},
"nail":	{"NN","VB","VBP"},
"nail-biting":	{"JJ","NN"},
"nailbrush":	{"NN"},
"nailbrushes":	{"NNS"},
"nailed":	{"VBN","VBD"},
"nailer":	{"NN"},
"nailers":	{"NNS"},
"nailfile":	{"NN"},
"nailhead":	{"NN"},
"nailing":	{"NN","VBG"},
"nailings":	{"NNS"},
"nailrod":	{"NN"},
"nails":	{"NNS","VBZ"},
"nainsook":	{"NN"},
"naira":	{"NN","NNS"},
"naismith":	{"NN"},
"naissance":	{"NN"},
"naive":	{"JJ"},
"naively":	{"RB"},
"naiveness":	{"NN"},
"naivete":	{"NN"},
"naivety":	{"NN"},
"naja":	{"NN"},
"najadaceae":	{"NN"},
"najas":	{"NNS"},
"najd":	{"NN"},
"naked":	{"JJ"},
"naked-muzzled":	{"JJ"},
"naked-tailed":	{"JJ"},
"nakedly":	{"RB"},
"nakedness":	{"NN"},
"nakedwood":	{"NN"},
"nakuru":	{"NN"},
"nalchik":	{"NN"},
"nalfon":	{"NN"},
"nalline":	{"NN"},
"nalorphine":	{"NN"},
"naloxone":	{"NN"},
"naltrexone":	{"NN"},
"namby-pambies":	{"NNS"},
"namby-pamby":	{"JJ","NN"},
"name":	{"NN","VB","VBP"},
"name-brand":	{"JJ"},
"name-calling":	{"NN"},
"name-day":	{"NN"},
"name-drop":	{"VB","VBP"},
"name-dropped":	{"VBD","VBN"},
"name-dropper":	{"NN"},
"name-droppers":	{"NNS"},
"name-dropping":	{"NN","VBG"},
"name-drops":	{"VBZ"},
"name-part":	{"NN"},
"name-plate":	{"NN"},
"name-plating":	{"JJ"},
"name-tape":	{"NN"},
"name-tapes":	{"NNS"},
"named":	{"VBN","VBD"},
"nameko":	{"NN"},
"nameless":	{"JJ","NN"},
"namelessness":	{"NN"},
"namely":	{"RB"},
"nameplate":	{"NN"},
"nameplates":	{"NNS"},
"namer":	{"NN"},
"names":	{"NNS","VBZ"},
"namesake":	{"NN"},
"namesakes":	{"NNS"},
"naming":	{"VBG"},
"nammad":	{"NN"},
"nammu":	{"NN"},
"namoi":	{"NN"},
"nampa":	{"NN"},
"namtar":	{"NN"},
"namtaru":	{"NN"},
"namur":	{"NN"},
"nan":	{"NN"},
"nan-chang":	{"NN"},
"nan-ning":	{"NN"},
"nanaimo":	{"NN"},
"nance":	{"NN"},
"nancere":	{"NN"},
"nanchang":	{"NN"},
"nandrolone":	{"NN"},
"nandu":	{"NN"},
"nanism":	{"NN"},
"nanjing":	{"NN"},
"nankeen":	{"NN"},
"nanna":	{"NN"},
"nannie":	{"NN"},
"nannies":	{"NNS"},
"nanning":	{"NN"},
"nanny":	{"NN"},
"nanny-goat":	{"NN"},
"nanny-goats":	{"NNS"},
"nano":	{"NN"},
"nanocephalic":	{"JJ"},
"nanocephaly":	{"NN"},
"nanogram":	{"NN"},
"nanometer":	{"NN"},
"nanometre":	{"NN"},
"nanomia":	{"NN"},
"nanophase":	{"NN"},
"nanophthalmos":	{"NNS"},
"nanopores":	{"NNS"},
"nanoprobe":	{"NN"},
"nanoprobes":	{"NNS"},
"nanosecond":	{"NN"},
"nanostructure":	{"NN"},
"nanotechnology":	{"NN"},
"nanotube":	{"NN"},
"nanovolt":	{"NN"},
"nanowire":	{"NN"},
"nanowires":	{"NNS"},
"nansen":	{"NN"},
"nantes":	{"NNS"},
"nanticoke":	{"NN"},
"nantua":	{"NN"},
"nanus":	{"NN"},
"nap":	{"NN","VB","VBP"},
"napa":	{"NN"},
"napaea":	{"NN"},
"napalm":	{"NN","VB","VBP"},
"napalmed":	{"VBD","VBN"},
"napalming":	{"VBG"},
"napalms":	{"VBZ"},
"nape":	{"NN"},
"napery":	{"NN"},
"napes":	{"NNS"},
"naphazoline":	{"NN"},
"naphtha":	{"NN"},
"naphthalene":	{"NN"},
"naphthol":	{"NN"},
"naphthoquinone":	{"NN"},
"napier":	{"NN"},
"napkin":	{"NN"},
"napkins":	{"NNS"},
"napoli":	{"NN"},
"napped":	{"VBD","VBN"},
"nappies":	{"NNS"},
"napping":	{"VBG"},
"nappy":	{"NN","JJ"},
"naprapath":	{"NN"},
"naprapathy":	{"NN"},
"naprosyn":	{"NN"},
"naproxen":	{"NN"},
"naps":	{"VBZ","NNS"},
"naptime":	{"NN"},
"napu":	{"NN"},
"naqua":	{"NN"},
"nara":	{"NN"},
"naranjilla":	{"NN"},
"narc":	{"NN","VBP","VB"},
"narcan":	{"NN"},
"narced":	{"VBD","VBN"},
"narcism":	{"NN"},
"narcissi":	{"NNS"},
"narcissism":	{"NN"},
"narcissist":	{"NN"},
"narcissistic":	{"JJ"},
"narcissistically":	{"RB"},
"narcissists":	{"NNS"},
"narcissus":	{"NN"},
"narcissuses":	{"NNS"},
"narcist":	{"NN"},
"narco":	{"NN"},
"narco-state":	{"NN"},
"narcokleptocrat":	{"NN"},
"narcolepsy":	{"NN"},
"narcoleptic":	{"JJ","NN"},
"narcos":	{"NNS"},
"narcosis":	{"NN"},
"narcoterrorism":	{"NN"},
"narcotic":	{"NN","JJ"},
"narcotics":	{"NNS"},
"narcotise":	{"VB","VBP"},
"narcotised":	{"VBD","VBN"},
"narcotises":	{"VBZ"},
"narcotising":	{"VBG"},
"narcotize":	{"VB","VBP"},
"narcotized":	{"VBD","VBN"},
"narcotizes":	{"VBZ"},
"narcotizing":	{"VBG"},
"narcotraffic":	{"NN"},
"narcotraficantes":	{"FW"},
"narcs":	{"NNS","VBZ"},
"nard":	{"NN"},
"nardil":	{"NN"},
"nardo":	{"NN"},
"nardoo":	{"NN"},
"narghile":	{"NN"},
"nargileh":	{"NN"},
"narial":	{"JJ"},
"naring":	{"VBG"},
"naris":	{"NN"},
"nark":	{"NN","VB","VBP"},
"narked":	{"VBD","VBN","JJ"},
"narking":	{"VBG"},
"narks":	{"NNS","VBZ"},
"narratage":	{"NN"},
"narrate":	{"VB","VBP"},
"narrated":	{"VBD","VBN"},
"narrates":	{"VBZ"},
"narrating":	{"VBG"},
"narration":	{"NN"},
"narrations":	{"NNS"},
"narrative":	{"NN","JJ"},
"narratives":	{"NNS"},
"narrator":	{"NN"},
"narrators":	{"NNS"},
"narrow":	{"JJ","VB","VBP"},
"narrow-bodied":	{"JJ"},
"narrow-body":	{"NN"},
"narrow-casting":	{"NN"},
"narrow-gauged":	{"JJ"},
"narrow-minded":	{"JJ"},
"narrow-mindedly":	{"RB"},
"narrow-mindedness":	{"NN"},
"narrow-mouthed":	{"JJ"},
"narrowboat":	{"NN"},
"narrowed":	{"VBN","VBD"},
"narrower":	{"JJR"},
"narrowest":	{"JJS"},
"narrowing":	{"VBG"},
"narrowly":	{"RB"},
"narrowness":	{"NN"},
"narrows":	{"VBZ","NNS"},
"narthecium":	{"NN"},
"narthex":	{"NN"},
"narwal":	{"NN"},
"narwhal":	{"NN"},
"narwhale":	{"NN"},
"nary":	{"RB"},
"nasal":	{"NN","JJ"},
"nasale":	{"FW"},
"nasalis":	{"NN"},
"nasalisation":	{"NN"},
"nasalise":	{"VB","VBP"},
"nasalised":	{"VBD","VBN"},
"nasalises":	{"VBZ"},
"nasalising":	{"VBG"},
"nasality":	{"NN"},
"nasalization":	{"NN"},
"nasalize":	{"VB","VBP"},
"nasalized":	{"VBD","VBN"},
"nasalizes":	{"VBZ"},
"nasalizing":	{"VBG"},
"nasally":	{"RB"},
"nasals":	{"NNS"},
"nascence":	{"NN"},
"nascency":	{"NN"},
"nascent":	{"JJ"},
"nasdaq-traded":	{"JJ"},
"naseby":	{"NN"},
"nasion":	{"NN"},
"nasopharyngeal":	{"JJ"},
"nasopharynx":	{"NN"},
"nast":	{"NN"},
"nastier":	{"JJR"},
"nastiest":	{"JJS"},
"nastily":	{"RB"},
"nastiness":	{"NN"},
"nasturtium":	{"NN"},
"nasturtiums":	{"NNS"},
"nasty":	{"JJ"},
"nasua":	{"NN"},
"natal":	{"JJ"},
"natality":	{"NN"},
"natantia":	{"NN"},
"natation":	{"NN"},
"natator":	{"NN"},
"natatorium":	{"NN"},
"natch":	{"RB"},
"natchez":	{"NN"},
"nates":	{"NNS"},
"naticidae":	{"NN"},
"nation":	{"NN"},
"nation-building":	{"NN","JJ"},
"nation-state":	{"NN"},
"nation-states":	{"NNS"},
"nation-wide":	{"JJ","RB"},
"national":	{"JJ","NN"},
"national-policy":	{"NN"},
"national-priority":	{"JJ"},
"national-security":	{"NN","JJ"},
"national-service":	{"JJ","NN"},
"national-treasure":	{"JJ"},
"nationalisation":	{"NN"},
"nationalisations":	{"NNS"},
"nationalise":	{"VB","VBP"},
"nationalised":	{"VBD","VBN"},
"nationalises":	{"VBZ"},
"nationalising":	{"VBG"},
"nationalism":	{"NN"},
"nationalist":	{"JJ","NN"},
"nationalistic":	{"JJ"},
"nationalists":	{"NNS"},
"nationalities":	{"NNS"},
"nationality":	{"NN"},
"nationalization":	{"NN"},
"nationalizations":	{"NNS"},
"nationalize":	{"VB","VBP"},
"nationalized":	{"VBD","VBN"},
"nationalizes":	{"VBZ"},
"nationalizing":	{"VBG"},
"nationally":	{"RB"},
"nationals":	{"NNS"},
"nationhood":	{"NN"},
"nations":	{"NNS"},
"nations-monitored":	{"JJ"},
"nationwide":	{"JJ","RB"},
"native":	{"JJ","NN"},
"native-born":	{"JJ"},
"nativeness":	{"NN"},
"natives":	{"NNS"},
"nativism":	{"NN"},
"nativist":	{"JJ","NN"},
"nativistic":	{"JJ"},
"nativities":	{"NNS"},
"nativity":	{"NN"},
"nato-led":	{"JJ"},
"natriuresis":	{"NN"},
"natriuretic":	{"NN","JJ"},
"natrix":	{"NN"},
"natrolite":	{"NN"},
"natta":	{"NN"},
"natter":	{"VB","VBP","NN"},
"nattered":	{"VBD","VBN"},
"nattering":	{"VBG"},
"natterjack":	{"NN"},
"natters":	{"VBZ"},
"nattier":	{"JJR"},
"nattiest":	{"JJS"},
"nattily":	{"RB"},
"nattiness":	{"NN"},
"natty":	{"JJ"},
"natural":	{"JJ","NN"},
"natural-foods":	{"NNS"},
"natural-gas":	{"NN","JJ"},
"natural-gas-pipeline":	{"JJ"},
"natural-gas-pricing":	{"JJ"},
"natural-law":	{"NN"},
"naturalisation":	{"NN"},
"naturalise":	{"VB","VBP"},
"naturalised":	{"VBD","VBN","JJ"},
"naturalises":	{"VBZ"},
"naturalising":	{"VBG"},
"naturalism":	{"NN"},
"naturalist":	{"NN"},
"naturalistic":	{"JJ"},
"naturalistically":	{"RB"},
"naturalists":	{"NNS"},
"naturalization":	{"NN"},
"naturalize":	{"VB","VBP"},
"naturalized":	{"JJ","VBD","VBN"},
"naturalizes":	{"VBZ"},
"naturalizing":	{"VBG"},
"naturally":	{"RB"},
"naturalness":	{"NN"},
"naturals":	{"NNS"},
"nature":	{"NN"},
"nature-conquering":	{"JJ"},
"natures":	{"NNS"},
"naturism":	{"NN"},
"naturist":	{"NN"},
"naturistic":	{"JJ"},
"naturists":	{"NNS"},
"naturopath":	{"NN"},
"naturopathic":	{"JJ"},
"naturopathically":	{"RB"},
"naturopaths":	{"NNS"},
"naturopathy":	{"NN"},
"nauch":	{"NN"},
"nauclea":	{"NN"},
"naucrates":	{"NNS"},
"naught":	{"NN"},
"naughtier":	{"JJR"},
"naughtiest":	{"JJS"},
"naughtily":	{"RB"},
"naughtiness":	{"NN"},
"naughty":	{"JJ"},
"naumachia":	{"NN"},
"naumachy":	{"NN"},
"naupathia":	{"NN"},
"nausea":	{"NN"},
"nauseant":	{"NN","JJ"},
"nauseate":	{"VB","VBP"},
"nauseated":	{"VBD","VBN"},
"nauseates":	{"VBZ"},
"nauseating":	{"JJ","VBG"},
"nauseatingly":	{"RB"},
"nauseatingness":	{"NN"},
"nauseous":	{"JJ"},
"nautch":	{"NN"},
"nautical":	{"JJ"},
"nautilidae":	{"NN"},
"nautilus":	{"NN"},
"nautiluses":	{"NNS"},
"naval":	{"JJ"},
"navane":	{"NN"},
"navarino":	{"NN"},
"nave":	{"NN"},
"navel":	{"NN"},
"navel-gazing":	{"NN"},
"navels":	{"NNS"},
"naves":	{"NNS"},
"navicular":	{"JJ","NN"},
"navies":	{"NNS"},
"navigability":	{"NN"},
"navigable":	{"JJ"},
"navigate":	{"VB","VBP"},
"navigated":	{"VBD","VBN"},
"navigates":	{"VBZ"},
"navigating":	{"VBG"},
"navigation":	{"NN"},
"navigational":	{"JJ"},
"navigator":	{"NN"},
"navigators":	{"NNS"},
"navratilova":	{"NN"},
"navvies":	{"NNS"},
"navvy":	{"NN"},
"navy":	{"NN","JJ"},
"naw":	{"NN"},
"nawab":	{"NN"},
"nawcwpns":	{"NNS"},
"nawt":	{"RB"},
"nawth":	{"NN"},
"nay":	{"NN","RB"},
"naysaid":	{"VBD","VBN"},
"naysay":	{"NN","VB","VBP"},
"naysayer":	{"NN"},
"naysayers":	{"NNS"},
"naysaying":	{"VBG"},
"naysays":	{"NNS","VBZ"},
"nazarene":	{"JJ","NN"},
"naze":	{"NN"},
"nazi-minded":	{"JJ"},
"nazi-occupied":	{"JJ"},
"nazification":	{"NN"},
"nazimova":	{"NN"},
"nb":	{"NN"},
"nbc-owned":	{"JJ"},
"nbe":	{"NN"},
"nbw":	{"NN"},
"nc":	{"NN"},
"ncaas":	{"NNS"},
"ncdc":	{"NN"},
"nd":	{"NN"},
"ndebele":	{"NN"},
"ndjamena":	{"NN"},
"ne'er":	{"RB"},
"ne'er-do-well":	{"NN"},
"neandertal":	{"JJ","NN"},
"neanderthal":	{"JJ","NN"},
"neanderthalian":	{"JJ"},
"neanderthals":	{"NNS"},
"neap":	{"NN"},
"near":	{"IN","JJ","RB","VB","VBP"},
"near-absence":	{"NN"},
"near-at-hand":	{"JJ"},
"near-balkanization":	{"NN"},
"near-blind":	{"JJ"},
"near-certain":	{"JJ"},
"near-communists":	{"NNS"},
"near-complete":	{"JJ"},
"near-completed":	{"JJ"},
"near-completion":	{"NN"},
"near-disaster":	{"NN"},
"near-doubling":	{"NN"},
"near-equivalents":	{"NNS"},
"near-hysteria":	{"NN"},
"near-identical":	{"JJ"},
"near-irrelevant":	{"JJ"},
"near-left":	{"NN"},
"near-limit":	{"JJ"},
"near-luxury":	{"JJ"},
"near-maddened":	{"JJ"},
"near-majority":	{"JJ"},
"near-manic":	{"JJ"},
"near-market":	{"JJ"},
"near-misses":	{"NNS"},
"near-monopolies":	{"NNS"},
"near-monopoly":	{"NN","JJ"},
"near-mutiny":	{"NN"},
"near-panic":	{"JJ","NN"},
"near-paralysis":	{"NN"},
"near-perfect":	{"JJ"},
"near-recession":	{"NN"},
"near-record":	{"JJ","NN"},
"near-rich":	{"NN"},
"near-sighted":	{"JJ"},
"near-sightedness":	{"NN"},
"near-solid":	{"JJ"},
"near-strangers":	{"NNS"},
"near-synonyms":	{"NNS"},
"near-term":	{"JJ","NN"},
"near-total":	{"JJ"},
"near-unanimous":	{"JJ"},
"near-unmatched":	{"JJ"},
"nearby":	{"JJ","RB"},
"neared":	{"VBD","VBN"},
"nearer":	{"JJR"},
"nearest":	{"JJS"},
"nearing":	{"VBG"},
"nearly":	{"RB"},
"nearness":	{"NN"},
"nears":	{"VBZ"},
"nearside":	{"NN","JJ"},
"nearsighted":	{"JJ"},
"nearsightedly":	{"RB"},
"nearsightedness":	{"NN"},
"neat":	{"JJ"},
"neaten":	{"VB","VBP"},
"neatened":	{"VBD","VBN"},
"neatening":	{"VBG"},
"neatens":	{"VBZ"},
"neater":	{"JJR"},
"neatest":	{"JJS"},
"neatly":	{"RB"},
"neatness":	{"NN"},
"neb":	{"NN"},
"nebbech":	{"NN"},
"nebbish":	{"NN","JJ"},
"nebcin":	{"NN"},
"nebe":	{"NN"},
"nebiim":	{"NN"},
"nebn":	{"NN"},
"nebo":	{"NN"},
"nebuchadrezzar":	{"NN"},
"nebula":	{"NN"},
"nebulae":	{"NNS"},
"nebular":	{"JJ"},
"nebule":	{"NN"},
"nebulisation":	{"NN"},
"nebulise":	{"VB","VBP"},
"nebulised":	{"VBD","VBN"},
"nebuliser":	{"NN"},
"nebulises":	{"VBZ"},
"nebulising":	{"VBG"},
"nebulization":	{"NN"},
"nebulize":	{"VB","VBP"},
"nebulized":	{"VBD","VBN"},
"nebulizer":	{"NN"},
"nebulizes":	{"VBZ"},
"nebulizing":	{"VBG"},
"nebulose":	{"JJ"},
"nebulous":	{"JJ"},
"nebulously":	{"RB"},
"nec":	{"NN"},
"nec-compatible":	{"JJ"},
"necessaries":	{"NNS"},
"necessarily":	{"RB"},
"necessary":	{"JJ","NN"},
"necessitarian":	{"NN"},
"necessitate":	{"VB","VBP"},
"necessitated":	{"VBD","VBN"},
"necessitates":	{"VBZ"},
"necessitating":	{"VBG"},
"necessities":	{"NNS"},
"necessitous":	{"JJ"},
"necessity":	{"NN"},
"neck":	{"NN","VB","VBP"},
"neck-and-neck":	{"JJ"},
"neck-deep":	{"JJ"},
"neckar":	{"NN"},
"neckband":	{"NN"},
"neckbands":	{"NNS"},
"neckcloth":	{"NN"},
"necked":	{"VBD","VBN"},
"necker":	{"NN"},
"neckerchief":	{"NN"},
"neckerchiefs":	{"NNS"},
"necking":	{"VBG"},
"necklace":	{"NN"},
"necklace-like":	{"JJ"},
"necklaces":	{"NNS"},
"neckless":	{"JJ"},
"necklet":	{"NN"},
"necklets":	{"NNS"},
"necklike":	{"JJ"},
"neckline":	{"NN"},
"necklines":	{"NNS"},
"neckpiece":	{"NN"},
"necks":	{"NNS","VBZ"},
"necktie":	{"NN"},
"neckties":	{"NNS"},
"neckwear":	{"NN"},
"necrobiosis":	{"NN"},
"necrology":	{"NN"},
"necrolysis":	{"NN"},
"necromancer":	{"NN"},
"necromancers":	{"NNS"},
"necromancy":	{"NN"},
"necromania":	{"NN"},
"necromantic":	{"JJ"},
"necromantical":	{"JJ"},
"necrophagia":	{"NN"},
"necrophagy":	{"NN"},
"necrophilia":	{"NN"},
"necrophilism":	{"NN"},
"necropolis":	{"NN"},
"necropolises":	{"NNS"},
"necropsies":	{"NNS"},
"necropsy":	{"NN"},
"necrose":	{"VB","VBP"},
"necrosed":	{"VBD","VBN"},
"necroses":	{"VBZ"},
"necrosing":	{"VBG"},
"necrosis":	{"NN"},
"necrotic":	{"JJ"},
"nectar":	{"NN"},
"nectar-rich":	{"JJ"},
"nectareous":	{"JJ"},
"nectarial":	{"JJ"},
"nectaries":	{"NNS"},
"nectariferous":	{"JJ"},
"nectarine":	{"NN"},
"nectarines":	{"NNS"},
"nectarous":	{"JJ"},
"nectary":	{"NN"},
"necturus":	{"NN"},
"nederland":	{"NN"},
"nee":	{"JJ"},
"need":	{"VB","NN","MD","VBP"},
"needed":	{"VBD","VBN"},
"needer":	{"NN"},
"needful":	{"JJ"},
"needfully":	{"RB"},
"needier":	{"JJR"},
"neediest":	{"JJS"},
"neediness":	{"NN"},
"needing":	{"VBG"},
"needle":	{"NN","VBP","VB"},
"needle-bush":	{"NN"},
"needle-like":	{"JJ"},
"needle-nosed":	{"JJ"},
"needle-shaped":	{"JJ"},
"needle-sharp":	{"JJ"},
"needle-wood":	{"NN"},
"needlebush":	{"NN"},
"needlecraft":	{"NN"},
"needled":	{"VBD","VBN"},
"needlefish":	{"NN"},
"needlelike":	{"JJ","NN"},
"needlepoint":	{"NN"},
"needles":	{"NNS","VBZ"},
"needless":	{"JJ"},
"needlessly":	{"RB"},
"needlewoman":	{"NN"},
"needlewomen":	{"NNS"},
"needlewood":	{"NN"},
"needlework":	{"NN"},
"needleworker":	{"NN"},
"needling":	{"VBG"},
"needs":	{"VBZ","NNS","RB"},
"needy":	{"JJ","NNS"},
"neel":	{"NN"},
"neem":	{"NN"},
"neencephalon":	{"NN"},
"neets":	{"NNS"},
"nefarious":	{"JJ"},
"nefariously":	{"RB"},
"nefariousness":	{"NN"},
"nefazodone":	{"NN"},
"nefertiti":	{"NN"},
"neff":	{"NN"},
"nefud":	{"NN"},
"negaprion":	{"NN"},
"negate":	{"VB","VBP"},
"negated":	{"VBD","VBN"},
"negates":	{"VBZ"},
"negating":	{"VBG"},
"negation":	{"NN"},
"negative":	{"JJ","NN","VB","VBP"},
"negatived":	{"VBD","VBN"},
"negatively":	{"RB"},
"negativeness":	{"NN"},
"negatives":	{"NNS","VBZ"},
"negativing":	{"VBG"},
"negativism":	{"NN"},
"negativist":	{"NN"},
"negativity":	{"NN"},
"negatron":	{"NN"},
"negev":	{"NN"},
"neggram":	{"NN"},
"neglect":	{"VB","VBP","NN"},
"neglected":	{"VBN","VBD","JJ"},
"neglecter":	{"NN"},
"neglectful":	{"JJ"},
"neglectfully":	{"RB"},
"neglectfulness":	{"NN"},
"neglecting":	{"VBG"},
"neglects":	{"VBZ"},
"neglige":	{"NN"},
"negligee":	{"NN"},
"negligence":	{"NN"},
"negligent":	{"JJ"},
"negligent-homicide":	{"NN"},
"negligently":	{"RB"},
"negligible":	{"JJ"},
"negligibly":	{"RB"},
"negociant":	{"NN"},
"negociants":	{"NNS"},
"negociate":	{"VB","VBP"},
"negotiable":	{"JJ"},
"negotiant":	{"NN"},
"negotiants":	{"NNS"},
"negotiate":	{"VB","VBP"},
"negotiated":	{"VBN","VBD"},
"negotiates":	{"VBZ"},
"negotiating":	{"VBG","NN"},
"negotiation":	{"NN"},
"negotiations":	{"NNS"},
"negotiator":	{"NN"},
"negotiators":	{"NNS"},
"negotiatress":	{"NN"},
"negotiatresses":	{"NNS"},
"negotiatrices":	{"NNS"},
"negotiatrix":	{"NN"},
"negritude":	{"NN"},
"negro-appeal":	{"JJ"},
"negroid":	{"JJ","NN"},
"negus":	{"NN"},
"neige":	{"FW"},
"neigh":	{"NN","VB","VBP"},
"neighbhorhoods":	{"NNS"},
"neighbor":	{"NN","VB","VBP"},
"neighbored":	{"VBD","VBN"},
"neighborhood":	{"NN"},
"neighborhoods":	{"NNS"},
"neighboring":	{"VBG","JJ"},
"neighborliness":	{"NN"},
"neighborly":	{"JJ"},
"neighbors":	{"NNS","VBZ"},
"neighbour":	{"NN","VB","VBP"},
"neighboured":	{"VBD","VBN"},
"neighbourhood":	{"NN"},
"neighbourhoods":	{"NNS"},
"neighbouring":	{"VBG","JJ"},
"neighbourliness":	{"NN"},
"neighbourly":	{"JJ"},
"neighbours":	{"NNS","VBZ"},
"neighed":	{"VBD","VBN"},
"neighing":	{"VBG"},
"neighs":	{"VBZ","NNS"},
"nein":	{"NN"},
"neither":	{"DT","RB","CC"},
"nejd":	{"NN"},
"nekton":	{"NN"},
"nelfinavir":	{"NN"},
"nell":	{"NN"},
"nellie":	{"NN","JJ"},
"nellies":	{"NNS"},
"nelly":	{"NN","JJ"},
"nelumbo":	{"NN"},
"nelumbonaceae":	{"NN"},
"nematocera":	{"NN"},
"nematoda":	{"NN"},
"nematode":	{"NN","JJ"},
"nemea":	{"NN"},
"nemertea":	{"NN"},
"nemertean":	{"NN"},
"nemertina":	{"NN"},
"nemertine":	{"NN"},
"nemeses":	{"NNS"},
"nemesis":	{"NN"},
"nemophila":	{"NN"},
"nenets":	{"NN","NNS"},
"nentsi":	{"NN"},
"nentsy":	{"NNS"},
"neo-classical":	{"JJ"},
"neo-classicism":	{"NN"},
"neo-dadaist":	{"NN"},
"neo-darwinian":	{"JJ"},
"neo-darwinism":	{"NN"},
"neo-fascism":	{"NN"},
"neo-fascist":	{"NN","JJ"},
"neo-fascists":	{"NNS"},
"neo-lamarckian":	{"JJ"},
"neo-lamarckism":	{"NN"},
"neo-latin":	{"NN"},
"neo-populist":	{"JJ"},
"neo-stagnationist":	{"JJ"},
"neo-swing":	{"NN"},
"neobiotic":	{"NN"},
"neoceratodus":	{"NN"},
"neoclassic":	{"JJ"},
"neoclassical":	{"JJ"},
"neoclassicism":	{"NN"},
"neoclassicist":	{"JJ"},
"neoclassicistic":	{"JJ"},
"neocolonialism":	{"NN"},
"neocon":	{"NN"},
"neoconservatism":	{"NN"},
"neoconservative":	{"NN"},
"neocortex":	{"NN"},
"neocortical":	{"JJ"},
"neocortical-hypothalamic":	{"JJ"},
"neodymium":	{"NN"},
"neoencephalon":	{"NN"},
"neoexpressionism":	{"NN"},
"neofiber":	{"NN"},
"neohygrophorus":	{"NN"},
"neoimperialism":	{"NN"},
"neoimperialisms":	{"NNS"},
"neoimperialist":	{"NN"},
"neoimperialists":	{"NNS"},
"neolentinus":	{"NN"},
"neoliberal":	{"NN"},
"neoliberalism":	{"NN"},
"neolith":	{"NN"},
"neolithic":	{"JJ"},
"neologism":	{"NN"},
"neologisms":	{"NNS"},
"neologist":	{"NN"},
"neology":	{"NN"},
"neomycin":	{"NN"},
"neomys":	{"NN"},
"neon":	{"NN"},
"neon-lighted":	{"JJ"},
"neon-lit":	{"JJ"},
"neonatal":	{"JJ"},
"neonate":	{"NN"},
"neonatology":	{"NN"},
"neonicotinoid":	{"NN"},
"neonicotinoids":	{"NNS"},
"neonics":	{"NNS"},
"neopallium":	{"NN"},
"neophobia":	{"NN"},
"neophron":	{"NN"},
"neophyte":	{"NN"},
"neophytes":	{"NNS"},
"neoplasia":	{"NN"},
"neoplasm":	{"NN"},
"neoplastic":	{"JJ"},
"neoplatonism":	{"NN"},
"neoplatonist":	{"NN"},
"neopolitan":	{"NN"},
"neoprene":	{"NN"},
"neoromanticism":	{"NN"},
"neosho":	{"NN"},
"neosporin":	{"NN"},
"neostigmine":	{"NN"},
"neotenic":	{"JJ"},
"neotenous":	{"JJ"},
"neoteny":	{"NN"},
"neotoma":	{"NN"},
"neotony":	{"NN"},
"nepa":	{"NN"},
"nepali":	{"JJ","NN"},
"nepenthaceae":	{"NN"},
"nepenthe":	{"NN"},
"nepenthes":	{"NNS","NN"},
"nepeta":	{"NN"},
"nepheline":	{"NN"},
"nephelinite":	{"NN"},
"nephelite":	{"NN"},
"nephelium":	{"NN"},
"nephew":	{"NN"},
"nephews":	{"NNS"},
"nephology":	{"NN"},
"nephoscope":	{"NN"},
"nephralgia":	{"NN"},
"nephrectomy":	{"NN"},
"nephrite":	{"NN"},
"nephritic":	{"JJ"},
"nephritis":	{"NN"},
"nephroangiosclerosis":	{"NN"},
"nephroblastoma":	{"NN"},
"nephrocalcinosis":	{"NN"},
"nephrolepis":	{"NN"},
"nephrolith":	{"NN"},
"nephrolithiasis":	{"NN"},
"nephrology":	{"NN"},
"nephron":	{"NN"},
"nephropathy":	{"NN"},
"nephrops":	{"NNS"},
"nephropsidae":	{"NN"},
"nephroptosia":	{"NN"},
"nephroptosis":	{"NN"},
"nephrosclerosis":	{"NN"},
"nephrosis":	{"NN"},
"nephrotomy":	{"NN"},
"nephrotoxic":	{"JJ"},
"nephrotoxin":	{"NN"},
"nephthys":	{"NNS"},
"nephthytis":	{"NN"},
"nepidae":	{"NN"},
"nepotism":	{"NN"},
"nepotist":	{"NN"},
"neptunium":	{"NN"},
"nerd":	{"NN"},
"nerd-and-geek":	{"JJ"},
"nerdier":	{"JJR"},
"nerdiest":	{"JJS"},
"nerds":	{"NNS"},
"nerdy":	{"JJ"},
"nereus":	{"NN"},
"nergal":	{"NN"},
"nerita":	{"NN"},
"neritic":	{"JJ"},
"neritid":	{"NN"},
"neritidae":	{"NN"},
"neritina":	{"NN"},
"nerium":	{"NN"},
"nerly":	{"RB"},
"nernst":	{"NN"},
"nerodia":	{"NN"},
"nerthus":	{"NN"},
"nerva":	{"NN"},
"nerve":	{"NN","VB","VBP"},
"nerve-cell":	{"JJ"},
"nerve-cells":	{"NNS"},
"nerve-centre":	{"NN"},
"nerve-ends":	{"NNS"},
"nerve-racking":	{"JJ"},
"nerve-shattering":	{"JJ"},
"nerve-wracking":	{"JJ"},
"nerved":	{"VBD","VBN"},
"nerveless":	{"JJ"},
"nervelessly":	{"RB"},
"nervelessness":	{"NN"},
"nerveroot":	{"NN"},
"nerves":	{"NNS","VBZ"},
"nervi":	{"NN"},
"nervier":	{"JJR"},
"nerviest":	{"JJS"},
"nervily":	{"RB"},
"nerving":	{"VBG"},
"nervous":	{"JJ"},
"nervously":	{"RB"},
"nervousness":	{"NN"},
"nervure":	{"NN"},
"nervus":	{"NN"},
"nervy":	{"JJ"},
"nescience":	{"NN"},
"nescient":	{"JJ"},
"nesokia":	{"NN"},
"nesselrode":	{"NN"},
"nest":	{"NN","VB","VBP"},
"nest-egg":	{"NN"},
"nest-eggs":	{"NNS"},
"nestbuilding":	{"NN"},
"nested":	{"VBD","VBN","JJ"},
"nester":	{"NN"},
"nesters":	{"NNS"},
"nesting":	{"VBG","NN"},
"nestle":	{"VB","VBP"},
"nestled":	{"VBD","VBN"},
"nestles":	{"VBZ"},
"nestling":	{"NN","VBG"},
"nestlings":	{"NNS"},
"nestor":	{"NN"},
"nestorian":	{"JJ","NN"},
"nestorianism":	{"NN"},
"nestorius":	{"NN"},
"nests":	{"NNS","VBZ"},
"net":	{"JJ","NN","VB","VBP"},
"net-benefit":	{"JJ"},
"net-capital":	{"JJ"},
"net-like":	{"JJ"},
"net-profits":	{"JJ"},
"netball":	{"NN"},
"nether":	{"JJ"},
"netherlander":	{"NN"},
"netherlands-based":	{"JJ"},
"nethermost":	{"JJ"},
"netherworld":	{"NN"},
"netizen":	{"NN"},
"netizens":	{"NNS"},
"netkeeper":	{"NN"},
"netlike":	{"JJ"},
"netmail":	{"NN"},
"netminder":	{"NN"},
"nets":	{"NNS","VBZ"},
"nett":	{"JJ"},
"netted":	{"JJ","VBD","VBN"},
"netting":	{"NN","VBG"},
"nettle":	{"NN","VB","VBP"},
"nettled":	{"VBD","VBN"},
"nettles":	{"NNS","VBZ"},
"nettlesome":	{"JJ"},
"nettling":	{"VBG"},
"network":	{"NN","VB","VBP"},
"network-access":	{"JJ"},
"network-affiliated":	{"JJ"},
"network-buying":	{"JJ"},
"network-owned":	{"JJ"},
"network-services":	{"JJ"},
"network-wide":	{"JJ"},
"network-writer":	{"JJ"},
"networked":	{"VBD","VBN"},
"networking":	{"NN","VBG"},
"networklike":	{"JJ"},
"networks":	{"NNS","VBZ"},
"neumann":	{"NN"},
"neural":	{"JJ"},
"neuralgia":	{"NN"},
"neuralgic":	{"JJ"},
"neuralgy":	{"NN"},
"neurasthenia":	{"NN"},
"neurasthenic":	{"JJ"},
"neurectomy":	{"NN"},
"neurilemma":	{"NN"},
"neurilemoma":	{"NN"},
"neurinoma":	{"NN"},
"neuritis":	{"NN"},
"neuroanatomic":	{"JJ"},
"neuroanatomical":	{"JJ"},
"neuroanatomy":	{"NN"},
"neurobehavioral":	{"JJ"},
"neurobiological":	{"JJ","RB"},
"neurobiologist":	{"NN"},
"neurobiology":	{"NN"},
"neuroblast":	{"NN"},
"neuroblastoma":	{"NN"},
"neurochemical":	{"JJ","NN"},
"neurodegeneration":	{"NN"},
"neurodegenerations":	{"NNS"},
"neurodegenerative":	{"JJ"},
"neurodermatitis":	{"NN"},
"neuroendocrine":	{"JJ","NN"},
"neuroepithelioma":	{"NN"},
"neuroepithelium":	{"NN"},
"neuroethics":	{"NN"},
"neurofibroma":	{"NN"},
"neurofibromatosis":	{"NN"},
"neurogenesis":	{"NN"},
"neurogenic":	{"JJ"},
"neuroglia":	{"NN"},
"neurogliacyte":	{"NN"},
"neuroglial":	{"JJ"},
"neurohormone":	{"NN"},
"neurohypophysis":	{"NN"},
"neuroimaging":	{"NN"},
"neurolemma":	{"NN"},
"neuroleptic":	{"JJ","NN"},
"neurolinguist":	{"NN"},
"neurolinguistics":	{"NN"},
"neurologic":	{"JJ","NN"},
"neurological":	{"JJ","NN"},
"neurologist":	{"NN"},
"neurologists":	{"NNS"},
"neurology":	{"NN"},
"neurolysin":	{"NN"},
"neuroma":	{"NN"},
"neuromatous":	{"JJ"},
"neuromotor":	{"JJ"},
"neuromuscular":	{"JJ"},
"neuron":	{"NN"},
"neuronal":	{"JJ"},
"neuronic":	{"JJ"},
"neurons":	{"NNS"},
"neurontin":	{"NN"},
"neuropathology":	{"NN"},
"neuropathy":	{"NN"},
"neurophysiological":	{"JJ"},
"neurophysiology":	{"NN"},
"neuropil":	{"NN"},
"neuropile":	{"NN"},
"neuroplasty":	{"NN"},
"neuropsychiatric":	{"JJ"},
"neuropsychiatry":	{"NN"},
"neuropsychological":	{"JJ"},
"neuropsychology":	{"NN"},
"neuroptera":	{"NN"},
"neuropteran":	{"NN"},
"neuropteron":	{"NN"},
"neurosarcoma":	{"NN"},
"neuroscience":	{"NN"},
"neuroscientist":	{"NN"},
"neuroselective":	{"JJ"},
"neuroses":	{"NNS"},
"neurosis":	{"NN"},
"neurospora":	{"NN"},
"neurosurgeon":	{"NN"},
"neurosurgery":	{"NN"},
"neurosyphilis":	{"NN"},
"neurotic":	{"JJ","NN"},
"neurotically":	{"RB"},
"neuroticism":	{"NN"},
"neurotics":	{"NNS"},
"neurotoxic":	{"JJ"},
"neurotoxin":	{"NN"},
"neurotransmitter":	{"NN"},
"neurotransmitters":	{"NNS"},
"neurotrichus":	{"NN"},
"neurotropic":	{"JJ"},
"neurotropism":	{"NN"},
"neurotypical":	{"JJ","NN"},
"neurotypicals":	{"NNS"},
"neuter":	{"JJ","NN","VB","VBP"},
"neutered":	{"JJ","VBD","VBN"},
"neutering":	{"VBG"},
"neuters":	{"VBZ","NNS"},
"neutral":	{"JJ","NN"},
"neutral-colored":	{"JJ"},
"neutral-coloured":	{"JJ"},
"neutralisation":	{"NN"},
"neutralise":	{"VB","VBP"},
"neutralised":	{"VBD","VBN"},
"neutralises":	{"VBZ"},
"neutralising":	{"VBG"},
"neutralism":	{"NN"},
"neutralist":	{"NN","JJ"},
"neutralists":	{"NNS"},
"neutrality":	{"NN"},
"neutralization":	{"NN"},
"neutralize":	{"VB","VBP"},
"neutralized":	{"VBD","VBN"},
"neutralizes":	{"VBZ"},
"neutralizing":	{"VBG"},
"neutrino":	{"NN"},
"neutrino-sized":	{"JJ"},
"neutrinos":	{"NNS"},
"neutron":	{"NN"},
"neutrons":	{"NNS"},
"neutropenia":	{"NN"},
"neutrophil":	{"NN"},
"neutrophile":	{"NN"},
"neutrophils":	{"NNS"},
"neva":	{"NN"},
"neve":	{"NN"},
"nevelson":	{"NN"},
"never":	{"RB","UH"},
"never-ending":	{"JJ"},
"never-never":	{"NN"},
"never-predictable":	{"JJ"},
"never-say-die":	{"JJ"},
"never-to-be-forgotten":	{"JJ"},
"nevermind":	{"NN"},
"nevermore":	{"RB"},
"nevertheless":	{"RB"},
"neville":	{"NN"},
"nevirapine":	{"NN"},
"nevus":	{"NN"},
"new":	{"JJ","NNS"},
"new-business":	{"NN","JJ"},
"new-car":	{"NN","JJ"},
"new-construction":	{"NN"},
"new-country":	{"JJ"},
"new-found":	{"JJ"},
"new-generation":	{"NN"},
"new-home":	{"JJ"},
"new-house":	{"JJ"},
"new-issue":	{"JJ","NN"},
"new-issues":	{"JJ","NNS"},
"new-job":	{"JJ"},
"new-loan":	{"JJ"},
"new-made":	{"JJ"},
"new-model":	{"JJ","NN"},
"new-money":	{"JJ"},
"new-mown":	{"JJ"},
"new-product":	{"NN","JJ"},
"new-rich":	{"JJ"},
"new-share":	{"JJ"},
"new-spilled":	{"JJ"},
"new-sprung":	{"JJ"},
"new-styled":	{"JJ"},
"new-telephone-line":	{"NN"},
"newage":	{"NN"},
"newari":	{"NN"},
"newbie":	{"NN"},
"newbies":	{"NNS"},
"newborn":	{"JJ","NN"},
"newborns":	{"NNS"},
"newburgh":	{"NN"},
"newcastle-upon-tyne":	{"NN"},
"newcasts":	{"NNS"},
"newcomb":	{"NN"},
"newcomer":	{"NN"},
"newcomers":	{"NNS"},
"newdrug":	{"NN"},
"newel":	{"NN"},
"newer":	{"JJR"},
"newest":	{"JJS"},
"newfangled":	{"JJ"},
"newfound":	{"JJ"},
"newhouse":	{"NN"},
"newissue":	{"NN"},
"newly":	{"RB"},
"newly-appointed":	{"JJ"},
"newly-created":	{"JJ"},
"newly-emerging":	{"JJ"},
"newly-married":	{"JJ"},
"newly-plowed":	{"JJ"},
"newly-scrubbed":	{"JJ"},
"newly-wed":	{"JJ"},
"newly-weds":	{"NNS"},
"newlywed":	{"JJ"},
"newlyweds":	{"NNS"},
"newness":	{"NN"},
"newport-based":	{"JJ"},
"news":	{"NN"},
"news-division":	{"NN"},
"news-letter":	{"NN"},
"news-letters":	{"NNS"},
"news-magazine":	{"NN"},
"news-oriented":	{"JJ"},
"news-reader":	{"NN"},
"news-readers":	{"NNS"},
"news-release":	{"NN"},
"news-room":	{"NN"},
"news-rooms":	{"NNS"},
"news-sheet":	{"NN"},
"news-sheets":	{"NNS"},
"news-stand":	{"NN"},
"news-stands":	{"NNS"},
"news-vendor":	{"NN"},
"news-vendors":	{"NNS"},
"newsagent":	{"NN"},
"newsagents":	{"NNS"},
"newsboy":	{"NN"},
"newsboys":	{"NNS"},
"newsbreak":	{"NN"},
"newsbreaks":	{"NNS"},
"newscast":	{"NN"},
"newscaster":	{"NN"},
"newscasters":	{"NNS"},
"newscasts":	{"NNS"},
"newsdealer":	{"NN"},
"newsdealers":	{"NNS"},
"newsflash":	{"NN"},
"newsflashes":	{"NNS"},
"newsgathering":	{"NN"},
"newsgroup":	{"NN"},
"newsgroups":	{"NNS"},
"newshour":	{"NN"},
"newsier":	{"JJR"},
"newsies":	{"NNS"},
"newsiest":	{"JJS"},
"newsless":	{"JJ"},
"newsletter":	{"NN"},
"newsletters":	{"NNS"},
"newsmagazine":	{"NN"},
"newsmagazines":	{"NNS"},
"newsmaker":	{"NN"},
"newsman":	{"NN"},
"newsmen":	{"NNS"},
"newsmonger":	{"NN"},
"newsmongers":	{"NNS"},
"newspaper":	{"NN"},
"newspaper-delivery":	{"NN"},
"newspaper-industry":	{"JJ"},
"newspaper-printing":	{"NN"},
"newspaper-publishing":	{"JJ"},
"newspapering":	{"NN"},
"newspaperman":	{"NN"},
"newspapermen":	{"NNS"},
"newspapers":	{"NNS"},
"newspaperwoman":	{"NN"},
"newspaperwomen":	{"NNS"},
"newspeak":	{"NN"},
"newsperson":	{"NN"},
"newsprint":	{"NN"},
"newsreader":	{"NN"},
"newsreaders":	{"NNS"},
"newsreel":	{"NN"},
"newsreels":	{"NNS"},
"newsroom":	{"NN"},
"newsrooms":	{"NNS"},
"newssheet":	{"NN"},
"newssheets":	{"NNS"},
"newsstand":	{"NN"},
"newsstands":	{"NNS"},
"newsvendor":	{"NN"},
"newsvendors":	{"NNS"},
"newsweeklies":	{"NNS"},
"newsweekly":	{"NN"},
"newswire":	{"NN"},
"newswires":	{"NNS"},
"newswoman":	{"NN"},
"newswomen":	{"NNS"},
"newsworthiness":	{"NN"},
"newsworthy":	{"JJ"},
"newswriter":	{"NN"},
"newsy":	{"JJ"},
"newt":	{"NN"},
"newts":	{"NNS"},
"next":	{"JJ","RB","PRP"},
"next-door":	{"JJ"},
"next-generation":	{"NN","JJ"},
"next-most-remarkable":	{"JJ"},
"next-to-last":	{"JJ"},
"nexus":	{"NN","NNS"},
"nexuses":	{"NNS"},
"ney":	{"NN"},
"ng":	{"NN"},
"nga":	{"NN"},
"nganasan":	{"NN"},
"ngandlu":	{"FW"},
"ngb":	{"NN"},
"ngf":	{"NN"},
"ngu":	{"NN"},
"ngultrum":	{"NN"},
"nguni":	{"NN"},
"ngwee":	{"NN"},
"ni-hard":	{"NN"},
"ni-resist":	{"NN"},
"niacin":	{"NN"},
"nib":	{"NN","VB","VBP"},
"nibbed":	{"VBD","VBN"},
"nibbing":	{"VBG"},
"nibble":	{"VB","VBP","NN"},
"nibbled":	{"VBD","VBN"},
"nibbler":	{"NN"},
"nibblers":	{"NNS"},
"nibbles":	{"VBZ","NNS"},
"nibbling":	{"VBG"},
"nibelung":	{"NN"},
"nibelungenlied":	{"NN"},
"niblick":	{"NN"},
"nibs":	{"NNS","VBZ"},
"nicaea":	{"NN"},
"nicaean":	{"JJ"},
"nicandra":	{"NN"},
"nice":	{"JJ"},
"nice-looking":	{"JJ"},
"nicely":	{"RB"},
"nicene":	{"JJ"},
"niceness":	{"NN"},
"nicer":	{"JJR"},
"nicest":	{"JJS"},
"niceties":	{"NNS"},
"nicety":	{"NN"},
"niche":	{"NN","JJ","VB","VBP"},
"niche-itis":	{"NN"},
"niche-market":	{"NN"},
"niched":	{"VBD","VBN"},
"niches":	{"VBZ","NNS"},
"niching":	{"VBG"},
"nichrome":	{"NN"},
"nichtige":	{"NN"},
"nick":	{"NN","VB","VBP"},
"nicked":	{"VBD","VBN"},
"nickel":	{"NN","VBP","VB"},
"nickel-and-dime":	{"VB","VBP","JJ"},
"nickel-and-dimed":	{"VBD","VBN"},
"nickel-and-diming":	{"VBG"},
"nickel-iron":	{"NN"},
"nickeled":	{"VBD","VBN"},
"nickeled-and-dimed":	{"VBD","VBN"},
"nickeling":	{"VBG"},
"nickeling-and-diming":	{"VBG"},
"nickelled":	{"VBD","VBN"},
"nickelling":	{"VBG"},
"nickelodeon":	{"NN"},
"nickels":	{"NNS","VBZ"},
"nickels-and-dimes":	{"VBZ"},
"nicker":	{"NN","NNS","VB","VBP"},
"nickered":	{"VBD","VBN"},
"nickering":	{"VBG"},
"nickers":	{"VBZ"},
"nicking":	{"VBG"},
"nicklaus":	{"NN"},
"nicknack":	{"NN"},
"nicknacks":	{"NNS"},
"nickname":	{"NN","VB","VBP"},
"nicknamed":	{"VBD","VBN"},
"nicknames":	{"NNS","VBZ"},
"nicknaming":	{"VBG"},
"nicks":	{"NNS","VBZ"},
"nicolson":	{"NN"},
"nicotiana":	{"NN"},
"nicotine":	{"NN"},
"nicotine-choked":	{"JJ"},
"nicotine-free":	{"JJ"},
"nictate":	{"VB","VBP"},
"nictated":	{"VBD","VBN"},
"nictates":	{"VBZ"},
"nictating":	{"VBG"},
"nictation":	{"NN"},
"nictations":	{"NNS"},
"nictitate":	{"VB","VBP"},
"nictitated":	{"VBD","VBN"},
"nictitates":	{"VBZ"},
"nictitating":	{"VBG"},
"nictitation":	{"NN"},
"nictitations":	{"NNS"},
"nicu":	{"NN"},
"nidaros":	{"NNS"},
"nidation":	{"NN"},
"niddm":	{"NN"},
"nidicolous":	{"JJ"},
"nidifugous":	{"JJ"},
"nidularia":	{"NN"},
"nidulariaceae":	{"NN"},
"nidulariales":	{"NNS"},
"nidus":	{"NN"},
"niebuhr":	{"NN"},
"niece":	{"NN"},
"nieces":	{"NNS"},
"nielsen":	{"NN"},
"nierembergia":	{"NN"},
"niff":	{"NN"},
"niffy":	{"JJ"},
"nifty":	{"JJ","NN"},
"nigella":	{"NN"},
"niger-congo":	{"NN"},
"niger-kordofanian":	{"NN"},
"nigerien":	{"JJ","NN"},
"nigga":	{"NN"},
"niggard":	{"NN","JJ"},
"niggardliness":	{"NN"},
"niggardly":	{"JJ","RB"},
"niggardness":	{"NN"},
"niggards":	{"NNS"},
"niggas":	{"NNS"},
"nigger":	{"NN"},
"niggers":	{"NNS"},
"niggle":	{"VB","VBP","NN"},
"niggled":	{"VBD","VBN"},
"niggler":	{"NN"},
"niggles":	{"VBZ","NNS"},
"niggling":	{"JJ","VBG"},
"nigh":	{"JJ","RB","IN"},
"nigher":	{"JJR","RBR"},
"nighest":	{"JJS","RBS"},
"night":	{"NN"},
"night-coach":	{"JJ"},
"night-light":	{"NN"},
"night-line":	{"NN"},
"night-robe":	{"NN"},
"night-sight":	{"NN"},
"night-stop":	{"NN"},
"night-time":	{"NN"},
"night-vision":	{"JJ","NN"},
"night-watchman":	{"NN"},
"nightbird":	{"NN"},
"nightcap":	{"NN"},
"nightcaps":	{"NNS"},
"nightclothes":	{"NNS"},
"nightclub":	{"NN"},
"nightclubs":	{"NNS"},
"nightcrawler":	{"NN"},
"nightdress":	{"NN"},
"nightdresses":	{"NNS"},
"nighted":	{"JJ"},
"nightfall":	{"NN"},
"nightgown":	{"NN"},
"nightgown-clad":	{"JJ"},
"nightgowns":	{"NNS"},
"nighthawk":	{"NN"},
"nighthawks":	{"NNS"},
"nightie":	{"NN"},
"nighties":	{"NNS"},
"nightingale":	{"NN"},
"nightingales":	{"NNS"},
"nightjar":	{"NN"},
"nightlife":	{"NN"},
"nightlong":	{"JJ","RB"},
"nightly":	{"JJ","RB"},
"nightmare":	{"NN"},
"nightmares":	{"NNS"},
"nightmarish":	{"JJ"},
"nightrider":	{"NN"},
"nights":	{"NNS","RB"},
"nightscape":	{"NN"},
"nightshade":	{"NN"},
"nightshades":	{"NNS"},
"nightshirt":	{"NN"},
"nightshirts":	{"NNS"},
"nightspot":	{"NN"},
"nightspots":	{"NNS"},
"nightstick":	{"NN"},
"nightsticks":	{"NNS"},
"nighttime":	{"NN"},
"nightwalker":	{"NN"},
"nightwalkers":	{"NNS"},
"nightwear":	{"NN"},
"nightwork":	{"NN"},
"nigra":	{"NN"},
"nigrae":	{"NNS"},
"nigrification":	{"NN"},
"nigrified":	{"VBD","VBN"},
"nigrifies":	{"VBZ"},
"nigrify":	{"VB","VBP"},
"nigrifying":	{"VBG"},
"nigroporus":	{"NN"},
"nigs":	{"NNS"},
"nih":	{"NN"},
"nih-appointed":	{"JJ"},
"nihau":	{"NN"},
"nihil":	{"NN"},
"nihilism":	{"NN"},
"nihilist":	{"NN"},
"nihilistic":	{"JJ"},
"nihilists":	{"NNS"},
"nihility":	{"NN"},
"nihon":	{"NN"},
"nij":	{"NN"},
"nijmegen":	{"NN"},
"nike":	{"NN"},
"nil":	{"NN"},
"nilgai":	{"NN","NNS"},
"nilgais":	{"NNS"},
"nilghau":	{"NN","NNS"},
"nilghaus":	{"NNS"},
"nilly":	{"RB"},
"nilo-saharan":	{"NN"},
"nilotic":	{"JJ","NN"},
"nilpotent":	{"JJ"},
"nilsson":	{"NN"},
"nim":	{"NN"},
"nimbi":	{"NNS"},
"nimbies":	{"NNS"},
"nimble":	{"JJ"},
"nimble-fingered":	{"JJ"},
"nimbleness":	{"NN"},
"nimbler":	{"JJR"},
"nimblest":	{"JJS"},
"nimblewill":	{"NN"},
"nimbly":	{"RB"},
"nimbus":	{"NN"},
"nimbuses":	{"NNS"},
"nimby":	{"NN","JJ"},
"nimiety":	{"NN"},
"niminy-piminy":	{"JJ"},
"nimitz":	{"NN"},
"nimravus":	{"NN"},
"nin-sin":	{"NN"},
"nincompoop":	{"NN"},
"nincompoops":	{"NNS"},
"nine":	{"CD","DT"},
"nine-bedroom":	{"JJ"},
"nine-cent":	{"JJ"},
"nine-chambered":	{"JJ"},
"nine-day":	{"JJ"},
"nine-digit":	{"JJ"},
"nine-fold":	{"JJ"},
"nine-game":	{"JJ"},
"nine-member":	{"JJ"},
"nine-membered":	{"JJ"},
"nine-month":	{"JJ"},
"nine-months":	{"NNS"},
"nine-page":	{"JJ"},
"nine-point":	{"JJ"},
"nine-press":	{"NN"},
"nine-sided":	{"JJ"},
"nine-spot":	{"NN"},
"nine-state":	{"JJ"},
"nine-story":	{"JJ"},
"nine-to-five":	{"JJ"},
"nine-year-old":	{"JJ"},
"ninefold":	{"JJ","RB"},
"ninepence":	{"NN"},
"ninepenny":	{"JJ"},
"ninepin":	{"NN"},
"ninepins":	{"NN","NNS"},
"niner":	{"NN"},
"nineteen":	{"CD","NN"},
"nineteen-year-old":	{"JJ"},
"nineteenth":	{"NN","JJ"},
"nineteenth-century":	{"JJ"},
"nineties":	{"NNS"},
"ninetieth":	{"JJ","NN"},
"ninety":	{"CD","NN"},
"ninety-eight":	{"CD","NN"},
"ninety-fifth":	{"JJ","NN"},
"ninety-five":	{"CD","NN"},
"ninety-four":	{"CD","NN"},
"ninety-nine":	{"CD","NN"},
"ninety-one":	{"CD","NN"},
"ninety-seven":	{"CD","NN"},
"ninety-six":	{"CD","NN"},
"ninety-three":	{"CD","NN"},
"ninety-two":	{"CD","NN"},
"ningal":	{"NN"},
"ningirsu":	{"NN"},
"ningishzida":	{"NN"},
"ninhursag":	{"NN"},
"ninib":	{"NN"},
"ninigi":	{"NN"},
"ninigino-mikoto":	{"NN"},
"ninja":	{"NN","NNS"},
"ninjas":	{"NNS"},
"ninjitsu":	{"NN"},
"ninjutsu":	{"NN"},
"ninkharsag":	{"NN"},
"ninkhursag":	{"NN"},
"ninnies":	{"NNS"},
"ninny":	{"NN"},
"ninon":	{"NN"},
"ninth":	{"JJ","NN"},
"ninth-circuit":	{"JJ"},
"ninth-grader":	{"NN"},
"ninth-graders":	{"NNS"},
"ninth-inning":	{"NN"},
"ninth-largest":	{"JJ"},
"nintoo":	{"NN"},
"nintu":	{"NN"},
"ninurta":	{"NN"},
"niobite":	{"NN"},
"niobium":	{"NN"},
"niobrara":	{"NN"},
"nip":	{"VB","VBP","NN"},
"nipa":	{"NN"},
"niping":	{"VBG"},
"nipped":	{"VBD","VBN"},
"nipper":	{"NN"},
"nippers":	{"NNS"},
"nipping":	{"JJ","VBG"},
"nipple":	{"NN"},
"nipples":	{"NNS"},
"nippur":	{"NN"},
"nippy":	{"JJ"},
"nipr":	{"NN"},
"nips":	{"NNS","VBZ"},
"niqaabi":	{"NN"},
"niqab":	{"NN"},
"nirvana":	{"NN"},
"nisan":	{"NN"},
"nise":	{"JJ"},
"nisei":	{"NN"},
"nisi":	{"NN"},
"nissan":	{"NN"},
"nist":	{"NN"},
"nisus":	{"NN"},
"nit":	{"NN"},
"nit-picking":	{"NN"},
"nit-picky":	{"JJ"},
"nitella":	{"NN"},
"niter":	{"NN"},
"nitid":	{"JJ"},
"nitpick":	{"VB","VBP"},
"nitpicked":	{"VBD","VBN"},
"nitpicker":	{"NN"},
"nitpickers":	{"NNS"},
"nitpicking":	{"JJ","VBG"},
"nitpicks":	{"VBZ"},
"nitramine":	{"NN"},
"nitrate":	{"NN","VB","VBP"},
"nitrated":	{"VBD","VBN"},
"nitrates":	{"NNS","VBZ"},
"nitrating":	{"VBG"},
"nitration":	{"NN"},
"nitrazepam":	{"NN"},
"nitre":	{"NN"},
"nitric":	{"JJ","NN"},
"nitride":	{"NN"},
"nitrification":	{"NN"},
"nitrified":	{"VBD","VBN"},
"nitrifier":	{"NN"},
"nitrifies":	{"VBZ"},
"nitrify":	{"VB","VBP"},
"nitrifying":	{"VBG"},
"nitril":	{"NN"},
"nitrile":	{"NN"},
"nitrite":	{"NN"},
"nitrobacter":	{"NN"},
"nitrobacteria":	{"NNS"},
"nitrobacteriaceae":	{"NN"},
"nitrobacterium":	{"NN"},
"nitrobenzene":	{"NN"},
"nitrocalcite":	{"NN"},
"nitrocellulose":	{"NN"},
"nitrochloroform":	{"NN"},
"nitrochloromethane":	{"NN"},
"nitrocotton":	{"NN"},
"nitrofuran":	{"NN"},
"nitrofurantoin":	{"NN"},
"nitrogen":	{"NN"},
"nitrogen-based":	{"JJ"},
"nitrogen-bearing":	{"JJ"},
"nitrogen-fertilizer":	{"NN"},
"nitrogen-fixing":	{"JJ"},
"nitrogen-mustard":	{"JJ"},
"nitrogenase":	{"NN"},
"nitrogenise":	{"VB","VBP"},
"nitrogenised":	{"VBD","VBN"},
"nitrogenises":	{"VBZ"},
"nitrogenising":	{"VBG"},
"nitrogenize":	{"VB","VBP"},
"nitrogenized":	{"VBD","VBN"},
"nitrogenizes":	{"VBZ"},
"nitrogenizing":	{"VBG"},
"nitrogenous":	{"JJ"},
"nitroglycerin":	{"NN"},
"nitroglycerine":	{"NN"},
"nitrosobacteria":	{"NN"},
"nitrosomonas":	{"NN"},
"nitrospan":	{"NN"},
"nitrostat":	{"NN"},
"nitrous":	{"JJ"},
"nits":	{"NNS"},
"nitty-gritty":	{"NN"},
"nitweed":	{"NN"},
"nitwit":	{"NN"},
"nitwits":	{"NNS"},
"nitwitted":	{"JJ"},
"nivolumab":	{"NN"},
"nivose":	{"NN"},
"nix":	{"NN","VB","VBP","RB"},
"nixed":	{"VBD","VBN"},
"nixes":	{"VBZ"},
"nixing":	{"VBG"},
"njord":	{"NN"},
"njorth":	{"NN"},
"nlp":	{"NN"},
"nlrb":	{"NN"},
"nm":	{"NN"},
"nmr":	{"NN"},
"nne":	{"NN"},
"nnrti":	{"NN"},
"nnuolapertar-it-vuh-karti-birifw":	{"FW"},
"nnw":	{"NN"},
"no":	{"DT","RB","UH","NN"},
"no-account":	{"JJ","NN"},
"no-back":	{"NN"},
"no-ball":	{"NN","VB","VBP"},
"no-balled":	{"VBD","VBN"},
"no-balling":	{"VBG"},
"no-balls":	{"NNS","VBZ"},
"no-brainer":	{"NN"},
"no-brainers":	{"NNS"},
"no-bunkum":	{"JJ"},
"no-claims":	{"JJ"},
"no-confidence":	{"NN"},
"no-count":	{"JJ"},
"no-drinking":	{"JJ"},
"no-driving":	{"JJ"},
"no-fat":	{"JJ"},
"no-fault":	{"JJ"},
"no-fly":	{"JJ"},
"no-frills":	{"JJ"},
"no-fuss":	{"JJ"},
"no-go":	{"JJ"},
"no-goal":	{"NN"},
"no-good":	{"JJ"},
"no-good-bums":	{"NNS"},
"no-growth":	{"JJ","NN"},
"no-hit":	{"JJ"},
"no-hitter":	{"NN"},
"no-hitters":	{"NNS"},
"no-inflation":	{"JJ","NN"},
"no-layoff":	{"JJ"},
"no-load":	{"JJ"},
"no-lose":	{"JJ"},
"no-man":	{"NN","JJ"},
"no-men":	{"NNS"},
"no-mistakes":	{"JJ"},
"no-more-nonsense":	{"JJ"},
"no-muss":	{"JJ"},
"no-new-tax":	{"JJ"},
"no-new-taxes":	{"JJ"},
"no-no":	{"NN"},
"no-nonsense":	{"JJ"},
"no-o":	{"UH"},
"no-one":	{"PRP"},
"no-profit":	{"JJ"},
"no-see-um":	{"NN"},
"no-show":	{"NN"},
"no-shows":	{"NNS"},
"no-smoking":	{"JJ"},
"no-star":	{"JJ"},
"no-strike":	{"JJ"},
"no-tax":	{"JJ"},
"no-tax-increase":	{"JJ"},
"no-trade":	{"JJ"},
"no-trading":	{"JJ"},
"no-trump":	{"NN"},
"no-valued":	{"JJ"},
"no-walls-no-doors":	{"JJ"},
"no-waste":	{"JJ"},
"no-win":	{"JJ"},
"no.":	{"NN"},
"noaa":	{"NN"},
"noachian":	{"JJ"},
"nob":	{"NN"},
"nobble":	{"VB","VBP"},
"nobbled":	{"VBD","VBN"},
"nobbles":	{"VBZ"},
"nobbling":	{"VBG"},
"nobelist":	{"NN"},
"nobelium":	{"NN"},
"nobility":	{"NN"},
"noble":	{"JJ","NN"},
"noble-minded":	{"JJ"},
"noble-mindedness":	{"NN"},
"nobleman":	{"NN"},
"noblemen":	{"NNS"},
"nobleness":	{"NN"},
"nobler":	{"JJR"},
"nobles":	{"NNS"},
"noblesse":	{"NN"},
"noblest":	{"JJS"},
"noblewoman":	{"NN"},
"noblewomen":	{"NNS"},
"nobly":	{"RB"},
"nobodies":	{"NNS"},
"nobody":	{"NN","PRP"},
"nobs":	{"NNS"},
"noc":	{"NN"},
"nocent":	{"JJ"},
"nociceptive":	{"JJ"},
"nock":	{"NN","VB","VBP"},
"nocked":	{"VBD","VBN"},
"nocking":	{"VBG"},
"nocks":	{"NNS","VBZ"},
"noconfidence":	{"JJ"},
"noctambulation":	{"NN"},
"noctambulations":	{"NNS"},
"noctambulism":	{"NN"},
"noctambulist":	{"NN"},
"noctambulists":	{"NNS"},
"noctiluca":	{"NN"},
"noctilucent":	{"JJ"},
"noctua":	{"NN"},
"noctuid":	{"NN"},
"noctuidae":	{"NN"},
"nocturia":	{"NN"},
"nocturnal":	{"JJ"},
"nocturnally":	{"RB"},
"nocturne":	{"NN"},
"nocturnes":	{"NNS"},
"nod":	{"NN","VB","VBP"},
"nodal":	{"JJ"},
"nodded":	{"VBD","VBN"},
"nodding":	{"JJ","VBG"},
"noddle":	{"NN"},
"noddles":	{"NNS"},
"node":	{"NN"},
"nodes":	{"NNS"},
"nods":	{"NNS","VBZ"},
"nodular":	{"JJ"},
"nodulated":	{"JJ"},
"nodule":	{"NN"},
"noduled":	{"JJ"},
"nodules":	{"NNS"},
"nodulose":	{"JJ"},
"noema":	{"NN"},
"noemi":	{"NN"},
"noes":	{"NNS"},
"noesis":	{"NN"},
"noether":	{"NN"},
"noetic":	{"JJ"},
"nog":	{"NN","VB","VBP"},
"nogales":	{"NNS"},
"nogged":	{"VBD","VBN"},
"noggin":	{"NN"},
"nogging":	{"VBG","NN"},
"noggings":	{"NNS"},
"noggins":	{"NNS"},
"nogs":	{"NNS","VBZ"},
"noguchi":	{"NN"},
"nohow":	{"RB"},
"noir":	{"NN","JJ"},
"noire":	{"FW"},
"noirish":	{"JJ"},
"noise":	{"NN","VBP","VB"},
"noised":	{"VBD","VBN"},
"noiseless":	{"JJ"},
"noiselessly":	{"RB"},
"noiselessness":	{"NN"},
"noisemaker":	{"NN"},
"noisemakers":	{"NNS"},
"noises":	{"NNS","VBZ"},
"noisier":	{"JJR"},
"noisiest":	{"JJS"},
"noisily":	{"RB"},
"noisiness":	{"NN"},
"noising":	{"VBG"},
"noisome":	{"JJ"},
"noisomeness":	{"NN"},
"noisy":	{"JJ"},
"nol-pros":	{"VB","VBP"},
"nol-proses":	{"VBZ"},
"nol-prossed":	{"VBD","VBN"},
"nol-prossing":	{"VBG"},
"nolens":	{"FW"},
"noli":	{"FW"},
"noli-me-tangere":	{"NN"},
"nolina":	{"NN"},
"noll":	{"NN"},
"nolle":	{"FW"},
"nolo":	{"NN"},
"noma":	{"NN"},
"nomad":	{"NN"},
"nomadic":	{"JJ"},
"nomads":	{"NNS"},
"nombril":	{"NN"},
"nome":	{"NN"},
"nomenclatural":	{"JJ"},
"nomenclature":	{"NN"},
"nomenclatures":	{"NNS"},
"nomenklatura":	{"NN"},
"nomia":	{"NN"},
"nominal":	{"JJ"},
"nominalism":	{"NN"},
"nominalist":	{"NN"},
"nominalistic":	{"JJ"},
"nominally":	{"RB"},
"nominate":	{"VB","VBP"},
"nominated":	{"VBN","VBD"},
"nominates":	{"VBZ"},
"nominating":	{"VBG"},
"nomination":	{"NN"},
"nominations":	{"NNS"},
"nominative":	{"JJ","NN"},
"nominatives":	{"NNS"},
"nominator":	{"NN"},
"nominators":	{"NNS"},
"nominee":	{"NN"},
"nominees":	{"NNS"},
"nomogram":	{"NN"},
"nomograph":	{"NN"},
"nomophobia":	{"NN"},
"nomophobic":	{"JJ"},
"nomothetic":	{"JJ"},
"non":	{"FW"},
"non-AMT":	{"JJ"},
"non-Aryan":	{"JJ"},
"non-Big":	{"JJ"},
"non-British":	{"JJ"},
"non-Cocom":	{"JJ"},
"non-Communist":	{"NN","JJ"},
"non-EC":	{"JJ"},
"non-English":	{"NN"},
"non-European":	{"JJ"},
"non-Fed":	{"JJ"},
"non-Federal":	{"JJ"},
"non-Ford":	{"JJ"},
"non-GM":	{"JJ"},
"non-Germans":	{"NNS"},
"non-God":	{"NN"},
"non-Greek":	{"JJ"},
"non-Hispanic":	{"JJ"},
"non-Humana":	{"JJ"},
"non-ICO":	{"JJ"},
"non-Indian":	{"JJ"},
"non-Indonesian":	{"JJ"},
"non-Japanese":	{"JJ"},
"non-Jew":	{"NN"},
"non-Jewish":	{"JJ"},
"non-Jews":	{"NNS"},
"non-Korean":	{"JJ"},
"non-Manpower":	{"JJ"},
"non-Mexican":	{"JJ"},
"non-NMS":	{"JJ"},
"non-New":	{"JJ"},
"non-OPEC":	{"JJ"},
"non-Russian":	{"JJ"},
"non-Socialist":	{"JJ"},
"non-Soviet":	{"JJ"},
"non-Swedish":	{"JJ"},
"non-Tagalog":	{"JJ"},
"non-Tories":	{"NNS"},
"non-U":	{"JJ"},
"non-Western":	{"JJ"},
"non-absorbent":	{"JJ"},
"non-academic":	{"JJ"},
"non-accrual":	{"JJ"},
"non-accruing":	{"JJ"},
"non-actor":	{"NN"},
"non-actors":	{"NNS"},
"non-advertising":	{"JJ"},
"non-affiliate":	{"NN"},
"non-airline":	{"JJ","NN"},
"non-alcohol":	{"NN"},
"non-alcoholic":	{"JJ"},
"non-algebraically":	{"JJ"},
"non-amendable":	{"JJ"},
"non-amortizing":	{"JJ"},
"non-amt":	{"JJ"},
"non-annualized":	{"JJ"},
"non-answer":	{"JJ","NN"},
"non-arbitrage":	{"JJ"},
"non-aromatic":	{"JJ"},
"non-artistic":	{"JJ"},
"non-aryan":	{"JJ"},
"non-authoritative":	{"JJ"},
"non-auto":	{"JJ"},
"non-automatic":	{"JJ"},
"non-automotive":	{"JJ"},
"non-bank":	{"JJ"},
"non-banking":	{"JJ"},
"non-bearing":	{"JJ"},
"non-beer":	{"JJ"},
"non-big":	{"JJ"},
"non-binding":	{"JJ"},
"non-biodegradable":	{"JJ"},
"non-black":	{"JJ"},
"non-blooming":	{"JJ"},
"non-books":	{"NNS"},
"non-brain":	{"JJ"},
"non-brand":	{"JJ"},
"non-british":	{"JJ"},
"non-building":	{"JJ"},
"non-buoyant":	{"JJ"},
"non-business":	{"JJ"},
"non-caffeine":	{"JJ"},
"non-call":	{"JJ"},
"non-callable":	{"JJ"},
"non-cash":	{"JJ"},
"non-casino":	{"JJ"},
"non-catholic":	{"NN"},
"non-church":	{"JJ"},
"non-circumvention":	{"NN"},
"non-clients":	{"NNS"},
"non-cocom":	{"JJ"},
"non-code":	{"JJ"},
"non-college":	{"JJ"},
"non-color":	{"NN"},
"non-com":	{"NN"},
"non-commissioned":	{"JJ"},
"non-communist":	{"NN","JJ"},
"non-communists":	{"NNS"},
"non-comparable":	{"JJ"},
"non-compete":	{"JJ"},
"non-competition":	{"JJ"},
"non-competitive":	{"JJ"},
"non-compliance":	{"NN"},
"non-conducting":	{"JJ"},
"non-conformists":	{"NNS"},
"non-confrontational":	{"JJ"},
"non-consensual":	{"JJ"},
"non-consolidated":	{"JJ"},
"non-consumer":	{"NN"},
"non-contact":	{"JJ"},
"non-contract":	{"JJ"},
"non-contributory":	{"JJ"},
"non-controlling":	{"JJ"},
"non-convertible":	{"JJ"},
"non-core":	{"JJ"},
"non-cosmetic":	{"JJ"},
"non-credit":	{"JJ"},
"non-crisis":	{"JJ"},
"non-cumulative":	{"JJ"},
"non-cyclical":	{"JJ"},
"non-daily":	{"JJ"},
"non-dairy-creamer":	{"NN"},
"non-dealer":	{"JJ"},
"non-deductible":	{"JJ"},
"non-defense":	{"JJ"},
"non-defense-related":	{"JJ"},
"non-democratic":	{"JJ"},
"non-direct":	{"JJ"},
"non-disabled":	{"JJ"},
"non-dischargable":	{"JJ"},
"non-discrimination":	{"NN"},
"non-diva-like":	{"JJ"},
"non-dividend-bearing":	{"JJ"},
"non-dramas":	{"NNS"},
"non-drug":	{"JJ"},
"non-dual":	{"JJ"},
"non-duck":	{"JJ"},
"non-durable":	{"JJ"},
"non-earning":	{"JJ"},
"non-ec":	{"JJ"},
"non-economical":	{"JJ"},
"non-economists":	{"NNS"},
"non-edible":	{"JJ"},
"non-elderly":	{"JJ"},
"non-elective":	{"JJ"},
"non-employee":	{"JJ"},
"non-encapsulating":	{"JJ"},
"non-energy":	{"JJ"},
"non-enforcement":	{"JJ"},
"non-engagement":	{"NN"},
"non-english":	{"NN"},
"non-enzymatic":	{"JJ"},
"non-equity":	{"JJ"},
"non-european":	{"JJ"},
"non-event":	{"NN"},
"non-events":	{"NNS"},
"non-exclusive":	{"JJ"},
"non-executive":	{"JJ","NN"},
"non-executives":	{"NNS"},
"non-exempt":	{"JJ"},
"non-existant":	{"JJ"},
"non-existence":	{"NN"},
"non-existent":	{"JJ"},
"non-familial":	{"JJ"},
"non-family":	{"JJ"},
"non-farm":	{"JJ"},
"non-fat":	{"JJ"},
"non-fed":	{"JJ"},
"non-federal":	{"JJ"},
"non-fiction":	{"JJ","NN"},
"non-figurative":	{"JJ"},
"non-financial":	{"JJ"},
"non-finite":	{"JJ"},
"non-firm":	{"JJ"},
"non-flight":	{"JJ"},
"non-food":	{"JJ","NN"},
"non-ford":	{"JJ"},
"non-forthcoming":	{"JJ"},
"non-fortress-like":	{"JJ"},
"non-freezing":	{"JJ"},
"non-gasoline":	{"JJ"},
"non-germans":	{"NNS"},
"non-gm":	{"JJ"},
"non-governmental":	{"JJ"},
"non-greek":	{"JJ"},
"non-high":	{"JJ"},
"non-hispanic":	{"JJ"},
"non-horticultural":	{"JJ"},
"non-humana":	{"JJ"},
"non-hydrogen-bonded":	{"JJ"},
"non-ico":	{"JJ"},
"non-identity":	{"JJ"},
"non-ideological":	{"JJ"},
"non-indian":	{"JJ"},
"non-indonesian":	{"JJ"},
"non-inflationary":	{"JJ"},
"non-insider":	{"NN"},
"non-instinctive":	{"JJ"},
"non-institutionalized":	{"JJ"},
"non-insurance":	{"JJ","NN"},
"non-intellectual":	{"JJ"},
"non-interest":	{"JJ","NN"},
"non-interest-bearing":	{"JJ"},
"non-interference":	{"NN"},
"non-interstate":	{"JJ"},
"non-interventionist":	{"JJ"},
"non-invasive":	{"JJ"},
"non-invertible":	{"JJ"},
"non-investment":	{"JJ"},
"non-involvement":	{"NN"},
"non-issue":	{"NN"},
"non-itemized":	{"JJ"},
"non-japanese":	{"JJ"},
"non-jew":	{"NN"},
"non-jewish":	{"JJ"},
"non-jews":	{"NNS"},
"non-job-connected":	{"JJ"},
"non-judgemental":	{"JJ"},
"non-judgmental":	{"JJ"},
"non-junk":	{"JJ"},
"non-junkies":	{"NNS"},
"non-korean":	{"JJ"},
"non-lawyers":	{"NNS"},
"non-lethal":	{"JJ"},
"non-life":	{"JJ"},
"non-linear":	{"JJ"},
"non-liquid":	{"JJ"},
"non-literary":	{"JJ"},
"non-living":	{"JJ"},
"non-management":	{"JJ","NN"},
"non-manpower":	{"JJ"},
"non-market":	{"NN"},
"non-meat":	{"NN"},
"non-medical":	{"JJ"},
"non-mega":	{"JJ"},
"non-member":	{"NN"},
"non-members":	{"NNS"},
"non-merger":	{"JJ"},
"non-metallic":	{"JJ"},
"non-methanol":	{"JJ"},
"non-metric":	{"JJ"},
"non-mexican":	{"JJ"},
"non-military":	{"JJ"},
"non-mining":	{"JJ"},
"non-miscible":	{"JJ"},
"non-monetary":	{"JJ"},
"non-money":	{"JJ"},
"non-monopolistic":	{"JJ"},
"non-negative":	{"JJ"},
"non-negotiable":	{"JJ"},
"non-network":	{"JJ"},
"non-new":	{"JJ"},
"non-newspaper":	{"JJ"},
"non-newtonian":	{"JJ"},
"non-nms":	{"JJ"},
"non-nonsense":	{"NN"},
"non-objective":	{"JJ"},
"non-objects":	{"NNS"},
"non-oil":	{"JJ"},
"non-opec":	{"JJ"},
"non-operating":	{"JJ"},
"non-option":	{"JJ"},
"non-packaging":	{"JJ"},
"non-paper":	{"NN"},
"non-partisan":	{"JJ"},
"non-party":	{"JJ"},
"non-patent":	{"JJ"},
"non-pathogenic":	{"JJ"},
"non-paying":	{"JJ"},
"non-person":	{"NN"},
"non-pipeline":	{"NN"},
"non-poetry":	{"NN"},
"non-poisonous":	{"JJ"},
"non-police":	{"JJ"},
"non-political":	{"JJ"},
"non-polygynous":	{"JJ"},
"non-porous":	{"JJ"},
"non-pregnant":	{"JJ"},
"non-prescription":	{"JJ","NN"},
"non-priority":	{"JJ"},
"non-productive":	{"JJ"},
"non-professional":	{"JJ"},
"non-professionals":	{"NNS"},
"non-profit":	{"JJ"},
"non-profit-making":	{"JJ"},
"non-proliferation":	{"NN"},
"non-propagandistic":	{"JJ"},
"non-propagating":	{"JJ"},
"non-public":	{"JJ"},
"non-publishers":	{"NNS"},
"non-qualified":	{"JJ"},
"non-reader":	{"NN"},
"non-readers":	{"NNS"},
"non-realistic":	{"JJ"},
"non-recessionary":	{"JJ"},
"non-recourse":	{"JJ"},
"non-recurring":	{"JJ"},
"non-refundable":	{"JJ"},
"non-regulated":	{"JJ"},
"non-religious":	{"JJ"},
"non-repetitious":	{"JJ"},
"non-representation":	{"JJ"},
"non-research":	{"JJ"},
"non-resident":	{"NN","JJ"},
"non-residential":	{"JJ"},
"non-residents":	{"NNS"},
"non-resinous":	{"JJ"},
"non-resiny":	{"JJ"},
"non-resistant":	{"NN"},
"non-resistants":	{"JJ"},
"non-retail":	{"JJ"},
"non-romantic":	{"JJ"},
"non-russian":	{"JJ"},
"non-sales":	{"JJ"},
"non-scheduled":	{"JJ"},
"non-scientific":	{"JJ"},
"non-scientist":	{"JJ"},
"non-seamen":	{"NNS"},
"non-sentimental":	{"JJ"},
"non-service":	{"JJ"},
"non-service-connected":	{"JJ"},
"non-skid":	{"JJ"},
"non-slave":	{"JJ"},
"non-smoker":	{"NN"},
"non-smokers":	{"NNS"},
"non-smoking":	{"JJ"},
"non-social":	{"JJ"},
"non-socialist":	{"JJ"},
"non-soviet":	{"JJ"},
"non-staple":	{"JJ"},
"non-state":	{"JJ"},
"non-steel":	{"JJ"},
"non-stop":	{"JJ","RB"},
"non-strategic":	{"JJ"},
"non-striking":	{"JJ"},
"non-subcommittee":	{"JJ"},
"non-subscribers":	{"NNS"},
"non-subscription":	{"JJ"},
"non-subsidized":	{"JJ"},
"non-success":	{"NN"},
"non-supervisory":	{"JJ"},
"non-surgical":	{"JJ"},
"non-swedish":	{"JJ"},
"non-swimmers":	{"NNS"},
"non-systematic":	{"JJ"},
"non-tagalog":	{"JJ"},
"non-tariff":	{"JJ"},
"non-taxable":	{"JJ"},
"non-telephone":	{"JJ"},
"non-thermal":	{"JJ"},
"non-time":	{"NN"},
"non-tories":	{"NNS"},
"non-toxic":	{"JJ"},
"non-trade":	{"JJ"},
"non-trade-related":	{"JJ"},
"non-traders":	{"NNS"},
"non-traditional":	{"JJ"},
"non-ugric":	{"NN"},
"non-union":	{"JJ"},
"non-user":	{"NN"},
"non-utility":	{"JJ"},
"non-vaccinated":	{"JJ"},
"non-verbal":	{"JJ"},
"non-verbally":	{"RB"},
"non-vested":	{"JJ"},
"non-veterans":	{"NNS"},
"non-violence":	{"NN"},
"non-violent":	{"JJ"},
"non-violently":	{"RB"},
"non-viral":	{"JJ"},
"non-virulent":	{"JJ"},
"non-volatile":	{"JJ"},
"non-voting":	{"JJ","NN"},
"non-wage":	{"JJ"},
"non-warranty":	{"NN"},
"non-water-soluble":	{"JJ"},
"non-wealthy":	{"JJ"},
"non-western":	{"JJ"},
"non-white":	{"JJ","NN"},
"non-wireline":	{"JJ"},
"non-working":	{"JJ"},
"non-writers":	{"NNS"},
"non-zero":	{"JJ"},
"nonabrasive":	{"JJ"},
"nonabsorbency":	{"NN"},
"nonabsorbent":	{"JJ"},
"nonabsorptive":	{"JJ"},
"nonacademic":	{"JJ","NN"},
"nonacademics":	{"NNS"},
"nonacceptance":	{"NN"},
"nonacceptances":	{"NNS"},
"nonaccomplishment":	{"NN"},
"nonachievement":	{"NN"},
"nonachiever":	{"NN"},
"nonacid":	{"JJ"},
"nonactive":	{"JJ"},
"nonadaptive":	{"JJ"},
"nonaddictive":	{"JJ"},
"nonadhesive":	{"JJ"},
"nonadjacent":	{"JJ"},
"nonadjectival":	{"JJ"},
"nonadjustable":	{"JJ"},
"nonadministrative":	{"JJ"},
"nonadsorbent":	{"JJ"},
"nonadsorptive":	{"JJ"},
"nonadvantageous":	{"JJ"},
"nonadverbial":	{"JJ"},
"nonaesthetic":	{"JJ"},
"nonaffiliated":	{"JJ"},
"nonage":	{"NN"},
"nonaged":	{"JJ"},
"nonagenarian":	{"NN","JJ"},
"nonagenarians":	{"NNS"},
"nonaggression":	{"NN"},
"nonaggressive":	{"JJ"},
"nonagon":	{"NN"},
"nonagreement":	{"NN","JJ"},
"nonagreements":	{"NNS"},
"nonagricultural":	{"JJ"},
"nonalcoholic":	{"JJ"},
"nonaligned":	{"JJ"},
"nonalignment":	{"NN"},
"nonalinement":	{"NN"},
"nonallele":	{"NN"},
"nonallergenic":	{"JJ"},
"nonallergic":	{"JJ"},
"nonalphabetic":	{"JJ"},
"nonamendable":	{"JJ"},
"nonanalytic":	{"JJ"},
"nonantagonistic":	{"JJ"},
"nonapologetic":	{"JJ"},
"nonapostolic":	{"JJ"},
"nonappearance":	{"NN"},
"nonappearing":	{"JJ"},
"nonapplicable":	{"JJ"},
"nonappointive":	{"JJ"},
"nonaquatic":	{"JJ"},
"nonarbitrable":	{"JJ"},
"nonarbitrary":	{"JJ"},
"nonarboreal":	{"JJ"},
"nonaristocratic":	{"JJ"},
"nonartistic":	{"JJ"},
"nonassertive":	{"JJ"},
"nonassessable":	{"JJ"},
"nonassignable":	{"JJ"},
"nonassociative":	{"JJ"},
"nonastringent":	{"JJ"},
"nonathlete":	{"NN"},
"nonathletes":	{"NNS"},
"nonathletic":	{"JJ"},
"nonatmospheric":	{"JJ"},
"nonattendance":	{"NN"},
"nonattendances":	{"NNS"},
"nonattender":	{"NN"},
"nonattributive":	{"JJ"},
"nonauthoritative":	{"JJ"},
"nonautomatic":	{"JJ"},
"nonautomotive":	{"JJ"},
"nonautonomous":	{"JJ"},
"nonavailability":	{"NN"},
"nonbacterial":	{"JJ"},
"nonbanking":	{"JJ"},
"nonbasic":	{"JJ"},
"nonbearing":	{"JJ"},
"nonbeing":	{"NN"},
"nonbeliever":	{"NN"},
"nonbelieving":	{"JJ"},
"nonbelligerency":	{"NN"},
"nonbelligerent":	{"JJ","NN"},
"nonbinding":	{"JJ"},
"nonblack":	{"JJ","NN"},
"nonblacks":	{"NNS"},
"nonbuilding":	{"JJ"},
"nonbusiness":	{"NN"},
"noncallable":	{"JJ"},
"noncaloric":	{"JJ"},
"noncandidate":	{"NN"},
"noncarbonated":	{"JJ"},
"noncareer":	{"JJ"},
"noncash":	{"NN","JJ"},
"noncausal":	{"JJ"},
"noncausative":	{"JJ"},
"nonce":	{"NN","JJ"},
"nonce-word":	{"NN"},
"noncellular":	{"JJ"},
"nonchalance":	{"NN"},
"nonchalant":	{"JJ"},
"nonchalantly":	{"RB"},
"nonchlorinated":	{"JJ"},
"nonchristian":	{"JJ"},
"nonchurchgoing":	{"JJ"},
"noncitizen":	{"NN"},
"noncivilised":	{"JJ"},
"noncivilized":	{"JJ"},
"nonclassical":	{"JJ"},
"nonclassifiable":	{"JJ"},
"nonclinical":	{"JJ"},
"noncollapsable":	{"JJ"},
"noncollapsible":	{"JJ"},
"noncolumned":	{"JJ"},
"noncom":	{"NN"},
"noncombat":	{"JJ","NN"},
"noncombatant":	{"NN","JJ"},
"noncombatants":	{"NNS"},
"noncombinative":	{"JJ"},
"noncombining":	{"JJ"},
"noncombustible":	{"JJ"},
"noncommercial":	{"JJ"},
"noncommissioned":	{"JJ"},
"noncommittal":	{"JJ"},
"noncommittally":	{"RB"},
"noncommunicable":	{"JJ"},
"noncommunist":	{"NN","JJ"},
"noncommunists":	{"NNS"},
"noncompetitive":	{"JJ"},
"noncompetitively":	{"RB"},
"noncompliance":	{"NN"},
"noncompliant":	{"JJ","NN"},
"noncomprehensive":	{"JJ"},
"noncomprehensively":	{"RB"},
"nonconcentric":	{"JJ"},
"nonconducting":	{"JJ"},
"nonconductive":	{"JJ"},
"nonconductor":	{"NN"},
"nonconformance":	{"NN"},
"nonconforming":	{"NN","JJ"},
"nonconformism":	{"NN"},
"nonconformist":	{"NN","JJ"},
"nonconformists":	{"NNS"},
"nonconformity":	{"NN"},
"nonconscious":	{"JJ"},
"noncontagious":	{"JJ"},
"noncontentious":	{"JJ"},
"noncontinuous":	{"JJ"},
"noncontract":	{"JJ"},
"noncontroversial":	{"JJ"},
"nonconvergent":	{"JJ"},
"nonconvertible":	{"JJ"},
"noncorrosive":	{"JJ"},
"noncriminal":	{"JJ"},
"noncritical":	{"JJ"},
"noncrucial":	{"JJ"},
"noncrystalline":	{"JJ"},
"noncumulative":	{"JJ"},
"noncurrent":	{"JJ"},
"noncustomer":	{"NN"},
"noncyclic":	{"JJ"},
"noncyclical":	{"JJ"},
"nondairy":	{"JJ"},
"nondeductible":	{"JJ"},
"nondefeatist":	{"JJ"},
"nondefense":	{"JJ","NN"},
"nondemocratic":	{"JJ"},
"nondenominational":	{"JJ"},
"nondescript":	{"JJ","NN"},
"nondescriptly":	{"RB"},
"nondestructive":	{"JJ"},
"nondeterminacy":	{"NN"},
"nondevelopment":	{"NN"},
"nondigestible":	{"JJ"},
"nondiscretionary":	{"JJ"},
"nondiscrimination":	{"NN"},
"nondiscriminatory":	{"JJ"},
"nondisjunction":	{"NN"},
"nondisposable":	{"JJ"},
"nondoctrinaire":	{"JJ"},
"nondollar":	{"JJ"},
"nondrinker":	{"NN"},
"nondriver":	{"NN"},
"nondrying":	{"JJ"},
"nondurable":	{"JJ"},
"nondurables":	{"NNS"},
"none":	{"PRP","RB"},
"nonechoic":	{"JJ"},
"noneconomic":	{"JJ"},
"noneffervescent":	{"JJ"},
"nonelected":	{"JJ"},
"nonelective":	{"JJ"},
"nonelectrical":	{"JJ"},
"nonenterprising":	{"JJ"},
"nonentities":	{"NNS"},
"nonentity":	{"NN"},
"nonenzymatic":	{"JJ"},
"nonequivalence":	{"NN"},
"nonequivalent":	{"JJ"},
"nones":	{"NN"},
"nonessential":	{"JJ","NN"},
"nonessentials":	{"NNS"},
"nonesuch":	{"NN"},
"nonetheless":	{"RB"},
"nonevent":	{"NN"},
"nonevents":	{"NNS"},
"nonexecutive":	{"JJ"},
"nonexempt":	{"NN","JJ"},
"nonexistence":	{"NN"},
"nonexistent":	{"JJ"},
"nonexplorative":	{"JJ"},
"nonexploratory":	{"JJ"},
"nonexplosive":	{"JJ"},
"nonextant":	{"JJ"},
"nonextensile":	{"JJ"},
"nonfarm":	{"JJ","NN"},
"nonfat":	{"JJ"},
"nonfatal":	{"JJ"},
"nonfeasance":	{"NN"},
"nonferrous":	{"JJ"},
"nonfiction":	{"NN","JJ"},
"nonfictional":	{"JJ"},
"nonfigurative":	{"JJ"},
"nonfinancial":	{"JJ"},
"nonfinite":	{"JJ"},
"nonfissile":	{"JJ"},
"nonfissionable":	{"JJ"},
"nonflammable":	{"JJ"},
"nonflavored":	{"JJ"},
"nonflavoured":	{"JJ"},
"nonflowering":	{"JJ"},
"nonfood":	{"NN"},
"nonfunctional":	{"JJ"},
"nonglutinous":	{"JJ"},
"nongovernmental":	{"JJ"},
"nongranular":	{"JJ"},
"nongregarious":	{"JJ"},
"nonhairy":	{"JJ"},
"nonharmonic":	{"JJ"},
"nonhereditary":	{"JJ"},
"nonheritable":	{"JJ"},
"nonhierarchic":	{"JJ"},
"nonhierarchical":	{"JJ"},
"nonhuman":	{"JJ","NN"},
"nonimitative":	{"JJ"},
"nonimmune":	{"JJ"},
"nonindulgence":	{"NN"},
"nonindulgent":	{"JJ"},
"nonindustrial":	{"JJ"},
"noninfectious":	{"JJ"},
"noninflammatory":	{"JJ"},
"noninflationary":	{"JJ"},
"noninheritable":	{"JJ"},
"noninstitutional":	{"JJ"},
"noninstitutionalised":	{"JJ"},
"noninstitutionalized":	{"JJ"},
"nonintegrated":	{"JJ"},
"nonintellectual":	{"JJ"},
"noninterchangeable":	{"JJ"},
"noninterest":	{"JJ"},
"noninterest-income":	{"NN"},
"noninterference":	{"NN"},
"nonintersecting":	{"JJ"},
"nonintervention":	{"NN"},
"noninvasive":	{"JJ"},
"nonionic":	{"JJ"},
"nonionised":	{"JJ"},
"nonionized":	{"JJ"},
"nonism":	{"NN"},
"nonjudgmental":	{"JJ"},
"nonkosher":	{"JJ"},
"nonleaded":	{"JJ"},
"nonlegal":	{"JJ"},
"nonlethal":	{"JJ"},
"nonlexical":	{"JJ"},
"nonlexically":	{"RB"},
"nonlinear":	{"JJ"},
"nonlinguistic":	{"JJ"},
"nonliteral":	{"JJ"},
"nonliterary":	{"JJ"},
"nonliterate":	{"JJ"},
"nonliving":	{"JJ"},
"nonlogical":	{"JJ"},
"nonmagnetic":	{"JJ"},
"nonmandatory":	{"JJ"},
"nonmaterial":	{"JJ"},
"nonmaterialistic":	{"JJ"},
"nonmeaningful":	{"JJ"},
"nonmechanical":	{"JJ"},
"nonmechanistic":	{"JJ"},
"nonmedia":	{"NN"},
"nonmedical":	{"JJ"},
"nonmedically":	{"RB"},
"nonmedicated":	{"JJ"},
"nonmedication":	{"NN"},
"nonmedicinal":	{"JJ"},
"nonmember":	{"NN"},
"nonmembers":	{"NNS"},
"nonmetal":	{"NN"},
"nonmetallic":	{"JJ"},
"nonmetamorphic":	{"JJ"},
"nonmigratory":	{"JJ"},
"nonmilitary":	{"JJ"},
"nonminority":	{"JJ"},
"nonmodern":	{"JJ"},
"nonmonotonic":	{"JJ"},
"nonmotile":	{"JJ"},
"nonmoving":	{"JJ"},
"nonmusical":	{"JJ"},
"nonmythological":	{"JJ"},
"nonnarrative":	{"JJ"},
"nonnative":	{"JJ"},
"nonnatural":	{"JJ"},
"nonnegative":	{"JJ"},
"nonnegligible":	{"JJ"},
"nonnomadic":	{"JJ"},
"nonnormative":	{"JJ"},
"nonobjective":	{"JJ"},
"nonobligatory":	{"JJ"},
"nonobservance":	{"NN"},
"nonobservant":	{"NN"},
"nonoccurrence":	{"NN"},
"nonogenarian":	{"NN"},
"nonopening":	{"JJ"},
"nonoperating":	{"NN"},
"nonoperational":	{"JJ"},
"nonoscillatory":	{"JJ"},
"nonparallel":	{"JJ"},
"nonparametric":	{"JJ"},
"nonparasitic":	{"JJ"},
"nonpareil":	{"NN","JJ"},
"nonpareils":	{"NNS"},
"nonparticipant":	{"NN"},
"nonparticipation":	{"NN"},
"nonparticulate":	{"JJ"},
"nonpartisan":	{"JJ","NN"},
"nonpartisanship":	{"NN"},
"nonpartizan":	{"JJ","NN"},
"nonpasserine":	{"JJ"},
"nonpaying":	{"JJ"},
"nonpayment":	{"NN"},
"nonperformance":	{"NN"},
"nonperformers":	{"NNS"},
"nonperforming":	{"JJ"},
"nonperiodic":	{"JJ"},
"nonperson":	{"NN"},
"nonpersonal":	{"JJ"},
"nonphotosynthetic":	{"JJ"},
"nonphysical":	{"JJ"},
"nonplus":	{"VB","VBP","NN"},
"nonplused":	{"VBD","VBN","JJ"},
"nonpluses":	{"VBZ","NNS"},
"nonplusing":	{"VBG"},
"nonplussed":	{"VBD","VBN","JJ"},
"nonplusses":	{"VBZ"},
"nonplussing":	{"VBG"},
"nonpoisonous":	{"JJ"},
"nonpolar":	{"JJ"},
"nonpolitical":	{"JJ"},
"nonporous":	{"JJ"},
"nonpregnant":	{"JJ"},
"nonprehensile":	{"JJ"},
"nonprescription":	{"JJ","NN"},
"nonpriority":	{"NN"},
"nonproductive":	{"JJ"},
"nonprofessional":	{"JJ"},
"nonprofit":	{"JJ","NN"},
"nonprognosticative":	{"JJ"},
"nonprogressive":	{"JJ"},
"nonproliferation":	{"NN"},
"nonproprietary":	{"JJ"},
"nonprotractile":	{"JJ"},
"nonpsychoactive":	{"JJ"},
"nonpublic":	{"JJ"},
"nonpurulent":	{"JJ"},
"nonqualified":	{"JJ"},
"nonracial":	{"JJ"},
"nonracist":	{"JJ"},
"nonradioactive":	{"JJ"},
"nonrandom":	{"JJ"},
"nonrational":	{"JJ"},
"nonreactivity":	{"NN"},
"nonreactor":	{"NN"},
"nonreactors":	{"NNS"},
"nonreader":	{"NN"},
"nonreaders":	{"NNS"},
"nonreciprocal":	{"JJ"},
"nonreciprocating":	{"JJ"},
"nonrecourse":	{"JJ"},
"nonrecreational":	{"JJ"},
"nonrecurring":	{"JJ"},
"nonreflecting":	{"JJ"},
"nonreflective":	{"JJ"},
"nonrefundable":	{"JJ"},
"nonregulated":	{"JJ"},
"nonremittal":	{"NN"},
"nonrenewable":	{"JJ"},
"nonrepetitive":	{"JJ"},
"nonrepresentational":	{"JJ"},
"nonrepresentative":	{"JJ"},
"nonresident":	{"NN","JJ"},
"nonresidential":	{"JJ"},
"nonresidential-contracting":	{"JJ"},
"nonresidents":	{"NNS"},
"nonresilient":	{"JJ"},
"nonresinous":	{"JJ"},
"nonresiny":	{"JJ"},
"nonresistance":	{"NN"},
"nonresistant":	{"JJ"},
"nonresonant":	{"JJ"},
"nonrestrictive":	{"JJ"},
"nonreticulate":	{"JJ"},
"nonretractable":	{"JJ"},
"nonretractile":	{"JJ"},
"nonreturnable":	{"JJ"},
"nonreversible":	{"JJ"},
"nonrhythmic":	{"JJ"},
"nonrigid":	{"JJ"},
"nonroyal":	{"JJ"},
"nonruminant":	{"JJ"},
"nonsectarian":	{"NN","JJ"},
"nonsegmental":	{"JJ"},
"nonsegregated":	{"JJ"},
"nonsense":	{"NN","JJ","UH"},
"nonsensical":	{"JJ"},
"nonsensicality":	{"NN"},
"nonsensically":	{"RB"},
"nonsensicalness":	{"NN"},
"nonsensitive":	{"JJ"},
"nonsexual":	{"JJ"},
"nonshifters":	{"NNS"},
"nonsignificant":	{"JJ"},
"nonsingular":	{"JJ"},
"nonskid":	{"JJ"},
"nonslip":	{"JJ"},
"nonslippery":	{"JJ"},
"nonsmoker":	{"NN"},
"nonsmokers":	{"NNS"},
"nonsocial":	{"JJ"},
"nonsocialist":	{"JJ"},
"nonsolution":	{"NN"},
"nonsolutions":	{"NNS"},
"nonsovereign":	{"JJ"},
"nonspatial":	{"JJ"},
"nonspeaking":	{"JJ"},
"nonspecific":	{"JJ"},
"nonspecifically":	{"RB"},
"nonspherical":	{"JJ"},
"nonsporting":	{"JJ"},
"nonstandard":	{"JJ"},
"nonstarter":	{"NN"},
"nonstate":	{"JJ"},
"nonsteroid":	{"NN"},
"nonsteroidal":	{"JJ","NN"},
"nonstick":	{"JJ"},
"nonstop":	{"JJ","RB"},
"nonstrategic":	{"JJ"},
"nonstriker":	{"NN"},
"nonstrikers":	{"NNS"},
"nonstructural":	{"JJ"},
"nonsubjective":	{"JJ"},
"nonsubmergible":	{"JJ"},
"nonsubmersible":	{"JJ"},
"nonsuccessful":	{"JJ"},
"nonsuch":	{"NN"},
"nonsuppurative":	{"JJ"},
"nonsurgical":	{"JJ"},
"nonsweet":	{"JJ"},
"nonsyllabic":	{"JJ"},
"nonsymbiotic":	{"JJ"},
"nonsynchronous":	{"JJ"},
"nonsynthetic":	{"JJ"},
"nonsystematic":	{"JJ"},
"nontaxable":	{"JJ"},
"nontechnical":	{"JJ"},
"nontelescopic":	{"JJ"},
"nontelescoping":	{"JJ"},
"nonterritorial":	{"JJ"},
"nontheatrical":	{"JJ"},
"nonthermal":	{"JJ"},
"nonthreatening":	{"JJ"},
"nontoxic":	{"JJ"},
"nontrade":	{"NN"},
"nontraditional":	{"JJ"},
"nontransferable":	{"JJ"},
"nontranslational":	{"JJ"},
"nontransmissible":	{"JJ"},
"nontricyclic":	{"NN"},
"nonturbulent":	{"JJ"},
"nonuniform":	{"JJ"},
"nonuniformity":	{"NN"},
"nonunion":	{"JJ","NN"},
"nonunionised":	{"JJ"},
"nonunionized":	{"JJ"},
"nonuple":	{"JJ"},
"nonurgent":	{"JJ"},
"nonvenomous":	{"JJ"},
"nonverbal":	{"JJ"},
"nonverbally":	{"RB"},
"nonviable":	{"JJ"},
"nonvintage":	{"JJ"},
"nonviolence":	{"NN"},
"nonviolent":	{"JJ"},
"nonviolently":	{"RB"},
"nonvirulent":	{"JJ"},
"nonviscid":	{"JJ"},
"nonvisual":	{"JJ"},
"nonvolatile":	{"JJ"},
"nonvolatilisable":	{"JJ"},
"nonvolatilizable":	{"JJ"},
"nonvoluntary":	{"JJ"},
"nonvoting":	{"JJ"},
"nonwashable":	{"JJ"},
"nonwhite":	{"NN","JJ"},
"nonwhites":	{"NNS"},
"nonwoody":	{"JJ"},
"nonworker":	{"NN"},
"nonworking":	{"JJ"},
"noodle":	{"NN","VB","VBP"},
"noodled":	{"VBD","VBN"},
"noodles":	{"NNS","VBZ"},
"noodling":	{"VBG"},
"nook":	{"NN"},
"nookie":	{"NN"},
"nooks":	{"NNS"},
"nooky":	{"NN"},
"noon":	{"NN","JJ"},
"noonan":	{"NN"},
"noonday":	{"JJ","NN"},
"noontide":	{"NN"},
"noontime":	{"NN"},
"noose":	{"NN","VB","VBP"},
"noosed":	{"VBD","VBN"},
"nooses":	{"NNS","VBZ"},
"noosing":	{"VBG"},
"nootka":	{"NN"},
"nootropic":	{"JJ","NN"},
"nootropics":	{"NNS"},
"nopal":	{"NN"},
"nopalea":	{"NN"},
"nope":	{"UH"},
"nor":	{"CC","RB"},
"nor'-east":	{"NN","RB","JJ"},
"nor'-nor'-east":	{"NN","RB"},
"nor'-nor'-west":	{"NN","RB"},
"nor'-west":	{"JJ","RB","NN"},
"nor-q-d":	{"NN"},
"noradrenalin":	{"NN"},
"noradrenaline":	{"NN"},
"norcross":	{"NNS"},
"nord-pas-de-calais":	{"NN"},
"noreaster":	{"NN"},
"noreg":	{"NN"},
"norepinephrine":	{"NN"},
"norethandrolone":	{"NN"},
"norethindrone":	{"NN"},
"norethynodrel":	{"NN"},
"norflex":	{"NN"},
"norge":	{"NN"},
"norgestrel":	{"NN"},
"noria":	{"NN"},
"noriegan":	{"JJ"},
"noriegas":	{"NNS"},
"norinyl":	{"NN"},
"norlestrin":	{"NN"},
"norlutin":	{"NN"},
"norm":	{"NN"},
"normal":	{"JJ","NN"},
"normalcy":	{"NN"},
"normalisation":	{"NN"},
"normalise":	{"VB","VBP"},
"normalised":	{"VBD","VBN"},
"normaliser":	{"NN"},
"normalises":	{"VBZ"},
"normalising":	{"VBG"},
"normality":	{"NN"},
"normalization":	{"NN"},
"normalize":	{"VB","VBP"},
"normalized":	{"VBD","VBN"},
"normalizer":	{"NN"},
"normalizes":	{"VBZ"},
"normalizing":	{"VBG"},
"normally":	{"RB"},
"norman-french":	{"NN"},
"normandie":	{"NN"},
"normative":	{"JJ"},
"normativity":	{"NN"},
"normcore":	{"NN"},
"normie":	{"NN"},
"normies":	{"NNS"},
"normodyne":	{"NN"},
"normotensive":	{"JJ"},
"normothermia":	{"NN"},
"norms":	{"NNS"},
"norn":	{"NN"},
"norrish":	{"NN"},
"norte":	{"NN"},
"north":	{"RB","NN","JJ"},
"north-bound":	{"JJ"},
"north-central":	{"JJ"},
"north-east":	{"RB"},
"north-easterly":	{"JJ"},
"north-eastern":	{"JJ"},
"north-eastward":	{"JJ","RB"},
"north-eastwards":	{"RB"},
"north-flowing":	{"JJ"},
"north-northeast":	{"NN","JJ","RB"},
"north-northwest":	{"NN","JJ","RB"},
"north-polar":	{"JJ"},
"north-west":	{"JJ","RB","NN"},
"north-westerly":	{"JJ"},
"north-western":	{"JJ"},
"north-westward":	{"JJ","RB"},
"north-westwards":	{"RB"},
"northbound":	{"JJ"},
"northeast":	{"JJ","NN","RB"},
"northeaster":	{"NN"},
"northeasterly":	{"JJ"},
"northeastern":	{"JJ"},
"northeasters":	{"NNS"},
"northeastward":	{"JJ","RB"},
"northeastwardly":	{"RB"},
"northeastwards":	{"RB"},
"norther":	{"NN"},
"northerly":	{"JJ"},
"northern":	{"JJ"},
"northerner":	{"NN"},
"northerners":	{"NNS"},
"northernmost":	{"JJ"},
"northernness":	{"NN"},
"northers":	{"NNS"},
"northland":	{"NN"},
"northman":	{"NN"},
"northmost":	{"JJ"},
"northrop":	{"NN"},
"northward":	{"RB","JJ"},
"northwards":	{"RB"},
"northwest":	{"JJ","RB","NN"},
"northwester":	{"NN"},
"northwesterly":	{"JJ"},
"northwestern":	{"JJ"},
"northwesters":	{"NNS"},
"northwestward":	{"JJ","RB"},
"northwestwardly":	{"RB"},
"northwestwards":	{"RB"},
"nortriptyline":	{"NN"},
"noruz":	{"NN"},
"norvasc":	{"NN"},
"norvir":	{"NN"},
"nos":	{"NNS"},
"nos.":	{"NNS"},
"nose":	{"NN","VB","VBP"},
"nose-cone":	{"NN"},
"nose-cones":	{"NNS"},
"nose-dive":	{"NN","VB","VBP"},
"nose-dived":	{"VBD","VBN"},
"nose-dives":	{"NNS","VBZ"},
"nose-diving":	{"VBG"},
"nose-dove":	{"VBD"},
"nose-to-nose":	{"JJ"},
"nosebag":	{"NN"},
"nosebags":	{"NNS"},
"noseband":	{"NN"},
"nosebleed":	{"NN"},
"nosebleeds":	{"NNS"},
"nosecount":	{"NN"},
"nosed":	{"JJ","VBD","VBN"},
"nosedive":	{"NN","VB","VBP"},
"nosedived":	{"VBD","VBN"},
"nosedives":	{"NNS","VBZ"},
"nosediving":	{"VBG"},
"nosegay":	{"NN"},
"nosegays":	{"NNS"},
"noseless":	{"JJ"},
"nosepiece":	{"NN"},
"nosepieces":	{"NNS"},
"noses":	{"NNS","VBZ"},
"nosewheel":	{"NN"},
"nosey":	{"JJ","NN"},
"nosey-parker":	{"NN"},
"nosh":	{"NN","VB","VBP"},
"nosh-up":	{"NN"},
"noshed":	{"VBD","VBN"},
"nosher":	{"NN"},
"noshes":	{"VBZ"},
"noshing":	{"VBG"},
"nosier":	{"JJR"},
"nosiest":	{"JJS"},
"nosiness":	{"NN"},
"nosing":	{"VBG"},
"nosocomial":	{"JJ"},
"nosohusial":	{"JJ"},
"nosology":	{"NN"},
"nostalgia":	{"NN"},
"nostalgic":	{"JJ"},
"nostalgically":	{"RB"},
"nostalgist":	{"NN"},
"nostalgists":	{"NNS"},
"nostoc":	{"NN"},
"nostocaceae":	{"NN"},
"nostril":	{"NN"},
"nostrils":	{"NNS"},
"nostrum":	{"NN"},
"nostrums":	{"NNS"},
"nosy":	{"JJ","NN"},
"nosy-parker":	{"NN"},
"not":	{"RB"},
"not-A":	{"NN"},
"not-a":	{"NN"},
"not-ace":	{"NN"},
"not-for-profit":	{"JJ"},
"not-guilty":	{"JJ"},
"not-knowing":	{"RB"},
"not-less-deadly":	{"JJ"},
"not-quite-mainstream":	{"JJ"},
"not-quite-perfect":	{"JJ"},
"not-so-favorite":	{"JJ"},
"not-so-lonely":	{"JJ"},
"not-so-new":	{"JJ"},
"not-so-pale":	{"JJ"},
"not-so-rich":	{"NN"},
"not-so-subtly":	{"RB"},
"not-so-trivial":	{"JJ"},
"not-strictly-practical":	{"JJ"},
"not-too-distant":	{"JJ"},
"not-yet-married":	{"JJ"},
"nota":	{"NNS"},
"notability":	{"NN"},
"notable":	{"JJ","NN"},
"notables":	{"NNS"},
"notably":	{"RB"},
"notarise":	{"VB","VBP"},
"notarised":	{"VBD","VBN","JJ"},
"notarises":	{"VBZ"},
"notarising":	{"VBG"},
"notarization":	{"NN"},
"notarize":	{"VB","VBP"},
"notarized":	{"VBD","VBN","JJ"},
"notarizes":	{"VBZ"},
"notarizing":	{"VBG"},
"notary":	{"NN","JJ"},
"notate":	{"VB","VBP"},
"notated":	{"VBD","VBN"},
"notates":	{"VBZ"},
"notating":	{"VBG"},
"notation":	{"NN"},
"notations":	{"NNS"},
"notch":	{"NN","VB","VBP"},
"notched":	{"JJ","VBD","VBN"},
"notched-stick":	{"JJ"},
"notches":	{"VBZ","NNS"},
"notching":	{"VBG"},
"note":	{"NN","VBP","VB"},
"notebook":	{"NN"},
"notebook-size":	{"JJ"},
"notebook-sized":	{"JJ"},
"notebooks":	{"NNS"},
"notecase":	{"NN"},
"notechis":	{"NN"},
"noted":	{"VBD","VBN","JJ"},
"noteholder":	{"NN"},
"noteholders":	{"NNS"},
"notemigonus":	{"NN"},
"notepad":	{"NN"},
"notepads":	{"NNS"},
"notepaper":	{"NN"},
"notes":	{"NNS","VBZ"},
"noteworthy":	{"JJ"},
"nothin":	{"NN"},
"nothing":	{"PRP","RB","NN"},
"nothing-down":	{"JJ"},
"nothingness":	{"NN"},
"nothings":	{"NNS"},
"nothofagus":	{"NN"},
"nothosaur":	{"NN"},
"nothosauria":	{"NN"},
"notice":	{"NN","VB","VBP"},
"notice-board":	{"NN"},
"notice-boards":	{"NNS"},
"noticeability":	{"NN"},
"noticeable":	{"JJ","NN"},
"noticeableness":	{"NN"},
"noticeably":	{"RB"},
"noticed":	{"VBD","VBN"},
"noticer":	{"NN"},
"notices":	{"NNS","VBZ"},
"noticing":	{"VBG"},
"notifiable":	{"JJ"},
"notification":	{"NN"},
"notifications":	{"NNS"},
"notified":	{"VBD","VBN"},
"notifies":	{"VBZ"},
"notify":	{"VB","VBP"},
"notifying":	{"VBG"},
"noting":	{"VBG"},
"notion":	{"NN"},
"notional":	{"JJ"},
"notionally":	{"RB"},
"notions":	{"NNS"},
"notitia":	{"NN"},
"notitiae":	{"NNS"},
"notochord":	{"NN"},
"notomys":	{"NNS"},
"notonecta":	{"NN"},
"notonectidae":	{"NN"},
"notophthalmus":	{"NN"},
"notoriety":	{"NN"},
"notorious":	{"JJ"},
"notoriously":	{"RB"},
"notornis":	{"NN"},
"notoryctidae":	{"NN"},
"notoryctus":	{"NN"},
"notostraca":	{"NN"},
"notropis":	{"NN"},
"nott":	{"RB"},
"notturno":	{"NN"},
"notum":	{"NN"},
"notwithstanding":	{"IN","RB"},
"nouakchott":	{"NN"},
"nougat":	{"NN"},
"nought":	{"NN","CD"},
"noumenon":	{"NN"},
"noun":	{"NN"},
"nouns":	{"NNS"},
"nourish":	{"VB","VBP"},
"nourished":	{"JJ","VBD","VBN"},
"nourishes":	{"VBZ"},
"nourishing":	{"JJ","VBG"},
"nourishment":	{"NN"},
"nous":	{"NN"},
"nouveau":	{"JJ"},
"nouveau-riche":	{"JJ","NN","NNS"},
"nouveaux":	{"FW"},
"nouveaux-riches":	{"NNS"},
"nouvelle":	{"NN","JJ"},
"nov":	{"NN"},
"nov-esperanto":	{"NN"},
"nov-latin":	{"NN"},
"nova":	{"NN"},
"novae":	{"NNS"},
"novas":	{"NNS"},
"novate":	{"VB","VBP"},
"novation":	{"NN"},
"novel":	{"NN","JJ"},
"novel-in-progress":	{"NN"},
"novelette":	{"NN"},
"novelisation":	{"NN"},
"novelise":	{"VB","VBP"},
"novelised":	{"VBD","VBN"},
"novelises":	{"VBZ"},
"novelising":	{"VBG"},
"novelist":	{"NN"},
"novelistic":	{"JJ"},
"novelists":	{"NNS"},
"novelization":	{"NN"},
"novelize":	{"VB","VBP"},
"novelized":	{"VBD","VBN"},
"novelizes":	{"VBZ"},
"novelizing":	{"VBG"},
"novella":	{"NN"},
"novellas":	{"NNS"},
"novels":	{"NNS"},
"novelties":	{"NNS"},
"novelty":	{"NN"},
"novena":	{"NN"},
"novgorod":	{"NN"},
"novial":	{"NN"},
"novice":	{"NN"},
"novices":	{"NNS"},
"noviciate":	{"NN"},
"noviciates":	{"NNS"},
"novillada":	{"NN"},
"novillero":	{"NN"},
"novitiate":	{"NN"},
"novitiates":	{"NNS"},
"novo":	{"FW"},
"novobiocin":	{"NN"},
"novocain":	{"NN"},
"novocaine":	{"NN"},
"novosibirsk":	{"NN"},
"now":	{"RB","IN","CC","PRP"},
"now-Rep":	{"JJ"},
"now-deceased":	{"JJ"},
"now-defunct":	{"JJ","NNP"},
"now-discontinued":	{"JJ"},
"now-dismembered":	{"JJ"},
"now-dominant":	{"JJ"},
"now-evident":	{"JJ"},
"now-famous":	{"JJ"},
"now-historic":	{"JJ"},
"now-infamous":	{"JJ"},
"now-legal":	{"JJ"},
"now-misplaced":	{"JJ"},
"now-notorious":	{"JJ"},
"now-obscure":	{"JJ"},
"now-ousted":	{"JJ"},
"now-purged":	{"JJ"},
"now-rep":	{"JJ"},
"now-repentant":	{"JJ"},
"now-scuttled":	{"JJ"},
"now-shaky":	{"JJ"},
"now-shuttered":	{"JJ"},
"now-smaller":	{"JJ"},
"now-standard":	{"JJ"},
"now-troubled":	{"JJ"},
"now-vacant":	{"JJ"},
"nowadays":	{"RB"},
"nowak":	{"NN"},
"nowbankrupt":	{"JJ"},
"nowhere":	{"RB","NN"},
"nowise":	{"RB"},
"nowness":	{"NN"},
"nowrooz":	{"NN"},
"nowruz":	{"NN"},
"nox":	{"NN"},
"noxious":	{"JJ"},
"noxiously":	{"RB"},
"noxiousness":	{"NN"},
"nozzle":	{"NN"},
"nozzles":	{"NNS"},
"np":	{"NN"},
"npa":	{"NN"},
"npc":	{"NN"},
"nra":	{"NN"},
"nrc":	{"NN"},
"nrem":	{"NN"},
"nrl":	{"NN"},
"nrna":	{"NN"},
"nro":	{"NN"},
"nrti":	{"NN"},
"nsa":	{"NN"},
"nsaid":	{"NN"},
"nsc":	{"NN"},
"nsf":	{"NN"},
"nsu":	{"NN"},
"nsw":	{"NN"},
"nswc":	{"NN"},
"nt":	{"RB","NN"},
"nth":	{"JJ"},
"ntis":	{"NN"},
"nu":	{"NN","JJ"},
"nuance":	{"NN"},
"nuanced":	{"JJ"},
"nuances":	{"NNS"},
"nub":	{"NN"},
"nubbin":	{"NN"},
"nubbiness":	{"NN"},
"nubbins":	{"NNS"},
"nubble":	{"NN"},
"nubbly":	{"JJ"},
"nubby":	{"JJ"},
"nubile":	{"JJ"},
"nucellus":	{"NN"},
"nuceoside":	{"NN"},
"nucha":	{"NN"},
"nucifraga":	{"NN"},
"nuclear":	{"JJ"},
"nuclear-armed":	{"JJ"},
"nuclear-arms":	{"NNS"},
"nuclear-bomb":	{"NN"},
"nuclear-industry":	{"NN"},
"nuclear-plant":	{"JJ"},
"nuclear-power":	{"JJ","NN"},
"nuclear-powered":	{"JJ"},
"nuclear-propulsion":	{"JJ"},
"nuclear-tipped":	{"JJ"},
"nuclear-weapons":	{"NNS","JJ"},
"nuclear-weapons-sites":	{"NNS"},
"nuclease":	{"NN"},
"nucleate":	{"JJ","VB","VBP"},
"nucleated":	{"VBD","VBN"},
"nucleates":	{"VBZ"},
"nucleating":	{"VBG"},
"nuclei":	{"NNS"},
"nucleic":	{"JJ"},
"nucleole":	{"NN"},
"nucleoli":	{"NNS"},
"nucleolus":	{"NN"},
"nucleon":	{"NN"},
"nucleonics":	{"NN"},
"nucleoplasm":	{"NN"},
"nucleoprotein":	{"NN"},
"nucleoside":	{"NN"},
"nucleosynthesis":	{"NN"},
"nucleotide":	{"NN"},
"nucleotides":	{"NNS"},
"nucleus":	{"NN"},
"nuclide":	{"NN"},
"nucor-like":	{"JJ"},
"nuda":	{"NN"},
"nude":	{"JJ","NN"},
"nudeness":	{"NN"},
"nudes":	{"NNS"},
"nudge":	{"VB","VBP","NN"},
"nudged":	{"VBD","VBN"},
"nudger":	{"NN"},
"nudges":	{"VBZ"},
"nudging":	{"VBG"},
"nudibranch":	{"NN"},
"nudibranchia":	{"FW"},
"nudibranchs":	{"NNS"},
"nudism":	{"NN"},
"nudist":	{"NN"},
"nudists":	{"NNS"},
"nudity":	{"NN"},
"nudnick":	{"NN"},
"nudnik":	{"NN"},
"nuf":	{"RB"},
"nuffield":	{"NN"},
"nuffin":	{"NN"},
"nugatory":	{"JJ"},
"nugget":	{"NN"},
"nuggets":	{"NNS"},
"nuisance":	{"NN"},
"nuisances":	{"NNS"},
"nuke":	{"NN","VB","VBP"},
"nuked":	{"VBD","VBN"},
"nukes":	{"NNS","VBZ"},
"nuking":	{"VBG"},
"null":	{"JJ"},
"null-type":	{"JJ"},
"nullah":	{"NN"},
"nullification":	{"NN"},
"nullified":	{"VBD","VBN"},
"nullifier":	{"NN"},
"nullifiers":	{"NNS"},
"nullifies":	{"VBZ"},
"nullify":	{"VB","VBP"},
"nullifying":	{"VBG"},
"nullipara":	{"NN"},
"nulliparae":	{"NNS"},
"nulliparas":	{"NNS"},
"nulliparous":	{"JJ"},
"nullity":	{"NN"},
"numb":	{"JJ","VB","VBP"},
"numbat":	{"NN"},
"numbed":	{"JJ","VBD","VBN"},
"number":	{"NN","VBP","VB"},
"number-cruncher":	{"NN"},
"number-crunchers":	{"NNS"},
"number-one":	{"JJ"},
"numbered":	{"JJ","VBD","VBN"},
"numbering":	{"NN","VBG"},
"numberless":	{"JJ"},
"numberplate":	{"NN"},
"numbers":	{"NNS","VBZ"},
"numbfish":	{"NN"},
"numbing":	{"JJ","VBG"},
"numbingly":	{"RB"},
"numbly":	{"RB"},
"numbness":	{"NN"},
"numbs":	{"VBZ"},
"numdah":	{"NN"},
"numen":	{"NN"},
"numenius":	{"NN"},
"numenous":	{"JJ"},
"numerable":	{"JJ"},
"numeracy":	{"NN"},
"numeral":	{"NN","JJ"},
"numerals":	{"NNS"},
"numerate":	{"JJ","VB","VBP"},
"numerated":	{"VBD","VBN"},
"numerates":	{"VBZ"},
"numerating":	{"VBG"},
"numeration":	{"NN"},
"numerations":	{"NNS"},
"numerator":	{"NN"},
"numerators":	{"NNS"},
"numeric":	{"JJ"},
"numerical":	{"JJ"},
"numerically":	{"RB"},
"numerological":	{"JJ"},
"numerologist":	{"NN"},
"numerology":	{"NN"},
"numerosity":	{"NN"},
"numerous":	{"JJ"},
"numerousness":	{"NN"},
"numida":	{"NN"},
"numidia":	{"NN"},
"numidian":	{"JJ","NN"},
"numididae":	{"NN"},
"numidinae":	{"NN"},
"numinous":	{"JJ"},
"numismatic":	{"JJ"},
"numismatics":	{"NN"},
"numismatist":	{"NN"},
"numismatists":	{"NNS"},
"numismatologist":	{"NN"},
"numismatology":	{"NN"},
"nummulite":	{"NN"},
"nummulitidae":	{"NN"},
"numskull":	{"NN"},
"numskulls":	{"NNS"},
"nun":	{"NN"},
"nunavut":	{"NN"},
"nuncio":	{"NN"},
"nuncios":	{"NNS"},
"nung":	{"NN"},
"nunn":	{"NN"},
"nunneries":	{"NNS"},
"nunnery":	{"NN"},
"nuns":	{"NNS"},
"nuper":	{"FW"},
"nuphar":	{"NN"},
"nuprin":	{"NN"},
"nuptial":	{"JJ"},
"nuptials":	{"NNS"},
"nuptse":	{"NN"},
"nurnberg":	{"NN"},
"nurse":	{"NN","VBP","VB"},
"nurse-midwife":	{"NN"},
"nursed":	{"VBD","VBN"},
"nurseling":	{"NN"},
"nurselings":	{"NNS"},
"nursemaid":	{"NN"},
"nursemaids":	{"NNS"},
"nurser":	{"NN"},
"nurseries":	{"NNS"},
"nursers":	{"NNS"},
"nursery":	{"NN"},
"nurseryman":	{"NN"},
"nurserymen":	{"NNS"},
"nurses":	{"NNS","VBZ"},
"nursing":	{"NN","VBG"},
"nursing-home":	{"NN"},
"nursing-homes":	{"NNS"},
"nursling":	{"NN"},
"nurslings":	{"NNS"},
"nurtural":	{"JJ"},
"nurturance":	{"NN"},
"nurturant":	{"JJ"},
"nurture":	{"VB","NN","VBP"},
"nurtured":	{"VBD","VBN"},
"nurturer":	{"NN"},
"nurtures":	{"VBZ"},
"nurturing":	{"VBG","NN","JJ"},
"nusku":	{"NN"},
"nussbaum":	{"NN"},
"nut":	{"NN","VB","VBP"},
"nut-bearing":	{"JJ"},
"nut-brown":	{"JJ"},
"nut-case":	{"NN"},
"nut-cases":	{"NNS"},
"nut-house":	{"NN"},
"nut-houses":	{"NNS"},
"nut-like":	{"JJ"},
"nutate":	{"VB","VBP"},
"nutated":	{"VBD","VBN"},
"nutates":	{"VBZ"},
"nutating":	{"VBG"},
"nutation":	{"NN"},
"nutations":	{"NNS"},
"nutbag":	{"NN"},
"nutbags":	{"NNS"},
"nutcase":	{"NN"},
"nutcases":	{"NNS"},
"nutcracker":	{"NN"},
"nutcrackers":	{"NNS"},
"nutgrass":	{"NN"},
"nuthatch":	{"NN"},
"nuthouse":	{"NN"},
"nuthouses":	{"NNS"},
"nutlet":	{"NN"},
"nutlike":	{"JJ"},
"nutmeg":	{"NN","VB","VBP"},
"nutmeg-shaped":	{"JJ"},
"nutmeg-yew":	{"NN"},
"nutmegged":	{"VBD","VBN"},
"nutmegging":	{"VBG"},
"nutmegs":	{"NNS","VBZ"},
"nutria":	{"NN"},
"nutrient":	{"JJ","NN"},
"nutrients":	{"NNS"},
"nutrification":	{"NN"},
"nutrified":	{"VBD","VBN"},
"nutrifies":	{"VBZ"},
"nutrify":	{"VB","VBP"},
"nutrifying":	{"VBG"},
"nutriment":	{"NN"},
"nutriments":	{"NNS"},
"nutrition":	{"NN"},
"nutritional":	{"JJ"},
"nutritionally":	{"RB"},
"nutritionary":	{"JJ"},
"nutritionist":	{"NN"},
"nutritionists":	{"NNS"},
"nutritious":	{"JJ"},
"nutritiousness":	{"NN"},
"nutritive":	{"JJ"},
"nutritiveness":	{"NN"},
"nuts":	{"NNS","JJ","VBZ","UH"},
"nuts-and-bolts":	{"JJ"},
"nutsedge":	{"NN"},
"nutshell":	{"NN"},
"nutshells":	{"NNS"},
"nutted":	{"VBD","VBN"},
"nutter":	{"NN"},
"nutters":	{"NNS"},
"nuttily":	{"RB"},
"nutting":	{"VBG"},
"nutty":	{"JJ"},
"nuwc":	{"NN"},
"nux":	{"NN"},
"nuytsia":	{"NN"},
"nuzzle":	{"VB","VBP"},
"nuzzled":	{"VBD","VBN"},
"nuzzles":	{"VBZ"},
"nuzzling":	{"VBG"},
"nv":	{"NN"},
"nw":	{"NN"},
"nw.":	{"NN"},
"nwbn":	{"NN"},
"nwbw":	{"NN"},
"nyala":	{"NN"},
"nyamuragira":	{"NN"},
"nyamwezi":	{"NN"},
"nyasaland":	{"NN"},
"nybble":	{"NN"},
"nyctaginaceae":	{"NN"},
"nyctaginia":	{"NN"},
"nyctalopia":	{"NN"},
"nyctanassa":	{"NN"},
"nyctereutes":	{"NNS"},
"nycticebus":	{"NN"},
"nycticorax":	{"NN"},
"nyctimene":	{"NN"},
"nyctophobia":	{"NN"},
"nycturia":	{"NN"},
"nydrazid":	{"NN"},
"nyet":	{"NN"},
"nyiragongo":	{"NN"},
"nylghai":	{"NN"},
"nylghau":	{"NN","NNS"},
"nylghaus":	{"NNS"},
"nylon":	{"NN"},
"nylons":	{"NNS"},
"nymph":	{"NN"},
"nymphaea":	{"NN"},
"nymphaeaceae":	{"NN"},
"nymphalid":	{"NN"},
"nymphalidae":	{"NN"},
"nymphalis":	{"NN"},
"nymphet":	{"NN"},
"nymphets":	{"NNS"},
"nymphicus":	{"NN"},
"nympho":	{"NN"},
"nympholepsy":	{"NN"},
"nympholept":	{"NN"},
"nymphomania":	{"NN"},
"nymphomaniac":	{"NN","JJ"},
"nymphomaniacal":	{"JJ"},
"nymphomaniacs":	{"NNS"},
"nymphos":	{"NNS"},
"nymphs":	{"NNS"},
"nynorsk":	{"NN"},
"nypa":	{"NN"},
"nyssa":	{"NN"},
"nyssaceae":	{"NN"},
"nystagmus":	{"NN"},
"nystan":	{"NN"},
"nystatin":	{"NN"},
"nyx":	{"NN"},
"o":	{"NN","SYM","LS"},
"o'casey":	{"NN"},
"o'clock":	{"RB"},
"o'er":	{"RB","IN"},
"o'flaherty":	{"NN"},
"o'toole":	{"NN"},
"o.d.":	{"NN"},
"o.e.d.":	{"NN"},
"o.k.":	{"JJ","NN","RB","VB"},
"oaf":	{"NN"},
"oafish":	{"JJ"},
"oafs":	{"NNS"},
"oahu":	{"NN"},
"oak":	{"NN"},
"oak-apple":	{"NN"},
"oak-log":	{"NN"},
"oaken":	{"JJ"},
"oaks":	{"NNS"},
"oakum":	{"NN"},
"oar":	{"NN","VB","VBP"},
"oared":	{"VBD","VBN"},
"oarfish":	{"NN"},
"oaring":	{"VBG"},
"oarlock":	{"NN"},
"oarlocks":	{"NNS"},
"oars":	{"NNS","VBZ"},
"oarsman":	{"NN"},
"oarsmanship":	{"NN"},
"oarsmen":	{"NNS"},
"oarswoman":	{"NN"},
"oarswomen":	{"NNS"},
"oases":	{"NNS"},
"oasis":	{"NN"},
"oast":	{"NN"},
"oasthouse":	{"NN"},
"oat":	{"NN","JJ"},
"oat-based":	{"JJ"},
"oat-bran":	{"NN"},
"oatcake":	{"NN"},
"oaten":	{"JJ"},
"oath":	{"NN"},
"oath-taking":	{"NN"},
"oathe":	{"NN"},
"oaths":	{"NNS"},
"oatmeal":	{"NN"},
"oats":	{"NNS"},
"oaxaca":	{"NN"},
"ob":	{"NN"},
"obbligati":	{"NNS"},
"obbligato":	{"NN","JJ"},
"obbligatos":	{"NNS"},
"obduracy":	{"NN"},
"obdurate":	{"JJ"},
"obdurately":	{"RB"},
"obeah":	{"NN"},
"obeche":	{"NN"},
"obechi":	{"NN"},
"obedience":	{"NN"},
"obedience-trained":	{"JJ"},
"obediences":	{"NNS"},
"obedient":	{"JJ"},
"obediently":	{"RB"},
"obeisance":	{"NN"},
"obeisances":	{"NNS"},
"obeisant":	{"NN"},
"obelion":	{"NN"},
"obelisk":	{"NN"},
"obelisks":	{"NNS"},
"oberson":	{"NN"},
"obese":	{"JJ"},
"obesity":	{"NN"},
"obey":	{"VB","VBP"},
"obeyed":	{"VBD","VBN"},
"obeying":	{"VBG"},
"obeys":	{"VBZ"},
"obfuscate":	{"VB","VBP"},
"obfuscated":	{"VBD","VBN"},
"obfuscates":	{"VBZ"},
"obfuscating":	{"VBG"},
"obfuscation":	{"NN"},
"obfuscations":	{"NNS"},
"obi":	{"NN"},
"obiism":	{"NN"},
"obit":	{"NN"},
"obits":	{"NNS"},
"obituaries":	{"NNS"},
"obituary":	{"NN","JJ"},
"object":	{"NN","VB","VBP"},
"objected":	{"VBD","VBN"},
"objectification":	{"NN"},
"objectified":	{"VBD","VBN"},
"objectifies":	{"VBZ"},
"objectify":	{"VB","VBP"},
"objectifying":	{"VBG"},
"objecting":	{"VBG"},
"objection":	{"NN"},
"objectionable":	{"JJ"},
"objectionableness":	{"NN"},
"objectionably":	{"RB"},
"objections":	{"NNS"},
"objective":	{"NN","JJ"},
"objectively":	{"RB"},
"objectiveness":	{"NN"},
"objectives":	{"NNS"},
"objectivity":	{"NN"},
"objector":	{"NN"},
"objectors":	{"NNS"},
"objects":	{"NNS","VBZ"},
"objet":	{"NN"},
"objets":	{"FW"},
"objurgate":	{"VB","VBP"},
"objurgated":	{"VBD","VBN"},
"objurgates":	{"VBZ"},
"objurgating":	{"VBG"},
"objurgation":	{"NN"},
"objurgations":	{"NNS"},
"oblanceolate":	{"JJ"},
"oblate":	{"JJ","NN"},
"oblateness":	{"NN"},
"oblation":	{"NN"},
"oblations":	{"NNS"},
"obligate":	{"VB","VBP"},
"obligated":	{"VBD","VBN","JJ"},
"obligates":	{"VBZ"},
"obligating":	{"VBG"},
"obligation":	{"NN"},
"obligational":	{"JJ"},
"obligations":	{"NNS"},
"obligato":	{"NN"},
"obligatorily":	{"RB"},
"obligatory":	{"JJ"},
"obligatto":	{"NN"},
"oblige":	{"VB","VBP"},
"obliged":	{"VBD","VBN","JJ"},
"obliger":	{"NN"},
"obligers":	{"NNS"},
"obliges":	{"VBZ"},
"obliging":	{"JJ","VBG"},
"obligingly":	{"RB"},
"obligingness":	{"NN"},
"oblique":	{"JJ","NN"},
"oblique-angled":	{"JJ"},
"obliquely":	{"RB"},
"obliqueness":	{"NN"},
"obliques":	{"NNS"},
"obliquity":	{"NN"},
"obliterable":	{"JJ"},
"obliterans":	{"JJ"},
"obliterate":	{"VB","VBP"},
"obliterated":	{"VBD","VBN"},
"obliterates":	{"VBZ"},
"obliterating":	{"VBG"},
"obliteration":	{"NN"},
"obliterator":	{"NN"},
"oblivion":	{"NN"},
"oblivious":	{"JJ"},
"obliviousness":	{"NN"},
"oblong":	{"JJ","NN"},
"oblongness":	{"NN"},
"oblongs":	{"NNS"},
"obloquy":	{"NN"},
"obnoxious":	{"JJ"},
"obnoxiously":	{"RB"},
"obnoxiousness":	{"NN"},
"obnubilate":	{"VB","VBP"},
"obnubilated":	{"VBD","VBN"},
"obnubilates":	{"VBZ"},
"obnubilating":	{"VBG"},
"oboe":	{"NN"},
"oboes":	{"NNS"},
"oboist":	{"NN"},
"oboists":	{"NNS"},
"obolus":	{"NN"},
"obovate":	{"JJ"},
"obscene":	{"JJ"},
"obscenely":	{"RB"},
"obscenities":	{"NNS"},
"obscenity":	{"NN"},
"obscurantism":	{"NN"},
"obscurantist":	{"JJ","NN"},
"obscurantists":	{"NNS"},
"obscure":	{"JJ","VB","VBP"},
"obscured":	{"VBN","VBD"},
"obscurely":	{"RB"},
"obscureness":	{"NN"},
"obscures":	{"VBZ"},
"obscuring":	{"VBG"},
"obscurities":	{"NNS"},
"obscurity":	{"NN"},
"obsequies":	{"NNS"},
"obsequious":	{"JJ"},
"obsequiously":	{"RB"},
"obsequiousness":	{"NN"},
"observable":	{"JJ","NN"},
"observably":	{"RB"},
"observance":	{"NN"},
"observances":	{"NNS"},
"observant":	{"JJ"},
"observantly":	{"RB"},
"observation":	{"NN"},
"observational":	{"JJ"},
"observations":	{"NNS"},
"observatories":	{"NNS"},
"observatory":	{"NN"},
"observe":	{"VB","VBP"},
"observed":	{"VBD","VBN"},
"observer":	{"NN"},
"observers":	{"NNS"},
"observes":	{"VBZ"},
"observing":	{"JJ","VBG"},
"observingly":	{"RB"},
"obsess":	{"VB","VBP"},
"obsessed":	{"JJ","VBD","VBN"},
"obsesses":	{"VBZ"},
"obsessing":	{"VBG"},
"obsession":	{"NN"},
"obsessional":	{"JJ"},
"obsessionally":	{"RB"},
"obsessions":	{"NNS"},
"obsessive":	{"JJ","NN"},
"obsessive-compulsive":	{"JJ"},
"obsessively":	{"RB"},
"obsessiveness":	{"NN"},
"obsessives":	{"NNS"},
"obsessivity":	{"NN"},
"obsidian":	{"NN"},
"obsolesce":	{"VB","VBP"},
"obsolesced":	{"VBD","VBN"},
"obsolescence":	{"NN"},
"obsolescent":	{"JJ"},
"obsolesces":	{"VBZ"},
"obsolescing":	{"VBG"},
"obsolete":	{"JJ","VB","VBP"},
"obsoleted":	{"VBD","VBN"},
"obsoletely":	{"RB"},
"obsoleteness":	{"NN"},
"obsoletes":	{"VBZ"},
"obsoleting":	{"VBG"},
"obstacle":	{"NN"},
"obstacles":	{"NNS"},
"obstetric":	{"JJ"},
"obstetrical":	{"JJ"},
"obstetrician":	{"NN"},
"obstetricians":	{"NNS"},
"obstetrics":	{"NN"},
"obstinacy":	{"NN"},
"obstinance":	{"NN"},
"obstinate":	{"JJ"},
"obstinately":	{"RB"},
"obstipate":	{"VB","VBP"},
"obstipated":	{"VBD","VBN"},
"obstipates":	{"VBZ"},
"obstipating":	{"VBG"},
"obstipation":	{"NN"},
"obstreperous":	{"JJ"},
"obstreperously":	{"RB"},
"obstreperousness":	{"NN"},
"obstruct":	{"VB","VBP"},
"obstructed":	{"VBD","VBN"},
"obstructer":	{"NN"},
"obstructers":	{"NNS"},
"obstructing":	{"VBG"},
"obstruction":	{"NN"},
"obstructionism":	{"NN"},
"obstructionist":	{"NN"},
"obstructionists":	{"NNS"},
"obstructions":	{"NNS"},
"obstructive":	{"JJ"},
"obstructively":	{"RB"},
"obstructor":	{"NN"},
"obstructors":	{"NNS"},
"obstructs":	{"VBZ"},
"obstruent":	{"NN","JJ"},
"obtain":	{"VB","VBP"},
"obtainable":	{"JJ"},
"obtained":	{"VBN","VBD"},
"obtaining":	{"VBG"},
"obtainment":	{"NN"},
"obtains":	{"VBZ"},
"obtention":	{"NN"},
"obtrude":	{"VB","VBP"},
"obtruded":	{"VBD","VBN"},
"obtrudes":	{"VBZ"},
"obtruding":	{"VBG"},
"obtrusion":	{"NN"},
"obtrusions":	{"NNS"},
"obtrusive":	{"JJ"},
"obtrusively":	{"RB"},
"obtrusiveness":	{"NN"},
"obtund":	{"VB","VBP"},
"obtunded":	{"VBD","VBN"},
"obtunding":	{"VBG"},
"obtunds":	{"VBZ"},
"obturate":	{"VB","VBP"},
"obturated":	{"VBD","VBN"},
"obturates":	{"VBZ"},
"obturating":	{"VBG"},
"obturation":	{"NN"},
"obturator":	{"NN"},
"obturators":	{"NNS"},
"obtuse":	{"JJ"},
"obtusely":	{"RB"},
"obtuseness":	{"NN"},
"obverse":	{"NN"},
"obviate":	{"VB","VBP"},
"obviated":	{"VBD","VBN"},
"obviates":	{"VBZ"},
"obviating":	{"VBG"},
"obviation":	{"NN"},
"obviations":	{"NNS"},
"obvious":	{"JJ"},
"obviously":	{"RB"},
"obviousness":	{"NN"},
"oca":	{"NN"},
"ocarina":	{"NN"},
"ocarinas":	{"NNS"},
"occ-member":	{"JJ"},
"occam":	{"NN"},
"occasion":	{"NN","VB","VBP"},
"occasional":	{"JJ"},
"occasionally":	{"RB"},
"occasioned":	{"VBD","VBN"},
"occasioning":	{"VBG"},
"occasions":	{"NNS","VBZ"},
"occidental":	{"JJ","NN"},
"occidentalism":	{"NN"},
"occidentals":	{"NNS"},
"occipita":	{"NNS"},
"occipital":	{"JJ","NN"},
"occiput":	{"NN"},
"occiputs":	{"NNS"},
"occitan":	{"NN"},
"occlude":	{"VB","VBP"},
"occluded":	{"VBD","VBN"},
"occludes":	{"VBZ"},
"occluding":	{"VBG"},
"occlusion":	{"NN"},
"occlusions":	{"NNS"},
"occlusive":	{"JJ"},
"occult":	{"NN","JJ","VB","VBP"},
"occultation":	{"NN"},
"occulted":	{"VBD","VBN"},
"occulting":	{"VBG"},
"occultism":	{"NN"},
"occultist":	{"NN"},
"occultists":	{"NNS"},
"occultly":	{"RB"},
"occultness":	{"NN"},
"occults":	{"VBZ"},
"occupancies":	{"NNS"},
"occupancy":	{"NN"},
"occupant":	{"NN"},
"occupants":	{"NNS"},
"occupation":	{"NN"},
"occupational":	{"JJ"},
"occupationally":	{"RB"},
"occupations":	{"NNS"},
"occupied":	{"VBN","VBD","JJ"},
"occupier":	{"NN"},
"occupiers":	{"NNS"},
"occupies":	{"VBZ"},
"occupy":	{"VB","VBP"},
"occupying":	{"VBG"},
"occur":	{"VB","VBP"},
"occurred":	{"VBD","VBN"},
"occurrence":	{"NN"},
"occurrences":	{"NNS"},
"occurrent":	{"JJ"},
"occurring":	{"VBG"},
"occurs":	{"VBZ"},
"ocean":	{"NN"},
"ocean-going":	{"JJ"},
"ocean-pollution":	{"NN"},
"ocean-shipping":	{"NN"},
"ocean-thermal":	{"JJ"},
"oceanaut":	{"NN"},
"oceanfront":	{"JJ"},
"oceangoing":	{"JJ"},
"oceanic":	{"JJ"},
"oceanica":	{"NN"},
"oceanid":	{"NN"},
"oceanites":	{"NNS"},
"oceanographer":	{"NN"},
"oceanographers":	{"NNS"},
"oceanographic":	{"JJ"},
"oceanography":	{"NN"},
"oceanology":	{"NN"},
"oceans":	{"NNS"},
"oceanthermal":	{"JJ"},
"oceanus":	{"NN"},
"ocellar":	{"JJ"},
"ocellate":	{"JJ"},
"ocellated":	{"JJ"},
"ocellation":	{"NN"},
"ocelli":	{"NNS"},
"ocellus":	{"NN"},
"ocelot":	{"NN"},
"ocelots":	{"NNS"},
"och":	{"UH"},
"ocher":	{"NN","JJ"},
"ochlocracy":	{"NN"},
"ochna":	{"NN"},
"ochnaceae":	{"NN"},
"ochoa":	{"NN"},
"ochotona":	{"NN"},
"ochotonidae":	{"NN"},
"ochre":	{"NN","JJ"},
"ochroma":	{"NN"},
"ochronosis":	{"NN"},
"ocimum":	{"NN"},
"ockham":	{"NN"},
"ocotillo":	{"NN"},
"oct":	{"NN"},
"octad":	{"NN"},
"octagon":	{"NN"},
"octagonal":	{"JJ"},
"octagons":	{"NNS"},
"octahedron":	{"NN"},
"octal":	{"JJ"},
"octameter":	{"NN"},
"octane":	{"NN"},
"octangular":	{"JJ"},
"octant":	{"NN"},
"octave":	{"NN"},
"octaves":	{"NNS"},
"octavian":	{"NN"},
"octavo":	{"NN"},
"octavos":	{"NNS"},
"octet":	{"NN"},
"octets":	{"NNS"},
"octette":	{"NN"},
"octillion":	{"NN"},
"octoberfest":	{"NN"},
"octogenaraians":	{"NNS"},
"octogenarian":	{"NN"},
"octogenarians":	{"NNS"},
"octonary":	{"NN"},
"octopi":	{"NNS"},
"octopod":	{"NN"},
"octopoda":	{"NN"},
"octopodidae":	{"NN"},
"octopus":	{"NN"},
"octopuses":	{"NNS"},
"octoroon":	{"NN"},
"octosyllabic":	{"JJ","NN"},
"octosyllable":	{"NN"},
"octroi":	{"NN"},
"octuple":	{"JJ"},
"ocular":	{"JJ","NN"},
"oculi":	{"NNS"},
"oculism":	{"NN"},
"oculist":	{"NN"},
"oculists":	{"NNS"},
"oculomotor":	{"NN","JJ"},
"oculus":	{"NN"},
"ocyurus":	{"NN"},
"odalisque":	{"NN"},
"odalisques":	{"NNS"},
"odd":	{"JJ"},
"odd-job":	{"JJ"},
"odd-looking":	{"JJ"},
"odd-lot":	{"JJ"},
"odd-pinnate":	{"JJ"},
"odd-sounding":	{"JJ"},
"odd-year":	{"JJ"},
"oddball":	{"NN","JJ"},
"oddballs":	{"NNS"},
"odder":	{"JJR"},
"oddest":	{"JJS"},
"oddish":	{"JJ"},
"oddities":	{"NNS"},
"oddity":	{"NN"},
"oddly":	{"RB"},
"oddment":	{"NN"},
"oddments":	{"NNS"},
"oddness":	{"NN"},
"odds":	{"NNS"},
"odds-maker":	{"NN"},
"odds-on":	{"JJ"},
"ode":	{"NN"},
"odes":	{"NNS"},
"odesa":	{"NN"},
"odious":	{"JJ"},
"odiously":	{"RB"},
"odiousness":	{"NN"},
"odist":	{"NN"},
"odium":	{"NN"},
"odo":	{"NN"},
"odoacer":	{"NN"},
"odobenidae":	{"NN"},
"odobenus":	{"NN"},
"odocoileus":	{"NN"},
"odometer":	{"NN"},
"odometers":	{"NNS"},
"odonata":	{"NN"},
"odonate":	{"NN"},
"odontalgia":	{"NN"},
"odontaspididae":	{"NN"},
"odontaspis":	{"NN"},
"odontiasis":	{"NN"},
"odontoceti":	{"NN"},
"odontoglossum":	{"NN"},
"odontology":	{"NN"},
"odontophorus":	{"NN"},
"odor":	{"NN"},
"odoriferous":	{"JJ"},
"odorise":	{"VB","VBP"},
"odorised":	{"VBD","VBN"},
"odorises":	{"VBZ"},
"odorising":	{"VBG"},
"odorize":	{"VB","VBP"},
"odorized":	{"VBD","VBN"},
"odorizes":	{"VBZ"},
"odorizing":	{"VBG"},
"odorless":	{"JJ"},
"odorous":	{"JJ"},
"odors":	{"NNS"},
"odour":	{"NN"},
"odourise":	{"VB","VBP"},
"odourised":	{"VBD","VBN"},
"odourises":	{"VBZ"},
"odourising":	{"VBG"},
"odourless":	{"JJ"},
"odours":	{"NNS"},
"odovacar":	{"NN"},
"odovakar":	{"NN"},
"odynophagia":	{"NN"},
"odyssey":	{"NN"},
"odysseys":	{"NNS"},
"oecanthus":	{"NN"},
"oecumenic":	{"JJ"},
"oecumenical":	{"JJ"},
"oecumenism":	{"NN"},
"oedema":	{"NN"},
"oedipal":	{"JJ"},
"oedogoniaceae":	{"NN"},
"oedogonium":	{"NN"},
"oenanthe":	{"NN"},
"oengus":	{"NN"},
"oenologist":	{"NN"},
"oenology":	{"NN"},
"oenomel":	{"NN"},
"oenophile":	{"NN"},
"oenothera":	{"NN"},
"oerations":	{"NNS"},
"oersted":	{"NN"},
"oesophagitis":	{"NN"},
"oesophagoscope":	{"NN"},
"oesophagus":	{"NN"},
"oesophaguses":	{"NNS"},
"oesterreich":	{"NN"},
"oestradiol":	{"NN"},
"oestridae":	{"NN"},
"oestriol":	{"NN"},
"oestrogen":	{"NN"},
"oestrone":	{"NN"},
"oestrus":	{"NN"},
"oeufs":	{"FW"},
"oeuvre":	{"NN"},
"oeuvres":	{"NNS"},
"of":	{"IN"},
"off":	{"RP","IN","RB","JJ","NN","VB","VBP"},
"off-Broadway":	{"JJ","RB"},
"off-again":	{"JJ"},
"off-and-on":	{"JJ"},
"off-balance":	{"JJ"},
"off-base":	{"JJ"},
"off-beat":	{"JJ"},
"off-brand":	{"JJ","NN"},
"off-brands":	{"NNS"},
"off-budget":	{"JJ","NN"},
"off-center":	{"JJ"},
"off-centered":	{"JJ"},
"off-centre":	{"JJ"},
"off-color":	{"JJ"},
"off-colour":	{"JJ"},
"off-day":	{"NN"},
"off-days":	{"NNS"},
"off-duty":	{"JJ"},
"off-exchange":	{"JJ","NN"},
"off-farm":	{"JJ"},
"off-field":	{"JJ"},
"off-flavor":	{"NN"},
"off-flavors":	{"NNS"},
"off-guard":	{"JJ"},
"off-hand":	{"JJ","RB"},
"off-hours":	{"JJ","NNS"},
"off-key":	{"JJ","RB"},
"off-level":	{"JJ"},
"off-licence":	{"NN"},
"off-licences":	{"NNS"},
"off-limits":	{"JJ"},
"off-line":	{"JJ","RB"},
"off-network":	{"JJ"},
"off-off":	{"JJ"},
"off-price":	{"JJ"},
"off-putting":	{"JJ"},
"off-puttingly":	{"RB"},
"off-road":	{"JJ","RB"},
"off-roader":	{"NN"},
"off-roaders":	{"NNS"},
"off-screen":	{"RB","JJ"},
"off-season":	{"NN","JJ","RB"},
"off-shore":	{"JJ"},
"off-side":	{"JJ","RB","NN"},
"off-site":	{"JJ","RB"},
"off-speed":	{"JJ"},
"off-stage":	{"RB","JJ"},
"off-street":	{"JJ"},
"off-the-books":	{"JJ"},
"off-the-clock":	{"RB"},
"off-the-cuff":	{"JJ","RB"},
"off-the-peg":	{"JJ","RB"},
"off-the-rack":	{"JJ","RB"},
"off-the-record":	{"JJ","RB"},
"off-the-shelf":	{"JJ","RB"},
"off-the-shoulder":	{"JJ"},
"off-the-wall":	{"JJ"},
"off-white":	{"JJ","NN"},
"off-year":	{"JJ","NN"},
"offal":	{"NN"},
"offbeat":	{"JJ"},
"offcourse":	{"JJ"},
"offed":	{"VBD","VBN"},
"offenbach":	{"NN"},
"offence":	{"NN"},
"offenceless":	{"JJ"},
"offences":	{"NNS"},
"offend":	{"VB","VBP"},
"offended":	{"JJ","VBD","VBN"},
"offender":	{"NN"},
"offenders":	{"NNS"},
"offending":	{"NN","JJ","VBG"},
"offends":	{"VBZ"},
"offense":	{"NN"},
"offenseless":	{"JJ"},
"offenses":	{"NNS"},
"offensive":	{"JJ","NN"},
"offensively":	{"RB"},
"offensiveness":	{"NN"},
"offensives":	{"NNS"},
"offer":	{"VB","NN","VBP"},
"offered":	{"VBD","VBN"},
"offerer":	{"NN"},
"offering":	{"NN","VBG"},
"offering-price":	{"JJ"},
"offerings":	{"NNS"},
"offeror":	{"NN"},
"offers":	{"VBZ","NNS"},
"offertories":	{"NNS"},
"offertory":	{"NN"},
"offhand":	{"JJ","RB"},
"offhanded":	{"JJ"},
"offhandedly":	{"RB"},
"offhandedness":	{"NN"},
"office":	{"NN"},
"office-bearer":	{"NN"},
"office-block":	{"NN"},
"office-blocks":	{"NNS"},
"office-equipment":	{"NN"},
"office-furniture":	{"JJ"},
"office-product":	{"NN"},
"office-products":	{"NNS"},
"office-supplies":	{"NNS"},
"office-supply":	{"JJ"},
"office-systems":	{"NNS"},
"officeholder":	{"NN"},
"officeholders":	{"NNS"},
"officer":	{"NN","VB","VBP"},
"officered":	{"VBN","VBD"},
"officering":	{"VBG"},
"officers":	{"NNS","VBZ"},
"offices":	{"NNS"},
"official":	{"NN","JJ"},
"officialdom":	{"NN"},
"officialese":	{"NN"},
"officialise":	{"VB","VBP"},
"officialised":	{"VBD","VBN"},
"officialises":	{"VBZ"},
"officialising":	{"VBG"},
"officialism":	{"NN"},
"officialist":	{"NN","JJ"},
"officialize":	{"VB","VBP"},
"officialized":	{"VBD","VBN"},
"officializes":	{"VBZ"},
"officializing":	{"VBG"},
"officially":	{"RB"},
"officials":	{"NNS"},
"officials-cum-drug-traffickers":	{"NNS"},
"officiant":	{"NN"},
"officiate":	{"VB","VBP"},
"officiated":	{"VBD","VBN"},
"officiates":	{"VBZ"},
"officiating":	{"VBG"},
"officiation":	{"NN"},
"officio":	{"FW"},
"officious":	{"JJ"},
"officiously":	{"RB"},
"officiousness":	{"NN"},
"offing":	{"NN","VBG"},
"offish":	{"JJ"},
"offline":	{"JJ","RB"},
"offload":	{"VB","VBP"},
"offloaded":	{"VBD","VBN"},
"offloading":	{"VBG"},
"offloads":	{"VBZ"},
"offocus":	{"NN"},
"offprint":	{"NN"},
"offprints":	{"NNS"},
"offputting":	{"JJ"},
"offs":	{"VBZ"},
"offsaddle":	{"VB","VBP"},
"offsaddled":	{"VBD","VBN"},
"offsaddles":	{"VBZ"},
"offsaddling":	{"VBG"},
"offscreen":	{"RB","JJ"},
"offset":	{"VB","VBN","VBP","VBD","JJ","NN"},
"offsets":	{"VBZ"},
"offsetting":	{"VBG"},
"offshoot":	{"NN"},
"offshoots":	{"NNS"},
"offshore":	{"JJ","RB","VB","VBP"},
"offshore-rig":	{"NN"},
"offshored":	{"VBD","VBN"},
"offshores":	{"VBZ"},
"offshoring":	{"VBG"},
"offside":	{"JJ","RB","NN"},
"offspring":	{"NN","NNS"},
"offstage":	{"RB","JJ"},
"ofo":	{"NN"},
"oft":	{"RB"},
"oft-quoted":	{"JJ"},
"oft-repeated":	{"JJ"},
"oft-times":	{"RB"},
"often":	{"RB"},
"often-criticized":	{"JJ"},
"often-disparaged":	{"JJ"},
"often-fatal":	{"JJ"},
"often-heard":	{"JJ"},
"often-ignored":	{"JJ"},
"often-repeated":	{"JJ"},
"oftener":	{"RB"},
"oftenness":	{"NN"},
"oftentimes":	{"RB"},
"ogalala":	{"NN"},
"ogcocephalidae":	{"NN"},
"ogden":	{"NN"},
"ogdoad":	{"NN"},
"ogee":	{"NN"},
"ogive":	{"NN"},
"oglala":	{"NN"},
"ogle":	{"VB","VBP","NN"},
"ogled":	{"VBD","VBN"},
"ogler":	{"NN"},
"oglers":	{"NNS"},
"ogles":	{"VBZ","NNS"},
"ogling":	{"VBG"},
"ogre":	{"NN"},
"ogres":	{"NNS"},
"ogress":	{"NN"},
"ogresses":	{"NNS"},
"ogrish":	{"JJ"},
"oh":	{"UH"},
"ohio-based":	{"JJ"},
"ohio-chartered":	{"JJ"},
"ohioan":	{"NN"},
"ohm":	{"NN"},
"ohmage":	{"NN"},
"ohmic":	{"JJ"},
"ohmmeter":	{"NN"},
"ohmmeters":	{"NNS"},
"ohms":	{"NNS"},
"oig":	{"NN"},
"oil":	{"NN","VBP","VB"},
"oil-and-gas":	{"JJ"},
"oil-based":	{"JJ"},
"oil-bath":	{"NN"},
"oil-bearing":	{"JJ"},
"oil-colour":	{"NN"},
"oil-colours":	{"NNS"},
"oil-consuming":	{"JJ"},
"oil-covered":	{"JJ"},
"oil-depletion":	{"JJ"},
"oil-driller":	{"NN"},
"oil-drilling":	{"NN"},
"oil-exporting":	{"NN"},
"oil-field":	{"NN","JJ"},
"oil-finding":	{"JJ"},
"oil-fired":	{"JJ"},
"oil-futures":	{"NNS"},
"oil-industry":	{"NN"},
"oil-lease":	{"JJ"},
"oil-leasing":	{"NN"},
"oil-paint":	{"NN"},
"oil-painting":	{"NN"},
"oil-paintings":	{"NNS"},
"oil-paints":	{"NNS"},
"oil-palm":	{"NN"},
"oil-palms":	{"NNS"},
"oil-patch":	{"JJ","NN"},
"oil-poor":	{"JJ"},
"oil-price":	{"NN","JJ"},
"oil-producing":	{"JJ","NN"},
"oil-production":	{"NN"},
"oil-recycling":	{"NN"},
"oil-related":	{"JJ"},
"oil-rich":	{"JJ"},
"oil-service":	{"NN"},
"oil-services":	{"JJ"},
"oil-slicked":	{"JJ"},
"oil-soluble":	{"JJ"},
"oil-spill":	{"NN","JJ"},
"oil-tanker":	{"NN"},
"oil-tankers":	{"NNS"},
"oil-tool":	{"NN"},
"oil-trading":	{"NN"},
"oil-transport":	{"JJ"},
"oilbird":	{"NN"},
"oilcake":	{"NN"},
"oilcan":	{"NN"},
"oilcloth":	{"NN"},
"oilcloths":	{"NNS"},
"oiled":	{"JJ","VBD","VBN"},
"oiler":	{"NN"},
"oilers":	{"NNS"},
"oilfield":	{"NN"},
"oilfields":	{"NNS"},
"oilfish":	{"NN"},
"oilheating":	{"NN"},
"oilier":	{"JJR"},
"oiliest":	{"JJS"},
"oiliness":	{"NN"},
"oiling":	{"VBG"},
"oilman":	{"NN"},
"oilman-rancher":	{"NN"},
"oilmen":	{"NNS"},
"oilpaper":	{"NN"},
"oils":	{"NNS","VBZ"},
"oilseed":	{"NN"},
"oilseeds":	{"NNS"},
"oilskin":	{"NN"},
"oilskins":	{"NNS"},
"oilstone":	{"NN"},
"oilstove":	{"NN"},
"oilworkers":	{"NNS"},
"oily":	{"JJ"},
"oink":	{"VB","VBP","NN","UH"},
"oinked":	{"VBD","VBN"},
"oinking":	{"VBG"},
"oinks":	{"VBZ","NNS"},
"ointment":	{"NN"},
"ointments":	{"NNS"},
"oireachtas":	{"NNS"},
"ois":	{"NN"},
"oiticica":	{"NN"},
"ojibway":	{"NN"},
"oka":	{"NN"},
"okapi":	{"NN","NNS"},
"okapia":	{"NN"},
"okapis":	{"NNS"},
"okay":	{"JJ","RB","UH","VB","VBP","NN"},
"okayed":	{"VBD","VBN"},
"okaying":	{"VBG"},
"okays":	{"VBZ"},
"okeh":	{"NN"},
"oken":	{"NN"},
"okenfuss":	{"NN"},
"okey":	{"NN"},
"okey-doke":	{"JJ","RB","UH"},
"okey-dokey":	{"JJ","RB","UH"},
"okra":	{"NN"},
"oktoberfest":	{"NN"},
"ola":	{"NN"},
"old":	{"JJ","NN"},
"old-age":	{"JJ"},
"old-boy":	{"NN"},
"old-boys":	{"NNS"},
"old-fashioned":	{"JJ"},
"old-fashionedness":	{"NN"},
"old-grad-type":	{"NN"},
"old-growth":	{"JJ"},
"old-guard":	{"JJ"},
"old-hat":	{"JJ"},
"old-line":	{"JJ"},
"old-liner":	{"NN"},
"old-maid":	{"NN"},
"old-maidish":	{"JJ"},
"old-man-of-the-woods":	{"NNS"},
"old-model":	{"JJ"},
"old-name":	{"JJ"},
"old-school":	{"JJ"},
"old-style":	{"JJ"},
"old-time":	{"JJ"},
"old-timer":	{"NN"},
"old-timers":	{"NNS"},
"old-woman":	{"NN"},
"old-womanish":	{"JJ"},
"old-women":	{"NNS"},
"old-world":	{"JJ"},
"olden":	{"JJ"},
"older":	{"JJR"},
"oldest":	{"JJS"},
"oldfield":	{"NN"},
"oldie":	{"NN","JJ"},
"oldies":	{"NNS"},
"oldish":	{"JJ"},
"oldness":	{"NN"},
"oldster":	{"NN"},
"oldsters":	{"NNS"},
"oldtimer":	{"NN"},
"oldwench":	{"NN"},
"oldwife":	{"NN"},
"ole":	{"JJ"},
"olea":	{"NN"},
"oleaceae":	{"NN"},
"oleaceous":	{"JJ"},
"oleaginous":	{"JJ"},
"oleaginousness":	{"NN"},
"oleales":	{"NNS"},
"oleander":	{"NN"},
"oleanders":	{"NNS"},
"oleandra":	{"NN"},
"oleandraceae":	{"NN"},
"olearia":	{"NN"},
"oleaster":	{"NN"},
"olecranon":	{"NN"},
"oled":	{"NN"},
"olefin":	{"NN"},
"olefine":	{"NN"},
"olefins":	{"NNS"},
"olein":	{"NN"},
"oleo":	{"NN"},
"oleomargarine":	{"NN"},
"oleophilic":	{"JJ"},
"oleophobic":	{"JJ"},
"oleoresin":	{"NN"},
"olestra":	{"NN"},
"olfaction":	{"NN"},
"olfactive":	{"JJ"},
"olfactory":	{"JJ"},
"olfersia":	{"NN"},
"olibanum":	{"NN"},
"oligarch":	{"NN"},
"oligarchic":	{"JJ"},
"oligarchical":	{"JJ"},
"oligarchies":	{"NNS"},
"oligarchs":	{"NNS"},
"oligarchy":	{"NN"},
"oligocene":	{"NN"},
"oligochaeta":	{"NN"},
"oligochaete":	{"NN","JJ"},
"oligoclase":	{"NN"},
"oligodactyly":	{"NN"},
"oligodendria":	{"NN"},
"oligodendrocyte":	{"NN"},
"oligodendroglia":	{"NN"},
"oligodontia":	{"NN"},
"oligomenorrhea":	{"NN"},
"oligoplites":	{"NNS"},
"oligopolies":	{"NNS"},
"oligopoly":	{"NN"},
"oligoporus":	{"NN"},
"oligosaccharide":	{"NN"},
"oligosaccharides":	{"NNS"},
"oligospermia":	{"NN"},
"oliguria":	{"NN"},
"olim":	{"NN"},
"olimbos":	{"NNS"},
"olinguito":	{"NN"},
"olinguitos":	{"NNS"},
"olive":	{"NN","JJ"},
"olive-brown":	{"JJ"},
"olive-colored":	{"JJ"},
"olive-coloured":	{"JJ"},
"olive-drab":	{"JJ"},
"olive-flushed":	{"JJ"},
"olive-gray":	{"JJ"},
"olive-green":	{"NN"},
"olive-grey":	{"JJ"},
"olive-like":	{"JJ"},
"olive-sized":	{"JJ"},
"olivefaced":	{"JJ"},
"olivelike":	{"JJ"},
"olivenite":	{"NN"},
"oliver":	{"NN"},
"olives":	{"NNS"},
"olivine":	{"NN"},
"olla":	{"NN"},
"ollari":	{"NN"},
"olm":	{"NN"},
"olmec":	{"NN"},
"olmsted":	{"NN"},
"olsen":	{"NN"},
"omasum":	{"NN"},
"omayyad":	{"NN"},
"ombu":	{"NN"},
"ombudsman":	{"NN"},
"ombudsmen":	{"NNS"},
"omega":	{"NN"},
"omega-3":	{"NN"},
"omega-6":	{"NN"},
"omelet":	{"NN"},
"omelets":	{"NNS"},
"omelette":	{"NN"},
"omelettes":	{"NNS"},
"omen":	{"NN","VB","VBP"},
"omened":	{"VBD","VBN"},
"omening":	{"VBG"},
"omens":	{"VBZ","NNS"},
"omentum":	{"NN"},
"omeprazole":	{"NN"},
"omerta":	{"NN"},
"omicron":	{"NN"},
"ominous":	{"JJ"},
"ominously":	{"RB"},
"omissible":	{"JJ"},
"omission":	{"NN"},
"omissions":	{"NNS"},
"omissive":	{"JJ"},
"omit":	{"VB","VBP"},
"omits":	{"VBZ"},
"omitted":	{"VBN","VBD"},
"omitting":	{"VBG"},
"omiya":	{"NN"},
"ommastrephes":	{"NNS"},
"ommatidium":	{"NN"},
"ommiad":	{"NN"},
"ommission":	{"NN"},
"omnia":	{"FW"},
"omnibus":	{"JJ","NN"},
"omnibuses":	{"NNS"},
"omnidirectional":	{"JJ"},
"omnifarious":	{"JJ"},
"omnipotence":	{"NN"},
"omnipotent":	{"JJ"},
"omnipresence":	{"NN"},
"omnipresent":	{"JJ"},
"omnirange":	{"NN"},
"omniscience":	{"NN"},
"omniscient":	{"JJ"},
"omnium-gatherum":	{"NN"},
"omnivore":	{"NN"},
"omnivores":	{"NNS"},
"omnivorous":	{"JJ"},
"omomyid":	{"NN"},
"omophagia":	{"NN"},
"omotic":	{"NN"},
"omphalocele":	{"NN"},
"omphalos":	{"NN"},
"omphaloskepsis":	{"NN"},
"omphalotus":	{"NN"},
"omphalus":	{"NNS"},
"omsk":	{"NN"},
"on":	{"IN","RB","JJ","RP"},
"on-again":	{"JJ"},
"on-again-off-again":	{"JJ"},
"on-air":	{"JJ"},
"on-and-off":	{"JJ"},
"on-base":	{"JJ"},
"on-board":	{"JJ"},
"on-budget":	{"JJ"},
"on-campus":	{"JJ"},
"on-field":	{"JJ","NN"},
"on-going":	{"JJ"},
"on-key":	{"JJ"},
"on-level":	{"NN"},
"on-license":	{"NN"},
"on-line":	{"JJ"},
"on-ramp":	{"NN"},
"on-ramps":	{"NNS"},
"on-screen":	{"JJ","RB"},
"on-set":	{"JJ"},
"on-site":	{"JJ"},
"on-stage":	{"JJ"},
"on-street":	{"JJ"},
"on-sure":	{"JJ"},
"on-the-go":	{"JJ"},
"on-the-job":	{"JJ"},
"on-the-scene":	{"JJ"},
"on-the-spot":	{"JJ"},
"on-time":	{"JJ"},
"onager":	{"NN"},
"onagraceae":	{"NN"},
"onanism":	{"NN"},
"onanist":	{"NN"},
"onboard":	{"JJ","RB"},
"once":	{"RB","IN","CC"},
"once-a-day":	{"JJ"},
"once-a-month":	{"JJ"},
"once-absolute":	{"JJ"},
"once-balkanized":	{"JJ"},
"once-bloated":	{"JJ"},
"once-bustling":	{"JJ"},
"once-closed":	{"JJ"},
"once-cozy":	{"JJ"},
"once-desirable":	{"JJ"},
"once-devoted":	{"JJ"},
"once-distinct":	{"JJ"},
"once-downtrodden":	{"JJ"},
"once-dry":	{"JJ"},
"once-dull":	{"JJ"},
"once-exploding":	{"JJ"},
"once-faltering":	{"JJ"},
"once-fashionable":	{"JJ"},
"once-grumpy":	{"JJ"},
"once-high-flying":	{"JJ"},
"once-in-a-lifetime":	{"JJ"},
"once-indomitable":	{"JJ"},
"once-loyal":	{"JJ"},
"once-lucrative":	{"JJ"},
"once-mighty":	{"JJ"},
"once-moribund":	{"JJ"},
"once-only":	{"JJ"},
"once-over":	{"NN"},
"once-over-lightly":	{"NN"},
"once-popular":	{"JJ"},
"once-powerful":	{"JJ"},
"once-prestigious":	{"JJ"},
"once-prevailing":	{"JJ"},
"once-private":	{"JJ"},
"once-profitable":	{"JJ"},
"once-promising":	{"JJ"},
"once-proud":	{"JJ"},
"once-rich":	{"JJ"},
"once-sacred":	{"JJ"},
"once-scandalous":	{"JJ"},
"once-sleepy":	{"JJ"},
"once-spare":	{"JJ"},
"once-sporadic":	{"JJ"},
"once-staid":	{"JJ"},
"once-stately":	{"JJ"},
"once-stodgy":	{"JJ"},
"once-strong":	{"JJ"},
"once-troubled":	{"JJ"},
"once-unprofitable":	{"JJ"},
"once-unthinkable":	{"JJ"},
"once-vast":	{"JJ"},
"onchocerciasis":	{"NN"},
"oncidium":	{"NN"},
"oncogene":	{"NN"},
"oncogenes":	{"NNS"},
"oncologic":	{"NN"},
"oncological":	{"JJ"},
"oncologist":	{"NN"},
"oncologists":	{"NNS"},
"oncology":	{"NN"},
"oncoming":	{"JJ","NN"},
"oncorhynchus":	{"NNS"},
"oncovin":	{"NN"},
"onct":	{"IN","JJ"},
"ondaatje":	{"NN"},
"ondatra":	{"NN"},
"one":	{"CD","NN","PRP","JJ","DT"},
"one-act":	{"JJ"},
"one-act-play":	{"JJ"},
"one-acter":	{"NN"},
"one-acters":	{"NNS"},
"one-and-one":	{"NN"},
"one-arm":	{"JJ"},
"one-armed":	{"JJ"},
"one-billionth":	{"JJ","NN"},
"one-by-one":	{"JJ"},
"one-day":	{"JJ"},
"one-dimensional":	{"JJ"},
"one-eighth":	{"JJ","NN"},
"one-eyed":	{"JJ"},
"one-fifth":	{"JJ","NN"},
"one-fourth":	{"CD","NN"},
"one-handed":	{"JJ","RB"},
"one-hit":	{"NN"},
"one-horse":	{"JJ"},
"one-hundred-millionth":	{"JJ","NN"},
"one-hundred-thousandth":	{"JJ","NN"},
"one-hundredth":	{"CD","NN"},
"one-in-a-million":	{"JJ"},
"one-legged":	{"JJ"},
"one-line":	{"JJ"},
"one-liner":	{"NN"},
"one-liners":	{"NNS"},
"one-man":	{"JJ"},
"one-millionth":	{"JJ","NN"},
"one-night":	{"JJ","NN"},
"one-ninth":	{"JJ","NN"},
"one-note":	{"JJ"},
"one-of-a-kind":	{"JJ"},
"one-off":	{"NN","JJ"},
"one-offs":	{"NNS"},
"one-on-one":	{"JJ","RB","NN"},
"one-on-ones":	{"NNS"},
"one-owner":	{"JJ"},
"one-parent":	{"JJ"},
"one-party":	{"JJ"},
"one-piece":	{"JJ","NN"},
"one-pieces":	{"NNS"},
"one-reel":	{"JJ"},
"one-reeler":	{"NN"},
"one-room":	{"JJ"},
"one-roomed":	{"JJ"},
"one-shot":	{"JJ"},
"one-shots":	{"NNS"},
"one-sided":	{"JJ"},
"one-sidedly":	{"RB"},
"one-sidedness":	{"NN"},
"one-sixteenth":	{"JJ","NN"},
"one-sixth":	{"JJ","NN"},
"one-sixtieth":	{"JJ","NN"},
"one-sixty-fourth":	{"JJ","NN"},
"one-size":	{"JJ"},
"one-size-fits-all":	{"JJ"},
"one-step":	{"NN","VB","VBP"},
"one-stepped":	{"VBD","VBN"},
"one-stepping":	{"VBG"},
"one-steps":	{"NNS","VBZ"},
"one-stop":	{"JJ"},
"one-tenth":	{"JJ","NN"},
"one-third":	{"JJ","NN"},
"one-thirty":	{"RB"},
"one-thousandth":	{"JJ","NN"},
"one-time":	{"JJ"},
"one-to-one":	{"JJ","RB"},
"one-track":	{"JJ"},
"one-trillionth":	{"JJ","NN"},
"one-twelfth":	{"JJ","NN"},
"one-twentieth":	{"JJ","NN"},
"one-two":	{"NN"},
"one-two-three":	{"NN"},
"one-twos":	{"NNS"},
"one-up":	{"JJ","VB","VBP","NN"},
"one-upmanship":	{"NN"},
"one-upped":	{"VBD","VBN"},
"one-upping":	{"VBG"},
"one-ups":	{"VBZ","NNS"},
"one-upsmanship":	{"NN"},
"one-way":	{"JJ","RB"},
"one-woman":	{"JJ"},
"oneasy":	{"NN"},
"oneday":	{"RB"},
"onega":	{"NN"},
"oneiric":	{"JJ"},
"oneirism":	{"NN"},
"oneiromancer":	{"NN"},
"oneiromancy":	{"NN"},
"oneness":	{"NN"},
"onepage":	{"JJ"},
"onerous":	{"JJ"},
"onerously":	{"RB"},
"onerousness":	{"NN"},
"ones":	{"NNS"},
"oneself":	{"PRP"},
"onesie":	{"NN"},
"onesies":	{"NNS"},
"onetime":	{"JJ"},
"oneupmanship":	{"NN"},
"ongoing":	{"JJ"},
"oni":	{"NN"},
"onion":	{"NN"},
"onions":	{"NNS"},
"onionskin":	{"NN"},
"oniscidae":	{"NN"},
"oniscus":	{"NNS"},
"onleh":	{"RB"},
"online":	{"JJ","RB"},
"onlooker":	{"NN"},
"onlookers":	{"NNS"},
"only":	{"RB","JJ","IN","CC"},
"ono":	{"NN"},
"onobrychis":	{"NN"},
"onoclea":	{"NN"},
"onomancer":	{"NN"},
"onomancy":	{"NN"},
"onomastic":	{"JJ"},
"onomasticon":	{"NN"},
"onomastics":	{"NN"},
"onomatomania":	{"NN"},
"onomatopoeia":	{"NN"},
"onomatopoeic":	{"JJ"},
"onomatopoeical":	{"JJ"},
"onomatopoetic":	{"JJ"},
"ononis":	{"NN"},
"onopordon":	{"NN"},
"onopordum":	{"NN"},
"onosmodium":	{"NN"},
"onrush":	{"NN"},
"onrushing":	{"JJ"},
"onsager":	{"NN"},
"onscreen":	{"NN"},
"onset":	{"NN"},
"onsets":	{"NNS"},
"onshore":	{"JJ","RB"},
"onside":	{"JJ","RB"},
"onslaught":	{"NN"},
"onslaughts":	{"NNS"},
"onstage":	{"RB","JJ"},
"onto":	{"IN"},
"ontogenesis":	{"NN"},
"ontogenetic":	{"JJ"},
"ontogeny":	{"NN"},
"ontological":	{"JJ"},
"ontologically":	{"RB"},
"ontology":	{"NN"},
"onus":	{"NN"},
"onward":	{"JJ","RB"},
"onward-driving":	{"JJ"},
"onwards":	{"RB"},
"onychium":	{"NN"},
"onychogalea":	{"NN"},
"onycholysis":	{"NN"},
"onychomys":	{"NNS"},
"onychophora":	{"NN"},
"onychophoran":	{"NN"},
"onychosis":	{"NN"},
"onymous":	{"JJ"},
"onyx":	{"NN"},
"onyxis":	{"NN"},
"oocyte":	{"NN"},
"oodles":	{"NNS"},
"oogenesis":	{"NN"},
"ooh":	{"UH","NN","VB","VBP"},
"oohed":	{"VBD","VBN"},
"oohing":	{"VBG"},
"oohs":	{"NNS","VBZ"},
"oology":	{"NN"},
"oolong":	{"NN"},
"oomph":	{"NN"},
"oomycetes":	{"NNS"},
"oophorectomy":	{"NN"},
"oophoritis":	{"NN"},
"oophorosalpingectomy":	{"NN"},
"oops":	{"UH"},
"oort":	{"NN"},
"oosphere":	{"NN"},
"oospore":	{"NN"},
"ootid":	{"NN"},
"ooze":	{"VB","VBP","NN"},
"oozed":	{"VBD","VBN"},
"oozes":	{"VBZ"},
"oozing":	{"VBG"},
"oozy":	{"JJ"},
"op":	{"NN"},
"op-ed":	{"JJ","NN"},
"op-eds":	{"NNS"},
"opacification":	{"NN"},
"opacified":	{"VBD","VBN"},
"opacifies":	{"VBZ"},
"opacify":	{"VB","VBP"},
"opacifying":	{"VBG"},
"opacity":	{"NN"},
"opah":	{"NN"},
"opal":	{"NN"},
"opalesce":	{"VB","VBP"},
"opalesced":	{"VBD","VBN"},
"opalescence":	{"NN"},
"opalescent":	{"JJ"},
"opalesces":	{"VBZ"},
"opalescing":	{"VBG"},
"opaline":	{"NN","JJ"},
"opalise":	{"VB","VBP"},
"opalised":	{"VBD","VBN","JJ"},
"opalises":	{"VBZ"},
"opalising":	{"VBG"},
"opalize":	{"VB","VBP"},
"opalized":	{"VBD","VBN","JJ"},
"opalizes":	{"VBZ"},
"opalizing":	{"VBG"},
"opals":	{"NNS"},
"opaque":	{"JJ"},
"opaquely":	{"RB"},
"opaqueness":	{"NN"},
"opcw":	{"NN"},
"opel":	{"NN"},
"open":	{"JJ","VB","VBP","NN"},
"open-access":	{"JJ","NN"},
"open-adoption":	{"NN"},
"open-air":	{"JJ","NN"},
"open-and-shut":	{"JJ"},
"open-bank":	{"JJ"},
"open-chain":	{"JJ"},
"open-checkbook":	{"NN"},
"open-collared":	{"JJ"},
"open-door":	{"NN","JJ"},
"open-end":	{"NN","JJ"},
"open-ended":	{"JJ"},
"open-endedness":	{"NN"},
"open-eyed":	{"JJ","RB"},
"open-face":	{"JJ"},
"open-flame":	{"JJ"},
"open-handed":	{"JJ"},
"open-handedly":	{"RB"},
"open-handedness":	{"NN"},
"open-heart":	{"JJ"},
"open-hearted":	{"JJ"},
"open-hearth":	{"JJ"},
"open-interest":	{"JJ"},
"open-market":	{"NN"},
"open-meeting":	{"JJ"},
"open-minded":	{"JJ"},
"open-mindedness":	{"NN"},
"open-mouthed":	{"JJ","RB"},
"open-necked":	{"JJ"},
"open-plan":	{"JJ"},
"open-shelf":	{"JJ"},
"open-skies":	{"JJ"},
"open-source":	{"JJ","NN"},
"open-top":	{"JJ"},
"open-work":	{"JJ"},
"open-year":	{"JJ"},
"openbill":	{"NN"},
"opencast":	{"JJ"},
"opencut":	{"JJ"},
"opened":	{"VBD","VBN"},
"opener":	{"NN"},
"openers":	{"NNS"},
"openhanded":	{"JJ"},
"openhandedness":	{"NN"},
"openhearted":	{"JJ"},
"opening":	{"NN","VBG","JJ"},
"opening-day":	{"NN"},
"opening-hour":	{"JJ"},
"openings":	{"NNS"},
"openly":	{"RB"},
"openmouthed":	{"JJ"},
"openness":	{"NN"},
"opens":	{"VBZ"},
"openwork":	{"JJ","NN"},
"opepe":	{"NN"},
"opera":	{"NN","NNS"},
"opera-glasses":	{"NNS"},
"opera-house":	{"NN"},
"opera-houses":	{"NNS"},
"operable":	{"JJ"},
"operagoer":	{"NN"},
"operagoers":	{"NNS"},
"operalet":	{"NN"},
"operand":	{"NN"},
"operands":	{"NNS"},
"operant":	{"JJ","NN"},
"operas":	{"NNS"},
"operate":	{"VB","VBP"},
"operated":	{"VBN","VBD"},
"operates":	{"VBZ"},
"operatic":	{"JJ"},
"operatically":	{"RB"},
"operating":	{"VBG","JJ"},
"operating-cost":	{"JJ"},
"operating-profit":	{"NN"},
"operating-room":	{"NN"},
"operating-rooms":	{"NNS"},
"operating-system":	{"JJ","NN"},
"operating-table":	{"NN"},
"operating-tables":	{"NNS"},
"operating-theatre":	{"NN"},
"operating-theatres":	{"NNS"},
"operatingroom":	{"NN"},
"operatingrooms":	{"NNS"},
"operation":	{"NN"},
"operational":	{"JJ"},
"operationalism":	{"NN"},
"operationalist":	{"NN","JJ"},
"operationalists":	{"NNS"},
"operationalization":	{"NN"},
"operationalize":	{"VB","VBP"},
"operationalized":	{"VBD","VBN"},
"operationalizes":	{"VBZ"},
"operationalizing":	{"VBG"},
"operationally":	{"RB"},
"operationist":	{"NN"},
"operationists":	{"NNS"},
"operations":	{"NNS"},
"operative":	{"JJ","NN"},
"operatively":	{"RB"},
"operatives":	{"NNS"},
"operator":	{"NN"},
"operator-assisted":	{"JJ"},
"operator-services":	{"NNS"},
"operators":	{"NNS"},
"operatorship":	{"NN"},
"operculate":	{"JJ"},
"operculated":	{"JJ"},
"operculum":	{"NN"},
"operetta":	{"NN"},
"operettas":	{"NNS"},
"operina":	{"NN"},
"operon":	{"NN"},
"operose":	{"JJ"},
"operoseness":	{"NN"},
"opheodrys":	{"NNS"},
"ophidia":	{"NN"},
"ophidian":	{"NN"},
"ophidiidae":	{"NN"},
"ophidism":	{"NN"},
"ophiodon":	{"NN"},
"ophiodontidae":	{"NN"},
"ophioglossaceae":	{"NN"},
"ophioglossales":	{"NNS"},
"ophioglossum":	{"NN"},
"ophiolatry":	{"NN"},
"ophiophagus":	{"NN"},
"ophisaurus":	{"NN"},
"ophiuchus":	{"NNS"},
"ophiurida":	{"NN"},
"ophiuroidea":	{"NN"},
"ophryon":	{"NN"},
"ophrys":	{"NN"},
"ophthalmectomy":	{"NN"},
"ophthalmia":	{"NN"},
"ophthalmic":	{"JJ"},
"ophthalmitis":	{"NN"},
"ophthalmologist":	{"NN"},
"ophthalmologists":	{"NNS"},
"ophthalmology":	{"NN"},
"ophthalmoplegia":	{"NN"},
"ophthalmoscope":	{"NN"},
"ophthalmoscopy":	{"NN"},
"opiate":	{"NN"},
"opiates":	{"NNS"},
"opiliones":	{"NNS"},
"opine":	{"VB","VBP"},
"opined":	{"VBD","VBN"},
"opines":	{"VBZ"},
"opining":	{"VBG"},
"opinion":	{"NN"},
"opinion-makers":	{"NNS"},
"opinionated":	{"JJ"},
"opinionative":	{"JJ"},
"opinionator":	{"NN"},
"opinionators":	{"NNS"},
"opinionise":	{"VB","VBP"},
"opinionised":	{"VBD","VBN"},
"opinionises":	{"VBZ"},
"opinionising":	{"NN","VBG"},
"opinionize":	{"VB","VBP"},
"opinionized":	{"VBD","VBN"},
"opinionizes":	{"VBZ"},
"opinionizing":	{"NN","VBG"},
"opinionmakers":	{"NNS"},
"opinions":	{"NNS"},
"opioid":	{"NN","JJ"},
"opioids":	{"NNS"},
"opisthobranchia":	{"NN"},
"opisthocomidae":	{"NN"},
"opisthocomus":	{"NNS"},
"opisthognathidae":	{"NN"},
"opisthognathous":	{"JJ"},
"opisthorchiasis":	{"NN"},
"opisthotonos":	{"NNS"},
"opium":	{"NN"},
"opopanax":	{"NN"},
"oporto":	{"NN"},
"opossum":	{"NN"},
"opossums":	{"NNS"},
"opponent":	{"NN","JJ"},
"opponents":	{"NNS"},
"opportune":	{"JJ"},
"opportunely":	{"RB"},
"opportuneness":	{"NN"},
"opportuning":	{"NN"},
"opportunism":	{"NN"},
"opportunist":	{"NN","JJ"},
"opportunistic":	{"JJ"},
"opportunists":	{"NNS"},
"opportunities":	{"NNS"},
"opportunity":	{"NN"},
"opposable":	{"JJ"},
"oppose":	{"VB","VBP"},
"opposed":	{"VBN","VBD","JJ"},
"opposer":	{"NN"},
"opposes":	{"VBZ"},
"opposing":	{"VBG","JJ"},
"opposite":	{"JJ","NN","IN","RB"},
"oppositely":	{"RB"},
"oppositeness":	{"NN"},
"opposites":	{"NNS"},
"opposition":	{"NN"},
"opposition-party":	{"JJ"},
"oppositions":	{"NNS"},
"oppositive":	{"JJ"},
"oppress":	{"VB","VBP"},
"oppressed":	{"JJ","VBD","VBN"},
"oppresses":	{"VBZ"},
"oppressing":	{"VBG"},
"oppression":	{"NN"},
"oppressive":	{"JJ"},
"oppressively":	{"RB"},
"oppressiveness":	{"NN"},
"oppressor":	{"NN"},
"oppressors":	{"NNS"},
"opprobrious":	{"JJ"},
"opprobriously":	{"RB"},
"opprobrium":	{"NN"},
"oppugn":	{"VB","VBP"},
"oppugned":	{"VBD","VBN"},
"oppugner":	{"NN"},
"oppugning":	{"VBG"},
"oppugns":	{"VBZ"},
"ops":	{"NNS"},
"opsin":	{"NN"},
"opsonification":	{"NN"},
"opsonin":	{"NN"},
"opsonisation":	{"NN"},
"opsonise":	{"VB","VBP"},
"opsonised":	{"VBD","VBN"},
"opsonises":	{"VBZ"},
"opsonising":	{"VBG"},
"opsonization":	{"NN"},
"opsonize":	{"VB","VBP"},
"opsonized":	{"VBD","VBN"},
"opsonizes":	{"VBZ"},
"opsonizing":	{"VBG"},
"opt":	{"VB","VBP"},
"optative":	{"JJ"},
"opted":	{"VBD","VBN"},
"optez":	{"NN"},
"opthalmic":	{"JJ"},
"optic":	{"JJ"},
"optical":	{"JJ"},
"optical-disk":	{"JJ"},
"optical-fiber":	{"NN"},
"optical-products":	{"NNS"},
"optical-scanning":	{"JJ"},
"optical-storage":	{"JJ"},
"optically":	{"RB"},
"optician":	{"NN"},
"opticians":	{"NNS"},
"optics":	{"NN"},
"optimal":	{"JJ"},
"optimality":	{"NN"},
"optimally":	{"RB"},
"optimisation":	{"NN"},
"optimise":	{"VB","VBP"},
"optimised":	{"VBD","VBN"},
"optimises":	{"VBZ"},
"optimising":	{"VBG"},
"optimism":	{"NN"},
"optimist":	{"NN"},
"optimistic":	{"JJ"},
"optimistically":	{"RB"},
"optimists":	{"NNS"},
"optimization":	{"NN"},
"optimize":	{"VB","VBP"},
"optimized":	{"VBD","VBN"},
"optimizes":	{"VBZ"},
"optimizing":	{"VBG"},
"optimo":	{"FW"},
"optimum":	{"JJ","NN"},
"opting":	{"VBG"},
"option":	{"NN","VB","VBP"},
"option-based":	{"JJ"},
"option-related":	{"JJ"},
"optional":	{"JJ"},
"optionally":	{"RB"},
"optioned":	{"VBD","VBN"},
"optioning":	{"VBG"},
"options":	{"NNS","VBZ"},
"options-related":	{"JJ"},
"options-trading":	{"JJ"},
"opto-electronic":	{"JJ"},
"optogenetics":	{"NN"},
"optomechanically":	{"RB"},
"optometrist":	{"NN"},
"optometrists":	{"NNS"},
"optometry":	{"NN"},
"optronics":	{"NN"},
"opts":	{"VBZ"},
"opulence":	{"NN"},
"opulent":	{"JJ","NN"},
"opulently":	{"RB"},
"opuntia":	{"NN"},
"opuntiales":	{"NNS"},
"opus":	{"NN"},
"opuscule":	{"NN"},
"opuscules":	{"NNS"},
"opusculum":	{"NN"},
"opuses":	{"NNS"},
"opv":	{"NN"},
"or":	{"CC","IN"},
"orach":	{"NN"},
"orache":	{"NN"},
"oracle":	{"NN"},
"oracles":	{"NNS"},
"oracular":	{"JJ"},
"orad":	{"RB"},
"oradexon":	{"NN"},
"oral":	{"JJ","NN"},
"oral-care":	{"JJ"},
"orally":	{"RB"},
"orals":	{"NNS"},
"orang":	{"NN"},
"orang-utan":	{"NN"},
"orang-utang":	{"NN"},
"orang-utangs":	{"NNS"},
"orang-utans":	{"NNS"},
"orange":	{"JJ","NN"},
"orange-and-blue":	{"JJ"},
"orange-and-white":	{"JJ"},
"orange-blossom":	{"NN"},
"orange-brown":	{"JJ"},
"orange-colored":	{"JJ"},
"orange-coloured":	{"JJ"},
"orange-flavored":	{"JJ"},
"orange-flowered":	{"JJ"},
"orange-hued":	{"JJ"},
"orange-juice":	{"NN"},
"orange-red":	{"JJ"},
"orange-sized":	{"JJ"},
"orangeade":	{"NN"},
"orangeades":	{"NNS"},
"orangeness":	{"NN"},
"orangeries":	{"NNS"},
"orangery":	{"NN"},
"oranges":	{"NNS"},
"orangewood":	{"NN"},
"orangish":	{"JJ"},
"orangish-red":	{"JJ"},
"orangutan":	{"NN"},
"orangutang":	{"NN"},
"orangutangs":	{"NNS"},
"orangutans":	{"NNS"},
"orasone":	{"NN"},
"orate":	{"VB","VBP"},
"orated":	{"VBD","VBN"},
"orates":	{"VBZ"},
"orating":	{"VBG"},
"oratio":	{"FW"},
"oration":	{"NN"},
"orations":	{"NNS"},
"orator":	{"NN"},
"oratorical":	{"JJ"},
"oratories":	{"NNS"},
"oratorio":	{"NN"},
"oratorios":	{"NNS"},
"orators":	{"NNS"},
"oratory":	{"NN"},
"orb":	{"NN","VB","VBP"},
"orb-weaver":	{"NN"},
"orb-weaving":	{"JJ"},
"orbed":	{"VBD","VBN"},
"orbicular":	{"JJ"},
"orbicularity":	{"NN"},
"orbicularly":	{"RB"},
"orbiculate":	{"JJ"},
"orbignya":	{"NN"},
"orbing":	{"VBG"},
"orbison":	{"NN"},
"orbit":	{"NN","VB","VBP"},
"orbital":	{"JJ","NN"},
"orbitale":	{"NN"},
"orbitals":	{"NNS"},
"orbited":	{"VBD","VBN"},
"orbiter":	{"NN"},
"orbiters":	{"NNS"},
"orbiting":	{"VBG"},
"orbits":	{"VBZ","NNS"},
"orbitual":	{"JJ"},
"orbs":	{"NNS","VBZ"},
"orc":	{"NN"},
"orca":	{"NN"},
"orchard":	{"NN"},
"orchardist":	{"NN"},
"orchardists":	{"NNS"},
"orchards":	{"NNS"},
"orchestia":	{"NN"},
"orchestra":	{"NN"},
"orchestral":	{"JJ"},
"orchestras":	{"NNS"},
"orchestrate":	{"VB","VBP"},
"orchestrated":	{"VBD","VBN"},
"orchestrates":	{"VBZ"},
"orchestrating":	{"VBG"},
"orchestration":	{"NN"},
"orchestrations":	{"NNS"},
"orchestrator":	{"NN"},
"orchestrators":	{"NNS"},
"orchid":	{"NN"},
"orchid-strewn":	{"JJ"},
"orchidaceae":	{"NN"},
"orchidales":	{"NNS"},
"orchidalgia":	{"NN"},
"orchidectomy":	{"NN"},
"orchids":	{"NNS"},
"orchiectomy":	{"NN"},
"orchil":	{"NN"},
"orchiopexy":	{"NN"},
"orchis":	{"NN"},
"orchitis":	{"NN"},
"orchotomy":	{"NN"},
"orcinus":	{"NN"},
"orcs":	{"NNS"},
"orcus":	{"NN"},
"orczy":	{"NN"},
"ordain":	{"VB","VBP"},
"ordained":	{"VBD","VBN"},
"ordainer":	{"NN"},
"ordaining":	{"VBG"},
"ordains":	{"VBZ"},
"ordeal":	{"NN"},
"ordeals":	{"NNS"},
"order":	{"NN","VB","VBP"},
"order-book":	{"NN"},
"order-books":	{"NNS"},
"order-chenopodiales":	{"NNS"},
"order-delivery":	{"JJ"},
"order-entry":	{"JJ","NN"},
"order-form":	{"NN"},
"order-forms":	{"NNS"},
"order-imbalance":	{"NN"},
"order-paper":	{"NN"},
"order-papers":	{"NNS"},
"order-processing":	{"JJ"},
"order-taker":	{"NN"},
"order-taking":	{"NN"},
"order-to-ship":	{"JJ"},
"ordered":	{"VBD","VBN","JJ"},
"orderer":	{"NN"},
"ordering":	{"VBG","NN"},
"orderings":	{"NNS"},
"orderlies":	{"NNS"},
"orderliness":	{"NN"},
"orderly":	{"JJ","NN"},
"orders":	{"NNS","VBZ"},
"orders-related":	{"JJ"},
"ordinal":	{"NN","JJ"},
"ordinals":	{"NNS"},
"ordinance":	{"NN"},
"ordinances":	{"NNS"},
"ordinand":	{"NN"},
"ordinands":	{"NNS"},
"ordinaries":	{"NNS"},
"ordinarily":	{"RB"},
"ordinariness":	{"NN"},
"ordinarius":	{"NN"},
"ordinary":	{"JJ"},
"ordinate":	{"NN","VB","VBP"},
"ordinated":	{"VBD","VBN"},
"ordinates":	{"NNS","VBZ"},
"ordinating":	{"VBG"},
"ordination":	{"NN"},
"ordinations":	{"NNS"},
"ordnance":	{"NN"},
"ordo":	{"NN"},
"ordure":	{"NN"},
"ore":	{"NN"},
"oread":	{"NN"},
"oreamnos":	{"NNS"},
"orectolobidae":	{"NN"},
"orectolobus":	{"NN"},
"oregano":	{"NN"},
"oregonian":	{"NN"},
"oreide":	{"NN"},
"orel":	{"NN"},
"oreo":	{"NN"},
"oreopteris":	{"NN"},
"oreortyx":	{"NN"},
"ores":	{"NNS"},
"orff":	{"NN"},
"organ":	{"NN"},
"organ-grinder":	{"NN"},
"organ-grinders":	{"NNS"},
"organ-transplant":	{"JJ","NN"},
"organdie":	{"NN"},
"organdy":	{"NN"},
"organelle":	{"NN"},
"organic":	{"JJ"},
"organically":	{"RB"},
"organicism":	{"NN"},
"organicistic":	{"JJ"},
"organics":	{"NNS"},
"organification":	{"NN"},
"organisation":	{"NN"},
"organisational":	{"JJ"},
"organisations":	{"NNS"},
"organise":	{"VB","VBP"},
"organised":	{"JJ","VBD","VBN"},
"organiser":	{"NN"},
"organisers":	{"NNS"},
"organises":	{"VBZ"},
"organising":	{"VBG"},
"organism":	{"NN"},
"organismal":	{"JJ"},
"organismic":	{"JJ"},
"organisms":	{"NNS"},
"organist":	{"NN"},
"organists":	{"NNS"},
"organization":	{"NN"},
"organization-position":	{"JJ"},
"organizational":	{"JJ"},
"organizationally":	{"RB"},
"organizations":	{"NNS"},
"organize":	{"VB","VBP"},
"organized":	{"VBN","JJ","VBD"},
"organized-crime":	{"NN"},
"organizer":	{"NN"},
"organizers":	{"NNS"},
"organizes":	{"VBZ"},
"organizing":	{"VBG"},
"organon":	{"NN"},
"organophosphate":	{"NN"},
"organophosphates":	{"NNS"},
"organs":	{"NNS"},
"organza":	{"NN"},
"orgasm":	{"NN"},
"orgasms":	{"NNS"},
"orgiastic":	{"JJ"},
"orgies":	{"NNS"},
"orginally":	{"RB"},
"orgone":	{"JJ","NN"},
"orgy":	{"NN"},
"oriel":	{"NN"},
"orient":	{"VB","VBP","JJ","NN"},
"oriental":	{"JJ","NN"},
"orientalise":	{"VB","VBP"},
"orientalised":	{"VBD","VBN"},
"orientalises":	{"VBZ"},
"orientalising":	{"VBG"},
"orientalism":	{"NN"},
"orientalist":	{"NN"},
"orientalists":	{"NNS"},
"orientalize":	{"VB","VBP"},
"orientalized":	{"VBD","VBN"},
"orientalizes":	{"VBZ"},
"orientalizing":	{"VBG"},
"orientals":	{"NNS"},
"orientate":	{"VB","VBP"},
"orientated":	{"JJ","VBD","VBN"},
"orientates":	{"VBZ"},
"orientating":	{"JJ","VBG"},
"orientation":	{"NN"},
"orientations":	{"NNS"},
"oriented":	{"VBD","VBN","JJ"},
"oriented-polypropylene":	{"JJ"},
"orienting":	{"VBG"},
"orients":	{"VBZ"},
"orifice":	{"NN"},
"orifices":	{"NNS"},
"oriflamme":	{"NN"},
"origami":	{"NN"},
"origanum":	{"NN"},
"origin":	{"NN"},
"original":	{"JJ","NN"},
"original-equipment":	{"JJ","NN"},
"original-instrument":	{"JJ"},
"original-issue":	{"JJ"},
"originalism":	{"NN"},
"originalist":	{"NN"},
"originalists":	{"NNS"},
"originality":	{"NN"},
"originally":	{"RB"},
"originals":	{"NNS"},
"originate":	{"VB","VBP"},
"originated":	{"VBD","VBN"},
"originates":	{"VBZ"},
"originating":	{"VBG"},
"origination":	{"NN"},
"originations":	{"NNS"},
"originative":	{"JJ"},
"originator":	{"NN"},
"originators":	{"NNS"},
"origins":	{"NNS"},
"orinasal":	{"NN"},
"orinase":	{"NN"},
"orinoco":	{"NN"},
"oriole":	{"NN"},
"orioles":	{"NNS"},
"oriolidae":	{"NN"},
"oriolus":	{"NN"},
"orion":	{"NN"},
"orison":	{"NN"},
"orissa":	{"NN"},
"orites":	{"NNS"},
"oriya":	{"NN"},
"orizaba":	{"NN"},
"orleanais":	{"NNS"},
"orleanism":	{"NN"},
"orleanist":	{"NN"},
"orleans":	{"NNS"},
"orleans-based":	{"JJ"},
"orlon":	{"NN"},
"orlop":	{"NN"},
"ormandy":	{"NN"},
"ormazd":	{"NN"},
"ormer":	{"NN"},
"ormolu":	{"NN"},
"ormosia":	{"NN"},
"ormuzd":	{"NN"},
"ornament":	{"VB","VBP","NN"},
"ornamental":	{"JJ"},
"ornamentalism":	{"NN"},
"ornamentalist":	{"NN"},
"ornamentally":	{"RB"},
"ornamentation":	{"NN"},
"ornamented":	{"VBN","VBD","JJ"},
"ornamenting":	{"VBG"},
"ornaments":	{"NNS","VBZ"},
"ornate":	{"JJ"},
"ornately":	{"RB"},
"ornateness":	{"NN"},
"orneriness":	{"NN"},
"ornery":	{"JJ"},
"orney":	{"JJ"},
"ornithine":	{"NN"},
"ornithischia":	{"NN"},
"ornithischian":	{"NN"},
"ornithogalum":	{"NN"},
"ornithological":	{"JJ"},
"ornithologist":	{"NN"},
"ornithologists":	{"NNS"},
"ornithology":	{"NN"},
"ornithomimid":	{"NN"},
"ornithomimida":	{"NN"},
"ornithopod":	{"NN"},
"ornithopoda":	{"NN"},
"ornithopter":	{"NN"},
"ornithorhynchidae":	{"NN"},
"ornithorhynchus":	{"NN"},
"ornithosis":	{"NN"},
"orobanchaceae":	{"NN"},
"orogeny":	{"NN"},
"orography":	{"NN"},
"oroide":	{"NN"},
"orology":	{"NN"},
"orono":	{"NN"},
"orontium":	{"NN"},
"oropharyngeal":	{"JJ"},
"oropharynx":	{"NN"},
"orotund":	{"JJ"},
"orphan":	{"NN","VB","VBP"},
"orphanage":	{"NN"},
"orphanages":	{"NNS"},
"orphaned":	{"VBD","VBN"},
"orphanhood":	{"NN"},
"orphaning":	{"VBG"},
"orphans":	{"VBZ","NNS"},
"orphenadrine":	{"NN"},
"orphic":	{"JJ"},
"orphrey":	{"NN"},
"orpiment":	{"NN"},
"orpin":	{"NN"},
"orpine":	{"NN"},
"orpington":	{"NN"},
"orr":	{"NN"},
"orrery":	{"NN"},
"orris":	{"NN"},
"orrisroot":	{"NN"},
"ortalis":	{"NN"},
"ortega":	{"NN"},
"orthicon":	{"NN"},
"orthilia":	{"NN"},
"orthochorea":	{"NN"},
"orthoclase":	{"NN"},
"orthodontia":	{"NN"},
"orthodontic":	{"JJ"},
"orthodontics":	{"NN"},
"orthodontist":	{"NN"},
"orthodontists":	{"NNS"},
"orthodonture":	{"NN"},
"orthodox":	{"JJ"},
"orthodoxies":	{"NNS"},
"orthodoxy":	{"NN"},
"orthoepist":	{"NN"},
"orthoepists":	{"NNS"},
"orthoepy":	{"NN"},
"orthogonal":	{"JJ"},
"orthogonality":	{"NN"},
"orthographic":	{"JJ"},
"orthographies":	{"NNS"},
"orthography":	{"NN"},
"orthomolecular":	{"JJ"},
"orthomyxovirus":	{"NN"},
"orthopaedic":	{"JJ"},
"orthopaedics":	{"NN"},
"orthopaedist":	{"NN"},
"orthopaedists":	{"NNS"},
"orthopedic":	{"JJ"},
"orthopedical":	{"JJ"},
"orthopedically":	{"RB"},
"orthopedics":	{"NN"},
"orthopedist":	{"NN"},
"orthopedists":	{"NNS"},
"orthophosphate":	{"NN"},
"orthophosphates":	{"NNS"},
"orthopnea":	{"NN"},
"orthopristis":	{"NN"},
"orthopter":	{"NN"},
"orthoptera":	{"NN"},
"orthopteran":	{"NN","JJ"},
"orthopterans":	{"NNS"},
"orthopteron":	{"NN"},
"orthoptic":	{"JJ"},
"orthoptics":	{"NN"},
"orthoptist":	{"NN"},
"orthorhombic":	{"JJ"},
"orthoscope":	{"NN"},
"orthostatic":	{"JJ"},
"orthotomus":	{"NN"},
"orthotropous":	{"JJ"},
"orthroplasty":	{"NN"},
"ortolan":	{"NN"},
"ortygan":	{"NN"},
"orudis":	{"NN"},
"orumiyeh":	{"NN"},
"oruvail":	{"NN"},
"orwellian":	{"JJ"},
"orycteropodidae":	{"NN"},
"orycteropus":	{"NN"},
"oryctolagus":	{"NN"},
"oryx":	{"NN","NNS"},
"oryxes":	{"NNS"},
"oryza":	{"NN"},
"oryzomys":	{"NNS"},
"oryzopsis":	{"NN"},
"orzae":	{"NNS"},
"orzo":	{"NN"},
"os":	{"NN"},
"osasco":	{"NN"},
"oscan":	{"NN"},
"oscan-speaking":	{"JJ"},
"oscheocele":	{"NN"},
"oscheocoele":	{"NN"},
"oscillate":	{"VB","VBP"},
"oscillated":	{"VBD","VBN"},
"oscillates":	{"VBZ"},
"oscillating":	{"VBG"},
"oscillation":	{"NN"},
"oscillations":	{"NNS"},
"oscillator":	{"NN"},
"oscillatoriaceae":	{"NN"},
"oscillators":	{"NNS"},
"oscillatory":	{"JJ"},
"oscillogram":	{"NN"},
"oscillograms":	{"NNS"},
"oscillograph":	{"NN"},
"oscillographs":	{"NNS"},
"oscilloscope":	{"NN"},
"oscilloscopes":	{"NNS"},
"oscine":	{"JJ","NN"},
"oscines":	{"NNS"},
"oscitance":	{"NN"},
"oscitancy":	{"NN"},
"oscitant":	{"JJ"},
"osco-umbrian":	{"NN"},
"osculate":	{"VB","VBP"},
"osculated":	{"VBD","VBN"},
"osculates":	{"VBZ"},
"osculating":	{"VBG"},
"osculation":	{"NN"},
"osculator":	{"NN"},
"osier":	{"NN"},
"osiers":	{"NNS"},
"osmanli":	{"NN"},
"osmanthus":	{"NNS"},
"osmeridae":	{"NN"},
"osmerus":	{"NN"},
"osmiridium":	{"NN"},
"osmitrol":	{"NN"},
"osmium":	{"NN"},
"osmoreceptor":	{"NN"},
"osmosis":	{"NN"},
"osmotic":	{"JJ"},
"osmotically":	{"RB"},
"osmund":	{"NN"},
"osmundaceae":	{"NN"},
"osprey":	{"NN"},
"ospreys":	{"NNS"},
"osseous":	{"JJ"},
"ossete":	{"NN"},
"ossicle":	{"NN"},
"ossicular":	{"JJ"},
"ossiculate":	{"JJ"},
"ossiculum":	{"NN"},
"ossiferous":	{"JJ"},
"ossification":	{"NN"},
"ossified":	{"VBD","VBN","JJ"},
"ossifies":	{"VBZ"},
"ossify":	{"VB","VBP"},
"ossifying":	{"VBG"},
"ossuary":	{"NN"},
"ostariophysi":	{"NN"},
"osteal":	{"JJ"},
"osteichthyes":	{"NN"},
"osteitis":	{"NN"},
"ostensible":	{"JJ"},
"ostensibly":	{"RB"},
"ostensive":	{"JJ"},
"ostensoria":	{"NNS"},
"ostensories":	{"NNS"},
"ostensorium":	{"NN"},
"ostensory":	{"NN"},
"ostentate":	{"VB","VBP"},
"ostentated":	{"VBD","VBN"},
"ostentates":	{"VBZ"},
"ostentating":	{"VBG"},
"ostentation":	{"NN"},
"ostentatious":	{"JJ"},
"ostentatiously":	{"RB"},
"ostentatiousness":	{"NN"},
"osteoarthritis":	{"NN"},
"osteoblast":	{"NN"},
"osteoblastoma":	{"NN"},
"osteochondroma":	{"NN"},
"osteoclasis":	{"NN"},
"osteoclast":	{"NN"},
"osteocyte":	{"NN"},
"osteodystrophy":	{"NN"},
"osteoglossidae":	{"NN"},
"osteoglossiformes":	{"NNS"},
"osteologer":	{"NN"},
"osteologist":	{"NN"},
"osteology":	{"NN"},
"osteolysis":	{"NN"},
"osteoma":	{"NN"},
"osteomalacia":	{"NN"},
"osteomyelitis":	{"NN"},
"osteopath":	{"NN"},
"osteopathist":	{"NN"},
"osteopaths":	{"NNS"},
"osteopathy":	{"NN"},
"osteopetrosis":	{"NN"},
"osteophyte":	{"NN"},
"osteopontin":	{"NN"},
"osteopontins":	{"NNS"},
"osteoporosis":	{"NN"},
"osteosarcoma":	{"NN"},
"osteosclerosis":	{"NN"},
"osteostracan":	{"NN"},
"osteostraci":	{"NN"},
"osteotomy":	{"NN"},
"ostiarius":	{"NN"},
"ostiary":	{"NN"},
"ostinati":	{"NNS"},
"ostinato":	{"NN"},
"ostinatos":	{"NNS"},
"ostiole":	{"NN"},
"ostler":	{"NN"},
"ostlers":	{"NNS"},
"ostomy":	{"NN"},
"ostraciidae":	{"NN"},
"ostracise":	{"VB","VBP"},
"ostracised":	{"VBD","VBN"},
"ostracises":	{"VBZ"},
"ostracising":	{"VBG"},
"ostracism":	{"NN"},
"ostracize":	{"VB","VBP"},
"ostracized":	{"VBD","VBN"},
"ostracizes":	{"VBZ"},
"ostracizing":	{"VBG"},
"ostracod":	{"NN"},
"ostracoda":	{"NN"},
"ostracoderm":	{"NN"},
"ostracodermi":	{"NN"},
"ostrava":	{"NN"},
"ostrea":	{"NN"},
"ostreidae":	{"NN"},
"ostrich":	{"NN"},
"ostriches":	{"NNS"},
"ostrichlike":	{"JJ","RB"},
"ostrogoth":	{"NN"},
"ostrya":	{"NN"},
"ostryopsis":	{"NN"},
"ostwald":	{"NN"},
"ostyak":	{"NN"},
"ostyak-samoyed":	{"NN"},
"otalgia":	{"NN"},
"otaria":	{"NN"},
"otariidae":	{"NN"},
"otc-market":	{"JJ"},
"othe":	{"JJ"},
"other":	{"DT","JJ","PRP"},
"other-directed":	{"JJ"},
"other-nation":	{"JJ"},
"other-worldly":	{"JJ"},
"otherness":	{"NN"},
"others":	{"PRP"},
"otherwise":	{"RB","JJ"},
"otherworld":	{"NN"},
"otherworldliness":	{"NN"},
"otherworldly":	{"JJ"},
"otho":	{"NN"},
"othonna":	{"NN"},
"otic":	{"JJ"},
"otides":	{"NNS"},
"otididae":	{"NN"},
"otiose":	{"JJ"},
"otitis":	{"NN"},
"oto":	{"NN"},
"otoe":	{"NN"},
"otoganglion":	{"NN"},
"otolaryngologist":	{"NN"},
"otolaryngology":	{"NN"},
"otologist":	{"NN"},
"otology":	{"NN"},
"otoplasty":	{"NN"},
"otorhinolaryngologist":	{"NN"},
"otorhinolaryngology":	{"NN"},
"otorrhea":	{"NN"},
"otosclerosis":	{"NN"},
"otoscope":	{"NN"},
"ototoxic":	{"JJ"},
"ottar":	{"NN"},
"otter":	{"NN"},
"otterhound":	{"NN"},
"otters":	{"NNS"},
"ottoman":	{"NN","JJ"},
"ottomans":	{"NNS"},
"ottumwa":	{"NN"},
"otus":	{"NN"},
"ouachita":	{"NN"},
"oubliette":	{"NN"},
"oubliettes":	{"NNS"},
"ouch":	{"UH"},
"oud":	{"NN"},
"ought":	{"MD"},
"oughta":	{"MD"},
"ouguiya":	{"NN"},
"oui":	{"FW"},
"ouija":	{"NN"},
"oujda":	{"NN"},
"ould":	{"NN"},
"ounce":	{"NN"},
"ounces":	{"NNS"},
"our":	{"PRP$"},
"ouranopithecus":	{"NN"},
"ouranos":	{"NNS"},
"ours":	{"PRP"},
"ourself":	{"PRP"},
"ourselves":	{"PRP"},
"ousel":	{"NN"},
"oust":	{"VB","VBP"},
"ousted":	{"VBD","VBN"},
"ouster":	{"NN"},
"ousting":	{"VBG","NN"},
"ousts":	{"VBZ"},
"out":	{"RP","IN","RB","VBP","NN","VB","JJ"},
"out-Herod":	{"VB","VBP"},
"out-Herodded":	{"VBD","VBN"},
"out-Herodding":	{"VBG"},
"out-Herods":	{"VBZ"},
"out-and-out":	{"JJ"},
"out-and-outer":	{"NN"},
"out-basket":	{"NN"},
"out-dated":	{"JJ"},
"out-group":	{"NN"},
"out-migrants":	{"NNS"},
"out-migration":	{"NN"},
"out-moded":	{"JJ"},
"out-of-alignment":	{"NN"},
"out-of-bounds":	{"JJ"},
"out-of-control":	{"JJ"},
"out-of-court":	{"JJ"},
"out-of-date":	{"JJ"},
"out-of-door":	{"JJ"},
"out-of-doors":	{"RB"},
"out-of-favor":	{"JJ"},
"out-of-kilter":	{"JJ"},
"out-of-mind":	{"JJ"},
"out-of-pocket":	{"JJ"},
"out-of-repair":	{"NN"},
"out-of-school":	{"JJ"},
"out-of-sight":	{"JJ"},
"out-of-state":	{"JJ"},
"out-of-staters":	{"NNS"},
"out-of-step":	{"JJ"},
"out-of-synch":	{"JJ"},
"out-of-the-way":	{"JJ"},
"out-of-touch":	{"JJ"},
"out-of-town":	{"JJ"},
"out-plunging":	{"JJ"},
"out-reaching":	{"JJ"},
"out-tray":	{"NN"},
"out-trays":	{"NNS"},
"outage":	{"NN"},
"outages":	{"NNS"},
"outaouais":	{"NN"},
"outback":	{"NN"},
"outbalance":	{"VB","VBP"},
"outbalanced":	{"VBD","VBN"},
"outbalances":	{"VBZ"},
"outbalancing":	{"VBG"},
"outbid":	{"VB","VBP","VBD","VBN"},
"outbidding":	{"VBG"},
"outbids":	{"VBZ"},
"outboard":	{"JJ","RB","NN"},
"outboards":	{"NNS"},
"outbound":	{"JJ"},
"outbrave":	{"VB","VBP"},
"outbraved":	{"VBD","VBN"},
"outbraves":	{"VBZ"},
"outbraving":	{"VBG"},
"outbreak":	{"NN"},
"outbreaks":	{"NNS"},
"outbred":	{"VBD","VBN"},
"outbreed":	{"VB","VBP"},
"outbreeding":	{"VBG","NN"},
"outbreeds":	{"VBZ"},
"outbuilding":	{"NN"},
"outbuildings":	{"NNS"},
"outburst":	{"NN"},
"outbursts":	{"NNS"},
"outcall":	{"NN"},
"outcalls":	{"NNS"},
"outcast":	{"NN","JJ"},
"outcaste":	{"JJ","NN","VB","VBP"},
"outcasted":	{"VBD","VBN"},
"outcastes":	{"NNS","VBZ"},
"outcasting":	{"VBG"},
"outcasts":	{"NNS"},
"outclass":	{"VB","VBP"},
"outclassed":	{"VBD","VBN"},
"outclasses":	{"VBZ"},
"outclassing":	{"VBG"},
"outcome":	{"NN"},
"outcomes":	{"NNS"},
"outcompete":	{"VB","VBP"},
"outcompeted":	{"VBD","VBN"},
"outcompetes":	{"VBZ"},
"outcompeting":	{"VBG"},
"outcries":	{"NNS"},
"outcrop":	{"NN","VB","VBP"},
"outcropped":	{"VBD","VBN"},
"outcropping":	{"NN","VBG"},
"outcrops":	{"NNS","VBZ"},
"outcry":	{"NN"},
"outdate":	{"VB","VBP"},
"outdated":	{"JJ","VBD","VBN"},
"outdates":	{"VBZ"},
"outdating":	{"VBG"},
"outdid":	{"VBD"},
"outdistance":	{"VB","VBP"},
"outdistanced":	{"VBD","VBN"},
"outdistances":	{"VBZ"},
"outdistancing":	{"VBG"},
"outdo":	{"VB","VBP"},
"outdoes":	{"VBZ"},
"outdoing":	{"VBG"},
"outdone":	{"VBN"},
"outdoor":	{"JJ"},
"outdoor-maintenance":	{"NN"},
"outdoors":	{"NN","RB"},
"outdoorsman":	{"NN"},
"outdoorsmen":	{"NNS"},
"outdoorswoman":	{"NN"},
"outdoorsy":	{"JJ"},
"outdraw":	{"VB","VBP"},
"outdrawing":	{"VBG"},
"outdrawn":	{"VBN"},
"outdraws":	{"VBZ"},
"outdrew":	{"VBD"},
"outed":	{"VBD","VBN"},
"outer":	{"JJ"},
"outer-space":	{"NN"},
"outercourse":	{"NN"},
"outermost":	{"JJ"},
"outerwear":	{"NN"},
"outface":	{"VB","VBP"},
"outfaced":	{"VBD","VBN"},
"outfaces":	{"VBZ"},
"outfacing":	{"VBG"},
"outfall":	{"NN"},
"outfalls":	{"NNS"},
"outfield":	{"NN"},
"outfielder":	{"NN"},
"outfielders":	{"NNS"},
"outfight":	{"VB","VBP"},
"outfighting":	{"VBG"},
"outfights":	{"VBZ"},
"outfit":	{"NN","VB","VBP"},
"outfits":	{"VBZ","NNS"},
"outfitted":	{"VBD","VBN"},
"outfitter":	{"NN"},
"outfitters":	{"NNS"},
"outfitting":	{"VBG"},
"outflank":	{"VB","VBP"},
"outflanked":	{"VBD","VBN"},
"outflanking":	{"VBG"},
"outflanks":	{"VBZ"},
"outflew":	{"VBD"},
"outflies":	{"NNS","VBZ"},
"outflow":	{"NN"},
"outflowing":	{"JJ"},
"outflown":	{"VBN"},
"outflows":	{"NNS"},
"outfly":	{"NN","VB","VBP"},
"outflying":	{"VBG"},
"outfought":	{"VBD","VBN"},
"outfox":	{"VB","VBP"},
"outfoxed":	{"VBD","VBN"},
"outfoxes":	{"VBZ"},
"outfoxing":	{"VBG"},
"outgain":	{"VB","VBP"},
"outgained":	{"VBD","VBN"},
"outgaining":	{"VBG"},
"outgains":	{"VBZ"},
"outgeneral":	{"VB","VBP"},
"outgeneraled":	{"VBN","VBD"},
"outgeneraling":	{"VBG"},
"outgeneralled":	{"VBD","VBN"},
"outgeneralling":	{"VBG"},
"outgenerals":	{"VBZ"},
"outgo":	{"VB","VBP","NN"},
"outgoer":	{"NN"},
"outgoes":	{"VBZ","NNS"},
"outgoing":	{"JJ","VBG"},
"outgone":	{"VBN"},
"outgrew":	{"VBD"},
"outgrow":	{"VB","VBP"},
"outgrowing":	{"VBG"},
"outgrown":	{"VBN"},
"outgrows":	{"VBZ"},
"outgrowth":	{"NN"},
"outguess":	{"VB","VBP"},
"outguessed":	{"VBD","VBN"},
"outguesses":	{"VBZ"},
"outguessing":	{"VBG"},
"outgun":	{"VB","VBP"},
"outgunned":	{"VBD","VBN"},
"outgunning":	{"VBG"},
"outguns":	{"VBZ"},
"outhouse":	{"NN"},
"outhouses":	{"NNS"},
"outing":	{"NN","VBG"},
"outings":	{"NNS"},
"outlaid":	{"VBD","VBN"},
"outlander":	{"NN"},
"outlanders":	{"NNS"},
"outlandish":	{"JJ"},
"outlandishly":	{"RB"},
"outlandishness":	{"NN"},
"outlast":	{"VB","VBP"},
"outlasted":	{"VBD","VBN"},
"outlasting":	{"VBG"},
"outlasts":	{"VBZ"},
"outlaw":	{"NN","VB","VBP"},
"outlawed":	{"VBD","VBN","JJ"},
"outlawing":	{"VBG"},
"outlawry":	{"NN"},
"outlaws":	{"NNS","VBZ"},
"outlay":	{"NN","VB","VBP"},
"outlaying":	{"VBG"},
"outlays":	{"NNS","VBZ"},
"outleap":	{"NN","VB","VBP"},
"outleaped":	{"VBD","VBN"},
"outleaping":	{"VBG"},
"outleaps":	{"NNS","VBZ"},
"outlet":	{"NN"},
"outlets":	{"NNS"},
"outlier":	{"NN"},
"outliers":	{"NNS"},
"outline":	{"NN","VB","VBP"},
"outlined":	{"VBD","VBN"},
"outlines":	{"NNS","VBZ"},
"outlining":	{"VBG"},
"outlive":	{"VB","VBP"},
"outlived":	{"VBD","VBN"},
"outlives":	{"VBZ"},
"outliving":	{"VBG"},
"outlook":	{"NN"},
"outlooks":	{"NNS"},
"outlying":	{"JJ"},
"outmaneuver":	{"VB","VBP"},
"outmaneuvered":	{"VBD","VBN"},
"outmaneuvering":	{"VBG"},
"outmaneuvers":	{"VBZ"},
"outmanoeuvre":	{"VB","VBP"},
"outmanoeuvred":	{"VBD","VBN"},
"outmanoeuvres":	{"VBZ"},
"outmanoeuvring":	{"VBG"},
"outmarch":	{"VB","VBP"},
"outmarched":	{"VBD","VBN"},
"outmarches":	{"VBZ"},
"outmarching":	{"VBG"},
"outmatch":	{"VB","VBP"},
"outmatched":	{"VBD","VBN"},
"outmatches":	{"VBZ"},
"outmatching":	{"VBG"},
"outmode":	{"VB","VBP"},
"outmoded":	{"JJ","VBD","VBN"},
"outmodes":	{"VBZ"},
"outmoding":	{"VBG"},
"outmost":	{"JJ"},
"outnumber":	{"VB","VBP"},
"outnumbered":	{"VBD","VBN"},
"outnumbering":	{"VBG"},
"outnumbers":	{"VBZ"},
"outpace":	{"VB","VBP"},
"outpaced":	{"VBD","VBN"},
"outpaces":	{"VBZ"},
"outpacing":	{"VBG"},
"outpatient":	{"NN"},
"outpatients":	{"NNS"},
"outperform":	{"VB","VBP"},
"outperformed":	{"VBD","VBN"},
"outperforming":	{"VBG"},
"outperforms":	{"VBZ"},
"outplacement":	{"NN"},
"outplacements":	{"NNS"},
"outplay":	{"VB","VBP"},
"outplayed":	{"VBD","VBN"},
"outplaying":	{"VBG"},
"outplays":	{"VBZ"},
"outpoint":	{"VB","VBP"},
"outpointed":	{"VBD","VBN"},
"outpointing":	{"VBG"},
"outpoints":	{"VBZ"},
"outport":	{"NN"},
"outpost":	{"NN"},
"outposts":	{"NNS"},
"outpour":	{"VB","VBP"},
"outpoured":	{"VBD","VBN"},
"outpouring":	{"NN","VBG"},
"outpourings":	{"NNS"},
"outpours":	{"VBZ"},
"output":	{"NN","VB","VBP","VBD","VBN"},
"output-axis":	{"NN"},
"output-restricting":	{"JJ"},
"outputs":	{"NNS","VBZ"},
"outputted":	{"VBD","VBN"},
"outputting":	{"VBG"},
"outrage":	{"NN","VB","VBP"},
"outraged":	{"JJ","VBD","VBN"},
"outrageous":	{"JJ"},
"outrageously":	{"RB"},
"outrageousness":	{"NN"},
"outrages":	{"VBZ","NNS"},
"outraging":	{"VBG"},
"outran":	{"VBD"},
"outrange":	{"VB","VBP"},
"outranged":	{"VBD","VBN"},
"outranges":	{"VBZ"},
"outranging":	{"VBG"},
"outrank":	{"VB","VBP"},
"outranked":	{"VBD","VBN"},
"outranking":	{"VBG"},
"outranks":	{"VBZ"},
"outre":	{"JJ"},
"outreach":	{"NN","VB","VBP"},
"outreached":	{"VBD","VBN"},
"outreaches":	{"VBZ"},
"outreaching":	{"VBG"},
"outridden":	{"VBN"},
"outride":	{"VB","VBP"},
"outrider":	{"NN"},
"outriders":	{"NNS"},
"outrides":	{"VBZ"},
"outriding":	{"VBG"},
"outrigged":	{"JJ"},
"outrigger":	{"NN"},
"outriggers":	{"NNS"},
"outright":	{"JJ","RB"},
"outrival":	{"VB","VBP"},
"outrivaled":	{"VBD","VBN"},
"outrivaling":	{"VBG"},
"outrivalled":	{"VBD","VBN"},
"outrivalling":	{"VBG"},
"outrivals":	{"VBZ"},
"outroar":	{"VB","VBP"},
"outroared":	{"VBD","VBN"},
"outroaring":	{"VBG"},
"outroars":	{"VBZ"},
"outrode":	{"VBD"},
"outrun":	{"VB","VBP","VBN"},
"outrunning":	{"VBG"},
"outruns":	{"VBZ"},
"outs":	{"VBZ","NNS"},
"outsail":	{"VB","VBP"},
"outsailed":	{"VBD","VBN"},
"outsailing":	{"VBG"},
"outsails":	{"VBZ"},
"outscore":	{"VB","VBP"},
"outscored":	{"VBD","VBN"},
"outscores":	{"VBZ"},
"outscoring":	{"VBG"},
"outsell":	{"VB","VBP"},
"outselling":	{"VBG"},
"outsells":	{"VBZ"},
"outset":	{"NN"},
"outshine":	{"VB","VBP"},
"outshines":	{"VBZ"},
"outshining":	{"VBG"},
"outshone":	{"VBD","VBN"},
"outshoot":	{"VB","VBP","NN"},
"outshooting":	{"VBG"},
"outshoots":	{"VBZ","NNS"},
"outshot":	{"VBD","VBN"},
"outshout":	{"NN","VB","VBP"},
"outshouted":	{"VBD","VBN"},
"outshouting":	{"VBG"},
"outshouts":	{"NNS","VBZ"},
"outside":	{"IN","JJ","NN","RB"},
"outsider":	{"NN"},
"outsiders":	{"NNS"},
"outsides":	{"NNS"},
"outsize":	{"JJ","NN"},
"outsized":	{"JJ"},
"outskirts":	{"NNS"},
"outslug":	{"VB","VBP"},
"outslugged":	{"VBD","VBN"},
"outslugging":	{"VBG"},
"outslugs":	{"VBZ"},
"outsmart":	{"VB","VBP"},
"outsmarted":	{"VBD","VBN"},
"outsmarting":	{"VBG"},
"outsmarts":	{"VBZ"},
"outsold":	{"VBD","VBN"},
"outsole":	{"NN"},
"outsoles":	{"NNS"},
"outsource":	{"VB","VBP"},
"outsourced":	{"VBD","VBN"},
"outsourcer":	{"NN"},
"outsourcers":	{"NNS"},
"outsources":	{"VBZ"},
"outsourcing":	{"NN","VBG"},
"outspan":	{"VB","VBP","NN"},
"outspanned":	{"VBD","VBN"},
"outspanning":	{"VBG"},
"outspans":	{"VBZ","NNS"},
"outspend":	{"VB","VBP"},
"outspending":	{"VBG"},
"outspends":	{"VBZ"},
"outspent":	{"VBD","VBN"},
"outspoken":	{"JJ"},
"outspokenly":	{"RB"},
"outspokenness":	{"NN"},
"outspread":	{"JJ","NN","VB","VBP","VBD","VBN"},
"outspreading":	{"VBG"},
"outspreads":	{"VBZ"},
"outstand":	{"VB","VBP"},
"outstanding":	{"JJ","VBG"},
"outstandingly":	{"RB"},
"outstands":	{"VBZ"},
"outstare":	{"VB","VBP"},
"outstared":	{"VBD","VBN"},
"outstares":	{"VBZ"},
"outstaring":	{"VBG"},
"outstate":	{"JJ"},
"outstation":	{"NN"},
"outstay":	{"VB","VBP"},
"outstayed":	{"VBD","VBN"},
"outstaying":	{"VBG"},
"outstays":	{"VBZ"},
"outstood":	{"VBD","VBN"},
"outstretch":	{"VB","VBP"},
"outstretched":	{"VBD","VBN","JJ"},
"outstretches":	{"VBZ"},
"outstretching":	{"VBG"},
"outstrip":	{"VB","VBP"},
"outstripped":	{"VBD","VBN"},
"outstripping":	{"VBG"},
"outstrips":	{"VBZ"},
"outstroke":	{"NN"},
"outta":	{"IN"},
"outtake":	{"NN"},
"outthink":	{"VB","VBP"},
"outthinking":	{"VBG"},
"outthinks":	{"VBZ"},
"outthought":	{"VBD","VBN"},
"outthrust":	{"NN"},
"outtrade":	{"VB","VBP"},
"outtraded":	{"VBD","VBG"},
"outtrades":	{"VBZ"},
"outtrading":	{"VBG"},
"outturn":	{"NN"},
"outvie":	{"VB","VBP"},
"outvied":	{"VBD","VBN"},
"outvies":	{"VBZ"},
"outvote":	{"VB","VBP"},
"outvoted":	{"VBD","VBN"},
"outvotes":	{"VBZ"},
"outvoting":	{"VBG"},
"outvying":	{"VBG"},
"outward":	{"RB","JJ","NN"},
"outward-bound":	{"JJ"},
"outward-developing":	{"JJ"},
"outward-looking":	{"JJ"},
"outward-moving":	{"JJ"},
"outward-projecting":	{"JJ"},
"outwardly":	{"RB"},
"outwardness":	{"NN"},
"outwards":	{"RB"},
"outwear":	{"VB","VBP"},
"outwearing":	{"VBG"},
"outwears":	{"VBZ"},
"outweigh":	{"VB","VBP"},
"outweighed":	{"VBD","VBN"},
"outweighing":	{"VBG"},
"outweighs":	{"VBZ"},
"outwent":	{"VBD"},
"outwit":	{"VB","VBP"},
"outwits":	{"VBZ"},
"outwitted":	{"VBD","VBN"},
"outwitting":	{"VBG"},
"outwore":	{"VBD"},
"outwork":	{"NN","VB","VBP"},
"outworked":	{"VBD","VBN"},
"outworking":	{"VBG"},
"outworks":	{"VBZ"},
"outworn":	{"VBN","JJ"},
"ouzel":	{"NN"},
"ouzels":	{"NNS"},
"ouzo":	{"NN"},
"ouzos":	{"NNS"},
"ov":	{"NN"},
"ova":	{"NNS"},
"oval":	{"NN","JJ"},
"oval-bodied":	{"JJ"},
"oval-fruited":	{"JJ"},
"oval-shaped":	{"JJ"},
"ovalbumin":	{"NN"},
"ovalipes":	{"NNS"},
"ovals":	{"NNS"},
"ovarian":	{"JJ"},
"ovariectomy":	{"NN"},
"ovaries":	{"NNS"},
"ovaritis":	{"NN"},
"ovary":	{"NN"},
"ovata":	{"NN"},
"ovate":	{"JJ"},
"ovation":	{"NN"},
"ovations":	{"NNS"},
"oven":	{"NN"},
"oven-ready":	{"JJ"},
"oven-shaped":	{"JJ"},
"ovenbake":	{"VB","VBP"},
"ovenbaked":	{"VBD","VBN"},
"ovenbakes":	{"VBZ"},
"ovenbaking":	{"VBG"},
"ovenbird":	{"NN"},
"ovenbirds":	{"NNS"},
"ovens":	{"NNS"},
"ovenware":	{"NN"},
"over":	{"IN","RP","RB","JJ","NN","VB","VBP"},
"over-able":	{"JJ"},
"over-achievement":	{"NN"},
"over-achiever":	{"NN"},
"over-achievers":	{"NNS"},
"over-advertise":	{"VB","VBP"},
"over-advertised":	{"VBD","VBN"},
"over-advertises":	{"VBZ"},
"over-advertising":	{"VBG"},
"over-age":	{"JJ"},
"over-alert":	{"JJ"},
"over-allotment":	{"JJ","NN"},
"over-allotments":	{"NNS"},
"over-articulate":	{"VB","VBP","JJ"},
"over-articulated":	{"VBD","VBN"},
"over-articulates":	{"VBZ"},
"over-articulating":	{"VBG"},
"over-assessment":	{"NN"},
"over-assessments":	{"NNS"},
"over-busied":	{"VBD","VBN"},
"over-busy":	{"JJ","VB","VBP"},
"over-busyies":	{"VBZ"},
"over-busying":	{"VBG"},
"over-designed":	{"JJ"},
"over-easy":	{"RB"},
"over-egg":	{"VB","VBP"},
"over-egged":	{"VBD","VBN"},
"over-egging":	{"VBG"},
"over-eggs":	{"VBZ"},
"over-engineered":	{"JJ"},
"over-excited":	{"JJ"},
"over-rule":	{"VB","VBP"},
"over-ruled":	{"VBD","VBN"},
"over-rules":	{"VBZ"},
"over-ruling":	{"VBG"},
"over-the-top":	{"JJ"},
"over-under":	{"NN","JJ"},
"over-unders":	{"NNS"},
"over-use":	{"VB","VBP","NN"},
"over-used":	{"VBD","VBN"},
"over-uses":	{"VBZ"},
"over-using":	{"VBG"},
"overabound":	{"VB","VBP"},
"overabounded":	{"VBD","VBN"},
"overabounding":	{"VBG"},
"overabounds":	{"VBZ"},
"overabstract":	{"VB","VBP","JJ"},
"overabstracted":	{"VBD","VBN"},
"overabstracting":	{"VBG"},
"overabstracts":	{"VBZ"},
"overabundance":	{"NN"},
"overabundant":	{"JJ"},
"overaccentuate":	{"VB","VBP"},
"overaccentuated":	{"VBD","VBN"},
"overaccentuates":	{"VBZ"},
"overaccentuating":	{"VBG"},
"overachieve":	{"VB","VBP"},
"overachieved":	{"VBD","VBN"},
"overachievement":	{"NN"},
"overachiever":	{"NN"},
"overachievers":	{"NNS"},
"overachieves":	{"VBZ"},
"overachieving":	{"VBG"},
"overact":	{"VB","VBP"},
"overacted":	{"VBD","VBN"},
"overacting":	{"NN","VBG"},
"overaction":	{"NN"},
"overactive":	{"JJ"},
"overactivity":	{"NN"},
"overacts":	{"VBZ"},
"overacute":	{"JJ"},
"overadjustment":	{"NN"},
"overadvertise":	{"VB","VBP"},
"overadvertised":	{"VBD","VBN"},
"overadvertises":	{"VBZ"},
"overadvertising":	{"VBG"},
"overage":	{"JJ","NN"},
"overaged":	{"JJ"},
"overages":	{"NNS"},
"overaggressive":	{"JJ"},
"overall":	{"JJ","RB","NN"},
"overalled":	{"JJ"},
"overallotment":	{"NN","JJ"},
"overallotments":	{"NNS"},
"overalls":	{"NNS"},
"overambition":	{"NN"},
"overambitious":	{"JJ"},
"overamplified":	{"JJ"},
"overanalyse":	{"VB","VBP"},
"overanalysed":	{"VBD","VBN"},
"overanalyses":	{"VBZ"},
"overanalysing":	{"VBG"},
"overanalysis":	{"NN"},
"overanalytical":	{"JJ"},
"overanalyze":	{"VB","VBP"},
"overanalyzed":	{"VBD","VBN"},
"overanalyzes":	{"VBZ"},
"overanalyzing":	{"VBG"},
"overanxieties":	{"NNS"},
"overanxiety":	{"NN"},
"overanxious":	{"JJ"},
"overapplication":	{"NN"},
"overapplications":	{"NNS"},
"overappraisal":	{"NN"},
"overapt":	{"JJ"},
"overarch":	{"VB","VBP"},
"overarched":	{"VBD","VBN"},
"overarches":	{"VBZ"},
"overarching":	{"VBG","JJ"},
"overarm":	{"JJ","RB","VB","VBP"},
"overarmed":	{"VBD","VBN"},
"overarms":	{"VBZ"},
"overarousal":	{"NN"},
"overarrange":	{"VB","VBP"},
"overarranged":	{"VBD","VBN"},
"overarranges":	{"VBZ"},
"overarranging":	{"VBG"},
"overarticulate":	{"JJ","VB","VBP"},
"overarticulated":	{"VBD","VBN"},
"overarticulates":	{"VBZ"},
"overarticulating":	{"VBG"},
"overassert":	{"VB","VBP"},
"overasserted":	{"VBD","VBN"},
"overasserting":	{"VBG"},
"overassertion":	{"NN"},
"overassertive":	{"JJ"},
"overasserts":	{"VBZ"},
"overassessment":	{"NN"},
"overate":	{"VBD"},
"overattachment":	{"NN"},
"overattention":	{"NN"},
"overattentive":	{"JJ"},
"overattribute":	{"VB","VBP"},
"overattributed":	{"VBD","VBN"},
"overattributes":	{"VBZ"},
"overattributing":	{"VBG"},
"overawe":	{"VB","VBP"},
"overawed":	{"VBD","VBN","JJ"},
"overawes":	{"VBZ"},
"overawing":	{"VBG"},
"overbake":	{"VB","VBP"},
"overbaked":	{"VBD","VBN"},
"overbakes":	{"VBZ"},
"overbaking":	{"VBG"},
"overbalance":	{"VB","VBP"},
"overbalanced":	{"VBD","VBN"},
"overbalances":	{"VBZ"},
"overbalancing":	{"VBG"},
"overbank":	{"JJ","NN"},
"overbar":	{"NN"},
"overbarren":	{"JJ"},
"overbars":	{"NNS"},
"overbattle":	{"JJ"},
"overbear":	{"VB","VBP"},
"overbearance":	{"NN"},
"overbearing":	{"JJ","VBG"},
"overbearingly":	{"RB"},
"overbearingness":	{"NN"},
"overbears":	{"VBZ"},
"overbeat":	{"VB","VBP","VBD","VBN"},
"overbeaten":	{"VBN","JJ"},
"overbeating":	{"VBG"},
"overbeats":	{"VBZ"},
"overbed":	{"JJ"},
"overbejeweled":	{"JJ"},
"overbejewelled":	{"JJ"},
"overbend":	{"VB","VBP"},
"overbending":	{"VBG"},
"overbends":	{"VBZ"},
"overbent":	{"VBD","VBN"},
"overbet":	{"NN","VB","VBP","VBD","VBN"},
"overbets":	{"NNS","VBZ"},
"overbetting":	{"VBG","NN"},
"overbid":	{"VB","VBP","NN","VBD","VBN"},
"overbidder":	{"NN"},
"overbidders":	{"NNS"},
"overbidding":	{"VBG"},
"overbide":	{"VB","VBP"},
"overbided":	{"VBD","VBN"},
"overbides":	{"VBZ"},
"overbiding":	{"VBG"},
"overbids":	{"VBZ"},
"overbig":	{"JJ"},
"overbill":	{"VB","VBP"},
"overbilled":	{"VBD","VBN"},
"overbilling":	{"VBG"},
"overbills":	{"VBZ"},
"overbind":	{"VB","VBP"},
"overbinded":	{"VBD","VBN"},
"overbinding":	{"VBG"},
"overbinds":	{"VBZ"},
"overbite":	{"NN"},
"overbites":	{"NNS"},
"overbitter":	{"JJ"},
"overblanket":	{"NN"},
"overblankets":	{"NNS"},
"overbleach":	{"VB","VBP"},
"overbleached":	{"VBD","VBN"},
"overbleaches":	{"VBZ"},
"overbleaching":	{"VBG"},
"overblew":	{"VBD"},
"overblouse":	{"NN"},
"overblouses":	{"NNS"},
"overblow":	{"VB","VBP"},
"overblowing":	{"VBG"},
"overblown":	{"JJ","VBN"},
"overblows":	{"VBZ"},
"overboard":	{"RB"},
"overboil":	{"VB","VBP"},
"overboiled":	{"VBD","VBN"},
"overboiling":	{"VBG"},
"overboils":	{"VBZ"},
"overbold":	{"JJ"},
"overboldly":	{"RB"},
"overbook":	{"VB","VBP"},
"overbooked":	{"VBD","VBN","JJ"},
"overbooker":	{"NN"},
"overbookers":	{"NNS"},
"overbooking":	{"VBG","NN"},
"overbookings":	{"NNS"},
"overbookish":	{"JJ"},
"overbooks":	{"VBZ"},
"overboot":	{"NN"},
"overboots":	{"NNS"},
"overbore":	{"VBD"},
"overborne":	{"VBN"},
"overborrow":	{"VB","VBP"},
"overborrowed":	{"VBD","VBN"},
"overborrowing":	{"VBG"},
"overborrows":	{"VBZ"},
"overbought":	{"JJ","VBD","VBN"},
"overbound":	{"VB","VBP"},
"overbounded":	{"VBD","VBN"},
"overbounding":	{"VBG"},
"overbounds":	{"VBZ"},
"overbounteous":	{"JJ"},
"overbow":	{"VB","VBP"},
"overbowed":	{"VBD","VBN"},
"overbowing":	{"VBG"},
"overbows":	{"VBZ"},
"overbrake":	{"VB","VBP"},
"overbraked":	{"VBD","VBN"},
"overbrakes":	{"VBZ"},
"overbraking":	{"VBG"},
"overbrand":	{"VB","VBP"},
"overbranded":	{"VBD","VBN"},
"overbranding":	{"VBG"},
"overbrands":	{"VBZ"},
"overbreadth":	{"NN"},
"overbreathing":	{"NN"},
"overbred":	{"VBD","VBN","JJ"},
"overbreed":	{"VB","VBP"},
"overbreeding":	{"VBG"},
"overbreeds":	{"VBZ"},
"overbridge":	{"NN"},
"overbridges":	{"NNS"},
"overbrief":	{"JJ"},
"overbright":	{"JJ"},
"overbrim":	{"VB","VBP"},
"overbrimmed":	{"VBD","VBN"},
"overbrimming":	{"VBG"},
"overbrims":	{"VBZ"},
"overbroad":	{"JJ"},
"overbroadly":	{"RB"},
"overbroadness":	{"NN"},
"overbrow":	{"VB","VBP"},
"overbrowed":	{"VBD","VBN"},
"overbrowing":	{"VBG"},
"overbrows":	{"VBZ"},
"overbrowse":	{"VB","VBP"},
"overbrowsed":	{"VBD","VBN"},
"overbrowses":	{"VBZ"},
"overbrowsing":	{"VBG"},
"overbrutal":	{"JJ"},
"overbubble":	{"VB","VBP"},
"overbubbled":	{"VBD","VBN"},
"overbubbles":	{"VBZ"},
"overbubbling":	{"VBG"},
"overbudget":	{"JJ","VB","VBP"},
"overbudgetd":	{"VBD","VBN"},
"overbudgeting":	{"VBG"},
"overbudgets":	{"VBZ"},
"overbuild":	{"VB","VBP"},
"overbuilder":	{"NN"},
"overbuilders":	{"NNS"},
"overbuilding":	{"VBG"},
"overbuilds":	{"VBZ"},
"overbuilt":	{"JJ","VBD","VBN"},
"overbulk":	{"VB","VBP"},
"overbulked":	{"VBD","VBN"},
"overbulking":	{"VBG"},
"overbulks":	{"VBZ"},
"overbullish":	{"JJ"},
"overburden":	{"VB","VBP"},
"overburdened":	{"VBD","VBN","JJ"},
"overburdening":	{"VBG"},
"overburdens":	{"VBZ"},
"overburdensome":	{"JJ"},
"overburn":	{"VB","VBP"},
"overburned":	{"VBD","VBN"},
"overburning":	{"VBG"},
"overburns":	{"VBZ"},
"overburnt":	{"VBD","VBN"},
"overbusied":	{"VBD","VBN"},
"overbusies":	{"VBZ"},
"overbust":	{"JJ"},
"overbusy":	{"JJ","VB","VBP"},
"overbusying":	{"VBG"},
"overbuy":	{"VB","VBP"},
"overbuying":	{"VBG"},
"overbuys":	{"VBZ"},
"overby":	{"RB"},
"overcaffeinated":	{"JJ"},
"overcalculate":	{"VB","VBP"},
"overcalculated":	{"VBD","VBN"},
"overcalculates":	{"VBZ"},
"overcalculating":	{"VBG"},
"overcalculation":	{"NN"},
"overcalculations":	{"NNS"},
"overcall":	{"NN","VB","VBP"},
"overcalled":	{"VBD","VBN"},
"overcaller":	{"NN"},
"overcallers":	{"NNS"},
"overcalling":	{"VBG"},
"overcalls":	{"NNS","VBZ"},
"overcame":	{"VBD"},
"overcanopied":	{"VBD","VBN"},
"overcanopies":	{"VBZ"},
"overcanopy":	{"VB","VBP"},
"overcanopying":	{"VBG"},
"overcanvassed":	{"JJ"},
"overcapable":	{"JJ"},
"overcapacity":	{"NN"},
"overcapitalisation":	{"NN"},
"overcapitalise":	{"VB","VBP"},
"overcapitalised":	{"VBD","VBN","JJ"},
"overcapitalises":	{"VBZ"},
"overcapitalising":	{"VBG"},
"overcapitalization":	{"NN"},
"overcapitalize":	{"VB","VBP"},
"overcapitalized":	{"VBD","VBN","JJ"},
"overcapitalizes":	{"VBZ"},
"overcapitalizing":	{"VBG"},
"overcard":	{"NN"},
"overcards":	{"NNS"},
"overcare":	{"VB","VBP"},
"overcared":	{"VBD","VBN"},
"overcareful":	{"JJ"},
"overcares":	{"VBZ"},
"overcaring":	{"VBG"},
"overcark":	{"VB","VBP"},
"overcarked":	{"VBD","VBN"},
"overcarking":	{"VBG"},
"overcarks":	{"VBZ"},
"overcarried":	{"VBD","VBN"},
"overcarries":	{"VBZ"},
"overcarry":	{"VB","VBP"},
"overcarrying":	{"VBG"},
"overcarve":	{"VB","VBP"},
"overcarved":	{"VBD","VBN"},
"overcarves":	{"VBZ"},
"overcarving":	{"VBG"},
"overcast":	{"JJ","NN","VB","VBP","VBD","VBN"},
"overcasting":	{"NN","VBG"},
"overcasts":	{"VBZ","NNS"},
"overcatch":	{"VB","VBP"},
"overcatches":	{"VBZ"},
"overcatching":	{"VBG"},
"overcategorization":	{"NN"},
"overcategorizations":	{"NNS"},
"overcategorize":	{"VB","VBP"},
"overcategorized":	{"VBD","VBN"},
"overcategorizes":	{"VBZ"},
"overcategorizing":	{"VBG"},
"overcaught":	{"VBD","VBN"},
"overcaution":	{"NN"},
"overcautious":	{"JJ"},
"overcautiously":	{"RB"},
"overcautiousness":	{"NN"},
"overcentralise":	{"VB","VBP"},
"overcentralised":	{"VBD","VBN","JJ"},
"overcentralises":	{"VBZ"},
"overcentralising":	{"VBG"},
"overcentralize":	{"VB","VBP"},
"overcentralized":	{"VBD","VBN","JJ"},
"overcentralizes":	{"VBZ"},
"overcentralizing":	{"VBG"},
"overcerebral":	{"JJ"},
"overchange":	{"NN"},
"overcharge":	{"VB","VBP","NN"},
"overcharged":	{"JJ","VBN","VBD"},
"overcharger":	{"NN"},
"overchargers":	{"NNS"},
"overcharges":	{"VBZ","NNS"},
"overcharging":	{"VBG","NN"},
"overcheap":	{"JJ"},
"overcheck":	{"NN"},
"overchecks":	{"NNS"},
"overchill":	{"VB","VBP"},
"overchilled":	{"VBD","VBN"},
"overchilling":	{"VBG"},
"overchills":	{"VBZ"},
"overchlorinated":	{"JJ"},
"overchoreograph":	{"VB","VBP"},
"overchoreographed":	{"VBD","VBN"},
"overchoreographing":	{"VBG"},
"overchoreographs":	{"VBZ"},
"overcite":	{"VB","VBP"},
"overcited":	{"VBD","VBN"},
"overcites":	{"VBZ"},
"overciting":	{"VBG"},
"overcivil":	{"JJ"},
"overcivilised":	{"JJ"},
"overcivilized":	{"JJ"},
"overclad":	{"JJ"},
"overclaim":	{"VB","VBP"},
"overclaimed":	{"VBD","VBN"},
"overclaiming":	{"VBG"},
"overclaims":	{"VBZ"},
"overclass":	{"NN"},
"overclasses":	{"NNS"},
"overclassification":	{"NN"},
"overclassified":	{"VBD","VBN"},
"overclassifies":	{"VBZ"},
"overclassify":	{"VB","VBP"},
"overclassifying":	{"VBG"},
"overclean":	{"VB","VBP"},
"overcleaned":	{"VBD","VBN"},
"overcleaning":	{"VBG"},
"overcleans":	{"VBZ"},
"overclear":	{"JJ"},
"overclimb":	{"VB","VBP"},
"overclimbed":	{"VBD","VBN"},
"overclimbing":	{"VBG"},
"overclimbs":	{"VBZ"},
"overclock":	{"VB","VBP"},
"overclockable":	{"JJ"},
"overclocked":	{"VBD","VBN"},
"overclocker":	{"NN"},
"overclockers":	{"NNS"},
"overclocking":	{"VBG","NN"},
"overclocks":	{"VBZ"},
"overclose":	{"JJ"},
"overclothes":	{"NNS"},
"overcloud":	{"VB","VBP"},
"overclouded":	{"VBD","VBN"},
"overclouding":	{"VBG"},
"overclouds":	{"VBZ"},
"overcloy":	{"VB","VBP"},
"overcloyed":	{"VBD","VBN"},
"overcloying":	{"VBG"},
"overcloys":	{"VBZ"},
"overclub":	{"VB","VBP"},
"overclubbed":	{"VBD","VBN"},
"overclubbing":	{"VBG"},
"overclubs":	{"VBZ"},
"overcluttered":	{"JJ"},
"overcoach":	{"VB","VBP"},
"overcoached":	{"VBD","VBN"},
"overcoaches":	{"VBZ"},
"overcoaching":	{"VBG"},
"overcoat":	{"NN"},
"overcoating":	{"NN"},
"overcoatless":	{"JJ"},
"overcoats":	{"NNS"},
"overcoddle":	{"VB","VBP"},
"overcoddled":	{"VBD","VBN"},
"overcoddles":	{"VBZ"},
"overcoddling":	{"VBG"},
"overcoil":	{"NN"},
"overcoils":	{"NNS"},
"overcold":	{"JJ"},
"overcollateralization":	{"NN"},
"overcollateralize":	{"VB","VBP"},
"overcollateralized":	{"VBD","VBN"},
"overcollateralizes":	{"VBZ"},
"overcollateralizing":	{"VBG"},
"overcollection":	{"NN"},
"overcollections":	{"NNS"},
"overcolor":	{"VB","VBP"},
"overcolored":	{"VBD","VBN"},
"overcoloring":	{"VBG"},
"overcolors":	{"VBZ"},
"overcolour":	{"VB","VBP"},
"overcoloured":	{"VBD","VBN","JJ"},
"overcolouring":	{"VBG"},
"overcolours":	{"VBZ"},
"overcome":	{"VB","VBN","VBP"},
"overcomeable":	{"JJ"},
"overcomer":	{"NN"},
"overcomers":	{"NNS"},
"overcomes":	{"VBZ"},
"overcoming":	{"VBG","NN"},
"overcomingly":	{"RB"},
"overcomings":	{"NNS"},
"overcommercialization":	{"NN"},
"overcommercialize":	{"VB","VBP"},
"overcommercialized":	{"VBD","VBN"},
"overcommercializes":	{"VBZ"},
"overcommercializing":	{"VBG"},
"overcommit":	{"VB","VBP"},
"overcommitment":	{"NN"},
"overcommits":	{"VBZ"},
"overcommitted":	{"VBD","VBN"},
"overcommitting":	{"VBG"},
"overcommunicate":	{"VB","VBP"},
"overcommunicated":	{"VBD","VBN"},
"overcommunicates":	{"VBZ"},
"overcommunicating":	{"VBG"},
"overcommunication":	{"NN"},
"overcompensate":	{"VB","VBP"},
"overcompensated":	{"VBD","VBN"},
"overcompensates":	{"VBZ"},
"overcompensating":	{"VBG"},
"overcompensation":	{"NN"},
"overcompensations":	{"NNS"},
"overcompensatory":	{"JJ"},
"overcompetitive":	{"JJ"},
"overcompetitiveness":	{"NN"},
"overcomplacency":	{"NN"},
"overcomplete":	{"JJ"},
"overcompleteness":	{"NN"},
"overcomplex":	{"JJ"},
"overcomplexities":	{"NNS"},
"overcomplexity":	{"NN"},
"overcompliance":	{"NN"},
"overcomplicate":	{"VB","VBP"},
"overcomplicated":	{"VBD","VBN"},
"overcomplicates":	{"VBZ"},
"overcomplicating":	{"VBG"},
"overcomplication":	{"NN"},
"overcomplications":	{"NNS"},
"overcomplicator":	{"NN"},
"overcomplicators":	{"NNS"},
"overcompliment":	{"VB","VBP"},
"overcomplimented":	{"VBD","VBN"},
"overcomplimenting":	{"VBG"},
"overcompliments":	{"VBZ"},
"overcompress":	{"VB","VBP"},
"overcompressed":	{"VBD","VBN"},
"overcompresses":	{"VBZ"},
"overcompressing":	{"VBG"},
"overconcern":	{"NN","VB","VBP"},
"overconcerned":	{"VBD","VBN","JJ"},
"overconcerning":	{"VBG"},
"overconcerns":	{"NNS","VBZ"},
"overconfidence":	{"NN"},
"overconfident":	{"JJ"},
"overconfidently":	{"RB"},
"overconscious":	{"JJ"},
"overconstruct":	{"VB","VBP"},
"overconstructed":	{"VBD","VBN"},
"overconstructing":	{"VBG"},
"overconstructs":	{"VBZ"},
"overconsume":	{"VB","VBP"},
"overconsumed":	{"VBD","VBN"},
"overconsumes":	{"VBZ"},
"overconsuming":	{"JJ","VBG"},
"overconsumption":	{"NN"},
"overcontrol":	{"VB","VBP"},
"overcontrolled":	{"VBD","VBN"},
"overcontrolling":	{"VBG"},
"overcontrols":	{"VBZ"},
"overcook":	{"VB","VBP"},
"overcooked":	{"VBD","VBN"},
"overcooking":	{"VBG"},
"overcooks":	{"VBZ"},
"overcool":	{"VB","VBP"},
"overcooled":	{"VBD","VBN","JJ"},
"overcooling":	{"VBG"},
"overcools":	{"VBZ"},
"overcorrect":	{"VB","VBP"},
"overcorrected":	{"VBD","VBN"},
"overcorrecting":	{"VBG"},
"overcorrection":	{"NN"},
"overcorrections":	{"NNS"},
"overcorrects":	{"VBZ"},
"overcount":	{"VB","VBP"},
"overcounted":	{"VBD","VBN"},
"overcounting":	{"VBG"},
"overcounts":	{"VBZ"},
"overcover":	{"VB","VBP"},
"overcovered":	{"VBD","VBN"},
"overcovering":	{"VBG"},
"overcovers":	{"VBZ"},
"overcoy":	{"JJ"},
"overcram":	{"VB","VBP"},
"overcrammed":	{"VBD","VBN","JJ"},
"overcramming":	{"VBG","NN"},
"overcrams":	{"VBZ"},
"overcredulity":	{"NN"},
"overcredulous":	{"JJ"},
"overcriminalization":	{"NN"},
"overcritical":	{"JJ"},
"overcrop":	{"VB","VBP"},
"overcropped":	{"VBD","VBN"},
"overcropping":	{"VBG"},
"overcrops":	{"VBZ"},
"overcrossing":	{"NN"},
"overcrowd":	{"VB","VBP"},
"overcrowded":	{"JJ","VBD","VBN"},
"overcrowding":	{"NN","VBG"},
"overcrowds":	{"VBZ"},
"overcultivate":	{"VB","VBP"},
"overcultivated":	{"VBD","VBN"},
"overcultivates":	{"VBZ"},
"overcultivating":	{"VBG"},
"overcure":	{"VB","VBP","NN"},
"overcured":	{"VBD","VBN"},
"overcures":	{"VBZ","NNS"},
"overcuring":	{"VBG"},
"overcurious":	{"JJ"},
"overcurrent":	{"NN"},
"overcurrents":	{"NNS"},
"overcut":	{"VB","VBP","VBD","VBN"},
"overcuts":	{"VBZ"},
"overcutting":	{"VBG","NN"},
"overdare":	{"VB","VBP"},
"overdared":	{"VBD","VBN"},
"overdares":	{"VBZ"},
"overdaring":	{"VBG"},
"overdate":	{"NN","VB","VBP"},
"overdated":	{"VBD","VBN","JJ"},
"overdates":	{"NNS","VBZ"},
"overdating":	{"VBG"},
"overdear":	{"JJ"},
"overdeck":	{"NN","VB","VBP"},
"overdecked":	{"VBD","VBN"},
"overdecking":	{"VBG"},
"overdecks":	{"NNS","VBZ"},
"overdecorate":	{"VB","VBP"},
"overdecorated":	{"VBD","VBN"},
"overdecorates":	{"VBZ"},
"overdecorating":	{"VBG"},
"overdecoration":	{"NN"},
"overdelicate":	{"JJ"},
"overdemand":	{"NN","VB","VBP"},
"overdemanded":	{"VBD","VBN"},
"overdemanding":	{"VBG","JJ"},
"overdemands":	{"NNS","VBZ"},
"overdependence":	{"NN"},
"overdependences":	{"NNS"},
"overdependent":	{"JJ"},
"overdesign":	{"VB","VBP"},
"overdesigned":	{"VBD","VBN"},
"overdesigning":	{"VBG"},
"overdesigns":	{"VBZ"},
"overdetermine":	{"VB","VBP"},
"overdetermined":	{"VBD","VBN","JJ"},
"overdetermines":	{"VBZ"},
"overdetermining":	{"VBG"},
"overdevelop":	{"VB","VBP"},
"overdeveloped":	{"JJ","VBD","VBN"},
"overdeveloping":	{"VBG"},
"overdevelopment":	{"NN"},
"overdevelops":	{"VBZ"},
"overdeviate":	{"VB","VBP"},
"overdeviated":	{"VBD","VBN"},
"overdeviates":	{"VBZ"},
"overdeviating":	{"VBG"},
"overdiagnose":	{"VB","VBP"},
"overdiagnosed":	{"VBD","VBN"},
"overdiagnoses":	{"VBZ"},
"overdiagnosing":	{"VBG"},
"overdiagnosis":	{"NN"},
"overdid":	{"VBD"},
"overdirect":	{"JJ"},
"overdiscount":	{"VB","VBP"},
"overdiscounted":	{"VBD","VBN"},
"overdiscounting":	{"VBG"},
"overdiscounts":	{"VBZ"},
"overdiversity":	{"NN"},
"overdo":	{"VB","VBP"},
"overdocument":	{"VB","VBP"},
"overdocumentation":	{"NN"},
"overdocumented":	{"VBD","VBN"},
"overdocumenting":	{"VBG"},
"overdocuments":	{"VBZ"},
"overdoer":	{"NN"},
"overdoers":	{"NNS"},
"overdoes":	{"VBZ"},
"overdog":	{"NN"},
"overdogs":	{"NNS"},
"overdoing":	{"VBG"},
"overdominance":	{"NN"},
"overdominant":	{"NN"},
"overdone":	{"JJ","VBN"},
"overdosage":	{"NN"},
"overdose":	{"NN","VB","VBP"},
"overdosed":	{"VBD","VBN"},
"overdoses":	{"NNS","VBZ"},
"overdosing":	{"VBG"},
"overdraft":	{"NN"},
"overdrafts":	{"NNS"},
"overdramatic":	{"JJ"},
"overdramatise":	{"VB","VBP"},
"overdramatised":	{"VBD","VBN"},
"overdramatises":	{"VBZ"},
"overdramatising":	{"VBG"},
"overdramatize":	{"VB","VBP"},
"overdramatized":	{"VBD","VBN"},
"overdramatizes":	{"VBZ"},
"overdramatizing":	{"VBG"},
"overdrank":	{"VBD"},
"overdraught":	{"NN"},
"overdraughts":	{"NNS"},
"overdraw":	{"VB","VBP"},
"overdrawing":	{"VBG"},
"overdrawn":	{"JJ","VBN"},
"overdraws":	{"VBZ"},
"overdress":	{"VB","VBP"},
"overdressed":	{"VBD","VBN","JJ"},
"overdresses":	{"VBZ"},
"overdressing":	{"VBG"},
"overdrew":	{"VBD"},
"overdried":	{"VBD","VBN"},
"overdries":	{"VBZ"},
"overdrink":	{"VB","VBP"},
"overdrinking":	{"VBG"},
"overdrinks":	{"VBZ"},
"overdrive":	{"NN","VB","VBP"},
"overdriven":	{"VBN"},
"overdrives":	{"NNS","VBZ"},
"overdriving":	{"VBG"},
"overdrove":	{"VBD"},
"overdrunk":	{"VBN"},
"overdry":	{"VB","VBP","JJ"},
"overdrying":	{"VBG"},
"overdub":	{"VB","VBP","NN"},
"overdubbed":	{"VBD","VBN"},
"overdubbing":	{"VBG"},
"overdubs":	{"VBZ","NNS"},
"overdue":	{"JJ"},
"overdust":	{"VB","VBP"},
"overdusted":	{"VBD","VBN"},
"overdusting":	{"VBG"},
"overdusts":	{"VBZ"},
"overdye":	{"VB","VBP"},
"overdyed":	{"VBD","VBN"},
"overdyeing":	{"VBG"},
"overdyer":	{"NN"},
"overdyers":	{"NNS"},
"overdyes":	{"VBZ"},
"overeager":	{"JJ"},
"overeagerness":	{"NN"},
"overearnest":	{"JJ"},
"overeasy":	{"JJ"},
"overeat":	{"VB","VBP"},
"overeaten":	{"VBN"},
"overeater":	{"NN"},
"overeaters":	{"NNS"},
"overeating":	{"NN","VBG"},
"overeats":	{"VBZ"},
"overed":	{"VBD","VBN"},
"overedit":	{"VB","VBP"},
"overedited":	{"VBD","VBN"},
"overediting":	{"VBG"},
"overedits":	{"VBZ"},
"overeducate":	{"VB","VBP"},
"overeducated":	{"VBD","VBN"},
"overeducates":	{"VBZ"},
"overeducating":	{"VBG"},
"overeducation":	{"NN"},
"overeducations":	{"NNS"},
"overegg":	{"VB","VBP"},
"overegged":	{"VBD","VBN"},
"overegging":	{"VBG"},
"overeggs":	{"VBZ"},
"overelaborate":	{"JJ","VB","VBP"},
"overelaborated":	{"VBD","VBN"},
"overelaborates":	{"VBZ"},
"overelaborating":	{"VBG"},
"overelaboration":	{"NN"},
"overelaborations":	{"NNS"},
"overembellish":	{"VB","VBP"},
"overembellished":	{"VBD","VBN"},
"overembellishes":	{"VBZ"},
"overembellishing":	{"VBG"},
"overemote":	{"VB","VBP"},
"overemoted":	{"VBD","VBN"},
"overemotes":	{"VBZ"},
"overemoting":	{"VBG"},
"overemotional":	{"JJ"},
"overemphases":	{"NNS"},
"overemphasis":	{"NN"},
"overemphasise":	{"VB","VBP"},
"overemphasised":	{"VBD","VBN"},
"overemphasises":	{"VBZ"},
"overemphasising":	{"VBG"},
"overemphasize":	{"VB","VBP"},
"overemphasized":	{"VBD","VBN","JJ"},
"overemphasizes":	{"VBZ"},
"overemphasizing":	{"VBG"},
"overemphatic":	{"JJ"},
"overemployment":	{"NN"},
"overenamored":	{"JJ"},
"overenamoured":	{"JJ"},
"overencourage":	{"VB","VBP"},
"overencouraged":	{"VBD","VBN"},
"overencourages":	{"VBZ"},
"overencouraging":	{"VBG"},
"overenergetic":	{"JJ"},
"overengineer":	{"VB","VBP"},
"overengineered":	{"VBD","VBN"},
"overengineering":	{"VBG"},
"overengineers":	{"VBZ"},
"overenrolled":	{"JJ"},
"overentertained":	{"JJ"},
"overenthusiasm":	{"NN"},
"overenthusiastic":	{"JJ"},
"overenthusiastically":	{"RB"},
"overequip":	{"VB","VBP"},
"overequipped":	{"VBD","VBN","JJ"},
"overequipping":	{"VBG"},
"overequips":	{"VBZ"},
"overestimate":	{"VB","NN","VBP"},
"overestimated":	{"VBD","VBN"},
"overestimates":	{"VBZ","NNS"},
"overestimating":	{"VBG"},
"overestimation":	{"NN"},
"overestimations":	{"NNS"},
"overevaluate":	{"VB","VBP"},
"overevaluated":	{"VBD","VBN"},
"overevaluates":	{"VBZ"},
"overevaluating":	{"VBG"},
"overevaluation":	{"NN"},
"overevaluations":	{"NNS"},
"overexaggerate":	{"VB","VBP"},
"overexaggerated":	{"VBD","VBN"},
"overexaggerates":	{"VBZ"},
"overexaggerating":	{"VBG"},
"overexcitable":	{"JJ"},
"overexcite":	{"VB","VBP"},
"overexcited":	{"JJ","VBD","VBN"},
"overexcitement":	{"NN"},
"overexcites":	{"VBZ"},
"overexciting":	{"VBG"},
"overexercise":	{"VB","VBP"},
"overexercised":	{"VBD","VBN"},
"overexercises":	{"VBZ"},
"overexercising":	{"VBG"},
"overexert":	{"VB","VBP"},
"overexerted":	{"VBD","VBN"},
"overexerting":	{"VBG"},
"overexertion":	{"NN"},
"overexertions":	{"NNS"},
"overexerts":	{"VBZ"},
"overexpand":	{"VB","VBP"},
"overexpanded":	{"VBD","VBN"},
"overexpanding":	{"VBG"},
"overexpands":	{"VBZ"},
"overexpansion":	{"NN"},
"overexpectation":	{"NN"},
"overexpectations":	{"NNS"},
"overexplain":	{"VB","VBP"},
"overexplained":	{"VBD","VBN"},
"overexplaining":	{"VBG"},
"overexplains":	{"VBZ"},
"overexplicit":	{"JJ"},
"overexploit":	{"VB","VBP"},
"overexploitation":	{"NN"},
"overexploited":	{"JJ","VBD","VBN"},
"overexploiting":	{"VBG"},
"overexploits":	{"VBZ"},
"overexpose":	{"VB","VBP"},
"overexposed":	{"VBD","VBN","JJ"},
"overexposes":	{"VBZ"},
"overexposing":	{"VBG"},
"overexposure":	{"NN"},
"overextend":	{"VB","VBP"},
"overextended":	{"VBN","VBD","JJ"},
"overextending":	{"VBG"},
"overextends":	{"VBZ"},
"overextension":	{"NN"},
"overextensions":	{"NNS"},
"overextraction":	{"NN"},
"overextractions":	{"NNS"},
"overextravagant":	{"JJ"},
"overexuberant":	{"JJ"},
"overeye":	{"VB","VBP"},
"overfacile":	{"JJ"},
"overfall":	{"NN"},
"overfalls":	{"NNS"},
"overfamiliar":	{"JJ"},
"overfamiliarity":	{"NN"},
"overfar":	{"RB"},
"overfast":	{"JJ"},
"overfastidious":	{"JJ"},
"overfat":	{"JJ"},
"overfatigue":	{"VB","VBP","NN"},
"overfatigued":	{"VBD","VBN","JJ"},
"overfatigues":	{"VBZ"},
"overfatiguing":	{"VBG"},
"overfavor":	{"VB","VBP"},
"overfavored":	{"VBD","VBN"},
"overfavoring":	{"VBG"},
"overfavors":	{"VBZ"},
"overfavour":	{"VB","VBP"},
"overfavoured":	{"VBD","VBN"},
"overfavouring":	{"VBG"},
"overfavours":	{"VBZ"},
"overfear":	{"VB","VBP"},
"overfeared":	{"VBD","VBN"},
"overfearing":	{"VBG"},
"overfears":	{"VBZ"},
"overfed":	{"VBD","VBN"},
"overfeed":	{"VB","VBP"},
"overfeeding":	{"VBG","NN"},
"overfeeds":	{"VBZ"},
"overfertilise":	{"VB","VBP"},
"overfertilised":	{"VBD","VBN"},
"overfertilises":	{"VBZ"},
"overfertilising":	{"VBG"},
"overfertilization":	{"NN"},
"overfertilizations":	{"NNS"},
"overfertilize":	{"VB","VBP"},
"overfertilized":	{"VBD","VBN"},
"overfertilizes":	{"VBZ"},
"overfertilizing":	{"VBG"},
"overfill":	{"VB","VBP","NN"},
"overfilled":	{"VBD","VBN"},
"overfilling":	{"VBG"},
"overfills":	{"VBZ","NNS"},
"overfine":	{"JJ"},
"overfineness":	{"NN"},
"overfinished":	{"JJ"},
"overfish":	{"VB","VBP"},
"overfished":	{"VBD","VBN"},
"overfishes":	{"VBZ"},
"overfishing":	{"VBG","NN"},
"overfit":	{"JJ"},
"overflew":	{"VBD"},
"overflies":	{"VBZ"},
"overflight":	{"NN"},
"overflights":	{"NNS"},
"overflood":	{"VB","VBP","NN"},
"overflooded":	{"VBD","VBN"},
"overflooding":	{"VBG"},
"overfloods":	{"VBZ","NNS"},
"overflourish":	{"VB","VBP"},
"overflourished":	{"VBD","VBN"},
"overflourishes":	{"VBZ"},
"overflourishing":	{"VBG"},
"overflow":	{"NN","VB","VBP"},
"overflowed":	{"VBD","VBN"},
"overflowing":	{"JJ","VBG"},
"overflowingly":	{"RB"},
"overflown":	{"VBN"},
"overflows":	{"NNS","VBZ"},
"overflush":	{"JJ"},
"overfly":	{"VB","VBP"},
"overflying":	{"VBG"},
"overfond":	{"JJ"},
"overfull":	{"JJ"},
"overfund":	{"VB","VBP"},
"overfunded":	{"VBD","VBN"},
"overfunding":	{"NN","VBG"},
"overfunds":	{"VBZ"},
"overgarment":	{"NN"},
"overgarments":	{"NNS"},
"overgeneralise":	{"VB","VBP"},
"overgeneralised":	{"VBD","VBN"},
"overgeneralises":	{"VBZ"},
"overgeneralising":	{"VBG"},
"overgeneralization":	{"NN"},
"overgeneralize":	{"VB","VBP"},
"overgeneralized":	{"VBD","VBN"},
"overgeneralizes":	{"VBZ"},
"overgeneralizing":	{"VBG"},
"overgenerous":	{"JJ"},
"overgorge":	{"VB","VBP"},
"overgorged":	{"VBD","VBN"},
"overgorges":	{"VBZ"},
"overgorging":	{"VBG"},
"overgraze":	{"VB","VBP"},
"overgrazed":	{"VBD","VBN"},
"overgrazes":	{"VBZ"},
"overgrazing":	{"NN","VBG"},
"overgreedy":	{"JJ"},
"overgrew":	{"VBD"},
"overgrow":	{"VB","VBP"},
"overgrowing":	{"VBG"},
"overgrown":	{"VBN","JJ"},
"overgrows":	{"VBZ"},
"overgrowth":	{"NN"},
"overhand":	{"JJ","RB","NN","VB","VBP"},
"overhanded":	{"JJ","VBD","VBN"},
"overhanding":	{"VBG"},
"overhands":	{"VBZ"},
"overhang":	{"NN","VB","VBP"},
"overhanging":	{"VBG"},
"overhangs":	{"NNS","VBZ"},
"overharvesting":	{"NN"},
"overhasty":	{"JJ"},
"overhaul":	{"NN","VB","VBP"},
"overhauled":	{"VBD","VBN"},
"overhauling":	{"VBG"},
"overhauls":	{"VBZ","NNS"},
"overhead":	{"JJ","RB","NN"},
"overheads":	{"NNS"},
"overhear":	{"VB","VBP"},
"overheard":	{"VBD","VBN"},
"overhearing":	{"VBG"},
"overhears":	{"VBZ"},
"overheat":	{"VB","VBP"},
"overheated":	{"JJ","VBD","VBN"},
"overheating":	{"VBG"},
"overheats":	{"VBZ"},
"overhung":	{"VBD","VBN"},
"overhype":	{"VB","VBP"},
"overhyped":	{"VBD","VBN","JJ"},
"overhypes":	{"VBZ"},
"overhyping":	{"VBG"},
"overinclusion":	{"NN"},
"overindebtedness":	{"NN"},
"overindulge":	{"VB","VBP"},
"overindulged":	{"VBD","VBN"},
"overindulgence":	{"NN"},
"overindulgent":	{"JJ"},
"overindulges":	{"VBZ"},
"overindulging":	{"VBG"},
"overinsistent":	{"JJ"},
"overinvest":	{"VB","VBP"},
"overinvested":	{"JJ","VBD","VBN"},
"overinvesting":	{"VBG"},
"overinvests":	{"VBZ"},
"overjealous":	{"JJ"},
"overjoy":	{"VB","VBP"},
"overjoyed":	{"JJ","VBD","VBN"},
"overjoying":	{"VBG"},
"overjoys":	{"VBZ"},
"overkill":	{"NN","VB","VBP"},
"overkilled":	{"VBD","VBN"},
"overkilling":	{"VBG"},
"overkills":	{"VBZ"},
"overladen":	{"JJ"},
"overlaid":	{"VBN","VBD"},
"overlain":	{"VBN"},
"overland":	{"JJ","RB"},
"overlap":	{"VB","NN","VBP"},
"overlapped":	{"VBN","VBD"},
"overlapping":	{"VBG"},
"overlaps":	{"VBZ","NNS"},
"overlarge":	{"JJ"},
"overlay":	{"NN","VB","VBP","VBD"},
"overlayer":	{"NN"},
"overlaying":	{"VBG"},
"overlays":	{"NNS","VBZ"},
"overleaf":	{"RB"},
"overleap":	{"VB","VBP"},
"overleaped":	{"VBD","VBN"},
"overleaping":	{"VBG"},
"overleaps":	{"VBZ"},
"overleapt":	{"VBD","VBN"},
"overleverage":	{"NN","VB","VBP"},
"overleveraged":	{"JJ","VBD","VBN"},
"overleverages":	{"VBZ"},
"overleveraging":	{"VBG"},
"overlie":	{"VB","VBP"},
"overlies":	{"VBZ"},
"overlip":	{"NN"},
"overload":	{"VB","VBP","NN"},
"overloaded":	{"JJ","VBD","VBN"},
"overloading":	{"VBG"},
"overloads":	{"VBZ"},
"overlong":	{"JJ"},
"overlook":	{"VB","NN","VBP"},
"overlooked":	{"VBD","VBN"},
"overlooking":	{"VBG"},
"overlooks":	{"VBZ","NNS"},
"overlord":	{"NN"},
"overlords":	{"NNS"},
"overlordship":	{"NN"},
"overloud":	{"JJ","RB"},
"overly":	{"RB"},
"overlying":	{"VBG","JJ"},
"overmantel":	{"NN"},
"overmaster":	{"VB","VBP"},
"overmastered":	{"VBD","VBN"},
"overmastering":	{"VBG"},
"overmasters":	{"VBZ"},
"overmatch":	{"VB","VBP"},
"overmatched":	{"VBD","VBN"},
"overmatches":	{"VBZ"},
"overmatching":	{"VBG"},
"overmedicate":	{"VB","VBP"},
"overmedicated":	{"VBD","VBN"},
"overmedicates":	{"VBZ"},
"overmedicating":	{"VBG"},
"overmighty":	{"JJ"},
"overmodest":	{"JJ"},
"overmuch":	{"RB"},
"overmuchness":	{"NN"},
"overnice":	{"JJ"},
"overnight":	{"JJ","RB","VB","VBP","NN"},
"overnighted":	{"VBD","VBN"},
"overnighter":	{"NN"},
"overnighters":	{"NNS"},
"overnighting":	{"VBG"},
"overnights":	{"VBZ","NNS"},
"overoccupied":	{"JJ"},
"overoptimistic":	{"JJ"},
"overpaid":	{"JJ","VBD","VBN"},
"overpass":	{"NN","VB","VBP"},
"overpassed":	{"VBD","VBN"},
"overpasses":	{"VBZ"},
"overpassing":	{"VBG"},
"overpay":	{"VB","VBP"},
"overpaying":	{"VBG"},
"overpayment":	{"NN"},
"overpayments":	{"NNS"},
"overpays":	{"VBZ"},
"overplant":	{"VB","VBP"},
"overplanted":	{"VBD","VBN"},
"overplanting":	{"VBG"},
"overplants":	{"VBZ"},
"overplay":	{"VB","VBP"},
"overplayed":	{"VBD","VBN"},
"overplaying":	{"VBG"},
"overplays":	{"VBZ"},
"overplus":	{"NN"},
"overpopulate":	{"VB","VBP"},
"overpopulated":	{"VBD","VBN","JJ"},
"overpopulates":	{"VBZ"},
"overpopulating":	{"VBG"},
"overpopulation":	{"NN"},
"overpower":	{"VB","VBP"},
"overpowered":	{"VBD","VBN"},
"overpowering":	{"JJ","VBG"},
"overpoweringly":	{"RB"},
"overpowers":	{"VBZ"},
"overpraise":	{"VB","VBP"},
"overpraised":	{"VBD","VBN"},
"overpraises":	{"VBZ"},
"overpraising":	{"VBG"},
"overpressure":	{"NN"},
"overprice":	{"VB","VBP"},
"overpriced":	{"VBD","VBN","JJ"},
"overprices":	{"VBZ"},
"overpricing":	{"VBG"},
"overprint":	{"NN","VB","VBP"},
"overprinted":	{"VBD","VBN"},
"overprinting":	{"VBG"},
"overprints":	{"NNS","VBZ"},
"overproduce":	{"VB","VBP"},
"overproduced":	{"VBD","VBN"},
"overproducer":	{"NN"},
"overproducers":	{"NNS"},
"overproduces":	{"VBZ"},
"overproducing":	{"VBG"},
"overproduction":	{"NN"},
"overprotect":	{"VB","VBP"},
"overprotected":	{"VBD","VBN"},
"overprotecting":	{"VBG"},
"overprotection":	{"NN"},
"overprotective":	{"JJ"},
"overprotects":	{"VBZ"},
"overproud":	{"JJ"},
"overpurchased":	{"VBD","VBN"},
"overpurchases":	{"VBZ"},
"overpurchasing":	{"VBG"},
"overran":	{"VBD"},
"overrate":	{"VB","VBP"},
"overrated":	{"VBD","VBN","JJ"},
"overrates":	{"VBZ"},
"overrating":	{"VBG"},
"overreach":	{"VB","VBP"},
"overreached":	{"VBD","VBN"},
"overreaches":	{"VBZ"},
"overreaching":	{"VBG"},
"overreact":	{"VB","VBP"},
"overreacted":	{"VBD","VBN"},
"overreacting":	{"VBG"},
"overreaction":	{"NN"},
"overreacts":	{"VBZ"},
"overreckoning":	{"NN"},
"overrefine":	{"VB","VBP"},
"overrefined":	{"JJ","VBD","VBN"},
"overrefinement":	{"NN"},
"overrefines":	{"VBZ"},
"overrefining":	{"VBG"},
"overregulate":	{"VB","VBP"},
"overregulated":	{"VBD","VBN"},
"overregulates":	{"VBZ"},
"overregulating":	{"VBG"},
"overregulation":	{"NN"},
"overridden":	{"VBN"},
"override":	{"VB","VBP","NN"},
"overrides":	{"VBZ","NNS"},
"overriding":	{"JJ","VBG"},
"overripe":	{"JJ","NN"},
"overrode":	{"VBD"},
"overrule":	{"VB","VBP"},
"overruled":	{"VBD","VBN"},
"overrules":	{"VBZ"},
"overruling":	{"VBG"},
"overrun":	{"VB","VBP","NN","VBN"},
"overrunning":	{"VBG"},
"overruns":	{"NNS","VBZ"},
"overs":	{"NNS","VBZ"},
"oversaturate":	{"VB","VBP"},
"oversaturated":	{"VBD","VBN"},
"oversaturates":	{"VBZ"},
"oversaturating":	{"VBG"},
"oversaw":	{"VBD"},
"overscrupulous":	{"JJ"},
"oversea":	{"JJ","RB"},
"overseas":	{"JJ","RB"},
"oversee":	{"VB","VBP"},
"overseeing":	{"VBG"},
"overseen":	{"VBN","NN"},
"overseer":	{"NN"},
"overseers":	{"NNS"},
"oversees":	{"VBZ"},
"oversell":	{"VB","VBP"},
"overselling":	{"VBG"},
"oversells":	{"VBZ"},
"oversensitive":	{"JJ"},
"oversensitiveness":	{"NN"},
"overserious":	{"JJ"},
"oversew":	{"VB","VBP"},
"oversewed":	{"VBD","VBN"},
"oversewing":	{"VBG"},
"oversewn":	{"VBN"},
"oversews":	{"VBZ"},
"oversexed":	{"JJ"},
"overshadow":	{"VB","VBP"},
"overshadowed":	{"VBD","VBN"},
"overshadowing":	{"VBG"},
"overshadows":	{"VBZ"},
"overshare":	{"VB","VBP"},
"overshared":	{"VBD","VBN"},
"overshares":	{"VBZ"},
"oversharing":	{"VBG"},
"oversharp":	{"JJ"},
"overshielding":	{"NN"},
"overshine":	{"VB","VBP"},
"overshines":	{"VBZ"},
"overshining":	{"VBG"},
"overshirt":	{"NN"},
"overshirts":	{"NNS"},
"overshoe":	{"NN"},
"overshoes":	{"NNS"},
"overshone":	{"VBD","VBN"},
"overshoot":	{"VB","VBP","NN"},
"overshooting":	{"VBG"},
"overshoots":	{"VBZ","NNS"},
"overshot":	{"VBD","VBN"},
"overshower":	{"VB","VBP"},
"overshowered":	{"VBD","VBN"},
"overshowering":	{"VBG"},
"overshowers":	{"VBZ"},
"oversick":	{"JJ"},
"overside":	{"RB"},
"oversight":	{"NN"},
"oversights":	{"NNS"},
"oversimple":	{"JJ"},
"oversimplification":	{"NN"},
"oversimplifications":	{"NNS"},
"oversimplified":	{"VBN","JJ","VBD"},
"oversimplifies":	{"VBZ"},
"oversimplify":	{"VB","VBP"},
"oversimplifying":	{"VBG"},
"oversimplistic":	{"JJ"},
"oversimply":	{"RB"},
"oversize":	{"JJ","NN"},
"oversized":	{"JJ"},
"overskip":	{"VB","VBP"},
"overskipped":	{"VBD","VBN"},
"overskipping":	{"VBG"},
"overskips":	{"VBZ"},
"overskirt":	{"NN"},
"overskirts":	{"NNS"},
"overslaugh":	{"NN","VB","VBP"},
"overslaughed":	{"VBD","VBN"},
"overslaughing":	{"VBG"},
"overslaughs":	{"NNS","VBZ"},
"oversleep":	{"VB","VBP"},
"oversleeping":	{"VBG"},
"oversleeps":	{"VBZ"},
"oversleeve":	{"NN"},
"oversleeves":	{"NNS"},
"overslept":	{"VBD","VBN"},
"overslip":	{"VB","VBP"},
"overslipped":	{"VBD","VBN"},
"overslipping":	{"VBG"},
"overslips":	{"VBZ"},
"overslow":	{"JJ"},
"overslowly":	{"RB"},
"oversman":	{"NN"},
"oversmen":	{"NNS"},
"oversmoke":	{"VB","VBP"},
"oversmoked":	{"VBD","VBN"},
"oversmokes":	{"VBZ"},
"oversmoking":	{"VBG"},
"oversoak":	{"VB","VBP"},
"oversoaked":	{"VBD","VBN"},
"oversoaking":	{"VBG"},
"oversoaks":	{"VBZ"},
"oversoft":	{"JJ"},
"oversoftness":	{"NN"},
"oversold":	{"JJ","VBD","VBN"},
"oversolicitous":	{"JJ"},
"oversoon":	{"RB"},
"oversoul":	{"NN"},
"oversouls":	{"NNS"},
"oversow":	{"VB","VBP"},
"oversowed":	{"VBD"},
"oversowing":	{"VBG"},
"oversown":	{"VBN"},
"oversows":	{"VBZ"},
"overspecialisation":	{"NN"},
"overspecialise":	{"VB","VBP"},
"overspecialised":	{"VBD","VBN"},
"overspecialises":	{"VBZ"},
"overspecialising":	{"VBG"},
"overspecialization":	{"NN"},
"overspecialize":	{"VB","VBP"},
"overspecialized":	{"VBD","VBN"},
"overspecializes":	{"VBZ"},
"overspecializing":	{"VBG"},
"overspeculate":	{"VB","VBP"},
"overspeculated":	{"VBD","VBN"},
"overspeculates":	{"VBZ"},
"overspeculating":	{"VBG"},
"overspeculation":	{"NN"},
"overspend":	{"VB","VBP","NN"},
"overspender":	{"NN"},
"overspenders":	{"NNS"},
"overspending":	{"VBG","NN"},
"overspends":	{"VBZ","NNS"},
"overspent":	{"VBD","VBN"},
"overspice":	{"VB","VBP"},
"overspiced":	{"VBD","VBN"},
"overspices":	{"VBZ"},
"overspicing":	{"VBG"},
"overspill":	{"NN","VB","VBP"},
"overspilled":	{"VBD","VBN"},
"overspilling":	{"VBG"},
"overspills":	{"VBZ"},
"overspilt":	{"VBD","VBN"},
"overspin":	{"NN"},
"overspread":	{"VB","VBP","VBD","VBN"},
"overspreading":	{"VBG"},
"overspreads":	{"VBZ"},
"oversquare":	{"JJ"},
"overstability":	{"NN"},
"overstaff":	{"VB","VBP"},
"overstaffed":	{"JJ","VBD","VBN"},
"overstaffing":	{"VBG","NN"},
"overstaffs":	{"VBZ"},
"overstain":	{"VB","VBP"},
"overstained":	{"VBD","VBN"},
"overstaining":	{"VBG"},
"overstains":	{"VBZ"},
"overstand":	{"VB","VBP"},
"overstanding":	{"VBG"},
"overstands":	{"VBZ"},
"overstank":	{"VBD"},
"overstare":	{"VB","VBP"},
"overstared":	{"VBD","VBN"},
"overstares":	{"VBZ"},
"overstaring":	{"VBG"},
"overstate":	{"VB","VBP"},
"overstated":	{"VBD","VBN","JJ"},
"overstatement":	{"NN"},
"overstatements":	{"NNS"},
"overstates":	{"VBZ"},
"overstating":	{"VBG"},
"overstay":	{"VB","VBP"},
"overstayed":	{"VBD","VBN"},
"overstayer":	{"NN"},
"overstayers":	{"NNS"},
"overstaying":	{"VBG"},
"overstays":	{"VBZ"},
"oversteer":	{"VB","VBP","NN"},
"oversteered":	{"VBD","VBN"},
"oversteering":	{"VBG"},
"oversteers":	{"VBZ","NNS"},
"overstep":	{"VB","VBP"},
"overstepped":	{"VBD","VBN"},
"overstepping":	{"VBG"},
"oversteps":	{"VBZ"},
"overstimulate":	{"VB","VBP"},
"overstimulated":	{"VBD","VBN"},
"overstimulates":	{"VBZ"},
"overstimulating":	{"VBG"},
"overstimulation":	{"NN"},
"overstink":	{"VB","VBP"},
"overstinking":	{"VBG"},
"overstinks":	{"VBZ"},
"overstir":	{"VB","VBP"},
"overstirred":	{"VBD","VBN"},
"overstirring":	{"VBG"},
"overstirs":	{"VBZ"},
"overstitch":	{"NN","VB","VBP"},
"overstitched":	{"VBD","VBN"},
"overstitches":	{"NNS","VBZ"},
"overstitching":	{"VBG"},
"overstock":	{"VB","VBP","NN"},
"overstocked":	{"VBD","VBN","JJ"},
"overstocking":	{"VBG"},
"overstocks":	{"VBZ"},
"overstood":	{"VBD","VBN"},
"overstore":	{"VB","VBP"},
"overstored":	{"VBD","VBN"},
"overstores":	{"VBZ"},
"overstorey":	{"NN"},
"overstoreys":	{"NNS"},
"overstories":	{"NNS"},
"overstoring":	{"VBG"},
"overstory":	{"NN"},
"overstrain":	{"VB","VBP"},
"overstrained":	{"VBD","VBN","JJ"},
"overstraining":	{"VBG"},
"overstrains":	{"VBZ"},
"overstress":	{"VB","VBP"},
"overstressed":	{"VBD","VBN"},
"overstresses":	{"VBZ"},
"overstressing":	{"VBG"},
"overstretch":	{"VB","VBP"},
"overstretched":	{"VBD","VBN","JJ"},
"overstretches":	{"VBZ"},
"overstretching":	{"VBG"},
"overstrew":	{"VB","VBP"},
"overstrewed":	{"VBD","VBN"},
"overstrewing":	{"VBG"},
"overstrewn":	{"VBN","JJ"},
"overstrews":	{"VBZ"},
"overstrict":	{"JJ"},
"overstridden":	{"VBN"},
"overstride":	{"VB","VBP"},
"overstrides":	{"VBZ"},
"overstriding":	{"VBG"},
"overstrike":	{"VB","VBP"},
"overstrikes":	{"VBZ"},
"overstriking":	{"VBG"},
"overstrode":	{"VBD"},
"overstrong":	{"JJ"},
"overstruck":	{"VBD","VBN"},
"overstructured":	{"JJ"},
"overstrung":	{"JJ"},
"overstudied":	{"VBD","VBN"},
"overstudies":	{"VBZ"},
"overstudy":	{"VB","VBP","NN"},
"overstudying":	{"VBG"},
"overstuff":	{"VB","VBP"},
"overstuffed":	{"VBD","VBN","JJ"},
"overstuffing":	{"VBG"},
"overstuffs":	{"VBZ"},
"overstunk":	{"VBN"},
"oversubscribe":	{"VB","VBP"},
"oversubscribed":	{"VBD","VBN","JJ"},
"oversubscribes":	{"VBZ"},
"oversubscribing":	{"VBG"},
"oversubscription":	{"NN"},
"oversubscriptions":	{"NNS"},
"oversubtle":	{"JJ"},
"oversubtlety":	{"NN"},
"oversup":	{"VB","VBP"},
"oversupped":	{"VBD","VBN"},
"oversupping":	{"VBG"},
"oversupplied":	{"VBD","VBN"},
"oversupplies":	{"VBZ","NNS"},
"oversupply":	{"VB","VBP","NN"},
"oversupplying":	{"VBG"},
"oversups":	{"VBZ"},
"oversure":	{"JJ"},
"oversuspicious":	{"JJ"},
"overswam":	{"VBD"},
"oversway":	{"VB","VBP"},
"overswayed":	{"VBD","VBN"},
"overswaying":	{"VBG"},
"oversways":	{"VBZ"},
"overswear":	{"VB","VBP"},
"overswearing":	{"VBG"},
"overswears":	{"VBZ"},
"oversweet":	{"JJ"},
"oversweeten":	{"VB","VBP"},
"oversweetened":	{"VBD","VBN"},
"oversweetening":	{"VBG"},
"oversweetens":	{"VBZ"},
"oversweetness":	{"NN"},
"overswell":	{"VB","VBP"},
"overswelled":	{"VBD","VBN"},
"overswelling":	{"VBG"},
"overswells":	{"VBZ"},
"overswim":	{"VB","VBP"},
"overswimming":	{"VBG"},
"overswims":	{"VBZ"},
"overswing":	{"VB","VBP"},
"overswinging":	{"VBG"},
"overswings":	{"VBZ"},
"overswollen":	{"VBN","JJ"},
"overswore":	{"VBD"},
"oversworn":	{"VBN"},
"overswum":	{"VBN"},
"overswung":	{"VBD","VBN"},
"overt":	{"JJ"},
"overtake":	{"VB","VBP"},
"overtaken":	{"VBN"},
"overtakes":	{"VBZ"},
"overtaking":	{"NN","VBG"},
"overtalk":	{"VB","VBP"},
"overtalkative":	{"JJ"},
"overtalked":	{"VBD","VBN"},
"overtalking":	{"VBG"},
"overtalks":	{"VBZ"},
"overtame":	{"JJ"},
"overtart":	{"JJ"},
"overtask":	{"VB","VBP"},
"overtasked":	{"VBD","VBN"},
"overtasking":	{"VBG"},
"overtasks":	{"VBZ"},
"overtaught":	{"VBD","VBN","JJ"},
"overtax":	{"VB","VBP"},
"overtaxation":	{"NN"},
"overtaxed":	{"VBD","VBN","JJ"},
"overtaxex":	{"VBZ"},
"overtaxing":	{"VBG"},
"overteach":	{"VB","VBP"},
"overteaching":	{"VBG"},
"overteachs":	{"VBZ"},
"overtedious":	{"JJ"},
"overteem":	{"VB","VBP"},
"overteemed":	{"VBD","VBN"},
"overteeming":	{"VBG"},
"overteems":	{"VBZ"},
"overthick":	{"JJ"},
"overthin":	{"JJ"},
"overthink":	{"VB","VBP"},
"overthinking":	{"VBG"},
"overthinks":	{"VBZ"},
"overthought":	{"VBD","VBN"},
"overthrew":	{"VBD"},
"overthrow":	{"VB","VBP","NN"},
"overthrower":	{"NN"},
"overthrowers":	{"NNS"},
"overthrowing":	{"NN","VBG"},
"overthrown":	{"VBN"},
"overthrows":	{"VBZ"},
"overthrust":	{"NN"},
"overthrusts":	{"NNS"},
"overthwart":	{"VB","VBP","IN","JJ"},
"overtight":	{"JJ"},
"overtighten":	{"VB","VBP"},
"overtightened":	{"VBD","VBN"},
"overtightening":	{"VBG"},
"overtightens":	{"VBZ"},
"overtime":	{"NN","JJ","RB","VB","VBP"},
"overtimed":	{"VBD","VBN"},
"overtimely":	{"RB"},
"overtimer":	{"NN"},
"overtimers":	{"NNS"},
"overtimes":	{"NNS","VBZ"},
"overtimid":	{"JJ"},
"overtiming":	{"VBG"},
"overtip":	{"VB","VBP"},
"overtipped":	{"VBD","VBN"},
"overtipping":	{"VBG"},
"overtips":	{"VBZ"},
"overtire":	{"VB","VBP"},
"overtired":	{"VBD","VBN","JJ"},
"overtires":	{"VBZ"},
"overtiring":	{"VBG"},
"overtly":	{"RB"},
"overtoil":	{"VB","VBP"},
"overtoiled":	{"VBD","VBN"},
"overtoiling":	{"VBG"},
"overtoils":	{"VBZ"},
"overtolerance":	{"NN"},
"overtone":	{"NN"},
"overtones":	{"NNS"},
"overtook":	{"VBD"},
"overtop":	{"VB","VBP"},
"overtopped":	{"VBD","VBN"},
"overtopping":	{"VBG"},
"overtops":	{"VBZ"},
"overtower":	{"VB","VBP"},
"overtowered":	{"VBD","VBN"},
"overtowering":	{"VBG"},
"overtowers":	{"VBZ"},
"overtrade":	{"VB","VBP"},
"overtraded":	{"VBD","VBN"},
"overtrades":	{"VBZ"},
"overtrading":	{"VBG"},
"overtrain":	{"VB","VBP"},
"overtrained":	{"VBD","VBN"},
"overtraining":	{"VBG"},
"overtrains":	{"VBZ"},
"overtreat":	{"VB","VBP"},
"overtreated":	{"VBD","VBN"},
"overtreating":	{"VBG"},
"overtreatment":	{"NN"},
"overtreatments":	{"NNS"},
"overtreats":	{"VBZ"},
"overtrick":	{"NN"},
"overtricks":	{"NNS"},
"overtrim":	{"VB","VBP"},
"overtrimmed":	{"VBD","VBN"},
"overtrimming":	{"VBG"},
"overtrims":	{"VBZ"},
"overtrump":	{"VB","VBP"},
"overtrumped":	{"VBD","VBN"},
"overtrumping":	{"VBG"},
"overtrumps":	{"VBZ"},
"overtrust":	{"VB","VBP"},
"overtrusted":	{"VBD","VBN"},
"overtrusting":	{"VBG"},
"overtrusts":	{"VBZ"},
"overture":	{"NN"},
"overtures":	{"NNS"},
"overturn":	{"VB","VBP"},
"overturned":	{"VBD","VBN"},
"overturner":	{"NN"},
"overturners":	{"NNS"},
"overturning":	{"VBG"},
"overturns":	{"VBZ"},
"overtype":	{"VB","VBP"},
"overtyped":	{"VBD","VBN"},
"overtypes":	{"VBZ"},
"overtyping":	{"VBG"},
"overurge":	{"VB","VBP"},
"overurged":	{"VBD","VBN"},
"overurges":	{"VBZ"},
"overurging":	{"VBG"},
"overuse":	{"NN","VB","VBP"},
"overused":	{"VBD","VBN","JJ"},
"overuses":	{"VBZ"},
"overusing":	{"VBG"},
"overutilisation":	{"NN"},
"overutilise":	{"VB","VBP"},
"overutilised":	{"VBD","VBN"},
"overutilises":	{"VBZ"},
"overutilising":	{"VBG"},
"overutilization":	{"NN"},
"overutilize":	{"VB","VBP"},
"overutilized":	{"VBD","VBN"},
"overutilizes":	{"VBZ"},
"overutilizing":	{"VBG"},
"overvaliant":	{"JJ"},
"overvaluation":	{"NN"},
"overvalue":	{"VB","VBP"},
"overvalued":	{"VBN","JJ","VBD"},
"overvalues":	{"VBZ"},
"overvaluing":	{"VBG"},
"overvaulting":	{"JJ"},
"overveil":	{"VB","VBP"},
"overveiled":	{"VBD","VBN"},
"overveiling":	{"VBG"},
"overveils":	{"VBZ"},
"overview":	{"NN"},
"overviews":	{"NNS"},
"overviolent":	{"JJ"},
"overvivid":	{"JJ"},
"overvoltage":	{"NN"},
"overvoltages":	{"NNS"},
"overvote":	{"VB","VBP","NN"},
"overvoted":	{"VBD","VBN"},
"overvotes":	{"VBZ","NNS"},
"overvoting":	{"VBG"},
"overwarm":	{"VB","VBP"},
"overwarmed":	{"VBD","VBN"},
"overwarming":	{"VBG"},
"overwarms":	{"VBZ"},
"overwary":	{"JJ"},
"overwash":	{"NN","VB","VBP"},
"overwashed":	{"VBD","VBN"},
"overwashes":	{"VBZ"},
"overwashing":	{"VBG"},
"overwatch":	{"VB","VBP"},
"overwatched":	{"VBD","VBN"},
"overwatches":	{"VBZ"},
"overwatching":	{"VBG"},
"overwater":	{"VB","VBP"},
"overwatered":	{"VBD","VBN"},
"overwatering":	{"VBG"},
"overwaters":	{"VBZ"},
"overweak":	{"JJ"},
"overwear":	{"VB","VBP"},
"overwearied":	{"VBD","VBN"},
"overwearies":	{"VBZ"},
"overwearing":	{"VBG"},
"overwears":	{"VBZ"},
"overweary":	{"VB","VBP"},
"overwearying":	{"VBG"},
"overweather":	{"VB","VBP"},
"overweathered":	{"VBD","VBN"},
"overweathering":	{"VBG"},
"overweathers":	{"VBZ"},
"overween":	{"VB","VBP"},
"overweened":	{"VBD","VBN"},
"overweening":	{"VBG","JJ"},
"overweeningly":	{"RB"},
"overweeningness":	{"NN"},
"overweens":	{"VBZ"},
"overweigh":	{"VB","VBP"},
"overweighed":	{"VBD","VBN"},
"overweighing":	{"VBG"},
"overweighs":	{"VBZ"},
"overweight":	{"JJ","NN","VB","VBP"},
"overweighted":	{"VBN","VBD","JJ"},
"overweighting":	{"VBG"},
"overweights":	{"VBZ"},
"overwet":	{"VB","VBP","VBD","VBN"},
"overwets":	{"VBZ"},
"overwetted":	{"VBD","VBN"},
"overwetting":	{"VBG"},
"overwhelm":	{"VB","VBP"},
"overwhelmed":	{"VBN","JJ","VBD"},
"overwhelming":	{"JJ","VBG"},
"overwhelmingly":	{"RB"},
"overwhelms":	{"VBZ"},
"overwide":	{"JJ"},
"overwily":	{"JJ"},
"overwind":	{"VB","VBP"},
"overwinding":	{"VBG"},
"overwinds":	{"VBZ"},
"overwing":	{"VB","VBP","JJ"},
"overwinged":	{"VBD","VBN"},
"overwinging":	{"VBG"},
"overwings":	{"VBZ"},
"overwinter":	{"VB","VBP","JJ"},
"overwintered":	{"VBD","VBN"},
"overwintering":	{"VBG"},
"overwinters":	{"VBZ"},
"overwise":	{"JJ"},
"overwisely":	{"RB"},
"overwithheld":	{"VBD","VBN"},
"overwithhold":	{"VB","VBP"},
"overwithholding":	{"VBG"},
"overwithholds":	{"VBZ"},
"overword":	{"NN","VB","VBP"},
"overworded":	{"VBD","VBN"},
"overwording":	{"VBG"},
"overwords":	{"NNS","VBZ"},
"overwore":	{"VBD"},
"overwork":	{"NN","VB","VBP"},
"overworked":	{"JJ","VBD","VBN"},
"overworking":	{"VBG"},
"overworks":	{"VBZ"},
"overworn":	{"VBN"},
"overwound":	{"VBD","VBN","JJ"},
"overwrap":	{"VB","VBP"},
"overwrapped":	{"VBD","VBN"},
"overwrapping":	{"VBG"},
"overwraps":	{"VBZ"},
"overwrest":	{"VB","VBP"},
"overwrested":	{"VBD","VBN"},
"overwresting":	{"VBG"},
"overwrestle":	{"VB","VBP"},
"overwrestled":	{"VBD","VBN"},
"overwrestles":	{"VBZ"},
"overwrestling":	{"VBG"},
"overwrests":	{"VBZ"},
"overwrite":	{"VB","VBP"},
"overwrites":	{"VBZ"},
"overwriting":	{"VBG"},
"overwritten":	{"VBN"},
"overwrote":	{"VBD"},
"overwrought":	{"JJ"},
"overzeal":	{"NN"},
"overzealous":	{"JJ"},
"overzealously":	{"RB"},
"overzealousness":	{"NN"},
"ovibos":	{"NNS"},
"oviduct":	{"NN"},
"oviductal":	{"JJ"},
"oviducts":	{"NNS"},
"oviedo":	{"NN"},
"oviform":	{"JJ"},
"ovimbundu":	{"NN"},
"ovine":	{"JJ"},
"oviparous":	{"JJ"},
"ovipositor":	{"NN"},
"oviraptorid":	{"NN"},
"ovis":	{"NN"},
"ovocon":	{"NN"},
"ovoflavin":	{"NN"},
"ovoid":	{"JJ","NN"},
"ovoids":	{"NNS"},
"ovolo":	{"NN"},
"ovotestis":	{"NN"},
"ovoviviparous":	{"JJ"},
"ovral":	{"NN"},
"ovrette":	{"NN"},
"ovular":	{"JJ"},
"ovulate":	{"VB","VBP"},
"ovulated":	{"VBD","VBN"},
"ovulates":	{"VBZ"},
"ovulating":	{"VBG"},
"ovulation":	{"NN"},
"ovule":	{"NN"},
"ovulen":	{"NN"},
"ovum":	{"NN"},
"owe":	{"VB","VBP"},
"owed":	{"VBN","VBD"},
"owensboro":	{"NN"},
"owes":	{"VBZ"},
"owing":	{"JJ","VBG"},
"owl":	{"NN"},
"owl-shaped":	{"JJ"},
"owlclaw":	{"NN"},
"owlclaws":	{"NNS"},
"owlet":	{"NN"},
"owlets":	{"NNS"},
"owlish":	{"JJ"},
"owlishly":	{"RB"},
"owls":	{"NNS"},
"owlt":	{"NN"},
"own":	{"JJ","VB","VBP","PRP"},
"owne":	{"JJ"},
"owned":	{"VBN","VBD","JJ"},
"owner":	{"NN"},
"owner-bred":	{"JJ"},
"owner-driver":	{"NN"},
"owner-occupied":	{"JJ"},
"owner-occupier":	{"NN"},
"owner-occupiers":	{"NNS"},
"ownerless":	{"JJ"},
"owners":	{"NNS"},
"ownership":	{"NN"},
"ownerships":	{"NNS"},
"owning":	{"VBG"},
"owns":	{"VBZ"},
"ox":	{"NN"},
"ox-eyed":	{"JJ"},
"oxacillin":	{"NN"},
"oxalacetate":	{"NN"},
"oxalate":	{"NN"},
"oxalidaceae":	{"NN"},
"oxalis":	{"NNS"},
"oxaloacetate":	{"NN"},
"oxaloacetic":	{"JJ"},
"oxandra":	{"NN"},
"oxaprozin":	{"NN"},
"oxazepam":	{"NN"},
"oxbow":	{"NN"},
"oxcart":	{"NN"},
"oxcarts":	{"NNS"},
"oxen":	{"NNS"},
"oxeye":	{"NN"},
"oxford":	{"NN"},
"oxford-gray":	{"JJ"},
"oxford-grey":	{"JJ"},
"oxheart":	{"NN"},
"oxidant":	{"NN"},
"oxidase":	{"NN"},
"oxidate":	{"VB","VBP"},
"oxidated":	{"VBD","VBN"},
"oxidates":	{"VBZ"},
"oxidating":	{"VBG"},
"oxidation":	{"NN"},
"oxidation-reduction":	{"NN"},
"oxidative":	{"JJ"},
"oxide":	{"NN"},
"oxides":	{"NNS"},
"oxidisation":	{"NN"},
"oxidise":	{"VB","VBP"},
"oxidised":	{"JJ","VBD","VBN"},
"oxidiser":	{"NN"},
"oxidises":	{"VBZ"},
"oxidising":	{"VBG"},
"oxidizable":	{"JJ"},
"oxidization":	{"NN"},
"oxidize":	{"VB","VBP"},
"oxidized":	{"VBD","VBN"},
"oxidizer":	{"NN"},
"oxidizes":	{"VBZ"},
"oxidizing":	{"VBG"},
"oxidoreductase":	{"NN"},
"oxidoreduction":	{"NN"},
"oxime":	{"NN"},
"oximeter":	{"NN"},
"oxlip":	{"NN"},
"oxonian":	{"JJ","NN"},
"oxtail":	{"NN"},
"oxtails":	{"NNS"},
"oxtant":	{"NN"},
"oxtongue":	{"NN"},
"oxyacetylene":	{"NN"},
"oxyacid":	{"NN"},
"oxybelis":	{"NN"},
"oxybenzene":	{"NN"},
"oxycephaly":	{"NN"},
"oxycodone":	{"NN"},
"oxydendrum":	{"NN"},
"oxygen":	{"NN"},
"oxygenase":	{"NN"},
"oxygenate":	{"VB","VBP"},
"oxygenated":	{"VBD","VBN"},
"oxygenates":	{"VBZ"},
"oxygenating":	{"VBG"},
"oxygenation":	{"NN"},
"oxygenator":	{"NN"},
"oxygenators":	{"NNS"},
"oxygenic":	{"JJ"},
"oxygenise":	{"VB","VBP"},
"oxygenised":	{"VBD","VBN"},
"oxygenises":	{"VBZ"},
"oxygenising":	{"VBG"},
"oxygenize":	{"VB","VBP"},
"oxygenized":	{"VBD","VBN"},
"oxygenizes":	{"VBZ"},
"oxygenizing":	{"VBG"},
"oxygenous":	{"JJ"},
"oxygens":	{"NNS"},
"oxyhaemoglobin":	{"NN"},
"oxyhemoglobin":	{"NN"},
"oxyhydroxides":	{"NNS"},
"oxylebius":	{"NN"},
"oxymoron":	{"NN"},
"oxyopia":	{"NN"},
"oxyphenbutazone":	{"NN"},
"oxyphencyclimine":	{"NN"},
"oxysporum":	{"NN"},
"oxytetracycline":	{"NN"},
"oxytocic":	{"JJ"},
"oxytocin":	{"NN"},
"oxytone":	{"NN"},
"oxytropis":	{"NN"},
"oxyura":	{"NN"},
"oxyuranus":	{"NN"},
"oxyuridae":	{"NN"},
"oyabun":	{"NN"},
"oystchers":	{"NNS"},
"oyster":	{"NN","VB","VBP"},
"oyster-catcher":	{"NN"},
"oyster-catchers":	{"NNS"},
"oyster-fish":	{"NN"},
"oystercatcher":	{"NN"},
"oystercatchers":	{"NNS"},
"oystered":	{"VBD","VBN"},
"oysterfish":	{"NN"},
"oystering":	{"VBG"},
"oysters":	{"NNS","VBZ"},
"oz":	{"NN","NNS"},
"oz.":	{"NN"},
"ozaena":	{"NN"},
"ozagenians":	{"NNS"},
"ozawa":	{"NN"},
"ozena":	{"NN"},
"ozocerite":	{"NN"},
"ozokerite":	{"NN"},
"ozon":	{"NN"},
"ozone":	{"NN"},
"ozone-cancer":	{"JJ"},
"ozone-damaging":	{"JJ"},
"ozone-depleting":	{"JJ"},
"ozone-destroying":	{"JJ"},
"ozone-exposed":	{"JJ"},
"ozone-forming":	{"JJ"},
"ozone-safe":	{"JJ"},
"ozonedepletion":	{"NN"},
"ozonide":	{"NN"},
"ozonisation":	{"NN"},
"ozonise":	{"VB","VBP"},
"ozonised":	{"VBD","VBN"},
"ozoniser":	{"NN"},
"ozonisers":	{"NNS"},
"ozonises":	{"VBZ"},
"ozonising":	{"VBG"},
"ozonium":	{"NN"},
"ozonization":	{"NN"},
"ozonize":	{"VB","VBP"},
"ozonized":	{"VBD","VBN"},
"ozonizer":	{"NN"},
"ozonizers":	{"NNS"},
"ozonizes":	{"VBZ"},
"ozonizing":	{"VBG"},
"ozonosphere":	{"NN"},
"ozothamnus":	{"NN"},
"ozs":	{"NNS"},
"p":	{"NN","SYM","LS"},
"p-aminobenzoic":	{"JJ"},
"p.":	{"NN"},
"p.a.":	{"RB"},
"p.m":	{"RB"},
"p.m.":	{"RB"},
"p.m.-conclusion":	{"NN"},
"p.m.-midnight":	{"NN"},
"pH":	{"NN"},
"pa":	{"NN"},
"pa'anga":	{"NN"},
"paba":	{"NN"},
"pabir":	{"NN"},
"pablum":	{"NN"},
"pabulum":	{"NN"},
"paca":	{"NN"},
"pace":	{"NN","VB","VBP","IN"},
"pace-setter":	{"NN"},
"pace-setters":	{"NNS"},
"paced":	{"VBD","VBN","JJ"},
"pacem":	{"FW"},
"pacemaker":	{"NN"},
"pacemakers":	{"NNS"},
"pacer":	{"NN"},
"pacers":	{"NNS"},
"paces":	{"NNS","VBZ"},
"pacesetter":	{"NN"},
"pacesetters":	{"NNS"},
"pacha":	{"NN"},
"pachinko":	{"NN"},
"pachisi":	{"NN"},
"pachouli":	{"NN"},
"pachuco":	{"NN"},
"pachycephala":	{"NN"},
"pachycephalosaur":	{"NN"},
"pachycephalosaurus":	{"NN"},
"pachycheilia":	{"NN"},
"pachyderm":	{"NN"},
"pachyderma":	{"NN"},
"pachydermal":	{"JJ"},
"pachydermatous":	{"JJ"},
"pachydermic":	{"JJ"},
"pachydermous":	{"JJ"},
"pachyderms":	{"NNS"},
"pachyrhizus":	{"NN"},
"pachysandra":	{"NN"},
"pachytene":	{"NN"},
"pacific":	{"JJ"},
"pacific-listed":	{"JJ"},
"pacifically":	{"RB"},
"pacification":	{"NN"},
"pacificism":	{"NN"},
"pacificist":	{"NN"},
"pacified":	{"VBD","VBN"},
"pacifier":	{"NN"},
"pacifiers":	{"NNS"},
"pacifies":	{"VBZ"},
"pacifism":	{"NN"},
"pacifist":	{"NN","JJ"},
"pacifistic":	{"JJ"},
"pacifistically":	{"RB"},
"pacifists":	{"NNS"},
"pacify":	{"VB","VBP"},
"pacifying":	{"VBG"},
"pacing":	{"NN","VBG"},
"pack":	{"NN","VB","VBP"},
"pack-animal":	{"NN"},
"pack-animals":	{"NNS"},
"pack-ice":	{"NN"},
"pack-saddle":	{"NN"},
"pack-saddles":	{"NNS"},
"packable":	{"JJ"},
"package":	{"NN","VB","VBP"},
"package-delivery":	{"JJ"},
"package-design":	{"NN"},
"package-holiday":	{"JJ"},
"package-sort":	{"JJ"},
"package-sorting":	{"NN"},
"package-tracing":	{"NN"},
"packaged":	{"VBN","VBD","JJ"},
"packaged-goods":	{"NNS","JJ"},
"packages":	{"NNS","VBZ"},
"packaging":	{"NN","VBG"},
"packed":	{"JJ","VBN","VBD"},
"packer":	{"NN"},
"packera":	{"NN"},
"packers":	{"NNS"},
"packet":	{"NN"},
"packet-boat":	{"NN"},
"packet-boats":	{"NNS"},
"packets":	{"NNS"},
"packhorse":	{"NN"},
"packing":	{"NN","VBG"},
"packinghouse":	{"NN"},
"packinghouses":	{"NNS"},
"packman":	{"NN"},
"packmen":	{"NNS"},
"packrat":	{"NN"},
"packs":	{"VBZ","NNS"},
"packsack":	{"NN"},
"packsacks":	{"NNS"},
"packsaddle":	{"NN"},
"packsaddles":	{"NNS"},
"packthread":	{"NN"},
"packthreads":	{"NNS"},
"pact":	{"NN"},
"pacts":	{"NNS"},
"pad":	{"NN","VB","VBP"},
"padauk":	{"NN"},
"padda":	{"NN"},
"padded":	{"JJ","VBD","VBN"},
"padder":	{"NN"},
"paddies":	{"NNS"},
"padding":	{"NN","VBG"},
"paddle":	{"NN","VB","VBP"},
"paddle-boat":	{"NN"},
"paddle-boats":	{"NNS"},
"paddle-box":	{"NN"},
"paddle-shaped":	{"JJ"},
"paddle-steamer":	{"NN"},
"paddle-steamers":	{"NNS"},
"paddle-wheel":	{"NN"},
"paddle-wheeler":	{"NN"},
"paddle-wheels":	{"NNS"},
"paddleball":	{"NN"},
"paddleboard":	{"NN","VB","VBP"},
"paddleboarded":	{"VBD","VBN"},
"paddleboarding":	{"VBG","NN"},
"paddleboards":	{"NNS","VBZ"},
"paddled":	{"VBD","VBN"},
"paddlefish":	{"NN"},
"paddler":	{"NN"},
"paddlers":	{"NNS"},
"paddles":	{"NNS","VBZ"},
"paddling":	{"VBG"},
"paddock":	{"NN","VB","VBP"},
"paddocked":	{"VBD","VBN"},
"paddocking":	{"VBG"},
"paddocks":	{"NNS","VBZ"},
"paddy":	{"NN"},
"paddymelon":	{"NN"},
"pademelon":	{"NN"},
"padlock":	{"NN","VB","VBP"},
"padlocked":	{"VBD","VBN"},
"padlocking":	{"VBG"},
"padlocks":	{"NNS","VBZ"},
"padouk":	{"NN"},
"padova":	{"NN"},
"padre":	{"NN"},
"padres":	{"NNS"},
"padrone":	{"NN"},
"pads":	{"NNS","VBZ"},
"padua":	{"NN"},
"paducah":	{"NN"},
"paean":	{"NN"},
"paeans":	{"NNS"},
"paederast":	{"NN"},
"paederastic":	{"JJ"},
"paederasts":	{"NNS"},
"paederasty":	{"NN"},
"paediatric":	{"JJ"},
"paediatrician":	{"NN"},
"paediatricians":	{"NNS"},
"paediatrics":	{"NN"},
"paedophile":	{"NN"},
"paedophiles":	{"NNS"},
"paedophilia":	{"NN"},
"paella":	{"NN"},
"paellas":	{"NNS"},
"paeonia":	{"NN"},
"paeoniaceae":	{"NN"},
"paeonies":	{"NNS"},
"paeony":	{"NN"},
"pagad":	{"NN"},
"pagan":	{"NN","JJ"},
"paganise":	{"VB","VBP"},
"paganised":	{"VBD","VBN"},
"paganises":	{"VBZ"},
"paganising":	{"VBG"},
"paganism":	{"NN"},
"paganize":	{"VB","VBP"},
"paganized":	{"VBD","VBN"},
"paganizes":	{"VBZ"},
"paganizing":	{"VBG"},
"pagans":	{"NNS"},
"page":	{"NN","VBP","VB"},
"page-composition":	{"NN"},
"page-long":	{"JJ"},
"page-one":	{"JJ","NN"},
"pageant":	{"NN"},
"pageantry":	{"NN"},
"pageants":	{"NNS"},
"pageboy":	{"NN"},
"pageboys":	{"NNS"},
"paged":	{"VBD","VBN"},
"pagellus":	{"NN"},
"pager":	{"NN"},
"pagers":	{"NNS"},
"pages":	{"NNS","VBZ"},
"paget":	{"NN"},
"paginate":	{"VB","VBP"},
"paginated":	{"VBD","VBN"},
"paginates":	{"VBZ"},
"paginating":	{"VBG"},
"pagination":	{"NN"},
"paging":	{"VBG","NN"},
"pagoda":	{"NN"},
"pagodas":	{"NNS"},
"pagophila":	{"NN"},
"pagophilus":	{"NN"},
"pagrus":	{"NN"},
"paguridae":	{"NN"},
"pagurus":	{"NN"},
"pahautea":	{"NN"},
"pahlavi":	{"NN"},
"pahlevi":	{"NN"},
"pahoehoe":	{"NN"},
"paid":	{"VBN","VBD","JJ"},
"paid-for":	{"IN"},
"paid-in":	{"JJ"},
"paid-up":	{"JJ"},
"paigle":	{"NN"},
"pail":	{"NN"},
"pailful":	{"NN"},
"paillasse":	{"NN"},
"pails":	{"NNS"},
"pain":	{"NN","VBP","VB"},
"pain-bringing":	{"JJ"},
"pain-free":	{"JJ"},
"pain-relief":	{"NN"},
"pained":	{"JJ","VBD","VBN"},
"painewebber-involved":	{"JJ"},
"painful":	{"JJ"},
"painfully":	{"RB"},
"painfulness":	{"NN"},
"paining":	{"VBG"},
"painkiller":	{"NN"},
"painkillers":	{"NNS"},
"painless":	{"JJ"},
"painlessly":	{"RB"},
"pains":	{"NNS","VBZ"},
"pains-taking":	{"JJ"},
"painstaking":	{"JJ"},
"painstakingly":	{"RB"},
"painstakingness":	{"NN"},
"paint":	{"NN","VB","VBP"},
"paint-recycling":	{"JJ"},
"paintable":	{"JJ"},
"paintball":	{"NN"},
"paintbox":	{"NN"},
"paintboxes":	{"NNS"},
"paintbrush":	{"NN"},
"paintbrushes":	{"NNS"},
"painted":	{"VBN","VBD","JJ"},
"painted-in":	{"NN"},
"painter":	{"NN"},
"painteresque":	{"JJ"},
"painterly":	{"JJ"},
"painters":	{"NNS"},
"painting":	{"NN","VBG"},
"paintings":	{"NNS"},
"paints":	{"NNS","VBZ"},
"pair":	{"NN","NNS","VB","VBP"},
"paired":	{"VBD","VBN"},
"pairing":	{"NN","VBG"},
"pairings":	{"NNS"},
"pairs":	{"NNS","VBZ"},
"pais":	{"NN"},
"paisa":	{"NN"},
"paisley":	{"NN"},
"paisleys":	{"NNS"},
"paiute":	{"NN"},
"paiwanic":	{"NN"},
"pajama":	{"JJ"},
"pajama-clad":	{"JJ"},
"pajamas":	{"NNS"},
"pakchoi":	{"NN"},
"pal":	{"NN","VB","VBP"},
"palace":	{"NN"},
"palaces":	{"NNS"},
"paladin":	{"NN"},
"paladins":	{"NNS"},
"palaeencephalon":	{"NN"},
"palaemon":	{"NN"},
"palaemonidae":	{"NN"},
"palaeoanthropological":	{"JJ"},
"palaeoanthropologist":	{"NN"},
"palaeoanthropologists":	{"NNS"},
"palaeoanthropology":	{"NN"},
"palaeobiologist":	{"NN"},
"palaeobiologists":	{"NNS"},
"palaeobiology":	{"NN"},
"palaeobotany":	{"NN"},
"palaeoclimatology":	{"NN"},
"palaeodendrology":	{"NN"},
"palaeoecology":	{"NN"},
"palaeoethnography":	{"NN"},
"palaeogeography":	{"NN"},
"palaeogeology":	{"NN"},
"palaeolithic":	{"JJ"},
"palaeology":	{"NN"},
"palaeontological":	{"JJ"},
"palaeontologist":	{"NN"},
"palaeontologists":	{"NNS"},
"palaeontology":	{"NN"},
"palaeopathology":	{"NN"},
"palaeornithology":	{"NN"},
"palaeosol":	{"NN"},
"palaeosols":	{"NNS"},
"palaeozoology":	{"NN"},
"palaestra":	{"NN"},
"palaetiology":	{"NN"},
"palaic":	{"NN"},
"palankeen":	{"NN"},
"palanquin":	{"NN"},
"palaquium":	{"NN"},
"palas":	{"NNS"},
"palatability":	{"NN"},
"palatable":	{"JJ"},
"palatableness":	{"NN"},
"palatably":	{"RB"},
"palatal":	{"JJ","NN"},
"palatalise":	{"VB","VBP"},
"palatalised":	{"VBD","VBN"},
"palatalises":	{"VBZ"},
"palatalising":	{"VBG"},
"palatalize":	{"VB","VBP"},
"palatalized":	{"VBD","VBN"},
"palatalizes":	{"VBZ"},
"palatalizing":	{"VBG"},
"palate":	{"NN"},
"palates":	{"NNS"},
"palatial":	{"JJ"},
"palatinate":	{"NN"},
"palatinates":	{"NNS"},
"palatine":	{"JJ","NN"},
"palatines":	{"NNS"},
"palatoglossal":	{"JJ"},
"palatopharyngoplasty":	{"NN"},
"palaver":	{"NN","VB","VBP"},
"palavered":	{"VBD","VBN"},
"palavering":	{"VBG"},
"palavers":	{"VBZ"},
"palazzi":	{"NNS"},
"palazzo":	{"NN"},
"palazzos":	{"NNS"},
"pale":	{"JJ","VBP","NN","VB"},
"pale-blue":	{"JJ"},
"pale-colored":	{"JJ"},
"pale-face":	{"NN"},
"pale-faced":	{"JJ"},
"pale-hued":	{"JJ"},
"paleacrita":	{"NN"},
"paled":	{"VBD","VBN"},
"paleencephalon":	{"NN"},
"paleface":	{"NN"},
"palely":	{"RB"},
"paleness":	{"NN"},
"paleo-american":	{"NN"},
"paleo-amerind":	{"NN"},
"paleo-indian":	{"NN"},
"paleoanthropological":	{"JJ"},
"paleoanthropologist":	{"NN"},
"paleoanthropologists":	{"NNS"},
"paleoanthropology":	{"NN"},
"paleobiology":	{"NN"},
"paleobotany":	{"NN"},
"paleocene":	{"NN"},
"paleocerebellum":	{"NN"},
"paleoclimatologist":	{"NN"},
"paleoclimatology":	{"NN"},
"paleocortex":	{"NN"},
"paleocortical":	{"JJ"},
"paleodendrology":	{"NN"},
"paleoecology":	{"NN"},
"paleoencephalon":	{"NN"},
"paleoethnography":	{"NN"},
"paleoexplosion":	{"NN"},
"paleogeography":	{"NN"},
"paleogeology":	{"NN"},
"paleographer":	{"NN"},
"paleographist":	{"NN"},
"paleography":	{"NN"},
"paleolith":	{"NN"},
"paleolithic":	{"JJ"},
"paleology":	{"NN"},
"paleomammalogy":	{"NN"},
"paleontological":	{"JJ"},
"paleontologically":	{"RB"},
"paleontologist":	{"NN"},
"paleontologists":	{"NNS"},
"paleontology":	{"NN"},
"paleopathology":	{"NN"},
"paleornithology":	{"NN"},
"paleostriatum":	{"NN"},
"paleozoic":	{"JJ"},
"paleozoology":	{"NN"},
"paler":	{"JJR"},
"palermo":	{"NN"},
"pales":	{"VBZ","NN"},
"palest":	{"JJS"},
"palestra":	{"NN"},
"palestrina":	{"NN"},
"paletiology":	{"NN"},
"palette":	{"NN"},
"palettes":	{"NNS"},
"palfrey":	{"NN"},
"palgrave":	{"NN"},
"pali":	{"NN"},
"palilalia":	{"NN"},
"palimony":	{"NN"},
"palimpsest":	{"NN"},
"palimpsests":	{"NNS"},
"palindrome":	{"NN"},
"palindromes":	{"NNS"},
"paling":	{"NN","VBG"},
"palingenesis":	{"NN"},
"palingenetic":	{"JJ"},
"palinuridae":	{"NN"},
"palinurus":	{"NN"},
"palisade":	{"NN","VB","VBP"},
"palisaded":	{"VBD","VBN"},
"palisades":	{"NNS","VBZ"},
"palisading":	{"VBG"},
"palish":	{"JJ"},
"paliurus":	{"NN"},
"pall":	{"VB","VBP","NN"},
"pall-mall":	{"NN"},
"palladian":	{"JJ"},
"palladio":	{"NN"},
"palladium":	{"NN"},
"pallas":	{"NNS"},
"pallasite":	{"NN"},
"pallbearer":	{"NN"},
"palled":	{"VBD","VBN"},
"pallet":	{"NN"},
"palletized":	{"VBN"},
"pallets":	{"NNS"},
"pallette":	{"NN"},
"palliasse":	{"NN"},
"palliate":	{"VB"},
"palliation":	{"NN"},
"palliative":	{"NN","JJ"},
"pallid":	{"JJ","NN"},
"pallidity":	{"NN"},
"pallidly":	{"RB"},
"pallidness":	{"NN"},
"pallidum":	{"NN"},
"palling":	{"VBG"},
"pallium":	{"NN"},
"pallone":	{"NN"},
"pallor":	{"NN"},
"palls":	{"VBZ","NNS"},
"pally":	{"JJ"},
"palm":	{"NN","VB","VBP"},
"palm-fringed":	{"JJ"},
"palm-lined":	{"JJ"},
"palm-oil":	{"NN"},
"palm-shaped":	{"JJ"},
"palm-studded":	{"JJ"},
"palm-tree":	{"NN"},
"palm-trees":	{"NNS"},
"palmaceae":	{"NN"},
"palmae":	{"NN"},
"palmales":	{"NNS"},
"palmar":	{"JJ"},
"palmate":	{"JJ"},
"palmately":	{"RB"},
"palmately-lobed":	{"JJ"},
"palmatifid":	{"JJ"},
"palmature":	{"NN"},
"palmed":	{"VBD","VBN"},
"palmer":	{"NN"},
"palmers":	{"NNS"},
"palmetto":	{"NN"},
"palmettos":	{"NNS"},
"palmier":	{"JJR"},
"palmiest":	{"JJS"},
"palming":	{"VBG"},
"palmist":	{"NN"},
"palmister":	{"NN"},
"palmistry":	{"NN"},
"palmists":	{"NNS"},
"palmitin":	{"NN"},
"palmlike":	{"NN","JJ"},
"palmolive":	{"NN"},
"palms":	{"NNS","VBZ"},
"palmtop":	{"NN"},
"palmtops":	{"NNS"},
"palmy":	{"JJ"},
"palmyra":	{"NN"},
"palometa":	{"NN"},
"palomino":	{"NN"},
"palominos":	{"NNS"},
"palooka":	{"NN"},
"paloverde":	{"NN"},
"palpability":	{"NN"},
"palpable":	{"JJ"},
"palpably":	{"RB"},
"palpate":	{"VB","VBP"},
"palpated":	{"VBD","VBN"},
"palpates":	{"VBZ"},
"palpating":	{"VBG"},
"palpation":	{"NN"},
"palpatory":	{"JJ"},
"palpebra":	{"NN"},
"palpebrate":	{"JJ"},
"palpebration":	{"NN"},
"palpitant":	{"JJ"},
"palpitate":	{"VB","VBP"},
"palpitated":	{"VBD","VBN"},
"palpitates":	{"VBZ"},
"palpitating":	{"VBG"},
"palpitation":	{"NN"},
"palpitations":	{"NNS"},
"pals":	{"NNS","VBZ"},
"palsgrave":	{"NN"},
"palsied":	{"JJ","VBD","VBN"},
"palsies":	{"NNS","VBZ"},
"palsy":	{"NN","VB","VBP"},
"palsy-walsy":	{"JJ"},
"palsying":	{"VBG"},
"palter":	{"VB","VBP"},
"paltered":	{"VBD","VBN"},
"paltering":	{"NN","VBG"},
"palterings":	{"NNS"},
"palters":	{"VBZ"},
"paltriness":	{"NN"},
"paltry":	{"JJ"},
"pam":	{"NN"},
"pamelor":	{"NN"},
"pamlico":	{"NN"},
"pampas":	{"NN"},
"pamper":	{"VB","VBP"},
"pampered":	{"VBD","VBN","JJ"},
"pamperer":	{"NN"},
"pampering":	{"VBG","NN"},
"pampers":	{"VBZ"},
"pamphlet":	{"NN"},
"pamphleteer":	{"NN"},
"pamphleteers":	{"NNS"},
"pamphlets":	{"NNS"},
"pan":	{"NN","VB","VBP"},
"pan-European":	{"JJ"},
"pan-american":	{"JJ"},
"pan-broil":	{"VB","VBP"},
"pan-broiled":	{"VBD","VBN"},
"pan-broiling":	{"VBG"},
"pan-broils":	{"VBZ"},
"pan-european":	{"JJ"},
"pan-fried":	{"VBD","VBN","JJ"},
"pan-fries":	{"VBZ"},
"pan-fry":	{"VB","VBP"},
"pan-frying":	{"VBG"},
"pan-hellenic":	{"JJ"},
"pan-national":	{"JJ"},
"pan-nationalism":	{"NN"},
"pan-tribal":	{"JJ"},
"panacea":	{"NN"},
"panaceas":	{"NNS"},
"panache":	{"NN"},
"panadol":	{"NN"},
"panama":	{"NN"},
"panama-based":	{"JJ"},
"panama-incorporated":	{"JJ"},
"panamica":	{"NN"},
"panamiga":	{"NN"},
"panatela":	{"NN"},
"panax":	{"NN"},
"pancake":	{"NN"},
"pancake-like":	{"JJ"},
"pancake-style":	{"JJ"},
"pancakes":	{"NNS"},
"pancarditis":	{"NNS"},
"panchayat":	{"NN"},
"panchayats":	{"NNS"},
"panchayet":	{"NN"},
"pancreas":	{"NN"},
"pancreases":	{"NNS"},
"pancreatectomy":	{"NN"},
"pancreatic":	{"JJ"},
"pancreaticoduodenectomy":	{"NN"},
"pancreatin":	{"NN"},
"pancreatitis":	{"NN"},
"pancytopenia":	{"NN"},
"panda":	{"NN"},
"pandanaceae":	{"NN"},
"pandanales":	{"NNS"},
"pandanus":	{"NN"},
"pandar":	{"NN"},
"pandas":	{"NNS"},
"pandemic":	{"NN","JJ"},
"pandemics":	{"NNS"},
"pandemonium":	{"NN"},
"pander":	{"VB","VBP","NN"},
"pandered":	{"VBD","VBN"},
"panderer":	{"NN"},
"pandering":	{"VBG"},
"panders":	{"VBZ","NNS"},
"pandiculation":	{"NN"},
"pandion":	{"NN"},
"pandionidae":	{"NN"},
"pandowdy":	{"NN"},
"pandurate":	{"JJ"},
"panduriform":	{"JJ"},
"pane":	{"NN"},
"panegyric":	{"NN"},
"panegyrical":	{"JJ"},
"panegyrics":	{"NNS"},
"panegyrist":	{"NN"},
"panegyrists":	{"NNS"},
"panel":	{"NN","VB","VBP"},
"panelboard":	{"NN"},
"paneled":	{"VBD","VBN","JJ"},
"paneling":	{"NN","VBG"},
"panelist":	{"NN"},
"panelists":	{"NNS"},
"panelization":	{"NN"},
"panelized":	{"JJ"},
"panelled":	{"VBD","VBN","JJ"},
"panelling":	{"NN","VBG"},
"panellist":	{"NN"},
"panellists":	{"NNS"},
"panels":	{"NNS","VBZ"},
"panencephalitis":	{"NNS"},
"panes":	{"NNS"},
"panetela":	{"NN"},
"panetella":	{"NN"},
"panfish":	{"NN"},
"panfried":	{"VBD","VBN","JJ"},
"panfries":	{"VBZ"},
"panfry":	{"VB","VBP"},
"panfrying":	{"VBG"},
"pang":	{"NN","VB","VBP"},
"panga":	{"NN"},
"pangea":	{"NN"},
"panged":	{"VBD","VBN"},
"panging":	{"VBG"},
"pangolin":	{"NN"},
"pangs":	{"NNS","VBZ"},
"panhandle":	{"NN","VB","VBP"},
"panhandled":	{"VBD","VBN"},
"panhandler":	{"NN"},
"panhandlers":	{"NNS"},
"panhandles":	{"NNS","VBZ"},
"panhandling":	{"VBG","NN"},
"panhellenic":	{"JJ"},
"panhysterectomy":	{"NN"},
"panic":	{"NN","VB","VBP"},
"panic-driven":	{"JJ"},
"panic-stricken":	{"JJ"},
"panic-struck":	{"NN","JJ"},
"panicked":	{"VBD","VBN","JJ"},
"panicking":	{"JJ","VBG"},
"panicky":	{"JJ"},
"panicle":	{"NN"},
"panicled":	{"JJ"},
"panics":	{"NNS","VBZ"},
"paniculate":	{"JJ"},
"panicum":	{"NN"},
"panini":	{"NN","NNS"},
"paninis":	{"NNS"},
"panipat":	{"NN"},
"panjabi":	{"NN"},
"panjandra":	{"NNS"},
"panjandrum":	{"NN"},
"panky":	{"NN"},
"panned":	{"VBD","VBN"},
"pannier":	{"NN"},
"panniers":	{"NNS"},
"pannikin":	{"NN"},
"pannikins":	{"NNS"},
"panning":	{"NN","VBG"},
"panocha":	{"NN"},
"panoche":	{"NN"},
"panofsky":	{"NN"},
"panonychus":	{"NNS"},
"panoplied":	{"JJ"},
"panoply":	{"NN"},
"panoptic":	{"JJ"},
"panoptical":	{"JJ"},
"panopticon":	{"NN"},
"panorama":	{"NN"},
"panoramas":	{"NNS"},
"panoramic":	{"JJ"},
"panorpidae":	{"NN"},
"panpipe":	{"NN"},
"pans":	{"NNS","VBZ"},
"pansa":	{"NN"},
"pansexual":	{"NN"},
"pansies":	{"NNS"},
"pansinusitis":	{"NNS"},
"pansy":	{"NN"},
"pant":	{"VB","VBP","NN"},
"pant-leg":	{"NN"},
"pant-legs":	{"NNS"},
"pantaloon":	{"NN"},
"pantalooned":	{"JJ"},
"pantaloons":	{"NNS"},
"pantechnicon":	{"NN"},
"panted":	{"VBD","VBN"},
"pantheism":	{"NN"},
"pantheist":	{"NN"},
"pantheistic":	{"JJ"},
"pantheists":	{"NNS"},
"pantheon":	{"NN"},
"pantheons":	{"NNS"},
"panther":	{"NN"},
"panthera":	{"NN"},
"panthers":	{"NNS"},
"pantie":	{"NN"},
"panties":	{"NNS"},
"pantile":	{"NN"},
"pantiled":	{"JJ"},
"pantiles":	{"NNS"},
"panting":	{"VBG"},
"panto":	{"NN"},
"pantograph":	{"NN"},
"pantographs":	{"NNS"},
"pantomime":	{"NN","VB","VBP"},
"pantomimed":	{"VBD","VBN"},
"pantomimes":	{"NNS","VBZ"},
"pantomimic":	{"JJ"},
"pantomiming":	{"VBG"},
"pantomimist":	{"NN"},
"pantomimists":	{"NNS"},
"pantos":	{"NNS"},
"pantothen":	{"NN"},
"pantotheria":	{"NN"},
"pantries":	{"NNS"},
"pantropic":	{"JJ"},
"pantropical":	{"JJ"},
"pantry":	{"NN"},
"pantryman":	{"NN"},
"pantrymen":	{"NNS"},
"pants":	{"NNS","VBZ","JJ"},
"pantsuit":	{"NN"},
"pantsuits":	{"NNS"},
"panty":	{"NN"},
"pantyhose":	{"NNS"},
"pantywaist":	{"NN"},
"pany":	{"NN"},
"panzer":	{"NN"},
"panzers":	{"NNS"},
"paot":	{"NN"},
"pap":	{"NN"},
"papa":	{"NN"},
"papacy":	{"NN"},
"papaia":	{"NN"},
"papain":	{"NN"},
"papal":	{"JJ"},
"papanicolaou":	{"NN"},
"paparazzi":	{"NNS"},
"paparazzo":	{"NN"},
"papas":	{"NNS"},
"papaver":	{"NN"},
"papaveraceae":	{"NN"},
"papaverales":	{"NNS"},
"papaverine":	{"NN"},
"papaw":	{"NN"},
"papaya":	{"NN"},
"papayas":	{"NNS"},
"papeete":	{"NN"},
"paper":	{"NN","JJ","VB","VBP"},
"paper-and-crayon":	{"JJ"},
"paper-boy":	{"NN"},
"paper-boys":	{"NNS"},
"paper-chase":	{"NN"},
"paper-clip":	{"NN"},
"paper-clips":	{"NNS"},
"paper-company":	{"JJ","NN"},
"paper-cut":	{"NN"},
"paper-cuts":	{"NNS"},
"paper-cutter":	{"NN"},
"paper-cutters":	{"NNS"},
"paper-girl":	{"NN"},
"paper-girls":	{"NNS"},
"paper-goods":	{"NNS"},
"paper-knife":	{"NN"},
"paper-knives":	{"NNS"},
"paper-littered":	{"JJ"},
"paper-mache":	{"NN"},
"paper-making":	{"JJ"},
"paper-manufacturing":	{"JJ"},
"paper-mill":	{"NN"},
"paper-products":	{"NNS","JJ"},
"paper-pusher":	{"NN"},
"paper-pushers":	{"NNS"},
"paper-pushing":	{"JJ"},
"paper-shuffling":	{"NN"},
"paper-work":	{"NN"},
"paperback":	{"NN","JJ"},
"paperbacked":	{"JJ"},
"paperbacks":	{"NNS"},
"paperboard":	{"NN"},
"paperboy":	{"NN"},
"paperboys":	{"NNS"},
"paperclip":	{"NN"},
"paperclips":	{"NNS"},
"papercut":	{"NN"},
"papercuts":	{"NNS"},
"papered":	{"VBD","VBN"},
"paperer":	{"NN"},
"paperhanger":	{"NN"},
"paperhanging":	{"NN"},
"papering":	{"VBG"},
"paperless":	{"JJ"},
"paperlike":	{"JJ"},
"papermaking":	{"NN","JJ"},
"papers":	{"NNS","VBZ"},
"paperwads":	{"NNS"},
"paperweight":	{"NN"},
"paperweights":	{"NNS"},
"paperwork":	{"NN"},
"papery":	{"JJ"},
"paphiopedilum":	{"NN"},
"papier":	{"FW"},
"papier-mache":	{"NN"},
"papilionaceae":	{"NN"},
"papilionoideae":	{"NN"},
"papilla":	{"NN"},
"papillary":	{"JJ"},
"papillate":	{"JJ"},
"papilledema":	{"NN"},
"papilliform":	{"JJ"},
"papilloma":	{"NN"},
"papillon":	{"NN"},
"papillose":	{"JJ"},
"papio":	{"NN"},
"papism":	{"NN"},
"papist":	{"NN"},
"papistic":	{"JJ"},
"papistical":	{"JJ"},
"papists":	{"NNS"},
"papoose":	{"NN"},
"papooseroot":	{"NN"},
"papooses":	{"NNS"},
"papovavirus":	{"NN"},
"pappa":	{"NN"},
"pappoose":	{"NN"},
"pappose":	{"JJ"},
"pappus":	{"NN"},
"paprika":	{"NN"},
"paprilus":	{"NN"},
"papule":	{"NN"},
"papulovesicle":	{"NN"},
"papyri":	{"NNS"},
"papyrus":	{"NN","JJ"},
"par":	{"NN"},
"par-cook":	{"VB","VBP"},
"par-cooked":	{"VBD","VBN"},
"par-cooking":	{"JJ","VBG"},
"par-cooks":	{"VBZ"},
"para":	{"NN"},
"parable":	{"NN"},
"parables":	{"NNS"},
"parabola":	{"NN"},
"parabolas":	{"NNS"},
"parabolic":	{"JJ"},
"parabolical":	{"JJ"},
"paraboloid":	{"NN"},
"paraboloidal":	{"JJ"},
"paracelsus":	{"NN"},
"paracentesis":	{"NN"},
"paracheirodon":	{"NN"},
"parachute":	{"NN","VB","VBP"},
"parachuted":	{"VBD","VBN"},
"parachuter":	{"NN"},
"parachuters":	{"NNS"},
"parachutes":	{"NNS","VBZ"},
"parachuting":	{"NN","VBG"},
"parachutist":	{"NN"},
"parachutists":	{"NNS"},
"paraclete":	{"NN"},
"paracosm":	{"NN"},
"parade":	{"NN","VBP","VB"},
"parade-ground":	{"NN"},
"parade-grounds":	{"NNS"},
"paraded":	{"VBD","VBN"},
"parader":	{"NN"},
"paraders":	{"NNS"},
"parades":	{"NNS","VBZ"},
"paradiddle":	{"NN"},
"paradigm":	{"NN"},
"paradigmatic":	{"JJ"},
"paradigmatically":	{"RB"},
"paradigms":	{"NNS"},
"parading":	{"VBG"},
"paradisaeidae":	{"NN"},
"paradisaic":	{"JJ"},
"paradisaical":	{"JJ"},
"paradisal":	{"JJ"},
"paradise":	{"NN"},
"paradises":	{"NNS"},
"paradisiac":	{"JJ"},
"paradisiacal":	{"NN","JJ"},
"paradox":	{"NN"},
"paradoxes":	{"NNS"},
"paradoxical":	{"JJ"},
"paradoxically":	{"RB"},
"paradoxurus":	{"NN"},
"paraesthesia":	{"NN"},
"paraffin":	{"NN","VB","VBP"},
"paraffined":	{"VBD","VBN"},
"paraffining":	{"VBG"},
"paraffins":	{"VBZ","NNS"},
"parafovea":	{"NN"},
"paraglide":	{"VB","VBP"},
"paraglided":	{"VBD","VBN"},
"paraglider":	{"NN"},
"paragliders":	{"NNS"},
"paraglides":	{"VBZ"},
"paragliding":	{"VBG","NN"},
"paragon":	{"NN","VB","VBP"},
"paragoned":	{"VBD","VBN"},
"paragoning":	{"VBG"},
"paragonite":	{"NN"},
"paragons":	{"NNS","VBZ"},
"paragraph":	{"NN","VB","VBP"},
"paragraphed":	{"VBD","VBN"},
"paragrapher":	{"NN"},
"paragraphers":	{"NNS"},
"paragraphing":	{"NN","VBG"},
"paragraphs":	{"NNS","VBZ"},
"parakeet":	{"NN"},
"parakeets":	{"NNS"},
"paralanguage":	{"NN"},
"paraldehyde":	{"NN"},
"paralegal":	{"NN"},
"paralegals":	{"NNS"},
"paraleipsis":	{"NN"},
"paralepsis":	{"NN"},
"paralichthys":	{"NN"},
"paralinguistic":	{"JJ"},
"paralipomenon":	{"NN"},
"paralipsis":	{"NN"},
"paralithodes":	{"NNS"},
"parallax":	{"NN"},
"parallaxes":	{"NNS"},
"parallel":	{"JJ","NN","VB","VBP"},
"parallel-computing":	{"JJ"},
"parallel-park":	{"VB","VBP"},
"paralleled":	{"VBN","VBD"},
"parallelepiped":	{"NN"},
"parallelepipedon":	{"NN"},
"paralleling":	{"NN","VBG"},
"parallelise":	{"VB","VBP"},
"parallelised":	{"VBD","VBN"},
"parallelises":	{"VBZ"},
"parallelising":	{"VBG"},
"parallelism":	{"NN"},
"parallelize":	{"VB","VBP"},
"parallelized":	{"VBD","VBN"},
"parallelizes":	{"VBZ"},
"parallelizing":	{"VBG"},
"parallelled":	{"VBD","VBN"},
"parallelling":	{"VBG"},
"parallelogram":	{"NN"},
"parallelograms":	{"NNS"},
"parallelopiped":	{"NN"},
"parallelopipedon":	{"NN"},
"parallels":	{"NNS","VBZ"},
"paralogism":	{"NN"},
"paralyse":	{"VB","VBP"},
"paralysed":	{"VBD","VBN","JJ"},
"paralyses":	{"VBZ","NNS"},
"paralysing":	{"VBG"},
"paralysis":	{"NN"},
"paralytic":	{"JJ","NN"},
"paralytical":	{"JJ"},
"paralytically":	{"RB"},
"paralytics":	{"NNS"},
"paralyze":	{"VB","VBP"},
"paralyzed":	{"VBN","VBD","JJ"},
"paralyzes":	{"VBZ"},
"paralyzing":	{"VBG"},
"paramagnet":	{"NN"},
"paramagnetic":	{"JJ"},
"paramagnetism":	{"NN"},
"paramaribo":	{"NN"},
"paramecia":	{"NNS"},
"paramecium":	{"NN"},
"paramedic":	{"NN"},
"paramedical":	{"JJ"},
"paramedics":	{"NNS"},
"parameter":	{"NN"},
"parameters":	{"NNS"},
"parametric":	{"JJ"},
"parametritis":	{"NN"},
"paramilitaries":	{"NNS"},
"paramilitarism":	{"NN"},
"paramilitary":	{"JJ","NN"},
"paramnesia":	{"NN"},
"paramount":	{"JJ"},
"paramountcy":	{"NN"},
"paramour":	{"NN"},
"paramours":	{"NNS"},
"paramyxovirus":	{"NN"},
"parana":	{"NN"},
"paranasal":	{"JJ"},
"parang":	{"NN"},
"paranoia":	{"NN"},
"paranoiac":	{"JJ","NN"},
"paranoiacs":	{"NNS"},
"paranoid":	{"JJ","NN"},
"paranoids":	{"NNS"},
"paranormal":	{"JJ","NN"},
"paranthias":	{"NN"},
"paranthropus":	{"NN"},
"paraoxon":	{"NN"},
"paraparesis":	{"NN"},
"parapet":	{"NN"},
"parapets":	{"NNS"},
"paraph":	{"NN"},
"paraphernalia":	{"NN"},
"paraphilia":	{"NN"},
"paraphrase":	{"VB","VBP","NN"},
"paraphrased":	{"VBD","VBN"},
"paraphrases":	{"NNS","VBZ"},
"paraphrasing":	{"VBG"},
"paraphrasis":	{"NN"},
"paraphrastic":	{"JJ"},
"paraphrenia":	{"NN"},
"paraphysis":	{"NN"},
"paraplegia":	{"NN"},
"paraplegic":	{"NN","JJ"},
"paraplegics":	{"NNS"},
"parapodium":	{"NN"},
"parapraxis":	{"NN"},
"paraprofessional":	{"NN","JJ"},
"parapsychological":	{"JJ"},
"parapsychologist":	{"NN"},
"parapsychology":	{"NN"},
"paraquat":	{"NN"},
"paraquet":	{"NN"},
"paras":	{"NNS"},
"parasail":	{"VB","VBP","NN"},
"parasailed":	{"VBD","VBN"},
"parasailer":	{"NN"},
"parasailers":	{"NNS"},
"parasailing":	{"NN","VBG"},
"parasails":	{"VBZ","NNS"},
"parascalops":	{"NNS"},
"parashurama":	{"NN"},
"parasitaemia":	{"NN"},
"parasitaxus":	{"NN"},
"parasite":	{"NN"},
"parasitemia":	{"NN"},
"parasites":	{"NNS"},
"parasitic":	{"JJ"},
"parasitical":	{"JJ"},
"parasitically":	{"RB"},
"parasiticidal":	{"JJ"},
"parasitisation":	{"NN"},
"parasitise":	{"VB","VBP"},
"parasitised":	{"VBD","VBN"},
"parasitises":	{"VBZ"},
"parasitising":	{"VBG"},
"parasitism":	{"NN"},
"parasitization":	{"NN"},
"parasitize":	{"VB","VBP"},
"parasitized":	{"VBD","VBN"},
"parasitizes":	{"VBZ"},
"parasitizing":	{"VBG"},
"parasol":	{"NN"},
"parasols":	{"NNS"},
"parastatals":	{"NNS"},
"parasympathetic":	{"JJ"},
"parasympathomimetic":	{"JJ"},
"parathelypteris":	{"NN"},
"parathion":	{"NN"},
"parathormone":	{"NN"},
"parathyroid":	{"JJ","NN"},
"paratrooper":	{"NN"},
"paratroopers":	{"NNS"},
"paratroops":	{"NNS"},
"paratyphoid":	{"JJ","NN"},
"paraxial":	{"JJ"},
"parazoa":	{"NN"},
"parazoan":	{"NN"},
"parboil":	{"VB","VBP"},
"parboiled":	{"VBD","VBN"},
"parboiling":	{"VBG"},
"parboils":	{"VBZ"},
"parcae":	{"NN"},
"parcel":	{"NN","VB","VBP"},
"parceled":	{"VBD","VBN"},
"parceling":	{"VBG"},
"parcellation":	{"NN"},
"parcelled":	{"VBD","VBN"},
"parcelling":	{"VBG"},
"parcels":	{"VBZ","NNS"},
"parch":	{"VB","VBP"},
"parched":	{"JJ","VBD","VBN"},
"parcheesi":	{"NN"},
"parches":	{"VBZ"},
"parchesi":	{"NN"},
"parching":	{"VBG"},
"parchisi":	{"NN"},
"parchment":	{"NN"},
"parchments":	{"NNS"},
"pardner":	{"NN"},
"pardon":	{"UH","VB","VBP","NN"},
"pardonable":	{"JJ"},
"pardonably":	{"RB"},
"pardoned":	{"VBD","VBN"},
"pardoner":	{"NN"},
"pardoning":	{"VBG"},
"pardons":	{"VBZ","NNS"},
"pare":	{"VB","VBP"},
"pared":	{"VBD","VBN"},
"pared-down":	{"JJ"},
"paredon":	{"NN"},
"paregmenon":	{"NN"},
"paregoric":	{"NN"},
"parenchyma":	{"NN"},
"parent":	{"NN","JJ","VB","VBP"},
"parent-child":	{"JJ"},
"parent-company":	{"NN"},
"parent-teacher":	{"JJ"},
"parentage":	{"NN"},
"parental":	{"JJ"},
"parental-consent":	{"JJ"},
"parental-leave":	{"JJ"},
"parentally":	{"RB"},
"parented":	{"VBD","VBN"},
"parenteral":	{"JJ"},
"parenterally":	{"RB"},
"parentheses":	{"NNS"},
"parenthesis":	{"NN"},
"parenthetic":	{"JJ"},
"parenthetical":	{"JJ"},
"parenthetically":	{"RB"},
"parenthood":	{"NN"},
"parentification":	{"NN"},
"parenting":	{"NN","VBG"},
"parentis":	{"FW"},
"parentless":	{"JJ"},
"parents":	{"NNS","VBZ"},
"parer":	{"NN"},
"pares":	{"VBZ"},
"paresis":	{"NN"},
"paresthesia":	{"NN"},
"paretic":	{"NN","JJ"},
"pareto":	{"NN"},
"pareve":	{"JJ"},
"parfait":	{"NN"},
"parget":	{"NN","VB","VBP"},
"pargeted":	{"VBD","VBN"},
"pargeting":	{"NN","VBG"},
"pargetry":	{"NN"},
"pargets":	{"NNS","VBZ"},
"pargetted":	{"VBD","VBN"},
"pargetting":	{"NN","VBG"},
"parheliacal":	{"JJ"},
"parhelic":	{"JJ"},
"parhelion":	{"NN"},
"pari-mutuel":	{"NN"},
"pari-mutuels":	{"NNS"},
"pariah":	{"NN"},
"pariahs":	{"NNS"},
"paridae":	{"NN"},
"paries":	{"NN"},
"parietal":	{"JJ"},
"parietales":	{"NNS"},
"parietaria":	{"NN"},
"parimutuel":	{"NN"},
"parimutuels":	{"NNS"},
"paring":	{"NN","VBG"},
"parings":	{"NNS"},
"paripinnate":	{"JJ"},
"paris-based":	{"JJ"},
"paris-mutuels":	{"NNS"},
"parish":	{"NN"},
"parishes":	{"NNS"},
"parishioner":	{"NN"},
"parishioners":	{"NNS"},
"parisienne":	{"NN"},
"parisology":	{"NN"},
"parities":	{"NNS"},
"parity":	{"NN"},
"parjanya":	{"NN"},
"parji":	{"NN"},
"park":	{"NN","VB","VBP"},
"park-affiliated":	{"JJ"},
"parka":	{"NN"},
"parkas":	{"NNS"},
"parked":	{"VBN","VBD","JJ"},
"parkeriaceae":	{"NN"},
"parkersburg":	{"NN"},
"parkia":	{"NN"},
"parking":	{"NN","VBG"},
"parking-lot":	{"NN"},
"parking-lots":	{"NNS"},
"parking-meter":	{"NN"},
"parking-meters":	{"NNS"},
"parking-ticket":	{"NN"},
"parking-tickets":	{"NNS"},
"parkinsonia":	{"NN"},
"parkinsonism":	{"NN"},
"parkish":	{"JJ"},
"parkland":	{"NN"},
"parklike":	{"NN","JJ"},
"parks":	{"NNS","VBZ"},
"parkway":	{"NN"},
"parkways":	{"NNS"},
"parky":	{"JJ"},
"parlance":	{"NN"},
"parlay":	{"VB","VBP","NN"},
"parlayed":	{"VBD","VBN"},
"parlaying":	{"VBG"},
"parlays":	{"VBZ"},
"parley":	{"NN","VB","VBP"},
"parleyed":	{"VBD","VBN"},
"parleying":	{"VBG"},
"parleys":	{"NNS","VBZ"},
"parliament":	{"NN"},
"parliamentarian":	{"NN"},
"parliamentarians":	{"NNS"},
"parliamentary":	{"JJ"},
"parliaments":	{"NNS"},
"parlor":	{"NN"},
"parlormaid":	{"NN"},
"parlors":	{"NNS"},
"parlour":	{"NN"},
"parlourmaid":	{"NN"},
"parlourmaids":	{"NNS"},
"parlours":	{"NNS"},
"parlous":	{"JJ"},
"parmelia":	{"NN"},
"parmeliaceae":	{"NN"},
"parmenides":	{"NNS"},
"parnahiba":	{"NN"},
"parnaiba":	{"NN"},
"parnassia":	{"NN"},
"parochetus":	{"NN"},
"parochial":	{"JJ"},
"parochialism":	{"NN"},
"parochially":	{"RB"},
"parodied":	{"VBD","VBN"},
"parodies":	{"NNS","VBZ"},
"parodis":	{"NNS"},
"parodist":	{"NN"},
"parodists":	{"NNS"},
"parody":	{"NN","VB","VBP"},
"parodying":	{"VBG"},
"paroicous":	{"JJ"},
"parole":	{"NN","VB","VBP"},
"paroled":	{"VBD","VBN"},
"parolee":	{"NN"},
"parolees":	{"NNS"},
"paroles":	{"VBZ"},
"paroling":	{"VBG"},
"paronomasia":	{"NN"},
"paronychia":	{"NN"},
"parophrys":	{"NNS"},
"paroquet":	{"NN"},
"parosamia":	{"NN"},
"parotid":	{"NN","JJ"},
"parotitis":	{"NN"},
"parous":	{"JJ"},
"parousia":	{"NN"},
"paroxetime":	{"NN"},
"paroxysm":	{"NN"},
"paroxysmal":	{"JJ"},
"paroxysms":	{"NNS"},
"paroxytone":	{"NN"},
"parquet":	{"NN"},
"parqueterie":	{"NN"},
"parquetry":	{"NN"},
"parr":	{"NN","NNS"},
"parrakeet":	{"NN"},
"parricide":	{"NN"},
"parricides":	{"NNS"},
"parried":	{"VBD","VBN"},
"parries":	{"VBZ"},
"parrish":	{"NN"},
"parroket":	{"NN"},
"parroquet":	{"NN"},
"parrot":	{"NN","VB","VBP"},
"parrot-like":	{"JJ"},
"parroted":	{"VBD","VBN"},
"parrotfish":	{"NN"},
"parrotia":	{"NN"},
"parroting":	{"VBG"},
"parrotiopsis":	{"NN"},
"parrotlike":	{"JJ"},
"parrots":	{"NNS","VBZ"},
"parrs":	{"NNS"},
"parry":	{"VB","VBP","NN"},
"parrying":	{"VBG"},
"pars":	{"NNS"},
"parse":	{"VB","VBP"},
"parsec":	{"NN"},
"parsed":	{"VBD","VBN"},
"parseeism":	{"NN"},
"parser":	{"NN"},
"parsers":	{"NNS"},
"parses":	{"VBZ","NNS"},
"parsiism":	{"NN"},
"parsimonious":	{"JJ"},
"parsimoniously":	{"RB"},
"parsimoniousness":	{"NN"},
"parsimony":	{"NN"},
"parsing":	{"VBG"},
"parsley":	{"NN"},
"parsnip":	{"NN"},
"parsnips":	{"NNS"},
"parson":	{"NN"},
"parsonage":	{"NN"},
"parsonages":	{"NNS"},
"parsons":	{"NNS"},
"parsympathetic":	{"JJ"},
"part":	{"NN","VB","VBP","RB","JJ"},
"part-owner":	{"NN"},
"part-singing":	{"NN"},
"part-time":	{"JJ","RB"},
"part-timer":	{"NN"},
"part-timers":	{"NNS"},
"partake":	{"VB","VBP"},
"partaken":	{"VBN"},
"partaker":	{"NN"},
"partakers":	{"NNS"},
"partakes":	{"VBZ"},
"partaking":	{"VBG"},
"parte":	{"NN"},
"parted":	{"JJ","VBD","VBN"},
"parterre":	{"NN"},
"parthenium":	{"NN"},
"parthenocarpy":	{"NN"},
"parthenocissus":	{"NN"},
"parthenogenesis":	{"NN"},
"parthenogenetic":	{"JJ"},
"parthenogeny":	{"NN"},
"parthenote":	{"NN"},
"parthia":	{"NN"},
"parthian":	{"JJ","NN"},
"parti-colored":	{"JJ"},
"parti-coloured":	{"JJ"},
"partial":	{"JJ"},
"partiality":	{"NN"},
"partially":	{"RB"},
"partialness":	{"NN"},
"partible":	{"JJ"},
"participant":	{"NN"},
"participants":	{"NNS"},
"participate":	{"VB","VBP"},
"participated":	{"VBD","VBN"},
"participates":	{"VBZ"},
"participating":	{"VBG"},
"participation":	{"NN"},
"participations":	{"NNS"},
"participative":	{"JJ"},
"participatory":	{"JJ"},
"participial":	{"JJ"},
"participle":	{"NN"},
"participles":	{"NNS"},
"particle":	{"NN"},
"particle-board":	{"NN"},
"particles":	{"NNS"},
"particular":	{"JJ","NN"},
"particularisation":	{"NN"},
"particularise":	{"VB","VBP"},
"particularised":	{"VBD","VBN"},
"particularises":	{"VBZ"},
"particularising":	{"VBG"},
"particularism":	{"NN"},
"particularistic":	{"JJ"},
"particularistic-seeming":	{"JJ"},
"particularities":	{"NNS"},
"particularity":	{"NN"},
"particularization":	{"NN"},
"particularize":	{"VB","VBP"},
"particularized":	{"VBD","VBN"},
"particularizes":	{"VBZ"},
"particularizing":	{"VBG"},
"particularly":	{"RB"},
"particulars":	{"NNS"},
"particulate":	{"NN"},
"particulates":	{"NNS"},
"partied":	{"VBD","VBN"},
"parties":	{"NNS","VBZ"},
"parting":	{"NN","JJ","VBG"},
"partings":	{"NNS"},
"partisan":	{"JJ","NN"},
"partisans":	{"NNS"},
"partisanship":	{"NN"},
"partita":	{"NN"},
"partition":	{"NN","VB","VBP"},
"partitioned":	{"JJ","VBD","VBN"},
"partitioning":	{"NN","VBG"},
"partitionist":	{"NN"},
"partitions":	{"NNS","VBZ"},
"partitive":	{"JJ","NN"},
"partitives":	{"NNS"},
"partizan":	{"NN"},
"partly":	{"RB"},
"partner":	{"NN","VBP","VB"},
"partner-in-charge":	{"NN"},
"partner-notification":	{"NN"},
"partnered":	{"VBD","VBN"},
"partnering":	{"VBG"},
"partners":	{"NNS","VBZ"},
"partnership":	{"NN"},
"partnerships":	{"NNS"},
"partook":	{"VBD"},
"partridge":	{"NN"},
"partridgeberry":	{"NN"},
"partridges":	{"NNS"},
"parts":	{"NNS","VBZ"},
"parts-engineering":	{"JJ"},
"parts-suppliers":	{"NNS"},
"partsong":	{"NN"},
"parturiency":	{"NN"},
"parturient":	{"JJ"},
"parturition":	{"NN"},
"party":	{"NN","VBP","VB"},
"party-giving":	{"NN"},
"party-line":	{"JJ","NN"},
"party-spirited":	{"JJ"},
"party-wall":	{"NN"},
"partygoer":	{"NN"},
"partygoers":	{"NNS"},
"partying":	{"VBG"},
"parula":	{"NN"},
"parulidae":	{"NN"},
"parus":	{"NN"},
"parvati":	{"NN"},
"parve":	{"NN"},
"parvenu":	{"NN"},
"parvenue":	{"JJ"},
"parvenus":	{"NNS"},
"parvis":	{"NN"},
"parvo":	{"NN"},
"parvovirus":	{"NN"},
"pas":	{"NN","NNS","FW"},
"pasang":	{"NN"},
"pascal":	{"NN"},
"pasch":	{"NN"},
"pascha":	{"NN"},
"paschal":	{"JJ"},
"paseo":	{"NN"},
"pasha":	{"NN"},
"pashas":	{"NNS"},
"pashto":	{"NN"},
"pashtoon":	{"NN"},
"pashtu":	{"NN"},
"pashtun":	{"NN"},
"pasigraphy":	{"NN"},
"pasiphae":	{"NN"},
"paso":	{"NN"},
"paspalum":	{"NN"},
"pasqueflower":	{"NN"},
"pasquinade":	{"NN"},
"pass":	{"VB","VBP","NN"},
"pass-through":	{"NN"},
"passable":	{"JJ"},
"passably":	{"RB"},
"passado":	{"NN"},
"passage":	{"NN","VB","VBP"},
"passaged":	{"VBD","VBN"},
"passages":	{"NNS","VBZ"},
"passageway":	{"NN"},
"passageways":	{"NNS"},
"passaging":	{"VBG"},
"passamaquody":	{"NN"},
"passant":	{"JJ"},
"passback":	{"NN"},
"passbook":	{"NN"},
"passbooks":	{"NNS"},
"passcode":	{"NN"},
"passcodes":	{"NNS"},
"passe":	{"JJ"},
"passe-partout":	{"NN"},
"passed":	{"VBD","VBN","JJ"},
"passee":	{"JJ"},
"passel":	{"NN"},
"passementerie":	{"NN"},
"passenger":	{"NN"},
"passenger-car":	{"NN"},
"passenger-kilometers":	{"NNS"},
"passenger-loading":	{"JJ"},
"passenger-mile":	{"NN"},
"passenger-miles":	{"NNS"},
"passenger-reservation":	{"NN"},
"passenger-restraint":	{"NN"},
"passenger-tire":	{"JJ"},
"passenger-transportation":	{"JJ"},
"passengers":	{"NNS"},
"passer":	{"NN"},
"passer-by":	{"NN"},
"passerby":	{"NN"},
"passeres":	{"NNS"},
"passeridae":	{"NN"},
"passeriformes":	{"NNS"},
"passerina":	{"NN"},
"passerine":	{"JJ","NN"},
"passero":	{"NN"},
"passers":	{"NNS"},
"passers-by":	{"NNS"},
"passersby":	{"NNS"},
"passes":	{"NNS","VBZ"},
"passiflora":	{"NN"},
"passifloraceae":	{"NN"},
"passim":	{"RB"},
"passing":	{"VBG","NN","JJ"},
"passion":	{"NN"},
"passion-flower":	{"NN"},
"passion-flowers":	{"NNS"},
"passion-fruit":	{"NN"},
"passion-fruits":	{"NNS"},
"passion-play":	{"NN"},
"passion-plays":	{"NNS"},
"passionate":	{"JJ"},
"passionately":	{"RB"},
"passionateness":	{"NN"},
"passionflower":	{"NN"},
"passionflowers":	{"NNS"},
"passionless":	{"JJ"},
"passions":	{"NNS"},
"passive":	{"JJ","NN"},
"passive-loss":	{"JJ"},
"passively":	{"RB"},
"passiveness":	{"NN"},
"passivism":	{"NN"},
"passivity":	{"NN"},
"passkey":	{"NN"},
"passkeys":	{"NNS"},
"passport":	{"NN"},
"passports":	{"NNS"},
"passthrough":	{"JJ"},
"password":	{"NN"},
"passwords":	{"NNS"},
"past":	{"JJ","NN","IN","RB"},
"past-due":	{"JJ"},
"past-fantasy":	{"JJ"},
"past-oriented":	{"JJ"},
"pasta":	{"NN"},
"pastas":	{"NNS"},
"pastdue":	{"JJ"},
"paste":	{"NN","VB","VBP"},
"paste-up":	{"NN"},
"paste-ups":	{"NNS"},
"pasteboard":	{"NN"},
"pasted":	{"VBD","VBN"},
"pasted-in":	{"JJ"},
"pastel":	{"NN","JJ"},
"pastel-colored":	{"JJ"},
"pastel-like":	{"JJ"},
"pastelike":	{"JJ"},
"pastels":	{"NNS"},
"paster":	{"NN"},
"pastern":	{"NN"},
"pasters":	{"NNS"},
"pastes":	{"VBZ","NNS"},
"pasteurellosis":	{"NN"},
"pasteurian":	{"JJ"},
"pasteurisation":	{"NN"},
"pasteurise":	{"VB","VBP"},
"pasteurised":	{"JJ","VBD","VBN"},
"pasteurises":	{"VBZ"},
"pasteurising":	{"VBG"},
"pasteurization":	{"NN"},
"pasteurize":	{"VB","VBP"},
"pasteurized":	{"VBD","VBN","JJ"},
"pasteurizes":	{"VBZ"},
"pasteurizing":	{"VBG"},
"pastiche":	{"NN"},
"pastiches":	{"NNS"},
"pastier":	{"JJR"},
"pasties":	{"NNS"},
"pastiest":	{"JJS"},
"pastil":	{"NN"},
"pastille":	{"NN"},
"pastilles":	{"NNS"},
"pastime":	{"NN"},
"pastimes":	{"NNS"},
"pastinaca":	{"NN"},
"pasting":	{"VBG","NN"},
"pastis":	{"NN"},
"pastness":	{"NN"},
"pasto":	{"NN"},
"pastor":	{"NN","VB","VBP"},
"pastoral":	{"NN","JJ"},
"pastorale":	{"NN"},
"pastorals":	{"NNS"},
"pastorate":	{"NN"},
"pastored":	{"VBD","VBN"},
"pastoring":	{"VBG"},
"pastoris":	{"NN"},
"pastors":	{"NNS","VBZ"},
"pastorship":	{"NN"},
"pastrami":	{"NN"},
"pastries":	{"NNS"},
"pastry":	{"NN"},
"pastry-lined":	{"JJ"},
"pasturage":	{"NN"},
"pasture":	{"NN","VB","VBP"},
"pastured":	{"VBD","VBN"},
"pastureland":	{"NN"},
"pastures":	{"VBZ","NNS"},
"pasturing":	{"VBG"},
"pasty":	{"JJ","NN"},
"pat":	{"NN","VB","VBP","JJ","RB"},
"pataca":	{"NN"},
"patas":	{"NNS"},
"patavium":	{"NN"},
"patch":	{"NN","VB","VBP"},
"patchboard":	{"NN"},
"patchcord":	{"NN"},
"patched":	{"VBD","VBN"},
"patches":	{"NNS","VBZ"},
"patchier":	{"JJR"},
"patchiest":	{"JJS"},
"patchily":	{"RB"},
"patchiness":	{"NN"},
"patching":	{"VBG"},
"patchouli":	{"NN"},
"patchouly":	{"NN"},
"patchwork":	{"NN"},
"patchy":	{"JJ"},
"pate":	{"NN"},
"patella":	{"NN"},
"patellae":	{"NNS"},
"patellar":	{"JJ"},
"patellidae":	{"NN"},
"patelliform":	{"JJ"},
"patency":	{"NN"},
"patent":	{"NN","JJ","VBP","VB"},
"patent-infringement":	{"NN"},
"patent-law":	{"NN"},
"patent-sharing":	{"JJ"},
"patented":	{"VBD","VBN"},
"patentee":	{"NN"},
"patentees":	{"NNS"},
"patenting":	{"VBG"},
"patently":	{"RB"},
"patents":	{"NNS","VBZ"},
"pater":	{"NN"},
"paterfamilias":	{"NN"},
"paternal":	{"JJ"},
"paternalism":	{"NN"},
"paternalist":	{"NN","JJ"},
"paternalistic":	{"JJ"},
"paternalists":	{"NNS"},
"paternally":	{"RB"},
"paternity":	{"NN"},
"paternoster":	{"NN"},
"paterollers":	{"NNS"},
"paters":	{"NNS"},
"paterson":	{"NN"},
"pates":	{"NNS"},
"path":	{"NN"},
"pathan":	{"NN"},
"pathetic":	{"JJ"},
"pathetically":	{"RB"},
"pathfinder":	{"NN"},
"pathfinders":	{"NNS"},
"pathless":	{"JJ"},
"pathlogy":	{"NN"},
"pathogen":	{"NN"},
"pathogenesis":	{"NN"},
"pathogenic":	{"JJ"},
"pathogenically":	{"RB"},
"pathogens":	{"NNS"},
"pathologic":	{"JJ"},
"pathological":	{"JJ"},
"pathologically":	{"RB"},
"pathologist":	{"NN"},
"pathologists":	{"NNS"},
"pathology":	{"NN"},
"pathos":	{"NN"},
"paths":	{"NNS"},
"pathway":	{"NN"},
"pathways":	{"NNS"},
"patience":	{"NN"},
"patient":	{"NN","JJ"},
"patient-advocacy":	{"NN"},
"patient-care":	{"JJ"},
"patient-interview":	{"JJ"},
"patient-physician":	{"JJ"},
"patienthood":	{"NN"},
"patiently":	{"RB"},
"patients":	{"NNS"},
"patil":	{"NN"},
"patina":	{"NN"},
"patinae":	{"NNS"},
"patinas":	{"NNS"},
"patinate":	{"VB","VBP"},
"patinated":	{"VBD","VBN"},
"patinates":	{"VBZ"},
"patinating":	{"VBG"},
"patinise":	{"VB"},
"patinize":	{"VB"},
"patio":	{"NN"},
"patios":	{"NNS"},
"patisserie":	{"NN"},
"patisseries":	{"NNS"},
"patka":	{"NN"},
"patness":	{"NN"},
"patois":	{"NN","NNS"},
"patrai":	{"NN"},
"patras":	{"NNS"},
"patresfamilias":	{"NNS"},
"patria":	{"NN"},
"patrial":	{"NN"},
"patriarch":	{"NN"},
"patriarchal":	{"JJ"},
"patriarchate":	{"NN"},
"patriarchic":	{"JJ"},
"patriarchies":	{"NNS"},
"patriarchs":	{"NNS"},
"patriarchy":	{"NN"},
"patrice":	{"NN"},
"patricentric":	{"JJ"},
"patrician":	{"NN","JJ"},
"patricians":	{"NNS"},
"patricide":	{"NN"},
"patricides":	{"NNS"},
"patrikin":	{"NN"},
"patrilineage":	{"NN"},
"patrilineal":	{"JJ"},
"patrilineally":	{"RB"},
"patrilinear":	{"JJ"},
"patrimonial":	{"JJ"},
"patrimony":	{"NN"},
"patriot":	{"NN"},
"patrioteer":	{"NN"},
"patriotic":	{"JJ"},
"patriotically":	{"RB"},
"patriotism":	{"NN"},
"patriots":	{"NNS"},
"patrisib":	{"NN"},
"patristic":	{"JJ"},
"patristical":	{"JJ"},
"patristics":	{"NN"},
"patroclus":	{"NN"},
"patrol":	{"VB","VBP","NN"},
"patrolled":	{"VBD","VBN"},
"patroller":	{"NN"},
"patrolling":	{"VBG"},
"patrolman":	{"NN"},
"patrolmen":	{"NNS"},
"patrology":	{"NN"},
"patrols":	{"NNS","VBZ"},
"patron":	{"NN"},
"patronage":	{"NN"},
"patronage-free":	{"JJ"},
"patroness":	{"NN"},
"patronesses":	{"NNS"},
"patronise":	{"VB","VBP"},
"patronised":	{"VBD","VBN"},
"patronises":	{"VBZ"},
"patronising":	{"VBG","JJ"},
"patronisingly":	{"RB"},
"patronize":	{"VB","VBP"},
"patronized":	{"VBD","VBN"},
"patronizes":	{"VBZ"},
"patronizing":	{"JJ","VBG"},
"patronizingly":	{"RB"},
"patronless":	{"JJ"},
"patronne":	{"NN"},
"patrons":	{"NNS"},
"patronym":	{"NN"},
"patronymic":	{"NN","JJ"},
"pats":	{"NNS","VBZ"},
"patsies":	{"NNS"},
"patsy":	{"NN"},
"patted":	{"VBD","VBN"},
"patten":	{"NN"},
"patter":	{"NN","VB","VBP"},
"pattered":	{"VBD","VBN"},
"pattering":	{"VBG"},
"pattern":	{"NN","VBP","VB"},
"pattern-maker":	{"NN"},
"pattern-shop":	{"NN"},
"patterned":	{"JJ","VBD","VBN"},
"patterning":	{"VBG","NN"},
"patternmaker":	{"NN"},
"patterns":	{"NNS","VBZ"},
"patters":	{"VBZ"},
"patties":	{"NNS"},
"patting":	{"NN","VBG"},
"patty":	{"NN"},
"patty-cake":	{"JJ"},
"patty-pan":	{"NN"},
"patwin":	{"NN"},
"patzer":	{"NN"},
"paucity":	{"NN"},
"pauli":	{"NN"},
"pauline":	{"JJ"},
"paunch":	{"NN"},
"paunches":	{"NNS"},
"paunchiness":	{"NN"},
"paunchy":	{"JJ"},
"pauper":	{"NN"},
"pauperisation":	{"NN"},
"pauperise":	{"VB","VBP"},
"pauperised":	{"VBD","VBN"},
"pauperises":	{"VBZ"},
"pauperising":	{"VBG"},
"pauperism":	{"NN"},
"pauperization":	{"NN"},
"pauperize":	{"VB","VBP"},
"pauperized":	{"VBD","VBN"},
"pauperizes":	{"VBZ"},
"pauperizing":	{"VBG"},
"paupers":	{"NNS"},
"pauropoda":	{"NN"},
"pause":	{"NN","VBP","VB"},
"paused":	{"VBD","VBN"},
"pauses":	{"VBZ","NNS"},
"pausing":	{"VBG"},
"pavage":	{"NN"},
"pavan":	{"NN"},
"pavane":	{"NN"},
"pave":	{"VB","VBP"},
"paved":	{"VBD","VBN","JJ"},
"pavement":	{"NN"},
"pavement-performance":	{"NN"},
"pavements":	{"NNS"},
"paves":	{"VBZ"},
"pavian":	{"FW"},
"pavilion":	{"NN"},
"pavilions":	{"NNS"},
"paving":	{"NN","VBG"},
"paving-equipment":	{"NN"},
"pavior":	{"NN"},
"paviour":	{"NN"},
"pavis":	{"NN"},
"pavise":	{"NN"},
"pavlova":	{"NN"},
"pavlovas":	{"NNS"},
"pavo":	{"NN"},
"pavonia":	{"NN"},
"paw":	{"NN","VB","VBP"},
"pawed":	{"VBD","VBN"},
"pawer":	{"NN"},
"pawing":	{"NN","VBG"},
"pawkier":	{"JJR"},
"pawkiest":	{"JJS"},
"pawky":	{"JJ"},
"pawl":	{"NN"},
"pawn":	{"NN","VB","VBP"},
"pawnbroker":	{"NN"},
"pawnbrokers":	{"NNS"},
"pawned":	{"VBD","VBN"},
"pawnee":	{"NN"},
"pawnees":	{"NNS"},
"pawning":	{"VBG"},
"pawns":	{"VBZ","NNS"},
"pawnshop":	{"NN"},
"pawnshops":	{"NNS"},
"pawpaw":	{"NN"},
"pawpaws":	{"NNS"},
"paws":	{"NNS","VBZ"},
"pax":	{"NN","UH"},
"pax-ordo":	{"NN"},
"paxam":	{"NN"},
"paxil":	{"NN"},
"paxson":	{"NN"},
"paxto":	{"NN"},
"paxton":	{"NN"},
"pay":	{"VB","NN","VBP"},
"pay-TV":	{"NN"},
"pay-and-benefit":	{"JJ"},
"pay-as-you-go":	{"JJ"},
"pay-back":	{"JJ"},
"pay-cable":	{"JJ","NN"},
"pay-down":	{"JJ"},
"pay-for-performance":	{"JJ"},
"pay-hike":	{"JJ"},
"pay-in-kind":	{"JJ","NN"},
"pay-later":	{"JJ"},
"pay-movie":	{"JJ"},
"pay-out":	{"NN"},
"pay-outs":	{"NNS"},
"pay-per-view":	{"JJ","NN"},
"pay-phone":	{"NN"},
"pay-station":	{"NN"},
"pay-television":	{"NN"},
"pay-tv":	{"NN"},
"payable":	{"JJ","NN"},
"payables":	{"NNS"},
"payback":	{"NN"},
"paybacks":	{"NNS"},
"paycheck":	{"NN"},
"paychecks":	{"NNS"},
"payday":	{"NN"},
"paydirt":	{"NN"},
"paydown":	{"NN"},
"payee":	{"NN"},
"payees":	{"NNS"},
"payena":	{"NN"},
"payer":	{"NN"},
"payers":	{"NNS"},
"paygrade":	{"NN"},
"paying":	{"VBG","NN"},
"payload":	{"NN"},
"payloads":	{"NNS"},
"paymaster":	{"NN"},
"paymasters":	{"NNS"},
"payment":	{"NN"},
"payment-in-kind":	{"JJ"},
"payment-system":	{"NN"},
"payments":	{"NNS"},
"paynim":	{"NN"},
"payoff":	{"NN"},
"payoffif":	{"NN"},
"payoffs":	{"NNS"},
"payola":	{"NN"},
"payout":	{"NN"},
"payout-bylaws":	{"NNS"},
"payouts":	{"NNS"},
"payroll":	{"NN"},
"payroll-paring":	{"JJ"},
"payroll-reduction":	{"NN"},
"payroll-tax":	{"NN"},
"payrolls":	{"NNS"},
"pays":	{"VBZ"},
"paysheet":	{"NN"},
"payslip":	{"NN"},
"payslips":	{"NNS"},
"paywall":	{"NN"},
"pb":	{"NN"},
"pbit":	{"NN"},
"pc":	{"NN"},
"pc-magazine":	{"JJ"},
"pcbs":	{"NNS"},
"pct":	{"NN"},
"pd":	{"JJ"},
"pdflp":	{"NN"},
"pdl":	{"NN"},
"pe":	{"NN"},
"pe-tsai":	{"NN"},
"pea":	{"NN"},
"pea-chick":	{"NN"},
"pea-green":	{"JJ","NN"},
"pea-shooter":	{"NN"},
"pea-shooters":	{"NNS"},
"pea-souper":	{"NN"},
"peace":	{"NN"},
"peace-keeping":	{"NN","JJ"},
"peace-loving":	{"JJ"},
"peace-pipe":	{"NN"},
"peace-pipes":	{"NNS"},
"peace-treaty":	{"NN"},
"peaceable":	{"JJ"},
"peaceableness":	{"NN"},
"peaceably":	{"RB"},
"peaceful":	{"JJ"},
"peacefully":	{"RB"},
"peacefulness":	{"NN"},
"peacekeeper":	{"NN"},
"peacekeepers":	{"NNS"},
"peacekeeping":	{"JJ","NN"},
"peacemaker":	{"NN"},
"peacemakers":	{"NNS"},
"peacemaking":	{"NN","JJ"},
"peacenik":	{"NN"},
"peaceniks":	{"NNS"},
"peacetime":	{"NN"},
"peach":	{"NN","JJ","VBP","VB"},
"peach-colored":	{"JJ"},
"peach-wood":	{"NN"},
"peached":	{"VBD","VBN"},
"peaches":	{"NNS","VBZ"},
"peachick":	{"NN"},
"peachier":	{"JJR"},
"peachiest":	{"JJS"},
"peaching":	{"VBG"},
"peachwood":	{"NN"},
"peachy":	{"JJ"},
"peachy-colored":	{"JJ"},
"peachy-coloured":	{"JJ"},
"peacoat":	{"NN"},
"peacock":	{"NN","VB","VBP"},
"peacock-blue":	{"JJ"},
"peacock-throne":	{"NN"},
"peacocked":	{"VBD","VBN"},
"peacocking":	{"VBG"},
"peacocks":	{"NNS","VBZ"},
"peafowl":	{"NN","NNS"},
"peafowls":	{"NNS"},
"peag":	{"NN"},
"peahen":	{"NN"},
"peahens":	{"NNS"},
"peak":	{"NN","JJ","VB","VBP"},
"peaked":	{"JJ","VBD","VBN"},
"peakier":	{"JJR"},
"peakiest":	{"JJS"},
"peaking":	{"VBG"},
"peaks":	{"NNS","VBZ"},
"peaky":	{"JJ"},
"peal":	{"NN","VB","VBP"},
"pealed":	{"VBD","VBN"},
"pealike":	{"JJ"},
"pealing":	{"VBG"},
"peals":	{"NNS","VBZ"},
"pean":	{"NN"},
"peans":	{"NNS"},
"peanut":	{"NN"},
"peanut-butter":	{"NN"},
"peanuts":	{"NNS"},
"pear":	{"NN"},
"pear-shaped":	{"JJ"},
"pearl":	{"NN","VB","VBP"},
"pearl-fish":	{"NN"},
"pearl-gray":	{"JJ"},
"pearl-handled":	{"JJ"},
"pearl-weed":	{"NN"},
"pearled":	{"VBD","VBN"},
"pearler":	{"NN","JJ"},
"pearlescent":	{"JJ"},
"pearlfish":	{"NN"},
"pearlier":	{"JJR"},
"pearliest":	{"JJS"},
"pearling":	{"VBG"},
"pearlite":	{"NN"},
"pearls":	{"NNS","VBZ"},
"pearlweed":	{"NN"},
"pearlwort":	{"NN"},
"pearly":	{"JJ"},
"pearly-white":	{"JJ"},
"pearmain":	{"NN"},
"pearmains":	{"NNS"},
"pears":	{"NNS"},
"peas":	{"NNS"},
"peasant":	{"NN"},
"peasanthood":	{"NN"},
"peasantry":	{"NN"},
"peasants":	{"NNS"},
"peasecod":	{"NN"},
"peashooter":	{"NN"},
"peashooters":	{"NNS"},
"peat":	{"NN"},
"peaty":	{"JJ"},
"peavey":	{"NN"},
"peavy":	{"NN"},
"peba":	{"NN"},
"pebble":	{"NN","VB","VBP"},
"pebble-grained":	{"JJ"},
"pebbled":	{"VBD","VBN"},
"pebbles":	{"NNS","VBZ"},
"pebbling":	{"VBG"},
"pebbly":	{"JJ"},
"pebibit":	{"NN"},
"pebibyte":	{"NN"},
"pecan":	{"NN"},
"pecans":	{"NNS"},
"peccable":	{"JJ"},
"peccadillo":	{"NN"},
"peccadilloes":	{"NNS"},
"peccadillos":	{"NNS"},
"peccant":	{"JJ"},
"peccaries":	{"NNS"},
"peccary":	{"NN"},
"peccavi":	{"NN"},
"pechora-class":	{"JJ"},
"peck":	{"NN","VB","VBP"},
"pecked":	{"VBD","VBN"},
"pecker":	{"NN"},
"peckers":	{"NNS"},
"peckerwood":	{"NN"},
"pecking":	{"VBG"},
"peckish":	{"JJ"},
"pecks":	{"NNS","VBZ"},
"pecopteris":	{"NN"},
"pecos":	{"NNS"},
"pecs":	{"NNS"},
"pectic":	{"JJ"},
"pectin":	{"NN"},
"pectinate":	{"JJ"},
"pectineal":	{"JJ"},
"pectinibranchia":	{"NN"},
"pectinidae":	{"NN"},
"pectins":	{"NNS"},
"pectoral":	{"JJ","NN"},
"pectoral-front":	{"JJ"},
"pectoral-ribcage":	{"NN"},
"pectoralis":	{"NN"},
"pectorals":	{"NNS"},
"pectus":	{"NN"},
"peculate":	{"VB","VBP"},
"peculated":	{"VBD","VBN"},
"peculates":	{"VBZ"},
"peculating":	{"VBG"},
"peculation":	{"NN"},
"peculations":	{"NNS"},
"peculator":	{"NN"},
"peculators":	{"NNS"},
"peculiar":	{"JJ"},
"peculiarities":	{"NNS"},
"peculiarity":	{"NN"},
"peculiarly":	{"RB"},
"pecuniary":	{"JJ"},
"pedagog":	{"NN"},
"pedagogic":	{"JJ"},
"pedagogical":	{"JJ"},
"pedagogically":	{"RB"},
"pedagogics":	{"NN"},
"pedagogs":	{"NNS"},
"pedagogue":	{"NN"},
"pedagogues":	{"NNS"},
"pedagogy":	{"NN"},
"pedal":	{"NN","VB","VBP"},
"pedaled":	{"VBD","VBN"},
"pedaler":	{"NN"},
"pedaliaceae":	{"NN"},
"pedaling":	{"VBG"},
"pedalled":	{"VBD","VBN"},
"pedaller":	{"NN"},
"pedalling":	{"VBG"},
"pedals":	{"NNS","VBZ"},
"pedant":	{"NN"},
"pedantic":	{"JJ"},
"pedantically":	{"RB"},
"pedantry":	{"NN"},
"pedants":	{"NNS"},
"pedate":	{"JJ"},
"peddle":	{"VB","VBP"},
"peddled":	{"VBD","VBN"},
"peddler":	{"NN"},
"peddlers":	{"NNS"},
"peddles":	{"VBZ"},
"peddling":	{"NN","VBG","JJ"},
"pederast":	{"NN"},
"pederastic":	{"JJ"},
"pederasts":	{"NNS"},
"pederasty":	{"NN"},
"pedes":	{"NNS"},
"pedesis":	{"NN"},
"pedestal":	{"NN","VB","VBP"},
"pedestaled":	{"VBD","VBN"},
"pedestaling":	{"VBG"},
"pedestalled":	{"VBD","VBN"},
"pedestalling":	{"VBG"},
"pedestals":	{"NNS","VBZ"},
"pedestrian":	{"NN","JJ"},
"pedestrians":	{"NNS"},
"pediamycin":	{"NN"},
"pediapred":	{"NN"},
"pediatric":	{"JJ"},
"pediatrician":	{"NN"},
"pediatricians":	{"NNS"},
"pediatrics":	{"NN"},
"pediatrist":	{"NN"},
"pediatrists":	{"NNS"},
"pedicab":	{"NN"},
"pedicabs":	{"NNS"},
"pedicel":	{"NN"},
"pedicels":	{"NNS"},
"pedicle":	{"NN"},
"pedicles":	{"NNS"},
"pediculati":	{"NN"},
"pediculicide":	{"NN"},
"pediculidae":	{"NN"},
"pediculosis":	{"NN"},
"pediculus":	{"NN"},
"pedicure":	{"NN"},
"pedicures":	{"NNS"},
"pedigree":	{"NN","JJ"},
"pedigree-contemplating":	{"VBG"},
"pedigreed":	{"JJ"},
"pedigrees":	{"NNS"},
"pedilanthus":	{"NN"},
"pediment":	{"NN"},
"pedimental":	{"JJ"},
"pedimented":	{"JJ"},
"pediments":	{"NNS"},
"pediocactus":	{"NN"},
"pedioecetes":	{"NNS"},
"pedionomus":	{"NN"},
"pedipalpi":	{"NN"},
"pedlar":	{"NN"},
"pedlars":	{"NNS"},
"pedodontist":	{"NN"},
"pedology":	{"NN"},
"pedometer":	{"NN"},
"pedometers":	{"NNS"},
"pedophile":	{"NN"},
"pedophiles":	{"NNS"},
"pedophilia":	{"NN"},
"peduncle":	{"NN"},
"peduncles":	{"NNS"},
"pedunculate":	{"JJ"},
"pedwood":	{"NN"},
"pee":	{"VB","VBP","NN"},
"pee-pee":	{"VB","VBP"},
"pee-peed":	{"VBD","VBN"},
"pee-peeing":	{"VBG"},
"pee-pees":	{"VBZ"},
"pee-wee":	{"JJ"},
"peed":	{"VBD","VBN"},
"peeing":	{"VBG"},
"peek":	{"VB","VBP","NN"},
"peekaboo":	{"NN","JJ"},
"peeked":	{"VBD","VBN"},
"peeking":	{"VBG"},
"peeks":	{"VBZ","NNS"},
"peel":	{"VB","VBP","NN"},
"peel-off":	{"JJ"},
"peelback":	{"JJ"},
"peeled":	{"JJ","VBD","VBN"},
"peeler":	{"NN"},
"peelers":	{"NNS"},
"peeling":	{"NN","VBG"},
"peelings":	{"NNS"},
"peels":	{"VBZ","NNS"},
"peen":	{"NN","VB","VBP"},
"peened":	{"VBD","VBN"},
"peening":	{"VBG"},
"peens":	{"NNS","VBZ"},
"peep":	{"VB","VBP","NN"},
"peep-hole":	{"NN"},
"peep-holes":	{"NNS"},
"peep-show":	{"NN"},
"peep-shows":	{"NNS"},
"peeped":	{"VBD","VBN"},
"peeper":	{"NN"},
"peepers":	{"NNS"},
"peephole":	{"NN"},
"peepholes":	{"NNS"},
"peeping":	{"VBG"},
"peeps":	{"VBZ"},
"peepshow":	{"NN"},
"peepshows":	{"NNS"},
"peepul":	{"NN"},
"peepuls":	{"NNS"},
"peer":	{"NN","VB","VBP"},
"peer-group":	{"JJ"},
"peerage":	{"NN"},
"peerages":	{"NNS"},
"peered":	{"VBD","VBN"},
"peeress":	{"NN"},
"peeresses":	{"NNS"},
"peering":	{"VBG"},
"peerless":	{"JJ"},
"peers":	{"NNS","VBZ"},
"pees":	{"VBZ"},
"peeve":	{"VB","VBP"},
"peeved":	{"JJ","VBD","VBN"},
"peeves":	{"VBZ"},
"peeving":	{"VBG"},
"peevish":	{"JJ"},
"peevishly":	{"RB"},
"peevishness":	{"NN"},
"peewee":	{"NN"},
"peewees":	{"NNS"},
"peewit":	{"NN"},
"peewits":	{"NNS"},
"peg":	{"NN","VB","VBP"},
"peg-leg":	{"NN"},
"peg-legs":	{"NNS"},
"pegboard":	{"NN"},
"pegboards":	{"NNS"},
"pegged":	{"VBD","VBN"},
"pegged-down":	{"JJ"},
"peggin":	{"NN"},
"pegging":	{"VBG"},
"pegmatite":	{"NN"},
"pegmatites":	{"NNS"},
"pegs":	{"VBZ","NNS"},
"pehlevi":	{"NN"},
"peignoir":	{"NN"},
"peignoirs":	{"NNS"},
"peiping":	{"NN"},
"peireskia":	{"NN"},
"pejorative":	{"JJ"},
"pejoratively":	{"RB"},
"pekan":	{"NN"},
"peke":	{"NN"},
"pekes":	{"NNS"},
"pekinese":	{"NN","NNS"},
"pekineses":	{"NNS"},
"pekoe":	{"NN"},
"pel":	{"NN"},
"pelage":	{"NN"},
"pelages":	{"NNS"},
"pelagianism":	{"NN"},
"pelagic":	{"JJ"},
"pelagius":	{"NN"},
"pelargonium":	{"NN"},
"pelecanidae":	{"NN"},
"pelecaniformes":	{"NNS"},
"pelecanoididae":	{"NN"},
"pelecanus":	{"NN"},
"pelecypod":	{"JJ","NN"},
"pelecypodous":	{"JJ"},
"peleus":	{"NN"},
"pelew":	{"NN"},
"pelf":	{"NN"},
"pelham":	{"NN"},
"pelican":	{"NN"},
"pelicans":	{"NNS"},
"peliosis":	{"NN"},
"pelisse":	{"NN"},
"pell":	{"NN"},
"pell-mell":	{"RB"},
"pellaea":	{"NN"},
"pellagra":	{"NN"},
"pellet":	{"NN","VB","VBP"},
"pelleted":	{"VBD","VBN"},
"pelleting":	{"VBG"},
"pellets":	{"NNS","VBZ"},
"pellicle":	{"NN"},
"pellicularia":	{"NN"},
"pellitory":	{"NN"},
"pellitory-of-spain":	{"NN"},
"pellitory-of-the-wall":	{"NN"},
"pellucid":	{"JJ"},
"pellucidity":	{"NN"},
"pellucidly":	{"RB"},
"pellucidness":	{"NN"},
"pelmet":	{"NN"},
"pelmets":	{"NNS"},
"pelobatidae":	{"NN"},
"peloponnesian":	{"JJ"},
"peloponnesus":	{"NN"},
"pelota":	{"NN"},
"pels":	{"NNS"},
"pelt":	{"NN","VB","VBP"},
"peltandra":	{"NN"},
"peltate":	{"JJ"},
"pelted":	{"VBD","VBN"},
"pelter":	{"NN"},
"pelters":	{"NNS"},
"pelting":	{"VBG"},
"peltiphyllum":	{"NN"},
"peltry":	{"NN"},
"pelts":	{"NNS","VBZ"},
"peludo":	{"NN"},
"pelves":	{"NNS"},
"pelvic":	{"JJ"},
"pelvimeter":	{"NN"},
"pelvimetry":	{"NN"},
"pelvis":	{"NN"},
"pelvises":	{"NNS"},
"pelycosaur":	{"NN"},
"pelycosauria":	{"NN"},
"pembroke":	{"NN"},
"pembrolizumab":	{"NN"},
"pemican":	{"NN"},
"pemmican":	{"NN"},
"pempheridae":	{"NN"},
"pemphigous":	{"JJ"},
"pemphigus":	{"NN"},
"pen":	{"NN","VB","VBP"},
"pen-and-ink":	{"NN"},
"pen-and-pencil":	{"JJ"},
"pen-friend":	{"NN"},
"pen-friends":	{"NNS"},
"pen-name":	{"NN"},
"pen-names":	{"NNS"},
"pen-pal":	{"NN"},
"pen-pals":	{"NNS"},
"pen-pusher":	{"NN"},
"pen-pushers":	{"NNS"},
"pen-pushing":	{"NN"},
"pen-tail":	{"NN"},
"penal":	{"JJ"},
"penalisation":	{"NN"},
"penalise":	{"VB","VBP"},
"penalised":	{"VBD","VBN"},
"penalises":	{"VBZ"},
"penalising":	{"VBG"},
"penalization":	{"NN"},
"penalize":	{"VB","VBP"},
"penalized":	{"VBD","VBN"},
"penalizes":	{"VBZ"},
"penalizing":	{"VBG"},
"penally":	{"RB"},
"penalties":	{"NNS"},
"penalty":	{"NN"},
"penalty-free":	{"JJ"},
"penalty-lending":	{"JJ"},
"penance":	{"NN"},
"penances":	{"NNS"},
"pence":	{"NNS"},
"penchant":	{"NN"},
"pencil":	{"NN","VB","VBP"},
"pencil-and-sepia":	{"JJ"},
"pencil-pusher":	{"NN"},
"penciled":	{"JJ","VBD","VBN"},
"penciling":	{"VBG"},
"pencilled":	{"JJ","VBD","VBN"},
"pencilling":	{"VBG"},
"pencils":	{"VBZ","NNS"},
"pendant":	{"NN","JJ"},
"pendants":	{"NNS"},
"pendent":	{"JJ"},
"pending":	{"JJ","IN"},
"pendragon":	{"NN"},
"pendulous":	{"JJ"},
"pendulum":	{"NN"},
"pendulums":	{"NNS"},
"peneidae":	{"NN"},
"peneplain":	{"NN"},
"peneplane":	{"NN"},
"penetrability":	{"NN"},
"penetrable":	{"JJ"},
"penetralia":	{"NN"},
"penetrate":	{"VB","VBP"},
"penetrated":	{"VBN","VBD"},
"penetrates":	{"VBZ","NNS"},
"penetrating":	{"JJ","VBG"},
"penetratingly":	{"RB"},
"penetration":	{"NN"},
"penetrations":	{"NNS"},
"penetrative":	{"JJ"},
"penetratively":	{"RB"},
"penetrator":	{"NN"},
"penetrators":	{"NNS"},
"peneus":	{"NNS"},
"pengo":	{"NN"},
"penguin":	{"NN"},
"penguins":	{"NNS"},
"penial":	{"JJ"},
"penicillamine":	{"NN"},
"penicillin":	{"NN"},
"penicillin-resistant":	{"JJ"},
"penicillinase":	{"NN"},
"penicillium":	{"NN"},
"penile":	{"JJ"},
"peninsula":	{"NN"},
"peninsular":	{"JJ"},
"peninsulas":	{"NNS"},
"penis":	{"NN"},
"penises":	{"NNS"},
"penitence":	{"NN"},
"penitent":	{"NN","JJ"},
"penitential":	{"JJ","NN"},
"penitentially":	{"RB"},
"penitentials":	{"NNS"},
"penitentiaries":	{"NNS"},
"penitentiary":	{"NN","JJ"},
"penitently":	{"RB"},
"penitents":	{"NNS"},
"penknife":	{"NN"},
"penknives":	{"NNS"},
"penlight":	{"NN"},
"penlights":	{"NNS"},
"penman":	{"NN"},
"penmanship":	{"NN"},
"penmen":	{"NNS"},
"penn'orth":	{"NN"},
"pennant":	{"NN"},
"pennants":	{"NNS"},
"pennate":	{"JJ"},
"pennatula":	{"NN"},
"pennatulidae":	{"NN"},
"penne":	{"NN"},
"penned":	{"VBD","VBN"},
"penney":	{"NN"},
"penni":	{"NN"},
"pennies":	{"NNS"},
"penniless":	{"JJ"},
"pennilessness":	{"NN"},
"penning":	{"VBG"},
"pennisetum":	{"NN"},
"pennon":	{"NN"},
"pennoncel":	{"NN"},
"pennoncelle":	{"NN"},
"pennons":	{"NNS"},
"penny":	{"NN"},
"penny-ante":	{"JJ"},
"penny-brokerage":	{"JJ"},
"penny-pinch":	{"VB","VBP"},
"penny-pinched":	{"VBD","VBN"},
"penny-pinches":	{"VBZ"},
"penny-pinching":	{"JJ","NN","VBG"},
"penny-stock":	{"JJ","NN"},
"penny-stockbroker":	{"NN"},
"penny-stocks":	{"NNS"},
"penny-wise":	{"JJ"},
"pennycress":	{"NN"},
"pennyroyal":	{"NN"},
"pennystock":	{"NN"},
"pennyweight":	{"NN"},
"pennywhistle":	{"NN"},
"pennyworth":	{"NN"},
"penobscot":	{"NN"},
"penoche":	{"NN"},
"penologist":	{"NN"},
"penologists":	{"NNS"},
"penology":	{"NN"},
"penoncel":	{"NN"},
"penpusher":	{"NN"},
"pens":	{"NNS","VBZ"},
"pensacola":	{"NN"},
"pension":	{"NN","VB","VBP"},
"pension-fund":	{"NN","JJ"},
"pension-industry":	{"JJ","NN"},
"pension-insurance":	{"JJ"},
"pension-minded":	{"JJ"},
"pension-plan":	{"NN"},
"pension-tax":	{"NN","JJ"},
"pensionable":	{"JJ"},
"pensionaries":	{"NNS"},
"pensionary":	{"NN"},
"pensioned":	{"VBD","VBN"},
"pensioner":	{"NN"},
"pensioners":	{"NNS"},
"pensioning":	{"VBG"},
"pensions":	{"NNS","VBZ"},
"pensive":	{"JJ"},
"pensively":	{"RB"},
"pensiveness":	{"NN"},
"penstemon":	{"NN"},
"penstock":	{"NN"},
"pent":	{"JJ"},
"pent-up":	{"JJ"},
"pentacle":	{"NN"},
"pentacles":	{"NNS"},
"pentad":	{"NN"},
"pentaerythritol":	{"NN"},
"pentagon":	{"NN"},
"pentagon-related":	{"JJ"},
"pentagonal":	{"JJ"},
"pentagons":	{"NNS"},
"pentagram":	{"NN"},
"pentagrams":	{"NNS"},
"pentahedron":	{"NN"},
"pentail":	{"NN"},
"pentamerous":	{"JJ"},
"pentameter":	{"NN"},
"pentameters":	{"NNS"},
"pentamethylenetetrazol":	{"NN"},
"pentamidine":	{"NN"},
"pentangle":	{"NN"},
"pentangular":	{"JJ"},
"pentastomid":	{"NN"},
"pentastomida":	{"NN"},
"pentasyllabic":	{"JJ"},
"pentateuch":	{"NN"},
"pentathlete":	{"NN"},
"pentathlon":	{"NN"},
"pentathlons":	{"NNS"},
"pentatone":	{"NN"},
"pentatonic":	{"JJ"},
"pentavalent":	{"JJ"},
"pentazocine":	{"NN"},
"pentecost":	{"NN"},
"pentecostalism":	{"NN"},
"pentecostalist":	{"NN"},
"pentecostalists":	{"NNS"},
"penthouse":	{"NN"},
"penthouses":	{"NNS"},
"pentimento":	{"NN"},
"pentlandite":	{"NN"},
"pentobarbital":	{"NN"},
"pentode":	{"NN"},
"pentose":	{"NN"},
"pentothal":	{"NN"},
"pentoxide":	{"NN"},
"pentoxifylline":	{"NN"},
"pentylenetetrazol":	{"NN"},
"penuche":	{"NN"},
"penuchle":	{"NN"},
"penult":	{"NN"},
"penultima":	{"NN"},
"penultimate":	{"JJ"},
"penumbra":	{"NN"},
"penumbrae":	{"NNS"},
"penumbral":	{"JJ"},
"penumbras":	{"NNS"},
"penurious":	{"JJ"},
"penuriously":	{"RB"},
"penuriousness":	{"NN"},
"penury":	{"NN"},
"penutian":	{"NN"},
"peon":	{"NN"},
"peonage":	{"NN"},
"peonies":	{"NNS"},
"peons":	{"NNS"},
"peony":	{"NN"},
"people":	{"NNS","NN","VB","VBP"},
"people-oriented":	{"JJ"},
"peopled":	{"VBD","VBN"},
"peoples":	{"NNS","VBZ"},
"peopling":	{"VBG"},
"pep":	{"NN","VBP","VB"},
"pepcid":	{"NN"},
"peperomia":	{"NN"},
"pepin":	{"NN"},
"peplos":	{"NN"},
"peplum":	{"NN"},
"peplus":	{"NNS"},
"pepped":	{"VBD","VBN"},
"pepper":	{"NN","VB","VBP"},
"pepper-and-salt":	{"JJ"},
"pepper-coated":	{"JJ"},
"pepper-mill":	{"NN"},
"pepper-mills":	{"NNS"},
"pepper-pot":	{"NN"},
"pepper-pots":	{"NNS"},
"peppercorn":	{"NN"},
"peppercorns":	{"NNS"},
"peppered":	{"VBD","VBN"},
"pepperidge":	{"NN"},
"pepperiness":	{"NN"},
"peppering":	{"VBG","NN"},
"peppermint":	{"NN"},
"peppermints":	{"NNS"},
"pepperoni":	{"NN"},
"peppers":	{"VBZ","NNS"},
"pepperwood":	{"NN"},
"pepperwort":	{"NN"},
"peppery":	{"JJ"},
"peppiness":	{"NN"},
"pepping":	{"VBG"},
"peppy":	{"JJ"},
"peps":	{"VBZ"},
"pepsin":	{"NN"},
"pepsinogen":	{"NN"},
"peptic":	{"JJ"},
"peptidase":	{"NN"},
"peptidases":	{"NNS"},
"peptide":	{"NN"},
"peptides":	{"NNS"},
"peptisation":	{"NN"},
"peptise":	{"VB","VBP"},
"peptised":	{"VBD","VBN"},
"peptises":	{"VBZ"},
"peptising":	{"VBG"},
"peptization":	{"NN"},
"peptize":	{"VB","VBP"},
"peptized":	{"VBD","VBN"},
"peptizes":	{"VBZ"},
"peptizing":	{"VBG"},
"pepto-bismal":	{"NN"},
"peptone":	{"NN"},
"per":	{"IN"},
"per-ad":	{"JJ"},
"per-capita":	{"JJ","RB"},
"per-day":	{"JJ"},
"per-game":	{"JJ"},
"per-passenger":	{"NN"},
"per-pupil":	{"JJ"},
"per-sale":	{"JJ"},
"per-share":	{"JJ","NN"},
"per-store":	{"JJ"},
"per-subscriber":	{"NN"},
"per-ton":	{"JJ"},
"per-year":	{"JJ"},
"peradventure":	{"NN","RB"},
"perambulate":	{"VB","VBP"},
"perambulated":	{"VBD","VBN"},
"perambulates":	{"VBZ"},
"perambulating":	{"VBG"},
"perambulation":	{"NN"},
"perambulations":	{"NNS"},
"perambulator":	{"NN"},
"perambulators":	{"NNS"},
"peramelidae":	{"NN"},
"perca":	{"NN"},
"percale":	{"NN"},
"perceivable":	{"JJ"},
"perceive":	{"VB","VBP"},
"perceived":	{"VBN","VBD"},
"perceiver":	{"NN"},
"perceivers":	{"NNS"},
"perceives":	{"VBZ"},
"perceiving":	{"VBG"},
"percent":	{"NN","JJ","RB"},
"percentage":	{"NN"},
"percentage-point":	{"JJ"},
"percentages":	{"NNS"},
"percenter":	{"NN"},
"percentile":	{"NN"},
"percentiles":	{"NNS"},
"percept":	{"NN"},
"perceptibility":	{"NN"},
"perceptible":	{"JJ"},
"perceptibly":	{"RB"},
"perception":	{"NN"},
"perceptions":	{"NNS"},
"perceptive":	{"JJ"},
"perceptively":	{"RB"},
"perceptiveness":	{"NN"},
"perceptivity":	{"NN"},
"percepts":	{"NNS"},
"perceptual":	{"JJ"},
"perceptually":	{"RB"},
"perch":	{"NN","VB","VBP","NNS"},
"perchance":	{"RB"},
"perched":	{"VBD","VBN"},
"percher":	{"NN"},
"percheron":	{"NN"},
"perchers":	{"NNS"},
"perches":	{"NNS","VBZ"},
"perching":	{"VBG"},
"perchlorate":	{"NN"},
"perchloride":	{"NN"},
"perchloromethane":	{"NN"},
"percidae":	{"NN"},
"perciformes":	{"NNS"},
"percina":	{"NN"},
"percipience":	{"NN"},
"percipient":	{"JJ"},
"percoid":	{"NN"},
"percoidea":	{"NN"},
"percoidean":	{"NN"},
"percolate":	{"VB","VBP"},
"percolated":	{"VBD","VBN"},
"percolates":	{"VBZ"},
"percolating":	{"VBG"},
"percolation":	{"NN"},
"percolations":	{"NNS"},
"percolator":	{"NN"},
"percolators":	{"NNS"},
"percomorphi":	{"NN"},
"percophidae":	{"NN"},
"percuss":	{"VB","VBP"},
"percussed":	{"VBD","VBN"},
"percusses":	{"VBZ"},
"percussing":	{"VBG"},
"percussion":	{"NN"},
"percussionist":	{"NN"},
"percussionists":	{"NNS"},
"percussive":	{"JJ"},
"percussor":	{"NN"},
"percutaneous":	{"JJ"},
"percy":	{"NN"},
"perdicidae":	{"NN"},
"perdicinae":	{"NN"},
"perdition":	{"NN"},
"perdix":	{"NN"},
"perdurability":	{"NN"},
"perdurable":	{"JJ"},
"peregrinate":	{"VB","VBP"},
"peregrinated":	{"VBD","VBN"},
"peregrinates":	{"VBZ"},
"peregrinating":	{"VBG"},
"peregrination":	{"NN"},
"peregrinations":	{"NNS"},
"peregrine":	{"JJ","NN"},
"peregrines":	{"NNS"},
"perejil":	{"NN"},
"peremptorily":	{"RB"},
"peremptory":	{"JJ"},
"perennate":	{"VB","VBP"},
"perennated":	{"VBD","VBN"},
"perennates":	{"VBZ"},
"perennating":	{"VBG"},
"perennation":	{"NN"},
"perennial":	{"JJ","NN"},
"perennially":	{"RB"},
"perennials":	{"NNS"},
"pereskia":	{"NN"},
"perestroika":	{"NN"},
"perfect":	{"JJ","VBP","NN","VB"},
"perfect-attendance":	{"NN"},
"perfecta":	{"NN"},
"perfectability":	{"NN"},
"perfected":	{"VBD","VBN"},
"perfecter":	{"NN"},
"perfectibility":	{"NN"},
"perfectible":	{"JJ"},
"perfecting":	{"VBG"},
"perfection":	{"NN"},
"perfectionism":	{"NN"},
"perfectionist":	{"NN","JJ"},
"perfectionists":	{"NNS"},
"perfective":	{"NN","JJ"},
"perfectives":	{"NNS"},
"perfectly":	{"RB"},
"perfects":	{"VBZ"},
"perfervid":	{"JJ"},
"perfidious":	{"JJ"},
"perfidiously":	{"RB"},
"perfidiousness":	{"NN"},
"perfidy":	{"NN"},
"perfluorocarbon":	{"NN"},
"perfoliate":	{"JJ"},
"perforate":	{"VB","VBP"},
"perforated":	{"JJ","VBD","VBN"},
"perforates":	{"VBZ"},
"perforating":	{"VBG"},
"perforation":	{"NN"},
"perforations":	{"NNS"},
"perforce":	{"RB"},
"perform":	{"VB","VBP"},
"performance":	{"NN","JJ"},
"performance-based":	{"JJ"},
"performance-capacity":	{"NN"},
"performance-oriented":	{"JJ"},
"performance-related":	{"JJ"},
"performance-sharing":	{"JJ"},
"performances":	{"NNS"},
"performed":	{"VBN","VBD"},
"performer":	{"NN"},
"performers":	{"NNS"},
"performing":	{"VBG"},
"performing-arts":	{"NNS"},
"performs":	{"VBZ"},
"perfume":	{"NN","VB","VBP"},
"perfumed":	{"JJ","VBD","VBN"},
"perfumer":	{"NN"},
"perfumeries":	{"NNS"},
"perfumers":	{"NNS"},
"perfumery":	{"NN"},
"perfumes":	{"VBZ","NNS"},
"perfuming":	{"VBG"},
"perfunctorily":	{"RB"},
"perfunctory":	{"JJ"},
"perfuse":	{"VB","VBP"},
"perfused":	{"VBD","VBN"},
"perfuses":	{"VBZ"},
"perfusing":	{"VBG"},
"perfusion":	{"NN"},
"pergamum":	{"NN"},
"pergola":	{"NN"},
"pergolas":	{"NNS"},
"perhaps":	{"RB"},
"perhaps-decisive":	{"JJ"},
"peri":	{"NN"},
"periactin":	{"NN"},
"perianal":	{"JJ"},
"perianth":	{"NN"},
"periapsis":	{"NN"},
"periarteritis":	{"NN"},
"pericallis":	{"NN"},
"pericardiac":	{"JJ"},
"pericardial":	{"JJ"},
"pericarditis":	{"NN"},
"pericardium":	{"NN"},
"pericarp":	{"NN"},
"pericementoclasia":	{"NN"},
"periclase":	{"NN"},
"peridinian":	{"NN"},
"peridiniidae":	{"NN"},
"peridinium":	{"NN"},
"peridium":	{"NN"},
"peridontal":	{"JJ"},
"peridot":	{"NN"},
"peridotite":	{"NN"},
"perigee":	{"NN"},
"perigees":	{"NNS"},
"perigon":	{"NN"},
"perigonal":	{"JJ"},
"perigone":	{"NN"},
"perigonium":	{"NN"},
"perihelia":	{"NNS"},
"perihelion":	{"NN"},
"perijove":	{"NN"},
"peril":	{"NN","VB","VBP"},
"periled":	{"VBD","VBN"},
"periling":	{"VBG"},
"perilla":	{"NN"},
"perilled":	{"VBD","VBN"},
"perilling":	{"VBG"},
"perilous":	{"JJ"},
"perilously":	{"RB"},
"perilousness":	{"NN"},
"perils":	{"NNS","VBZ"},
"perilune":	{"NN"},
"perilunes":	{"NNS"},
"perilymph":	{"NN"},
"perimeter":	{"NN"},
"perimeters":	{"NNS"},
"perimysium":	{"NN"},
"perinasal":	{"JJ"},
"perinatal":	{"JJ"},
"perinatally":	{"RB"},
"perinatologist":	{"NN"},
"perinatologists":	{"NNS"},
"perinatology":	{"NN"},
"perinea":	{"NNS"},
"perineal":	{"JJ"},
"perineotomy":	{"NN"},
"perineum":	{"NN"},
"perineuria":	{"NNS"},
"perineurium":	{"NN"},
"period":	{"NN","JJ"},
"periodic":	{"JJ"},
"periodical":	{"NN","JJ"},
"periodically":	{"RB"},
"periodicals":	{"NNS"},
"periodicities":	{"NNS"},
"periodicity":	{"NN"},
"periodicos":	{"FW"},
"periodontal":	{"JJ"},
"periodontia":	{"NN"},
"periodontic":	{"JJ"},
"periodontics":	{"NN"},
"periodontist":	{"NN"},
"periodontists":	{"NNS"},
"periodontitis":	{"NN"},
"periods":	{"NNS"},
"perioperative":	{"JJ"},
"periophthalmus":	{"NN"},
"periostea":	{"NNS"},
"periosteum":	{"NN"},
"peripatetic":	{"JJ","NN"},
"peripatetically":	{"RB"},
"peripateticism":	{"NN"},
"peripatetics":	{"NNS"},
"peripatidae":	{"NN"},
"peripatopsidae":	{"NN"},
"peripatopsis":	{"NN"},
"peripatus":	{"NNS"},
"peripeteia":	{"NN"},
"peripetia":	{"NN"},
"peripety":	{"NN"},
"peripheral":	{"JJ","NN"},
"peripherally":	{"RB"},
"peripherals":	{"NNS"},
"peripheries":	{"NNS"},
"periphery":	{"NN"},
"periphrases":	{"NNS"},
"periphrasis":	{"NN"},
"periphrastic":	{"JJ"},
"periphrastically":	{"RB"},
"periplaneta":	{"NN"},
"periploca":	{"NN"},
"peripteral":	{"JJ"},
"perirhinal":	{"JJ"},
"periscope":	{"NN"},
"periscopes":	{"NNS"},
"periselene":	{"NN"},
"perish":	{"VB","VBP"},
"perishability":	{"NN"},
"perishable":	{"JJ"},
"perishableness":	{"NN"},
"perishables":	{"NNS"},
"perished":	{"JJ","VBD","VBN"},
"perisher":	{"NN"},
"perishers":	{"NNS"},
"perishes":	{"VBZ"},
"perishing":	{"VBG","JJ"},
"perishingly":	{"RB"},
"perisoreus":	{"NNS"},
"perisperm":	{"NN"},
"perissodactyl":	{"NN"},
"perissodactyla":	{"NN"},
"peristalsis":	{"NN"},
"peristediinae":	{"NN"},
"peristedion":	{"NN"},
"peristome":	{"NN"},
"peristylar":	{"JJ"},
"peristyle":	{"NN"},
"peristyles":	{"NNS"},
"perithecium":	{"NN"},
"perithelial":	{"JJ"},
"perithelium":	{"NN"},
"peritoneal":	{"JJ"},
"peritoneum":	{"NN"},
"peritonitis":	{"NN"},
"peritrate":	{"NN"},
"peritrichous":	{"JJ"},
"periwig":	{"NN"},
"periwigged":	{"JJ"},
"periwinkle":	{"NN"},
"periwinkles":	{"NNS"},
"perjure":	{"VB","VBP"},
"perjured":	{"VBD","VBN","JJ"},
"perjurer":	{"NN"},
"perjurers":	{"NNS"},
"perjures":	{"VBZ"},
"perjuring":	{"VBG"},
"perjury":	{"NN"},
"perk":	{"VB","VBP","NN"},
"perked":	{"VBD","VBN"},
"perkier":	{"JJR"},
"perkiest":	{"JJS"},
"perkily":	{"RB"},
"perkiness":	{"NN"},
"perking":	{"VBG"},
"perks":	{"VBZ","NNS"},
"perky":	{"JJ"},
"perleche":	{"NN"},
"perm":	{"NN","VB","VBP"},
"permafrost":	{"NN"},
"permalloy":	{"NN"},
"permalloys":	{"NNS"},
"permanence":	{"NN"},
"permanencies":	{"NNS"},
"permanency":	{"NN"},
"permanent":	{"JJ","NN"},
"permanent-insurance":	{"JJ"},
"permanent-looking":	{"JJ"},
"permanent-press":	{"JJ"},
"permanently":	{"RB"},
"permanents":	{"NNS"},
"permanganate":	{"NN"},
"permeability":	{"NN"},
"permeable":	{"JJ"},
"permeableness":	{"NN"},
"permeant":	{"JJ"},
"permeate":	{"VB","VBP"},
"permeated":	{"VBN","VBD"},
"permeates":	{"VBZ"},
"permeating":	{"VBG"},
"permeation":	{"NN"},
"permeative":	{"JJ"},
"permed":	{"VBD","VBN"},
"permic":	{"NN"},
"perming":	{"VBG","NN"},
"permissibility":	{"NN"},
"permissible":	{"JJ"},
"permissibly":	{"RB"},
"permission":	{"NN"},
"permissions":	{"NNS"},
"permissive":	{"JJ"},
"permissively":	{"RB"},
"permissiveness":	{"NN"},
"permit":	{"VB","NN","VBP"},
"permits":	{"NNS","VBZ"},
"permitted":	{"VBN","VBD"},
"permitting":	{"VBG"},
"perms":	{"NNS","VBZ"},
"permutability":	{"NN"},
"permutable":	{"JJ"},
"permutableness":	{"NN"},
"permutably":	{"RB"},
"permutation":	{"NN"},
"permutations":	{"NNS"},
"permute":	{"VB","VBP"},
"permuted":	{"VBD","VBN"},
"permutes":	{"VBZ"},
"permuting":	{"VBG"},
"pernambuco":	{"NN"},
"pernicious":	{"JJ"},
"perniciously":	{"RB"},
"perniciousness":	{"NN"},
"pernickety":	{"JJ"},
"pernio":	{"NN"},
"pernis":	{"NNS"},
"perodicticus":	{"NN"},
"perognathus":	{"NN"},
"peromyscus":	{"NN"},
"peroneal":	{"JJ"},
"peronei":	{"NNS"},
"peroneus":	{"NN"},
"peronist":	{"NN"},
"peronospora":	{"NN"},
"peronosporaceae":	{"NN"},
"peronosporales":	{"NNS"},
"perorate":	{"VB","VBP"},
"perorated":	{"VBD","VBN"},
"perorates":	{"VBZ"},
"perorating":	{"VBG"},
"peroration":	{"NN"},
"perorations":	{"NNS"},
"perot-eds":	{"JJ"},
"peroxidase":	{"NN"},
"peroxide":	{"NN","VB","VBP"},
"peroxided":	{"VBD","VBN"},
"peroxides":	{"NNS","VBZ"},
"peroxiding":	{"VBG"},
"peroxydisulphate":	{"NN"},
"perpendicular":	{"JJ","NN"},
"perpendicularity":	{"NN"},
"perpendicularly":	{"RB"},
"perpendiculars":	{"NNS"},
"perpetrate":	{"VB","VBP"},
"perpetrated":	{"VBD","VBN"},
"perpetrates":	{"VBZ"},
"perpetrating":	{"VBG"},
"perpetration":	{"NN"},
"perpetrator":	{"NN"},
"perpetrators":	{"NNS"},
"perpetual":	{"JJ"},
"perpetually":	{"RB"},
"perpetuate":	{"VB","VBP"},
"perpetuated":	{"VBD","VBN"},
"perpetuates":	{"VBZ"},
"perpetuating":	{"VBG"},
"perpetuation":	{"NN"},
"perpetuity":	{"NN"},
"perphenazine":	{"NN"},
"perplex":	{"VB","VBP"},
"perplexed":	{"JJ","VBD","VBN"},
"perplexedly":	{"RB"},
"perplexes":	{"VBZ"},
"perplexing":	{"JJ","VBG"},
"perplexities":	{"NNS"},
"perplexity":	{"NN"},
"perquisite":	{"NN"},
"perquisites":	{"NNS"},
"persea":	{"NN"},
"persecute":	{"VB","VBP"},
"persecuted":	{"VBD","VBN"},
"persecutes":	{"VBZ"},
"persecuting":	{"VBG"},
"persecution":	{"NN"},
"persecutions":	{"NNS"},
"persecutor":	{"NN"},
"persecutors":	{"NNS"},
"persecutory":	{"JJ"},
"persepolis":	{"NN"},
"perseverance":	{"NN"},
"perseverant":	{"JJ"},
"perseverate":	{"VB","VBP"},
"perseverated":	{"VBD","VBN"},
"perseverates":	{"VBZ"},
"perseverating":	{"VBG"},
"perseveration":	{"NN"},
"persevere":	{"VB","VBP"},
"persevered":	{"VBD","VBN"},
"perseveres":	{"VBZ"},
"persevering":	{"VBG","JJ"},
"perseveringly":	{"RB"},
"pershare":	{"JJ"},
"pershing":	{"NN"},
"persianesque":	{"JJ"},
"persiflage":	{"NN"},
"persimmon":	{"NN"},
"persimmons":	{"NNS"},
"persist":	{"VB","VBP"},
"persisted":	{"VBD","VBN"},
"persistence":	{"NN"},
"persistency":	{"NN"},
"persistent":	{"JJ"},
"persistently":	{"RB"},
"persisting":	{"VBG"},
"persists":	{"VBZ"},
"persnickety":	{"JJ"},
"person":	{"NN"},
"person-to-person":	{"JJ"},
"persona":	{"NN"},
"personable":	{"JJ"},
"personableness":	{"NN"},
"personae":	{"NNS"},
"personage":	{"NN"},
"personages":	{"NNS"},
"personal":	{"JJ"},
"personal-care":	{"JJ","NN"},
"personal-computer":	{"NN","JJ"},
"personal-income":	{"JJ"},
"personal-income-tax":	{"JJ"},
"personal-injury":	{"JJ","NN"},
"personal-property":	{"NN"},
"personal-spending":	{"NN"},
"personalise":	{"VB","VBP"},
"personalised":	{"VBD","VBN","JJ"},
"personalises":	{"VBZ"},
"personalising":	{"VBG"},
"personalities":	{"NNS"},
"personality":	{"NN"},
"personalize":	{"VB","VBP"},
"personalized":	{"JJ","VBD","VBN"},
"personalizes":	{"VBZ"},
"personalizing":	{"VBG"},
"personally":	{"RB"},
"personally-owned":	{"JJ"},
"personalties":	{"NNS"},
"personalty":	{"NN"},
"personas":	{"NNS"},
"personate":	{"VB","VBP"},
"personated":	{"VBD","VBN"},
"personates":	{"VBZ"},
"personating":	{"VBG"},
"personation":	{"NN"},
"personhood":	{"NN"},
"personification":	{"NN"},
"personifications":	{"NNS"},
"personified":	{"VBD","VBN"},
"personifies":	{"VBZ"},
"personify":	{"VB","VBP"},
"personifying":	{"VBG"},
"personnel":	{"NNS","NN"},
"persons":	{"NNS"},
"persoonia":	{"NN"},
"perspective":	{"NN"},
"perspectives":	{"NNS"},
"perspex":	{"NN"},
"perspicacious":	{"JJ"},
"perspicaciously":	{"RB"},
"perspicaciousness":	{"NN"},
"perspicacity":	{"NN"},
"perspicuity":	{"NN"},
"perspicuous":	{"JJ"},
"perspicuously":	{"RB"},
"perspicuousness":	{"NN"},
"perspiration":	{"NN"},
"perspire":	{"VB","VBP"},
"perspired":	{"VBD","VBN"},
"perspirer":	{"NN"},
"perspires":	{"VBZ"},
"perspiring":	{"VBG"},
"persuadable":	{"JJ"},
"persuade":	{"VB","VBP"},
"persuaded":	{"VBD","VBN","JJ"},
"persuader":	{"NN"},
"persuaders":	{"NNS"},
"persuades":	{"VBZ","NNS"},
"persuading":	{"VBG"},
"persuasible":	{"JJ"},
"persuasion":	{"NN"},
"persuasions":	{"NNS"},
"persuasive":	{"JJ"},
"persuasively":	{"RB"},
"persuasiveness":	{"NN"},
"pert":	{"JJ"},
"pertain":	{"VB","VBP"},
"pertained":	{"VBD","VBN"},
"pertaining":	{"VBG"},
"pertains":	{"VBZ"},
"pertainym":	{"NN"},
"pertinacious":	{"JJ"},
"pertinaciously":	{"RB"},
"pertinacity":	{"NN"},
"pertinence":	{"NN"},
"pertinency":	{"NN"},
"pertinent":	{"JJ"},
"pertinently":	{"RB"},
"pertly":	{"RB"},
"pertness":	{"NN"},
"perturb":	{"VB","VBP"},
"perturbation":	{"NN"},
"perturbations":	{"NNS"},
"perturbed":	{"JJ","VBD","VBN"},
"perturbing":	{"VBG"},
"perturbs":	{"VBZ"},
"pertusaria":	{"NN"},
"pertusariaceae":	{"NN"},
"pertussis":	{"NN"},
"peruke":	{"NN"},
"peruked":	{"JJ"},
"perusal":	{"NN"},
"perusals":	{"NNS"},
"peruse":	{"VB","VBP"},
"perused":	{"VBD","VBN"},
"peruses":	{"VBZ"},
"perusing":	{"VBG"},
"perutz":	{"NN"},
"pervade":	{"VB","VBP"},
"pervaded":	{"VBD","VBN"},
"pervades":	{"VBZ"},
"pervading":	{"VBG"},
"pervaporate":	{"VB","VBP"},
"pervaporated":	{"VBD","VBN"},
"pervaporates":	{"VBZ"},
"pervaporating":	{"VBG"},
"pervaporation":	{"NN"},
"pervasion":	{"NN"},
"pervasive":	{"JJ"},
"pervasively":	{"RB"},
"pervasiveness":	{"NN"},
"perverse":	{"JJ"},
"perversely":	{"RB"},
"perverseness":	{"NN"},
"perversion":	{"NN"},
"perversions":	{"NNS"},
"perversities":	{"NNS"},
"perversity":	{"NN"},
"perversive":	{"JJ"},
"pervert":	{"VB","VBP","NN"},
"perverted":	{"JJ","VBD","VBN"},
"perverting":	{"VBG"},
"perverts":	{"VBZ","NNS"},
"pervious":	{"JJ"},
"perviousness":	{"NN"},
"pes":	{"NN"},
"pesach":	{"NN"},
"pesah":	{"NN"},
"pesantran":	{"NN"},
"pesantren":	{"NN"},
"pesatas":	{"NNS"},
"peseta":	{"NN"},
"pesetas":	{"NNS"},
"pesewa":	{"NN"},
"peshawar":	{"NN"},
"peshmerga":	{"NN"},
"peskier":	{"JJR"},
"peskiest":	{"JJS"},
"pesky":	{"JJ"},
"peso":	{"NN"},
"pesos":	{"NNS"},
"pessaries":	{"NNS"},
"pessary":	{"NN"},
"pessimal":	{"JJ"},
"pessimism":	{"NN"},
"pessimist":	{"NN"},
"pessimistic":	{"JJ"},
"pessimistically":	{"RB"},
"pessimists":	{"NNS"},
"pessimum":	{"JJ"},
"pest":	{"NN"},
"pest-control":	{"JJ"},
"pester":	{"VB","VBP"},
"pestered":	{"VBD","VBN"},
"pesterer":	{"NN"},
"pestering":	{"VBG"},
"pesters":	{"VBZ"},
"pesthole":	{"NN"},
"pesthouse":	{"NN"},
"pesticide":	{"NN"},
"pesticide-free":	{"JJ"},
"pesticide-reform":	{"NN"},
"pesticides":	{"NNS"},
"pestiferous":	{"JJ"},
"pestilence":	{"NN"},
"pestilences":	{"NNS"},
"pestilent":	{"JJ"},
"pestilential":	{"JJ"},
"pestis":	{"NNS"},
"pestle":	{"NN","VB","VBP"},
"pestled":	{"VBD","VBN"},
"pestles":	{"NNS","VBZ"},
"pestling":	{"VBG"},
"pesto":	{"NN"},
"pests":	{"NNS"},
"pet":	{"NN","VBP","VB","JJ"},
"pet-food":	{"NN"},
"pet-rabbit-raising":	{"JJ"},
"petabit":	{"NN"},
"petabyte":	{"NN"},
"petal":	{"NN"},
"petal-like":	{"JJ"},
"petaled":	{"JJ"},
"petalled":	{"JJ"},
"petalless":	{"JJ"},
"petallike":	{"JJ"},
"petaloid":	{"JJ"},
"petalous":	{"JJ"},
"petals":	{"NNS"},
"petard":	{"NN"},
"petasites":	{"NNS"},
"petaurista":	{"NN"},
"petauristidae":	{"NN"},
"petaurus":	{"NN"},
"petchary":	{"NN"},
"petcock":	{"NN"},
"petechia":	{"NN"},
"petechiae":	{"NNS"},
"petechial":	{"JJ"},
"peter":	{"VB","VBP"},
"petered":	{"VBD","VBN"},
"petering":	{"VBG"},
"peters":	{"VBZ"},
"petey":	{"NN"},
"petfood":	{"NN"},
"petiolaris":	{"NN"},
"petiole":	{"NN"},
"petiolule":	{"NN"},
"petit":	{"JJ"},
"petite":	{"JJ"},
"petiteness":	{"NN"},
"petitio":	{"NN"},
"petition":	{"NN","VB","VBP"},
"petitionary":	{"JJ"},
"petitioned":	{"VBD","VBN"},
"petitioner":	{"NN"},
"petitioners":	{"NNS"},
"petitioning":	{"VBG"},
"petitions":	{"NNS","VBZ"},
"petits":	{"JJ"},
"petrarca":	{"NN"},
"petrarchan":	{"JJ"},
"petrel":	{"NN"},
"petrels":	{"NNS"},
"petrifaction":	{"NN"},
"petrification":	{"NN"},
"petrified":	{"JJ","VBN","VBD"},
"petrifies":	{"VBZ"},
"petrify":	{"VB","VBP"},
"petrifying":	{"VBG"},
"petrissage":	{"NN"},
"petro-dollar":	{"JJ"},
"petrochemical":	{"NN"},
"petrochemicals":	{"NNS"},
"petrocoptis":	{"NN"},
"petrogale":	{"NN"},
"petroglyph":	{"NN"},
"petrol":	{"NN"},
"petrolatum":	{"NN"},
"petroleum":	{"NN"},
"petroleum-exploration":	{"JJ"},
"petroleum-products":	{"NNS"},
"petroleum-related":	{"JJ"},
"petroleumproducts":	{"NNS"},
"petrology":	{"NN"},
"petromyzon":	{"NN"},
"petromyzoniformes":	{"NNS"},
"petromyzontidae":	{"NN"},
"petronius":	{"NN"},
"petroselinum":	{"NN"},
"petrous":	{"JJ"},
"pets":	{"NNS","VBZ"},
"petsat":	{"VBD","VBN"},
"petsit":	{"VB","VBP"},
"petsits":	{"VBZ"},
"petsitting":	{"VBG"},
"petted":	{"VBD","VBN"},
"petter":	{"NN"},
"petteria":	{"NN"},
"petticoat":	{"NN"},
"petticoated":	{"JJ"},
"petticoats":	{"NNS"},
"pettier":	{"JJR"},
"pettiest":	{"JJS"},
"pettifog":	{"VB","VBP"},
"pettifogged":	{"VBD","VBN"},
"pettifogger":	{"NN"},
"pettifoggers":	{"NNS"},
"pettifoggery":	{"NN"},
"pettifogging":	{"VBG"},
"pettifogs":	{"VBZ"},
"pettily":	{"RB"},
"pettiness":	{"NN"},
"pettinesses":	{"NNS"},
"petting":	{"NN","VBG"},
"pettish":	{"JJ"},
"pettishly":	{"RB"},
"pettishness":	{"NN"},
"petty":	{"JJ"},
"petulance":	{"NN"},
"petulant":	{"JJ"},
"petulantly":	{"RB"},
"petunia":	{"NN"},
"petunias":	{"NNS"},
"peul":	{"NN"},
"pew":	{"NN","UH"},
"pewee":	{"NN"},
"pewit":	{"NN"},
"pews":	{"NNS"},
"pewter":	{"NN"},
"peyote":	{"NN"},
"peyotes":	{"NNS"},
"peziza":	{"NN"},
"pezizaceae":	{"NN"},
"pezizales":	{"NNS"},
"pezophaps":	{"NNS"},
"pfaff":	{"NN"},
"pfalz":	{"NN"},
"pfannkuchen":	{"NN"},
"pfennig":	{"NN"},
"pfennigs":	{"NNS"},
"pflp":	{"NN"},
"pflp-gc":	{"NN"},
"phablets":	{"NNS"},
"phacelia":	{"NN"},
"phacochoerus":	{"NN"},
"phacoemulsification":	{"NN"},
"phaeochromocytoma":	{"NN"},
"phaeophyceae":	{"NN"},
"phaeophyta":	{"NN"},
"phaethon":	{"NN"},
"phaethontidae":	{"NN"},
"phaeton":	{"NN"},
"phaetons":	{"NNS"},
"phage":	{"NN"},
"phagocyte":	{"NN"},
"phagocytes":	{"NNS"},
"phagocytic":	{"JJ"},
"phagocytosis":	{"NN"},
"phagun":	{"NN"},
"phaius":	{"NN"},
"phalacrocoracidae":	{"NN"},
"phalacrocorax":	{"NN"},
"phalacrosis":	{"NN"},
"phalaenopsis":	{"NN"},
"phalaenoptilus":	{"NN"},
"phalange":	{"NN"},
"phalangeal":	{"JJ"},
"phalanger":	{"NN"},
"phalangeridae":	{"NN"},
"phalanges":	{"NNS"},
"phalangida":	{"NNS"},
"phalangiidae":	{"NNS"},
"phalangist":	{"NN"},
"phalangitis":	{"NN"},
"phalangium":	{"NN"},
"phalanx":	{"NN"},
"phalanxes":	{"NNS"},
"phalaris":	{"NN"},
"phalarope":	{"NN"},
"phalaropes":	{"NNS"},
"phalaropidae":	{"NN"},
"phalaropus":	{"NN"},
"phalguna":	{"NN"},
"phallaceae":	{"NN"},
"phallales":	{"NNS"},
"phalli":	{"NNS"},
"phallic":	{"JJ"},
"phalloplasty":	{"NN"},
"phallus":	{"NN"},
"phalluses":	{"NNS"},
"phalsa":	{"NN"},
"phanerogam":	{"NN"},
"phanerogamae":	{"NN"},
"phanerogams":	{"NNS"},
"phaneromania":	{"NN"},
"phanerozoic":	{"NN"},
"phantasies":	{"NNS"},
"phantasm":	{"NN"},
"phantasma":	{"NN"},
"phantasmagoria":	{"NN"},
"phantasmagorias":	{"NNS"},
"phantasmagoric":	{"JJ"},
"phantasmagorical":	{"JJ"},
"phantasmal":	{"JJ"},
"phantasmalian":	{"JJ"},
"phantasmally":	{"RB"},
"phantasmas":	{"NNS"},
"phantasmata":	{"NNS"},
"phantasmic":	{"JJ"},
"phantasmical":	{"JJ"},
"phantasmically":	{"RB"},
"phantasms":	{"NNS"},
"phantasy":	{"NN"},
"phantom":	{"NN","JJ"},
"phantoms":	{"NNS"},
"pharamaceuticals":	{"NNS"},
"pharaoh":	{"NN"},
"pharaohs":	{"NNS"},
"pharaonic":	{"JJ"},
"pharisaical":	{"JJ"},
"pharma":	{"NN"},
"pharmaceutic":	{"JJ"},
"pharmaceutical":	{"JJ","NN"},
"pharmaceuticals":	{"NNS"},
"pharmaceutics":	{"NN"},
"pharmacies":	{"NNS"},
"pharmacist":	{"NN"},
"pharmacists":	{"NNS"},
"pharmacogenetics":	{"NN"},
"pharmacokinetics":	{"NN"},
"pharmacologic":	{"NN"},
"pharmacological":	{"JJ"},
"pharmacologically":	{"RB"},
"pharmacologist":	{"NN"},
"pharmacologists":	{"NNS"},
"pharmacology":	{"NN"},
"pharmacopeia":	{"NN"},
"pharmacopoeia":	{"NN"},
"pharmacopoeias":	{"NNS"},
"pharmacuetical":	{"JJ"},
"pharmacy":	{"NN"},
"pharomacrus":	{"NN"},
"pharos":	{"NNS"},
"pharsalus":	{"NN"},
"pharyngeal":	{"JJ"},
"pharyngitis":	{"NN"},
"pharynx":	{"NN"},
"pharynxes":	{"NNS"},
"phascogale":	{"NN"},
"phascolarctos":	{"NNS"},
"phase":	{"NN","VB","VBP"},
"phase-in":	{"NN"},
"phase-one":	{"JJ"},
"phase-out":	{"NN"},
"phase-two":	{"JJ"},
"phased":	{"VBD","VBN"},
"phaseolus":	{"NNS"},
"phases":	{"NNS","VBZ"},
"phasianid":	{"NN"},
"phasianidae":	{"NN"},
"phasianus":	{"NN"},
"phasing":	{"VBG"},
"phasing-out":	{"NN"},
"phasmatidae":	{"NN"},
"phasmatodea":	{"NN"},
"phasmid":	{"NN"},
"phasmida":	{"NNS"},
"phasmidae":	{"NNS"},
"phasmidia":	{"NN"},
"pheasant":	{"NN","NNS"},
"pheasant's-eye":	{"NN"},
"pheasants":	{"NNS"},
"phegopteris":	{"NN"},
"pheidias":	{"NN"},
"phellem":	{"NN"},
"phellodendron":	{"NN"},
"phenacetin":	{"NN"},
"phenacomys":	{"NNS"},
"phenaphen":	{"NN"},
"phenazopyridine":	{"NN"},
"phencyclidine":	{"NN"},
"phenelzine":	{"NN"},
"phenergan":	{"NN"},
"phenicia":	{"NN"},
"pheniramine":	{"NN"},
"pheno-safranine":	{"NN"},
"phenobarbital":	{"NN"},
"phenobarbitone":	{"NN"},
"phenol":	{"NN"},
"phenolic":	{"JJ"},
"phenolphthalein":	{"NN"},
"phenolsulfonephthalein":	{"NN"},
"phenom":	{"NN"},
"phenomena":	{"NNS"},
"phenomenal":	{"JJ"},
"phenomenally":	{"RB"},
"phenomenological":	{"JJ"},
"phenomenology":	{"NN"},
"phenomenon":	{"NN"},
"phenoms":	{"NNS"},
"phenoplast":	{"NN"},
"phenothiazine":	{"NN"},
"phenotype":	{"NN"},
"phenotypic":	{"JJ"},
"phenotypical":	{"JJ"},
"phenotypically":	{"RB"},
"phensuximide":	{"NN"},
"phentolamine":	{"NN"},
"phenylacetamide":	{"NN"},
"phenylalanine":	{"NN"},
"phenylamine":	{"NN"},
"phenylbutazone":	{"NN"},
"phenylephrine":	{"NN"},
"phenylethylene":	{"NN"},
"phenylketonuria":	{"NN"},
"phenylpropanolamine":	{"NN"},
"phenyltoloxamine":	{"NN"},
"phenytoin":	{"NN"},
"pheochromocytoma":	{"NN"},
"pheresis":	{"NN"},
"pheromone":	{"NN"},
"pheromones":	{"NNS"},
"phi":	{"NN"},
"phial":	{"NN"},
"phials":	{"NNS"},
"philadelphaceae":	{"NN"},
"philadelphus":	{"NN"},
"philaenus":	{"NN"},
"philander":	{"VB","VBP"},
"philandered":	{"VBD","VBN"},
"philanderer":	{"NN"},
"philanderers":	{"NNS"},
"philandering":	{"VBG","JJ","NN"},
"philanders":	{"VBZ"},
"philanthrope":	{"NN"},
"philanthropic":	{"JJ"},
"philanthropically":	{"RB"},
"philanthropies":	{"NNS"},
"philanthropist":	{"NN"},
"philanthropists":	{"NNS"},
"philanthropy":	{"NN"},
"philatelic":	{"JJ"},
"philatelical":	{"JJ"},
"philatelically":	{"RB"},
"philatelist":	{"NN"},
"philatelists":	{"NNS"},
"philately":	{"NN"},
"philco-sponsored":	{"JJ"},
"philharmonic":	{"JJ","NN"},
"philharmonics":	{"NNS"},
"philhellene":	{"JJ","NN"},
"philhellenic":	{"JJ"},
"philhellenism":	{"NN"},
"philhellenist":	{"NN"},
"philia":	{"NN"},
"philippi":	{"NN"},
"philippic":	{"NN"},
"philippics":	{"NNS"},
"philippopolis":	{"NN"},
"philistia":	{"NN"},
"philistine":	{"NN","JJ"},
"philistines":	{"NNS"},
"philistinism":	{"NN"},
"phillidae":	{"NN"},
"phillipsite":	{"NN"},
"phillyrea":	{"NN"},
"philodendron":	{"NN"},
"philogyny":	{"NN"},
"philohela":	{"NN"},
"philological":	{"JJ"},
"philologist":	{"NN"},
"philologists":	{"NNS"},
"philologue":	{"NN"},
"philology":	{"NN"},
"philomachus":	{"NN"},
"philomath":	{"NN"},
"philophylla":	{"NN"},
"philosopher":	{"NN"},
"philosophers":	{"NNS"},
"philosophic":	{"JJ"},
"philosophical":	{"JJ"},
"philosophically":	{"RB"},
"philosophies":	{"NNS"},
"philosophise":	{"VB","VBP"},
"philosophised":	{"VBD","VBN"},
"philosophiser":	{"NN"},
"philosophises":	{"VBZ"},
"philosophising":	{"VBG","NN"},
"philosophize":	{"VB","VBP"},
"philosophized":	{"VBD","VBN"},
"philosophizer":	{"NN"},
"philosophizes":	{"VBZ"},
"philosophizing":	{"NN","VBG"},
"philosophy":	{"NN"},
"philter":	{"NN"},
"philters":	{"NNS"},
"philtre":	{"NN"},
"philtres":	{"NNS"},
"phimosis":	{"NN"},
"phis":	{"NNS"},
"phiz":	{"NN"},
"phlebectomy":	{"NN"},
"phlebitis":	{"NN"},
"phlebodium":	{"NN"},
"phlebogram":	{"NN"},
"phlebothrombosis":	{"NN"},
"phlebotomise":	{"VB","VBP"},
"phlebotomised":	{"VBD","VBN"},
"phlebotomises":	{"VBZ"},
"phlebotomising":	{"VBG"},
"phlebotomist":	{"NN"},
"phlebotomists":	{"NNS"},
"phlebotomize":	{"VB","VBP"},
"phlebotomized":	{"VBD","VBN"},
"phlebotomizes":	{"VBZ"},
"phlebotomizing":	{"VBG"},
"phlebotomus":	{"NN"},
"phlebotomy":	{"NN"},
"phlegm":	{"NN"},
"phlegmatic":	{"JJ"},
"phlegmatical":	{"JJ"},
"phlegmatically":	{"RB"},
"phlegmy":	{"JJ"},
"phleum":	{"NN"},
"phloem":	{"NN"},
"phlogiston":	{"NN"},
"phlogopite":	{"NN"},
"phlomis":	{"NN"},
"phlox":	{"NN","NNS"},
"phloxes":	{"NNS"},
"phobia":	{"NN"},
"phobias":	{"NNS"},
"phobic":	{"JJ","NN"},
"phobic-like":	{"JJ"},
"phobics":	{"NNS"},
"phobophobia":	{"NN"},
"phoca":	{"NN"},
"phocidae":	{"NN"},
"phocine":	{"JJ"},
"phocoena":	{"NN"},
"phocomelia":	{"NN"},
"phoebe":	{"NN"},
"phoebes":	{"NNS"},
"phoebus":	{"NN"},
"phoenicophorium":	{"NN"},
"phoenicopteridae":	{"NN"},
"phoeniculidae":	{"NN"},
"phoeniculus":	{"NN"},
"phoenicurus":	{"NN"},
"phoenix":	{"NN"},
"phoenixes":	{"NNS"},
"pholadidae":	{"NN"},
"pholas":	{"NNS"},
"pholidae":	{"NN"},
"pholidota":	{"NN"},
"pholiota":	{"NN"},
"pholis":	{"NN"},
"pholistoma":	{"NN"},
"phonate":	{"VB","VBP"},
"phonated":	{"VBD","VBN"},
"phonates":	{"VBZ"},
"phonating":	{"VBG"},
"phonation":	{"NN"},
"phone":	{"NN","VB","VBP"},
"phone-company":	{"NN"},
"phone-in":	{"NN"},
"phone-ins":	{"NNS"},
"phonebook":	{"NN"},
"phoned":	{"VBD","VBN"},
"phoneier":	{"JJR"},
"phoneiest":	{"JJS"},
"phoneme":	{"NN"},
"phonemes":	{"NNS"},
"phonemic":	{"JJ"},
"phonemically":	{"RB"},
"phonemics":	{"NN"},
"phoner":	{"NN"},
"phones":	{"NNS","VBZ"},
"phonetic":	{"JJ"},
"phonetically":	{"RB"},
"phonetician":	{"NN"},
"phoneticians":	{"NNS"},
"phonetics":	{"NN"},
"phoney":	{"JJ","NN"},
"phoneys":	{"NNS"},
"phonic":	{"JJ"},
"phonics":	{"NN"},
"phonier":	{"JJR"},
"phonies":	{"NNS"},
"phoniest":	{"JJS"},
"phoning":	{"VBG"},
"phonogram":	{"NN"},
"phonogramic":	{"JJ"},
"phonograph":	{"NN"},
"phonographs":	{"NNS"},
"phonologic":	{"JJ"},
"phonological":	{"JJ"},
"phonologist":	{"NN"},
"phonologists":	{"NNS"},
"phonology":	{"NN"},
"phonophobia":	{"NN"},
"phony":	{"JJ","NN"},
"phoradendron":	{"NN"},
"phoronid":	{"NN"},
"phoronida":	{"NNS"},
"phoronidea":	{"NNS"},
"phosgene":	{"NN"},
"phosphatase":	{"NN"},
"phosphate":	{"NN"},
"phosphate-buffered":	{"NN"},
"phosphates":	{"NNS"},
"phosphide":	{"NN"},
"phosphine":	{"NN"},
"phosphines":	{"NNS"},
"phosphocreatine":	{"NN"},
"phospholipid":	{"NN"},
"phosphoprotein":	{"NN"},
"phosphor":	{"NN"},
"phosphor-screen":	{"NN"},
"phosphoresce":	{"VB","VBP"},
"phosphoresced":	{"VBD","VBN"},
"phosphorescence":	{"NN"},
"phosphorescent":	{"JJ"},
"phosphoresces":	{"VBZ"},
"phosphorescing":	{"VBG"},
"phosphoric":	{"JJ"},
"phosphorous":	{"JJ"},
"phosphors":	{"NNS"},
"phosphorus":	{"NN"},
"phosphorus-bridged":	{"JJ"},
"phot":	{"NN"},
"photalgia":	{"NN"},
"photic":	{"JJ"},
"photinia":	{"NN"},
"photius":	{"NN"},
"photo":	{"NN"},
"photo-montage":	{"JJ"},
"photo-offset":	{"NN"},
"photoblepharon":	{"NN"},
"photocathode":	{"NN"},
"photocathodes":	{"NNS"},
"photocell":	{"NN"},
"photochemical":	{"JJ"},
"photochemistry":	{"NN"},
"photocoagulation":	{"NN"},
"photocoagulator":	{"NN"},
"photoconduction":	{"NN"},
"photoconductive":	{"JJ"},
"photoconductivity":	{"NN"},
"photocopied":	{"VBD","VBN"},
"photocopier":	{"NN"},
"photocopiers":	{"NNS"},
"photocopies":	{"NNS","VBZ"},
"photocopy":	{"NN","VB","VBP"},
"photocopying":	{"NN","VBG"},
"photoelectric":	{"JJ"},
"photoelectrical":	{"JJ"},
"photoelectrically":	{"RB"},
"photoelectricity":	{"NN"},
"photoelectron":	{"NN"},
"photoelectronic":	{"JJ"},
"photoelectrons":	{"NNS"},
"photoemission":	{"NN"},
"photoemissive":	{"JJ"},
"photoengrave":	{"VB","VBP"},
"photoengraved":	{"VBD","VBN"},
"photoengraver":	{"NN"},
"photoengraves":	{"VBZ"},
"photoengraving":	{"VBG","NN"},
"photofinishers":	{"NNS"},
"photofinishing":	{"NN"},
"photoflash":	{"NN"},
"photoflood":	{"NN"},
"photofloodlights":	{"NNS"},
"photofrin":	{"NN"},
"photogenic":	{"JJ"},
"photograph":	{"NN","VB","VBP"},
"photographed":	{"VBD","VBN"},
"photographer":	{"NN"},
"photographers":	{"NNS"},
"photographic":	{"JJ"},
"photographic-paper":	{"NN"},
"photographic-products":	{"JJ"},
"photographically":	{"RB"},
"photographing":	{"VBG"},
"photographs":	{"NNS","VBZ"},
"photography":	{"NN"},
"photogravure":	{"NN"},
"photojournalism":	{"NN"},
"photojournalist":	{"NN"},
"photojournalists":	{"NNS"},
"photolithograph":	{"NN"},
"photolithography":	{"NN"},
"photoluminescence":	{"NN"},
"photomechanical":	{"JJ"},
"photomechanics":	{"NN"},
"photometer":	{"NN"},
"photometers":	{"NNS"},
"photometric":	{"JJ"},
"photometrical":	{"JJ"},
"photometrically":	{"RB"},
"photometrician":	{"NN"},
"photometrist":	{"NN"},
"photometry":	{"NN"},
"photomicrograph":	{"NN"},
"photomicrography":	{"NN"},
"photomontage":	{"NN"},
"photomosaic":	{"NN"},
"photon":	{"NN"},
"photon-counting":	{"JJ"},
"photons":	{"NNS"},
"photophobia":	{"NN"},
"photopigment":	{"NN"},
"photorealism":	{"NN"},
"photoretinitis":	{"NN"},
"photos":	{"NNS"},
"photosensitise":	{"VB","VBP"},
"photosensitised":	{"VBD","VBN"},
"photosensitises":	{"VBZ"},
"photosensitising":	{"VBG"},
"photosensitive":	{"JJ"},
"photosensitivity":	{"NN"},
"photosensitize":	{"VB","VBP"},
"photosensitized":	{"VBD","VBN"},
"photosensitizes":	{"VBZ"},
"photosensitizing":	{"VBG"},
"photosphere":	{"NN"},
"photospheric":	{"JJ"},
"photostat":	{"NN","VB","VBP"},
"photostated":	{"VBD","VBN"},
"photostatic":	{"JJ"},
"photostating":	{"VBG"},
"photostats":	{"NNS","VBZ"},
"photostatted":	{"VBD","VBN"},
"photostatting":	{"VBG"},
"photosynthesis":	{"NN"},
"photosynthesise":	{"VB","VBP"},
"photosynthesised":	{"VBD","VBN"},
"photosynthesises":	{"VBZ"},
"photosynthesising":	{"VBG"},
"photosynthesize":	{"VB","VBP"},
"photosynthesized":	{"VBD","VBN"},
"photosynthesizes":	{"VBZ"},
"photosynthesizing":	{"VBG"},
"photosynthetic":	{"JJ"},
"phototherapy":	{"NN"},
"phototropism":	{"NN"},
"photovoltaic":	{"JJ"},
"phots":	{"NNS"},
"phoxinus":	{"NN"},
"phragmacone":	{"NN"},
"phragmipedium":	{"NN"},
"phragmites":	{"NNS"},
"phragmocone":	{"NN"},
"phrasal":	{"JJ"},
"phrase":	{"NN","VBP","VB"},
"phrase-book":	{"NN"},
"phrase-books":	{"NNS"},
"phrased":	{"VBD","VBN"},
"phrasemaking":	{"NN"},
"phraseology":	{"NN"},
"phrases":	{"NNS","VBZ"},
"phrasing":	{"NN","VBG"},
"phrasings":	{"NNS"},
"phratry":	{"NN"},
"phreatic":	{"JJ"},
"phrenetic":	{"JJ"},
"phrenic":	{"JJ"},
"phrenitis":	{"NN"},
"phrenological":	{"JJ"},
"phrenologist":	{"NN"},
"phrenologists":	{"NNS"},
"phrenology":	{"NN"},
"phrontistery":	{"NN"},
"phrygia":	{"NN"},
"phrygian":	{"NN"},
"phrynosoma":	{"NN"},
"phthalate":	{"NN"},
"phthiriidae":	{"NN"},
"phthirius":	{"NN"},
"phthirus":	{"NN"},
"phthisis":	{"NN"},
"phthorimaea":	{"NN"},
"phubbers":	{"NNS"},
"phubbing":	{"NN"},
"phubbings":	{"NNS"},
"phycobilin":	{"NN"},
"phycocyanin":	{"NN"},
"phycoerythrin":	{"NN"},
"phycology":	{"NN"},
"phycomycete":	{"NN"},
"phycomycetes":	{"NNS"},
"phycomycosis":	{"NN"},
"phyla":	{"NNS"},
"phylactery":	{"NN"},
"phyle":	{"NN"},
"phyletic":	{"JJ"},
"phyllidae":	{"NN"},
"phylliform":	{"JJ"},
"phyllitis":	{"NN"},
"phyllium":	{"NN"},
"phyllo":	{"NN"},
"phylloclad":	{"NN"},
"phyllocladaceae":	{"NN"},
"phylloclade":	{"NN"},
"phyllocladus":	{"NN"},
"phyllode":	{"NN"},
"phyllodial":	{"JJ"},
"phyllodoce":	{"NN"},
"phylloporus":	{"NN"},
"phylloquinone":	{"NN"},
"phyllorhynchus":	{"NN"},
"phylloscopus":	{"NN"},
"phyllostachys":	{"NN"},
"phyllostomatidae":	{"NN"},
"phyllostomidae":	{"NN"},
"phyllostomus":	{"NN"},
"phylloxera":	{"NN"},
"phylloxeridae":	{"NN"},
"phylogenesis":	{"NN"},
"phylogenetic":	{"JJ"},
"phylogenetically":	{"RB"},
"phylogeny":	{"NN"},
"phylum":	{"NN"},
"physa":	{"NN"},
"physalia":	{"NN"},
"physalis":	{"NN"},
"physaria":	{"NN"},
"physeter":	{"NN"},
"physeteridae":	{"NN"},
"physiatrics":	{"NN"},
"physic":	{"NN","VB","VBP"},
"physical":	{"JJ","NN"},
"physical-chemical":	{"JJ"},
"physicalism":	{"NN"},
"physicality":	{"NN"},
"physically":	{"RB"},
"physicalness":	{"NN"},
"physicals":	{"NNS"},
"physician":	{"NN"},
"physician-executive":	{"JJ"},
"physician-owned":	{"JJ"},
"physician-patient":	{"JJ"},
"physician-reimbursement":	{"JJ"},
"physicians":	{"NNS"},
"physicist":	{"NN"},
"physicists":	{"NNS"},
"physicked":	{"VBD","VBN"},
"physicking":	{"VBG"},
"physicky":	{"JJ"},
"physicochemical":	{"JJ"},
"physics":	{"NN","VBZ"},
"physidae":	{"NN"},
"physiochemical":	{"JJ"},
"physiognomies":	{"NNS"},
"physiognomy":	{"NN"},
"physiography":	{"NN"},
"physiologic":	{"JJ"},
"physiological":	{"JJ"},
"physiologically":	{"RB"},
"physiologist":	{"NN"},
"physiologists":	{"NNS"},
"physiology":	{"NN"},
"physiotherapeutic":	{"JJ"},
"physiotherapist":	{"NN"},
"physiotherapists":	{"NNS"},
"physiotherapy":	{"NN"},
"physique":	{"NN"},
"physiques":	{"NNS"},
"physostegia":	{"NN"},
"physostigma":	{"NN"},
"physostigmine":	{"NN"},
"phytelephas":	{"NNS"},
"phytochemical":	{"JJ","NN"},
"phytochemist":	{"NN"},
"phytochemistry":	{"NN"},
"phytohormone":	{"NN"},
"phytolacca":	{"NN"},
"phytolaccaceae":	{"NN"},
"phytologist":	{"NN"},
"phytology":	{"NN"},
"phytomastigina":	{"NN"},
"phytonadione":	{"NN"},
"phytophagic":	{"JJ"},
"phytophagous":	{"JJ"},
"phytophilous":	{"JJ"},
"phytophthora":	{"NN"},
"phytoplankton":	{"NN"},
"phytotherapy":	{"NN"},
"phytotoxin":	{"NN"},
"pi":	{"NN","VB","VBP"},
"pi-meson":	{"NN"},
"piaffe":	{"NN"},
"piaget":	{"NN"},
"piagetian":	{"JJ"},
"pianism":	{"NN"},
"pianissimi":	{"NNS"},
"pianissimo":	{"JJ","RB","NN"},
"pianissimos":	{"NNS"},
"pianist":	{"NN"},
"pianist-comedian":	{"NN"},
"pianistic":	{"JJ"},
"pianists":	{"NNS"},
"piano":	{"NN","JJ","RB"},
"pianoforte":	{"NN"},
"pianofortes":	{"NNS"},
"pianola":	{"NN"},
"pianolas":	{"NNS"},
"pianos":	{"NNS"},
"piaster":	{"NN"},
"piasters":	{"NNS"},
"piastre":	{"NN"},
"piazza":	{"NN"},
"piazzas":	{"NNS"},
"pib":	{"NN"},
"pibgorn":	{"NN"},
"pibit":	{"NN"},
"pibroch":	{"NN"},
"pic":	{"NN"},
"pica":	{"NN"},
"pica-pica":	{"NN"},
"picador":	{"NN"},
"picadors":	{"NNS"},
"picaninny":	{"NN"},
"picardie":	{"NN"},
"picardy":	{"NN"},
"picaresque":	{"JJ"},
"picariae":	{"NN"},
"picas":	{"NNS"},
"picayune":	{"NN","JJ"},
"piccalilli":	{"NN"},
"piccaninny":	{"NN"},
"piccolo":	{"NN"},
"piccolos":	{"NNS"},
"picea":	{"NN"},
"pichi":	{"NN"},
"pichia":	{"NN"},
"pichiciago":	{"NN"},
"pichiciego":	{"NN"},
"picidae":	{"NN"},
"piciformes":	{"NNS"},
"pick":	{"VB","VBP","NN"},
"pick-me-up":	{"NN"},
"pick-me-ups":	{"NNS"},
"pick-off":	{"NN"},
"pick-up":	{"NN","JJ"},
"pick-ups":	{"NNS"},
"pickaback":	{"RB"},
"pickaninnies":	{"NNS"},
"pickaninny":	{"NN"},
"pickax":	{"NN"},
"pickaxe":	{"NN"},
"pickaxes":	{"NNS"},
"picked":	{"VBD","VBN","JJ"},
"pickelhaube":	{"NN"},
"picker":	{"NN"},
"pickerel":	{"NN","NNS"},
"pickerels":	{"NNS"},
"pickerelweed":	{"NN"},
"pickeringia":	{"NN"},
"pickers":	{"NNS"},
"picket":	{"NN","VB","VBP"},
"picketed":	{"VBD","VBN"},
"picketer":	{"NN"},
"picketers":	{"NNS"},
"picketing":	{"NN","VBG"},
"pickets":	{"NNS","VBZ"},
"pickett":	{"NN"},
"pickier":	{"JJR"},
"pickiest":	{"JJS"},
"pickin":	{"NN"},
"picking":	{"VBG","NN"},
"pickings":	{"NNS"},
"pickins":	{"NNS"},
"pickle":	{"NN","VB","VBP"},
"pickled":	{"JJ","VBD","VBN"},
"picklepuss":	{"NN"},
"pickles":	{"NNS","VBZ"},
"pickling":	{"VBG","NN"},
"picklock":	{"NN"},
"picklocks":	{"NNS"},
"picknicker":	{"NN"},
"pickoff":	{"NN"},
"pickoffs":	{"NNS"},
"pickpocket":	{"NN"},
"pickpockets":	{"NNS"},
"picks":	{"NNS","VBZ"},
"pickup":	{"NN"},
"pickup-bed":	{"NN"},
"pickups":	{"NNS"},
"picky":	{"JJ"},
"picnic":	{"NN","VB","VBP"},
"picnicked":	{"VBD","VBN"},
"picnicker":	{"NN"},
"picnickers":	{"NNS"},
"picnicking":	{"VBG"},
"picnics":	{"VBZ","NNS"},
"picocassette":	{"NN"},
"picofarad":	{"NN"},
"picoides":	{"NNS"},
"picometer":	{"NN"},
"picometre":	{"NN"},
"picornavirus":	{"NN"},
"picosecond":	{"NN"},
"picot":	{"NN"},
"picovolt":	{"NN"},
"picrasma":	{"NN"},
"picris":	{"NN"},
"pics":	{"NNS"},
"pictogram":	{"NN"},
"pictograms":	{"NNS"},
"pictograph":	{"NN"},
"pictographic":	{"JJ"},
"pictorial":	{"NN","JJ"},
"pictorially":	{"RB"},
"pictural":	{"JJ"},
"picture":	{"NN","VB","VBP"},
"picture-book":	{"NN"},
"picture-books":	{"NNS"},
"picture-card":	{"NN"},
"picture-cards":	{"NNS"},
"picture-gallery":	{"NN"},
"picture-images":	{"NNS"},
"picture-palace":	{"NN"},
"picture-postcard":	{"NN","JJ"},
"picture-postcards":	{"NNS"},
"picture-taking":	{"NN"},
"picture-tube":	{"JJ"},
"pictured":	{"VBD","VBN"},
"pictures":	{"NNS","VBZ"},
"picturesque":	{"JJ","NN"},
"picturesquely":	{"RB"},
"picturesqueness":	{"NN"},
"picturing":	{"VBG"},
"picul":	{"NN"},
"piculet":	{"NN"},
"picumnus":	{"NN"},
"picus":	{"NN"},
"piddle":	{"VB","VBP","NN"},
"piddled":	{"VBD","VBN"},
"piddles":	{"VBZ","NNS"},
"piddling":	{"JJ","VBG"},
"piddock":	{"NN"},
"pidgin":	{"NN","JJ"},
"pidlimdi":	{"NN"},
"pie":	{"NN","VB","VBP"},
"pie-dog":	{"NN"},
"pie-eyed":	{"JJ"},
"pie-in-the-sky":	{"JJ","NN"},
"piebald":	{"JJ","NN"},
"piebalds":	{"NNS"},
"piece":	{"NN","VB","VBP"},
"piece-by-piece":	{"JJ"},
"piece-dyed":	{"JJ"},
"pieced":	{"VBD","VBN"},
"piecemeal":	{"JJ","RB"},
"pieces":	{"NNS","VBZ"},
"piecewise":	{"RB"},
"piecework":	{"NN"},
"piecing":	{"VBG"},
"pied":	{"JJ","VBD","VBN"},
"pied-a-terre":	{"NN"},
"piedmont":	{"NN"},
"pieds-a-terre":	{"NNS"},
"pieing":	{"VBG"},
"piemonte":	{"NN"},
"pieplant":	{"NN"},
"pier":	{"NN"},
"pier-table":	{"NN"},
"pierce":	{"VB","VBP"},
"pierced":	{"VBD","VBN"},
"pierces":	{"VBZ"},
"piercing":	{"JJ","NN","VBG"},
"piercingly":	{"RB"},
"piercings":	{"NNS"},
"pierid":	{"NN"},
"pieridae":	{"NN"},
"pieris":	{"NN"},
"piero":	{"NN"},
"pierrette":	{"NN"},
"pierrot":	{"NN"},
"piers":	{"NNS"},
"pies":	{"NNS"},
"pieta":	{"NN"},
"pietism":	{"NN"},
"pietistic":	{"JJ"},
"pietistical":	{"JJ"},
"piety":	{"NN"},
"piezoelectric":	{"JJ"},
"piezoelectricity":	{"NN"},
"piezometer":	{"NN"},
"piezometers":	{"NNS"},
"piezometric":	{"JJ"},
"piezometrically":	{"RB"},
"piffle":	{"NN","VB","VBP"},
"piffled":	{"VBD","VBN"},
"piffles":	{"VBZ"},
"piffling":	{"JJ","VBG"},
"pig":	{"NN","VBP","VB"},
"pig-a-back":	{"RB"},
"pig-drunk":	{"JJ"},
"pig-headedly":	{"RB"},
"pig-infested":	{"JJ"},
"pig-iron":	{"NN"},
"pig-sized":	{"JJ"},
"pigboat":	{"NN"},
"pigen":	{"NN"},
"pigeon":	{"NN"},
"pigeon-breasted":	{"JJ"},
"pigeon-hole":	{"NN","VB","VBP"},
"pigeon-holed":	{"VBD","VBN"},
"pigeon-holes":	{"NNS","VBZ"},
"pigeon-holing":	{"VBG"},
"pigeon-toed":	{"JJ"},
"pigeonhole":	{"NN","VB","VBP"},
"pigeonholed":	{"VBD","VBN"},
"pigeonholes":	{"NNS","VBZ"},
"pigeonholing":	{"VBG"},
"pigeons":	{"NNS"},
"pigfish":	{"NN"},
"pigged":	{"VBD","VBN"},
"piggeries":	{"NNS"},
"piggery":	{"NN"},
"piggies":	{"NNS"},
"pigging":	{"VBG"},
"piggish":	{"JJ"},
"piggishly":	{"RB"},
"piggishness":	{"NN"},
"piggy":	{"NN","JJ"},
"piggy-back":	{"NN","RB","VB","VBP"},
"piggy-backed":	{"VBD","VBN"},
"piggy-backing":	{"VBG"},
"piggy-backs":	{"NNS","VBZ"},
"piggyback":	{"NN","RB","VB","VBP"},
"piggybacked":	{"VBD","VBN"},
"piggybacking":	{"VBG","NN"},
"piggybacks":	{"NNS","VBZ"},
"pigheaded":	{"JJ"},
"pigheadedness":	{"NN"},
"piglet":	{"NN"},
"piglets":	{"NNS"},
"pigman":	{"NN"},
"pigmen":	{"NNS"},
"pigment":	{"NN","VB","VBP"},
"pigmentation":	{"NN"},
"pigmented":	{"JJ","VBD","VBN"},
"pigmenting":	{"VBG"},
"pigmentocracies":	{"NNS"},
"pigmentocracy":	{"NN"},
"pigments":	{"NNS","VBZ"},
"pigmies":	{"NNS"},
"pigmy":	{"NN","JJ"},
"pignolia":	{"NN"},
"pignut":	{"NN"},
"pigpen":	{"NN"},
"pigpens":	{"NNS"},
"pigs":	{"NNS","VBZ"},
"pigskin":	{"NN"},
"pigsticking":	{"NN"},
"pigsties":	{"NNS"},
"pigsty":	{"NN"},
"pigswill":	{"NN"},
"pigtail":	{"NN"},
"pigtails":	{"NNS"},
"pigwash":	{"NN"},
"pigweed":	{"NN"},
"piing":	{"VBG"},
"pij":	{"NN"},
"pika":	{"NN"},
"pike":	{"NN","NNS","VB","VBP"},
"pike-perch":	{"NN"},
"pikeblenny":	{"NN"},
"piked":	{"VBD","VBN"},
"piker":	{"NN"},
"pikers":	{"NNS"},
"pikes":	{"NNS","VBZ"},
"pikestaff":	{"NN"},
"piking":	{"VBG"},
"pilaf":	{"NN"},
"pilaff":	{"NN"},
"pilaffs":	{"NNS"},
"pilafs":	{"NNS"},
"pilar":	{"NN","JJ"},
"pilary":	{"JJ"},
"pilaster":	{"NN"},
"pilasters":	{"NNS"},
"pilau":	{"NN"},
"pilaus":	{"NNS"},
"pilaw":	{"NN"},
"pilchard":	{"NN"},
"pilchards":	{"NNS"},
"pile":	{"NN","VB","VBP"},
"pile-driver":	{"NN"},
"pile-drivers":	{"NNS"},
"pile-up":	{"NN"},
"pile-ups":	{"NNS"},
"pilea":	{"NN"},
"piled":	{"VBN","VBD"},
"piles":	{"NNS","VBZ"},
"pileup":	{"NN"},
"pileups":	{"NNS"},
"pileus":	{"NN"},
"pilewort":	{"NN"},
"pilfer":	{"VB","VBP"},
"pilferage":	{"NN"},
"pilfered":	{"VBD","VBN"},
"pilferer":	{"NN"},
"pilferers":	{"NNS"},
"pilfering":	{"VBG","NN"},
"pilfers":	{"VBZ"},
"pilgrim":	{"NN"},
"pilgrimage":	{"NN","VB","VBP"},
"pilgrimaged":	{"VBD","VBN"},
"pilgrimages":	{"NNS","VBZ"},
"pilgrimaging":	{"VBG"},
"pilgrims":	{"NNS"},
"piling":	{"NN","VBG"},
"pilings":	{"NNS"},
"pilipino":	{"NN"},
"pill":	{"NN","VB","VBP"},
"pill-factory":	{"JJ"},
"pillage":	{"VB","VBP","NN"},
"pillaged":	{"VBD","VBN"},
"pillager":	{"NN"},
"pillagers":	{"NNS"},
"pillages":	{"VBZ"},
"pillaging":	{"VBG","NN"},
"pillar":	{"NN","VB","VBP"},
"pillar-shaped":	{"JJ"},
"pillared":	{"JJ","VBD","VBN"},
"pillaring":	{"VBG"},
"pillars":	{"NNS","VBZ"},
"pillbox":	{"NN"},
"pillboxes":	{"NNS"},
"pilled":	{"VBD","VBN"},
"pilling":	{"VBG"},
"pillion":	{"NN","RB"},
"pillions":	{"NNS"},
"pillock":	{"NN"},
"pillocks":	{"NNS"},
"pilloried":	{"VBD","VBN"},
"pillories":	{"VBZ","NNS"},
"pillory":	{"VB","VBP","NN"},
"pillorying":	{"VBG"},
"pillow":	{"NN","VB","VBP"},
"pillowcase":	{"NN"},
"pillowcases":	{"NNS"},
"pillowed":	{"VBD","VBN"},
"pillowing":	{"VBG"},
"pillows":	{"NNS","VBZ"},
"pills":	{"NNS","VBZ"},
"pillsbury":	{"NN"},
"pillwort":	{"NN"},
"pilocarpine":	{"NN"},
"pilose":	{"JJ"},
"pilosebaceous":	{"JJ"},
"pilosella":	{"NN"},
"pilosity":	{"NN"},
"pilot":	{"NN","JJ","VB","VBP"},
"pilot-boat":	{"NN"},
"pilot-boats":	{"NNS"},
"pilot-burner":	{"NN"},
"pilot-dominated":	{"JJ"},
"pilot-fish":	{"NN"},
"pilot-light":	{"NN"},
"pilot-management":	{"JJ"},
"pilot-seniority":	{"NN"},
"pilot-training":	{"JJ","NN"},
"pilot-union":	{"JJ"},
"pilotage":	{"NN"},
"pilote":	{"FW"},
"piloted":	{"VBD","VBN"},
"pilotfish":	{"NN"},
"pilothouse":	{"NN"},
"pilothouses":	{"NNS"},
"piloting":	{"NN","VBG"},
"pilotless":	{"JJ"},
"pilots":	{"NNS","VBZ"},
"pilous":	{"JJ"},
"pilsen":	{"NN"},
"pilsener":	{"NN"},
"pilularia":	{"NN"},
"pilus":	{"NN"},
"pima":	{"NN"},
"pimenta":	{"NN"},
"pimento":	{"NN"},
"pimentos":	{"NNS"},
"pimiento":	{"NN"},
"pimlico":	{"NN"},
"pimozide":	{"NN"},
"pimp":	{"NN","VB","VBP"},
"pimped":	{"VBD","VBN"},
"pimpernel":	{"NN"},
"pimpernels":	{"NNS"},
"pimpinella":	{"NN"},
"pimping":	{"VBG","NN"},
"pimple":	{"NN"},
"pimpled":	{"JJ"},
"pimples":	{"NNS"},
"pimplike":	{"JJ"},
"pimply":	{"JJ"},
"pimps":	{"NNS","VBZ"},
"pin":	{"NN","VBP","VB"},
"pin-ball":	{"NN"},
"pin-curl":	{"JJ"},
"pin-head":	{"NN"},
"pin-heads":	{"NNS"},
"pin-money":	{"NN"},
"pin-stripe":	{"NN"},
"pin-table":	{"NN"},
"pin-tables":	{"NNS"},
"pin-up":	{"NN"},
"pin-ups":	{"NNS"},
"pinaceae":	{"NN"},
"pinafore":	{"NN"},
"pinafores":	{"NNS"},
"pinata":	{"NN"},
"pinball":	{"NN"},
"pinball-parlor":	{"NN"},
"pince-nez":	{"NN","NNS"},
"pincer":	{"NN"},
"pincers":	{"NNS"},
"pinch":	{"VB","VBP","NN"},
"pinch-hit":	{"VB","VBP","VBD","VBN"},
"pinch-hits":	{"VBZ"},
"pinch-hitter":	{"NN"},
"pinch-hitters":	{"NNS"},
"pinch-hitting":	{"VBG"},
"pinchbeck":	{"NN","JJ"},
"pinche":	{"NN"},
"pinched":	{"JJ","VBD","VBN"},
"pinches":	{"NNS","VBZ"},
"pinchgut":	{"NN"},
"pinching":	{"VBG"},
"pinckneya":	{"NN"},
"pinctada":	{"NN"},
"pincus":	{"NN"},
"pincushion":	{"NN"},
"pincushions":	{"NNS"},
"pindar":	{"NN"},
"pindaric":	{"NN"},
"pindolol":	{"NN"},
"pine":	{"NN","VBP","VB"},
"pine-cone":	{"NN"},
"pine-cones":	{"NNS"},
"pine-knot":	{"JJ"},
"pine-needle":	{"NN"},
"pine-needles":	{"NNS"},
"pine-weed":	{"NN"},
"pineal":	{"JJ"},
"pinealoma":	{"NN"},
"pineapple":	{"NN"},
"pineapples":	{"NNS"},
"pinecone":	{"NN"},
"pined":	{"VBD","VBN"},
"pines":	{"VBZ","NNS"},
"pinesap":	{"NN"},
"pinetum":	{"NN"},
"pineus":	{"NN"},
"pineweed":	{"NN"},
"pinfish":	{"NN"},
"pinfold":	{"NN"},
"ping":	{"NN","VB","VBP"},
"ping-pong":	{"NN"},
"pinged":	{"VBD","VBN"},
"pinger":	{"NN"},
"pinging":	{"VBG"},
"pings":	{"NNS","VBZ"},
"pinguecula":	{"NN"},
"pinguicula":	{"NN"},
"pinguinus":	{"NN"},
"pinhead":	{"NN"},
"pinheaded":	{"JJ"},
"pinheads":	{"NNS"},
"pinhole":	{"NN"},
"pinholes":	{"NNS"},
"pinicola":	{"NN"},
"pining":	{"VBG"},
"pinion":	{"NN","VB","VBP"},
"pinioned":	{"VBD","VBN"},
"pinioning":	{"VBG"},
"pinions":	{"NNS","VBZ"},
"pinite":	{"NN"},
"pink":	{"JJ","NN","VBP","VB"},
"pink-cheeked":	{"JJ"},
"pink-collar":	{"JJ"},
"pink-eye":	{"NN"},
"pink-lavender":	{"JJ"},
"pink-orange":	{"JJ"},
"pink-petticoated":	{"JJ"},
"pink-purple":	{"JJ"},
"pink-red":	{"JJ"},
"pink-sheet":	{"JJ"},
"pink-slipped":	{"JJ"},
"pink-tinged":	{"JJ"},
"pink-tipped":	{"JJ"},
"pinked":	{"VBD","VBN"},
"pinkeye":	{"NN"},
"pinkie":	{"NN"},
"pinkies":	{"NNS"},
"pinking":	{"VBG"},
"pinkish":	{"JJ"},
"pinkish-lavender":	{"JJ"},
"pinkish-orange":	{"JJ"},
"pinkish-purple":	{"JJ"},
"pinkish-white":	{"JJ"},
"pinkly":	{"RB"},
"pinkness":	{"NN"},
"pinko":	{"NN","JJ"},
"pinkos":	{"NNS"},
"pinkroot":	{"NN"},
"pinks":	{"NNS","VBZ"},
"pinky":	{"NN"},
"pinna":	{"NN"},
"pinnace":	{"NN"},
"pinnaces":	{"NNS"},
"pinnacle":	{"NN","VB","VBP"},
"pinnacled":	{"VBD","VBN"},
"pinnacles":	{"NNS","VBZ"},
"pinnacling":	{"VBG"},
"pinnate":	{"JJ"},
"pinnate-leafed":	{"JJ"},
"pinnate-leaved":	{"JJ"},
"pinnated":	{"JJ"},
"pinnately":	{"RB"},
"pinnatifid":	{"JJ"},
"pinnatiped":	{"NN"},
"pinnatisect":	{"JJ"},
"pinned":	{"VBD","VBN"},
"pinner":	{"NN"},
"pinnies":	{"NNS"},
"pinning":	{"VBG"},
"pinniped":	{"JJ","NN"},
"pinnipedia":	{"NN"},
"pinnotheres":	{"NNS"},
"pinnotheridae":	{"NN"},
"pinnule":	{"NN"},
"pinny":	{"NN"},
"pinochle":	{"NN"},
"pinocle":	{"NN"},
"pinocytosis":	{"NN"},
"pinole":	{"NN"},
"pinon":	{"NN"},
"pinophytina":	{"NN"},
"pinopsida":	{"NN"},
"pinot":	{"NN"},
"pinpoint":	{"VB","VBP","NN","JJ"},
"pinpointed":	{"VBD","VBN"},
"pinpointing":	{"VBG","NN"},
"pinpoints":	{"VBZ","NNS"},
"pinprick":	{"NN"},
"pinpricks":	{"NNS"},
"pins":	{"NNS","VBZ"},
"pinscher":	{"NN"},
"pinsk":	{"NN"},
"pinstripe":	{"NN"},
"pinstripe-suited":	{"JJ"},
"pinstriped":	{"JJ"},
"pinstripes":	{"NNS"},
"pint":	{"NN"},
"pint-sized":	{"JJ"},
"pintado":	{"NN"},
"pintail":	{"NN","NNS"},
"pintails":	{"NNS"},
"pintle":	{"NN"},
"pinto":	{"NN","JJ"},
"pintos":	{"NNS"},
"pints":	{"NNS"},
"pinup":	{"NN"},
"pinups":	{"NNS"},
"pinus":	{"NN"},
"pinwheel":	{"NN"},
"pinwheel-shaped":	{"JJ"},
"pinwheels":	{"NNS"},
"pinworm":	{"NN"},
"pinyon":	{"NN"},
"piolet":	{"NN"},
"pion":	{"NN"},
"pioneer":	{"NN","VB","VBP"},
"pioneered":	{"VBD","VBN"},
"pioneering":	{"VBG","JJ"},
"pioneers":	{"NNS","VBZ"},
"pious":	{"JJ"},
"piously":	{"RB"},
"piousness":	{"NN"},
"pip":	{"NN","VB","VBP"},
"pip-squeak":	{"NN"},
"pip-squeaks":	{"NNS"},
"pipa":	{"NN"},
"pipage":	{"NN"},
"pipal":	{"NN"},
"pipe":	{"NN","VBP","VB"},
"pipe-clay":	{"VB","VBP"},
"pipe-clayed":	{"VBD","VBN"},
"pipe-claying":	{"VBG"},
"pipe-clays":	{"VBZ"},
"pipe-dream":	{"NN"},
"pipe-dreams":	{"NNS"},
"pipeclay":	{"NN","VB","VBP"},
"pipeclayed":	{"VBD","VBN"},
"pipeclaying":	{"VBG"},
"pipeclays":	{"VBZ"},
"piped":	{"VBD","VBN"},
"pipefish":	{"NN","NNS"},
"pipefishes":	{"NNS"},
"pipefitting":	{"NN"},
"pipeful":	{"NN"},
"pipeline":	{"NN"},
"pipelines":	{"NNS"},
"piper":	{"NN"},
"piperaceae":	{"NN"},
"piperacillin":	{"NN"},
"piperales":	{"NNS"},
"piperazine":	{"NN"},
"piperin":	{"NN"},
"piperine":	{"NN"},
"piperocaine":	{"NN"},
"pipers":	{"NNS"},
"pipes":	{"NNS","VBZ"},
"pipet":	{"NN"},
"pipette":	{"NN"},
"pipettes":	{"NNS"},
"pipework":	{"NN"},
"pipewort":	{"NN"},
"pipidae":	{"NN"},
"pipile":	{"NN"},
"pipilo":	{"NN"},
"piping":	{"JJ","NN","VBG","RB"},
"pipistrel":	{"NN"},
"pipistrelle":	{"NN"},
"pipistrellus":	{"NN"},
"pipit":	{"NN"},
"pipits":	{"NNS"},
"pipped":	{"VBD","VBN"},
"pippin":	{"NN"},
"pipping":	{"VBG"},
"pippins":	{"NNS"},
"pipra":	{"NN"},
"pipracil":	{"NN"},
"pipridae":	{"NN"},
"pips":	{"NNS","VBZ"},
"pipsissewa":	{"NN"},
"pipsqueak":	{"NN"},
"pipsqueaks":	{"NNS"},
"piptadenia":	{"NN"},
"pipturus":	{"NN"},
"pipul":	{"NN"},
"piquance":	{"NN"},
"piquancy":	{"NN"},
"piquant":	{"JJ"},
"piquantly":	{"RB"},
"piquantness":	{"NN"},
"pique":	{"NN","VB","VBP"},
"piqued":	{"VBD","VBN"},
"piqueria":	{"NN"},
"piques":	{"VBZ"},
"piquet":	{"NN"},
"piquing":	{"VBG"},
"piracy":	{"NN"},
"pirana":	{"NN"},
"piranga":	{"NN"},
"piranha":	{"NN"},
"piranhas":	{"NNS"},
"pirate":	{"NN","VB","VBP"},
"pirated":	{"VBD","VBN","JJ"},
"pirates":	{"NNS","VBZ"},
"piratical":	{"JJ"},
"piratically":	{"RB"},
"pirating":	{"VBG"},
"piroghi":	{"NNS"},
"pirogi":	{"NN"},
"pirogue":	{"NN"},
"pirogues":	{"NNS"},
"piroplasm":	{"NN"},
"piroshki":	{"NN"},
"pirouette":	{"NN","VB","VBP"},
"pirouetted":	{"VBD","VBN"},
"pirouettes":	{"NNS","VBZ"},
"pirouetting":	{"VBG"},
"piroxicam":	{"NN"},
"pirozhki":	{"NN"},
"pisanosaur":	{"NN"},
"pisanosaurus":	{"NN"},
"piscary":	{"NN"},
"piscatorial":	{"JJ"},
"piscatory":	{"JJ"},
"piscidia":	{"NN"},
"piscine":	{"JJ"},
"piscivorous":	{"JJ"},
"pisiform":	{"NN"},
"pismire":	{"NN"},
"pisonia":	{"NN"},
"piss":	{"VB","VBP","NN"},
"piss-up":	{"NN"},
"pissed":	{"VBD","VBN","JJ"},
"pisser":	{"NN"},
"pissers":	{"NNS"},
"pisses":	{"VBZ"},
"pissing":	{"VBG"},
"pissis":	{"NN"},
"pistachio":	{"NN"},
"pistachios":	{"NNS"},
"pistacia":	{"NN"},
"piste":	{"NN"},
"pistes":	{"NNS"},
"pistia":	{"NN"},
"pistil":	{"NN"},
"pistillate":	{"JJ"},
"pistillode":	{"NN"},
"pistils":	{"NNS"},
"pistol":	{"NN","VB","VBP"},
"pistol-packing":	{"JJ"},
"pistol-whip":	{"VB","VBP"},
"pistol-whipped":	{"VBD","VBN"},
"pistol-whipping":	{"VBG"},
"pistol-whips":	{"VBZ"},
"pistoled":	{"VBD","VBN"},
"pistoleer":	{"NN"},
"pistoleers":	{"NNS"},
"pistoling":	{"VBG"},
"pistolled":	{"VBD","VBN"},
"pistolling":	{"VBG"},
"pistols":	{"NNS","VBZ"},
"piston":	{"NN"},
"piston-brake":	{"NN"},
"piston-engined":	{"JJ"},
"piston-rod":	{"NN"},
"pistons":	{"NNS"},
"pisum":	{"NN"},
"pit":	{"NN","VB","VBP"},
"pit-a-pat":	{"RB"},
"pit-head":	{"NN"},
"pit-heads":	{"NNS"},
"pit-prop":	{"NN"},
"pit-run":	{"JJ"},
"pita":	{"NN"},
"pitahaya":	{"NN"},
"pitanga":	{"NN"},
"pitch":	{"NN","VB","VBP"},
"pitch-and-toss":	{"NN"},
"pitch-black":	{"JJ","NN"},
"pitch-dark":	{"JJ"},
"pitch-pine":	{"NN"},
"pitch-pines":	{"NNS"},
"pitchblende":	{"NN"},
"pitched":	{"VBD","VBN","JJ"},
"pitcher":	{"NN"},
"pitcher-coach":	{"NN"},
"pitcher-shaped":	{"JJ"},
"pitcherful":	{"NN"},
"pitchers":	{"NNS"},
"pitches":	{"NNS","VBZ"},
"pitchfork":	{"NN","VBP","VB"},
"pitchforked":	{"VBD","VBN"},
"pitchforking":	{"VBG"},
"pitchforks":	{"NNS","VBZ"},
"pitching":	{"VBG","NN"},
"pitchman":	{"NN"},
"pitchmen":	{"NNS"},
"pitchstone":	{"NN"},
"pitchy":	{"JJ"},
"piteous":	{"JJ"},
"piteously":	{"RB"},
"piteousness":	{"NN"},
"pitfall":	{"NN"},
"pitfalls":	{"NNS"},
"pith":	{"NN","VB","VBP"},
"pithead":	{"NN"},
"pitheads":	{"NNS"},
"pithecanthropi":	{"NNS"},
"pithecanthropine":	{"JJ"},
"pithecanthropoid":	{"JJ"},
"pithecanthropus":	{"NN"},
"pithecellobium":	{"NN"},
"pithecia":	{"NN"},
"pithecolobium":	{"NN"},
"pithed":	{"VBD","VBN"},
"pithier":	{"JJR"},
"pithiest":	{"JJS"},
"pithily":	{"RB"},
"pithiness":	{"NN"},
"pithing":	{"VBG"},
"piths":	{"VBZ"},
"pithy":	{"JJ"},
"pitiable":	{"JJ"},
"pitiably":	{"RB"},
"pitied":	{"VBD","VBN"},
"pities":	{"VBZ"},
"pitiful":	{"JJ"},
"pitifully":	{"RB"},
"pitiless":	{"JJ"},
"pitilessly":	{"RB"},
"pitilessness":	{"NN"},
"pitman":	{"NN"},
"pitmen":	{"NNS"},
"pitocin":	{"NN"},
"piton":	{"NN"},
"pitons":	{"NNS"},
"pitot":	{"NN"},
"pitprop":	{"NN"},
"pitressin":	{"NN"},
"pits":	{"NNS","VBZ"},
"pitsaw":	{"NN"},
"pitt":	{"NN"},
"pitta":	{"NN"},
"pittance":	{"NN"},
"pittances":	{"NNS"},
"pittas":	{"NNS"},
"pitted":	{"JJ","VBN","VBD"},
"pitter-patter":	{"NN","VB","VBP","RB"},
"pitter-pattered":	{"VBD","VBN"},
"pitter-pattering":	{"VBG"},
"pitter-patters":	{"VBZ"},
"pittidae":	{"NN"},
"pitting":	{"VBG"},
"pittman":	{"NN"},
"pittsburgh-based":	{"JJ"},
"pittsfield":	{"NN"},
"pitty-pat":	{"RB"},
"pitty-patty":	{"RB"},
"pituitaries":	{"NNS"},
"pituitary":	{"JJ","NN"},
"pituitary-gland":	{"NN"},
"pituitary-glands":	{"NNS"},
"pituophis":	{"NN"},
"pity":	{"NN","VB","VBP"},
"pitying":	{"VBG","JJ"},
"pityingly":	{"RB"},
"pitymys":	{"NNS"},
"pityriasis":	{"NN"},
"pityrogramma":	{"NN"},
"piute":	{"NN"},
"pivot":	{"NN","VBP","JJ","VB"},
"pivotal":	{"JJ"},
"pivoted":	{"VBD","VBN"},
"pivoting":	{"NN","VBG"},
"pivots":	{"NNS","VBZ"},
"pix":	{"NNS"},
"pixel":	{"NN"},
"pixels":	{"NNS"},
"pixie":	{"NN"},
"pixie-like":	{"JJ"},
"pixies":	{"NNS"},
"pixilated":	{"JJ"},
"pixy":	{"NN"},
"pizazz":	{"NN"},
"pizza":	{"NN"},
"pizza-eating":	{"JJ"},
"pizzas":	{"NNS"},
"pizzas-with-everything":	{"NNS"},
"pizzazz":	{"NN"},
"pizzeria":	{"NN"},
"pizzerias":	{"NNS"},
"pizzicato":	{"JJ","RB","NN"},
"pizzicatos":	{"NNS"},
"pj's":	{"NNS"},
"pkd":	{"NN"},
"pku":	{"NN"},
"pl.":	{"NN"},
"placable":	{"JJ"},
"placard":	{"NN","VB","VBP"},
"placard-carrying":	{"JJ"},
"placarded":	{"VBD","VBN"},
"placarding":	{"VBG"},
"placards":	{"NNS","VBZ"},
"placate":	{"VB","VBP"},
"placated":	{"VBD","VBN"},
"placates":	{"VBZ"},
"placating":	{"VBG"},
"placatingly":	{"RB"},
"placation":	{"NN"},
"placative":	{"JJ"},
"placatory":	{"JJ"},
"place":	{"NN","VB","VBP"},
"place-bet":	{"NN"},
"place-kick":	{"NN"},
"place-kicker":	{"NN"},
"place-kicking":	{"NN"},
"place-mat":	{"NN"},
"place-mats":	{"NNS"},
"place-name":	{"NN"},
"place-names":	{"NNS"},
"place-setting":	{"NN"},
"place-settings":	{"NNS"},
"place-worship":	{"NN"},
"placeable":	{"JJ"},
"placebo":	{"NN"},
"placed":	{"VBN","VBD"},
"placeholder":	{"NN"},
"placeholders":	{"NNS"},
"placekicker":	{"NN"},
"placeless":	{"JJ"},
"placeman":	{"NN"},
"placemen":	{"NNS"},
"placement":	{"NN"},
"placements":	{"NNS"},
"placenta":	{"NN"},
"placentae":	{"NNS"},
"placental":	{"JJ"},
"placentas":	{"NNS"},
"placentation":	{"NN"},
"placer":	{"NN"},
"places":	{"NNS","VBZ"},
"placeseeker":	{"NN"},
"placid":	{"JJ"},
"placidity":	{"NN"},
"placidly":	{"RB"},
"placidness":	{"NN"},
"placidyl":	{"NN"},
"placing":	{"VBG","NN"},
"placings":	{"NNS"},
"placket":	{"NN"},
"placoderm":	{"NN"},
"placodermi":	{"NN"},
"placoid":	{"JJ"},
"placuna":	{"NN"},
"plage":	{"NN"},
"plagianthus":	{"NN"},
"plagiarisation":	{"NN"},
"plagiarise":	{"VB","VBP"},
"plagiarised":	{"VBD","VBN"},
"plagiariser":	{"NN"},
"plagiarises":	{"VBZ"},
"plagiarising":	{"VBG"},
"plagiarism":	{"NN"},
"plagiarisms":	{"NNS"},
"plagiarist":	{"NN"},
"plagiaristic":	{"JJ"},
"plagiarists":	{"NNS"},
"plagiarization":	{"NN"},
"plagiarize":	{"VB","VBP"},
"plagiarized":	{"VBD","VBN"},
"plagiarizer":	{"NN"},
"plagiarizers":	{"NNS"},
"plagiarizes":	{"VBZ"},
"plagiarizing":	{"VBG"},
"plagiocephaly":	{"NN"},
"plagioclase":	{"NN"},
"plagioclastic":	{"JJ"},
"plague":	{"VB","NN","VBP"},
"plague-ridden":	{"JJ"},
"plague-sized":	{"JJ"},
"plague-stricken":	{"JJ"},
"plagued":	{"VBN","VBD"},
"plagues":	{"VBZ","NNS"},
"plaguey":	{"JJ"},
"plaguily":	{"RB"},
"plaguing":	{"VBG"},
"plaguy":	{"JJ"},
"plaice":	{"NN","NNS"},
"plaid":	{"NN","JJ"},
"plaid-floored":	{"JJ"},
"plaids":	{"NNS"},
"plain":	{"JJ","NN","RB"},
"plain-clothes":	{"JJ"},
"plain-out":	{"RB"},
"plain-spoken":	{"JJ"},
"plain-vanilla":	{"JJ"},
"plain-woven":	{"JJ"},
"plainchant":	{"NN"},
"plainclothes":	{"JJ"},
"plainclothesman":	{"NN"},
"plainclothesmen":	{"NNS"},
"plainer":	{"JJR"},
"plainest":	{"JJS"},
"plainly":	{"RB"},
"plainness":	{"NN"},
"plains":	{"NNS"},
"plainsman":	{"NN"},
"plainsmen":	{"NNS"},
"plainsong":	{"NN"},
"plainspoken":	{"JJ"},
"plaint":	{"NN"},
"plaintiff":	{"NN"},
"plaintiffs":	{"NNS"},
"plaintive":	{"JJ"},
"plaintively":	{"RB"},
"plaintiveness":	{"NN"},
"plaints":	{"NNS"},
"plait":	{"VB","VBP","NN"},
"plaited":	{"VBD","VBN"},
"plaiter":	{"NN"},
"plaiting":	{"VBG"},
"plaits":	{"VBZ","NNS"},
"plan":	{"NN","VBP","VB"},
"planar":	{"JJ"},
"planaria":	{"NN"},
"planarian":	{"NN"},
"planate":	{"JJ"},
"planation":	{"NN"},
"planchet":	{"NN"},
"planchette":	{"NN"},
"plane":	{"NN","VBP","JJ","VB"},
"plane-building":	{"NN"},
"plane-polarized":	{"JJ"},
"plane-table":	{"NN"},
"plane-tables":	{"NNS"},
"plane-tree":	{"NN"},
"plane-trees":	{"NNS"},
"planed":	{"VBD","VBN"},
"planeload":	{"NN"},
"planeloads":	{"NNS"},
"planeness":	{"NN"},
"planer":	{"NN"},
"planera":	{"NN"},
"planers":	{"NNS"},
"planes":	{"NNS","VBZ"},
"planet":	{"NN"},
"planetal":	{"JJ"},
"planetaria":	{"NNS"},
"planetarium":	{"NN"},
"planetariums":	{"NNS"},
"planetary":	{"JJ"},
"planetary-science":	{"JJ"},
"planetesimal":	{"JJ","NN"},
"planetoid":	{"NN"},
"planetoids":	{"NNS"},
"planets":	{"NNS"},
"plangency":	{"NN"},
"plangent":	{"JJ"},
"plangently":	{"RB"},
"planimeter":	{"NN"},
"planimeters":	{"NNS"},
"planing":	{"VBG"},
"plank":	{"NN","VB","VBP"},
"plank-bed":	{"NN"},
"planked":	{"VBD","VBN"},
"planking":	{"NN","VBG"},
"planks":	{"VBZ","NNS"},
"plankton":	{"NN"},
"planktonic":	{"JJ"},
"planless":	{"JJ"},
"planned":	{"VBN","VBD","JJ"},
"planner":	{"NN"},
"planners":	{"NNS"},
"planning":	{"VBG","NN"},
"plano":	{"NN"},
"planococcus":	{"NNS"},
"planoconcave":	{"JJ"},
"planoconvex":	{"JJ"},
"planographic":	{"JJ"},
"planography":	{"NN"},
"plans":	{"NNS","VBZ"},
"plant":	{"NN","VB","VBP"},
"plant-and-equipment":	{"JJ"},
"plant-closing":	{"JJ"},
"plant-eating":	{"JJ"},
"plant-expansion":	{"JJ"},
"plant-location":	{"JJ"},
"plant-modernization":	{"JJ"},
"plant-science":	{"NN"},
"plant-sciences":	{"JJ"},
"plant-vaccine":	{"JJ"},
"plant-wide":	{"JJ"},
"plantae":	{"NN"},
"plantagenet":	{"NN"},
"plantaginaceae":	{"NN"},
"plantaginales":	{"NNS"},
"plantago":	{"NN"},
"plantain":	{"NN"},
"plantains":	{"NNS"},
"plantal":	{"JJ"},
"plantar":	{"JJ"},
"plantation":	{"NN"},
"plantations":	{"NNS"},
"planted":	{"VBN","VBD"},
"planter":	{"NN"},
"planters":	{"NNS"},
"planthopper":	{"NN"},
"plantigrade":	{"JJ","NN"},
"planting":	{"VBG","NN"},
"plantings":	{"NNS"},
"plantlet":	{"NN"},
"plants":	{"NNS","VBZ"},
"plantsman":	{"NN"},
"plantsmen":	{"NNS"},
"plantswoman":	{"NN"},
"plantswomen":	{"NNS"},
"planula":	{"NN"},
"plaque":	{"NN"},
"plaquenil":	{"NN"},
"plaques":	{"NNS"},
"plash":	{"NN","VB","VBP"},
"plashed":	{"VBD","VBN"},
"plashes":	{"NNS","VBZ"},
"plashing":	{"VBG"},
"plasm":	{"NN"},
"plasma":	{"NN"},
"plasmablast":	{"NN"},
"plasmacyte":	{"NN"},
"plasmacytoma":	{"NN"},
"plasmapheresis":	{"NN"},
"plasmid":	{"NN"},
"plasmin":	{"NN"},
"plasminogen":	{"NN"},
"plasmodiidae":	{"NN"},
"plasmodiophora":	{"NN"},
"plasmodiophoraceae":	{"NN"},
"plasmodium":	{"NN"},
"plassey":	{"NN"},
"plaster":	{"NN","VB","VBP"},
"plaster-of-Paris":	{"NN"},
"plasterboard":	{"NN"},
"plastered":	{"JJ","VBD","VBN"},
"plasterer":	{"NN"},
"plasterers":	{"NNS"},
"plastering":	{"NN","VBG"},
"plasters":	{"NNS","VBZ"},
"plasterwork":	{"NN"},
"plastic":	{"NN","JJ"},
"plastic-bodied":	{"JJ"},
"plastic-body":	{"JJ"},
"plastic-coated":	{"JJ"},
"plastic-covered":	{"JJ"},
"plastic-pipe":	{"JJ"},
"plastic-products":	{"NNS"},
"plastic-timber":	{"NN"},
"plastically":	{"RB"},
"plasticine":	{"NN"},
"plasticisation":	{"NN"},
"plasticise":	{"VB","VBP"},
"plasticised":	{"VBD","VBN"},
"plasticiser":	{"NN"},
"plasticises":	{"VBZ"},
"plasticising":	{"VBG"},
"plasticity":	{"NN"},
"plasticization":	{"NN"},
"plasticize":	{"VB","VBP"},
"plasticized":	{"VBD","VBN"},
"plasticizer":	{"NN"},
"plasticizes":	{"VBZ"},
"plasticizing":	{"VBG"},
"plastics":	{"NN","NNS"},
"plastics-industry":	{"NN"},
"plastid":	{"NN"},
"plastination":	{"NN"},
"plastique":	{"NN"},
"plastisols":	{"NNS"},
"plastron":	{"NN"},
"plat":	{"NN","VB","VBP"},
"plataea":	{"NN"},
"platalea":	{"NN"},
"plataleidae":	{"NN"},
"platan":	{"NN"},
"platanaceae":	{"NN"},
"platanistidae":	{"NN"},
"platanthera":	{"NN"},
"platanus":	{"NN"},
"plate":	{"NN","VB","VBP"},
"plate-rack":	{"NN"},
"plateau":	{"NN","VB","VBP"},
"plateaued":	{"VBD","VBN"},
"plateauing":	{"VBG"},
"plateaus":	{"NNS","VBZ"},
"plateaux":	{"NNS"},
"plated":	{"VBN","VBD","JJ"},
"plateful":	{"NN"},
"platefuls":	{"NNS"},
"platelayer":	{"NN"},
"platelayers":	{"NNS"},
"platelet":	{"NN"},
"plateletpheresis":	{"NN"},
"platelets":	{"NNS"},
"platelike":	{"JJ"},
"platen":	{"NN"},
"platens":	{"NNS"},
"plater":	{"NN"},
"plates":	{"NNS","VBZ"},
"platform":	{"NN"},
"platform-controller":	{"NN"},
"platforms":	{"NNS"},
"platichthys":	{"NNS"},
"plating":	{"NN","VBG"},
"platinize":	{"VB","VBP"},
"platinized":	{"VBD","VBN"},
"platinizes":	{"VBZ"},
"platinizing":	{"VBG"},
"platinum":	{"NN"},
"platinum-blonde":	{"JJ"},
"platitude":	{"NN"},
"platitudes":	{"NNS"},
"platitudinal":	{"JJ"},
"platitudinarian":	{"NN"},
"platitudinize":	{"VB","VBP"},
"platitudinized":	{"VBD","VBN"},
"platitudinizes":	{"VBZ"},
"platitudinizing":	{"VBG"},
"platitudinous":	{"JJ"},
"platonic":	{"JJ"},
"platonist":	{"NN"},
"platonistic":	{"JJ"},
"platoon":	{"NN","VB","VBP"},
"platooned":	{"VBD","VBN"},
"platooning":	{"VBG"},
"platoons":	{"NNS","VBZ"},
"plats":	{"NNS","VBZ"},
"platt":	{"NN"},
"plattdeutsch":	{"NN"},
"platte":	{"NN"},
"platted":	{"VBD","VBN"},
"plattensee":	{"NN"},
"platter":	{"NN"},
"platters":	{"NNS"},
"platting":	{"VBG"},
"platy":	{"NN"},
"platycephalidae":	{"NN"},
"platycerium":	{"NN"},
"platyctenea":	{"NN"},
"platyctenean":	{"NN"},
"platyhelminth":	{"NN"},
"platyhelminthes":	{"NNS"},
"platylobium":	{"NN"},
"platymiscium":	{"NN"},
"platypoecilus":	{"NN"},
"platypus":	{"NN"},
"platypuses":	{"NNS"},
"platyrhine":	{"JJ"},
"platyrhinian":	{"JJ"},
"platyrrhine":	{"JJ","NN"},
"platyrrhini":	{"NN"},
"platyrrhinian":	{"JJ","NN"},
"platyrrhinic":	{"JJ"},
"platysma":	{"NN"},
"platystemon":	{"NN"},
"plaudit":	{"NN"},
"plaudits":	{"NNS"},
"plausibility":	{"NN"},
"plausible":	{"JJ"},
"plausibleness":	{"NN"},
"plausibly":	{"RB"},
"plausive":	{"JJ"},
"plautus":	{"NN"},
"plavix":	{"NN"},
"play":	{"VB","NN","VBP"},
"play-act":	{"VB","VBP"},
"play-acted":	{"VBD","VBN"},
"play-acting":	{"VBG","NN"},
"play-actor":	{"NN"},
"play-acts":	{"VBZ"},
"play-back":	{"NN"},
"play-backs":	{"NNS"},
"play-box":	{"NN"},
"play-by-play":	{"NN"},
"play-girl":	{"NN"},
"play-it-safe":	{"JJ"},
"play-off":	{"NN"},
"play-offs":	{"NNS"},
"play-pen":	{"NN"},
"play-pens":	{"NNS"},
"play-room":	{"NN"},
"play-rooms":	{"NNS"},
"playable":	{"JJ"},
"playact":	{"VB","VBP"},
"playacted":	{"VBD","VBN"},
"playacting":	{"VBG","NN"},
"playactor":	{"NN"},
"playacts":	{"VBZ"},
"playback":	{"NN"},
"playbacks":	{"NNS"},
"playbill":	{"NN"},
"playbills":	{"NNS"},
"playbook":	{"NN"},
"playbox":	{"NN"},
"playboy":	{"NN"},
"playboys":	{"NNS"},
"playday":	{"NN"},
"played":	{"VBD","VBN"},
"played-out":	{"JJ"},
"player":	{"NN"},
"player-piano":	{"NN"},
"player-pianos":	{"NNS"},
"players":	{"NNS"},
"playfellow":	{"NN"},
"playfellows":	{"NNS"},
"playful":	{"JJ"},
"playfully":	{"RB"},
"playfulness":	{"NN"},
"playgoer":	{"NN"},
"playgoers":	{"NNS"},
"playground":	{"NN"},
"playgrounds":	{"NNS"},
"playhouse":	{"NN"},
"playhouses":	{"NNS"},
"playing":	{"VBG","NN"},
"playland":	{"NN"},
"playlet":	{"NN"},
"playlets":	{"NNS"},
"playlist":	{"NN","VB","VBP"},
"playlisted":	{"VBD","VBN"},
"playlisting":	{"VBG"},
"playlists":	{"NNS","VBZ"},
"playmaker":	{"NN"},
"playmate":	{"NN"},
"playmates":	{"NNS"},
"playoff":	{"NN"},
"playoffs":	{"NNS"},
"playpen":	{"NN"},
"playpens":	{"NNS"},
"playroom":	{"NN"},
"playrooms":	{"NNS"},
"plays":	{"VBZ","NNS"},
"playschool":	{"NN"},
"playschools":	{"NNS"},
"playscript":	{"NN"},
"playsuit":	{"NN"},
"playsuits":	{"NNS"},
"plaything":	{"NN"},
"playthings":	{"NNS"},
"playtime":	{"NN"},
"playwright":	{"NN"},
"playwright-director":	{"NN"},
"playwrights":	{"NNS"},
"playwriting":	{"NN"},
"plaza":	{"NN"},
"plazas":	{"NNS"},
"plea":	{"NN"},
"plea-bargain":	{"VB","VBP"},
"plea-bargained":	{"VBD","VBN"},
"plea-bargaining":	{"VBG"},
"plea-bargains":	{"VBZ"},
"pleach":	{"VB","VBP"},
"pleached":	{"VBD","VBN"},
"pleaches":	{"VBZ"},
"pleaching":	{"VBG"},
"plead":	{"VB","VBP"},
"pleaded":	{"VBD","VBN"},
"pleader":	{"NN"},
"pleaders":	{"NNS"},
"pleading":	{"VBG","JJ","NN"},
"pleadingly":	{"RB"},
"pleadings":	{"NNS"},
"pleads":	{"VBZ","NNS"},
"pleas":	{"NNS"},
"pleasance":	{"NN"},
"pleasant":	{"JJ"},
"pleasant-smelling":	{"JJ"},
"pleasant-tasting":	{"JJ"},
"pleasanter":	{"JJR"},
"pleasantest":	{"JJS"},
"pleasantly":	{"RB"},
"pleasantness":	{"NN"},
"pleasantries":	{"NNS"},
"pleasantry":	{"NN"},
"please":	{"VB","VBP","UH"},
"pleased":	{"VBN","JJ","VBD"},
"pleaser":	{"NN"},
"pleases":	{"VBZ"},
"pleasing":	{"JJ","VBG"},
"pleasingly":	{"RB"},
"pleasingness":	{"NN"},
"pleasurable":	{"JJ"},
"pleasurably":	{"RB"},
"pleasure":	{"NN","VB","VBP"},
"pleasure-boat":	{"NN"},
"pleasure-boats":	{"NNS"},
"pleasure-craft":	{"NN","NNS"},
"pleasure-ground":	{"NN"},
"pleasure-grounds":	{"NNS"},
"pleasure-seeking":	{"JJ"},
"pleasured":	{"VBD","VBN"},
"pleasureful":	{"JJ"},
"pleasureless":	{"JJ"},
"pleasures":	{"VBZ","NNS"},
"pleasuring":	{"VBG"},
"pleat":	{"NN","VB","VBP"},
"pleated":	{"VBD","VBN","JJ"},
"pleating":	{"VBG"},
"pleats":	{"NNS","VBZ"},
"pleb":	{"NN"},
"plebby":	{"JJ"},
"plebe":	{"NN"},
"plebeian":	{"JJ","NN"},
"plebeians":	{"NNS"},
"plebes":	{"NNS"},
"plebian":	{"JJ"},
"plebiscite":	{"NN"},
"plebiscites":	{"NNS"},
"plebs":	{"NNS"},
"plecoptera":	{"NN"},
"plecopteran":	{"NN"},
"plecotus":	{"NN"},
"plectania":	{"NN"},
"plectognath":	{"NN"},
"plectognathi":	{"NN"},
"plectomycetes":	{"NNS"},
"plectophera":	{"NN"},
"plectorrhiza":	{"NN"},
"plectra":	{"NNS"},
"plectranthus":	{"NNS"},
"plectron":	{"NN"},
"plectrophenax":	{"NN"},
"plectrum":	{"NN"},
"pled":	{"VBD","VBN"},
"pledge":	{"NN","VB","VBP"},
"pledged":	{"VBD","VBN"},
"pledgee":	{"NN"},
"pledgees":	{"NNS"},
"pledger":	{"NN"},
"pledgers":	{"NNS"},
"pledges":	{"NNS","VBZ"},
"pledging":	{"NN","VBG"},
"pleione":	{"NN"},
"pleiospilos":	{"NN"},
"plenaries":	{"NNS"},
"plenarily":	{"RB"},
"plenary":	{"JJ","NN"},
"plenipotentiaries":	{"NNS"},
"plenipotentiary":	{"NN","JJ"},
"plenitude":	{"NN"},
"plenteous":	{"JJ"},
"plenteously":	{"RB"},
"plenteousness":	{"NN"},
"plentiful":	{"JJ"},
"plentifully":	{"RB"},
"plentifulness":	{"NN"},
"plentitude":	{"NN"},
"plenty":	{"JJ","RB","NN"},
"plenum":	{"NN"},
"plenums":	{"NNS"},
"pleochroic":	{"JJ"},
"pleochroism":	{"NN"},
"pleomorphic":	{"JJ"},
"pleomorphism":	{"NN"},
"pleonasm":	{"NN"},
"pleonaste":	{"NN"},
"pleonastic":	{"JJ"},
"pleopod":	{"NN"},
"plesianthropus":	{"NN"},
"plesiosaur":	{"NN"},
"plesiosauria":	{"NN"},
"plesiosaurus":	{"NN"},
"plessimeter":	{"NN"},
"plessis":	{"NN"},
"plessor":	{"NN"},
"plethodon":	{"NN"},
"plethodont":	{"NN"},
"plethodontidae":	{"NN"},
"plethora":	{"NN"},
"plethoric":	{"JJ"},
"plethysmograph":	{"NN"},
"pleura":	{"NN"},
"pleural":	{"JJ"},
"pleuralgia":	{"NN"},
"pleurisy":	{"NN"},
"pleurobrachia":	{"NN"},
"pleurobrachiidae":	{"NN"},
"pleurocarp":	{"NN"},
"pleurocarpous":	{"JJ"},
"pleurodont":	{"NN"},
"pleurodynia":	{"NN"},
"pleuronectes":	{"NNS"},
"pleuronectidae":	{"NN"},
"pleuropneumonia":	{"NN"},
"pleurosorus":	{"NN"},
"pleurothallis":	{"NN"},
"pleurotus":	{"NN"},
"pleven":	{"NN"},
"plevna":	{"NN"},
"plexiglass":	{"NN"},
"pleximeter":	{"NN"},
"pleximetry":	{"NN"},
"plexor":	{"NN"},
"plexus":	{"NN","NNS"},
"plexuses":	{"NNS"},
"plf":	{"NN"},
"pliability":	{"NN"},
"pliable":	{"JJ"},
"pliancy":	{"NN"},
"pliant":	{"JJ"},
"pliantly":	{"RB"},
"pliantness":	{"NN"},
"plica":	{"NN"},
"plicate":	{"JJ"},
"plication":	{"NN"},
"plicatoperipatus":	{"NN"},
"plie":	{"NN"},
"plied":	{"VBD","VBN"},
"plier":	{"NN"},
"pliers":	{"NNS"},
"plies":	{"VBZ"},
"plight":	{"NN","VB","VBP"},
"plighted":	{"VBD","VBN"},
"plighting":	{"VBG"},
"plights":	{"NNS","VBZ"},
"plimsoll":	{"NN"},
"plimsolls":	{"NNS"},
"plink":	{"NN","VB","VBP"},
"plinked":	{"VBD","VBN"},
"plinking":	{"VBG","NN","JJ"},
"plinks":	{"NNS","VBZ"},
"plinth":	{"NN"},
"plinths":	{"NNS"},
"pliny":	{"NN"},
"plo-backed":	{"JJ"},
"ploce":	{"NN"},
"ploceidae":	{"NN"},
"ploceus":	{"NN"},
"plod":	{"VB","VBP","NN"},
"plodded":	{"VBD","VBN"},
"plodder":	{"NN"},
"plodders":	{"NNS"},
"plodding":	{"JJ","VBG"},
"ploddingly":	{"RB"},
"ploddingness":	{"NN"},
"plods":	{"VBZ","NNS"},
"plonk":	{"NN","VB","VBP","RB"},
"plonked":	{"VBD","VBN"},
"plonking":	{"VBG"},
"plonks":	{"VBZ"},
"plop":	{"NN","VB","VBP","RB"},
"plopped":	{"VBD","VBN"},
"plopping":	{"VBG"},
"plops":	{"VBZ","NNS"},
"plosion":	{"NN"},
"plosive":	{"NN","JJ"},
"plosives":	{"NNS"},
"plot":	{"NN","VB","VBP"},
"plotinus":	{"NN"},
"plots":	{"NNS","VBZ"},
"plotted":	{"VBD","VBN"},
"plotter":	{"NN"},
"plotters":	{"NNS"},
"plotting":	{"VBG","NN"},
"plottings":	{"NNS"},
"plough":	{"NN","VB","VBP"},
"ploughboy":	{"NN"},
"ploughed":	{"VBD","VBN"},
"ploughing":	{"NN","VBG"},
"ploughland":	{"NN"},
"ploughman":	{"NN"},
"ploughmen":	{"NNS"},
"ploughs":	{"NNS","VBZ"},
"ploughshare":	{"NN"},
"ploughshares":	{"NNS"},
"ploughwright":	{"NN"},
"plovdiv":	{"NN"},
"plover":	{"NN"},
"plovers":	{"NNS"},
"plow":	{"NN","VB","VBP"},
"plowboy":	{"NN"},
"plowboys":	{"NNS"},
"plowed":	{"VBD","VBN"},
"plower":	{"NN"},
"plowing":	{"NN","VBG"},
"plowland":	{"NN"},
"plowman":	{"NN"},
"plowmen":	{"NNS"},
"plows":	{"NNS","VBZ"},
"plowshare":	{"NN"},
"plowshares":	{"NNS"},
"plowwright":	{"NN"},
"ploy":	{"NN"},
"ployment":	{"NN"},
"ploys":	{"NNS"},
"pluck":	{"VB","VBP","NN"},
"plucked":	{"VBD","VBN"},
"pluckier":	{"JJR"},
"pluckiest":	{"JJS"},
"pluckily":	{"RB"},
"pluckiness":	{"NN"},
"plucking":	{"VBG"},
"plucks":	{"VBZ"},
"plucky":	{"JJ"},
"plug":	{"NN","VB","VBP"},
"plug-hole":	{"NN"},
"plug-holes":	{"NNS"},
"plug-in":	{"JJ","NN"},
"plug-ins":	{"NNS"},
"plug-ugly":	{"NN"},
"plugboard":	{"NN"},
"plugged":	{"VBD","VBN"},
"plugger":	{"NN"},
"plugging":	{"VBG"},
"plughole":	{"NN"},
"plugholes":	{"NNS"},
"plugs":	{"VBZ","NNS"},
"plugugly":	{"JJ","NN"},
"plum":	{"NN","JJ"},
"plum-yew":	{"NN"},
"plumage":	{"NN"},
"plumaged":	{"JJ"},
"plumate":	{"JJ"},
"plumb":	{"NN","VBP","RB","JJ","VB"},
"plumbable":	{"JJ"},
"plumbaginaceae":	{"NN"},
"plumbaginaceous":	{"JJ"},
"plumbaginales":	{"NNS"},
"plumbago":	{"NN"},
"plumbed":	{"VBD","VBN"},
"plumber":	{"NN"},
"plumbers":	{"NNS"},
"plumbery":	{"NN"},
"plumbic":	{"JJ"},
"plumbing":	{"NN","VBG"},
"plumbism":	{"NN"},
"plumbous":	{"JJ"},
"plumbs":	{"VBZ"},
"plumcot":	{"NN"},
"plume":	{"NN","VBP","VB"},
"plume-tipped":	{"JJ"},
"plumed":	{"VBD","VBN","JJ"},
"plumelike":	{"JJ"},
"plumeria":	{"NN"},
"plumes":	{"NNS","VBZ"},
"plumiera":	{"NN"},
"pluming":	{"VBG"},
"plumlike":	{"JJ"},
"plummet":	{"VB","VBP","NN"},
"plummeted":	{"VBD","VBN"},
"plummeting":	{"VBG"},
"plummets":	{"VBZ","NNS"},
"plummier":	{"JJR"},
"plummiest":	{"JJS"},
"plummy":	{"JJ"},
"plumose":	{"JJ"},
"plump":	{"JJ","NN","VB","VBP","RB"},
"plumped":	{"VBD","VBN"},
"plumping":	{"VBG"},
"plumpness":	{"NN"},
"plumps":	{"VBZ"},
"plums":	{"NNS"},
"plumule":	{"NN"},
"plumy":	{"JJ"},
"plunder":	{"VB","VBP","NN"},
"plunderage":	{"NN"},
"plundered":	{"VBD","VBN"},
"plunderer":	{"NN"},
"plunderers":	{"NNS"},
"plundering":	{"NN","VBG"},
"plunders":	{"VBZ"},
"plunge":	{"VB","VBP","NN"},
"plunged":	{"VBD","VBN"},
"plunger":	{"NN"},
"plungers":	{"NNS"},
"plunges":	{"NNS","VBZ"},
"plunging":	{"VBG","NN"},
"plunk":	{"VB","VBP","NN","UH","RB"},
"plunked":	{"VBD","VBN"},
"plunker":	{"NN"},
"plunkers":	{"NNS"},
"plunking":	{"VBG"},
"plunks":	{"VBZ"},
"pluperfect":	{"JJ","NN"},
"plural":	{"JJ","NN"},
"pluralisation":	{"NN"},
"pluralise":	{"VB","VBP"},
"pluralised":	{"VBD","VBN"},
"pluraliser":	{"NN"},
"pluralises":	{"VBZ"},
"pluralising":	{"VBG"},
"pluralism":	{"NN"},
"pluralist":	{"NN","JJ"},
"pluralistic":	{"JJ"},
"pluralists":	{"NNS"},
"pluralities":	{"NNS"},
"plurality":	{"NN"},
"pluralization":	{"NN"},
"pluralize":	{"VB","VBP"},
"pluralized":	{"VBD","VBN"},
"pluralizer":	{"NN"},
"pluralizes":	{"VBZ"},
"pluralizing":	{"VBG"},
"plurals":	{"NNS"},
"pluri-party":	{"JJ"},
"plus":	{"IN","JJ","NN"},
"plus-fours":	{"NNS"},
"plus-one":	{"JJ","RB"},
"pluses":	{"NNS"},
"plush":	{"NN","JJ"},
"plush-like":	{"JJ"},
"plusher":	{"JJR"},
"plushest":	{"JJS"},
"plushier":	{"JJR"},
"plushiest":	{"JJS"},
"plushy":	{"JJ"},
"pluteaceae":	{"NN"},
"pluteus":	{"NNS"},
"plutocracies":	{"NNS"},
"plutocracy":	{"NN"},
"plutocrat":	{"NN"},
"plutocratic":	{"JJ"},
"plutocratical":	{"JJ"},
"plutocrats":	{"NNS"},
"pluton":	{"NN"},
"plutonian":	{"JJ"},
"plutonic":	{"JJ"},
"plutonium":	{"NN"},
"plutonium-based":	{"JJ"},
"plutonium-handling":	{"NN"},
"plutonium-powered":	{"JJ"},
"plutonium-recovery":	{"JJ"},
"pluvialis":	{"NN"},
"pluvianus":	{"NN"},
"pluviometer":	{"NN"},
"pluviose":	{"NN"},
"ply":	{"NN","NNS","VB","VBP"},
"plyboard":	{"NN"},
"plyer":	{"NN"},
"plyers":	{"NNS"},
"plying":	{"NN","VBG"},
"plywood":	{"NN"},
"plzen":	{"NN"},
"pm":	{"RB"},
"pm.":	{"RB"},
"pms":	{"NN"},
"pneumatic":	{"JJ"},
"pneumatically":	{"RB"},
"pneumatics":	{"NN"},
"pneumatophore":	{"NN"},
"pneumococcal":	{"JJ"},
"pneumococcus":	{"NN"},
"pneumoconiosis":	{"NN"},
"pneumocystis":	{"NN"},
"pneumocytosis":	{"NN"},
"pneumoencephalogram":	{"NN"},
"pneumogastric":	{"JJ"},
"pneumonectomy":	{"NN"},
"pneumonia":	{"NN"},
"pneumonic":	{"JJ"},
"pneumonitis":	{"NN"},
"pneumonoconiosis":	{"NN"},
"pneumonosis":	{"NN"},
"pneumothorax":	{"NN"},
"pneumovax":	{"NN"},
"po-faced":	{"JJ"},
"poa":	{"NN"},
"poaceae":	{"NN"},
"poach":	{"VB","VBP"},
"poached":	{"VBD","VBN"},
"poacher":	{"NN"},
"poachers":	{"NNS"},
"poaches":	{"VBZ","NNS"},
"poaching":	{"NN","VBG"},
"poark":	{"NN"},
"pocatello":	{"NN"},
"pochard":	{"NN","NNS"},
"pochards":	{"NNS"},
"pock":	{"NN"},
"pocked":	{"JJ"},
"pocket":	{"NN","VB","VBP","JJ"},
"pocket-handkerchief":	{"NN","JJ"},
"pocket-size":	{"JJ"},
"pocket-sized":	{"JJ"},
"pocketable":	{"JJ"},
"pocketbook":	{"NN"},
"pocketbooks":	{"NNS"},
"pocketcomb":	{"NN"},
"pocketed":	{"VBD","VBN"},
"pocketful":	{"NN"},
"pocketfuls":	{"NNS"},
"pocketing":	{"VBG"},
"pocketknife":	{"NN"},
"pocketknives":	{"NNS"},
"pockets":	{"NNS","VBZ"},
"pockier":	{"JJR"},
"pockiest":	{"JJS"},
"pockmark":	{"NN","VB","VBP"},
"pockmarked":	{"VBD","VBN","JJ"},
"pockmarking":	{"VBG"},
"pockmarks":	{"NNS","VBZ"},
"pocky":	{"JJ"},
"pod":	{"NN","VB","VBP"},
"podalgia":	{"NN"},
"podalyria":	{"NN"},
"podargidae":	{"NN"},
"podargus":	{"NN"},
"podaxaceae":	{"NN"},
"podcast":	{"NN","VB","VBP","VBD","VBN"},
"podcasted":	{"VBD","VBN"},
"podcaster":	{"NN"},
"podcasting":	{"VBG","NN"},
"podcasts":	{"NNS","VBZ"},
"podded":	{"VBD","VBN"},
"podding":	{"VBG"},
"podetium":	{"NN"},
"podgers":	{"NNS"},
"podgier":	{"JJR"},
"podgiest":	{"JJS"},
"podgy":	{"JJ"},
"podiatric":	{"JJ"},
"podiatrist":	{"NN"},
"podiatrists":	{"NNS"},
"podiatry":	{"NN"},
"podiceps":	{"NNS"},
"podicipedidae":	{"NN"},
"podicipediformes":	{"NNS"},
"podicipitiformes":	{"NNS"},
"podilymbus":	{"NN"},
"podium":	{"NN"},
"podiums":	{"NNS"},
"podlike":	{"JJ"},
"podocarp":	{"NN"},
"podocarpaceae":	{"NN"},
"podocarpus":	{"NN"},
"podophyllum":	{"NN"},
"pods":	{"NNS","VBZ"},
"podsol":	{"NN"},
"podzol":	{"NN"},
"poeciliid":	{"NN"},
"poeciliidae":	{"NN"},
"poecilocapsus":	{"NN"},
"poecilogale":	{"NN"},
"poem":	{"NN"},
"poems":	{"NNS"},
"poems-in-drawing-and-type":	{"JJ"},
"poenology":	{"NN"},
"poephila":	{"NN"},
"poesies":	{"NNS"},
"poesy":	{"NN"},
"poet":	{"NN"},
"poet-painter":	{"NN"},
"poet-singer":	{"NN"},
"poetess":	{"NN"},
"poetesses":	{"NNS"},
"poetic":	{"JJ"},
"poetical":	{"JJ"},
"poetically":	{"RB"},
"poeticise":	{"VB","VBP"},
"poeticised":	{"VBD","VBN"},
"poeticises":	{"VBZ"},
"poeticising":	{"VBG"},
"poeticize":	{"VB","VBP"},
"poeticized":	{"VBD","VBN"},
"poeticizes":	{"VBZ"},
"poeticizing":	{"VBG"},
"poetics":	{"NN"},
"poetise":	{"VB","VBP"},
"poetised":	{"VBD","VBN"},
"poetiser":	{"NN"},
"poetises":	{"VBZ"},
"poetising":	{"VBG"},
"poetize":	{"VB","VBP"},
"poetized":	{"VBD","VBN"},
"poetizer":	{"NN"},
"poetizes":	{"VBZ"},
"poetizing":	{"VBG"},
"poetry":	{"NN"},
"poetry-and-jazz":	{"NN","JJ"},
"poetry-writing":	{"JJ"},
"poets":	{"NNS"},
"pogey":	{"NN"},
"pogge":	{"NN"},
"pogonia":	{"NN"},
"pogonion":	{"NN"},
"pogonip":	{"NN"},
"pogonophora":	{"NN"},
"pogonophoran":	{"NN"},
"pogostemon":	{"NN"},
"pogrom":	{"NN"},
"pogroms":	{"NNS"},
"pogue":	{"NN"},
"pogy":	{"NN"},
"poi":	{"NN"},
"poignance":	{"NN"},
"poignancy":	{"NN"},
"poignant":	{"JJ"},
"poignantly":	{"RB"},
"poikilotherm":	{"NN"},
"poikilothermic":	{"JJ"},
"poikilothermous":	{"JJ"},
"poilu":	{"NN"},
"poinciana":	{"NN"},
"poinsettia":	{"NN"},
"poinsettias":	{"NNS"},
"point":	{"NN","VB","VBP"},
"point-blank":	{"RB","JJ"},
"point-duty":	{"NN"},
"point-of-sale":	{"JJ","NN"},
"point-spread":	{"JJ"},
"point-to-point":	{"NN"},
"pointe":	{"NN"},
"pointed":	{"VBD","VBN","JJ"},
"pointed-toe":	{"JJ"},
"pointedly":	{"RB"},
"pointedness":	{"NN"},
"pointel":	{"NN"},
"pointer":	{"NN"},
"pointers":	{"NNS"},
"pointes":	{"NN"},
"pointier":	{"JJR"},
"pointiest":	{"JJS"},
"pointillism":	{"NN"},
"pointillist":	{"NN","JJ"},
"pointillistic":	{"JJ"},
"pointillists":	{"NNS"},
"pointing":	{"VBG","NN"},
"pointless":	{"JJ"},
"pointlessly":	{"RB"},
"pointlessness":	{"NN"},
"pointrel":	{"NN"},
"points":	{"NNS","VBZ"},
"pointsman":	{"NN"},
"pointsmen":	{"NNS"},
"pointy":	{"JJ"},
"pointy-toed":	{"JJ"},
"poise":	{"NN","VB","VBP"},
"poised":	{"VBN","VBD","JJ"},
"poises":	{"NNS","VBZ"},
"poising":	{"VBG"},
"poison":	{"NN","VB","VBP"},
"poison-berry":	{"NN"},
"poison-pen":	{"JJ"},
"poison-pill":	{"JJ","NN"},
"poisonberry":	{"NN"},
"poisoned":	{"JJ","VBD","VBN"},
"poisoner":	{"NN"},
"poisoners":	{"NNS"},
"poisoning":	{"NN","VBG"},
"poisonings":	{"NNS"},
"poisonous":	{"JJ"},
"poisonously":	{"RB"},
"poisons":	{"VBZ","NNS"},
"poitou":	{"NN"},
"poitou-charentes":	{"NNS"},
"poivrade":	{"NN"},
"poivre":	{"NN"},
"poke":	{"VB","VBP","NN"},
"poked":	{"VBD","VBN"},
"pokeies":	{"NNS"},
"pokeneu":	{"FW"},
"poker":	{"NN"},
"poker-face":	{"NN"},
"poker-faced":	{"JJ"},
"poker-work":	{"NN"},
"pokers":	{"NNS"},
"pokes":	{"VBZ","NNS"},
"pokeweed":	{"NN"},
"pokey":	{"JJ","NN"},
"pokeys":	{"NNS"},
"pokier":	{"JJR"},
"pokiest":	{"JJS"},
"pokily":	{"RB"},
"pokiness":	{"NN"},
"poking":	{"VBG"},
"pokomo":	{"NN"},
"poky":	{"JJ"},
"pol":	{"NN"},
"polanisia":	{"NN"},
"polar":	{"JJ"},
"polarimeter":	{"NN"},
"polarimeters":	{"NNS"},
"polarisation":	{"NN"},
"polariscope":	{"NN"},
"polariscopes":	{"NNS"},
"polarise":	{"VB","VBP"},
"polarised":	{"VBD","VBN"},
"polarises":	{"VBZ"},
"polarising":	{"VBG"},
"polarities":	{"NNS"},
"polarity":	{"NN"},
"polarization":	{"NN"},
"polarize":	{"VB","VBP"},
"polarized":	{"VBD","VBN"},
"polarizes":	{"VBZ"},
"polarizing":	{"VBG"},
"polarographic":	{"JJ"},
"polarography":	{"NN"},
"polder":	{"NN"},
"pole":	{"NN","VB","VBP"},
"pole-handled":	{"JJ"},
"pole-star":	{"NN"},
"pole-vault":	{"VB","VBP","NN"},
"pole-vaulted":	{"VBD","VBN"},
"pole-vaulter":	{"NN"},
"pole-vaulters":	{"NNS"},
"pole-vaulting":	{"VBG","NN"},
"pole-vaults":	{"VBZ"},
"poleax":	{"NN","VB","VBP"},
"poleaxe":	{"NN","VB","VBP"},
"poleaxed":	{"VBD","VBN"},
"poleaxes":	{"NNS","VBZ"},
"poleaxing":	{"VBG"},
"polecat":	{"NN"},
"polecats":	{"NNS"},
"poled":	{"VBD","VBN"},
"polemic":	{"NN","JJ"},
"polemical":	{"JJ"},
"polemically":	{"RB"},
"polemicise":	{"VB","VBP"},
"polemicised":	{"VBD","VBN"},
"polemicises":	{"VBZ"},
"polemicising":	{"VBG"},
"polemicist":	{"NN"},
"polemicists":	{"NNS"},
"polemicize":	{"VB","VBP"},
"polemicized":	{"VBD","VBN"},
"polemicizes":	{"VBZ"},
"polemicizing":	{"VBG"},
"polemics":	{"NN","NNS"},
"polemise":	{"VB","VBP"},
"polemist":	{"NN"},
"polemize":	{"VB","VBP"},
"polemoniaceae":	{"NN"},
"polemoniaceous":	{"JJ"},
"polemoniales":	{"NNS"},
"polemonium":	{"NN"},
"polenta":	{"NN"},
"poler":	{"NN"},
"polers":	{"NNS"},
"poles":	{"NNS","VBZ"},
"polestar":	{"NN"},
"polianthes":	{"NNS"},
"police":	{"NN","NNS","VB","VBP"},
"police-community":	{"JJ"},
"police-dodging":	{"NN"},
"policed":	{"VBD","VBN"},
"policeman":	{"NN"},
"policeman-murderer":	{"NN"},
"policemen":	{"NNS"},
"polices":	{"VBZ"},
"policewoman":	{"NN"},
"policewomen":	{"NNS"},
"policies":	{"NNS"},
"policing":	{"NN","VBG"},
"policy":	{"NN"},
"policy-coordination":	{"NN"},
"policy-maker":	{"NN"},
"policy-makers":	{"NNS"},
"policy-making":	{"NN"},
"policy-oriented":	{"JJ"},
"policy-research":	{"NN"},
"policy-setting":	{"JJ"},
"policyholder":	{"NN"},
"policyholders":	{"NNS"},
"policymaker":	{"NN"},
"policymakers":	{"NNS"},
"policymaking":	{"NN"},
"poling":	{"VBG"},
"polio":	{"NN"},
"poliomyelitis":	{"NN"},
"polioptila":	{"NN"},
"poliosis":	{"NN"},
"poliovirus":	{"NN","JJ"},
"polis":	{"NN"},
"polish":	{"NN","VB","VBP"},
"polished":	{"JJ","VBD","VBN"},
"polisher":	{"NN"},
"polishers":	{"NNS"},
"polishes":	{"VBZ","NNS"},
"polishing":	{"NN","VBG"},
"polistes":	{"NNS"},
"politburo":	{"NN"},
"politburos":	{"NNS"},
"polite":	{"JJ"},
"politely":	{"RB"},
"politeness":	{"NN"},
"politesse":	{"NN"},
"politic":	{"JJ","VB","VBP"},
"political":	{"JJ"},
"political-action":	{"JJ"},
"political-corruption":	{"NN"},
"political-reform":	{"JJ"},
"politically":	{"RB"},
"politician":	{"NN"},
"politicians":	{"NNS"},
"politicisation":	{"NN"},
"politicise":	{"VB","VBP"},
"politicised":	{"VBD","VBN","JJ"},
"politicises":	{"VBZ"},
"politicising":	{"VBG"},
"politicization":	{"NN"},
"politicize":	{"VB","VBP"},
"politicized":	{"VBD","VBN","JJ"},
"politicizes":	{"VBZ"},
"politicizing":	{"VBG"},
"politick":	{"VB","VBP"},
"politicked":	{"VBD","VBN"},
"politicking":	{"NN","VBG"},
"politicks":	{"VBZ"},
"politico":	{"NN"},
"politico-plaintiffs":	{"NNS"},
"politico-sociological":	{"JJ"},
"politicos":	{"NNS"},
"politics":	{"NN","NNS","VBZ"},
"politics-ridden":	{"JJ"},
"polities":	{"NNS"},
"politique":	{"NN","FW"},
"politrick":	{"NN"},
"polity":	{"NN"},
"polivinylchloride":	{"NN"},
"polka":	{"NN","VB","VBP"},
"polka-dotted":	{"JJ"},
"polkaed":	{"VBD","VBN"},
"polkaing":	{"VBG"},
"polkas":	{"NNS","VBZ"},
"poll":	{"NN","VB","VBP"},
"poll-taker":	{"NN"},
"poll-takers":	{"NNS"},
"pollachius":	{"NN"},
"pollack":	{"NN"},
"pollard":	{"VB","VBP","NN"},
"pollarded":	{"VBD","VBN"},
"pollarding":	{"VBG"},
"pollards":	{"VBZ"},
"polled":	{"VBN","VBD","JJ"},
"pollen":	{"NN"},
"pollen-and-nectar":	{"NN"},
"pollen-inhibiting":	{"JJ"},
"pollen-producing":	{"VBG"},
"pollenate":	{"VB","VBP"},
"pollenated":	{"VBD","VBN"},
"pollenates":	{"VBZ"},
"pollenating":	{"VBG"},
"pollenation":	{"NN"},
"pollens":	{"NNS"},
"pollex":	{"NN"},
"pollices":	{"NNS"},
"pollinate":	{"VB","VBP"},
"pollinated":	{"VBN","VBD"},
"pollinates":	{"VBZ"},
"pollinating":	{"VBG"},
"pollination":	{"NN"},
"pollinator":	{"NN"},
"pollinators":	{"NNS"},
"polling":	{"NN","VBG"},
"polling-booth":	{"NN"},
"polling-booths":	{"NNS"},
"polling-day":	{"NN"},
"polling-days":	{"NNS"},
"polling-station":	{"NN"},
"polling-stations":	{"NNS"},
"pollinium":	{"NN"},
"pollinosis":	{"NN"},
"polliwog":	{"NN"},
"polliwogs":	{"NNS"},
"polls":	{"NNS","VBZ"},
"pollster":	{"NN"},
"pollsters":	{"NNS"},
"pollucite":	{"NN"},
"pollutant":	{"NN"},
"pollutants":	{"NNS"},
"pollute":	{"VB","VBP"},
"polluted":	{"JJ","VBN","VBD"},
"polluter":	{"NN"},
"polluters":	{"NNS"},
"pollutes":	{"VBZ"},
"polluting":	{"VBG"},
"pollution":	{"NN"},
"pollution-causing":	{"JJ"},
"pollution-control":	{"JJ","NN"},
"pollution-free":	{"JJ"},
"pollution-reduction":	{"NN"},
"pollutional":	{"JJ"},
"pollyannaish":	{"JJ"},
"pollyfish":	{"NN"},
"pollywog":	{"NN"},
"pollywogs":	{"NNS"},
"polo":	{"NN"},
"polo-neck":	{"NN"},
"polo-necks":	{"NNS"},
"polonaise":	{"NN"},
"polonium":	{"NN"},
"polony":	{"NN"},
"pols":	{"NNS"},
"polska":	{"NN"},
"poltergeist":	{"NN"},
"poltergeists":	{"NNS"},
"poltically":	{"RB"},
"poltroon":	{"NN","JJ"},
"poltroonery":	{"NN"},
"poltroons":	{"NNS"},
"polyamide":	{"NN"},
"polyamorous":	{"JJ"},
"polyandrist":	{"NN"},
"polyandrous":	{"JJ"},
"polyandry":	{"NN"},
"polyangiaceae":	{"NN"},
"polyangium":	{"NN"},
"polyanthi":	{"NNS"},
"polyanthus":	{"NN"},
"polyanthuses":	{"NNS"},
"polyarteritis":	{"NN"},
"polyatomic":	{"JJ"},
"polyborus":	{"NN"},
"polybotria":	{"NN"},
"polybotrya":	{"NN"},
"polybrominated":	{"JJ"},
"polybutene":	{"NN"},
"polybutenes":	{"NNS"},
"polybutylene":	{"NN"},
"polycarp":	{"NN"},
"polychaeta":	{"NN"},
"polychaete":	{"NN"},
"polychete":	{"NN"},
"polychromatic":	{"JJ"},
"polychrome":	{"NN","JJ"},
"polychromic":	{"JJ"},
"polychromise":	{"VB","VBP"},
"polychromize":	{"VB","VBP"},
"polychronic":	{"JJ"},
"polycillin":	{"NN"},
"polycirrus":	{"NN"},
"polycrystalline":	{"JJ"},
"polycythemia":	{"NN"},
"polydactyl":	{"JJ"},
"polydactylous":	{"JJ"},
"polydactylus":	{"NN"},
"polydactyly":	{"NN"},
"polydipsia":	{"NN"},
"polyelectrolyte":	{"NN"},
"polyelectrolytes":	{"NNS"},
"polyergus":	{"NN"},
"polyester":	{"NN"},
"polyesters":	{"NNS"},
"polyestrous":	{"JJ"},
"polyether":	{"NN"},
"polyether-type":	{"JJ"},
"polyethers":	{"NNS"},
"polyethylene":	{"NN"},
"polyfoam":	{"NN"},
"polygala":	{"NN"},
"polygalaceae":	{"NN"},
"polygamist":	{"NN"},
"polygamous":	{"JJ"},
"polygamy":	{"NN"},
"polygene":	{"NN"},
"polygenic":	{"JJ"},
"polyglot":	{"NN","JJ"},
"polyglots":	{"NNS"},
"polygon":	{"NN"},
"polygonaceae":	{"NN"},
"polygonal":	{"JJ"},
"polygonales":	{"NNS"},
"polygonally":	{"RB"},
"polygonatum":	{"NN"},
"polygonia":	{"NN"},
"polygons":	{"NNS"},
"polygonum":	{"NN"},
"polygraph":	{"NN"},
"polygraphs":	{"NNS"},
"polygynist":	{"NN"},
"polygynous":	{"JJ"},
"polygyny":	{"NN"},
"polyhedra":	{"NNS"},
"polyhedral":	{"JJ"},
"polyhedron":	{"NN"},
"polyhedrons":	{"NNS"},
"polyhidrosis":	{"NN"},
"polyhymnia":	{"NN"},
"polyisobutylene":	{"NN"},
"polyisocyanate":	{"NN"},
"polyisocyanates":	{"NNS"},
"polymastigina":	{"NN"},
"polymastigote":	{"NN"},
"polymath":	{"NN"},
"polymaths":	{"NNS"},
"polymer":	{"NN"},
"polymerase":	{"NN"},
"polymeric":	{"JJ"},
"polymerisation":	{"NN"},
"polymerisations":	{"NNS"},
"polymerise":	{"VB","VBP"},
"polymerised":	{"VBD","VBN"},
"polymerises":	{"VBZ"},
"polymerising":	{"VBG"},
"polymerization":	{"NN"},
"polymerizations":	{"NNS"},
"polymerize":	{"VB","VBP"},
"polymerized":	{"VBD","VBN"},
"polymerizes":	{"VBZ"},
"polymerizing":	{"VBG"},
"polymers":	{"NNS"},
"polymorph":	{"NN"},
"polymorphemic":	{"JJ"},
"polymorphic":	{"JJ"},
"polymorphism":	{"NN"},
"polymorphous":	{"JJ"},
"polymox":	{"NN"},
"polymyositis":	{"NN"},
"polymyxin":	{"NN"},
"polynemidae":	{"NN"},
"polyneuritis":	{"NN"},
"polynomial":	{"NN"},
"polynomials":	{"NNS"},
"polynya":	{"NN"},
"polyodon":	{"NN"},
"polyodontidae":	{"NN"},
"polyoestrous":	{"JJ"},
"polyoicous":	{"JJ"},
"polyol":	{"NN"},
"polyols":	{"NNS"},
"polyoma":	{"NN"},
"polyose":	{"NN"},
"polyp":	{"NN"},
"polypectomy":	{"NN"},
"polypedates":	{"NNS"},
"polypedatidae":	{"NN"},
"polypeptide":	{"NN"},
"polypetalous":	{"JJ"},
"polyphase":	{"JJ"},
"polyphone":	{"NN"},
"polyphonic":	{"JJ"},
"polyphonically":	{"RB"},
"polyphonous":	{"JJ"},
"polyphony":	{"NN"},
"polyphosphate":	{"NN"},
"polyphosphates":	{"NNS"},
"polyplacophora":	{"NN"},
"polyplacophore":	{"NN"},
"polyploid":	{"JJ","NN"},
"polyploidy":	{"NN"},
"polypodiaceae":	{"NN"},
"polypodiales":	{"NNS"},
"polypodium":	{"NN"},
"polypody":	{"NN"},
"polyporaceae":	{"NN"},
"polypore":	{"NN"},
"polyporus":	{"NN"},
"polyprion":	{"NN"},
"polypropene":	{"NN"},
"polypropenonitrile":	{"NN"},
"polyproplene":	{"NN"},
"polypropylene":	{"NN"},
"polyps":	{"NNS"},
"polyptoton":	{"NN"},
"polypus":	{"NN"},
"polyrhythms":	{"NNS"},
"polysaccharide":	{"NN"},
"polysemant":	{"NN"},
"polysemantic":	{"JJ"},
"polysemous":	{"JJ"},
"polysemy":	{"NN"},
"polysilicon":	{"NN"},
"polysiloxanes":	{"NNS"},
"polysomy":	{"NN"},
"polystichum":	{"NN"},
"polystyrene":	{"NN"},
"polysyllabic":	{"JJ"},
"polysyllabically":	{"RB"},
"polysyllable":	{"NN"},
"polysyndeton":	{"NN"},
"polysynthetic":	{"JJ"},
"polytechnic":	{"NN"},
"polytechnics":	{"NNS"},
"polytetrafluoroethylene":	{"NN"},
"polytheism":	{"NN"},
"polytheist":	{"NN"},
"polytheistic":	{"JJ"},
"polytheists":	{"NNS"},
"polythene":	{"NN"},
"polytonal":	{"JJ"},
"polytonalism":	{"NN"},
"polytonality":	{"NN"},
"polyunsaturate":	{"NN"},
"polyunsaturated":	{"JJ"},
"polyunsaturates":	{"NNS"},
"polyurethan":	{"NN"},
"polyurethane":	{"NN"},
"polyurethanes":	{"NNS"},
"polyuria":	{"NN"},
"polyvalence":	{"NN"},
"polyvalency":	{"NN"},
"polyvalent":	{"JJ"},
"polyvinyl":	{"NN"},
"polyvinyl-formaldehyde":	{"NN"},
"polyzoa":	{"NN"},
"polyzoan":	{"NN"},
"pom":	{"NN"},
"pom-pom":	{"NN"},
"pom-poms":	{"NNS"},
"pomacanthus":	{"NN"},
"pomacentridae":	{"NN"},
"pomacentrus":	{"NN"},
"pomade":	{"NN","VB","VBP"},
"pomaded":	{"VBD","VBN"},
"pomaderris":	{"NN"},
"pomades":	{"VBZ"},
"pomading":	{"VBG"},
"pomatomidae":	{"NN"},
"pomatomus":	{"NN"},
"pomatum":	{"NN"},
"pome":	{"NN"},
"pomegranate":	{"NN"},
"pomegranates":	{"NNS"},
"pomelo":	{"NN"},
"pomeranian":	{"NN"},
"pomfret":	{"NN"},
"pommel":	{"NN","VB","VBP"},
"pommeled":	{"VBD","VBN"},
"pommeling":	{"VBG"},
"pommelled":	{"VBD","VBN"},
"pommelling":	{"VBG"},
"pommels":	{"NNS","VBZ"},
"pommie":	{"NN"},
"pommies":	{"NNS"},
"pommy":	{"NN"},
"pomo":	{"JJ"},
"pomolobus":	{"NN"},
"pomological":	{"JJ"},
"pomologist":	{"NN"},
"pomology":	{"NN"},
"pomoxis":	{"NN"},
"pomp":	{"NN"},
"pomp-filled":	{"JJ"},
"pompadour":	{"NN","VB","VBP"},
"pompadoured":	{"VBD","VBN"},
"pompadouring":	{"VBG"},
"pompadours":	{"NNS","VBZ"},
"pompano":	{"NN"},
"pompon":	{"NN"},
"pompons":	{"NNS"},
"pomposity":	{"NN"},
"pompous":	{"JJ"},
"pompously":	{"RB"},
"pompousness":	{"NN"},
"poms":	{"NNS"},
"ponca":	{"NN"},
"ponce":	{"NN","VB","VBP"},
"ponced":	{"VBD","VBN"},
"ponces":	{"NNS","VBZ"},
"poncho":	{"NN"},
"ponchos":	{"NNS"},
"poncing":	{"VBG"},
"poncirus":	{"NN"},
"pond":	{"NN"},
"pond-skater":	{"NN"},
"ponder":	{"VB","VBP"},
"ponderability":	{"NN"},
"ponderable":	{"JJ","NN"},
"ponderables":	{"NNS"},
"ponderably":	{"RB"},
"pondered":	{"VBD","VBN"},
"ponderer":	{"NN"},
"pondering":	{"VBG"},
"ponderosa":	{"NN"},
"ponderosity":	{"NN"},
"ponderous":	{"JJ"},
"ponderously":	{"RB"},
"ponderousness":	{"NN"},
"ponders":	{"VBZ"},
"ponds":	{"NNS"},
"pondweed":	{"NN"},
"pone":	{"NN"},
"pong":	{"NN","VB","VBP"},
"pongamia":	{"NN"},
"ponged":	{"VBD","VBN"},
"pongee":	{"NN"},
"pongid":	{"NN"},
"pongidae":	{"NN"},
"ponging":	{"VBG"},
"pongo":	{"NN"},
"pongs":	{"NNS","VBZ"},
"poniard":	{"NN","VB","VBP"},
"poniarded":	{"VBD","VBN"},
"poniarding":	{"VBG"},
"poniards":	{"NNS","VBZ"},
"ponied":	{"VBD","VBN"},
"ponies":	{"NNS","VBZ"},
"ponka":	{"NN"},
"pons":	{"NN"},
"ponselle":	{"NN"},
"ponstel":	{"NN"},
"pont":	{"NN"},
"pontederia":	{"NN"},
"pontederiaceae":	{"NN"},
"pontifex":	{"NN"},
"pontiff":	{"NN"},
"pontiffs":	{"NNS"},
"pontifical":	{"JJ"},
"pontificate":	{"VBP","NN","VB"},
"pontificated":	{"VBD","VBN"},
"pontificates":	{"VBZ","NNS"},
"pontificating":	{"VBG"},
"pontoon":	{"NN"},
"pontoons":	{"NNS"},
"pontos":	{"NN"},
"pontus":	{"NN"},
"pony":	{"NN","VB","VBP"},
"pony-tail":	{"NN"},
"pony-tails":	{"NNS"},
"pony-trekking":	{"NN"},
"ponycart":	{"NN"},
"ponying":	{"VBG"},
"ponytail":	{"NN"},
"ponytails":	{"NNS"},
"poo":	{"NN","VB","VBP"},
"pooch":	{"NN"},
"pooches":	{"NNS"},
"pood":	{"NN"},
"poodle":	{"NN"},
"poodles":	{"NNS"},
"pooecetes":	{"NNS"},
"pooed":	{"VBD","VBN"},
"poof":	{"NN","UH"},
"poofs":	{"NNS"},
"poofter":	{"NN"},
"poofters":	{"NNS"},
"pooh":	{"UH"},
"pooh-bah":	{"NN"},
"pooh-bahs":	{"NNS"},
"pooh-like":	{"JJ"},
"pooh-pooh":	{"VB","VBP"},
"pooh-poohed":	{"VBD","VBN"},
"pooh-poohing":	{"VBG"},
"poohbah":	{"NN"},
"poohpoohs":	{"VBZ"},
"pooing":	{"VBG"},
"pool":	{"NN","VB","VBP"},
"pool-care":	{"JJ"},
"pool-equipment":	{"NN"},
"pool-equipped":	{"JJ"},
"pool-owners":	{"NNS"},
"pool-side":	{"JJ","NN"},
"pool-table":	{"NN"},
"poole":	{"NN"},
"pooled":	{"VBN","VBD"},
"pooler":	{"NN"},
"pooling":	{"VBG"},
"pooling-of-interest":	{"JJ"},
"pooling-of-interests":	{"JJ"},
"poolroom":	{"NN"},
"poolrooms":	{"NNS"},
"pools":	{"NNS","VBZ"},
"poolside":	{"JJ","NN"},
"poon":	{"NN"},
"poop":	{"NN","VB","VBP"},
"pooped":	{"VBD","VBN","JJ"},
"pooper":	{"NN"},
"poopers":	{"NNS"},
"pooping":	{"VBG"},
"poops":	{"VBZ"},
"poor":	{"JJ","NNS"},
"poor-box":	{"NN"},
"poor-boxes":	{"NNS"},
"poor-mouth":	{"JJ"},
"poor-spirited":	{"JJ"},
"poor-white-trash":	{"JJ"},
"poorer":	{"JJR"},
"poorest":	{"JJS"},
"poorhouse":	{"NN"},
"poorhouses":	{"NNS"},
"poorly":	{"JJ","RB"},
"poorness":	{"NN"},
"poorwill":	{"NN"},
"poos":	{"NNS","VBZ"},
"poove":	{"NN"},
"pooves":	{"NNS"},
"pop":	{"NN","VB","VBP","RB"},
"pop-fly":	{"NN"},
"pop-music":	{"NN"},
"pop-out":	{"JJ"},
"pop-up":	{"JJ","NN"},
"pop-ups":	{"NNS"},
"popcorn":	{"NN"},
"pope":	{"NN"},
"popery":	{"NN"},
"popes":	{"NNS"},
"popeyed":	{"JJ"},
"popgun":	{"NN"},
"popillia":	{"NN"},
"popinjay":	{"NN"},
"popish":	{"JJ"},
"popishly":	{"RB"},
"poplar":	{"NN"},
"poplars":	{"NNS"},
"poplin":	{"NN"},
"popliteal":	{"JJ"},
"popover":	{"NN"},
"popovers":	{"NNS"},
"popped":	{"VBD","VBN"},
"popper":	{"NN"},
"poppers":	{"NNS"},
"poppet":	{"NN"},
"poppets":	{"NNS"},
"poppies":	{"NNS"},
"popping":	{"VBG"},
"poppy":	{"NN"},
"poppycock":	{"NN"},
"poppyseed":	{"NN"},
"pops":	{"NNS","VBZ"},
"popsicle":	{"NN"},
"popsicles":	{"NNS"},
"populace":	{"NN"},
"popular":	{"JJ"},
"popular-priced":	{"JJ"},
"popularisation":	{"NN"},
"popularise":	{"VB","VBP"},
"popularised":	{"VBD","VBN"},
"populariser":	{"NN"},
"popularises":	{"VBZ"},
"popularising":	{"VBG"},
"popularism":	{"NN"},
"popularity":	{"NN"},
"popularization":	{"NN"},
"popularize":	{"VB","VBP"},
"popularized":	{"VBD","VBN"},
"popularizer":	{"NN"},
"popularizes":	{"VBZ"},
"popularizing":	{"VBG"},
"popularly":	{"RB"},
"populate":	{"VB","VBP"},
"populated":	{"VBD","VBN","JJ"},
"populates":	{"VBZ"},
"populating":	{"VBG"},
"population":	{"NN"},
"population-control":	{"JJ"},
"populations":	{"NNS"},
"populism":	{"NN"},
"populist":	{"NN","JJ"},
"populists":	{"NNS"},
"populous":	{"JJ"},
"populus":	{"NN"},
"popup":	{"NN"},
"popups":	{"NNS"},
"por":	{"FW"},
"porbeagle":	{"NN"},
"porc":	{"NN"},
"porcelain":	{"NN"},
"porcelainise":	{"VB","VBP"},
"porcelainised":	{"VBD","VBN"},
"porcelainises":	{"VBZ"},
"porcelainising":	{"VBG"},
"porcelainize":	{"VB","VBP"},
"porcelainized":	{"VBD","VBN"},
"porcelainizes":	{"VBZ"},
"porcelainizing":	{"VBG"},
"porcelains":	{"NNS"},
"porcellio":	{"NN"},
"porcellionidae":	{"NN"},
"porch":	{"NN"},
"porches":	{"NNS"},
"porcine":	{"JJ"},
"porcupine":	{"NN"},
"porcupinefish":	{"NN","NNS"},
"porcupines":	{"NNS"},
"pore":	{"NN","VB","VBP"},
"pored":	{"VBD","VBN"},
"pores":	{"NNS","VBZ"},
"porgy":	{"NN"},
"porifera":	{"NN"},
"poriferan":	{"NN"},
"poriferous":	{"JJ"},
"poring":	{"VBG"},
"pork":	{"NN"},
"pork-barrel":	{"JJ","NN"},
"pork-barrelers":	{"NNS"},
"pork-barreling":	{"NN"},
"pork-fish":	{"NN"},
"porkchop":	{"NN"},
"porker":	{"NN"},
"porkers":	{"NNS"},
"porkfish":	{"NN"},
"porkholt":	{"NN"},
"porkpie":	{"NN"},
"porn":	{"NN"},
"porno":	{"JJ"},
"porno-inspired":	{"JJ"},
"pornographer":	{"NN"},
"pornographers":	{"NNS"},
"pornographic":	{"JJ"},
"pornographically":	{"RB"},
"pornography":	{"NN"},
"poronotus":	{"NN"},
"poroporo":	{"NN"},
"porose":	{"JJ"},
"porosity":	{"NN"},
"porous":	{"JJ"},
"porousness":	{"NN"},
"porphyra":	{"NN"},
"porphyria":	{"NN"},
"porphyrin":	{"NN"},
"porphyrio":	{"NN"},
"porphyritic":	{"JJ"},
"porphyrula":	{"NN"},
"porphyry":	{"NN"},
"porpoise":	{"NN"},
"porpoises":	{"NNS"},
"porque":	{"FW"},
"porridge":	{"NN"},
"porringer":	{"NN"},
"port":	{"NN","VB","VBP"},
"port-of-call":	{"NN"},
"port-of-spain":	{"NN"},
"port-shopping":	{"NN"},
"port-side":	{"JJ"},
"porta":	{"NN"},
"portability":	{"NN"},
"portable":	{"JJ","NN"},
"portables":	{"NNS"},
"portage":	{"NN","VB","VBP"},
"portaged":	{"VBD","VBN"},
"portages":	{"NNS","VBZ"},
"portaging":	{"VBG"},
"portal":	{"NN"},
"portals":	{"NNS"},
"portant":	{"FW"},
"portcullis":	{"NN"},
"portcullises":	{"NNS"},
"porte":	{"NN"},
"porte-cochere":	{"NN"},
"ported":	{"VBD","VBN"},
"portend":	{"VB","VBP"},
"portended":	{"VBD","VBN"},
"portending":	{"VBG"},
"portends":	{"VBZ"},
"portent":	{"NN"},
"portentous":	{"JJ"},
"portentously":	{"RB"},
"portents":	{"NNS"},
"porter":	{"NN"},
"porterage":	{"NN"},
"porterhouse":	{"NN"},
"porterhouses":	{"NNS"},
"portering":	{"NN"},
"porters":	{"NNS"},
"portfolio":	{"NN"},
"portfolio-maker":	{"NN"},
"portfolios":	{"NNS"},
"porthole":	{"NN"},
"portholes":	{"NNS"},
"portico":	{"NN"},
"porticoed":	{"JJ"},
"porticoes":	{"NNS"},
"porticos":	{"NNS"},
"portiere":	{"NN"},
"porting":	{"VBG","NN"},
"portion":	{"NN","VB","VBP"},
"portioned":	{"VBD","VBN"},
"portioning":	{"VBG"},
"portions":	{"NNS","VBZ"},
"portlier":	{"JJR"},
"portliest":	{"JJS"},
"portliness":	{"NN"},
"portly":	{"JJ"},
"portmanteau":	{"NN"},
"portmanteaus":	{"NNS"},
"portmanteaux":	{"NNS"},
"porto":	{"NN"},
"portobello":	{"NN"},
"portobellos":	{"NNS"},
"portrait":	{"NN","JJ"},
"portraitist":	{"NN"},
"portraitists":	{"NNS"},
"portraits":	{"NNS"},
"portraiture":	{"NN"},
"portray":	{"VB","VBP"},
"portrayal":	{"NN"},
"portrayals":	{"NNS"},
"portrayed":	{"VBN","VBD"},
"portrayer":	{"NN"},
"portraying":	{"VBG"},
"portrays":	{"VBZ","NNS"},
"ports":	{"NNS","VBZ"},
"portulaca":	{"NN"},
"portulacaceae":	{"NN"},
"portunidae":	{"NN"},
"portunus":	{"NN"},
"portwatcher":	{"NN"},
"portwatchers":	{"NNS"},
"porzana":	{"NN"},
"pose":	{"VB","VBP","NN"},
"posed":	{"VBD","VBN"},
"poser":	{"NN"},
"posers":	{"NNS"},
"poses":	{"VBZ","NNS"},
"poseur":	{"NN"},
"poseurs":	{"NNS"},
"poseuse":	{"NN"},
"posh":	{"JJ","RB"},
"posher":	{"JJR"},
"poshest":	{"JJS"},
"posies":	{"NNS"},
"posing":	{"VBG"},
"posit":	{"VB","VBP"},
"posited":	{"VBD","VBN"},
"positing":	{"VBG"},
"position":	{"NN","VB","VBP"},
"position-building":	{"NN"},
"position-squaring":	{"NN"},
"positionable":	{"JJ"},
"positional":	{"JJ"},
"positioned":	{"VBD","VBN"},
"positioner":	{"NN"},
"positioning":	{"VBG","NN"},
"positions":	{"NNS","VBZ"},
"positionsthat":	{"NN"},
"positive":	{"JJ","NN"},
"positively":	{"RB"},
"positiveness":	{"NN"},
"positives":	{"NNS"},
"positivism":	{"NN"},
"positivist":	{"NN","JJ"},
"positivistic":	{"JJ"},
"positivists":	{"NNS"},
"positivity":	{"NN"},
"positron":	{"NN"},
"positrons":	{"NNS"},
"posits":	{"VBZ"},
"posology":	{"NN"},
"posse":	{"NN"},
"posseman":	{"NN"},
"possemen":	{"NNS"},
"posses":	{"NNS"},
"possess":	{"VB","VBP"},
"possessed":	{"JJ","VBD","VBN"},
"possesses":	{"VBZ"},
"possessing":	{"VBG"},
"possession":	{"NN"},
"possessions":	{"NNS"},
"possessive":	{"JJ","NN"},
"possessively":	{"RB"},
"possessiveness":	{"NN"},
"possessives":	{"NNS"},
"possessor":	{"NN"},
"possessors":	{"NNS"},
"posset":	{"NN"},
"possibilities":	{"NNS"},
"possibility":	{"NN"},
"possible":	{"JJ","NN"},
"possibleness":	{"NN"},
"possibles":	{"NNS"},
"possibly":	{"RB"},
"possum":	{"NN"},
"possum-hunting":	{"NN"},
"possums":	{"NNS"},
"possumwood":	{"NN"},
"post":	{"NN","VB","VBP"},
"post-Inaugural":	{"JJ"},
"post-Romantic":	{"JJ"},
"post-attack":	{"JJ"},
"post-bag":	{"NN"},
"post-bags":	{"NNS"},
"post-bankruptcy":	{"JJ"},
"post-census":	{"NN"},
"post-chemotherapy":	{"JJ"},
"post-colonial":	{"JJ"},
"post-colonialism":	{"NN"},
"post-communist":	{"JJ"},
"post-conviction":	{"JJ"},
"post-crash":	{"JJ"},
"post-earthquake":	{"JJ"},
"post-free":	{"JJ","RB"},
"post-game":	{"JJ"},
"post-haste":	{"RB"},
"post-hearing":	{"JJ"},
"post-horse":	{"NN"},
"post-hurricane":	{"JJ"},
"post-impressionist":	{"NN"},
"post-inaugural":	{"JJ"},
"post-independence":	{"JJ"},
"post-maturity":	{"NN"},
"post-merger":	{"JJ"},
"post-midnight":	{"JJ"},
"post-minimalist":	{"JJ"},
"post-modern":	{"JJ"},
"post-modernism":	{"NN"},
"post-modernist":	{"NN","JJ"},
"post-modernists":	{"NNS"},
"post-mortal":	{"JJ"},
"post-mortem":	{"JJ","NN"},
"post-mortems":	{"NNS"},
"post-nuptial":	{"JJ"},
"post-operative":	{"JJ"},
"post-paid":	{"RB"},
"post-production":	{"NN"},
"post-quake":	{"JJ"},
"post-reapportionment":	{"JJ"},
"post-retirement":	{"JJ"},
"post-sale":	{"JJ"},
"post-season":	{"NN"},
"post-secondary":	{"JJ"},
"post-split":	{"JJ"},
"post-surgery":	{"JJ"},
"post-surgical":	{"JJ"},
"post-town":	{"NN"},
"post-tragedy":	{"RB"},
"post-traumatic":	{"JJ"},
"post-trial":	{"JJ"},
"post-war":	{"JJ","RB"},
"postage":	{"NN"},
"postage-prepaid":	{"JJ"},
"postage-stamp":	{"NN"},
"postal":	{"JJ"},
"postal-business":	{"JJ"},
"postapocalyptic":	{"JJ"},
"postbag":	{"NN"},
"postbags":	{"NNS"},
"postbiblical":	{"JJ"},
"postbox":	{"NN"},
"postboxes":	{"NNS"},
"postcard":	{"NN"},
"postcards":	{"NNS"},
"postcava":	{"NN"},
"postcode":	{"NN"},
"postcodes":	{"NNS"},
"postcoital":	{"JJ"},
"postcolonial":	{"JJ"},
"postdate":	{"VB","VBP"},
"postdated":	{"VBD","VBN"},
"postdates":	{"VBZ"},
"postdating":	{"VBG"},
"postdiluvian":	{"JJ","NN"},
"postdivorce":	{"JJ"},
"postdoc":	{"JJ","NN"},
"postdoctoral":	{"JJ"},
"posted":	{"VBN","VBD","JJ"},
"postelection":	{"JJ"},
"poster":	{"NN"},
"poster-sized":	{"JJ"},
"posterior":	{"NN","JJ"},
"posteriority":	{"NN"},
"posteriors":	{"NNS"},
"posterity":	{"NN"},
"postern":	{"NN","JJ"},
"posters":	{"NNS"},
"postexilic":	{"JJ"},
"postfix":	{"NN"},
"postgame":	{"JJ"},
"postganglionic":	{"JJ"},
"postglacial":	{"JJ"},
"postgraduate":	{"NN","JJ"},
"postgraduates":	{"NNS"},
"posthitis":	{"NN"},
"posthole":	{"NN"},
"posthouse":	{"NN"},
"posthumous":	{"JJ"},
"posthumously":	{"RB"},
"postiche":	{"NN","JJ"},
"postictal":	{"JJ"},
"postilion":	{"NN"},
"postillion":	{"NN"},
"postimpressionism":	{"NN"},
"postimpressionist":	{"JJ","NN"},
"postimpressionistic":	{"JJ"},
"postimpressionists":	{"NNS"},
"postindustrial":	{"JJ"},
"posting":	{"VBG","NN"},
"postings":	{"NNS"},
"postition":	{"NN"},
"postlude":	{"NN"},
"postman":	{"NN"},
"postmark":	{"NN","VB","VBP"},
"postmarked":	{"VBD","VBN","JJ"},
"postmarking":	{"VBG"},
"postmarks":	{"NNS","VBZ"},
"postmaster":	{"NN"},
"postmasters":	{"NNS"},
"postmen":	{"NNS"},
"postmenopausal":	{"JJ","NN"},
"postmenopausally":	{"RB"},
"postmenopause":	{"NN"},
"postmeridian":	{"JJ"},
"postmillennial":	{"JJ"},
"postmistress":	{"NN"},
"postmistresses":	{"NNS"},
"postmodern":	{"JJ"},
"postmodernism":	{"NN"},
"postmodernist":	{"NN","JJ"},
"postmodernists":	{"NNS"},
"postmortal":	{"JJ"},
"postmortem":	{"JJ","NN"},
"postmortems":	{"NNS"},
"postnatal":	{"JJ"},
"postnuptial":	{"JJ"},
"postoperative":	{"JJ"},
"postoperatively":	{"RB"},
"postpaid":	{"JJ"},
"postpartum":	{"JJ"},
"postponable":	{"JJ"},
"postpone":	{"VB","VBP"},
"postponed":	{"VBN","VBD"},
"postponement":	{"NN"},
"postponements":	{"NNS"},
"postponer":	{"NN"},
"postpones":	{"VBZ"},
"postponing":	{"VBG"},
"postpose":	{"VB","VBP"},
"postposed":	{"VBD","VBN"},
"postposes":	{"VBZ"},
"postposing":	{"VBG"},
"postposition":	{"NN"},
"postpositive":	{"JJ"},
"postprandial":	{"JJ"},
"postprimary":	{"JJ"},
"postprison":	{"JJ"},
"postpunk":	{"JJ","NN"},
"postride":	{"JJ"},
"postromantic":	{"JJ"},
"posts":	{"NNS","VBZ"},
"postscript":	{"NN"},
"postscripts":	{"NNS"},
"postseason":	{"NN","JJ"},
"postulant":	{"NN"},
"postulate":	{"VB","VBP","NN"},
"postulated":	{"VBD","VBN"},
"postulates":	{"VBZ","NNS"},
"postulating":	{"VBG"},
"postulation":	{"NN"},
"postulational":	{"JJ"},
"postulations":	{"NNS"},
"postulator":	{"NN"},
"postulators":	{"NNS"},
"postum":	{"NN"},
"postural":	{"JJ"},
"posture":	{"NN","VB","VBP"},
"postured":	{"VBD","VBN"},
"posturer":	{"NN"},
"postures":	{"NNS","VBZ"},
"posturing":	{"NN","VBG"},
"posturings":	{"NNS"},
"postwar":	{"JJ","RB"},
"posy":	{"NN"},
"pot":	{"NN","VB","VBP"},
"pot-au-feu":	{"NN","FW"},
"pot-bellied":	{"JJ"},
"pot-belly":	{"NN"},
"pot-boiler":	{"NN"},
"pot-boilers":	{"NNS"},
"pot-bound":	{"JJ"},
"pot-herb":	{"NN"},
"pot-hole":	{"NN"},
"pot-holer":	{"NN"},
"pot-holers":	{"NNS"},
"pot-holes":	{"NNS"},
"pot-holing":	{"NN"},
"pot-hunter":	{"NN"},
"pot-hunters":	{"NNS"},
"pot-roast":	{"NN"},
"pot-roasts":	{"NNS"},
"pot-shot":	{"NN"},
"pot-shots":	{"NNS"},
"pot-trained":	{"JJ"},
"potability":	{"NN"},
"potable":	{"JJ","NN"},
"potables":	{"NNS"},
"potage":	{"NN"},
"potamogale":	{"NN"},
"potamogalidae":	{"NN"},
"potamogeton":	{"NN"},
"potamogetonaceae":	{"NN"},
"potamophis":	{"NN"},
"potash":	{"NN"},
"potassium":	{"NN"},
"potation":	{"NN"},
"potations":	{"NNS"},
"potato":	{"NN"},
"potato-like":	{"JJ"},
"potato-supplier":	{"NN"},
"potatoes":	{"NNS"},
"potawatomi":	{"NN"},
"potbellied":	{"JJ"},
"potbellies":	{"NNS"},
"potbelly":	{"NN"},
"potboiler":	{"NN"},
"potboilers":	{"NNS"},
"potbound":	{"JJ"},
"potboy":	{"NN"},
"poteen":	{"NN"},
"potemkin":	{"NN"},
"potence":	{"NN"},
"potency":	{"NN"},
"potent":	{"JJ"},
"potentate":	{"NN"},
"potentates":	{"NNS"},
"potential":	{"JJ","NN"},
"potentialities":	{"NNS"},
"potentiality":	{"NN"},
"potentially":	{"RB"},
"potentials":	{"NNS"},
"potentiate":	{"VB","VBP"},
"potentiated":	{"VBD","VBN"},
"potentiates":	{"VBZ"},
"potentiating":	{"VBG"},
"potentiation":	{"NN"},
"potentilla":	{"NN"},
"potentiometer":	{"NN"},
"potentiometers":	{"NNS"},
"potently":	{"RB"},
"poterium":	{"NN"},
"potful":	{"NN"},
"potfuls":	{"NNS"},
"pothead":	{"NN"},
"pother":	{"NN","VB","VBP"},
"potherb":	{"NN"},
"pothered":	{"VBD","VBN"},
"pothering":	{"VBG"},
"pothers":	{"NNS","VBZ"},
"potholder":	{"NN"},
"potholders":	{"NNS"},
"pothole":	{"NN"},
"potholed":	{"JJ"},
"potholer":	{"NN"},
"potholers":	{"NNS"},
"potholes":	{"NNS"},
"potholing":	{"NN"},
"pothook":	{"NN"},
"pothos":	{"NN"},
"pothouse":	{"NN"},
"pothunter":	{"NN"},
"potion":	{"NN"},
"potions":	{"NNS"},
"potlatch":	{"NN"},
"potluck":	{"NN"},
"potman":	{"NN"},
"potomania":	{"NN"},
"potoroinae":	{"NN"},
"potoroo":	{"NN"},
"potorous":	{"NN"},
"potos":	{"NN"},
"potpie":	{"NN"},
"potpourri":	{"NN"},
"potpourris":	{"NNS"},
"pots":	{"NNS","VBZ"},
"potsdam":	{"NN"},
"potsherd":	{"NN"},
"potshot":	{"NN"},
"pottage":	{"NN"},
"potted":	{"JJ","VBN","VBD"},
"potter":	{"NN","VB","VBP"},
"pottered":	{"VBD","VBN"},
"potterer":	{"NN"},
"potterers":	{"NNS"},
"potteries":	{"NNS"},
"pottering":	{"VBG"},
"potters":	{"NNS","VBZ"},
"pottery":	{"NN"},
"pottier":	{"JJR"},
"potties":	{"NNS"},
"pottiest":	{"JJS"},
"potting":	{"VBG"},
"potting-shed":	{"NN"},
"potting-sheds":	{"NNS"},
"pottle":	{"NN"},
"potto":	{"NN"},
"potty":	{"NN","JJ"},
"potty-train":	{"VB","VBP"},
"potty-trained":	{"VBD","VBN","JJ"},
"potty-training":	{"VBG","NN"},
"potty-trains":	{"VBZ"},
"potyokin":	{"NN"},
"pouch":	{"NN","VB","VBP"},
"pouch-shaped":	{"JJ"},
"pouched":	{"JJ","VBD","VBN"},
"pouches":	{"NNS","VBZ"},
"pouching":	{"VBG"},
"pouchlike":	{"JJ"},
"poudrin":	{"NN"},
"pouf":	{"NN"},
"pouffe":	{"NN"},
"pouffes":	{"NNS"},
"poufs":	{"NNS"},
"poulet":	{"NN"},
"poulette":	{"NN"},
"poulterer":	{"NN"},
"poulterers":	{"NNS"},
"poultice":	{"NN","VB","VBP"},
"poulticed":	{"VBD","VBN"},
"poultices":	{"NNS","VBZ"},
"poulticing":	{"VBG"},
"poultry":	{"NN","NNS"},
"poultry-loving":	{"JJ"},
"poultryman":	{"NN"},
"pounce":	{"VB","VBP","NN"},
"pounced":	{"VBD","VBN"},
"pounces":	{"VBZ"},
"pouncing":	{"VBG"},
"pound":	{"NN","VB","VBP"},
"pound-DM":	{"JJ"},
"pound-deutsche":	{"JJ"},
"pound-dm":	{"JJ"},
"pound-foolish":	{"JJ"},
"pound-of-flesh":	{"JJ"},
"poundage":	{"NN"},
"poundal":	{"NN"},
"pounded":	{"VBD","VBN"},
"pounder":	{"NN"},
"pounding":	{"NN","VBG"},
"pounds":	{"NNS","VBZ"},
"pour":	{"VB","VBP"},
"pourboire":	{"NN"},
"poured":	{"VBD","VBN"},
"pouring":	{"VBG","JJ"},
"pours":	{"VBZ","NNS"},
"pousse-cafe":	{"NN"},
"pout":	{"VB","VBP","NN"},
"pouted":	{"VBD","VBN"},
"pouter":	{"NN"},
"pouteria":	{"NN"},
"pouters":	{"NNS"},
"pouting":	{"VBG","JJ"},
"poutingly":	{"RB"},
"pouts":	{"VBZ","NNS"},
"pouty":	{"JJ"},
"pouty-looking":	{"JJ"},
"poverty":	{"NN"},
"poverty-stricken":	{"JJ"},
"pow":	{"UH"},
"powder":	{"NN","VB","VBP"},
"powder-blue":	{"NN","JJ"},
"powder-blues":	{"NNS"},
"powder-keg":	{"NN"},
"powder-kegs":	{"NNS"},
"powder-magazine":	{"NN"},
"powder-puff":	{"JJ"},
"powder-room":	{"NN"},
"powder-rooms":	{"NNS"},
"powdered":	{"JJ","VBD","VBN"},
"powderer":	{"NN"},
"powderiness":	{"NN"},
"powdering":	{"VBG"},
"powders":	{"VBZ","NNS"},
"powdery":	{"JJ"},
"powdery-blue":	{"JJ"},
"power":	{"NN","VBP","JJ","VB"},
"power-assisted":	{"JJ"},
"power-buying":	{"JJ"},
"power-company":	{"NN"},
"power-dive":	{"VB","VBP"},
"power-dived":	{"VBD","VBN"},
"power-dives":	{"VBZ"},
"power-diving":	{"VBG"},
"power-driven":	{"JJ"},
"power-generation":	{"NN","JJ"},
"power-grid":	{"NN"},
"power-hitter":	{"NN"},
"power-hungry":	{"JJ"},
"power-play":	{"JJ","NN"},
"power-plays":	{"NNS"},
"power-seek":	{"NN"},
"power-sharing":	{"NN"},
"power-starved":	{"JJ"},
"power-steering":	{"NN"},
"power-surge":	{"NN"},
"power-switching":	{"JJ"},
"power-tool":	{"JJ","NN"},
"power-train":	{"NN"},
"power-transmission":	{"JJ"},
"powerboat":	{"NN"},
"powerboats":	{"NNS"},
"powerbroker":	{"NN"},
"powered":	{"JJ","VBD","VBN"},
"powerful":	{"JJ"},
"powerfully":	{"RB"},
"powerfulness":	{"NN"},
"powerhouse":	{"NN"},
"powerhouses":	{"NNS"},
"powering":	{"VBG"},
"powerless":	{"JJ"},
"powerlessly":	{"RB"},
"powerlessness":	{"NN"},
"powerpoint":	{"NN"},
"powers":	{"NNS","VBZ"},
"powertrain":	{"NN"},
"powerwash":	{"VB"},
"powhatan":	{"NN"},
"powpow":	{"NN"},
"powwow":	{"NN","VB","VBP"},
"powwowed":	{"VBD","VBN"},
"powwowing":	{"VBG"},
"powwows":	{"NNS","VBZ"},
"pox":	{"NN"},
"poxvirus":	{"NN"},
"poyou":	{"NN"},
"pp.":	{"NNS"},
"ppg":	{"NN","RB","JJ"},
"ppk":	{"NN"},
"pplo":	{"NN"},
"ppp":	{"NN"},
"pq":	{"NN"},
"pr":	{"NN"},
"pr-wise":	{"JJ"},
"practicability":	{"NN"},
"practicable":	{"JJ"},
"practicableness":	{"NN"},
"practicably":	{"RB"},
"practical":	{"JJ","NN"},
"practicalities":	{"NNS"},
"practicality":	{"NN"},
"practically":	{"RB"},
"practicals":	{"NNS"},
"practice":	{"NN","VB","VBP"},
"practiced":	{"VBD","VBN","JJ"},
"practices":	{"NNS","VBZ"},
"practician":	{"NN"},
"practicing":	{"VBG","JJ"},
"practise":	{"VBP","VB"},
"practised":	{"VBD","VBN","JJ"},
"practises":	{"VBZ"},
"practising":	{"VBG","JJ"},
"practitioner":	{"NN"},
"practitioners":	{"NNS"},
"praenomen":	{"NN"},
"praesidia":	{"NNS"},
"praesidium":	{"NN"},
"praetor":	{"NN"},
"praetoria":	{"NNS"},
"praetorial":	{"JJ"},
"praetorian":	{"JJ","NN"},
"praetorium":	{"NN"},
"praetorship":	{"NN"},
"prag":	{"NN"},
"pragmatic":	{"JJ"},
"pragmatical":	{"JJ"},
"pragmatically":	{"RB"},
"pragmatics":	{"NN"},
"pragmatism":	{"NN"},
"pragmatist":	{"NN"},
"pragmatists":	{"NNS"},
"praha":	{"NN"},
"prai":	{"VBP","VB"},
"praia":	{"NN"},
"prairial":	{"NN"},
"prairie":	{"NN"},
"prairie-dog":	{"NN"},
"prairie-dogs":	{"NNS"},
"prairies":	{"NNS"},
"praisable":	{"JJ"},
"praisableness":	{"NN"},
"praisablenesses":	{"NNS"},
"praisably":	{"RB"},
"praise":	{"VB","VBP","NN"},
"praised":	{"VBD","VBN"},
"praiseful":	{"JJ"},
"praises":	{"VBZ","NNS"},
"praiseworthily":	{"RB"},
"praiseworthiness":	{"NN"},
"praiseworthy":	{"JJ"},
"praising":	{"VBG","NN"},
"prajapati":	{"NN"},
"prakrit":	{"NN"},
"prakritic":	{"JJ"},
"praline":	{"NN"},
"pralines":	{"NNS"},
"pram":	{"NN"},
"prams":	{"NNS"},
"prance":	{"VB","VBP","NN"},
"pranced":	{"VBD","VBN"},
"prancer":	{"NN"},
"prances":	{"VBZ"},
"prancing":	{"VBG"},
"prandial":	{"JJ"},
"prang":	{"VB","VBP","NN"},
"pranged":	{"VBD","VBN"},
"pranging":	{"VBG"},
"prangs":	{"VBZ","NNS"},
"pranha":	{"NN"},
"prank":	{"NN","VB","VBP"},
"pranked":	{"VBD","VBN"},
"pranking":	{"VBG"},
"prankish":	{"JJ"},
"prankishness":	{"NN"},
"pranks":	{"NNS","VBZ"},
"prankster":	{"NN"},
"pranksters":	{"NNS"},
"praseodymium":	{"NN"},
"prat":	{"NN"},
"pratakku":	{"FW"},
"prate":	{"VB","VBP"},
"prated":	{"VBD","VBN"},
"prater":	{"NN"},
"prates":	{"VBZ"},
"pratfall":	{"NN"},
"pratfalls":	{"NNS"},
"pratincole":	{"NN"},
"prating":	{"VBG"},
"prats":	{"NNS"},
"pratt":	{"NN"},
"prattle":	{"VB","VBP","NN"},
"prattled":	{"VBD","VBN"},
"prattler":	{"NN"},
"prattlers":	{"NNS"},
"prattles":	{"VBZ"},
"prattling":	{"VBG"},
"praunus":	{"NN"},
"pravachol":	{"NN"},
"pravastatin":	{"NN"},
"prawn":	{"NN","VB","VBP"},
"prawned":	{"VBD","VBN"},
"prawning":	{"VBG"},
"prawns":	{"NNS","VBZ"},
"praxes":	{"NNS"},
"praxis":	{"NN"},
"praxises":	{"NNS"},
"pray":	{"VB","VBP","RB"},
"pray-for-growth-later":	{"JJ"},
"praya":	{"NN"},
"prayed":	{"VBD","VBN"},
"prayer":	{"NN"},
"prayer-book":	{"NN"},
"prayer-books":	{"NNS"},
"prayer-mat":	{"NN"},
"prayer-mats":	{"NNS"},
"prayer-meeting":	{"NN"},
"prayer-meetings":	{"NNS"},
"prayer-requests":	{"NNS"},
"prayer-rug":	{"NN"},
"prayer-rugs":	{"NNS"},
"prayer-time":	{"NN"},
"prayer-wheel":	{"NN"},
"prayer-wheels":	{"NNS"},
"prayerful":	{"JJ"},
"prayerfully":	{"RB"},
"prayers":	{"NNS"},
"prayin":	{"NN"},
"praying":	{"VBG","NN"},
"prays":	{"VBZ"},
"prazosin":	{"NN"},
"prc":	{"NN"},
"pre-Reagan":	{"JJ"},
"pre-Roman":	{"JJ"},
"pre-Socratic":	{"JJ","NN"},
"pre-Socratics":	{"NNS"},
"pre-arrange":	{"VB","VBP"},
"pre-arranged":	{"VBD","VBN","JJ"},
"pre-arrangement":	{"NN"},
"pre-arranges":	{"VBZ"},
"pre-arranging":	{"VBG"},
"pre-cast":	{"JJ"},
"pre-condition":	{"NN"},
"pre-conditions":	{"NNS"},
"pre-cooked":	{"JJ"},
"pre-crash":	{"JJ"},
"pre-cut":	{"JJ","NN","VB","VBP","VBD","VBN"},
"pre-cuts":	{"VBZ","NNS"},
"pre-cutting":	{"VBG"},
"pre-eminence":	{"NN"},
"pre-eminent":	{"JJ"},
"pre-eminently":	{"RB"},
"pre-employment":	{"JJ"},
"pre-empt":	{"VB","VBP"},
"pre-empted":	{"VBN","VBD"},
"pre-empting":	{"VBG"},
"pre-emption":	{"NN"},
"pre-emptive":	{"JJ"},
"pre-emptor":	{"NN"},
"pre-empts":	{"VBZ"},
"pre-enrollment":	{"JJ"},
"pre-establish":	{"VB","VBP"},
"pre-established":	{"VBD","VBN"},
"pre-establishes":	{"VBZ"},
"pre-establishing":	{"VBG"},
"pre-existent":	{"JJ"},
"pre-existing":	{"JJ"},
"pre-industrial":	{"JJ"},
"pre-launch":	{"JJ"},
"pre-law":	{"NN"},
"pre-loved":	{"JJ"},
"pre-med":	{"JJ","NN"},
"pre-natal":	{"JJ"},
"pre-owned":	{"JJ"},
"pre-packed":	{"JJ"},
"pre-pay":	{"JJ"},
"pre-prandial":	{"JJ"},
"pre-qualification":	{"NN"},
"pre-qualifications":	{"NNS"},
"pre-qualified":	{"VBD","VBN","JJ"},
"pre-qualifies":	{"VBZ"},
"pre-qualify":	{"VB","VBP"},
"pre-qualifying":	{"VBG"},
"pre-record":	{"VB","VBP"},
"pre-recorded":	{"VBD","VBN","JJ"},
"pre-recording":	{"VBG","NN"},
"pre-recordings":	{"NNS"},
"pre-records":	{"VBZ"},
"pre-sale":	{"NN"},
"pre-sales":	{"NNS"},
"pre-school":	{"JJ","NN"},
"pre-schools":	{"NNS"},
"pre-selected":	{"VBN","JJ"},
"pre-sell":	{"VB","VBP"},
"pre-selling":	{"VBG"},
"pre-sells":	{"VBZ"},
"pre-seminal":	{"JJ"},
"pre-set":	{"VB","VBP","VBD","VBN","JJ"},
"pre-sets":	{"VBZ"},
"pre-setting":	{"VBG"},
"pre-soak":	{"VB","VBP"},
"pre-soaked":	{"VBD","VBN"},
"pre-soaking":	{"VBG"},
"pre-soaks":	{"VBZ"},
"pre-sold":	{"VBD","VBN"},
"pre-strike":	{"JJ"},
"pre-suspension":	{"JJ"},
"pre-swing":	{"NN"},
"pre-tax":	{"JJ","RB"},
"pre-teen":	{"NN"},
"pre-teens":	{"NNS"},
"pre-trial":	{"JJ"},
"pre-war":	{"JJ"},
"preach":	{"VB","VBP"},
"preached":	{"VBD","VBN"},
"preacher":	{"NN"},
"preacher-singer":	{"NN"},
"preachers":	{"NNS"},
"preaches":	{"VBZ"},
"preachification":	{"NN"},
"preachified":	{"VBD","VBN"},
"preachifies":	{"VBZ"},
"preachify":	{"VB","VBP"},
"preachifying":	{"VBG","NN"},
"preachiness":	{"NN"},
"preaching":	{"VBG"},
"preachment":	{"NN"},
"preachy":	{"JJ"},
"preadmission":	{"NN"},
"preadolescent":	{"JJ"},
"preamble":	{"NN"},
"preambles":	{"NNS"},
"preanal":	{"JJ"},
"preannounce":	{"VB","VBP"},
"preannounced":	{"VBD","VBN"},
"preannounces":	{"VBZ"},
"preannouncing":	{"VBG"},
"preapprove":	{"VB","VBP"},
"preapproved":	{"VBD","VBN"},
"preapproves":	{"VBZ"},
"preapproving":	{"VBG"},
"prearrange":	{"VB","VBP"},
"prearranged":	{"VBD","VBN","JJ"},
"prearrangement":	{"NN"},
"prearranges":	{"VBZ"},
"prearranging":	{"VBG"},
"preassembled":	{"JJ"},
"prebend":	{"NN"},
"prebendary":	{"NN"},
"precancerous":	{"JJ"},
"precarious":	{"JJ"},
"precariously":	{"RB"},
"precariousness":	{"NN"},
"precarity":	{"NN"},
"precast":	{"JJ","VB","VBP","VBD","VBN"},
"precasting":	{"VBG"},
"precasts":	{"VBZ"},
"precative":	{"JJ"},
"precatory":	{"JJ"},
"precaution":	{"NN"},
"precautional":	{"JJ"},
"precautionary":	{"JJ"},
"precautions":	{"NNS"},
"precava":	{"NN"},
"precede":	{"VB","VBP"},
"preceded":	{"VBD","VBN"},
"precedence":	{"NN"},
"precedency":	{"NN"},
"precedent":	{"NN","JJ"},
"precedent-based":	{"JJ"},
"precedent-setting":	{"JJ"},
"precedented":	{"JJ"},
"precedentedly":	{"RB"},
"precedential":	{"JJ"},
"precedents":	{"NNS"},
"precedes":	{"VBZ","NNS"},
"preceding":	{"JJ","VBG"},
"precentor":	{"NN"},
"precentors":	{"NNS"},
"precentorship":	{"NN"},
"precept":	{"NN"},
"preceptor":	{"NN"},
"preceptors":	{"NNS"},
"preceptorship":	{"NN"},
"precepts":	{"NNS"},
"precess":	{"VB","VBP"},
"precessed":	{"VBD","VBN"},
"precesses":	{"VBZ"},
"precessing":	{"VBG"},
"precession":	{"NN"},
"prechlorination":	{"NN"},
"precinct":	{"NN"},
"precincts":	{"NNS"},
"preciosities":	{"NNS"},
"preciosity":	{"NN"},
"precious":	{"JJ","RB","NN"},
"precious-metal":	{"NN"},
"precious-metals":	{"NNS"},
"preciously":	{"RB"},
"preciousness":	{"NN"},
"precipice":	{"NN"},
"precipices":	{"NNS"},
"precipitance":	{"NN"},
"precipitancy":	{"NN"},
"precipitant":	{"NN","JJ"},
"precipitate":	{"VB","VBP","JJ","NN"},
"precipitated":	{"VBD","VBN"},
"precipitately":	{"RB"},
"precipitateness":	{"NN"},
"precipitates":	{"VBZ","NNS"},
"precipitating":	{"VBG"},
"precipitation":	{"NN"},
"precipitations":	{"NNS"},
"precipitator":	{"NN"},
"precipitin":	{"NN"},
"precipitous":	{"JJ"},
"precipitously":	{"RB"},
"precipitousness":	{"NN"},
"precis":	{"NN","NNS","VB","VBP"},
"precise":	{"JJ"},
"precised":	{"VBD","VBN"},
"precisely":	{"RB"},
"preciseness":	{"NN"},
"precises":	{"VBZ"},
"precising":	{"VBG"},
"precision":	{"NN","JJ"},
"precision-materials":	{"NNS"},
"precision-timing":	{"NN"},
"preclearance":	{"NN"},
"preclinical":	{"JJ"},
"preclude":	{"VB","VBP"},
"precluded":	{"VBD","VBN"},
"precludes":	{"VBZ"},
"precluding":	{"VBG"},
"preclusion":	{"NN"},
"preclusive":	{"JJ"},
"precocial":	{"JJ"},
"precocious":	{"JJ"},
"precociously":	{"RB"},
"precociousness":	{"NN"},
"precocity":	{"NN"},
"precognition":	{"NN"},
"precognitive":	{"JJ"},
"precompetitive":	{"JJ"},
"preconceive":	{"VB","VBP"},
"preconceived":	{"VBD","VBN","JJ"},
"preconceives":	{"VBZ"},
"preconceiving":	{"VBG"},
"preconception":	{"NN"},
"preconceptions":	{"NNS"},
"preconcert":	{"JJ","NN","VB","VBP"},
"preconcerted":	{"JJ","VBD","VBN"},
"preconcerting":	{"VBG"},
"preconcerts":	{"NNS","VBZ"},
"precondition":	{"NN","VB","VBP"},
"preconditioned":	{"NN","VBD","VBN"},
"preconditioning":	{"VBG"},
"preconditions":	{"NNS","VBZ"},
"preconference":	{"JJ"},
"preconscious":	{"JJ"},
"precook":	{"VB","VBP"},
"precooked":	{"VBD","VBN","JJ"},
"precooking":	{"VBG"},
"precooks":	{"VBZ"},
"precool":	{"VB","VBP"},
"precooled":	{"VBD","VBN"},
"precooling":	{"VBG","NN"},
"precools":	{"VBZ"},
"precordial":	{"JJ"},
"precordium":	{"NN"},
"precrash":	{"JJ"},
"precursor":	{"NN"},
"precursors":	{"NNS"},
"precursory":	{"JJ"},
"precut":	{"JJ","NN","VB","VBP","VBD","VBN"},
"precuting":	{"VBG"},
"precuts":	{"VBZ","NNS"},
"predaceous":	{"JJ"},
"predacious":	{"JJ"},
"predate":	{"VB","VBP"},
"predated":	{"VBD","VBN"},
"predates":	{"VBZ"},
"predating":	{"VBG"},
"predation":	{"NN"},
"predator":	{"NN"},
"predators":	{"NNS"},
"predatory":	{"JJ"},
"predawn":	{"NN","JJ","RB"},
"predecease":	{"VB","VBP","NN"},
"predeceased":	{"VBD","VBN"},
"predeceases":	{"VBZ"},
"predeceasing":	{"VBG"},
"predecessor":	{"NN"},
"predecessors":	{"NNS"},
"predeparture":	{"JJ"},
"predestinarian":	{"JJ","NN"},
"predestinarianism":	{"NN"},
"predestinarians":	{"NNS"},
"predestinate":	{"VB","VBP"},
"predestinated":	{"VBD","VBN"},
"predestinates":	{"VBZ"},
"predestinating":	{"VBG"},
"predestination":	{"NN"},
"predestinationist":	{"NN"},
"predestine":	{"VB","VBP"},
"predestined":	{"VBD","VBN","JJ"},
"predestines":	{"VBZ"},
"predestining":	{"VBG"},
"predetermination":	{"NN"},
"predetermine":	{"VB","VBP"},
"predetermined":	{"VBD","VBN","JJ"},
"predetermines":	{"VBZ"},
"predetermining":	{"VBG"},
"predicament":	{"NN"},
"predicaments":	{"NNS"},
"predicate":	{"NN","VB","VBP"},
"predicated":	{"VBD","VBN"},
"predicates":	{"NNS","VBZ"},
"predicating":	{"VBG"},
"predication":	{"NN"},
"predicative":	{"JJ"},
"predicatively":	{"RB"},
"predicator":	{"NN"},
"predict":	{"VB","VBP"},
"predictability":	{"NN"},
"predictable":	{"JJ"},
"predictably":	{"RB"},
"predicted":	{"VBD","VBN"},
"predicting":	{"VBG","NN"},
"predicting-machines":	{"NNS"},
"prediction":	{"NN"},
"predictions":	{"NNS"},
"predictive":	{"JJ"},
"predictor":	{"NN"},
"predictors":	{"NNS"},
"predicts":	{"VBZ"},
"predigest":	{"VB","VBP"},
"predigested":	{"VBD","VBN","JJ"},
"predigesting":	{"VBG"},
"predigests":	{"VBZ"},
"predilection":	{"NN"},
"predilections":	{"NNS"},
"predispose":	{"VB","VBP"},
"predisposed":	{"VBD","VBN","JJ"},
"predisposes":	{"VBZ"},
"predisposing":	{"VBG"},
"predisposition":	{"NN"},
"predispositions":	{"NNS"},
"prednisolone":	{"NN"},
"prednisone":	{"NN"},
"predominance":	{"NN"},
"predominant":	{"JJ"},
"predominantly":	{"RB"},
"predominate":	{"VB","VBP"},
"predominated":	{"VBD","VBN"},
"predominately":	{"RB"},
"predominates":	{"VBZ"},
"predominating":	{"VBG"},
"predomination":	{"NN"},
"preeclampsia":	{"NN"},
"preemie":	{"NN"},
"preemies":	{"NNS"},
"preeminence":	{"NN"},
"preeminent":	{"JJ"},
"preeminently":	{"RB"},
"preemployment":	{"NN"},
"preempt":	{"VB","VBP"},
"preempted":	{"VBD","VBN"},
"preempting":	{"VBG"},
"preemption":	{"NN"},
"preemptive":	{"JJ"},
"preemptor":	{"NN"},
"preemptors":	{"NNS"},
"preempts":	{"VBZ"},
"preen":	{"VB","VBP"},
"preened":	{"VBD","VBN"},
"preening":	{"VBG"},
"preenrollment":	{"JJ"},
"preens":	{"VBZ"},
"preestablish":	{"VB","VBP"},
"preestablished":	{"VBD","VBN"},
"preestablishes":	{"VBZ"},
"preestablishing":	{"VBG"},
"preexist":	{"VB","VBP"},
"preexisted":	{"VBD","VBN"},
"preexistence":	{"NN"},
"preexistent":	{"JJ"},
"preexisting":	{"VBG"},
"preexists":	{"VBZ"},
"prefab":	{"JJ","NN"},
"prefabricate":	{"VB","VBP"},
"prefabricated":	{"VBD","VBN","JJ"},
"prefabricates":	{"VBZ"},
"prefabricating":	{"VBG"},
"prefabrication":	{"NN"},
"prefabs":	{"NNS"},
"preface":	{"NN","VB","VBP"},
"prefaced":	{"VBD","VBN"},
"prefaces":	{"NNS","VBZ"},
"prefacing":	{"VBG"},
"prefaded":	{"JJ"},
"prefatorial":	{"JJ"},
"prefatory":	{"JJ"},
"prefect":	{"NN"},
"prefectural":	{"JJ"},
"prefecture":	{"NN"},
"prefectures":	{"NNS"},
"prefer":	{"VB","VBP"},
"preferable":	{"JJ"},
"preferably":	{"RB"},
"preference":	{"NN"},
"preferences":	{"NNS"},
"preferent":	{"JJ"},
"preferential":	{"JJ"},
"preferentially":	{"RB"},
"preferment":	{"NN"},
"preferments":	{"NNS"},
"preferrance":	{"NN"},
"preferred":	{"JJ","VBN","VBD"},
"preferred-dividend":	{"JJ"},
"preferred-share":	{"JJ","NN"},
"preferred-stock":	{"JJ","NN"},
"preferring":	{"VBG"},
"prefers":	{"VBZ"},
"prefiguration":	{"NN"},
"prefigurative":	{"JJ"},
"prefigure":	{"VB","VBP"},
"prefigured":	{"VBD","VBN"},
"prefigures":	{"VBZ"},
"prefiguring":	{"VBG"},
"prefix":	{"NN","VB","VBP"},
"prefixation":	{"NN"},
"prefixed":	{"VBD","VBN"},
"prefixes":	{"VBZ","NNS"},
"prefixing":	{"VBG"},
"preflight":	{"NN","JJ"},
"preform":	{"VB","VBP"},
"preformation":	{"NN"},
"preformed":	{"VBD","VBN"},
"preforming":	{"VBG"},
"preforms":	{"VBZ"},
"prefrontal":	{"JJ"},
"prefund":	{"VB","VBP"},
"prefunded":	{"VBD","VBN"},
"prefunding":	{"VBG"},
"prefunds":	{"VBZ"},
"pregame":	{"JJ","NN"},
"pregnancies":	{"NNS"},
"pregnancy":	{"NN"},
"pregnanediol":	{"NN"},
"pregnant":	{"JJ"},
"preheat":	{"VB","VBP"},
"preheated":	{"VBN","VBD"},
"preheating":	{"VBG"},
"preheats":	{"VBZ"},
"prehend":	{"VB","VBP"},
"prehended":	{"VBD","VBN"},
"prehending":	{"VBG"},
"prehends":	{"VBZ"},
"prehensile":	{"JJ"},
"prehension":	{"NN"},
"prehensor":	{"NN"},
"prehistoric":	{"JJ"},
"prehistorical":	{"JJ"},
"prehistory":	{"NN"},
"preindication":	{"NN"},
"prejudge":	{"VB","VBP"},
"prejudged":	{"VBD","VBN"},
"prejudges":	{"VBZ"},
"prejudging":	{"VBG"},
"prejudgment":	{"NN"},
"prejudgments":	{"NNS"},
"prejudice":	{"NN","VB","VBP"},
"prejudiced":	{"JJ","VBD","VBN"},
"prejudices":	{"VBZ","NNS"},
"prejudicial":	{"JJ"},
"prejudicing":	{"VBG"},
"prejudicious":	{"JJ"},
"prelacy":	{"NN"},
"prelapsarian":	{"JJ"},
"prelate":	{"NN"},
"prelates":	{"NNS"},
"prelature":	{"NN"},
"prelaunch":	{"JJ"},
"prelim":	{"NN"},
"preliminaries":	{"NNS"},
"preliminarily":	{"RB"},
"preliminary":	{"JJ","NN"},
"prelims":	{"NNS"},
"preliterate":	{"JJ"},
"prelone":	{"NN"},
"prelude":	{"NN","VB","VBP"},
"preluded":	{"VBD","VBN"},
"preludes":	{"NNS","VBZ"},
"preluding":	{"VBG"},
"premarital":	{"JJ"},
"premature":	{"JJ"},
"prematurely":	{"RB"},
"prematureness":	{"NN"},
"prematurity":	{"NN"},
"premediate":	{"VB","VBP"},
"premediated":	{"VBD","VBN"},
"premediates":	{"VBZ"},
"premediating":	{"VBG"},
"premedical":	{"JJ"},
"premeditate":	{"VB","VBP"},
"premeditated":	{"VBD","VBN","JJ"},
"premeditates":	{"VBZ"},
"premeditating":	{"VBG"},
"premeditation":	{"NN"},
"premenopausal":	{"JJ"},
"premenstrual":	{"JJ"},
"premie":	{"NN"},
"premier":	{"JJ","NN"},
"premiere":	{"NN","VB","VBP"},
"premiered":	{"VBD","VBN"},
"premieres":	{"NNS","VBZ"},
"premiering":	{"VBG","NN"},
"premiers":	{"NNS"},
"premiership":	{"NN"},
"premies":	{"NNS"},
"premise":	{"NN","VB","VBP"},
"premised":	{"VBD","VBN","JJ"},
"premises":	{"NNS","VBZ"},
"premising":	{"VBG"},
"premiss":	{"NN"},
"premisses":	{"NNS"},
"premium":	{"NN","JJ"},
"premiums":	{"NNS"},
"premix":	{"NN","JJ"},
"premolar":	{"NN","JJ"},
"premonition":	{"NN"},
"premonitions":	{"NNS"},
"premonitory":	{"JJ"},
"prenanthes":	{"NNS"},
"prenatal":	{"JJ"},
"prenatally":	{"RB"},
"prenominal":	{"JJ"},
"prentice":	{"NN"},
"prenups":	{"NN"},
"prenuptial":	{"JJ"},
"preoccupancy":	{"NN"},
"preoccupation":	{"NN"},
"preoccupations":	{"NNS"},
"preoccupied":	{"JJ","VBD","VBN"},
"preoccupies":	{"VBZ"},
"preoccupy":	{"VB","VBP"},
"preoccupying":	{"VBG"},
"preoperative":	{"JJ"},
"preordain":	{"VB","VBP"},
"preordained":	{"VBD","VBN","JJ"},
"preordaining":	{"VBG"},
"preordainment":	{"NN"},
"preordains":	{"VBZ"},
"preordination":	{"NN"},
"prep":	{"NN","VB","VBP"},
"prepackage":	{"VB","VBP"},
"prepackaged":	{"VBD","VBN","JJ"},
"prepackages":	{"VBZ"},
"prepackaging":	{"VBG"},
"prepacked":	{"JJ"},
"prepaid":	{"JJ","VBD","VBN"},
"prepaid-tuition":	{"JJ"},
"preparation":	{"NN"},
"preparations":	{"NNS"},
"preparative":	{"JJ","NN"},
"preparatives":	{"NNS"},
"preparatory":	{"JJ"},
"prepare":	{"VB","VBP"},
"prepared":	{"VBN","JJ","VBD"},
"preparedness":	{"NN"},
"preparer":	{"NN"},
"preparers":	{"NNS"},
"prepares":	{"VBZ"},
"preparing":	{"VBG"},
"prepay":	{"VB","VBP"},
"prepaying":	{"VBG"},
"prepayment":	{"NN"},
"prepayments":	{"NNS"},
"prepays":	{"VBZ"},
"preperformance":	{"JJ"},
"prepolymer":	{"NN"},
"preponderance":	{"NN"},
"preponderant":	{"JJ"},
"preponderantly":	{"RB"},
"preponderate":	{"VB","VBP"},
"preponderated":	{"VBD","VBN"},
"preponderates":	{"VBZ"},
"preponderating":	{"VBG"},
"prepose":	{"VB","VBP"},
"preposed":	{"VBD","VBN"},
"preposes":	{"VBZ"},
"preposing":	{"VBG"},
"preposition":	{"NN"},
"prepositional":	{"JJ"},
"prepositionally":	{"RB"},
"prepositioning":	{"JJ"},
"prepositions":	{"NNS"},
"prepossess":	{"VB","VBP"},
"prepossessed":	{"VBD","VBN"},
"prepossesses":	{"VBZ"},
"prepossessing":	{"JJ","VBG"},
"prepossession":	{"NN"},
"preposterous":	{"JJ"},
"preposterously":	{"RB"},
"preposterousness":	{"NN"},
"prepotency":	{"NN"},
"prepped":	{"VBD","VBN"},
"preppie":	{"NN","JJ"},
"preppies":	{"NNS"},
"prepping":	{"VBG"},
"preppy":	{"JJ","NN"},
"preprandial":	{"JJ"},
"prepreg":	{"NN"},
"preprepared":	{"JJ"},
"preprinting":	{"NN"},
"preprivatization":	{"NN"},
"preps":	{"VBZ"},
"prepubertal":	{"JJ"},
"prepuberty":	{"NN"},
"prepubescent":	{"JJ"},
"prepublication":	{"JJ"},
"prepuce":	{"NN"},
"prepulsid":	{"NN"},
"prepupal":	{"JJ"},
"prepurchase":	{"JJ"},
"prequalification":	{"NN"},
"prequalifications":	{"NNS"},
"prequalified":	{"VBD","VBN","JJ"},
"prequalifies":	{"VBZ"},
"prequalify":	{"VB","VBP"},
"prequalifying":	{"VBG"},
"preradiation":	{"NN"},
"prerecord":	{"VB","VBP"},
"prerecorded":	{"VBD","VBN","JJ"},
"prerecording":	{"VBG","NN"},
"prerecordings":	{"NNS"},
"prerecords":	{"VBZ"},
"preregistration":	{"NN","JJ"},
"prerequisite":	{"NN"},
"prerequisites":	{"NNS"},
"prerogative":	{"NN"},
"prerogatives":	{"NNS"},
"presage":	{"VB","VBP","NN"},
"presaged":	{"VBD","VBN"},
"presages":	{"VBZ","NNS"},
"presaging":	{"VBG"},
"presale":	{"NN"},
"presales":	{"NNS"},
"presbyope":	{"NN"},
"presbyopia":	{"NN"},
"presbyopic":	{"JJ"},
"presbyte":	{"NN"},
"presbyter":	{"NN"},
"presbyteries":	{"NNS"},
"presbyters":	{"NNS"},
"presbytery":	{"NN"},
"presbytes":	{"NNS"},
"preschool":	{"JJ","NN"},
"preschooler":	{"NN"},
"preschoolers":	{"NNS"},
"preschools":	{"NNS"},
"prescience":	{"NN"},
"presciences":	{"NNS"},
"prescient":	{"JJ"},
"presciently":	{"RB"},
"prescott":	{"NN"},
"prescribe":	{"VB","VBP"},
"prescribed":	{"JJ","VBD","VBN"},
"prescriber":	{"NN"},
"prescribers":	{"NNS"},
"prescribes":	{"VBZ"},
"prescribing":	{"VBG"},
"prescript":	{"NN","JJ"},
"prescription":	{"NN"},
"prescription-drug":	{"NN","JJ"},
"prescriptions":	{"NNS"},
"prescriptive":	{"JJ"},
"prescriptively":	{"RB"},
"prescriptivism":	{"NN"},
"prescripts":	{"NNS"},
"preseason":	{"JJ"},
"presence":	{"NN"},
"presences":	{"NNS"},
"present":	{"JJ","VB","NN","VBP"},
"present-day":	{"JJ"},
"present-time":	{"JJ"},
"presentable":	{"JJ"},
"presentably":	{"RB"},
"presentation":	{"NN"},
"presentational":	{"JJ"},
"presentations":	{"NNS"},
"presente":	{"JJ"},
"presented":	{"VBN","VBD"},
"presenter":	{"NN"},
"presenters":	{"NNS"},
"presentiment":	{"NN"},
"presentiments":	{"NNS"},
"presenting":	{"VBG"},
"presentism":	{"NN"},
"presentist":	{"NN","JJ"},
"presently":	{"RB"},
"presentlye":	{"NN"},
"presentment":	{"NN"},
"presentments":	{"NNS"},
"presentness":	{"NN"},
"presents":	{"VBZ","NNS"},
"preservable":	{"JJ"},
"preservation":	{"NN"},
"preservationist":	{"NN"},
"preservationists":	{"NNS"},
"preservative":	{"NN","JJ"},
"preservatives":	{"NNS"},
"preserve":	{"VB","NN","VBP"},
"preserved":	{"VBD","VBN"},
"preserver":	{"NN"},
"preservers":	{"NNS"},
"preserves":	{"NNS","VBZ"},
"preserving":	{"VBG"},
"preset":	{"VB","VBP","VBD","VBN"},
"presets":	{"VBZ"},
"presetting":	{"VBG"},
"preshow":	{"JJ"},
"preside":	{"VB","VBP"},
"presided":	{"VBD","VBN"},
"presidencies":	{"NNS"},
"presidency":	{"NN"},
"president":	{"NN"},
"president-elect":	{"NN"},
"presidente":	{"FW"},
"presidential":	{"JJ"},
"presidentially":	{"RB"},
"presidents":	{"NNS"},
"presidentship":	{"NN"},
"presides":	{"VBZ"},
"presidia":	{"NNS"},
"presiding":	{"VBG","JJ"},
"presidio":	{"NN"},
"presidium":	{"NN"},
"presidiums":	{"NNS"},
"presocratic":	{"JJ"},
"presorting":	{"NN"},
"press":	{"NN","VB","VBP"},
"press-forge":	{"NN"},
"press-freedom":	{"NN"},
"press-gang":	{"VB","VBP","NN"},
"press-ganged":	{"VBD","VBN"},
"press-ganging":	{"VBG","NN"},
"press-gangs":	{"VBZ","NNS"},
"press-release":	{"NN"},
"press-up":	{"NN"},
"press-ups":	{"NNS"},
"pressburg":	{"NN"},
"pressed":	{"VBN","VBD","JJ"},
"pressed-paper":	{"JJ"},
"presser":	{"NN"},
"pressers":	{"NNS"},
"presses":	{"NNS","VBZ"},
"pressing":	{"VBG","JJ","NN"},
"pressingly":	{"RB"},
"pressings":	{"NNS"},
"pressman":	{"NN"},
"pressmark":	{"NN"},
"pressmen":	{"NNS"},
"pressor":	{"JJ"},
"pressure":	{"NN","VB","VBP"},
"pressure-cook":	{"VB","VBP"},
"pressure-cooked":	{"VBD","VBN"},
"pressure-cooker":	{"NN"},
"pressure-cookers":	{"NNS"},
"pressure-cooking":	{"VBG"},
"pressure-cooks":	{"VBZ"},
"pressure-feed":	{"NN"},
"pressured":	{"JJ","VBD","VBN"},
"pressures":	{"NNS","VBZ"},
"pressuring":	{"NN","VBG"},
"pressurisation":	{"NN"},
"pressurise":	{"VB","VBP"},
"pressurised":	{"VBD","VBN","JJ"},
"pressurises":	{"VBZ"},
"pressurising":	{"VBG"},
"pressurization":	{"NN"},
"pressurize":	{"VB","VBP"},
"pressurized":	{"VBN","JJ","VBD"},
"pressurized-water":	{"JJ"},
"pressurizes":	{"VBZ"},
"pressurizing":	{"VBG"},
"prestidigitation":	{"NN"},
"prestidigitator":	{"NN"},
"prestidigitators":	{"NNS"},
"prestige":	{"NN","JJ"},
"prestige-sentitive":	{"JJ"},
"prestigious":	{"JJ"},
"prestigiousness":	{"NN"},
"prestissimo":	{"RB"},
"presto":	{"JJ","RB","NN","UH"},
"preston":	{"NN"},
"presumable":	{"JJ"},
"presumably":	{"RB"},
"presume":	{"VB","VBP"},
"presumed":	{"VBD","VBN","JJ"},
"presumedly":	{"RB"},
"presumer":	{"NN"},
"presumes":	{"VBZ"},
"presuming":	{"VBG","JJ"},
"presumingly":	{"RB"},
"presumption":	{"NN"},
"presumptions":	{"NNS"},
"presumptive":	{"JJ"},
"presumptively":	{"RB"},
"presumptuous":	{"JJ"},
"presumptuously":	{"RB"},
"presumptuousness":	{"NN"},
"presuppose":	{"VB","VBP"},
"presupposed":	{"VBN","VBD"},
"presupposes":	{"VBZ"},
"presupposing":	{"VBG"},
"presupposition":	{"NN"},
"presuppositions":	{"NNS"},
"presymptomatic":	{"JJ"},
"pretax":	{"JJ","RB"},
"preteen":	{"NN","JJ"},
"preteenager":	{"NN"},
"preteens":	{"NNS"},
"pretence":	{"NN"},
"pretences":	{"NNS"},
"pretend":	{"VB","VBP","JJ"},
"pretended":	{"JJ","VBD","VBN"},
"pretender":	{"NN"},
"pretenders":	{"NNS"},
"pretending":	{"VBG"},
"pretends":	{"VBZ"},
"pretense":	{"NN"},
"pretenses":	{"NNS"},
"pretension":	{"NN"},
"pretensions":	{"NNS"},
"pretentious":	{"JJ"},
"pretentiously":	{"RB"},
"pretentiousness":	{"NN"},
"preterist":	{"NN"},
"preterit":	{"NN","JJ"},
"preterite":	{"NN","JJ"},
"preterition":	{"NN"},
"pretermission":	{"NN"},
"pretermit":	{"VB","VBP"},
"pretermits":	{"VBZ"},
"pretermitted":	{"VBD","VBN"},
"pretermitter":	{"NN"},
"pretermitting":	{"VBG"},
"preternatural":	{"JJ"},
"preternaturally":	{"RB"},
"pretest":	{"NN","VB","VBP"},
"pretested":	{"VBD","VBN"},
"pretesting":	{"VBG"},
"pretests":	{"NNS","VBZ"},
"pretext":	{"NN","VB","VBP"},
"pretexted":	{"VBD","VBN"},
"pretexting":	{"VBG"},
"pretexts":	{"NNS","VBZ"},
"pretextual":	{"JJ"},
"pretor":	{"NN"},
"pretorial":	{"JJ"},
"pretorian":	{"JJ"},
"pretorium":	{"NN"},
"pretors":	{"NNS"},
"pretreatment":	{"NN"},
"pretrial":	{"JJ"},
"prettied":	{"VBD","VBN"},
"prettier":	{"JJR"},
"pretties":	{"VBZ"},
"prettiest":	{"JJS"},
"prettified":	{"VBD","VBN"},
"prettifies":	{"VBZ"},
"prettify":	{"VB","VBP"},
"prettifying":	{"VBG"},
"prettily":	{"RB"},
"prettiness":	{"NN"},
"pretty":	{"RB","JJ","VB","VBP"},
"pretty-pretty":	{"JJ"},
"prettying":	{"VBG"},
"pretzel":	{"NN"},
"pretzels":	{"NNS"},
"preussen":	{"NN"},
"prevacid":	{"NN"},
"prevail":	{"VB","VBP"},
"prevailed":	{"VBD","VBN"},
"prevailer":	{"NN"},
"prevailin":	{"NN"},
"prevailing":	{"JJ","VBG"},
"prevails":	{"VBZ"},
"prevalance":	{"NN"},
"prevalence":	{"NN"},
"prevalent":	{"JJ"},
"prevaricate":	{"VB","VBP"},
"prevaricated":	{"VBD","VBN"},
"prevaricates":	{"VBZ"},
"prevaricating":	{"VBG"},
"prevarication":	{"NN"},
"prevarications":	{"NNS"},
"prevaricator":	{"NN"},
"prevaricators":	{"NNS"},
"prevenient":	{"JJ"},
"prevent":	{"VB","VBP"},
"preventable":	{"JJ"},
"preventative":	{"JJ","NN"},
"preventatives":	{"NNS"},
"prevented":	{"VBN","VBD","JJ"},
"preventing":	{"VBG"},
"prevention":	{"NN"},
"preventive":	{"JJ","NN"},
"preventives":	{"NNS"},
"prevents":	{"VBZ"},
"preview":	{"NN","VB","VBP"},
"previewed":	{"VBD","VBN"},
"previewing":	{"VBG"},
"previews":	{"VBZ","NNS"},
"previous":	{"JJ"},
"previously":	{"RB"},
"previse":	{"VB","VBP"},
"prevised":	{"VBD","VBN"},
"previses":	{"VBZ"},
"prevising":	{"VBG"},
"prevision":	{"NN"},
"previsions":	{"NNS"},
"prevue":	{"NN"},
"prewar":	{"JJ"},
"prexies":	{"NNS"},
"prexy":	{"NN"},
"prey":	{"NN","VBP","VB"},
"preyed":	{"VBD","VBN"},
"preying":	{"VBG"},
"preys":	{"VBZ"},
"prezzie":	{"NN"},
"prezzies":	{"NNS"},
"priacanthidae":	{"NN"},
"priacanthus":	{"NN"},
"priapic":	{"JJ"},
"priapism":	{"NN"},
"priapus":	{"NN"},
"price":	{"NN","VB","VBP"},
"price-fixing":	{"NN"},
"price-list":	{"NN"},
"price-lists":	{"NNS"},
"price-rigging":	{"NN"},
"price-sensitive":	{"JJ"},
"price-tag":	{"NN"},
"price-tags":	{"NNS"},
"priced":	{"VBN","VBD","JJ"},
"priceless":	{"JJ"},
"pricelessly":	{"RB"},
"pricelessness":	{"NN"},
"pricelist":	{"NN"},
"prices":	{"NNS","VBZ"},
"pricey":	{"JJ"},
"pricier":	{"JJR"},
"priciest":	{"JJS"},
"pricily":	{"RB"},
"priciness":	{"NN"},
"pricing":	{"NN","VBG"},
"pricings":	{"NNS"},
"prick":	{"NN","VB","VBP"},
"pricked":	{"VBD","VBN"},
"pricker":	{"NN"},
"prickers":	{"NNS"},
"pricket":	{"NN"},
"pricking":	{"VBG","NN"},
"prickish":	{"JJ"},
"prickle":	{"NN","VB","VBP"},
"prickle-weed":	{"NN"},
"prickleback":	{"NN"},
"prickled":	{"VBD","VBN"},
"prickles":	{"NNS","VBZ"},
"pricklier":	{"JJR"},
"prickliest":	{"JJS"},
"prickliness":	{"NN"},
"prickling":	{"VBG"},
"prickly":	{"JJ"},
"pricks":	{"NNS","VBZ"},
"prickteaser":	{"NN"},
"pricy":	{"JJ"},
"pride":	{"NN","VBP","VB"},
"prided":	{"VBD","VBN"},
"prideful":	{"JJ"},
"pridefully":	{"RB"},
"pridefulness":	{"NN"},
"prides":	{"VBZ","NNS"},
"priding":	{"VBG"},
"prie-dieu":	{"NN"},
"pried":	{"VBD","VBN"},
"pries":	{"VBZ"},
"priest":	{"NN"},
"priest-doctor":	{"NN"},
"priestcraft":	{"NN"},
"priestess":	{"NN"},
"priestesses":	{"NNS"},
"priesthood":	{"NN"},
"priestlike":	{"JJ"},
"priestly":	{"JJ"},
"priests":	{"NNS"},
"prig":	{"NN","VB","VBP"},
"prigged":	{"VBD","VBN"},
"priggery":	{"NN"},
"prigging":	{"VBG"},
"priggish":	{"JJ"},
"priggishly":	{"RB"},
"priggishness":	{"NN"},
"priggism":	{"NN"},
"prigs":	{"NNS","VBZ"},
"prilosec":	{"NN"},
"prim":	{"JJ","VB","VBP"},
"prima":	{"JJ"},
"prima-facie":	{"FW","JJ"},
"primacy":	{"NN"},
"primaeval":	{"JJ"},
"primal":	{"JJ"},
"primality":	{"NN"},
"primaquine":	{"NN"},
"primaries":	{"NNS"},
"primarily":	{"RB"},
"primarly":	{"RB"},
"primary":	{"JJ","NN"},
"primary-election":	{"NN"},
"primate":	{"NN"},
"primates":	{"NNS"},
"primateship":	{"NN"},
"primatology":	{"NN"},
"primaxin":	{"NN"},
"prime":	{"JJ","NN","VB","VBP"},
"prime-time":	{"JJ","NN"},
"primed":	{"VBD","VBN"},
"primer":	{"NN"},
"primers":	{"NNS"},
"primes":	{"NNS","VBZ"},
"primetime":	{"NN"},
"primeval":	{"JJ"},
"primidone":	{"NN"},
"primigravida":	{"NN"},
"priming":	{"NN","VBG"},
"primipara":	{"NN"},
"primiparous":	{"JJ"},
"primitive":	{"JJ","NN"},
"primitively":	{"RB"},
"primitiveness":	{"NN"},
"primitives":	{"NNS"},
"primitivism":	{"NN"},
"primly":	{"RB"},
"primmed":	{"VBD","VBN"},
"primmer":	{"JJR"},
"primmest":	{"JJS"},
"primming":	{"VBG"},
"primness":	{"NN"},
"primo":	{"NN","JJ"},
"primogenitor":	{"NN"},
"primogeniture":	{"NN"},
"primordial":	{"JJ"},
"primordium":	{"NN"},
"primp":	{"VB","VBP"},
"primped":	{"VBD","VBN"},
"primping":	{"VBG"},
"primps":	{"VBZ"},
"primrose":	{"NN","JJ"},
"primroses":	{"NNS"},
"prims":	{"VBZ"},
"primula":	{"NN"},
"primulaceae":	{"NN"},
"primulales":	{"NNS"},
"primulas":	{"NNS"},
"prince":	{"NN"},
"prince's-feather":	{"NN"},
"prince's-plume":	{"NN"},
"princedom":	{"NN"},
"princeling":	{"NN"},
"princely":	{"JJ"},
"princes":	{"NNS"},
"princess":	{"NN"},
"princesses":	{"NNS"},
"princewood":	{"NN"},
"principal":	{"JJ","NN"},
"principalities":	{"NNS"},
"principality":	{"NN"},
"principally":	{"RB"},
"principals":	{"NNS"},
"principalship":	{"NN"},
"principe":	{"NN"},
"principen":	{"NN"},
"principle":	{"NN"},
"principled":	{"JJ"},
"principles":	{"NNS"},
"prinia":	{"NN"},
"prinival":	{"NN"},
"prink":	{"VB","VBP"},
"prinked":	{"VBD","VBN"},
"prinking":	{"VBG"},
"prinks":	{"VBZ"},
"print":	{"NN","VBP","VB"},
"print-out":	{"NN"},
"print-outs":	{"NNS"},
"printable":	{"JJ"},
"printed":	{"VBN","VBD","JJ"},
"printer":	{"NN"},
"printers":	{"NNS"},
"printing":	{"NN","VBG"},
"printings":	{"NNS"},
"printmaker":	{"NN"},
"printmaking":	{"NN"},
"printout":	{"NN"},
"printouts":	{"NNS"},
"prints":	{"NNS","VBZ"},
"priodontes":	{"NNS"},
"prion":	{"NN"},
"prionace":	{"NN"},
"prionotus":	{"NN"},
"prions":	{"NNS"},
"prior":	{"JJ","NN"},
"prior-review":	{"JJ"},
"prioress":	{"NN"},
"prioresses":	{"NNS"},
"priories":	{"NNS"},
"priorities":	{"NNS"},
"prioritisation":	{"NN"},
"prioritise":	{"VB","VBP"},
"prioritised":	{"VBD","VBN"},
"prioritises":	{"VBZ"},
"prioritising":	{"VBG"},
"prioritization":	{"NN"},
"prioritize":	{"VB","VBP"},
"prioritized":	{"VBD","VBN"},
"prioritizes":	{"VBZ"},
"prioritizing":	{"VBG"},
"priority":	{"NN","JJ"},
"priors":	{"NNS"},
"priorship":	{"NN"},
"priory":	{"NN"},
"priscoan":	{"NN"},
"prise":	{"VB","VBP"},
"prised":	{"VBD","VBN"},
"prises":	{"VBZ"},
"prising":	{"VBG"},
"prism":	{"NN"},
"prismatic":	{"JJ"},
"prismatoid":	{"NN"},
"prismoid":	{"NN"},
"prisms":	{"NNS"},
"prison":	{"NN"},
"prisoner":	{"NN"},
"prisoners":	{"NNS"},
"prisonlike":	{"JJ"},
"prisons":	{"NNS"},
"prissier":	{"JJR"},
"prissiest":	{"JJS"},
"prissily":	{"RB"},
"prissiness":	{"NN"},
"prissy":	{"JJ"},
"pristidae":	{"NN"},
"pristine":	{"JJ"},
"pristis":	{"NN"},
"pritzelago":	{"NN"},
"privacy":	{"NN"},
"private":	{"JJ","NN"},
"privateer":	{"NN","VB","VBP"},
"privateered":	{"VBD","VBN"},
"privateering":	{"VBG"},
"privateers":	{"NNS","VBZ"},
"privateersman":	{"NN"},
"privateersmen":	{"NNS"},
"privately":	{"RB"},
"privately-owned":	{"JJ"},
"privateness":	{"NN"},
"privates":	{"NNS"},
"privation":	{"NN"},
"privations":	{"NNS"},
"privatisation":	{"NN"},
"privatisations":	{"NNS"},
"privatise":	{"VB","VBP"},
"privatised":	{"VBD","VBN","JJ"},
"privatises":	{"VBZ"},
"privatising":	{"VBG"},
"privatization":	{"NN"},
"privatizations":	{"NNS"},
"privatize":	{"VB","NN"},
"privatized":	{"VBD","VBN","JJ"},
"privatizes":	{"VBZ"},
"privatizing":	{"VBG"},
"privet":	{"NN"},
"privies":	{"NNS"},
"privilege":	{"NN","VB","VBP"},
"privileged":	{"JJ","VBD","VBN"},
"privileges":	{"VBZ","NNS"},
"privileging":	{"VBG"},
"privily":	{"RB"},
"privine":	{"NN"},
"privy":	{"JJ","NN"},
"prize":	{"NN","JJ","VBP","VB"},
"prize-winning":	{"JJ"},
"prized":	{"VBD","VBN","JJ"},
"prizefight":	{"NN"},
"prizefighter":	{"NN"},
"prizefighters":	{"NNS"},
"prizefighting":	{"NN"},
"prizefights":	{"NNS"},
"prizeless":	{"JJ"},
"prizes":	{"NNS","VBZ"},
"prizewinning":	{"JJ"},
"prizing":	{"VBG"},
"prn":	{"RB"},
"pro":	{"NN","JJ","IN","FW"},
"pro-ALPA":	{"JJ"},
"pro-European":	{"JJ","NN"},
"pro-abortion":	{"JJ"},
"pro-alpa":	{"JJ"},
"pro-american":	{"JJ"},
"pro-ball":	{"NN"},
"pro-choice":	{"JJ"},
"pro-choicer":	{"NN"},
"pro-choicers":	{"NNS"},
"pro-family":	{"NN"},
"pro-growth":	{"JJ"},
"pro-inflammatory":	{"JJ"},
"pro-life":	{"JJ"},
"pro-lifer":	{"NN"},
"pro-rata":	{"JJ","RB"},
"proaccelerin":	{"NN"},
"proactive":	{"JJ"},
"proactively":	{"RB"},
"probabilism":	{"NN"},
"probabilistic":	{"JJ"},
"probabilistically":	{"RB"},
"probabilities":	{"NNS"},
"probability":	{"NN"},
"probable":	{"JJ","NN"},
"probables":	{"NNS"},
"probably":	{"RB"},
"probate":	{"NN","VBP","VB"},
"probated":	{"VBD","VBN"},
"probates":	{"VBZ"},
"probating":	{"VBG"},
"probation":	{"NN"},
"probationary":	{"JJ"},
"probationer":	{"NN"},
"probationers":	{"NNS"},
"probative":	{"JJ"},
"probatory":	{"JJ"},
"probe":	{"NN","VB","VBP"},
"probe-based":	{"JJ"},
"probed":	{"VBD","VBN"},
"probenecid":	{"NN"},
"probes":	{"NNS","VBZ"},
"probing":	{"JJ","VBG"},
"probingly":	{"RB"},
"probiotic":	{"JJ","NN"},
"probiotics":	{"NNS"},
"probity":	{"NN"},
"problem":	{"NN","JJ"},
"problem-solving":	{"JJ","NN"},
"problematic":	{"JJ"},
"problematical":	{"JJ"},
"problematically":	{"RB"},
"problematization":	{"NN"},
"problematize":	{"VB","VBP"},
"problematized":	{"VBD","VBN"},
"problematizes":	{"VBZ"},
"problematizing":	{"VBG"},
"problems":	{"NNS"},
"probosces":	{"NNS"},
"proboscidea":	{"NN"},
"proboscidean":	{"JJ","NN"},
"proboscidian":	{"JJ","NN"},
"proboscis":	{"NN"},
"proboscises":	{"NNS"},
"procaine":	{"NN"},
"procarbazine":	{"NN"},
"procardia":	{"NN"},
"procaryote":	{"NN"},
"procaryotic":	{"JJ"},
"procavia":	{"NN"},
"procaviidae":	{"NN"},
"procedural":	{"JJ"},
"procedurally":	{"RB"},
"procedure":	{"NN"},
"procedures":	{"NNS"},
"proceed":	{"VB","VBP"},
"proceeded":	{"VBD","VBN"},
"proceeding":	{"NN","VBG"},
"proceedings":	{"NNS"},
"proceeds":	{"VBZ","NNS"},
"procellaria":	{"NN"},
"procellariidae":	{"NN"},
"procellariiformes":	{"NNS"},
"process":	{"NN","VB","VBP"},
"process-control":	{"NN"},
"processed":	{"VBD","VBN","JJ"},
"processer":	{"NN"},
"processers":	{"NNS"},
"processes":	{"NNS","VBZ"},
"processing":	{"VBG","NN"},
"procession":	{"NN"},
"processional":	{"JJ","NN"},
"processions":	{"NNS"},
"processor":	{"NN"},
"processors":	{"NNS"},
"prochoice":	{"JJ"},
"prochoicer":	{"NN"},
"prociphilus":	{"NN"},
"proclaim":	{"VB","VBP"},
"proclaimed":	{"VBD","VBN"},
"proclaiming":	{"VBG"},
"proclaims":	{"VBZ"},
"proclamation":	{"NN"},
"proclamations":	{"NNS"},
"proclivities":	{"NNS"},
"proclivity":	{"NN"},
"procnias":	{"NNS"},
"proconsul":	{"NN"},
"proconsular":	{"JJ"},
"proconsulate":	{"NN"},
"proconsuls":	{"NNS"},
"proconsulship":	{"NN"},
"proconvertin":	{"NN"},
"procrastinate":	{"VB","VBP"},
"procrastinated":	{"VBD","VBN"},
"procrastinates":	{"VBZ"},
"procrastinating":	{"VBG"},
"procrastination":	{"NN"},
"procrastinator":	{"NN"},
"procreate":	{"VB","VBP"},
"procreated":	{"VBD","VBN"},
"procreates":	{"VBZ"},
"procreating":	{"VBG"},
"procreation":	{"NN"},
"procreative":	{"JJ"},
"procreativity":	{"NN"},
"procrustean":	{"JJ"},
"proctalgia":	{"NN"},
"proctitis":	{"NN"},
"proctocele":	{"NN"},
"proctologist":	{"NN"},
"proctology":	{"NN"},
"proctoplasty":	{"NN"},
"proctor":	{"NN","VB","VBP"},
"proctored":	{"VBD","VBN"},
"proctoring":	{"VBG"},
"proctors":	{"NNS","VBZ"},
"proctorship":	{"NN"},
"proctoscope":	{"NN"},
"proctoscopy":	{"NN"},
"procumbent":	{"JJ"},
"procurable":	{"JJ"},
"procural":	{"NN"},
"procurance":	{"NN"},
"procurator":	{"NN"},
"procuratorate":	{"NN"},
"procurators":	{"NNS"},
"procure":	{"VB","VBP"},
"procured":	{"VBD","VBN"},
"procurement":	{"NN"},
"procurer":	{"NN"},
"procurers":	{"NNS"},
"procures":	{"VBZ"},
"procuress":	{"NN"},
"procuring":	{"VBG"},
"procyclidine":	{"NN"},
"procyon":	{"NN"},
"procyonid":	{"NN"},
"procyonidae":	{"NN"},
"prod":	{"VB","VBP","NN"},
"prodded":	{"VBD","VBN"},
"prodding":	{"VBG","NN"},
"prodigal":	{"JJ","NN"},
"prodigality":	{"NN"},
"prodigally":	{"RB"},
"prodigals":	{"NNS"},
"prodigies":	{"NNS"},
"prodigious":	{"JJ"},
"prodigiously":	{"RB"},
"prodigy":	{"NN"},
"prodroma":	{"NN"},
"prodromal":	{"JJ"},
"prodrome":	{"NN"},
"prodromic":	{"JJ"},
"prods":	{"VBZ","NNS"},
"produce":	{"VB","VBP","NN"},
"produced":	{"VBN","VBD"},
"producer":	{"NN"},
"producers":	{"NNS"},
"produces":	{"VBZ"},
"producing":	{"VBG"},
"product":	{"NN"},
"production":	{"NN"},
"productions":	{"NNS"},
"productive":	{"JJ"},
"productively":	{"RB"},
"productiveness":	{"NN"},
"productivity":	{"NN"},
"products":	{"NNS"},
"proenzyme":	{"NN"},
"proessional":	{"NN"},
"prof":	{"NN"},
"profanation":	{"NN"},
"profanatory":	{"JJ"},
"profane":	{"JJ","VB","VBP"},
"profaned":	{"JJ","VBD","VBN"},
"profanely":	{"RB"},
"profaneness":	{"NN"},
"profanes":	{"VBZ"},
"profaning":	{"VBG"},
"profanities":	{"NNS"},
"profanity":	{"NN"},
"profess":	{"VB","VBP"},
"professed":	{"JJ","VBN","VBD"},
"professedly":	{"RB"},
"professes":	{"VBZ"},
"professeur":	{"NN"},
"professing":	{"VBG"},
"profession":	{"NN"},
"professional":	{"JJ","NN"},
"professionalisation":	{"NN"},
"professionalise":	{"VB","VBP"},
"professionalised":	{"VBD","VBN"},
"professionalises":	{"VBZ"},
"professionalising":	{"VBG"},
"professionalism":	{"NN"},
"professionalization":	{"NN"},
"professionalize":	{"VB","VBP"},
"professionalized":	{"VBD","VBN"},
"professionalizes":	{"VBZ"},
"professionalizing":	{"VBG"},
"professionally":	{"RB"},
"professionals":	{"NNS"},
"professions":	{"NNS"},
"professor":	{"NN"},
"professorial":	{"JJ"},
"professorially":	{"RB"},
"professoriate":	{"NN"},
"professors":	{"NNS"},
"professorship":	{"NN"},
"professorships":	{"NNS"},
"profet":	{"NN"},
"proffer":	{"VB","VBP","NN"},
"proffered":	{"VBD","VBN"},
"proffering":	{"VBG"},
"proffers":	{"VBZ","NNS"},
"proficiency":	{"NN"},
"proficient":	{"JJ"},
"proficiently":	{"RB"},
"profile":	{"NN","VB","VBP"},
"profiled":	{"VBD","VBN"},
"profiles":	{"NNS","VBZ"},
"profiling":	{"VBG","NN"},
"profit":	{"NN","VB","VBP"},
"profit-making":	{"JJ"},
"profit-margin":	{"NN"},
"profit-sharing":	{"NN"},
"profit-taking":	{"NN"},
"profitability":	{"NN"},
"profitable":	{"JJ"},
"profitableness":	{"NN"},
"profitably":	{"RB"},
"profited":	{"VBD","VBN"},
"profiteer":	{"NN","VB","VBP"},
"profiteered":	{"VBD","VBN"},
"profiteering":	{"VBG","NN"},
"profiteers":	{"NNS","VBZ"},
"profiterole":	{"NN"},
"profiting":	{"VBG"},
"profitless":	{"JJ"},
"profitlessly":	{"RB"},
"profits":	{"NNS","VBZ"},
"profligacy":	{"NN"},
"profligate":	{"JJ","NN"},
"profligately":	{"RB"},
"profligates":	{"NNS"},
"profound":	{"JJ"},
"profounder":	{"JJR"},
"profoundest":	{"JJS"},
"profoundly":	{"RB"},
"profoundness":	{"NN"},
"profs":	{"NNS"},
"profundities":	{"NNS"},
"profundity":	{"NN"},
"profuse":	{"JJ"},
"profusely":	{"RB"},
"profuseness":	{"NN"},
"profusion":	{"NN"},
"progandist":	{"NN"},
"progenitor":	{"NN"},
"progenitors":	{"NNS"},
"progeny":	{"NN"},
"progeria":	{"NN"},
"progestational":	{"JJ"},
"progesterone":	{"NN"},
"progestin":	{"NN"},
"progestogen":	{"NN"},
"prognathic":	{"JJ"},
"prognathism":	{"NN"},
"prognathous":	{"JJ"},
"progne":	{"NN"},
"prognoses":	{"NNS"},
"prognosis":	{"NN"},
"prognostic":	{"JJ","NN"},
"prognosticate":	{"VB","VBP"},
"prognosticated":	{"VBD","VBN"},
"prognosticates":	{"VBZ"},
"prognosticating":	{"VBG"},
"prognostication":	{"NN"},
"prognostications":	{"NNS"},
"prognosticative":	{"JJ"},
"prognosticator":	{"NN"},
"prognosticators":	{"NNS"},
"program":	{"NN","VB","VBP"},
"programed":	{"VBN","VBD"},
"programing":	{"NN","VBG"},
"programma":	{"NN"},
"programmable":	{"JJ"},
"programmatic":	{"JJ"},
"programmatically":	{"RB"},
"programme":	{"NN","VB","VBP"},
"programmed":	{"VBN","JJ","VBD"},
"programmer":	{"NN"},
"programmers":	{"NNS"},
"programmes":	{"NNS","VBZ"},
"programming":	{"NN","VBG"},
"programs":	{"NNS","VBZ"},
"progress":	{"NN","VB","VBP"},
"progressed":	{"VBD","VBN"},
"progresses":	{"VBZ"},
"progressing":	{"VBG"},
"progression":	{"NN"},
"progressions":	{"NNS"},
"progressive":	{"JJ","NN"},
"progressively":	{"RB"},
"progressiveness":	{"NN"},
"progressives":	{"NNS"},
"progressivism":	{"NN"},
"progressivity":	{"NN"},
"progun":	{"JJ"},
"progymnosperm":	{"NN"},
"prohibit":	{"VB","VBP"},
"prohibited":	{"VBN","VBD"},
"prohibiting":	{"VBG"},
"prohibition":	{"NN"},
"prohibitionist":	{"NN"},
"prohibitionists":	{"NNS"},
"prohibitions":	{"NNS"},
"prohibitive":	{"JJ"},
"prohibitively":	{"RB"},
"prohibitory":	{"JJ"},
"prohibits":	{"VBZ"},
"proinflammatory":	{"JJ"},
"project":	{"NN","VB","VBP"},
"projected":	{"VBN","VBD","JJ"},
"projectile":	{"NN","JJ"},
"projectiles":	{"NNS"},
"projecting":	{"JJ","VBG"},
"projection":	{"NN"},
"projectionist":	{"NN"},
"projectionists":	{"NNS"},
"projections":	{"NNS"},
"projective":	{"JJ"},
"projector":	{"NN"},
"projectors":	{"NNS"},
"projects":	{"NNS","VBZ"},
"prokaryote":	{"NN"},
"prokaryotic":	{"JJ"},
"prokayotae":	{"NN"},
"prokhorov":	{"NN"},
"prolabor":	{"JJ"},
"prolabour":	{"JJ"},
"prolactin":	{"NN"},
"prolamine":	{"NN"},
"prolapse":	{"NN","VB","VBP"},
"prolapsed":	{"VBD","VBN"},
"prolapses":	{"NNS","VBZ"},
"prolapsing":	{"VBG"},
"prolapsus":	{"NN"},
"prolate":	{"JJ"},
"prole":	{"NN"},
"prolegomena":	{"NNS"},
"prolegomenal":	{"JJ"},
"prolegomenary":	{"JJ"},
"prolegomenon":	{"NN"},
"prolegomenous":	{"JJ"},
"prolepsis":	{"NN"},
"proles":	{"NNS"},
"proletarian":	{"JJ","NN"},
"proletarians":	{"NNS"},
"proletariat":	{"NN","NNS"},
"proliferate":	{"VB","VBP"},
"proliferated":	{"VBD","VBN"},
"proliferates":	{"VBZ"},
"proliferating":	{"VBG"},
"proliferation":	{"NN"},
"prolific":	{"JJ"},
"prolificacy":	{"NN"},
"prolifically":	{"RB"},
"proline":	{"NN"},
"prolix":	{"JJ"},
"prolixity":	{"NN"},
"prolixly":	{"RB"},
"prolixness":	{"NN"},
"prolog":	{"NN"},
"prologise":	{"VB","VBP"},
"prologised":	{"VBD","VBN"},
"prologises":	{"VBZ"},
"prologising":	{"VBG"},
"prologize":	{"VB","VBP"},
"prologized":	{"VBD","VBN"},
"prologizes":	{"VBZ"},
"prologizing":	{"VBG"},
"prologue":	{"NN"},
"prologues":	{"NNS"},
"prologuise":	{"VB","VBP"},
"prologuised":	{"VBD","VBN"},
"prologuises":	{"VBZ"},
"prologuising":	{"VBG"},
"prologuize":	{"VB","VBP"},
"prologuized":	{"VBD","VBN"},
"prologuizes":	{"VBZ"},
"prologuizing":	{"VBG"},
"prolong":	{"VB","VBP"},
"prolongation":	{"NN"},
"prolongations":	{"NNS"},
"prolonge":	{"NN"},
"prolonged":	{"JJ","VBN","VBD"},
"prolonging":	{"VBG"},
"prolongs":	{"VBZ"},
"prolusion":	{"NN"},
"prolusions":	{"NNS"},
"prolusory":	{"JJ"},
"prom":	{"NN"},
"promazine":	{"JJ"},
"promenade":	{"NN","VB","VBP"},
"promenaded":	{"VBD","VBN"},
"promenader":	{"NN"},
"promenaders":	{"NNS"},
"promenades":	{"NNS","VBZ"},
"promenading":	{"VBG"},
"promethazine":	{"NN"},
"promethium":	{"NN"},
"prominence":	{"NN"},
"prominences":	{"NNS"},
"prominent":	{"JJ"},
"prominently":	{"RB"},
"promiscuity":	{"NN"},
"promiscuous":	{"JJ"},
"promiscuously":	{"RB"},
"promiscuousness":	{"NN"},
"promise":	{"NN","VBP","VB"},
"promised":	{"VBD","VBN","JJ"},
"promisee":	{"NN"},
"promisees":	{"NNS"},
"promiser":	{"NN"},
"promisers":	{"NNS"},
"promises":	{"VBZ","NNS"},
"promising":	{"JJ","VBG"},
"promisingly":	{"RB"},
"promisor":	{"NN"},
"promisors":	{"NNS"},
"promissory":	{"JJ"},
"promontories":	{"NNS"},
"promontory":	{"NN"},
"promote":	{"VB","VBP"},
"promoted":	{"VBN","VBD"},
"promoter":	{"NN"},
"promoters":	{"NNS"},
"promotes":	{"VBZ","NNS"},
"promoting":	{"VBG"},
"promotion":	{"NN"},
"promotional":	{"JJ"},
"promotions":	{"NNS"},
"promotive":	{"JJ"},
"promotiveness":	{"NN"},
"prompt":	{"VB","VBP","JJ","NN","RB"},
"promptbook":	{"NN"},
"prompted":	{"VBD","VBN"},
"prompter":	{"NN"},
"prompters":	{"NNS"},
"prompting":	{"VBG","NN"},
"promptings":	{"NNS"},
"promptitude":	{"NN"},
"promptly":	{"RB"},
"promptness":	{"NN"},
"prompts":	{"VBZ","NNS"},
"proms":	{"NNS"},
"promulgate":	{"VB","VBP"},
"promulgated":	{"VBD","VBN"},
"promulgates":	{"VBZ"},
"promulgating":	{"VBG"},
"promulgation":	{"NN"},
"promulgator":	{"NN"},
"promulgators":	{"NNS"},
"promycelium":	{"NN"},
"promyelocytic":	{"NN"},
"pronate":	{"VB","VBP"},
"pronated":	{"VBD","VBN"},
"pronates":	{"VBZ"},
"pronating":	{"VBG"},
"pronation":	{"NN"},
"pronator":	{"NN"},
"prone":	{"JJ","RB"},
"proneness":	{"NN"},
"prong":	{"NN","VB","VBP"},
"prongbuck":	{"NN"},
"pronged":	{"JJ","VBD","VBN"},
"pronghorn":	{"NN"},
"pronging":	{"VBG"},
"prongs":	{"NNS","VBZ"},
"prongy":	{"JJ"},
"pronk":	{"NN","VB","VBP"},
"pronked":	{"VBD","VBN"},
"pronking":	{"VBG"},
"pronks":	{"NNS","VBZ"},
"pronominal":	{"JJ"},
"pronominally":	{"RB"},
"pronoun":	{"NN"},
"pronounce":	{"VB","VBP"},
"pronounceable":	{"JJ"},
"pronounced":	{"JJ","VBD","VBN"},
"pronouncedly":	{"RB"},
"pronouncement":	{"NN"},
"pronouncements":	{"NNS"},
"pronounces":	{"VBZ","NNS"},
"pronouncing":	{"NN","VBG"},
"pronouns":	{"NNS"},
"pronto":	{"RB"},
"pronucleus":	{"NN"},
"pronunciamento":	{"NN"},
"pronunciation":	{"NN"},
"pronunciations":	{"NNS"},
"proof":	{"NN","JJ","VB","VBP"},
"proofed":	{"VBD","VBN"},
"proofing":	{"VBG"},
"proofread":	{"VB","VBP","VBD","VBN"},
"proofreader":	{"NN"},
"proofreaders":	{"NNS"},
"proofreading":	{"VBG","NN"},
"proofreads":	{"VBZ"},
"proofs":	{"NNS","VBZ"},
"prop":	{"VB","VBP","NN"},
"propaedeutic":	{"JJ","NN"},
"propaedeutical":	{"JJ"},
"propaedeutics":	{"NNS"},
"propaganda":	{"NN"},
"propagandise":	{"VB","VBP"},
"propagandised":	{"VBD","VBN"},
"propagandises":	{"VBZ"},
"propagandising":	{"VBG"},
"propagandist":	{"NN","JJ"},
"propagandistic":	{"JJ"},
"propagandists":	{"NNS"},
"propagandize":	{"VB","VBP"},
"propagandized":	{"VBD","VBN"},
"propagandizes":	{"VBZ"},
"propagandizing":	{"VBG"},
"propagate":	{"VB","VBP"},
"propagated":	{"VBD","VBN"},
"propagates":	{"VBZ"},
"propagating":	{"VBG"},
"propagation":	{"NN"},
"propagative":	{"JJ"},
"propagator":	{"NN"},
"propagators":	{"NNS"},
"propanal":	{"NN"},
"propanamide":	{"NN"},
"propane":	{"NN"},
"propanediol":	{"NN"},
"propanol":	{"NN"},
"propanolol":	{"NN"},
"propanone":	{"NN"},
"proparoxytone":	{"JJ","NN"},
"propel":	{"VB","VBP"},
"propellant":	{"JJ","NN"},
"propellants":	{"NNS"},
"propelled":	{"VBN","VBD"},
"propellent":	{"JJ","NN"},
"propellents":	{"NNS"},
"propeller":	{"NN"},
"propellers":	{"NNS"},
"propelling":	{"JJ","VBG"},
"propels":	{"VBZ","NNS"},
"propenal":	{"NN"},
"propene":	{"NN"},
"propenoate":	{"NN"},
"propenonitrile":	{"NN"},
"propensities":	{"NNS"},
"propensity":	{"NN"},
"proper":	{"JJ","RB"},
"properly":	{"RB"},
"properness":	{"NN"},
"propertied":	{"JJ"},
"properties":	{"NNS"},
"property":	{"NN"},
"propertyless":	{"JJ"},
"propfan":	{"NN"},
"propfans":	{"NNS"},
"prophase":	{"NN"},
"prophecies":	{"NNS"},
"prophecy":	{"NN"},
"prophesiable":	{"JJ"},
"prophesied":	{"VBD","VBN"},
"prophesier":	{"NN"},
"prophesies":	{"VBZ","NNS"},
"prophesy":	{"VB","NN"},
"prophesying":	{"VBG"},
"prophet":	{"NN"},
"prophetess":	{"NN"},
"prophetesses":	{"NNS"},
"prophetic":	{"JJ"},
"prophetical":	{"JJ"},
"prophetically":	{"RB"},
"prophets":	{"NNS"},
"prophylactic":	{"JJ","NN"},
"prophylactics":	{"NNS"},
"prophylaxes":	{"NNS"},
"prophylaxis":	{"NN"},
"prophyll":	{"NN"},
"propinquity":	{"NN"},
"propionaldehyde":	{"NN"},
"propionate":	{"NN"},
"propitiate":	{"VB","VBP"},
"propitiated":	{"VBD","VBN"},
"propitiates":	{"VBZ"},
"propitiating":	{"VBG"},
"propitiation":	{"NN"},
"propitiative":	{"JJ"},
"propitiatory":	{"JJ"},
"propitious":	{"JJ"},
"propitiously":	{"RB"},
"propitiousness":	{"NN"},
"propjet":	{"NN"},
"propman":	{"NN"},
"propmen":	{"NNS"},
"proponent":	{"NN"},
"proponents":	{"NNS"},
"proportion":	{"NN","VB","VBP"},
"proportionable":	{"JJ"},
"proportional":	{"JJ"},
"proportionality":	{"NN"},
"proportionally":	{"RB"},
"proportionate":	{"JJ"},
"proportionately":	{"RB"},
"proportionateness":	{"NN"},
"proportioned":	{"JJ","VBN","VBD"},
"proportioning":	{"VBG"},
"proportions":	{"NNS","VBZ"},
"proposal":	{"NN"},
"proposals":	{"NNS"},
"propose":	{"VB","VBP"},
"proposed":	{"VBN","VBD","JJ"},
"proposer":	{"NN"},
"proposers":	{"NNS"},
"proposes":	{"VBZ"},
"proposing":	{"VBG"},
"proposita":	{"NN"},
"propositae":	{"NNS"},
"propositi":	{"NNS"},
"proposition":	{"NN","VBP","VB"},
"propositional":	{"JJ"},
"propositioned":	{"VBD","VBN"},
"propositioning":	{"VBG"},
"propositions":	{"VBZ","NNS"},
"propositus":	{"NN"},
"propound":	{"VB","VBP"},
"propounded":	{"VBD","VBN"},
"propounding":	{"VBG"},
"propounds":	{"VBZ"},
"propoxyphene":	{"NN"},
"propped":	{"VBD","VBN"},
"propping":	{"VBG"},
"proprietary":	{"JJ"},
"proprieter":	{"NN"},
"proprieties":	{"NNS"},
"proprietor":	{"NN"},
"proprietors":	{"NNS"},
"proprietorship":	{"NN"},
"proprietorships":	{"NNS"},
"proprietory":	{"JJ"},
"proprietress":	{"NN"},
"proprietresses":	{"NNS"},
"propriety":	{"NN"},
"proprioception":	{"NN"},
"proprioceptive":	{"JJ"},
"proprioceptor":	{"NN"},
"proprionamide":	{"NN"},
"props":	{"NNS","VBZ","UH"},
"propulsion":	{"NN"},
"propulsions":	{"NNS"},
"propulsive":	{"JJ"},
"propyl":	{"NN"},
"propylene":	{"NN"},
"propylthiouracil":	{"NN"},
"prorate":	{"VB","VBP"},
"prorated":	{"VBD","VBN"},
"prorates":	{"VBZ"},
"prorating":	{"VBG"},
"proration":	{"NN"},
"prorogation":	{"NN"},
"prorogue":	{"VB","VBP"},
"prorogued":	{"VBD","VBN"},
"prorogues":	{"VBZ"},
"proroguing":	{"VBG"},
"pros":	{"NNS"},
"prosaic":	{"JJ"},
"prosaically":	{"RB"},
"prosaicness":	{"NN"},
"prosauropoda":	{"NN"},
"proscenium":	{"NN"},
"prosceniums":	{"NNS"},
"prosciutto":	{"NN"},
"proscribe":	{"VB","VBP"},
"proscribed":	{"VBD","VBN"},
"proscribes":	{"VBZ"},
"proscribing":	{"VBG"},
"proscription":	{"NN"},
"proscriptions":	{"NNS"},
"proscriptive":	{"JJ"},
"prose":	{"NN"},
"prosecute":	{"VB","VBP"},
"prosecuted":	{"VBN","VBD"},
"prosecutes":	{"VBZ"},
"prosecuting":	{"VBG"},
"prosecution":	{"NN"},
"prosecutions":	{"NNS"},
"prosecutor":	{"NN"},
"prosecutorial":	{"JJ"},
"prosecutors":	{"NNS"},
"proselyte":	{"NN","VB","VBP"},
"proselyted":	{"VBD","VBN"},
"proselytes":	{"NNS","VBZ"},
"proselyting":	{"VBG"},
"proselytise":	{"VB","VBP"},
"proselytised":	{"VBD","VBN"},
"proselytises":	{"VBZ"},
"proselytising":	{"VBG","NN"},
"proselytism":	{"NN"},
"proselytize":	{"VB","VBP"},
"proselytized":	{"VBD","VBN"},
"proselytizer":	{"NN"},
"proselytizers":	{"NNS"},
"proselytizes":	{"VBZ"},
"proselytizing":	{"VBG","NN"},
"prosencephalon":	{"NN"},
"prosier":	{"JJR"},
"prosiest":	{"JJS"},
"prosily":	{"RB"},
"prosimian":	{"NN"},
"prosimii":	{"NN"},
"prosiness":	{"NN"},
"prosodic":	{"JJ"},
"prosodies":	{"NNS"},
"prosodion":	{"NN"},
"prosody":	{"NN"},
"prosom":	{"NN"},
"prosoma":	{"NN"},
"prosopis":	{"NN"},
"prosopium":	{"NN"},
"prosopopoeia":	{"NN"},
"prospect":	{"NN","VB","VBP"},
"prospected":	{"VBD","VBN"},
"prospecting":	{"VBG","NN"},
"prospective":	{"JJ"},
"prospectively":	{"RB"},
"prospector":	{"NN"},
"prospectors":	{"NNS"},
"prospects":	{"NNS","VBZ"},
"prospectus":	{"NN"},
"prospectuses":	{"NNS"},
"prosper":	{"VB","VBP"},
"prospered":	{"VBD","VBN"},
"prospering":	{"VBG"},
"prosperity":	{"NN"},
"prosperous":	{"JJ"},
"prosperously":	{"RB"},
"prospers":	{"VBZ"},
"prospicience":	{"NN"},
"prospicient":	{"JJ"},
"prostaglandin":	{"NN"},
"prostate":	{"NN"},
"prostatectomy":	{"NN"},
"prostates":	{"NNS"},
"prostatic":	{"JJ"},
"prostatitis":	{"NN"},
"prostheon":	{"NN"},
"prostheses":	{"NNS"},
"prosthesis":	{"NN"},
"prosthetic":	{"JJ"},
"prosthetics":	{"NN"},
"prosthetist":	{"NN"},
"prosthion":	{"NN"},
"prosthodontia":	{"NN"},
"prosthodontic":	{"JJ"},
"prosthodontics":	{"NN"},
"prosthodontist":	{"NN"},
"prostigmin":	{"NN"},
"prostitute":	{"NN","VB","VBP"},
"prostituted":	{"VBD","VBN"},
"prostitutes":	{"NNS","VBZ"},
"prostituting":	{"VBG"},
"prostitution":	{"NN"},
"prostrate":	{"JJ","VB","VBP"},
"prostrated":	{"VBD","VBN"},
"prostrates":	{"VBZ"},
"prostrating":	{"VBG"},
"prostration":	{"NN"},
"prostrations":	{"NNS"},
"prostyle":	{"JJ","NN"},
"prosumer":	{"NN"},
"prosumers":	{"NNS"},
"prosy":	{"JJ"},
"protactinium":	{"NN"},
"protagonism":	{"NN"},
"protagonist":	{"NN"},
"protagonists":	{"NNS"},
"protamine":	{"NN"},
"protanopia":	{"NN"},
"protanopic":	{"JJ"},
"protea":	{"NN"},
"proteaceae":	{"NN"},
"proteales":	{"NNS"},
"protean":	{"JJ"},
"protease":	{"NN"},
"proteases":	{"NNS"},
"protect":	{"VB","VBP"},
"protected":	{"VBN","JJ","VBD"},
"protecting":	{"VBG"},
"protection":	{"NN"},
"protectionism":	{"NN"},
"protectionist":	{"NN","JJ"},
"protectionists":	{"NNS"},
"protections":	{"NNS"},
"protective":	{"JJ","NN"},
"protectively":	{"RB"},
"protectiveness":	{"NN"},
"protector":	{"NN"},
"protectorate":	{"NN"},
"protectorates":	{"NNS"},
"protectors":	{"NNS"},
"protectorship":	{"NN"},
"protects":	{"VBZ"},
"protege":	{"NN"},
"protegee":	{"NN"},
"protegees":	{"NNS"},
"proteges":	{"NNS"},
"proteidae":	{"NN"},
"protein":	{"NN"},
"proteinaceous":	{"JJ"},
"proteinase":	{"NN"},
"proteins":	{"NNS"},
"proteinuria":	{"NN"},
"proteles":	{"NNS"},
"proteolysis":	{"NN"},
"proteolytic":	{"JJ"},
"proteome":	{"NN"},
"proteomics":	{"NN"},
"proteosome":	{"NN"},
"proterochampsa":	{"NN"},
"proterozoic":	{"JJ"},
"protest":	{"NN","VB","VBP"},
"protestation":	{"NN"},
"protestations":	{"NNS"},
"protested":	{"VBD","VBN"},
"protester":	{"NN"},
"protesters":	{"NNS"},
"protesting":	{"VBG"},
"protestor":	{"NN"},
"protestors":	{"NNS"},
"protests":	{"NNS","VBZ"},
"proteus":	{"NN"},
"prothalamion":	{"NN"},
"prothalamium":	{"NN"},
"prothorax":	{"NN"},
"prothrombin":	{"NN"},
"prothrombinase":	{"NN"},
"protirelin":	{"NN"},
"protist":	{"NN"},
"protistan":	{"NN"},
"protists":	{"NNS"},
"protium":	{"NN"},
"proto-Athabascan":	{"NN"},
"proto-oncogene":	{"NN"},
"proto-oncogenes":	{"NNS"},
"proto-senility":	{"NN"},
"protoactinium":	{"NN"},
"protoanthropology":	{"NN"},
"protoarchaeology":	{"NN"},
"protoarcheology":	{"NN"},
"protoavis":	{"NN"},
"protoceratops":	{"NNS"},
"protocol":	{"NN","VB","VBP"},
"protocoled":	{"VBD","VBN"},
"protocoling":	{"VBG"},
"protocolled":	{"VBD","VBN"},
"protocolling":	{"VBG"},
"protocols":	{"NNS","VBZ"},
"protoctist":	{"NN"},
"protoctista":	{"NN"},
"protogeometric":	{"JJ"},
"protoheme":	{"NN"},
"protohemin":	{"NN"},
"protohippus":	{"NN"},
"protohistory":	{"NN"},
"protology":	{"NN"},
"protomammal":	{"NN"},
"proton":	{"NN"},
"protons":	{"NNS"},
"protoplasm":	{"NN"},
"protoplasmic":	{"JJ"},
"protoplast":	{"NN"},
"protosolar":	{"JJ"},
"prototheria":	{"NN"},
"prototherian":	{"NN"},
"prototypal":	{"JJ"},
"prototype":	{"NN"},
"prototypes":	{"NNS"},
"prototypic":	{"JJ"},
"prototypical":	{"JJ"},
"prototyping":	{"NN"},
"protozoa":	{"NNS"},
"protozoal":	{"JJ"},
"protozoan":	{"NN","JJ"},
"protozoans":	{"NNS"},
"protozoic":	{"JJ"},
"protozoological":	{"JJ"},
"protozoologist":	{"NN"},
"protozoology":	{"NN"},
"protozoon":	{"NN"},
"protract":	{"VB","VBP"},
"protracted":	{"JJ","VBD","VBN"},
"protractedly":	{"RB"},
"protractible":	{"JJ"},
"protractile":	{"JJ"},
"protracting":	{"VBG"},
"protraction":	{"NN"},
"protractor":	{"NN"},
"protractors":	{"NNS"},
"protracts":	{"VBZ"},
"protriptyline":	{"NN"},
"protropin":	{"NN"},
"protrude":	{"VB","VBP"},
"protruded":	{"VBD","VBN"},
"protrudes":	{"VBZ"},
"protruding":	{"VBG"},
"protrusible":	{"JJ"},
"protrusile":	{"JJ"},
"protrusion":	{"NN"},
"protrusions":	{"NNS"},
"protrusive":	{"JJ"},
"protuberance":	{"NN"},
"protuberances":	{"NNS"},
"protuberant":	{"JJ"},
"protuberate":	{"VB","VBP"},
"protura":	{"NN"},
"proturan":	{"NN"},
"proud":	{"JJ","RB"},
"prouder":	{"JJR"},
"proudest":	{"JJS"},
"proudhon":	{"NN"},
"proudly":	{"RB"},
"proustian":	{"JJ"},
"provability":	{"NN"},
"provable":	{"JJ"},
"provably":	{"RB"},
"prove":	{"VB","VBP"},
"proved":	{"VBD","VBN","JJ"},
"proven":	{"VBN","JJ","VBD"},
"provenance":	{"NN"},
"provenances":	{"NNS"},
"provender":	{"NN"},
"provenience":	{"NN"},
"proventil":	{"NN"},
"provera":	{"NN"},
"proverb":	{"NN"},
"proverbial":	{"JJ"},
"proverbially":	{"RB"},
"proverbs":	{"NNS"},
"proverty":	{"NN"},
"proves":	{"VBZ"},
"provide":	{"VB","VBP"},
"provided":	{"VBN","VBD","IN"},
"providence":	{"NN"},
"provident":	{"JJ"},
"providential":	{"JJ"},
"providentially":	{"RB"},
"providently":	{"RB"},
"provider":	{"NN"},
"providers":	{"NNS"},
"provides":	{"VBZ"},
"providing":	{"VBG","IN"},
"province":	{"NN"},
"provinces":	{"NNS"},
"provincial":	{"JJ","NN"},
"provincialism":	{"NN"},
"provincially":	{"RB"},
"proving":	{"VBG"},
"provirus":	{"NN"},
"provision":	{"NN","VBP","VB"},
"provisional":	{"JJ","NN"},
"provisionally":	{"RB"},
"provisionary":	{"JJ"},
"provisioned":	{"VBD","VBN"},
"provisioner":	{"NN"},
"provisioning":	{"VBG"},
"provisions":	{"NNS","VBZ"},
"proviso":	{"NN"},
"provisory":	{"JJ"},
"provisos":	{"NNS"},
"provitamin":	{"NN"},
"provocateur":	{"NN"},
"provocateurs":	{"NNS"},
"provocation":	{"NN"},
"provocations":	{"NNS"},
"provocative":	{"JJ"},
"provocatively":	{"RB"},
"provoke":	{"VB","VBP"},
"provoked":	{"VBD","VBN"},
"provoker":	{"NN"},
"provokes":	{"VBZ"},
"provoking":	{"JJ","VBG"},
"provokingly":	{"RB"},
"provost":	{"NN"},
"provosts":	{"NNS"},
"prow":	{"NN"},
"prowess":	{"NN"},
"prowl":	{"VB","VBP","NN"},
"prowled":	{"VBD","VBN"},
"prowler":	{"NN"},
"prowlers":	{"NNS"},
"prowling":	{"VBG"},
"prowls":	{"VBZ"},
"prows":	{"NNS"},
"prox.":	{"JJ"},
"proxemics":	{"NN"},
"proxies":	{"NNS"},
"proxima":	{"NN"},
"proximal":	{"JJ"},
"proximate":	{"JJ"},
"proximity":	{"NN"},
"proximo":	{"JJ"},
"proxy":	{"NN","JJ"},
"prude":	{"NN"},
"prudence":	{"NN"},
"prudent":	{"JJ"},
"prudential":	{"JJ"},
"prudentially":	{"RB"},
"prudently":	{"RB"},
"prudery":	{"NN"},
"prudes":	{"NNS"},
"prudish":	{"JJ"},
"prudishly":	{"RB"},
"prudishness":	{"NN"},
"prumnopitys":	{"NNS"},
"prune":	{"VB","VBP","NN"},
"pruned":	{"VBN","VBD"},
"prunella":	{"NN"},
"prunellidae":	{"NN"},
"pruner":	{"NN"},
"pruners":	{"NNS"},
"prunes":	{"VBZ","NNS"},
"pruning":	{"NN","VBG"},
"pruno":	{"NN"},
"prunus":	{"NN"},
"prurience":	{"NN"},
"pruriency":	{"NN"},
"prurient":	{"JJ"},
"pruriently":	{"RB"},
"prurigo":	{"NN"},
"pruritus":	{"NN"},
"pruta":	{"NN"},
"pry":	{"VB","VBP"},
"pryce":	{"NN"},
"prying":	{"JJ","VBG"},
"pryingly":	{"RB"},
"psa":	{"NN"},
"psalm":	{"NN"},
"psalmist":	{"NN"},
"psalmists":	{"NNS"},
"psalmody":	{"NN"},
"psalms":	{"NNS"},
"psalter":	{"NN"},
"psalteria":	{"NNS"},
"psalteries":	{"NNS"},
"psalterium":	{"NN"},
"psaltery":	{"NN"},
"psaltriparus":	{"NN"},
"psammoma":	{"NN"},
"psammophila":	{"NN"},
"psenes":	{"NNS"},
"psephological":	{"JJ"},
"psephologist":	{"NN"},
"psephologists":	{"NNS"},
"psephology":	{"NN"},
"psephurus":	{"NNS"},
"psetta":	{"NN"},
"psettichthys":	{"NNS"},
"pseud":	{"NN"},
"pseudacris":	{"NN"},
"pseudaletia":	{"NN"},
"pseudechis":	{"NN"},
"pseudemys":	{"NNS"},
"pseudepigrapha":	{"NN"},
"pseudnomynous":	{"JJ"},
"pseudo":	{"JJ"},
"pseudo-colour":	{"NN"},
"pseudo-intransitive":	{"JJ"},
"pseudoacid":	{"NN"},
"pseudoallele":	{"NN"},
"pseudoalum":	{"NN"},
"pseudoarthroses":	{"NNS"},
"pseudoarthrosis":	{"NN"},
"pseudobombax":	{"NN"},
"pseudobulb":	{"NN"},
"pseudocarp":	{"NN"},
"pseudocide":	{"NN"},
"pseudoclassic":	{"NN","JJ"},
"pseudococcidae":	{"NN"},
"pseudococcus":	{"NN"},
"pseudocode":	{"NN"},
"pseudocoel":	{"NN"},
"pseudocoelomate":	{"NN","JJ"},
"pseudocolus":	{"NN"},
"pseudocopulation":	{"NN"},
"pseudocyeses":	{"NNS"},
"pseudocyesis":	{"NN"},
"pseudoephedrine":	{"NN"},
"pseudogene":	{"NN"},
"pseudograph":	{"NN"},
"pseudography":	{"NN"},
"pseudohallucination":	{"NN"},
"pseudohermaphrodite":	{"NN"},
"pseudohermaphroditic":	{"JJ"},
"pseudohermaphroditism":	{"NN"},
"pseudolarix":	{"NN"},
"pseudologia":	{"NN"},
"pseudologue":	{"NN"},
"pseudomonad":	{"NN"},
"pseudomonadales":	{"NNS"},
"pseudomonas":	{"NNS"},
"pseudomonodaceae":	{"NNS"},
"pseudomononadaceae":	{"NNS"},
"pseudonym":	{"NN"},
"pseudonymous":	{"JJ"},
"pseudonymously":	{"RB"},
"pseudoperipteral":	{"JJ"},
"pseudophloem":	{"NN"},
"pseudopleuronectes":	{"NNS"},
"pseudopod":	{"NN"},
"pseudopodia":	{"NNS"},
"pseudopodium":	{"NN"},
"pseudoprostyle":	{"JJ"},
"pseudorubella":	{"NN"},
"pseudoryx":	{"NN"},
"pseudoscience":	{"NN"},
"pseudoscientific":	{"JJ"},
"pseudoscorpion":	{"NN"},
"pseudoscorpiones":	{"NNS"},
"pseudoscorpionida":	{"NN"},
"pseudosmallpox":	{"NN"},
"pseudosocialism":	{"NN"},
"pseudotaxus":	{"NN"},
"pseudotsuga":	{"NN"},
"pseudovariola":	{"NN"},
"pseudowintera":	{"NN"},
"pseuds":	{"NNS"},
"pseudynom":	{"NN"},
"psf":	{"NN"},
"psi":	{"NN"},
"psidium":	{"NN"},
"psilocin":	{"NN"},
"psilocybin":	{"NN"},
"psilomelane":	{"NN"},
"psilophytaceae":	{"NN"},
"psilophytales":	{"NNS"},
"psilophyte":	{"NN"},
"psilophyton":	{"NN"},
"psilopsida":	{"NN"},
"psilosis":	{"NN"},
"psilotaceae":	{"NN"},
"psilotales":	{"NNS"},
"psilotatae":	{"NN"},
"psilotum":	{"NN"},
"psithyrus":	{"NN"},
"psittacidae":	{"NN"},
"psittaciformes":	{"NNS"},
"psittacosaur":	{"NN"},
"psittacosaurus":	{"NN"},
"psittacosis":	{"NN"},
"psittacula":	{"NN"},
"psittacus":	{"NN"},
"psoas":	{"NN"},
"psocid":	{"NN"},
"psocidae":	{"NN"},
"psocoptera":	{"NN"},
"psophia":	{"NN"},
"psophiidae":	{"NN"},
"psophocarpus":	{"NN"},
"psoralea":	{"NN"},
"psoriasis":	{"NN"},
"pst":	{"NN"},
"psyche":	{"NN"},
"psychedelia":	{"NN"},
"psychedelic":	{"JJ"},
"psychedelically":	{"RB"},
"psyches":	{"NNS"},
"psychiatric":	{"JJ"},
"psychiatrically":	{"RB"},
"psychiatrist":	{"NN"},
"psychiatrists":	{"NNS"},
"psychiatry":	{"NN"},
"psychic":	{"JJ","NN"},
"psychical":	{"JJ"},
"psychically":	{"RB"},
"psychics":	{"NNS"},
"psycho":	{"NN","JJ"},
"psycho-physiology":	{"NN"},
"psychoactive":	{"JJ"},
"psychoanalyse":	{"VB","VBP"},
"psychoanalysed":	{"VBD","VBN"},
"psychoanalysing":	{"VBG"},
"psychoanalysis":	{"NN"},
"psychoanalyst":	{"NN"},
"psychoanalysts":	{"NNS"},
"psychoanalytic":	{"JJ"},
"psychoanalytical":	{"JJ"},
"psychoanalytically":	{"RB"},
"psychoanalyze":	{"VB","VBP"},
"psychoanalyzed":	{"VBD","VBN"},
"psychoanalyzes":	{"VBZ"},
"psychoanalyzing":	{"VBG"},
"psychobabble":	{"NN"},
"psychobiology":	{"NN"},
"psychodid":	{"NN"},
"psychodidae":	{"NN"},
"psychodynamics":	{"NN"},
"psychogenesis":	{"NN"},
"psychogenetic":	{"JJ"},
"psychogenic":	{"JJ"},
"psychokinesis":	{"NN"},
"psychokinetic":	{"JJ"},
"psychokinetically":	{"RB"},
"psycholinguist":	{"NN"},
"psycholinguistic":	{"JJ"},
"psycholinguistics":	{"NN"},
"psychological":	{"JJ"},
"psychologically":	{"RB"},
"psychologist":	{"NN"},
"psychologists":	{"NNS"},
"psychology":	{"NN"},
"psychometric":	{"JJ"},
"psychometrics":	{"NN"},
"psychometrika":	{"NN"},
"psychometry":	{"NN"},
"psychomotor":	{"JJ"},
"psychoneurosis":	{"NN"},
"psychoneurotic":	{"JJ","NN"},
"psychonomics":	{"NN"},
"psychopath":	{"NN"},
"psychopathic":	{"JJ"},
"psychopathically":	{"RB"},
"psychopathologic":	{"JJ"},
"psychopathological":	{"JJ"},
"psychopathology":	{"NN"},
"psychopaths":	{"NNS"},
"psychopathy":	{"NN"},
"psychopharmacological":	{"JJ"},
"psychopharmacology":	{"NN"},
"psychophysicist":	{"NN"},
"psychophysics":	{"NN"},
"psychophysiology":	{"NN"},
"psychopomp":	{"NN"},
"psychopsis":	{"NN"},
"psychoses":	{"NNS"},
"psychosexual":	{"JJ"},
"psychosexuality":	{"NN"},
"psychosis":	{"NN"},
"psychosocial":	{"JJ"},
"psychosomatic":	{"JJ"},
"psychosomatically":	{"RB"},
"psychosurgery":	{"NN"},
"psychotherapeutic":	{"JJ"},
"psychotherapeutics":	{"NN"},
"psychotherapist":	{"NN"},
"psychotherapists":	{"NNS"},
"psychotherapy":	{"NN"},
"psychotic":	{"NN","JJ"},
"psychotically":	{"RB"},
"psychotics":	{"NNS"},
"psychotria":	{"NN"},
"psychotropic":	{"JJ"},
"psychrometer":	{"NN"},
"psylla":	{"NN"},
"psyllid":	{"NN"},
"psyllidae":	{"NN"},
"psyllium":	{"NN"},
"psyop":	{"NN"},
"pt":	{"NN"},
"ptah":	{"NN"},
"ptarmigan":	{"NN","NNS"},
"ptarmigans":	{"NNS"},
"pteretis":	{"NN"},
"pteridaceae":	{"NN"},
"pteridium":	{"NN"},
"pteridological":	{"JJ"},
"pteridologist":	{"NN"},
"pteridology":	{"NN"},
"pteridophyta":	{"NN"},
"pteridophyte":	{"NN"},
"pteridosperm":	{"NN"},
"pteridospermae":	{"NN"},
"pteridospermaphyta":	{"NN"},
"pteridospermopsida":	{"NN"},
"pteriidae":	{"NN"},
"pterion":	{"NN"},
"pteris":	{"NN"},
"pternohyla":	{"NN"},
"pterocarpus":	{"NN"},
"pterocarya":	{"NN"},
"pterocles":	{"NN"},
"pteroclididae":	{"NN"},
"pterocnemia":	{"NN"},
"pterodactyl":	{"NN"},
"pterodactylidae":	{"NN"},
"pterodactylus":	{"NN"},
"pterois":	{"NN"},
"pteropogon":	{"NN"},
"pteropsida":	{"NN"},
"pteropus":	{"NN"},
"pterosaur":	{"NN"},
"pterosauria":	{"NN"},
"pterospermum":	{"NN"},
"pterostylis":	{"NN"},
"pterygia":	{"NN"},
"pterygium":	{"NN"},
"ptilocercus":	{"NN"},
"ptilocrinus":	{"NN"},
"ptilonorhynchidae":	{"NN"},
"ptilonorhynchus":	{"NN"},
"ptloris":	{"NN"},
"ptolemaic":	{"JJ"},
"ptomain":	{"NN"},
"ptomaine":	{"NN"},
"ptosis":	{"NN"},
"pts":	{"NNS"},
"ptsd":	{"NN"},
"ptyalin":	{"NN"},
"ptyalise":	{"VB","VBP"},
"ptyalism":	{"NN"},
"ptyalith":	{"NN"},
"ptyalize":	{"VB","VBP"},
"ptyas":	{"NN"},
"ptychozoon":	{"NN"},
"pu":	{"NN"},
"pub":	{"NN"},
"pub-crawl":	{"NN","VB","VBP"},
"pub-crawled":	{"VBD","VBN"},
"pub-crawling":	{"VBG"},
"pub-crawls":	{"VBZ"},
"pubcrawler":	{"NN"},
"puber":	{"NN"},
"pubertal":	{"JJ"},
"puberty":	{"NN"},
"puberulent":	{"JJ"},
"pubes":	{"NNS"},
"pubescence":	{"NN"},
"pubescent":	{"JJ"},
"pubic":	{"JJ"},
"pubis":	{"NN"},
"public":	{"JJ","NN"},
"public-affairs":	{"NNS"},
"public-health":	{"JJ","NN"},
"public-housing":	{"JJ","NN"},
"public-policy":	{"NN","JJ"},
"public-relations":	{"NN","NNS"},
"public-school":	{"JJ","NN"},
"public-sector":	{"NN","JJ"},
"public-service":	{"JJ","NN"},
"public-spirited":	{"JJ"},
"public-television":	{"NN"},
"public-works":	{"NNS"},
"publically":	{"RB"},
"publican":	{"NN"},
"publicans":	{"NNS"},
"publication":	{"NN"},
"publications":	{"NNS"},
"publicise":	{"VB","VBP"},
"publicised":	{"VBD","VBN"},
"publiciser":	{"NN"},
"publicises":	{"VBZ"},
"publicising":	{"VBG"},
"publicist":	{"NN"},
"publicists":	{"NNS"},
"publicity":	{"NN"},
"publicize":	{"VB","VBP"},
"publicized":	{"VBD","VBN","JJ"},
"publicizer":	{"NN"},
"publicizes":	{"VBZ"},
"publicizing":	{"VBG"},
"publicly":	{"RB"},
"publicsector":	{"JJ"},
"publish":	{"VB","VBP"},
"publishable":	{"JJ"},
"published":	{"VBN","VBD"},
"publisher":	{"NN"},
"publishers":	{"NNS"},
"publishes":	{"VBZ"},
"publishing":	{"NN","VBG"},
"pubs":	{"NNS"},
"puccinia":	{"NN"},
"pucciniaceae":	{"NN"},
"puccoon":	{"NN"},
"puce":	{"JJ","NN"},
"puck":	{"NN"},
"pucka":	{"JJ"},
"pucker":	{"VB","VBP","NN"},
"puckerbush":	{"NN"},
"puckered":	{"VBD","VBN","JJ"},
"puckering":	{"VBG"},
"puckers":	{"VBZ"},
"puckish":	{"JJ"},
"puckishly":	{"RB"},
"puckishness":	{"NN"},
"pucks":	{"NNS"},
"pud":	{"NN"},
"pudding":	{"NN"},
"pudding-face":	{"NN"},
"pudding-faced":	{"JJ"},
"pudding-head":	{"NN"},
"puddings":	{"NNS"},
"puddingstone":	{"NN"},
"puddle":	{"NN","VB","VBP"},
"puddled":	{"VBD","VBN"},
"puddler":	{"NN"},
"puddlers":	{"NNS"},
"puddles":	{"NNS","VBZ"},
"puddling":	{"VBG"},
"pudendal":	{"JJ"},
"pudendum":	{"NN"},
"pudge":	{"NN"},
"pudgier":	{"JJR"},
"pudgiest":	{"JJS"},
"pudginess":	{"NN"},
"pudgy":	{"JJ"},
"puds":	{"NNS"},
"puebla":	{"NN"},
"pueblo":	{"NN"},
"pueblos":	{"NNS"},
"pueraria":	{"NN"},
"puerile":	{"JJ"},
"puerility":	{"NN"},
"puerpera":	{"NN"},
"puerperal":	{"JJ"},
"puerperia":	{"NNS"},
"puerperium":	{"NN"},
"puff":	{"NN","VB","VBP"},
"puff-adder":	{"NN"},
"puff-ball":	{"NN"},
"puff-balls":	{"NNS"},
"puffball":	{"NN"},
"puffballs":	{"NNS"},
"puffbird":	{"NN"},
"puffbirds":	{"NNS"},
"puffed":	{"JJ","VBD","VBN"},
"puffed-up":	{"JJ"},
"puffer":	{"NN"},
"pufferfish":	{"NN"},
"puffers":	{"NNS"},
"puffery":	{"NN"},
"puffier":	{"JJR"},
"puffiest":	{"JJS"},
"puffily":	{"RB"},
"puffin":	{"NN"},
"puffiness":	{"NN"},
"puffing":	{"VBG"},
"puffinus":	{"NN"},
"puffs":	{"VBZ","NNS"},
"puffy":	{"JJ"},
"pug":	{"NN","VB","VBP"},
"pug-dog":	{"NN"},
"pug-faced":	{"JJ"},
"pug-nose":	{"NN"},
"pug-nosed":	{"JJ"},
"pugged":	{"VBD","VBN"},
"pugging":	{"VBG"},
"pugh":	{"JJ"},
"pugilism":	{"NN"},
"pugilist":	{"NN"},
"pugilistic":	{"JJ"},
"pugilists":	{"NNS"},
"pugnacious":	{"JJ"},
"pugnaciously":	{"RB"},
"pugnacity":	{"NN"},
"pugs":	{"NNS","VBZ"},
"puissance":	{"NN"},
"puissant":	{"JJ"},
"puka":	{"NN"},
"pukas":	{"NNS"},
"puke":	{"VB","VBP","NN"},
"puked":	{"VBD","VBN"},
"pukes":	{"VBZ"},
"puking":	{"VBG"},
"pukka":	{"JJ"},
"puku":	{"NN"},
"pul":	{"NN"},
"pulasan":	{"NN"},
"pulassan":	{"NN"},
"pulchritude":	{"NN"},
"pulchritudinous":	{"JJ"},
"pule":	{"VB","VBP"},
"puled":	{"VBD","VBN"},
"puler":	{"NN"},
"pules":	{"VBZ"},
"pulex":	{"NN"},
"pulicaria":	{"NN"},
"pulicidae":	{"NN"},
"puling":	{"VBG"},
"pulitzer":	{"NN"},
"pull":	{"NN","VB","VBP"},
"pull-down":	{"JJ"},
"pull-in":	{"NN"},
"pull-off":	{"NN"},
"pull-out":	{"NN"},
"pull-through":	{"NN"},
"pull-up":	{"NN"},
"pull-ups":	{"NNS"},
"pullback":	{"NN"},
"pullbacks":	{"NNS"},
"pulled":	{"VBD","VBN"},
"puller":	{"NN"},
"pullers":	{"NNS"},
"pullet":	{"NN"},
"pullets":	{"NNS"},
"pulley":	{"NN"},
"pulley-block":	{"NN"},
"pulleys":	{"NNS"},
"pulling":	{"VBG"},
"pullout":	{"NN"},
"pullouts":	{"NNS"},
"pullover":	{"NN"},
"pullovers":	{"NNS"},
"pulls":	{"VBZ","NNS"},
"pullulate":	{"VB","VBP"},
"pullulated":	{"VBD","VBN"},
"pullulates":	{"VBZ"},
"pullulating":	{"VBG"},
"pullulation":	{"NN"},
"pulmonary":	{"JJ"},
"pulmonata":	{"NN"},
"pulmonic":	{"JJ"},
"pulmonologist":	{"NN"},
"pulmonologists":	{"NNS"},
"pulmonology":	{"NN"},
"pulp":	{"NN","VB","VBP"},
"pulped":	{"VBD","VBN"},
"pulpier":	{"JJR"},
"pulpiest":	{"JJS"},
"pulpiness":	{"NN"},
"pulping":	{"VBG"},
"pulpit":	{"NN"},
"pulpits":	{"NNS"},
"pulps":	{"VBZ"},
"pulpwood":	{"NN"},
"pulpy":	{"JJ"},
"pulque":	{"NN"},
"pulsar":	{"NN"},
"pulsars":	{"NNS"},
"pulsate":	{"VB","VBP"},
"pulsated":	{"VBD","VBN"},
"pulsates":	{"VBZ"},
"pulsatilla":	{"NN"},
"pulsating":	{"VBG"},
"pulsation":	{"NN"},
"pulsations":	{"NNS"},
"pulse":	{"NN","VB","VBP"},
"pulse-jet":	{"NN"},
"pulse-timing":	{"JJ"},
"pulsed":	{"VBD","VBN"},
"pulseless":	{"JJ"},
"pulses":	{"NNS","VBZ"},
"pulsing":	{"VBG"},
"pulverisation":	{"NN"},
"pulverise":	{"VB","VBP"},
"pulverised":	{"VBD","VBN","JJ"},
"pulverises":	{"VBZ"},
"pulverising":	{"VBG"},
"pulverization":	{"NN"},
"pulverize":	{"VB","VBP"},
"pulverized":	{"JJ","VBD","VBN"},
"pulverizes":	{"VBZ"},
"pulverizing":	{"VBG"},
"puma":	{"NN"},
"pumas":	{"NNS"},
"pumice":	{"NN"},
"pumice-stone":	{"NN"},
"pumice-stones":	{"NNS"},
"pumices":	{"NNS"},
"pummel":	{"VB","VBP"},
"pummeled":	{"VBD","VBN"},
"pummeling":	{"VBG","NN"},
"pummelled":	{"VBD","VBN"},
"pummelling":	{"VBG","NN"},
"pummelo":	{"NN"},
"pummels":	{"VBZ"},
"pump":	{"NN","VB","VBP"},
"pump-action":	{"JJ"},
"pump-priming":	{"NN"},
"pumped":	{"VBD","VBN","JJ"},
"pumped-up":	{"JJ"},
"pumpernickel":	{"NN"},
"pumping":	{"VBG"},
"pumpkin":	{"NN"},
"pumpkins":	{"NNS"},
"pumpkinseed":	{"NN"},
"pumpkinseeds":	{"NNS"},
"pumps":	{"NNS","VBZ"},
"pun":	{"NN","VB","VBP"},
"punch":	{"NN","VB","VBP"},
"punch-ball":	{"NN"},
"punch-balls":	{"NNS"},
"punch-bowl":	{"NN"},
"punch-bowls":	{"NNS"},
"punch-drunk":	{"JJ"},
"punch-line":	{"NN"},
"punch-up":	{"NN"},
"punch-ups":	{"NNS"},
"punchayet":	{"NN"},
"punchball":	{"NN"},
"punchballs":	{"NNS"},
"punchboard":	{"NN"},
"punchbowl":	{"NN"},
"punched":	{"VBD","VBN"},
"punched-card":	{"JJ"},
"puncher":	{"NN"},
"punchers":	{"NNS"},
"punches":	{"VBZ","NNS"},
"punchier":	{"JJR"},
"punchiest":	{"JJS"},
"punchiness":	{"NN"},
"punching":	{"NN","VBG"},
"punchy":	{"JJ"},
"punctilio":	{"NN"},
"punctilios":	{"NNS"},
"punctilious":	{"JJ"},
"punctiliously":	{"RB"},
"punctiliousness":	{"NN"},
"punctual":	{"JJ"},
"punctuality":	{"NN"},
"punctually":	{"RB"},
"punctuate":	{"VB","VBP"},
"punctuated":	{"VBD","VBN"},
"punctuates":	{"VBZ"},
"punctuating":	{"VBG"},
"punctuation":	{"NN"},
"punctum":	{"NN"},
"puncturable":	{"JJ"},
"puncture":	{"NN","VB","VBP"},
"punctured":	{"VBD","VBN"},
"punctureless":	{"JJ"},
"punctures":	{"NNS","VBZ"},
"puncturing":	{"VBG"},
"pundit":	{"NN"},
"punditocracies":	{"NNS"},
"punditocracy":	{"NN"},
"punditry":	{"NN"},
"pundits":	{"NNS"},
"pung":	{"NN"},
"pungapung":	{"NN"},
"pungency":	{"NN"},
"pungent":	{"JJ"},
"pungently":	{"RB"},
"punica":	{"NN"},
"punicaceae":	{"NN"},
"punier":	{"JJR"},
"puniest":	{"JJS"},
"punily":	{"RB"},
"puniness":	{"NN"},
"punish":	{"VB","VBP"},
"punishable":	{"JJ"},
"punished":	{"VBN","VBD"},
"punishes":	{"VBZ","NNS"},
"punishing":	{"JJ","VBG"},
"punishingly":	{"RB"},
"punishment":	{"NN"},
"punishments":	{"NNS"},
"punitive":	{"JJ"},
"punitively":	{"RB"},
"punitorily":	{"RB"},
"punitory":	{"JJ"},
"punk":	{"NN","JJ"},
"punkah":	{"NN"},
"punkahs":	{"NNS"},
"punkey":	{"NN"},
"punkie":	{"NN"},
"punkier":	{"JJR"},
"punkiest":	{"JJS"},
"punks":	{"NNS"},
"punky":	{"JJ"},
"punned":	{"VBD","VBN"},
"punnet":	{"NN"},
"punnets":	{"NNS"},
"punning":	{"VBG","NN"},
"puns":	{"VBZ","NNS"},
"punster":	{"NN"},
"punsters":	{"NNS"},
"punt":	{"NN","VB","VBP"},
"punted":	{"VBD","VBN"},
"punter":	{"NN"},
"punters":	{"NNS"},
"punting":	{"NN","VBG"},
"punts":	{"NNS","VBZ"},
"puny":	{"JJ"},
"pup":	{"NN","VB","VBP"},
"pupa":	{"NN"},
"pupae":	{"NNS"},
"pupal":	{"JJ"},
"pupas":	{"NNS"},
"pupate":	{"VB","VBP"},
"pupated":	{"VBD","VBN"},
"pupates":	{"VBZ"},
"pupating":	{"VBG"},
"pupil":	{"NN"},
"pupillary":	{"JJ"},
"pupils":	{"NNS"},
"pupped":	{"VBD","VBN"},
"puppet":	{"NN"},
"puppet-play":	{"NN"},
"puppet-plays":	{"NNS"},
"puppet-show":	{"NN"},
"puppet-shows":	{"NNS"},
"puppeteer":	{"NN"},
"puppeteers":	{"NNS"},
"puppetry":	{"NN"},
"puppets":	{"NNS"},
"puppies":	{"NNS"},
"pupping":	{"VBG"},
"puppy":	{"NN"},
"puppy-fat":	{"NN"},
"puppy-love":	{"NN"},
"puppyhood":	{"NN"},
"puppyish":	{"JJ"},
"puppylike":	{"JJ","RB"},
"pups":	{"NNS","VBZ"},
"purana":	{"NN"},
"puranic":	{"JJ"},
"purau":	{"NN"},
"purblind":	{"JJ"},
"purchasable":	{"JJ"},
"purchase":	{"NN","VB","VBP"},
"purchased":	{"VBN","VBD"},
"purchaser":	{"NN"},
"purchasers":	{"NNS"},
"purchases":	{"NNS","VBZ"},
"purchasing":	{"VBG","NN"},
"purdah":	{"NN"},
"pure":	{"JJ"},
"pure-bred":	{"JJ","NN"},
"pure-breds":	{"NNS"},
"pureblood":	{"JJ","NN"},
"pureblooded":	{"JJ"},
"purebred":	{"JJ","NN"},
"purebreds":	{"NNS"},
"puree":	{"NN","VB","VBP"},
"pureed":	{"VBD","VBN"},
"pureeing":	{"VBG"},
"purees":	{"NNS","VBZ"},
"purely":	{"RB"},
"pureness":	{"NN"},
"purer":	{"JJR"},
"purest":	{"JJS"},
"purgation":	{"NN"},
"purgative":	{"JJ","NN"},
"purgatives":	{"NNS"},
"purgatorial":	{"JJ"},
"purgatory":	{"NN"},
"purge":	{"VB","VBP","NN"},
"purged":	{"VBD","VBN"},
"purges":	{"VBZ","NNS"},
"purging":	{"VBG"},
"purification":	{"NN"},
"purified":	{"VBD","VBN"},
"purifier":	{"NN"},
"purifiers":	{"NNS"},
"purifies":	{"VBZ"},
"purify":	{"VB","VBP"},
"purifying":	{"VBG"},
"purine":	{"NN"},
"purinethol":	{"NN"},
"purism":	{"NN"},
"purist":	{"NN"},
"purists":	{"NNS"},
"puritan":	{"NN","JJ"},
"puritanic":	{"JJ"},
"puritanical":	{"JJ"},
"puritanically":	{"RB"},
"puritanism":	{"NN"},
"puritans":	{"NNS"},
"purity":	{"NN"},
"purkinje":	{"NN"},
"purl":	{"NN","VB","VBP"},
"purled":	{"VBD","VBN"},
"purlieu":	{"NN"},
"purlin":	{"NN"},
"purling":	{"VBG"},
"purloin":	{"VB","VBP"},
"purloined":	{"VBD","VBN"},
"purloining":	{"VBG"},
"purloins":	{"VBZ"},
"purloo":	{"NN"},
"purls":	{"VBZ"},
"purple":	{"JJ","NN"},
"purpleness":	{"NN"},
"purplish":	{"JJ"},
"purport":	{"VB","VBP","NN"},
"purported":	{"JJ","VBD","VBN"},
"purportedly":	{"RB"},
"purporting":	{"VBG"},
"purports":	{"VBZ"},
"purpose":	{"NN","VB","VBP"},
"purpose-built":	{"JJ"},
"purposed":	{"VBD","VBN"},
"purposeful":	{"JJ"},
"purposefully":	{"RB"},
"purposefulness":	{"NN"},
"purposeless":	{"JJ"},
"purposelessly":	{"RB"},
"purposelessness":	{"NN"},
"purposely":	{"RB"},
"purposes":	{"NNS","VBZ"},
"purposing":	{"VBG"},
"purposive":	{"JJ"},
"purposively":	{"RB"},
"purpura":	{"NN"},
"purpurate":	{"NN"},
"purr":	{"VB","VBP","NN"},
"purred":	{"VBD","VBN"},
"purring":	{"VBG"},
"purrs":	{"VBZ","NNS"},
"purse":	{"NN","VB","VBP"},
"purse-strings":	{"NNS"},
"pursed":	{"VBD","VBN"},
"purser":	{"NN"},
"pursers":	{"NNS"},
"purses":	{"VBZ","NNS"},
"pursier":	{"JJR"},
"pursiest":	{"JJS"},
"pursiness":	{"NN"},
"pursing":	{"VBG"},
"purslane":	{"NN"},
"pursual":	{"NN"},
"pursuance":	{"NN"},
"pursuant":	{"JJ"},
"pursue":	{"VB","VBP"},
"pursued":	{"VBN","VBD"},
"pursuer":	{"NN"},
"pursuers":	{"NNS"},
"pursues":	{"VBZ"},
"pursuing":	{"VBG"},
"pursuit":	{"NN"},
"pursuits":	{"NNS"},
"pursy":	{"JJ"},
"purtier":	{"JJR"},
"purtiest":	{"JJS"},
"purty":	{"JJ","RB"},
"purulence":	{"NN"},
"purulency":	{"NN"},
"purulent":	{"JJ"},
"purvey":	{"VB","VBP"},
"purveyance":	{"NN"},
"purveyed":	{"VBD","VBN"},
"purveying":	{"VBG"},
"purveyor":	{"NN"},
"purveyors":	{"NNS"},
"purveys":	{"VBZ"},
"purview":	{"NN"},
"pus":	{"NN"},
"push":	{"VB","NN","VBP"},
"push-bike":	{"NN"},
"push-bikes":	{"NNS"},
"push-button":	{"JJ"},
"push-cart":	{"NN"},
"push-carts":	{"NNS"},
"push-chair":	{"NN"},
"push-chairs":	{"NNS"},
"push-off":	{"JJ"},
"push-up":	{"NN"},
"push-ups":	{"NNS"},
"pushback":	{"NN"},
"pushball":	{"NN"},
"pushcart":	{"NN"},
"pushcarts":	{"NNS"},
"pushchair":	{"NN"},
"pushchairs":	{"NNS"},
"pushed":	{"VBD","VBN","JJ"},
"pusher":	{"NN"},
"pushers":	{"NNS"},
"pushes":	{"VBZ","NNS"},
"pushful":	{"JJ"},
"pushier":	{"JJR"},
"pushiest":	{"JJS"},
"pushily":	{"RB"},
"pushiness":	{"NN"},
"pushing":	{"VBG","JJ","IN"},
"pushover":	{"NN"},
"pushovers":	{"NNS"},
"pushpin":	{"NN"},
"pushpins":	{"NNS"},
"pushup":	{"NN"},
"pushups":	{"NNS"},
"pushy":	{"JJ"},
"pusillanimity":	{"NN"},
"pusillanimous":	{"JJ"},
"pusillanimously":	{"RB"},
"pusillanimousness":	{"NN"},
"puss":	{"NN"},
"pusses":	{"NNS"},
"pussies":	{"NNS"},
"pussley":	{"NN"},
"pussy":	{"NN"},
"pussy-paw":	{"NN"},
"pussy-paws":	{"NN"},
"pussycat":	{"NN"},
"pussycats":	{"NNS"},
"pussyfoot":	{"VB","VBP"},
"pussyfooted":	{"VBD","VBN"},
"pussyfooting":	{"VBG"},
"pussyfoots":	{"VBZ"},
"pussytoes":	{"NNS"},
"pustulate":	{"VB","VBP","JJ"},
"pustulated":	{"VBD","VBN"},
"pustulates":	{"VBZ"},
"pustulating":	{"VBG"},
"pustule":	{"NN"},
"pustules":	{"NNS"},
"put":	{"VB","VBD","VBN","VBP","NN","JJ"},
"put-down":	{"NN"},
"put-on":	{"NN"},
"put-put":	{"NN","VB","VBP"},
"put-puts":	{"NNS","VBZ"},
"put-putted":	{"VBD","VBN"},
"put-putting":	{"VBG"},
"put-up":	{"JJ"},
"put-upon":	{"JJ"},
"putains":	{"FW"},
"putamen":	{"NN"},
"putamina":	{"NNS"},
"putative":	{"JJ"},
"pute":	{"JJ"},
"putoff":	{"NN"},
"putout":	{"NN"},
"putouts":	{"NNS"},
"putrajaya":	{"NN"},
"putrefacient":	{"JJ"},
"putrefaction":	{"NN"},
"putrefactive":	{"JJ"},
"putrefiable":	{"JJ"},
"putrefied":	{"VBD","VBN"},
"putrefies":	{"VBZ"},
"putrefy":	{"VB","VBP"},
"putrefying":	{"VBG"},
"putrescence":	{"NN"},
"putrescent":	{"JJ"},
"putrescible":	{"JJ"},
"putrescine":	{"NN"},
"putrid":	{"JJ"},
"putridity":	{"NN"},
"putridness":	{"NN"},
"puts":	{"VBZ","NNS"},
"putsch":	{"NN"},
"putsches":	{"NNS"},
"putt":	{"NN","VB","VBP"},
"putt-putt":	{"NN","VB","VBP"},
"putt-putted":	{"VBD","VBN"},
"putt-putting":	{"VBG"},
"putt-putts":	{"NNS","VBZ"},
"puttable":	{"JJ"},
"puttana":	{"NN"},
"putted":	{"VBD","VBN"},
"puttee":	{"NN"},
"puttees":	{"NNS"},
"putter":	{"NN","VB","VBP"},
"puttered":	{"VBD","VBN"},
"putterer":	{"NN"},
"puttering":	{"VBG"},
"putters":	{"VBZ","NNS"},
"puttied":	{"VBD","VBN"},
"putties":	{"VBZ"},
"putting":	{"VBG","NN"},
"putts":	{"NNS","VBZ"},
"putty":	{"NN","VB","VBP"},
"puttying":	{"VBG"},
"puttyless":	{"JJ"},
"puttylike":	{"JJ"},
"puttyroot":	{"NN"},
"putz":	{"NN","VBP","VB"},
"putzed":	{"VBD","VBN"},
"putzes":	{"NNS","VBZ"},
"putzing":	{"VBG"},
"puzzle":	{"NN","VB","VBP"},
"puzzled":	{"VBD","VBN","JJ"},
"puzzlement":	{"NN"},
"puzzler":	{"NN"},
"puzzlers":	{"NNS"},
"puzzles":	{"NNS","VBZ"},
"puzzling":	{"VBG","JJ"},
"pva":	{"NN"},
"pw":	{"NN"},
"pwr":	{"NN"},
"pya":	{"NN"},
"pyaemia":	{"NN"},
"pyaemic":	{"JJ"},
"pycnanthemum":	{"NN"},
"pycnidium":	{"NN"},
"pycnodysostosis":	{"NN"},
"pycnogonid":	{"NN"},
"pycnogonida":	{"NN"},
"pycnosis":	{"NN"},
"pycnotic":	{"JJ"},
"pydna":	{"NN"},
"pye-dog":	{"NN"},
"pyelitis":	{"NN"},
"pyelogram":	{"NN"},
"pyelography":	{"NN"},
"pyelonephritis":	{"NN"},
"pyemia":	{"NN"},
"pyemic":	{"JJ"},
"pygmies":	{"NNS"},
"pygmy":	{"NN","JJ"},
"pygopodidae":	{"NN"},
"pygopus":	{"NN"},
"pygoscelis":	{"NN"},
"pyhrric":	{"JJ"},
"pyinma":	{"NN"},
"pyjama":	{"JJ"},
"pyjamas":	{"NNS"},
"pyknic":	{"JJ"},
"pyknosis":	{"NN"},
"pyknotic":	{"JJ"},
"pyle":	{"NN"},
"pylodictus":	{"NN"},
"pylon":	{"NN"},
"pylons":	{"NNS"},
"pyloric":	{"JJ"},
"pylorus":	{"NN"},
"pynchon":	{"NN"},
"pynte":	{"NN"},
"pyocanea":	{"NN"},
"pyocyanase":	{"NN"},
"pyocyanin":	{"NN"},
"pyogenic":	{"JJ"},
"pyorrhea":	{"NN"},
"pyorrhoea":	{"NN"},
"pyracanth":	{"NN"},
"pyracantha":	{"NN"},
"pyralid":	{"NN"},
"pyralidae":	{"NN"},
"pyralididae":	{"NN"},
"pyralis":	{"NN"},
"pyramid":	{"NN","VB","VBP"},
"pyramidal":	{"JJ"},
"pyramided":	{"VBD","VBN"},
"pyramidic":	{"JJ"},
"pyramidical":	{"JJ"},
"pyramidically":	{"RB"},
"pyramiding":	{"VBG"},
"pyramids":	{"NNS","VBZ"},
"pyrausta":	{"NN"},
"pyre":	{"NN"},
"pyrene":	{"NN"},
"pyrenomycetes":	{"NNS"},
"pyrethrum":	{"NN"},
"pyretic":	{"JJ"},
"pyrexia":	{"NN"},
"pyridine":	{"NN"},
"pyridium":	{"NN"},
"pyridoxal":	{"NN"},
"pyridoxamine":	{"NN"},
"pyridoxine":	{"NN"},
"pyrilamine":	{"NN"},
"pyrimidine":	{"NN"},
"pyrite":	{"NN"},
"pyrites":	{"NN"},
"pyrocellulose":	{"NN"},
"pyrocephalus":	{"NN"},
"pyrochemical":	{"JJ"},
"pyrochemistry":	{"NN"},
"pyroelectric":	{"JJ"},
"pyroelectrical":	{"JJ"},
"pyroelectricity":	{"NN"},
"pyrogallic":	{"JJ"},
"pyrogallol":	{"NN"},
"pyrogen":	{"NN"},
"pyrogenetic":	{"JJ"},
"pyrogenic":	{"JJ"},
"pyrogenous":	{"JJ"},
"pyrograph":	{"NN"},
"pyrographer":	{"NN"},
"pyrographic":	{"JJ"},
"pyrography":	{"NN"},
"pyrola":	{"NN"},
"pyrolaceae":	{"NN"},
"pyrolatry":	{"NN"},
"pyroligneous":	{"JJ"},
"pyrolignic":	{"JJ"},
"pyrolusite":	{"NN"},
"pyrolysis":	{"NN"},
"pyrolytic":	{"JJ"},
"pyromancer":	{"NN"},
"pyromancy":	{"NN"},
"pyromania":	{"NN"},
"pyromaniac":	{"NN"},
"pyromaniacs":	{"NNS"},
"pyrometer":	{"NN"},
"pyrometers":	{"NNS"},
"pyromorphite":	{"NN"},
"pyrope":	{"NN"},
"pyrophobia":	{"NN"},
"pyrophorus":	{"NN"},
"pyrophosphate":	{"NN"},
"pyrophyllite":	{"NN"},
"pyroscope":	{"NN"},
"pyrosis":	{"NN"},
"pyrostat":	{"NN"},
"pyrotechnic":	{"JJ"},
"pyrotechnical":	{"JJ"},
"pyrotechnics":	{"NN","NNS"},
"pyrotechny":	{"NN"},
"pyroxene":	{"NN"},
"pyroxylin":	{"NN"},
"pyroxyline":	{"NN"},
"pyrrhic":	{"JJ","NN"},
"pyrrhocoridae":	{"NN"},
"pyrrhotine":	{"NN"},
"pyrrhotite":	{"NN"},
"pyrrhula":	{"NN"},
"pyrrhuloxia":	{"NN"},
"pyrrhus":	{"NN"},
"pyrrophyta":	{"NN"},
"pyrrosia":	{"NN"},
"pyrularia":	{"NN"},
"pyrus":	{"NN"},
"pyschiatrist":	{"NN"},
"pysllium":	{"NN"},
"pythagorean":	{"JJ"},
"pythia":	{"NN"},
"pythiaceae":	{"NN"},
"pythias":	{"NN"},
"pythium":	{"NN"},
"pythius":	{"NN"},
"python":	{"NN"},
"pythoness":	{"NN"},
"pythonidae":	{"NN"},
"pythoninae":	{"NN"},
"pythons":	{"NNS"},
"pyuria":	{"NN"},
"pyx":	{"NN"},
"pyxidanthera":	{"NN"},
"pyxidium":	{"NN"},
"pyxie":	{"NN"},
"pyxis":	{"NN"},
"q":	{"NN","SYM","LS"},
"qabala":	{"NN"},
"qabalah":	{"NN"},
"qabalism":	{"NN"},
"qabalist":	{"NN"},
"qabalistic":	{"JJ"},
"qabbala":	{"NN"},
"qabbalah":	{"NN"},
"qadi":	{"NN"},
"qaeda":	{"NN"},
"qandahar":	{"NN"},
"qat":	{"NN"},
"qepiq":	{"NN"},
"qi":	{"NN"},
"qiang":	{"NN"},
"qiangic":	{"NN"},
"qibla":	{"NN"},
"qin":	{"NN"},
"qindarka":	{"NN"},
"qing":	{"NN"},
"qintar":	{"NN"},
"qoph":	{"NN"},
"qua":	{"IN"},
"quaalude":	{"NN"},
"quack":	{"NN","VB","VBP","JJ","UH"},
"quack-quack":	{"NN"},
"quacked":	{"VBD","VBN"},
"quackery":	{"NN"},
"quackgrass":	{"NN"},
"quacking":	{"VBG"},
"quacks":	{"NNS","VBZ"},
"quad":	{"NN"},
"quadcopter":	{"NN"},
"quadcopters":	{"NNS"},
"quadrangle":	{"NN"},
"quadrangles":	{"NNS"},
"quadrangular":	{"JJ"},
"quadrant":	{"NN"},
"quadrantanopia":	{"NN"},
"quadrants":	{"NNS"},
"quadraphonic":	{"JJ"},
"quadraphony":	{"NN"},
"quadrasonic":	{"JJ"},
"quadrate":	{"JJ","NN","VB","VBP"},
"quadrated":	{"VBD","VBN"},
"quadrates":	{"NNS","VBZ"},
"quadratic":	{"JJ","NN"},
"quadratics":	{"NNS"},
"quadrating":	{"VBG"},
"quadrature":	{"NN"},
"quadrennia":	{"NNS"},
"quadrennial":	{"JJ","NN"},
"quadrennium":	{"NN"},
"quadrenniums":	{"NNS"},
"quadric":	{"JJ","NN"},
"quadriceps":	{"NN","NNS"},
"quadrilateral":	{"JJ","NN"},
"quadrille":	{"NN"},
"quadrilles":	{"NNS"},
"quadrillion":	{"CD","PRP"},
"quadrillionth":	{"JJ","NN"},
"quadripara":	{"NN"},
"quadripartite":	{"JJ"},
"quadriphonic":	{"JJ"},
"quadriplegia":	{"NN"},
"quadriplegic":	{"NN","JJ"},
"quadriplegics":	{"NNS"},
"quadrisonic":	{"JJ"},
"quadrivium":	{"NN"},
"quadroon":	{"NN"},
"quadrumvirate":	{"NN"},
"quadruped":	{"NN"},
"quadrupedal":	{"JJ"},
"quadrupeds":	{"NNS"},
"quadruple":	{"JJ","NN","RB","VB","VBP"},
"quadrupled":	{"VBD","VBN","JJ"},
"quadruples":	{"VBZ","NN","JJ"},
"quadruplet":	{"NN"},
"quadruplets":	{"NNS"},
"quadruplex":	{"JJ"},
"quadruplicate":	{"NN","JJ","VB","VBP"},
"quadruplicated":	{"VBD","VBN"},
"quadruplicates":	{"VBZ"},
"quadruplicating":	{"VBG"},
"quadruplication":	{"NN"},
"quadrupling":	{"VBG"},
"quads":	{"NNS"},
"quaestor":	{"NN"},
"quaff":	{"VB","VBP"},
"quaffed":	{"VBD","VBN"},
"quaffer":	{"NN"},
"quaffing":	{"VBG"},
"quaffs":	{"VBZ"},
"quag":	{"NN"},
"quagga":	{"NN","NNS"},
"quaggas":	{"NNS"},
"quaggy":	{"JJ"},
"quagmire":	{"NN"},
"quagmires":	{"NNS"},
"quahaug":	{"NN"},
"quahog":	{"NN"},
"quaid":	{"NN"},
"quail":	{"NN","NNS","VB","VBP"},
"quailed":	{"VBD","VBN"},
"quailing":	{"VBG"},
"quails":	{"NNS","VBZ"},
"quaint":	{"JJ"},
"quainter":	{"JJR"},
"quaintest":	{"JJS"},
"quaintly":	{"RB"},
"quaintness":	{"NN"},
"quake":	{"NN","VBP","VB"},
"quake-displaced":	{"JJ"},
"quake-hit":	{"JJ"},
"quake-prone":	{"JJ"},
"quake-relief":	{"JJ"},
"quaked":	{"VBD","VBN"},
"quakes":	{"NNS","VBZ"},
"quaking":	{"VBG"},
"qualification":	{"NN"},
"qualifications":	{"NNS"},
"qualified":	{"VBN","VBD","JJ"},
"qualifier":	{"NN"},
"qualifiers":	{"NNS"},
"qualifies":	{"VBZ"},
"qualify":	{"VB","VBP"},
"qualifying":	{"VBG"},
"qualitative":	{"JJ"},
"qualitatively":	{"RB"},
"qualities":	{"NNS"},
"quality":	{"NN","JJ"},
"quality-conscious":	{"JJ"},
"qualm":	{"NN"},
"qualms":	{"NNS"},
"quam":	{"NN"},
"quamash":	{"NN"},
"quamassia":	{"NN"},
"quandang":	{"NN"},
"quandaries":	{"NNS"},
"quandary":	{"NN"},
"quandong":	{"NN"},
"quango":	{"NN"},
"quangos":	{"NNS"},
"quanta":	{"NNS"},
"quantal":	{"JJ"},
"quantic":	{"NN"},
"quantifiability":	{"NN"},
"quantifiable":	{"JJ"},
"quantification":	{"NN"},
"quantified":	{"VBD","VBN"},
"quantifier":	{"NN"},
"quantifiers":	{"NNS"},
"quantifies":	{"VBZ"},
"quantify":	{"VB","VBP"},
"quantifying":	{"VBG"},
"quantisation":	{"NN"},
"quantise":	{"VB","VBP"},
"quantised":	{"VBD","VBN"},
"quantises":	{"VBZ"},
"quantising":	{"VBG"},
"quantitative":	{"JJ"},
"quantitatively":	{"RB"},
"quantities":	{"NNS"},
"quantitive":	{"JJ"},
"quantitively":	{"RB"},
"quantity":	{"NN"},
"quantity-based":	{"JJ"},
"quantization":	{"NN"},
"quantize":	{"VB","VBP"},
"quantized":	{"VBD","VBN"},
"quantizes":	{"VBZ"},
"quantizing":	{"VBG"},
"quantong":	{"NN"},
"quantum":	{"NN","JJ"},
"quaoar":	{"NN"},
"quapaw":	{"NN"},
"quar":	{"NN","JJ","RB"},
"quarantine":	{"NN","VB","VBP"},
"quarantined":	{"VBD","VBN"},
"quarantines":	{"VBZ"},
"quarantining":	{"VBG"},
"quark":	{"NN"},
"quarks":	{"NNS"},
"quarrel":	{"NN","VB","VBP"},
"quarreled":	{"VBD","VBN"},
"quarreler":	{"NN"},
"quarrelers":	{"NNS"},
"quarreling":	{"VBG","NN","JJ"},
"quarrelled":	{"VBD","VBN"},
"quarreller":	{"NN"},
"quarrellers":	{"NNS"},
"quarrelling":	{"VBG","NN","JJ"},
"quarrels":	{"NNS","VBZ"},
"quarrelsome":	{"JJ"},
"quarrelsomeness":	{"NN"},
"quarried":	{"VBD","VBN"},
"quarrier":	{"NN"},
"quarries":	{"NNS","VBZ"},
"quarry":	{"NN","VB","VBP"},
"quarrying":	{"NN","VBG"},
"quarryman":	{"NN"},
"quarrymen":	{"NNS"},
"quart":	{"NN"},
"quartan":	{"JJ"},
"quarter":	{"NN","VB","VBP"},
"quarter-circle":	{"NN"},
"quarter-hour":	{"NN"},
"quarter-inch":	{"JJ"},
"quarter-mile":	{"NN","JJ"},
"quarter-moon":	{"NN"},
"quarter-point":	{"NN","JJ"},
"quarter-to-quarter":	{"JJ"},
"quarter-tone":	{"NN"},
"quarter-vine":	{"NN"},
"quarterback":	{"NN","VBP","VB"},
"quarterbacked":	{"VBD","VBN"},
"quarterbacking":	{"VBG"},
"quarterbacks":	{"NNS","VBZ"},
"quarterdeck":	{"NN"},
"quarterdecks":	{"NNS"},
"quartered":	{"VBD","VBN","JJ"},
"quarterfinal":	{"NN","JJ"},
"quarterfinals":	{"NNS"},
"quartering":	{"NN","VBG","JJ"},
"quarterlies":	{"NNS"},
"quarterlight":	{"NN"},
"quarterly":	{"JJ","NN","RB"},
"quartermaster":	{"NN"},
"quartermasters":	{"NNS"},
"quartern":	{"NN"},
"quarters":	{"NNS","VBZ"},
"quarterstaff":	{"NN"},
"quarterstaffs":	{"NNS"},
"quartervine":	{"NN"},
"quartet":	{"NN"},
"quartets":	{"NNS"},
"quartette":	{"NN"},
"quartic":	{"NN","JJ"},
"quartile":	{"NN","JJ"},
"quarto":	{"NN"},
"quartos":	{"NNS"},
"quarts":	{"NNS"},
"quartz":	{"NN"},
"quartzite":	{"NN"},
"quartzose":	{"JJ"},
"quasar":	{"NN"},
"quasars":	{"NNS"},
"quash":	{"VB","VBP"},
"quashed":	{"VBD","VBN"},
"quashes":	{"VBZ"},
"quashing":	{"VBG"},
"quasi":	{"JJ"},
"quasiparticle":	{"NN"},
"quassia":	{"NN"},
"quat":	{"NN"},
"quatercentenaries":	{"NNS"},
"quatercentenary":	{"NN"},
"quatercentennial":	{"JJ"},
"quatern":	{"NN"},
"quaternary":	{"JJ","NN"},
"quaternate":	{"JJ"},
"quaternion":	{"NN"},
"quaternity":	{"NN"},
"quatrain":	{"NN"},
"quattrocento":	{"NN"},
"quaver":	{"VB","VBP","NN"},
"quavered":	{"VBD","VBN"},
"quavering":	{"VBG"},
"quaveringly":	{"RB"},
"quavers":	{"VBZ","NNS"},
"quavery":	{"JJ"},
"quay":	{"NN"},
"quayage":	{"NN"},
"quays":	{"NNS"},
"quayside":	{"NN"},
"queasier":	{"JJR"},
"queasiest":	{"JJS"},
"queasily":	{"RB"},
"queasiness":	{"NN"},
"queasy":	{"JJ"},
"quechua":	{"NN"},
"quechuan":	{"JJ","NN"},
"queen":	{"NN","VB","VBP"},
"queen-size":	{"JJ"},
"queen-sized":	{"JJ"},
"queened":	{"VBD","VBN"},
"queenfish":	{"NN"},
"queening":	{"VBG","NN"},
"queenlike":	{"JJ"},
"queenly":	{"JJ"},
"queens":	{"NNS","VBZ"},
"queenside":	{"NN","JJ"},
"queer":	{"JJ","NN","VB","VBP"},
"queered":	{"VBD","VBN"},
"queerer":	{"JJR"},
"queerest":	{"JJS"},
"queering":	{"VBG"},
"queerly":	{"RB"},
"queerness":	{"NN"},
"queers":	{"NNS","VBZ"},
"quell":	{"VB","VBP"},
"quelled":	{"VBD","VBN"},
"quelling":	{"VBG"},
"quells":	{"VBZ"},
"quellung":	{"NN"},
"quench":	{"VB","VBP"},
"quenched":	{"VBD","VBN"},
"quenches":	{"VBZ"},
"quenching":	{"VBG","NN"},
"quenchless":	{"JJ"},
"quercitron":	{"NN"},
"quercus":	{"NN"},
"queried":	{"VBD","VBN"},
"querier":	{"NN"},
"queries":	{"NNS","VBZ"},
"quern":	{"NN"},
"querulous":	{"JJ"},
"querulously":	{"RB"},
"querulousness":	{"NN"},
"query":	{"NN","VB","VBP"},
"querying":	{"VBG"},
"quesadilla":	{"NN"},
"quest":	{"NN","VB","VBP"},
"quested":	{"VBD","VBN"},
"quester":	{"NN"},
"questing":	{"VBG","JJ"},
"question":	{"NN","VB","VBP"},
"questionable":	{"JJ"},
"questionably":	{"RB"},
"questioned":	{"VBD","VBN"},
"questioner":	{"NN"},
"questioners":	{"NNS"},
"questioning":	{"VBG","NN","JJ"},
"questioningly":	{"RB"},
"questionnaire":	{"NN"},
"questionnaires":	{"NNS"},
"questions":	{"NNS","VBZ"},
"quests":	{"NNS","VBZ"},
"quetch":	{"VB","VBP"},
"quetzal":	{"NN"},
"queue":	{"NN","VB","VBP"},
"queued":	{"VBD","VBN"},
"queues":	{"NNS","VBZ"},
"queuing":	{"VBG"},
"qui":	{"FW"},
"quib":	{"NN"},
"quibble":	{"VB","VBP","NN"},
"quibbled":	{"VBD","VBN"},
"quibbler":	{"NN"},
"quibblers":	{"NNS"},
"quibbles":	{"VBZ","NNS"},
"quibblesome":	{"JJ"},
"quibbling":	{"JJ","NN","VBG"},
"quibblingly":	{"RB"},
"quibs":	{"NNS"},
"quibusdam":	{"FW"},
"quiche":	{"NN"},
"quiches":	{"NNS"},
"quick":	{"JJ","NN","RB","UH"},
"quick-change":	{"JJ"},
"quick-drying":	{"JJ"},
"quick-eared":	{"JJ"},
"quick-fire":	{"JJ"},
"quick-freeze":	{"VB","VBP"},
"quick-freezes":	{"VBZ"},
"quick-freezing":	{"VBG"},
"quick-froze":	{"VBD"},
"quick-frozen":	{"VBN"},
"quick-handling":	{"JJ"},
"quick-kill":	{"JJ"},
"quick-release":	{"JJ"},
"quick-service":	{"JJ"},
"quick-sighted":	{"JJ"},
"quick-tempered":	{"JJ"},
"quick-witted":	{"JJ"},
"quick-wittedness":	{"NN"},
"quicken":	{"VB","VBP"},
"quickened":	{"VBD","VBN"},
"quickener":	{"NN"},
"quickening":	{"NN","VBG"},
"quickens":	{"VBZ"},
"quicker":	{"JJR","RBR"},
"quickest":	{"JJS","RBS"},
"quickie":	{"NN","JJ"},
"quickies":	{"NNS"},
"quicklime":	{"NN"},
"quickly":	{"RB"},
"quickness":	{"NN"},
"quicksand":	{"NN"},
"quicksands":	{"NNS"},
"quickset":	{"JJ","NN"},
"quicksilver":	{"NN","JJ"},
"quickstep":	{"NN"},
"quicksteps":	{"NNS"},
"quicky":	{"NN"},
"quid":	{"NN","NNS","FW"},
"quiddity":	{"NN"},
"quidnunc":	{"NN"},
"quids":	{"NNS"},
"quiesce":	{"VB","VBP"},
"quiesced":	{"VBD","VBN"},
"quiescence":	{"NN"},
"quiescency":	{"NN"},
"quiescent":	{"JJ"},
"quiesces":	{"VBZ"},
"quiescing":	{"VBG"},
"quiet":	{"JJ","NN","VB","VBP"},
"quieted":	{"VBD","VBN"},
"quieten":	{"VB","VBP"},
"quietened":	{"VBD","VBN"},
"quietening":	{"VBG"},
"quietens":	{"VBZ"},
"quieter":	{"JJR"},
"quietest":	{"JJS"},
"quieting":	{"VBG"},
"quietism":	{"NN"},
"quietist":	{"NN"},
"quietists":	{"NNS"},
"quietly":	{"RB"},
"quietness":	{"NN"},
"quiets":	{"VBZ"},
"quietude":	{"NN"},
"quietus":	{"NN"},
"quiff":	{"NN"},
"quiffs":	{"NNS"},
"quigley":	{"NN"},
"quill":	{"NN","VB","VBP"},
"quill-pen":	{"NN"},
"quilled":	{"VBD","VBN"},
"quilling":	{"VBG"},
"quills":	{"NNS","VBZ"},
"quillwort":	{"NN"},
"quilt":	{"NN","VB","VBP"},
"quilted":	{"JJ","VBD","VBN"},
"quilting":	{"NN","VBG"},
"quilts":	{"NNS","VBZ"},
"quin":	{"NN"},
"quinacrine":	{"NN"},
"quince":	{"NN"},
"quincentenary":	{"NN"},
"quincentennial":	{"NN"},
"quine":	{"NN"},
"quinidex":	{"NN"},
"quinidine":	{"NN"},
"quinine":	{"NN"},
"quinolone":	{"NN"},
"quinone":	{"NN"},
"quinora":	{"NN"},
"quinquefoliate":	{"JJ"},
"quinquennium":	{"NN"},
"quinsy":	{"NN"},
"quint":	{"NN"},
"quintal":	{"NN"},
"quintessence":	{"NN"},
"quintessential":	{"JJ"},
"quintessentially":	{"RB"},
"quintet":	{"NN"},
"quintets":	{"NNS"},
"quintette":	{"NN"},
"quintillion":	{"CD","PRP"},
"quintillionth":	{"JJ","NN"},
"quintipara":	{"NN"},
"quintuple":	{"JJ","NN","VB","VBP"},
"quintupled":	{"VBD","VBN"},
"quintuples":	{"VBZ"},
"quintuplet":	{"NN"},
"quintupling":	{"VBG"},
"quip":	{"NN","VB","VBP"},
"quipped":	{"VBD","VBN"},
"quipping":	{"VBG"},
"quips":	{"NNS","VBZ"},
"quipu":	{"NN"},
"quira":	{"NN"},
"quire":	{"NN"},
"quires":	{"NNS"},
"quirk":	{"NN"},
"quirkier":	{"JJR"},
"quirkiest":	{"JJS"},
"quirkily":	{"RB"},
"quirkiness":	{"NN"},
"quirking":	{"VBG"},
"quirks":	{"NNS"},
"quirky":	{"JJ"},
"quirt":	{"NN","VB","VBP"},
"quiscalus":	{"NN"},
"quisling":	{"NN"},
"quislingism":	{"NN"},
"quislings":	{"NNS"},
"quit":	{"VB","VBD","VBP","VBN","JJ"},
"quitclaim":	{"NN","VB","VBP"},
"quite":	{"RB","PDT"},
"quits":	{"JJ","VBZ"},
"quittance":	{"NN"},
"quitted":	{"VBD","VBN"},
"quitter":	{"NN"},
"quitters":	{"NNS"},
"quitting":	{"VBG"},
"quiver":	{"VB","VBP","NN"},
"quivered":	{"VBD","VBN"},
"quivering":	{"VBG"},
"quivers":	{"NNS","VBZ"},
"quixotic":	{"JJ"},
"quixotically":	{"RB"},
"quixotism":	{"NN"},
"quiz":	{"NN","VB","VBP"},
"quizmaster":	{"NN"},
"quizmasters":	{"NNS"},
"quizzed":	{"VBD","VBN"},
"quizzer":	{"NN"},
"quizzers":	{"NNS"},
"quizzes":	{"NNS","VBZ"},
"quizzical":	{"JJ"},
"quizzically":	{"RB"},
"quizzing":	{"VBG"},
"qum":	{"NN"},
"quo":	{"NN","FW"},
"quodlibet":	{"NN"},
"quoin":	{"NN"},
"quoit":	{"NN"},
"quoits":	{"NNS"},
"quok":	{"FW"},
"quondam":	{"JJ"},
"quoratean":	{"NN"},
"quorum":	{"NN"},
"quos":	{"NNS"},
"quota":	{"NN"},
"quotability":	{"NN"},
"quotable":	{"JJ"},
"quotas":	{"NNS"},
"quotation":	{"NN"},
"quotations":	{"NNS"},
"quote":	{"VB","NN","VBP"},
"quoted":	{"VBN","VBD"},
"quoter":	{"NN"},
"quoters":	{"NNS"},
"quotes":	{"NNS","VBZ"},
"quotidian":	{"JJ"},
"quotient":	{"NN"},
"quotients":	{"NNS"},
"quoting":	{"VBG","NN"},
"qurush":	{"NN"},
"quyney":	{"NN"},
"r":	{"NN","SYM","LS"},
"r.c.":	{"JJ"},
"r.p.m.":	{"NNS"},
"ra":	{"NN"},
"rabato":	{"NN"},
"rabatos":	{"NNS"},
"rabbet":	{"NN","VB","VBP"},
"rabbeted":	{"VBD","VBN"},
"rabbeting":	{"VBG"},
"rabbets":	{"NNS","VBZ"},
"rabbi":	{"NN"},
"rabbinate":	{"NN"},
"rabbinic":	{"JJ"},
"rabbinical":	{"JJ"},
"rabbinically":	{"RB"},
"rabbis":	{"NNS"},
"rabbit":	{"NN","VBP","VB"},
"rabbit-hutch":	{"NN"},
"rabbit-warren":	{"NN"},
"rabbit-warrens":	{"NNS"},
"rabbited":	{"VBD","VBN"},
"rabbiteye":	{"NN"},
"rabbitfish":	{"NN"},
"rabbiting":	{"VBG"},
"rabbits":	{"NNS","VBZ"},
"rabbitwood":	{"NN"},
"rabble":	{"NN"},
"rabble-rouser":	{"NN"},
"rabble-rousers":	{"NNS"},
"rabble-rousing":	{"NN","JJ"},
"rabid":	{"JJ"},
"rabidity":	{"NN"},
"rabidness":	{"NN"},
"rabies":	{"NN"},
"raccoon":	{"NN"},
"raccoons":	{"NNS"},
"race":	{"NN","VB","VBP"},
"race-based":	{"JJ"},
"race-driver":	{"NN"},
"race-drivers":	{"NNS"},
"race-goer":	{"NN"},
"race-goers":	{"NNS"},
"race-meeting":	{"NN"},
"race-meetings":	{"NNS"},
"race-riot":	{"NN"},
"race-riots":	{"NNS"},
"race-track":	{"NN"},
"race-tracks":	{"NNS"},
"raceabout":	{"NN"},
"racecar":	{"NN"},
"racecard":	{"NN"},
"racecards":	{"NNS"},
"racecars":	{"NNS"},
"racecourse":	{"NN"},
"racecourses":	{"NNS"},
"raced":	{"VBD","VBN"},
"racegoer":	{"NN"},
"racegoers":	{"NNS"},
"racehorse":	{"NN"},
"racehorses":	{"NNS"},
"raceme":	{"NN"},
"racemisation":	{"NN"},
"racemise":	{"VB","VBP"},
"racemised":	{"VBD","VBN"},
"racemises":	{"VBZ"},
"racemising":	{"VBG"},
"racemization":	{"NN"},
"racemize":	{"VB","VBP"},
"racemized":	{"VBD","VBN"},
"racemizes":	{"VBZ"},
"racemizing":	{"VBG"},
"racemose":	{"JJ"},
"racer":	{"NN"},
"racers":	{"NNS"},
"racerunner":	{"NN"},
"races":	{"NNS","VBZ"},
"racetam":	{"NN"},
"racetams":	{"NNS"},
"racetrack":	{"NN"},
"racetracks":	{"NNS"},
"raceway":	{"NN"},
"rachis":	{"NN"},
"rachischisis":	{"NN"},
"rachitic":	{"JJ"},
"rachitis":	{"NN"},
"rachmaninov":	{"NN"},
"rachycentridae":	{"NN"},
"rachycentron":	{"NN"},
"racial":	{"JJ"},
"racialisation":	{"NN"},
"racialise":	{"VB","VBP"},
"racialised":	{"VBD","VBN"},
"racialises":	{"VBZ"},
"racialising":	{"VBG"},
"racialism":	{"NN"},
"racialist":	{"NN","JJ"},
"racialists":	{"NNS"},
"racialization":	{"NN"},
"racialize":	{"VB","VBP"},
"racialized":	{"VBD","VBN"},
"racializes":	{"VBZ"},
"racializing":	{"VBG"},
"racially":	{"RB"},
"racier":	{"JJR"},
"raciest":	{"JJS"},
"racily":	{"RB"},
"raciness":	{"NN"},
"racing":	{"NN","VBG","JJ"},
"racism":	{"NN"},
"racist":	{"JJ","NN"},
"racists":	{"NNS"},
"rack":	{"NN","VB","VBP"},
"rack-railway":	{"NN"},
"rack-rent":	{"NN","VB","VBP"},
"rack-rented":	{"VBD","VBN"},
"rack-renting":	{"VBG"},
"rack-rents":	{"NNS","VBZ"},
"racked":	{"VBN","VBD"},
"racker":	{"NN"},
"racket":	{"NN","VB","VBP"},
"racketed":	{"VBD","VBN"},
"racketeer":	{"NN","VB","VBP"},
"racketeered":	{"VBD","VBN"},
"racketeering":	{"NN","VBG"},
"racketeers":	{"NNS","VBZ"},
"racketiness":	{"NN"},
"racketing":	{"VBG"},
"rackets":	{"NNS","VBZ"},
"rackety":	{"JJ"},
"racking":	{"JJ","VBG"},
"racks":	{"VBZ","NNS"},
"racon":	{"NN"},
"raconteur":	{"NN"},
"raconteurs":	{"NNS"},
"racoon":	{"NN"},
"racoons":	{"NNS"},
"racquet":	{"NN"},
"racquetball":	{"NN"},
"racquets":	{"NNS"},
"racy":	{"JJ"},
"rad":	{"NN","JJ"},
"radar":	{"NN"},
"radars":	{"NNS"},
"raddle":	{"NN","VB","VBP"},
"raddled":	{"JJ","VBD","VBN"},
"raddles":	{"VBZ"},
"raddling":	{"VBG"},
"radial":	{"NN","JJ"},
"radial-ply":	{"JJ"},
"radially":	{"RB"},
"radials":	{"NNS"},
"radian":	{"NN"},
"radiance":	{"NN"},
"radiancy":	{"NN"},
"radiant":	{"JJ"},
"radiantly":	{"RB"},
"radiate":	{"VB","VBP"},
"radiated":	{"VBD","VBN"},
"radiates":	{"VBZ"},
"radiating":	{"VBG"},
"radiation":	{"NN"},
"radiations":	{"NNS"},
"radiative":	{"JJ"},
"radiator":	{"NN"},
"radiators":	{"NNS"},
"radical":	{"JJ","NN"},
"radicalisation":	{"NN"},
"radicalise":	{"VB","VBP"},
"radicalised":	{"VBD","VBN"},
"radicalises":	{"VBZ"},
"radicalising":	{"VBG"},
"radicalism":	{"NN"},
"radicalization":	{"NN"},
"radicalize":	{"VB","VBP"},
"radicalized":	{"VBD","VBN"},
"radicalizes":	{"VBZ"},
"radicalizing":	{"VBG"},
"radically":	{"RB"},
"radicals":	{"NNS"},
"radicchio":	{"NN"},
"radicle":	{"NN"},
"radiculitis":	{"NN"},
"radii":	{"NNS"},
"radiigera":	{"NN"},
"radio":	{"NN","VB","VBP"},
"radio-controlled":	{"JJ"},
"radio-opacity":	{"NN"},
"radio-opaque":	{"JJ"},
"radio-pharmaceutical":	{"JJ"},
"radio-phonograph":	{"NN"},
"radio-station":	{"NN"},
"radio-transmitter":	{"NN"},
"radioactive":	{"JJ"},
"radioactively":	{"RB"},
"radioactivity":	{"NN"},
"radiobiologist":	{"NN"},
"radiobiology":	{"NN"},
"radiocarbon":	{"NN"},
"radiochemist":	{"NN"},
"radiochemistry":	{"NN"},
"radiochlorine":	{"NN"},
"radioclast":	{"NN"},
"radiocommunication":	{"NN"},
"radioed":	{"VBD","VBN"},
"radiogram":	{"NN"},
"radiograms":	{"NNS"},
"radiograph":	{"NN","VB","VBP"},
"radiographed":	{"VBD","VBN"},
"radiographer":	{"NN"},
"radiographers":	{"NNS"},
"radiographic":	{"JJ"},
"radiographing":	{"VBG"},
"radiographs":	{"NNS","VBZ"},
"radiography":	{"NN"},
"radioimmunoassay":	{"NN"},
"radioing":	{"VBG"},
"radioisotope":	{"NN"},
"radiolaria":	{"NN"},
"radiolarian":	{"NN"},
"radiolocate":	{"VB"},
"radiolocation":	{"NN"},
"radiological":	{"JJ"},
"radiologist":	{"NN"},
"radiologists":	{"NNS"},
"radiology":	{"NN"},
"radiolucent":	{"JJ"},
"radiolysis":	{"NN"},
"radioman":	{"NN"},
"radiomen":	{"NNS"},
"radiometer":	{"NN"},
"radiomicrometer":	{"NN"},
"radionic":	{"JJ"},
"radiopacity":	{"NN"},
"radiopaque":	{"JJ"},
"radiopasteurization":	{"NN"},
"radiopharmaceutical":	{"JJ","NN"},
"radiophone":	{"NN"},
"radiophonic":	{"JJ"},
"radiophoto":	{"NN"},
"radiophotograph":	{"NN"},
"radiophotography":	{"NN"},
"radioprotection":	{"NN"},
"radios":	{"NNS","VBZ"},
"radioscopy":	{"NN"},
"radiosensitive":	{"JJ"},
"radiosensitivity":	{"NN"},
"radiosterilization":	{"NN"},
"radiosterilize":	{"VB","VBP"},
"radiosterilized":	{"VBD","VBN"},
"radiosterilizes":	{"VBZ"},
"radiosterilizing":	{"VBG"},
"radiotelegraph":	{"NN"},
"radiotelegraphy":	{"NN"},
"radiotelephone":	{"NN"},
"radiotelephonic":	{"JJ"},
"radiotelephony":	{"NN"},
"radiotherapist":	{"NN"},
"radiotherapists":	{"NNS"},
"radiotherapy":	{"NN"},
"radiothorium":	{"NN"},
"radish":	{"NN"},
"radishes":	{"NNS"},
"radium":	{"NN"},
"radius":	{"NN"},
"radix":	{"NN"},
"radome":	{"NN"},
"radon":	{"NN"},
"rads":	{"NNS"},
"radyera":	{"NN"},
"raetam":	{"NN"},
"raffia":	{"NN"},
"raffinose":	{"NN"},
"raffish":	{"JJ"},
"raffishly":	{"RB"},
"raffishness":	{"NN"},
"raffle":	{"NN","VB","VBP"},
"raffled":	{"VBD","VBN"},
"raffles":	{"NNS","VBZ"},
"rafflesiaceae":	{"NN"},
"raffling":	{"VBG"},
"raft":	{"NN","VB","VBP"},
"rafted":	{"VBD","VBN"},
"rafter":	{"NN"},
"raftered":	{"JJ"},
"rafters":	{"NNS"},
"rafting":	{"NN","VBG"},
"rafts":	{"NNS","VBZ"},
"raftsman":	{"NN"},
"raftsmen":	{"NNS"},
"rag":	{"NN","VB","VBP"},
"rag-bag":	{"NN"},
"rag-tag":	{"NN","JJ"},
"ragamuffin":	{"NN"},
"ragamuffins":	{"NNS"},
"ragbag":	{"NN"},
"rage":	{"NN","VB","VBP"},
"raged":	{"VBD","VBN"},
"rages":	{"NNS","VBZ"},
"ragged":	{"JJ","VBD","VBN"},
"raggedly":	{"RB"},
"raggedness":	{"NN"},
"ragging":	{"VBG"},
"ragi":	{"NN"},
"raging":	{"VBG","JJ"},
"raglan":	{"NN","JJ"},
"ragnarok":	{"NN"},
"ragout":	{"NN"},
"ragouts":	{"NNS"},
"ragpicker":	{"NN"},
"rags":	{"NNS","VBZ"},
"ragsorter":	{"NN"},
"ragtag":	{"NN","JJ"},
"ragtime":	{"NN"},
"ragu":	{"NN"},
"ragusa":	{"NN"},
"ragweed":	{"NN"},
"ragwort":	{"NN"},
"rahu":	{"NN"},
"raid":	{"NN","VB","VBP"},
"raided":	{"VBD","VBN"},
"raider":	{"NN"},
"raiders":	{"NNS"},
"raiding":	{"VBG"},
"raids":	{"NNS","VBZ"},
"rail":	{"NN","VB","VBP"},
"rail-car":	{"NN"},
"railbed":	{"NN"},
"railbike":	{"NN"},
"railbiker":	{"NN"},
"railbikers":	{"NNS"},
"railbikes":	{"NNS"},
"railbiking":	{"NN"},
"railbird":	{"NN"},
"railbirds":	{"NNS"},
"railcar":	{"NN"},
"railcars":	{"NNS"},
"railed":	{"VBD","VBN"},
"railhead":	{"NN"},
"railheads":	{"NNS"},
"railing":	{"NN","VBG"},
"railings":	{"NNS"},
"raillery":	{"NN"},
"railroad":	{"NN","VBP","VB"},
"railroaded":	{"VBD","VBN"},
"railroader":	{"NN"},
"railroaders":	{"NNS"},
"railroading":	{"NN","VBG"},
"railroads":	{"NNS","VBZ"},
"rails":	{"NNS","VBZ"},
"railway":	{"NN"},
"railwayman":	{"NN"},
"railwaymen":	{"NNS"},
"railways":	{"NNS"},
"railyard":	{"NN"},
"raiment":	{"NN"},
"raimentless":	{"JJ"},
"rain":	{"NN","VB","VBP"},
"rain-wash":	{"NN"},
"rainbow":	{"NN"},
"rainbows":	{"NNS"},
"raincoat":	{"NN"},
"raincoats":	{"NNS"},
"raindrop":	{"NN"},
"raindrops":	{"NNS"},
"rained":	{"VBD","VBN"},
"rainfall":	{"NN"},
"rainflies":	{"NNS"},
"rainfly":	{"NN"},
"rainforest":	{"NN"},
"rainforests":	{"NNS"},
"rainier":	{"JJR"},
"rainiest":	{"JJS"},
"raininess":	{"NN"},
"raining":	{"VBG"},
"rainless":	{"JJ"},
"rainmaker":	{"NN"},
"rainmakers":	{"NNS"},
"rainmaking":	{"NN"},
"rainout":	{"NN"},
"rainproof":	{"JJ","VB","VBP"},
"rainproofed":	{"VBD","VBN"},
"rainproofing":	{"VBG"},
"rainproofs":	{"VBZ"},
"rains":	{"NNS","VBZ"},
"rainstorm":	{"NN"},
"rainstorms":	{"NNS"},
"rainwater":	{"NN"},
"rainy":	{"JJ"},
"raisable":	{"JJ"},
"raise":	{"VB","NN","VBP"},
"raiseable":	{"JJ"},
"raised":	{"VBN","VBD","JJ"},
"raiser":	{"NN"},
"raisers":	{"NNS"},
"raises":	{"VBZ","NNS"},
"raisin":	{"NN"},
"raising":	{"VBG","NN"},
"raisins":	{"NNS"},
"raison":	{"NN","FW"},
"raita":	{"NN"},
"raiu":	{"NN"},
"raja":	{"NN"},
"rajab":	{"NN"},
"rajah":	{"NN"},
"rajahs":	{"NNS"},
"rajanya":	{"NN"},
"rajidae":	{"NN"},
"rajiformes":	{"NNS"},
"rajpoot":	{"NN"},
"rajput":	{"NN"},
"rakaposhi":	{"NN"},
"rake":	{"NN","VB","VBP"},
"rake-off":	{"NN"},
"rake-offs":	{"NNS"},
"raked":	{"VBD","VBN","JJ"},
"rakehell":	{"NN"},
"rakes":	{"NNS","VBZ"},
"raking":	{"VBG"},
"rakish":	{"JJ"},
"rakishly":	{"RB"},
"rakishness":	{"NN"},
"raku":	{"NN"},
"rale":	{"NN"},
"ralegh":	{"NN"},
"rallentandi":	{"NNS"},
"rallentando":	{"JJ","RB","NN"},
"rallentandos":	{"NNS"},
"rallidae":	{"NN"},
"rallied":	{"VBD","VBN"},
"rallies":	{"NNS","VBZ"},
"rally":	{"NN","VB","VBP"},
"rallying":	{"VBG"},
"ralphs":	{"NN"},
"ram":	{"NN","VB","VBP"},
"ram-jet":	{"NN"},
"ramachandra":	{"NN"},
"ramalina":	{"NN"},
"ramanavami":	{"NN"},
"ramate":	{"JJ"},
"ramayana":	{"NN"},
"ramble":	{"VB","VBP","NN"},
"rambled":	{"VBD","VBN"},
"rambler":	{"NN"},
"ramblers":	{"NNS"},
"rambles":	{"VBZ","NNS"},
"rambling":	{"JJ","VBG"},
"ramblingly":	{"RB"},
"ramblings":	{"NNS"},
"rambotan":	{"NN"},
"rambouillet":	{"NN"},
"rambunctious":	{"JJ"},
"rambutan":	{"NN"},
"rameau":	{"NN"},
"ramee":	{"NN"},
"ramekin":	{"NN"},
"ramekins":	{"NNS"},
"ramequin":	{"NN"},
"rami":	{"NNS"},
"ramie":	{"NN"},
"ramification":	{"NN"},
"ramifications":	{"NNS"},
"ramified":	{"VBD","VBN"},
"ramifies":	{"VBZ"},
"ramify":	{"VB","VBP"},
"ramifying":	{"VBG"},
"ramipril":	{"NN"},
"ramjet":	{"NN"},
"ramman":	{"NN"},
"rammed":	{"VBD","VBN"},
"rammer":	{"NN"},
"rammers":	{"NNS"},
"ramming":	{"VBG"},
"ramona":	{"NN"},
"ramontchi":	{"NN"},
"ramose":	{"JJ"},
"ramous":	{"JJ"},
"ramp":	{"NN","VB","VBP"},
"rampage":	{"VB","VBP","NN"},
"rampaged":	{"VBD","VBN"},
"rampageous":	{"JJ"},
"rampages":	{"VBZ"},
"rampaging":	{"VBG"},
"rampancy":	{"NN"},
"rampant":	{"JJ"},
"rampantly":	{"RB"},
"rampart":	{"NN","VB","VBP"},
"ramparted":	{"VBD","VBN"},
"ramparting":	{"VBG"},
"ramparts":	{"NNS","VBZ"},
"ramped":	{"VBD","VBN"},
"ramphastidae":	{"NN"},
"ramphomicron":	{"NN"},
"ramping":	{"VBG"},
"rampion":	{"NN"},
"ramps":	{"VBZ","NNS"},
"ramrod":	{"NN","VB","VBP"},
"ramrodded":	{"VBD","VBN"},
"ramrodding":	{"VBG"},
"ramrods":	{"NNS","VBZ"},
"rams":	{"NNS","VBZ"},
"ramshackle":	{"JJ"},
"ramsons":	{"NNS"},
"ramus":	{"NN"},
"ran":	{"VBD"},
"rana":	{"NN"},
"ranales":	{"NNS"},
"ranatra":	{"NN"},
"ranch":	{"NN","VB","VBP"},
"ranched":	{"VBD","VBN"},
"rancher":	{"NN"},
"ranchers":	{"NNS"},
"ranches":	{"NNS","VBZ"},
"ranching":	{"NN","VBG"},
"rancho":	{"NN"},
"rancid":	{"JJ"},
"rancidity":	{"NN"},
"rancidness":	{"NN"},
"rancor":	{"NN"},
"rancorous":	{"JJ"},
"rancour":	{"NN"},
"rand":	{"NN","NNS"},
"randier":	{"JJR"},
"randiest":	{"JJS"},
"random":	{"JJ","NN"},
"random-access":	{"JJ"},
"randomisation":	{"NN"},
"randomise":	{"VB","VBP"},
"randomised":	{"VBD","VBN"},
"randomises":	{"VBZ"},
"randomising":	{"VBG"},
"randomization":	{"NN"},
"randomize":	{"VB","VBP"},
"randomized":	{"VBD","VBN"},
"randomizes":	{"VBZ"},
"randomizing":	{"VBG"},
"randomly":	{"RB"},
"randomness":	{"NN"},
"rands":	{"NNS"},
"randy":	{"JJ"},
"ranee":	{"NN"},
"rang":	{"VBD"},
"range":	{"NN","VBP","VB"},
"ranged":	{"VBD","VBN"},
"rangefinder":	{"NN"},
"rangefinders":	{"NNS"},
"rangeland":	{"NN"},
"rangelands":	{"NNS"},
"ranger":	{"NN"},
"rangers":	{"NNS"},
"ranges":	{"NNS","VBZ"},
"rangifer":	{"NN"},
"ranging":	{"VBG","NN"},
"rangpur":	{"NN"},
"rangy":	{"JJ"},
"rani":	{"NN"},
"ranid":	{"NN"},
"ranidae":	{"NN"},
"ranier":	{"NN"},
"ranitidine":	{"NN"},
"rank":	{"NN","VB","VBP","JJ"},
"rank-and-file":	{"JJ","NN"},
"rank-smelling":	{"JJ"},
"ranked":	{"VBD","VBN"},
"ranker":	{"JJR"},
"rankest":	{"JJS"},
"rankin":	{"NN"},
"rankine":	{"NN"},
"ranking":	{"NN","JJ","VBG"},
"rankings":	{"NNS"},
"rankle":	{"VB","VBP"},
"rankled":	{"VBD","VBN"},
"rankles":	{"VBZ"},
"rankling":	{"VBG"},
"rankness":	{"NN"},
"ranks":	{"NNS","VBZ"},
"ransack":	{"VB","VBP"},
"ransacked":	{"VBD","VBN"},
"ransacking":	{"VBG","NN"},
"ransacks":	{"VBZ"},
"ransom":	{"NN","VB","VBP"},
"ransomed":	{"VBD","VBN"},
"ransoming":	{"VBG"},
"ransoms":	{"NNS","VBZ"},
"rant":	{"VB","VBP","NN"},
"rantankerous":	{"JJ"},
"ranted":	{"VBD","VBN"},
"ranter":	{"NN"},
"ranters":	{"NNS"},
"ranting":	{"NN","VBG"},
"rantings":	{"NNS"},
"rants":	{"VBZ","NNS"},
"ranula":	{"NN"},
"ranunculaceae":	{"NN"},
"ranunculales":	{"NNS"},
"ranunculus":	{"NN"},
"raoul":	{"NN"},
"raoulia":	{"NN"},
"rap":	{"NN","VB","VBP"},
"rapacious":	{"JJ"},
"rapaciously":	{"RB"},
"rapaciousness":	{"NN"},
"rapacity":	{"NN"},
"rapateaceae":	{"NN"},
"rape":	{"VB","VBP","NN"},
"raped":	{"VBD","VBN"},
"raper":	{"NN"},
"rapers":	{"NNS"},
"rapes":	{"NNS","VBZ"},
"rapeseed":	{"NN"},
"rapeseeds":	{"NNS"},
"raphanus":	{"NN"},
"raphe":	{"NN"},
"raphia":	{"NN"},
"raphicerus":	{"NN"},
"raphidae":	{"NN"},
"raphidiidae":	{"NN"},
"raphus":	{"NN"},
"rapid":	{"JJ"},
"rapid-fire":	{"JJ"},
"rapid-transit":	{"JJ"},
"rapidement":	{"FW"},
"rapidity":	{"NN"},
"rapidly":	{"RB"},
"rapidness":	{"NN"},
"rapids":	{"NNS"},
"rapier":	{"NN"},
"rapier-thrust":	{"NN"},
"rapiers":	{"NNS"},
"rapine":	{"NN"},
"raping":	{"VBG"},
"rapist":	{"NN"},
"rapists":	{"NNS"},
"rapped":	{"VBD","VBN"},
"rappee":	{"NN"},
"rappel":	{"VB","VBP","NN"},
"rappelled":	{"VBD","VBN"},
"rappeller":	{"NN"},
"rappelling":	{"VBG"},
"rappels":	{"VBZ","NNS"},
"rapper":	{"NN"},
"rappers":	{"NNS"},
"rapping":	{"VBG"},
"rapport":	{"NN"},
"rapporteur":	{"NN"},
"rapporteurs":	{"NNS"},
"rapprochement":	{"NN"},
"raps":	{"NNS","VBZ"},
"rapscallion":	{"NN"},
"rapt":	{"JJ"},
"raptly":	{"RB"},
"raptor":	{"NN"},
"raptorial":	{"JJ"},
"raptors":	{"NNS"},
"rapture":	{"NN","VB","VBP"},
"raptured":	{"VBD","VBN"},
"raptures":	{"NNS","VBZ"},
"rapturing":	{"VBG"},
"rapturous":	{"JJ"},
"rapturously":	{"RB"},
"raptus":	{"NN"},
"raptuses":	{"NNS"},
"rare":	{"JJ"},
"rarebit":	{"NN"},
"raree-show":	{"NN"},
"rarefaction":	{"NN"},
"rarefied":	{"VBD","VBN","JJ"},
"rarefies":	{"VBZ"},
"rarefy":	{"VB","VBP"},
"rarefying":	{"VBG"},
"rarely":	{"RB"},
"rareness":	{"NN"},
"rarer":	{"JJR"},
"rarest":	{"JJS"},
"rarified":	{"VBD","VBN"},
"rarifis":	{"VBZ"},
"rarify":	{"VB","VBP"},
"rarifying":	{"VBG"},
"raring":	{"JJ"},
"rariora":	{"NN"},
"rarities":	{"NNS"},
"rarity":	{"NN"},
"rasa":	{"NN","FW"},
"rascal":	{"NN"},
"rascality":	{"NN"},
"rascally":	{"JJ","RB"},
"rascals":	{"NNS"},
"rase":	{"VB","VBP"},
"rased":	{"VBD","VBN"},
"rases":	{"VBZ"},
"rash":	{"NN","JJ"},
"rasher":	{"NN","JJR"},
"rashers":	{"NNS"},
"rashes":	{"NNS"},
"rashest":	{"JJS"},
"rashly":	{"RB"},
"rashness":	{"NN"},
"rasht":	{"NN"},
"rasing":	{"VBG"},
"rask":	{"NN"},
"raskolnikov":	{"NN"},
"rasmussen":	{"NN"},
"rasp":	{"NN","VB","VBP"},
"raspberries":	{"NNS","VBZ"},
"raspberry":	{"NN"},
"rasped":	{"VBD","VBN"},
"rasping":	{"JJ","VBG"},
"raspingly":	{"RB"},
"rasps":	{"NNS","VBZ"},
"raspy":	{"JJ"},
"rassling":	{"NN"},
"rastafari":	{"NN"},
"raster":	{"NN"},
"rasterise":	{"VB","VBP"},
"rasterize":	{"VB","VBP"},
"rat":	{"NN","VB","VBP"},
"rat-a-tat":	{"NN"},
"rat-a-tat-tat":	{"NN"},
"rat-catcher":	{"NN"},
"rat-tat":	{"NN"},
"rata":	{"FW","JJ","NN"},
"ratability":	{"NN"},
"ratable":	{"JJ"},
"ratafee":	{"NN"},
"ratafia":	{"NN"},
"ratan":	{"NN"},
"rataplan":	{"NN"},
"ratatouille":	{"NN"},
"ratbag":	{"NN"},
"ratbags":	{"NNS"},
"ratch":	{"NN"},
"ratchet":	{"NN","VB","VBP"},
"ratcheted":	{"VBD","VBN"},
"ratcheting":	{"VBG"},
"ratchets":	{"NNS","VBZ"},
"rate":	{"NN","VB","VBP"},
"rate-cap":	{"VB","VBP"},
"rate-capped":	{"VBD","VBN"},
"rate-capping":	{"VBG","NN"},
"rate-caps":	{"VBZ"},
"rate-of-return":	{"JJ"},
"rateability":	{"NN"},
"rateable":	{"JJ"},
"rated":	{"VBN","VBD"},
"ratel":	{"NN"},
"ratepayer":	{"NN"},
"ratepayers":	{"NNS"},
"rates":	{"NNS","VBZ"},
"ratfink":	{"NN"},
"ratfinks":	{"NNS"},
"rather":	{"RB","UH"},
"rathole":	{"NN"},
"ratholes":	{"NNS"},
"rathskeller":	{"NN"},
"rathskellers":	{"NNS"},
"ratibida":	{"NN"},
"ratification":	{"NN"},
"ratifications":	{"NNS"},
"ratified":	{"VBD","VBN"},
"ratifier":	{"NN"},
"ratifiers":	{"NNS"},
"ratifies":	{"VBZ"},
"ratify":	{"VB","VBP"},
"ratifying":	{"VBG"},
"rating":	{"NN","VBG"},
"ratings":	{"NNS"},
"ratio":	{"NN"},
"ratiocinate":	{"VB","VBP"},
"ratiocinated":	{"VBD","VBN"},
"ratiocinates":	{"VBZ"},
"ratiocinating":	{"VBG"},
"ratiocination":	{"NN"},
"ratiocinative":	{"JJ"},
"ratiocinator":	{"NN"},
"ration":	{"NN","VB","VBP"},
"rational":	{"JJ"},
"rationale":	{"NN"},
"rationales":	{"NNS"},
"rationalisation":	{"NN"},
"rationalisations":	{"NNS"},
"rationalise":	{"VB","VBP"},
"rationalised":	{"VBD","VBN"},
"rationalises":	{"VBZ"},
"rationalising":	{"VBG"},
"rationalism":	{"NN"},
"rationalist":	{"NN","JJ"},
"rationalistic":	{"JJ"},
"rationalists":	{"NNS"},
"rationality":	{"NN"},
"rationalization":	{"NN"},
"rationalizations":	{"NNS"},
"rationalize":	{"VB","VBP"},
"rationalized":	{"VBD","VBN"},
"rationalizes":	{"VBZ"},
"rationalizing":	{"VBG"},
"rationally":	{"RB"},
"rationalness":	{"NN"},
"rationed":	{"VBD","VBN"},
"rationing":	{"NN","VBG"},
"rations":	{"VBZ","NNS"},
"ratios":	{"NNS"},
"ratitae":	{"NN"},
"ratite":	{"NN"},
"ratlike":	{"JJ"},
"ratlin":	{"NN"},
"ratline":	{"NN"},
"ratlines":	{"NNS"},
"rats":	{"VBZ","NNS","UH"},
"ratsbane":	{"NN"},
"rattail":	{"JJ","NN"},
"rattailed":	{"JJ"},
"rattan":	{"NN"},
"rattans":	{"NNS"},
"ratted":	{"VBD","VBN"},
"ratter":	{"NN"},
"ratters":	{"NNS"},
"rattier":	{"JJR"},
"rattiest":	{"JJS"},
"ratting":	{"VBG"},
"rattle":	{"VB","VBP","NN"},
"rattlebox":	{"NN"},
"rattlebrained":	{"JJ"},
"rattled":	{"VBD","VBN","JJ"},
"rattlepated":	{"JJ"},
"rattler":	{"NN"},
"rattlers":	{"NNS"},
"rattles":	{"VBZ","NNS"},
"rattlesnake":	{"NN"},
"rattlesnakes":	{"NNS"},
"rattling":	{"VBG","JJ","NN","RB"},
"rattrap":	{"NN"},
"rattus":	{"NN"},
"ratty":	{"JJ"},
"raucous":	{"JJ"},
"raucously":	{"RB"},
"raucousness":	{"NN"},
"raudixin":	{"NN"},
"raunch":	{"NN"},
"raunchier":	{"JJR"},
"raunchiest":	{"JJS"},
"raunchily":	{"RB"},
"raunchiness":	{"NN"},
"raunchy":	{"JJ"},
"rauvolfia":	{"NN"},
"rauwolfia":	{"NN"},
"ravage":	{"VB","VBP","NN"},
"ravaged":	{"VBD","VBN"},
"ravagement":	{"NN"},
"ravager":	{"NN"},
"ravages":	{"VBZ","NNS"},
"ravaging":	{"VBG"},
"rave":	{"VB","VBP","NN","JJ"},
"raved":	{"VBD","VBN"},
"ravehook":	{"NN"},
"ravel":	{"VB","VBP"},
"raveled":	{"VBD","VBN"},
"raveling":	{"VBG"},
"ravelled":	{"VBD","VBN"},
"ravelling":	{"VBG"},
"ravels":	{"VBZ"},
"raven":	{"NN","JJ","VBP","VB"},
"ravenala":	{"NN"},
"ravened":	{"VBD","VBN"},
"ravening":	{"JJ","VBG"},
"ravenna":	{"NN"},
"ravenous":	{"JJ"},
"ravenously":	{"RB"},
"ravenousness":	{"NN"},
"ravens":	{"NNS","VBZ"},
"raver":	{"NN"},
"ravers":	{"NNS"},
"raves":	{"VBZ","NNS"},
"ravigote":	{"NN"},
"ravigotte":	{"NN"},
"ravine":	{"NN"},
"ravines":	{"NNS"},
"raving":	{"JJ","RB","VBG"},
"ravingly":	{"RB"},
"ravings":	{"NNS"},
"ravioli":	{"NN"},
"raviolis":	{"NNS"},
"ravish":	{"VB","VBP"},
"ravished":	{"VBD","VBN"},
"ravisher":	{"NN"},
"ravishes":	{"VBZ"},
"ravishing":	{"JJ","VBG"},
"ravishingly":	{"RB"},
"ravishment":	{"NN"},
"raw":	{"JJ","NN"},
"raw-boned":	{"JJ"},
"rawalpindi":	{"NN"},
"rawboned":	{"JJ"},
"rawhide":	{"NN"},
"rawness":	{"NN"},
"ray":	{"NN","VB","VBP"},
"rayed":	{"VBD","VBN"},
"raying":	{"VBG"},
"rayleigh":	{"NN"},
"rayless":	{"JJ"},
"rayon":	{"NN"},
"rayons":	{"NNS"},
"rays":	{"NNS","VBZ"},
"razbliuto":	{"NN"},
"raze":	{"VB","VBP"},
"razed":	{"VBD","VBN"},
"razes":	{"VBZ"},
"razing":	{"VBG"},
"razmataz":	{"NN"},
"razor":	{"NN","VB","VBP"},
"razor-backed":	{"JJ"},
"razor-cut":	{"VB","VBP","VBD","VBN"},
"razor-cuts":	{"VBZ"},
"razor-cutting":	{"VBG"},
"razor-edged":	{"JJ"},
"razor-fish":	{"NN"},
"razor-sharp":	{"JJ"},
"razor-thin":	{"JJ"},
"razorback":	{"NN"},
"razorbill":	{"NN"},
"razorblade":	{"NN"},
"razored":	{"VBD","VBN"},
"razoring":	{"VBG"},
"razors":	{"NNS","VBZ"},
"razz":	{"VB","VBP","NN"},
"razzamatazz":	{"NN"},
"razzed":	{"VBD","VBN"},
"razzes":	{"VBZ"},
"razzing":	{"VBG"},
"razzle":	{"NN"},
"razzle-dazzle":	{"NN"},
"razzmatazz":	{"NN"},
"rb":	{"NN"},
"rbc":	{"NN"},
"rbi":	{"NN"},
"rcmp":	{"NN"},
"rdw":	{"NN"},
"rdws":	{"NN"},
"re":	{"IN","NN","JJ"},
"re-argue":	{"VB","VBP"},
"re-argued":	{"VBD","VBN"},
"re-argues":	{"VBZ"},
"re-arguing":	{"VBG"},
"re-arm":	{"VB","VBP"},
"re-armed":	{"VBD","VBN"},
"re-arming":	{"VBG"},
"re-arms":	{"VBZ"},
"re-create":	{"VB","VBP"},
"re-created":	{"VBD","VBN"},
"re-creates":	{"VBZ"},
"re-creating":	{"VBG"},
"re-creation":	{"NN"},
"re-creations":	{"NNS"},
"re-echo":	{"VB","VBP","NN"},
"re-echoed":	{"VBD","VBN"},
"re-echoes":	{"VBZ","NNS"},
"re-echoing":	{"VBG"},
"re-edit":	{"VB","VBP"},
"re-edited":	{"VBD","VBN"},
"re-editing":	{"VBG"},
"re-edition":	{"NN"},
"re-edits":	{"VBZ"},
"re-educate":	{"VB","VBP"},
"re-educated":	{"VBD","VBN"},
"re-educates":	{"VBZ"},
"re-educating":	{"VBG"},
"re-education":	{"NN"},
"re-elect":	{"VB","VBP"},
"re-elected":	{"VBN","VBD"},
"re-electing":	{"VBG"},
"re-election":	{"NN"},
"re-elects":	{"VBZ"},
"re-emerge":	{"VB","VBP"},
"re-emerged":	{"VBD","VBN"},
"re-emergence":	{"NN"},
"re-emerges":	{"VBZ"},
"re-emerging":	{"VBG"},
"re-emission":	{"NN"},
"re-emissions":	{"NNS"},
"re-emit":	{"VB","VBP"},
"re-emits":	{"VBZ"},
"re-emitted":	{"VBD","VBN"},
"re-emitting":	{"VBG"},
"re-emphases":	{"NNS"},
"re-emphasis":	{"NN"},
"re-emphasise":	{"VB","VBP"},
"re-emphasised":	{"VBD","VBN"},
"re-emphasises":	{"VBZ"},
"re-emphasising":	{"VBG"},
"re-emphasize":	{"VB","VBP"},
"re-emphasized":	{"VBD","VBN"},
"re-emphasizes":	{"VBZ"},
"re-emphasizing":	{"VBG"},
"re-enact":	{"VB","VBP"},
"re-enacted":	{"VBD","VBN"},
"re-enacting":	{"VBG"},
"re-enactment":	{"NN"},
"re-enactments":	{"NNS"},
"re-enactor":	{"NN"},
"re-enacts":	{"VBZ"},
"re-energise":	{"VB","VBP"},
"re-energised":	{"VBD","VBN"},
"re-energises":	{"VBZ"},
"re-energising":	{"VBG"},
"re-energize":	{"VB","VBP"},
"re-energized":	{"VBD","VBN"},
"re-energizes":	{"VBZ"},
"re-energizing":	{"VBG"},
"re-enforce":	{"VB","VBP"},
"re-enforced":	{"VBD","VBN"},
"re-enforces":	{"VBZ"},
"re-enforcing":	{"VBG"},
"re-engineer":	{"VB","VBP"},
"re-engineered":	{"VBD","VBN"},
"re-engineering":	{"VBG","NN"},
"re-engineers":	{"VBZ"},
"re-enrol":	{"VB","VBP"},
"re-enroll":	{"VB","VBP"},
"re-enrolled":	{"VBD","VBN"},
"re-enrolling":	{"VBG"},
"re-enrollment":	{"NN"},
"re-enrollments":	{"NNS"},
"re-enrolls":	{"VBZ"},
"re-enrols":	{"VBZ"},
"re-enter":	{"VB","VBP"},
"re-entered":	{"VBD","VBN"},
"re-entering":	{"VBG"},
"re-enters":	{"VBZ"},
"re-entrance":	{"NN"},
"re-entrant":	{"JJ"},
"re-entries":	{"NNS"},
"re-entry":	{"NN"},
"re-equip":	{"VB","VBP"},
"re-equipped":	{"VBD","VBN"},
"re-equipping":	{"VBG"},
"re-equips":	{"VBZ"},
"re-establish":	{"VB","VBP"},
"re-established":	{"VBD","VBN"},
"re-establishes":	{"VBZ"},
"re-establishing":	{"VBG","JJ"},
"re-establishment":	{"NN"},
"re-evaluate":	{"VB","VBP"},
"re-evaluated":	{"VBD","VBN"},
"re-evaluates":	{"VBZ"},
"re-evaluating":	{"JJ","VBG"},
"re-evaluation":	{"NN"},
"re-examination":	{"NN"},
"re-examine":	{"VB","VBP"},
"re-examined":	{"VBD","VBN"},
"re-examines":	{"VBZ"},
"re-examining":	{"VBG"},
"re-experience":	{"VB","VBP"},
"re-experienced":	{"VBD","VBN"},
"re-experiences":	{"VBZ"},
"re-experiencing":	{"VBG"},
"re-explain":	{"VB","VBP"},
"re-explained":	{"VBD","VBN"},
"re-explaining":	{"VBG"},
"re-explains":	{"VBZ"},
"re-explore":	{"VB","VBP"},
"re-explored":	{"VBD","VBN"},
"re-explores":	{"VBZ"},
"re-exploring":	{"VBG"},
"re-export":	{"VB","VBP","NN"},
"re-exportation":	{"NN"},
"re-exported":	{"VBD","VBN"},
"re-exporter":	{"NN"},
"re-exporting":	{"VBG"},
"re-exports":	{"VBZ","NNS"},
"re-form":	{"VB","VBP"},
"re-formed":	{"VBD","VBN","JJ"},
"re-forming":	{"VBG"},
"re-forms":	{"VBZ"},
"re-offer":	{"VB","VBP","NN"},
"re-offered":	{"VBD","VBN"},
"re-offering":	{"VBG"},
"re-offers":	{"VBZ"},
"re-present":	{"VB","VBP"},
"re-presentation":	{"NN"},
"re-presented":	{"VBD","VBN"},
"re-presenting":	{"VBG"},
"re-presents":	{"VBZ"},
"re-ran":	{"VBD"},
"re-release":	{"NN","VB","VBP"},
"re-released":	{"VBD","VBN"},
"re-releases":	{"NNS","VBZ"},
"re-releasing":	{"VBG"},
"re-run":	{"NN","VB","VBP","VBN"},
"re-running":	{"VBG"},
"re-runs":	{"NNS","VBZ"},
"re-sentencing":	{"NN"},
"re-sharpening":	{"NN"},
"re-sign":	{"VB","NN","VBP","NNP"},
"reabsorb":	{"VB","VBP"},
"reabsorbed":	{"VBD","VBN"},
"reabsorbing":	{"VBG"},
"reabsorbs":	{"VBZ"},
"reabsorption":	{"NN"},
"reaccelerate":	{"VB","VBP"},
"reaccelerated":	{"VBD","VBN"},
"reaccelerates":	{"VBZ"},
"reaccelerating":	{"VBG"},
"reacceleration":	{"NN"},
"reach":	{"VB","NN","VBP"},
"reachable":	{"JJ"},
"reached":	{"VBN","VBD"},
"reaches":	{"VBZ","NNS"},
"reaching":	{"VBG"},
"reacquaint":	{"VB","VBP"},
"reacquainted":	{"VBD","VBN"},
"reacquainting":	{"VBG"},
"reacquaints":	{"VBZ"},
"reacquire":	{"VB","VBP"},
"reacquired":	{"VBD","VBN"},
"reacquires":	{"VBZ"},
"reacquiring":	{"VBG"},
"reacquisition":	{"NN"},
"react":	{"VB","VBP"},
"reactance":	{"NN"},
"reactant":	{"NN"},
"reactants":	{"NNS"},
"reacted":	{"VBD","VBN"},
"reacting":	{"VBG"},
"reaction":	{"NN"},
"reactionaries":	{"NNS"},
"reactionary":	{"JJ","NN"},
"reactionism":	{"NN"},
"reactionist":	{"JJ"},
"reactions":	{"NNS"},
"reactivate":	{"VB","VBP"},
"reactivated":	{"VBD","VBN"},
"reactivates":	{"VBZ"},
"reactivating":	{"VBG"},
"reactive":	{"JJ"},
"reactivity":	{"NN"},
"reactor":	{"NN"},
"reactors":	{"NNS"},
"reacts":	{"VBZ"},
"read":	{"VB","VBP","VBD","VBN","NN","JJ"},
"readability":	{"NN"},
"readable":	{"JJ"},
"readably":	{"RB"},
"readapt":	{"VB","VBP"},
"readapted":	{"VBD","VBN"},
"readapting":	{"VBG"},
"readapts":	{"VBZ"},
"readdress":	{"VB","VBP"},
"readdressed":	{"VBD","VBN"},
"readdresses":	{"VBZ"},
"readdressing":	{"VBG"},
"reader":	{"NN"},
"readers":	{"NNS"},
"readership":	{"NN"},
"readerships":	{"NNS"},
"readied":	{"VBD","VBN"},
"readier":	{"JJR"},
"readies":	{"VBZ","NNS"},
"readiest":	{"JJS"},
"readily":	{"RB"},
"readiness":	{"NN"},
"reading":	{"VBG","NN"},
"reading-desk":	{"NN"},
"reading-desks":	{"NNS"},
"reading-glasses":	{"NNS"},
"reading-lamp":	{"NN"},
"reading-lamps":	{"NNS"},
"reading-light":	{"NN"},
"reading-lights":	{"NNS"},
"reading-room":	{"NN"},
"reading-rooms":	{"NNS"},
"readings":	{"NNS"},
"readjust":	{"VB","VBP"},
"readjusted":	{"VBD","VBN"},
"readjusting":	{"VBG"},
"readjustment":	{"NN"},
"readjustments":	{"NNS"},
"readjusts":	{"VBZ"},
"readme":	{"NN"},
"readmission":	{"NN"},
"readmit":	{"VB","VBP"},
"readmits":	{"VBZ"},
"readmitted":	{"VBD","VBN"},
"readmitting":	{"VBG"},
"readopt":	{"VB","VBP"},
"readopted":	{"VBD","VBN"},
"readopting":	{"VBG"},
"readopts":	{"VBZ"},
"readout":	{"NN"},
"readouts":	{"NNS"},
"reads":	{"VBZ"},
"ready":	{"JJ","NN","RB","VBP","VB"},
"ready-made":	{"JJ"},
"ready-to-wear":	{"JJ"},
"readying":	{"VBG"},
"reaffiliation":	{"NN"},
"reaffirm":	{"VB","VBP"},
"reaffirmation":	{"NN"},
"reaffirmed":	{"VBD","VBN"},
"reaffirming":	{"VBG"},
"reaffirms":	{"VBZ"},
"reafforest":	{"VB","VBP"},
"reafforestation":	{"NN"},
"reafforested":	{"VBD","VBN"},
"reafforesting":	{"VBG"},
"reafforests":	{"VBZ"},
"reaganauts":	{"NNS"},
"reaganite":	{"JJ"},
"reagent":	{"NN"},
"reagents":	{"NNS"},
"reagin":	{"NN"},
"real":	{"JJ","RB","NN"},
"real-estate":	{"JJ"},
"real-life":	{"JJ"},
"real-time":	{"JJ"},
"real-world":	{"JJ"},
"realgar":	{"NN"},
"realign":	{"VB","VBP"},
"realigned":	{"VBD","VBN"},
"realigning":	{"VBG"},
"realignment":	{"NN"},
"realignments":	{"NNS"},
"realigns":	{"VBZ"},
"realisation":	{"NN"},
"realise":	{"VB","VBP"},
"realised":	{"VBD","VBN"},
"realises":	{"VBZ"},
"realising":	{"VBG"},
"realism":	{"NN"},
"realismo":	{"FW"},
"realist":	{"NN"},
"realistic":	{"JJ"},
"realistically":	{"RB"},
"realists":	{"NNS"},
"realities":	{"NNS"},
"reality":	{"NN"},
"realizable":	{"JJ"},
"realization":	{"NN"},
"realize":	{"VB","VBP"},
"realized":	{"VBD","VBN"},
"realizes":	{"VBZ"},
"realizing":	{"VBG"},
"reallocate":	{"VB","VBP"},
"reallocated":	{"VBD","VBN"},
"reallocates":	{"VBZ"},
"reallocating":	{"VBG"},
"reallocation":	{"NN"},
"reallot":	{"VB","VBP"},
"reallotment":	{"NN"},
"reallots":	{"VBZ"},
"reallotted":	{"VBD","VBN"},
"reallotting":	{"VBG"},
"really":	{"RB"},
"realm":	{"NN"},
"realms":	{"NNS"},
"realness":	{"NN"},
"realpolitik":	{"NN"},
"realtor":	{"NN"},
"realtors":	{"NNS"},
"realty":	{"NN"},
"ream":	{"NN","VB","VBP"},
"reamed":	{"VBD","VBN"},
"reamer":	{"NN"},
"reamers":	{"NNS"},
"reaming":	{"VBG"},
"reams":	{"NNS","VBZ"},
"reanimate":	{"VB","VBP"},
"reanimated":	{"VBD","VBN"},
"reanimates":	{"VBZ"},
"reanimating":	{"VBG"},
"reap":	{"VB","VBP"},
"reaped":	{"VBD","VBN"},
"reaper":	{"NN"},
"reapers":	{"NNS"},
"reaping":	{"VBG"},
"reappear":	{"VB","VBP"},
"reappearance":	{"NN"},
"reappearances":	{"NNS"},
"reappeared":	{"VBD","VBN"},
"reappearing":	{"VBG"},
"reappears":	{"VBZ"},
"reappoint":	{"VB","VBP"},
"reappointed":	{"VBD","VBN"},
"reappointing":	{"VBG"},
"reappoints":	{"VBZ"},
"reapportion":	{"VB","VBP"},
"reapportioned":	{"VBN","VBD"},
"reapportioning":	{"VBG"},
"reapportionment":	{"NN"},
"reapportions":	{"VBZ"},
"reappraisal":	{"NN"},
"reappraisals":	{"NNS"},
"reappraise":	{"VB","VBP"},
"reappraised":	{"VBD","VBN"},
"reappraises":	{"VBZ"},
"reappraising":	{"VBG"},
"reaps":	{"VBZ"},
"rear":	{"NN","VB","VBP","JJ"},
"rear-admiral":	{"NN"},
"rear-admirals":	{"NNS"},
"rear-end":	{"VB","VBP"},
"rear-ended":	{"VBD","VBN"},
"rear-ending":	{"VBG"},
"rear-ends":	{"VBZ"},
"rear-guard":	{"JJ"},
"rear-view":	{"JJ"},
"reared":	{"VBD","VBN"},
"rearguard":	{"NN"},
"rearing":	{"VBG"},
"rearm":	{"VB","VBP"},
"rearmament":	{"NN"},
"rearmed":	{"VBD","VBN"},
"rearming":	{"VBG"},
"rearmost":	{"JJ"},
"rearms":	{"VBZ"},
"rearrange":	{"VB","VBP"},
"rearranged":	{"VBD","VBN"},
"rearrangement":	{"NN"},
"rearrangements":	{"NNS"},
"rearranges":	{"VBZ"},
"rearranging":	{"VBG"},
"rearrest":	{"VB","VBP"},
"rearrested":	{"VBD","VBN"},
"rearresting":	{"VBG"},
"rearrests":	{"VBZ"},
"rears":	{"NNS","VBZ"},
"rearview":	{"NN"},
"rearward":	{"JJ","RB","NN"},
"rearwards":	{"RB"},
"reasearch":	{"NN"},
"reason":	{"NN","VB","VBP"},
"reasonable":	{"JJ"},
"reasonableness":	{"NN"},
"reasonably":	{"RB"},
"reasoned":	{"JJ","VBD","VBN"},
"reasoner":	{"NN"},
"reasoning":	{"NN","VBG"},
"reasoningly":	{"RB"},
"reasonless":	{"JJ"},
"reasons":	{"NNS","VBZ"},
"reassail":	{"VB","VBP"},
"reassemble":	{"VB","VBP"},
"reassembled":	{"VBD","VBN"},
"reassembles":	{"VBZ"},
"reassembling":	{"VBG"},
"reassembly":	{"NN"},
"reassert":	{"VB","VBP"},
"reasserted":	{"VBD","VBN"},
"reasserting":	{"VBG"},
"reassertion":	{"NN"},
"reasserts":	{"VBZ"},
"reassess":	{"VB","VBP"},
"reassessed":	{"VBD","VBN"},
"reassesses":	{"VBZ"},
"reassessing":	{"VBG"},
"reassessment":	{"NN"},
"reassessments":	{"NNS"},
"reassign":	{"VB","VBP"},
"reassigned":	{"VBD","VBN"},
"reassigning":	{"VBG"},
"reassignment":	{"NN"},
"reassignments":	{"NNS"},
"reassigns":	{"VBZ"},
"reassume":	{"VB","VBP"},
"reassumed":	{"VBD","VBN"},
"reassumes":	{"VBZ"},
"reassuming":	{"VBG"},
"reassurance":	{"NN"},
"reassurances":	{"NNS"},
"reassure":	{"VB","VBP"},
"reassured":	{"VBD","VBN","JJ"},
"reassures":	{"VBZ"},
"reassuring":	{"JJ","VBG"},
"reassuringly":	{"RB"},
"reata":	{"NN"},
"reattach":	{"VB","VBP"},
"reattached":	{"VBD","VBN"},
"reattaches":	{"VBZ"},
"reattaching":	{"VBG"},
"reattribute":	{"VB","VBP"},
"reattributed":	{"VBD","VBN"},
"reattributes":	{"VBZ"},
"reattributing":	{"VBG"},
"reauthorise":	{"VB","VBP"},
"reauthorised":	{"VBD","VBN"},
"reauthorises":	{"VBZ"},
"reauthorising":	{"VBG"},
"reauthorization":	{"NN"},
"reauthorize":	{"VB","VBP"},
"reauthorized":	{"VBD","VBN"},
"reauthorizes":	{"VBZ"},
"reauthorizing":	{"VBG"},
"reave":	{"VB","VBP"},
"reaved":	{"VBD","VBN"},
"reaves":	{"VBZ"},
"reaving":	{"VBG"},
"reawaken":	{"VB","VBP"},
"reawakened":	{"VBD","VBN"},
"reawakening":	{"VBG","NN"},
"reawakens":	{"VBZ"},
"reb":	{"NN"},
"rebalance":	{"VB","VBP"},
"rebalanced":	{"VBD","VBN"},
"rebalances":	{"VBZ"},
"rebalancing":	{"VBG"},
"rebarbative":	{"JJ"},
"rebate":	{"NN","VB","VBP"},
"rebated":	{"VBD","VBN"},
"rebates":	{"NNS","VBZ"},
"rebating":	{"VBG"},
"rebato":	{"NN"},
"rebatos":	{"NNS"},
"rebekah":	{"NN"},
"rebel":	{"NN","VB","VBP"},
"rebelled":	{"VBD","VBN"},
"rebelling":	{"VBG"},
"rebellion":	{"NN"},
"rebellions":	{"NNS"},
"rebellious":	{"JJ"},
"rebelliously":	{"RB"},
"rebelliousness":	{"NN"},
"rebels":	{"NNS","VBZ"},
"rebind":	{"VB","VBP"},
"rebinding":	{"VBG"},
"rebinds":	{"VBZ"},
"rebirth":	{"NN"},
"reboot":	{"VB","VBP","NN"},
"rebooted":	{"VBD","VBN"},
"rebooting":	{"VBG"},
"reboots":	{"VBZ","NNS"},
"reborn":	{"JJ","VBN"},
"rebound":	{"NN","VB","VBP","VBD","VBN"},
"rebounded":	{"VBD","VBN"},
"rebounder":	{"NN"},
"rebounders":	{"NNS"},
"rebounding":	{"VBG"},
"rebounds":	{"NNS","VBZ"},
"reboxetine":	{"NN"},
"rebozo":	{"NN"},
"rebroadcast":	{"VB","VBP"},
"rebroadcasted":	{"VBD","VBN"},
"rebroadcasting":	{"VBG"},
"rebroadcasts":	{"VBZ"},
"rebuff":	{"NN","VB","VBP"},
"rebuffed":	{"VBD","VBN"},
"rebuffing":	{"VBG"},
"rebuffs":	{"NNS","VBZ"},
"rebuild":	{"VB","VBP"},
"rebuilder":	{"NN"},
"rebuilding":	{"NN","VBG"},
"rebuilds":	{"VBZ","NNS"},
"rebuilt":	{"VBD","VBN"},
"rebukable":	{"JJ"},
"rebuke":	{"VB","VBP","NN"},
"rebuked":	{"NN","VBD","VBN"},
"rebuker":	{"NN"},
"rebukes":	{"VBZ","NNS"},
"rebuking":	{"VBG"},
"rebukingly":	{"RB"},
"reburial":	{"NN"},
"reburied":	{"VBD","VBN"},
"reburies":	{"VBZ"},
"rebury":	{"VB","VBP"},
"reburying":	{"VBG"},
"rebus":	{"NN"},
"rebuses":	{"NNS"},
"rebut":	{"VB","VBP"},
"rebuts":	{"VBZ"},
"rebuttal":	{"NN"},
"rebuttals":	{"NNS"},
"rebutted":	{"VBN","VBD"},
"rebutter":	{"NN"},
"rebutters":	{"NNS"},
"rebutting":	{"VBG"},
"rec":	{"NN"},
"recalcitrance":	{"NN"},
"recalcitrancy":	{"NN"},
"recalcitrant":	{"JJ"},
"recalcitrate":	{"VB","VBP"},
"recalcitrated":	{"VBD","VBN"},
"recalcitrates":	{"VBZ"},
"recalcitrating":	{"VBG"},
"recalculate":	{"VB","VBP"},
"recalculated":	{"VBD","VBN"},
"recalculates":	{"VBZ"},
"recalculating":	{"VBG"},
"recalculation":	{"NN"},
"recalculations":	{"NNS"},
"recall":	{"VB","NN","VBP"},
"recalled":	{"VBD","VBN"},
"recalling":	{"VBG"},
"recalls":	{"VBZ","NNS"},
"recant":	{"VB","VBP"},
"recantation":	{"NN"},
"recantations":	{"NNS"},
"recanted":	{"VBD","VBN"},
"recanting":	{"VBG"},
"recants":	{"VBZ"},
"recap":	{"VB","VBP","NN"},
"recapitalisation":	{"NN"},
"recapitalisations":	{"NNS"},
"recapitalise":	{"VB","VBP"},
"recapitalised":	{"VBD","VBN"},
"recapitalises":	{"VBZ"},
"recapitalising":	{"VBG"},
"recapitalization":	{"NN"},
"recapitalizations":	{"NNS"},
"recapitalize":	{"VB","VBP"},
"recapitalized":	{"VBD","VBN"},
"recapitalizes":	{"VBZ"},
"recapitalizing":	{"VBG"},
"recapitulate":	{"VB","VBP"},
"recapitulated":	{"VBD","VBN"},
"recapitulates":	{"VBZ"},
"recapitulating":	{"VBG"},
"recapitulation":	{"NN"},
"recapitulations":	{"NNS"},
"recapped":	{"VBD","VBN"},
"recapping":	{"VBG"},
"recaps":	{"VBZ","NNS"},
"recapture":	{"VB","VBP","NN"},
"recaptured":	{"VBD","VBN"},
"recaptures":	{"VBZ"},
"recapturing":	{"VBG"},
"recast":	{"VB","VBP","VBD","VBN"},
"recasting":	{"NN","VBG"},
"recastings":	{"NNS"},
"recasts":	{"VBZ"},
"recategorisation":	{"NN"},
"recategorisations":	{"NNS"},
"recategorise":	{"VB","VBP"},
"recategorised":	{"VBD","VBN"},
"recategorises":	{"VBZ"},
"recategorising":	{"VBG"},
"recategorization":	{"NN"},
"recategorizations":	{"NNS"},
"recategorize":	{"VB","VBP"},
"recategorized":	{"VBD","VBN"},
"recategorizes":	{"VBZ"},
"recategorizing":	{"VBG"},
"recce":	{"NN","VB","VBP"},
"recced":	{"VBD","VBN"},
"recceing":	{"VBG"},
"recces":	{"NNS","VBZ"},
"recco":	{"NN"},
"reccy":	{"NN"},
"recede":	{"VB","VBP"},
"receded":	{"VBD","VBN"},
"recedes":	{"VBZ"},
"receding":	{"VBG"},
"receipt":	{"NN","VB","VBP"},
"receipted":	{"VBD","VBN"},
"receipting":	{"VBG"},
"receipts":	{"NNS","VBZ"},
"receivable":	{"JJ"},
"receivables":	{"NNS"},
"receive":	{"VB","VBP"},
"received":	{"VBD","VBN","JJ"},
"receiver":	{"NN"},
"receivers":	{"NNS"},
"receivership":	{"NN"},
"receiverships":	{"NNS"},
"receives":	{"VBZ"},
"receiving":	{"VBG","NN"},
"recency":	{"NN"},
"recent":	{"JJ"},
"recently":	{"RB"},
"recentness":	{"NN"},
"recentralize":	{"VB","VBP"},
"recentralized":	{"VBD","VBN"},
"recentralizes":	{"VBZ"},
"recentralizing":	{"VBG"},
"receptacle":	{"NN"},
"receptacles":	{"NNS"},
"reception":	{"NN"},
"receptionist":	{"NN"},
"receptionists":	{"NNS"},
"receptions":	{"NNS"},
"receptive":	{"JJ"},
"receptively":	{"RB"},
"receptiveness":	{"NN"},
"receptivity":	{"NN"},
"receptor":	{"NN"},
"receptors":	{"NNS"},
"recess":	{"NN","VB","VBP"},
"recessed":	{"VBD","VBN","JJ"},
"recesses":	{"NNS","VBZ"},
"recessing":	{"VBG"},
"recession":	{"NN"},
"recessional":	{"NN","JJ"},
"recessionary":	{"JJ"},
"recessions":	{"NNS"},
"recessive":	{"JJ"},
"rechannel":	{"VB","VBP"},
"rechannelled":	{"VBD","VBN"},
"rechannelling":	{"VBG"},
"rechannels":	{"VBZ"},
"recharge":	{"VB","VBP"},
"rechargeable":	{"JJ","NN"},
"rechargeables":	{"NNS"},
"recharged":	{"VBD","VBN"},
"recharges":	{"VBZ"},
"recharging":	{"VBG"},
"recharter":	{"VB","VBP"},
"rechartered":	{"VBD","VBN"},
"rechartering":	{"VBG"},
"recharters":	{"VBZ"},
"rechauffe":	{"NN"},
"recheck":	{"VB","VBP"},
"rechecked":	{"VBD","VBN"},
"rechecking":	{"VBG"},
"rechecks":	{"VBZ"},
"recherche":	{"JJ"},
"rechristen":	{"VB","VBP"},
"rechristened":	{"VBD","VBN"},
"rechristening":	{"VBG"},
"rechristens":	{"VBZ"},
"recidivate":	{"VB","VBP"},
"recidivated":	{"VBD","VBN"},
"recidivates":	{"VBZ"},
"recidivating":	{"VBG"},
"recidivism":	{"NN"},
"recidivist":	{"NN"},
"recidivists":	{"NNS"},
"recife":	{"NN"},
"recipe":	{"NN"},
"recipes":	{"NNS"},
"recipient":	{"NN"},
"recipients":	{"NNS"},
"reciprocal":	{"JJ","NN"},
"reciprocality":	{"NN"},
"reciprocally":	{"RB"},
"reciprocate":	{"VB","VBP"},
"reciprocated":	{"VBD","VBN"},
"reciprocates":	{"VBZ"},
"reciprocating":	{"VBG"},
"reciprocation":	{"NN"},
"reciprocative":	{"JJ"},
"reciprocatory":	{"JJ"},
"reciprocity":	{"NN"},
"recirculate":	{"VB","VBP"},
"recirculated":	{"VBD","VBN"},
"recirculates":	{"VBZ"},
"recirculating":	{"VBG"},
"recirculation":	{"NN"},
"recission":	{"NN"},
"recital":	{"NN"},
"recitalist":	{"NN"},
"recitals":	{"NNS"},
"recitation":	{"NN"},
"recitations":	{"NNS"},
"recitative":	{"NN","JJ"},
"recitatives":	{"NNS"},
"recite":	{"VB","VBP"},
"recited":	{"VBD","VBN"},
"reciter":	{"NN"},
"reciters":	{"NNS"},
"recites":	{"VBZ"},
"reciting":	{"VBG","NN"},
"reckless":	{"JJ"},
"recklessly":	{"RB"},
"recklessness":	{"NN"},
"reckon":	{"VB","VBP"},
"reckoned":	{"VBD","VBN"},
"reckoner":	{"NN"},
"reckoners":	{"NNS"},
"reckoning":	{"NN","VBG"},
"reckonings":	{"NNS"},
"reckons":	{"VBZ"},
"reclaim":	{"VB","VBP"},
"reclaimable":	{"JJ"},
"reclaimed":	{"VBD","VBN"},
"reclaiming":	{"VBG"},
"reclaims":	{"VBZ"},
"reclamation":	{"NN"},
"reclassification":	{"NN"},
"reclassified":	{"VBD","VBN"},
"reclassifies":	{"VBZ"},
"reclassify":	{"VB","VBP"},
"reclassifying":	{"VBG"},
"recline":	{"VB","VBP"},
"reclined":	{"VBD","VBN"},
"recliner":	{"NN"},
"recliners":	{"NNS"},
"reclines":	{"VBZ"},
"reclining":	{"VBG"},
"recluse":	{"NN"},
"recluses":	{"NNS"},
"reclusive":	{"JJ"},
"reclusiveness":	{"NN"},
"recoat":	{"VB","VBP"},
"recoated":	{"VBD","VBN"},
"recoating":	{"VBG"},
"recoats":	{"VBZ"},
"recode":	{"VB","VBP"},
"recoded":	{"VBD","VBN"},
"recodes":	{"VBZ"},
"recoding":	{"VBG"},
"recognisability":	{"NN"},
"recognisable":	{"JJ"},
"recognisably":	{"RB"},
"recognisance":	{"NN"},
"recognisances":	{"NNS"},
"recognise":	{"VB","VBP"},
"recognised":	{"VBD","VBN","JJ"},
"recogniser":	{"NN"},
"recognisers":	{"NNS"},
"recognises":	{"VBZ"},
"recognising":	{"VBG"},
"recognition":	{"NN"},
"recognitions":	{"NNS"},
"recognizability":	{"NN"},
"recognizable":	{"JJ"},
"recognizably":	{"RB"},
"recognizance":	{"NN"},
"recognizances":	{"NNS"},
"recognize":	{"VB","VBP"},
"recognized":	{"VBN","VBD","JJ"},
"recognizer":	{"NN"},
"recognizers":	{"NNS"},
"recognizes":	{"VBZ"},
"recognizing":	{"VBG"},
"recoil":	{"VB","VBP","NN"},
"recoiled":	{"VBD","VBN"},
"recoiling":	{"VBG"},
"recoilless":	{"JJ"},
"recoils":	{"VBZ"},
"recollect":	{"VB","VBP"},
"recollected":	{"VBD","VBN"},
"recollecting":	{"VBG"},
"recollection":	{"NN"},
"recollections":	{"NNS"},
"recollective":	{"JJ"},
"recollectivization":	{"NN"},
"recollects":	{"VBZ"},
"recombinant":	{"JJ","NN"},
"recombination":	{"NN"},
"recombine":	{"VB","VBP"},
"recombined":	{"VBD","VBN"},
"recombineering":	{"NN"},
"recombines":	{"VBZ"},
"recombining":	{"VBG"},
"recommence":	{"VB","VBP"},
"recommenced":	{"VBD","VBN"},
"recommencement":	{"NN"},
"recommences":	{"VBZ"},
"recommencing":	{"VBG"},
"recommend":	{"VB","VBP"},
"recommendable":	{"JJ"},
"recommendation":	{"NN"},
"recommendations":	{"NNS"},
"recommended":	{"VBD","VBN","JJ"},
"recommending":	{"VBG"},
"recommends":	{"VBZ"},
"recommit":	{"VB","VBP"},
"recommitment":	{"NN"},
"recommits":	{"VBZ"},
"recommittal":	{"NN"},
"recommitted":	{"VBD","VBN"},
"recommitting":	{"VBG"},
"recompense":	{"VB","VBP","NN"},
"recompensed":	{"VBD","VBN"},
"recompenses":	{"VBZ"},
"recompensing":	{"VBG"},
"recompose":	{"VB","VBP"},
"recomposed":	{"VBD","VBN"},
"recomposes":	{"VBZ"},
"recomposing":	{"VBG"},
"recomposition":	{"NN"},
"reconceive":	{"VB","VBP"},
"reconceived":	{"VBD","VBN"},
"reconceives":	{"VBZ"},
"reconceiving":	{"VBG"},
"reconceptualization":	{"NN"},
"reconcilable":	{"JJ"},
"reconcile":	{"VB","VBP"},
"reconciled":	{"VBD","VBN","JJ"},
"reconcilement":	{"NN"},
"reconciler":	{"NN"},
"reconciles":	{"VBZ"},
"reconciliation":	{"NN"},
"reconciliations":	{"NNS"},
"reconciliatory":	{"JJ"},
"reconciling":	{"VBG"},
"recondite":	{"JJ"},
"reconditeness":	{"NN"},
"recondition":	{"VB","VBP"},
"reconditioned":	{"VBD","VBN"},
"reconditioning":	{"VBG"},
"reconditions":	{"VBZ"},
"reconfiguration":	{"NN"},
"reconfigure":	{"VB","VBP"},
"reconfigured":	{"VBD","VBN"},
"reconfigures":	{"VBZ"},
"reconfiguring":	{"VBG"},
"reconfirm":	{"VB","VBP"},
"reconfirmation":	{"NN"},
"reconfirmed":	{"VBD","VBN"},
"reconfirming":	{"VBG"},
"reconfirms":	{"VBZ"},
"reconnaissanace":	{"NN"},
"reconnaissance":	{"NN"},
"reconnect":	{"VB","VBP"},
"reconnected":	{"VBD","VBN"},
"reconnecting":	{"VBG"},
"reconnection":	{"NN"},
"reconnects":	{"VBZ"},
"reconnoiter":	{"VB","VBP"},
"reconnoitered":	{"VBD","VBN"},
"reconnoitering":	{"VBG"},
"reconnoiters":	{"VBZ"},
"reconnoitre":	{"VB","VBP"},
"reconnoitred":	{"VBD","VBN"},
"reconnoitres":	{"VBZ"},
"reconnoitring":	{"VBG"},
"reconquer":	{"VB","VBP"},
"reconquered":	{"VBD","VBN"},
"reconquering":	{"VBG"},
"reconquers":	{"VBZ"},
"reconsecrate":	{"VB","VBP"},
"reconsider":	{"VB","VBP"},
"reconsideration":	{"NN"},
"reconsidered":	{"VBD","VBN"},
"reconsidering":	{"VBG"},
"reconsiders":	{"VBZ"},
"reconstitute":	{"VB","VBP"},
"reconstituted":	{"VBD","VBN"},
"reconstitutes":	{"VBZ"},
"reconstituting":	{"VBG"},
"reconstitution":	{"NN"},
"reconstruct":	{"VB","VBP"},
"reconstructed":	{"JJ","VBD","VBN"},
"reconstructing":	{"VBG"},
"reconstruction":	{"NN"},
"reconstructions":	{"NNS"},
"reconstructive":	{"JJ"},
"reconstructs":	{"VBZ"},
"recontamination":	{"NN"},
"reconvene":	{"VB","VBP"},
"reconvened":	{"VBD","VBN"},
"reconvenes":	{"VBZ"},
"reconvening":	{"VBG"},
"reconvention":	{"NN"},
"reconvert":	{"VB","VBP"},
"reconverted":	{"VBD","VBN"},
"reconverting":	{"VBG"},
"reconverts":	{"VBZ"},
"reconvict":	{"VB","VBP"},
"reconvicted":	{"VBD","VBN"},
"reconvicting":	{"VBG"},
"reconvicts":	{"VBZ"},
"recopied":	{"VBD","VBN"},
"recopies":	{"VBZ"},
"recopy":	{"VB","VBP"},
"recopying":	{"VBG"},
"record":	{"NN","VB","VBP"},
"record-breaker":	{"NN"},
"record-breakers":	{"NNS"},
"record-breaking":	{"JJ"},
"record-holder":	{"NN"},
"record-holders":	{"NNS"},
"record-keeping":	{"NN"},
"record-player":	{"NN"},
"record-players":	{"NNS"},
"recorded":	{"VBN","VBD","JJ"},
"recorder":	{"NN"},
"recorders":	{"NNS"},
"recording":	{"NN","VBG"},
"recordings":	{"NNS"},
"records":	{"NNS","VBZ"},
"recork":	{"VB","VBP"},
"recount":	{"VB","VBP","NN"},
"recounted":	{"VBD","VBN"},
"recounting":	{"VBG"},
"recounts":	{"VBZ","NNS"},
"recoup":	{"VB","VBP"},
"recouped":	{"VBD","VBN"},
"recouping":	{"VBG"},
"recoups":	{"VBZ"},
"recourse":	{"NN"},
"recover":	{"VB","VBP"},
"recoverability":	{"NN"},
"recoverable":	{"JJ"},
"recovered":	{"VBD","VBN"},
"recoverer":	{"NN"},
"recoveries":	{"NNS"},
"recovering":	{"VBG"},
"recovers":	{"VBZ"},
"recovery":	{"NN"},
"recovery-program":	{"NN"},
"recreance":	{"NN"},
"recreant":	{"JJ","NN"},
"recreants":	{"NNS"},
"recreate":	{"VB","VBP"},
"recreated":	{"VBD","VBN"},
"recreates":	{"VBZ"},
"recreating":	{"VBG"},
"recreation":	{"NN"},
"recreational":	{"JJ"},
"recreations":	{"NNS"},
"recriminate":	{"VB","VBP"},
"recriminated":	{"VBD","VBN"},
"recriminates":	{"VBZ"},
"recriminating":	{"VBG"},
"recrimination":	{"NN"},
"recriminations":	{"NNS"},
"recriminative":	{"JJ"},
"recriminatory":	{"JJ"},
"recrudesce":	{"VB","VBP"},
"recrudesced":	{"VBD","VBN"},
"recrudescence":	{"NN"},
"recrudescences":	{"NNS"},
"recrudescent":	{"JJ"},
"recrudesces":	{"VBZ"},
"recrudescing":	{"VBG"},
"recruit":	{"VB","NN","VBP"},
"recruited":	{"VBN","VBD"},
"recruiter":	{"NN"},
"recruiters":	{"NNS"},
"recruiting":	{"VBG","NN"},
"recruitment":	{"NN"},
"recruits":	{"NNS","VBZ"},
"recta":	{"NNS"},
"rectal":	{"JJ"},
"rectangle":	{"NN"},
"rectangles":	{"NNS"},
"rectangular":	{"JJ"},
"rectangularity":	{"NN"},
"rectifiable":	{"JJ"},
"rectification":	{"NN"},
"rectifications":	{"NNS"},
"rectified":	{"VBD","VBN"},
"rectifier":	{"NN"},
"rectifiers":	{"NNS"},
"rectifies":	{"VBZ"},
"rectify":	{"VB","VBP"},
"rectifying":	{"VBG"},
"rectilineal":	{"JJ"},
"rectilineally":	{"RB"},
"rectilinear":	{"JJ"},
"rectitude":	{"NN"},
"rectlinearly":	{"RB"},
"recto":	{"NN"},
"rectocele":	{"NN"},
"rectoplasty":	{"NN"},
"rector":	{"NN"},
"rectorate":	{"NN"},
"rectories":	{"NNS"},
"rectors":	{"NNS"},
"rectorship":	{"NN"},
"rectory":	{"NN"},
"rectos":	{"NNS"},
"rectosigmoid":	{"JJ"},
"rectum":	{"NN"},
"rectums":	{"NNS"},
"rectus":	{"NN"},
"recumbence":	{"NN"},
"recumbency":	{"NN"},
"recumbent":	{"JJ"},
"recumbently":	{"RB"},
"recuperate":	{"VB","VBP"},
"recuperated":	{"VBD","VBN"},
"recuperates":	{"VBZ"},
"recuperating":	{"VBG"},
"recuperation":	{"NN"},
"recuperative":	{"JJ"},
"recur":	{"VB","VBP"},
"recurred":	{"VBD","VBN"},
"recurrence":	{"NN"},
"recurrences":	{"NNS"},
"recurrent":	{"JJ"},
"recurrently":	{"RB"},
"recurring":	{"VBG","JJ"},
"recurs":	{"VBZ"},
"recursion":	{"NN"},
"recursions":	{"NNS"},
"recursive":	{"JJ"},
"recurvate":	{"JJ"},
"recurve":	{"VB","VBP"},
"recurved":	{"VBD","VBN"},
"recurves":	{"VBZ"},
"recurving":	{"VBG"},
"recurvirostra":	{"NN"},
"recurvirostridae":	{"NN"},
"recusal":	{"NN"},
"recusancy":	{"NN"},
"recusant":	{"NN"},
"recusation":	{"NN"},
"recuse":	{"VB","VBP"},
"recused":	{"VBD","VBN"},
"recuses":	{"VBZ"},
"recusing":	{"VBG"},
"recut":	{"VB","VBP","VBD","VBN"},
"recuts":	{"VBZ"},
"recutting":	{"VBG"},
"recyclability":	{"NN"},
"recyclable":	{"JJ","NN"},
"recycle":	{"VB","VBP"},
"recycled":	{"VBD","VBN"},
"recycler":	{"NN"},
"recycles":	{"VBZ"},
"recycling":	{"NN","VBG"},
"red":	{"JJ","NN"},
"red-bellied":	{"JJ"},
"red-berry":	{"NN"},
"red-blind":	{"JJ"},
"red-blindness":	{"NN"},
"red-blooded":	{"JJ"},
"red-eye":	{"NN"},
"red-eyes":	{"NNS"},
"red-faced":	{"JJ"},
"red-figured":	{"JJ"},
"red-flag":	{"VB","VBP"},
"red-flagged":	{"VBD","VBN"},
"red-flagging":	{"VBG"},
"red-flags":	{"VBZ"},
"red-haired":	{"JJ"},
"red-handed":	{"JJ"},
"red-hot":	{"JJ"},
"red-letter":	{"JJ"},
"red-light":	{"JJ"},
"red-tape":	{"NN"},
"redact":	{"VB","VBP"},
"redacted":	{"VBD","VBN"},
"redacting":	{"VBG"},
"redaction":	{"NN"},
"redactional":	{"JJ"},
"redactions":	{"NNS"},
"redactor":	{"NN"},
"redacts":	{"VBZ"},
"redbellies":	{"NNS"},
"redbelly":	{"NN"},
"redberry":	{"NN"},
"redbird":	{"NN"},
"redbone":	{"NN"},
"redbreast":	{"NN"},
"redbrick":	{"JJ"},
"redbrush":	{"NN"},
"redbud":	{"NN"},
"redbug":	{"NN"},
"redcap":	{"NN"},
"redcaps":	{"NNS"},
"redcoat":	{"NN"},
"redcoats":	{"NNS"},
"redd":	{"VB","VBP","VBD","VBN","NN"},
"redded":	{"VBD","VBN"},
"redden":	{"VB","VBP"},
"reddened":	{"VBD","VBN"},
"reddening":	{"VBG"},
"reddens":	{"VBZ"},
"redder":	{"JJR"},
"reddest":	{"JJS"},
"redding":	{"VBG"},
"reddish":	{"JJ"},
"reddle":	{"NN"},
"redds":	{"VBZ"},
"rede":	{"VB","VBP","NN"},
"redecorate":	{"VB","VBP"},
"redecorated":	{"VBD","VBN"},
"redecorates":	{"VBZ"},
"redecorating":	{"VBG","NN"},
"redecoration":	{"NN"},
"reded":	{"VBD","VBN"},
"rededicate":	{"VB","VBP"},
"rededicated":	{"VBD","VBN"},
"rededicates":	{"VBZ"},
"rededicating":	{"VBG"},
"rededication":	{"NN"},
"redeem":	{"VB","VBP"},
"redeemable":	{"JJ"},
"redeemed":	{"VBD","VBN"},
"redeemer":	{"NN"},
"redeeming":	{"VBG"},
"redeems":	{"VBZ"},
"redefine":	{"VB","VBP"},
"redefined":	{"VBD","VBN"},
"redefines":	{"VBZ"},
"redefining":	{"VBG"},
"redefinition":	{"NN"},
"redeliver":	{"VB","VBP"},
"redelivered":	{"VBD","VBN"},
"redelivering":	{"VBG"},
"redelivers":	{"VBZ"},
"redemption":	{"NN"},
"redemptional":	{"JJ"},
"redemptions":	{"NNS"},
"redemptive":	{"JJ"},
"redemptory":	{"JJ"},
"redeploy":	{"VB","VBP"},
"redeployed":	{"VBD","VBN"},
"redeploying":	{"VBG"},
"redeployment":	{"NN"},
"redeploys":	{"VBZ"},
"redeposit":	{"VB","VBP"},
"redeposition":	{"NN"},
"redes":	{"VBZ"},
"redesign":	{"VB","VBP","NN"},
"redesignate":	{"VB","VBP"},
"redesignated":	{"VBD","VBN"},
"redesignates":	{"VBZ"},
"redesignating":	{"VBG"},
"redesignation":	{"NN"},
"redesigned":	{"VBD","VBN"},
"redesigning":	{"VBG"},
"redesigns":	{"VBZ","NNS"},
"redetermination":	{"NN"},
"redetermine":	{"VB","VBP"},
"redetermined":	{"VBD","VBN"},
"redetermines":	{"VBZ"},
"redetermining":	{"VBG"},
"redevelop":	{"VB","VBP"},
"redeveloped":	{"VBD","VBN"},
"redeveloper":	{"NN"},
"redevelopers":	{"NNS"},
"redeveloping":	{"VBG"},
"redevelopment":	{"NN"},
"redevelopments":	{"NNS"},
"redevelops":	{"VBZ"},
"redeye":	{"NN"},
"redfish":	{"NN","NNS"},
"redfishes":	{"NNS"},
"redhead":	{"NN"},
"redheaded":	{"JJ"},
"redheads":	{"NNS"},
"redhorse":	{"NN"},
"redial":	{"VB","VBP"},
"redialed":	{"VBD","VBN"},
"redialing":	{"VBG"},
"redialled":	{"VBD","VBN"},
"redialling":	{"VBG"},
"redials":	{"VBZ"},
"redid":	{"VBD"},
"rediffusion":	{"NN"},
"reding":	{"VBG"},
"redirect":	{"VB","VBP"},
"redirected":	{"VBD","VBN"},
"redirecting":	{"VBG"},
"redirection":	{"NN"},
"redirects":	{"VBZ"},
"rediscover":	{"VB","VBP"},
"rediscovered":	{"VBD","VBN"},
"rediscoveries":	{"NNS"},
"rediscovering":	{"VBG"},
"rediscovers":	{"VBZ"},
"rediscovery":	{"NN"},
"redispose":	{"VB","VBP"},
"redisposed":	{"VBD","VBN"},
"redisposes":	{"VBZ"},
"redisposing":	{"VBG"},
"redisposition":	{"NN"},
"redistribute":	{"VB","VBP"},
"redistributed":	{"VBD","VBN"},
"redistributes":	{"VBZ"},
"redistributing":	{"VBG"},
"redistribution":	{"NN"},
"redistributionism":	{"NN"},
"redistributionist":	{"NN"},
"redistributive":	{"JJ"},
"redistrict":	{"VB","VBP"},
"redistricted":	{"VBD","VBN"},
"redistricting":	{"VBG"},
"redistricts":	{"VBZ"},
"redline":	{"VB","VBP","NN"},
"redlined":	{"VBD","VBN"},
"redlines":	{"VBZ"},
"redlining":	{"VBG","NN"},
"redly":	{"RB"},
"redneck":	{"NN"},
"rednecks":	{"NNS"},
"redness":	{"NN"},
"redo":	{"VB","VBP"},
"redoes":	{"VBZ"},
"redoing":	{"VBG"},
"redolence":	{"NN"},
"redolent":	{"JJ"},
"redonda":	{"NN"},
"redone":	{"VBN"},
"redouble":	{"VB","VBP"},
"redoubled":	{"VBD","VBN"},
"redoubles":	{"VBZ"},
"redoubling":	{"VBG"},
"redoubt":	{"NN"},
"redoubtable":	{"JJ"},
"redoubts":	{"NNS"},
"redound":	{"VB","VBP"},
"redounded":	{"VBD","VBN"},
"redounding":	{"VBG"},
"redounds":	{"VBZ"},
"redox":	{"JJ"},
"redpoll":	{"NN"},
"redraft":	{"VB","VBP"},
"redrafted":	{"VBD","VBN"},
"redrafting":	{"VBG"},
"redrafts":	{"VBZ"},
"redraw":	{"VB","VBP"},
"redrawing":	{"VBG"},
"redrawn":	{"VBN"},
"redraws":	{"VBZ"},
"redress":	{"VB","VBP","NN"},
"redressed":	{"VBD","VBN"},
"redresses":	{"VBZ"},
"redressing":	{"VBG"},
"redrew":	{"VBD"},
"redroot":	{"NN"},
"reds":	{"NNS"},
"redshank":	{"NN"},
"redshift":	{"NN"},
"redshirt":	{"NN","VB","VBP"},
"redshirted":	{"VBD","VBN"},
"redshirting":	{"VBG"},
"redshirts":	{"NNS","VBZ"},
"redskin":	{"NN"},
"redstart":	{"NN"},
"redstreak":	{"NN"},
"redstreaks":	{"NNS"},
"redtail":	{"NN"},
"reduce":	{"VB","VBP"},
"reduced":	{"VBN","VBD","JJ"},
"reducer":	{"NN"},
"reducers":	{"NNS"},
"reduces":	{"VBZ"},
"reducible":	{"JJ"},
"reducing":	{"VBG","NN"},
"reductant":	{"NN"},
"reductase":	{"NN"},
"reductio":	{"FW"},
"reduction":	{"NN"},
"reductionism":	{"NN"},
"reductionist":	{"NN","JJ"},
"reductions":	{"NNS"},
"reductive":	{"JJ"},
"reductivism":	{"NN"},
"redundance":	{"NN"},
"redundancies":	{"NNS"},
"redundancy":	{"NN"},
"redundant":	{"JJ"},
"reduplicate":	{"VB","VBP","JJ"},
"reduplicated":	{"VBD","VBN"},
"reduplicates":	{"VBZ"},
"reduplicating":	{"VBG"},
"reduplication":	{"NN"},
"reduplicative":	{"JJ"},
"reduviid":	{"NN"},
"reduviidae":	{"NN"},
"redux":	{"JJ"},
"redwing":	{"NN"},
"redwood":	{"NN"},
"redwoods":	{"NNS"},
"reecho":	{"VB","VBP","NN"},
"reechoed":	{"VBD","VBN"},
"reechoes":	{"VBZ","NNS"},
"reechoing":	{"VBG"},
"reed":	{"NN"},
"reedbird":	{"NN"},
"reedbuck":	{"NN"},
"reedier":	{"JJR"},
"reediest":	{"JJS"},
"reedlike":	{"JJ"},
"reedmace":	{"NN"},
"reeds":	{"NNS"},
"reedy":	{"JJ"},
"reef":	{"NN","VBP","VB"},
"reef-knot":	{"NN"},
"reef-knots":	{"NNS"},
"reefed":	{"VBD","VBN"},
"reefer":	{"NN"},
"reefer-jacket":	{"NN"},
"reefer-jackets":	{"NNS"},
"reefers":	{"NNS"},
"reefier":	{"JJR"},
"reefiest":	{"JJS"},
"reefing":	{"VBG"},
"reefs":	{"NNS","VBZ"},
"reefy":	{"JJ"},
"reek":	{"NN","VB","VBP"},
"reeked":	{"VBD","VBN"},
"reeking":	{"VBG"},
"reeks":	{"VBZ"},
"reel":	{"NN","VB","VBP"},
"reelect":	{"VB","VBP"},
"reelected":	{"VBN","VBD"},
"reelecting":	{"VBG"},
"reelection":	{"NN"},
"reelects":	{"VBZ"},
"reeled":	{"VBD","VBN"},
"reeler":	{"NN"},
"reeling":	{"VBG"},
"reels":	{"VBZ"},
"reemission":	{"NN"},
"reemissions":	{"NNS"},
"reemit":	{"VB","VBP"},
"reemits":	{"VBZ"},
"reemitted":	{"VBD","VBN"},
"reemitting":	{"VBG"},
"reemphasize":	{"VB","VBP"},
"reemphasized":	{"VBD","VBN"},
"reemphasizes":	{"VBZ"},
"reemphasizing":	{"VBG"},
"reenact":	{"VB","VBP"},
"reenacted":	{"VBD","VBN"},
"reenacting":	{"VBG"},
"reenactment":	{"NN"},
"reenactments":	{"NNS"},
"reenactor":	{"NN"},
"reenacts":	{"VBZ"},
"reenforce":	{"VB","VBP"},
"reenforced":	{"VBD","VBN"},
"reenforcement":	{"NN"},
"reenforces":	{"VBZ"},
"reenforcing":	{"VBG"},
"reengineer":	{"VB","VBP"},
"reengineered":	{"VBD","VBN"},
"reengineering":	{"VBG","NN"},
"reengineers":	{"VBZ"},
"reenlistment":	{"NN"},
"reenlistments":	{"NNS"},
"reenrol":	{"VB","VBP"},
"reenroll":	{"VB","VBP"},
"reenrolled":	{"VBD","VBN"},
"reenrolling":	{"VBG"},
"reenrollment":	{"NN"},
"reenrollments":	{"NNS"},
"reenrolls":	{"VBZ"},
"reenrols":	{"VBZ"},
"reenter":	{"VB","VBP"},
"reentered":	{"VBD","VBN"},
"reentering":	{"VBG"},
"reenters":	{"VBZ"},
"reentrance":	{"NN"},
"reentrant":	{"JJ","NN"},
"reentries":	{"NNS"},
"reentry":	{"NN"},
"reese":	{"NN"},
"reestablish":	{"VB","VBP"},
"reestablished":	{"VBD","VBN"},
"reestablishes":	{"VBZ"},
"reestablishing":	{"VBG"},
"reestablishment":	{"NN"},
"reevaluate":	{"VB","VBP"},
"reevaluated":	{"VBD","VBN"},
"reevaluates":	{"VBZ"},
"reevaluating":	{"VBG"},
"reevaluation":	{"NN"},
"reeve":	{"NN","VB","VBP"},
"reeved":	{"VBD","VBN"},
"reeves":	{"NNS","VBZ"},
"reeving":	{"VBG"},
"reexamination":	{"NN"},
"reexamine":	{"VB","VBP"},
"reexamined":	{"VBD","VBN"},
"reexamines":	{"VBZ"},
"reexamining":	{"VBG"},
"ref":	{"NN"},
"refabrication":	{"NN"},
"reface":	{"VB","VBP"},
"refaced":	{"VBD","VBN"},
"refaces":	{"VBZ"},
"refacing":	{"VBG"},
"refashion":	{"VB","VBP"},
"refashioned":	{"VBD","VBN"},
"refashioning":	{"VBG"},
"refashions":	{"VBZ"},
"refection":	{"NN"},
"refectories":	{"NNS"},
"refectory":	{"NN"},
"refer":	{"VB","VBP"},
"referable":	{"JJ"},
"referee":	{"NN","VB","VBP"},
"refereed":	{"VBD","VBN"},
"refereeing":	{"NN","VBG"},
"referees":	{"NNS","VBZ"},
"reference":	{"NN","VB","VBP"},
"referenced":	{"VBD","VBN"},
"references":	{"NNS","VBZ"},
"referencing":	{"VBG"},
"referenda":	{"NNS"},
"referendum":	{"NN"},
"referendums":	{"NNS"},
"referent":	{"NN"},
"referential":	{"JJ"},
"referral":	{"NN"},
"referrals":	{"NNS"},
"referred":	{"VBD","VBN"},
"referring":	{"VBG"},
"refers":	{"VBZ"},
"refight":	{"VB","VBP","NN"},
"refighted":	{"VBD","VBN"},
"refighting":	{"VBG"},
"refights":	{"VBZ"},
"refile":	{"VB","VBP"},
"refiled":	{"VBD","VBN"},
"refiles":	{"VBZ"},
"refiling":	{"VBG"},
"refill":	{"VB","VBP","NN"},
"refillable":	{"JJ"},
"refilled":	{"VBD","VBN"},
"refilling":	{"VBG"},
"refills":	{"VBZ","NNS"},
"refinance":	{"VB","VBP"},
"refinanced":	{"VBD","VBN"},
"refinances":	{"VBZ"},
"refinancing":	{"NN","VBG"},
"refinancings":	{"NNS"},
"refine":	{"VB","VBP"},
"refined":	{"JJ","VBD","VBN"},
"refinement":	{"NN"},
"refinements":	{"NNS"},
"refiner":	{"NN"},
"refineries":	{"NNS"},
"refiners":	{"NNS"},
"refinery":	{"NN"},
"refines":	{"VBZ"},
"refining":	{"NN","VBG"},
"refinish":	{"VB","VBP"},
"refinished":	{"VBD","VBN"},
"refinisher":	{"NN"},
"refinishes":	{"VBZ"},
"refinishing":	{"VBG"},
"refit":	{"NN","VB","VBP"},
"refits":	{"NNS","VBZ"},
"refitted":	{"VBD","VBN"},
"refitting":	{"VBG"},
"reflate":	{"VB","VBP"},
"reflated":	{"VBD","VBN"},
"reflates":	{"VBZ"},
"reflating":	{"VBG"},
"reflation":	{"NN"},
"reflationary":	{"JJ"},
"reflect":	{"VB","VBP"},
"reflectance":	{"NN"},
"reflected":	{"VBD","VBN","JJ"},
"reflecting":	{"VBG"},
"reflection":	{"NN"},
"reflections":	{"NNS"},
"reflective":	{"JJ"},
"reflectively":	{"RB"},
"reflectiveness":	{"NN"},
"reflectivity":	{"NN"},
"reflectometer":	{"NN"},
"reflector":	{"NN"},
"reflectorise":	{"VB","VBP"},
"reflectorised":	{"VBD","VBN"},
"reflectorises":	{"VBZ"},
"reflectorising":	{"VBG"},
"reflectorize":	{"VB","VBP"},
"reflectorized":	{"VBD","VBN"},
"reflectorizes":	{"VBZ"},
"reflectorizing":	{"VBG"},
"reflectors":	{"NNS"},
"reflects":	{"VBZ"},
"reflex":	{"NN","VB","VBP"},
"reflexed":	{"VBD","VBN"},
"reflexes":	{"NNS","VBZ"},
"reflexing":	{"VBG"},
"reflexion":	{"NN"},
"reflexive":	{"NN","JJ"},
"reflexively":	{"RB"},
"reflexiveness":	{"NN"},
"reflexives":	{"NNS"},
"reflexivity":	{"NN"},
"reflexly":	{"RB"},
"reflexologist":	{"NN"},
"reflexologists":	{"NNS"},
"reflexology":	{"NN"},
"refloat":	{"VB","VBP"},
"refloated":	{"VBD","VBN"},
"refloating":	{"VBG"},
"refloats":	{"VBZ"},
"reflux":	{"NN","VB","VBP"},
"refluxed":	{"VBD","VBN"},
"refluxes":	{"NNS","VBZ"},
"refluxing":	{"VBG"},
"refocus":	{"VB","VBP"},
"refocused":	{"VBD","VBN"},
"refocuses":	{"VBZ"},
"refocusing":	{"VBG"},
"refold":	{"VB","VBP"},
"refolded":	{"VBD","VBN"},
"refolding":	{"VBG"},
"refolds":	{"VBZ"},
"reforest":	{"VB","VBP"},
"reforestation":	{"NN"},
"reforested":	{"VBD","VBN"},
"reforesting":	{"VBG"},
"reforests":	{"VBZ"},
"reforge":	{"VB","VBP"},
"reforged":	{"VBD","VBN"},
"reforges":	{"VBZ"},
"reforging":	{"VBG"},
"reform":	{"NN","VB","VBP"},
"reformable":	{"JJ"},
"reformation":	{"NN"},
"reformative":	{"JJ"},
"reformatories":	{"NNS"},
"reformatory":	{"NN","JJ"},
"reformed":	{"VBD","VBN","JJ"},
"reformer":	{"NN"},
"reformers":	{"NNS"},
"reforming":	{"VBG"},
"reformism":	{"NN"},
"reformist":	{"JJ","NN"},
"reformists":	{"NNS"},
"reforms":	{"NNS","VBZ"},
"reformulate":	{"VB","VBP"},
"reformulated":	{"VBN","VBD"},
"reformulates":	{"VBZ"},
"reformulating":	{"VBG"},
"reformulation":	{"NN"},
"refract":	{"VB","VBP"},
"refracted":	{"VBD","VBN"},
"refractile":	{"JJ"},
"refracting":	{"VBG"},
"refraction":	{"NN"},
"refractive":	{"JJ"},
"refractiveness":	{"NN"},
"refractivity":	{"NN"},
"refractometer":	{"NN"},
"refractories":	{"NNS"},
"refractorily":	{"RB"},
"refractoriness":	{"NN"},
"refractory":	{"JJ","NN"},
"refracts":	{"VBZ"},
"refracture":	{"VB","VBP"},
"refrain":	{"NN","VB","VBP"},
"refrained":	{"VBD","VBN"},
"refraining":	{"VBG"},
"refrains":	{"NNS","VBZ"},
"refresh":	{"VB","VBP"},
"refreshed":	{"JJ","VBD","VBN"},
"refreshen":	{"VB"},
"refresher":	{"NN"},
"refreshes":	{"VBZ"},
"refreshful":	{"JJ"},
"refreshfully":	{"RB"},
"refreshing":	{"JJ","VBG"},
"refreshingly":	{"RB"},
"refreshment":	{"NN"},
"refreshments":	{"NNS"},
"refrigerant":	{"NN","JJ"},
"refrigerate":	{"VB","VBP"},
"refrigerated":	{"VBD","VBN"},
"refrigerates":	{"VBZ"},
"refrigerating":	{"VBG"},
"refrigeration":	{"NN"},
"refrigerator":	{"NN"},
"refrigerators":	{"NNS"},
"reft":	{"VBD","VBN"},
"refuel":	{"VB","VBP"},
"refueled":	{"VBD","VBN"},
"refueling":	{"VBG","NN"},
"refuelled":	{"VBD","VBN"},
"refuelling":	{"VBG","NN"},
"refuels":	{"VBZ"},
"refuge":	{"NN","VB","VBP"},
"refuged":	{"VBD","VBN"},
"refugee":	{"NN"},
"refugees":	{"NNS"},
"refuges":	{"VBZ"},
"refuging":	{"VBG"},
"refulgence":	{"NN"},
"refulgency":	{"NN"},
"refulgent":	{"JJ"},
"refund":	{"NN","VB","VBP"},
"refundable":	{"JJ"},
"refunded":	{"VBD","VBN"},
"refunding":	{"NN","JJ","VBG"},
"refunds":	{"NNS","VBZ"},
"refurbish":	{"VB","VBP"},
"refurbished":	{"VBD","VBN"},
"refurbishes":	{"VBZ"},
"refurbishing":	{"VBG","NN"},
"refurbishment":	{"NN"},
"refurbishments":	{"NNS"},
"refurnish":	{"VB","VBP"},
"refurnished":	{"VBN"},
"refurnishes":	{"VBZ"},
"refurnishing":	{"VBG"},
"refusal":	{"NN"},
"refusals":	{"NNS"},
"refuse":	{"VB","VBP","NN"},
"refused":	{"VBD","VBN"},
"refuser":	{"NN"},
"refusers":	{"NNS"},
"refuses":	{"VBZ"},
"refusing":	{"VBG"},
"refutability":	{"NN"},
"refutable":	{"JJ"},
"refutably":	{"RB"},
"refutal":	{"NN"},
"refutation":	{"NN"},
"refutations":	{"NNS"},
"refute":	{"VB","VBP"},
"refuted":	{"VBD","VBN"},
"refuter":	{"NN"},
"refutes":	{"VBZ"},
"refuting":	{"VBG"},
"reg":	{"NN"},
"regain":	{"VB","VBP"},
"regained":	{"VBD","VBN"},
"regaining":	{"VBG"},
"regains":	{"VBZ"},
"regal":	{"JJ"},
"regale":	{"VB","VBP"},
"regalecidae":	{"NN"},
"regaled":	{"VBD","VBN"},
"regales":	{"VBZ"},
"regalia":	{"NN"},
"regaling":	{"VBG"},
"regally":	{"RB"},
"regard":	{"NN","VBP","VB"},
"regardant":	{"JJ"},
"regarded":	{"VBN","VBD"},
"regardful":	{"JJ"},
"regarding":	{"IN","VBG"},
"regardless":	{"RB"},
"regards":	{"VBZ","NNS"},
"regatta":	{"NN"},
"regattas":	{"NNS"},
"regencies":	{"NNS"},
"regency":	{"NN"},
"regenerate":	{"VB","VBP","JJ"},
"regenerated":	{"VBD","VBN"},
"regenerates":	{"VBZ"},
"regenerating":	{"VBG"},
"regeneration":	{"NN"},
"regenerative":	{"JJ"},
"regent":	{"NN","JJ"},
"regents":	{"NNS"},
"reggae":	{"NN"},
"reggane":	{"NN"},
"regi":	{"FW"},
"regicide":	{"NN"},
"regicides":	{"NNS"},
"regime":	{"NN"},
"regimen":	{"NN"},
"regimens":	{"NNS"},
"regiment":	{"NN","VB","VBP"},
"regimental":	{"JJ"},
"regimentally":	{"RB"},
"regimentals":	{"NNS"},
"regimentation":	{"NN"},
"regimented":	{"VBD","VBN","JJ"},
"regimenting":	{"VBG"},
"regiments":	{"NNS","VBZ"},
"regimes":	{"NNS"},
"regina":	{"NN"},
"regiomontanus":	{"NN"},
"region":	{"NN"},
"region-by-region":	{"JJ"},
"regional":	{"JJ"},
"regionalism":	{"NN"},
"regionality":	{"NN"},
"regionally":	{"RB"},
"regions":	{"NNS"},
"register":	{"NN","VB","VBP"},
"registered":	{"VBN","JJ","VBD"},
"registering":	{"VBG"},
"registers":	{"VBZ","NNS"},
"registrant":	{"NN"},
"registrants":	{"NNS"},
"registrar":	{"NN"},
"registrars":	{"NNS"},
"registration":	{"NN"},
"registrations":	{"NNS"},
"registries":	{"NNS"},
"registry":	{"NN"},
"reglaecus":	{"NN"},
"regnant":	{"JJ"},
"regnellidium":	{"NN"},
"regorge":	{"VB","VBP"},
"regorged":	{"VBD","VBN"},
"regorges":	{"VBZ"},
"regorging":	{"VBG"},
"regosol":	{"NN"},
"regress":	{"VB","VBP"},
"regressed":	{"VBD","VBN"},
"regresses":	{"VBZ"},
"regressing":	{"VBG"},
"regression":	{"NN"},
"regressions":	{"NNS"},
"regressive":	{"JJ"},
"regret":	{"VB","NN","VBP"},
"regretful":	{"JJ"},
"regretfully":	{"RB"},
"regretless":	{"JJ"},
"regrets":	{"VBZ","NNS"},
"regrettable":	{"JJ"},
"regrettably":	{"RB"},
"regretted":	{"VBD","VBN"},
"regretting":	{"VBG"},
"regrew":	{"VBD"},
"reground":	{"JJ"},
"regroup":	{"VB","VBP"},
"regrouped":	{"VBD","VBN"},
"regrouping":	{"VBG"},
"regroups":	{"VBZ"},
"regrow":	{"VB","VBP"},
"regrowing":	{"VBG"},
"regrown":	{"VBN"},
"regrows":	{"VBZ"},
"regular":	{"JJ","NN"},
"regularisation":	{"NN"},
"regularise":	{"VB","VBP"},
"regularised":	{"VBD","VBN"},
"regularises":	{"VBZ"},
"regularising":	{"VBG"},
"regularities":	{"NNS"},
"regularity":	{"NN"},
"regularization":	{"NN"},
"regularize":	{"VB","VBP"},
"regularized":	{"VBD","VBN"},
"regularizes":	{"VBZ"},
"regularizing":	{"VBG"},
"regularly":	{"RB"},
"regulars":	{"NNS"},
"regulate":	{"VB","VBP"},
"regulated":	{"VBD","VBN","JJ"},
"regulates":	{"VBZ"},
"regulating":	{"VBG"},
"regulation":	{"NN","JJ"},
"regulations":	{"NNS"},
"regulative":	{"JJ"},
"regulator":	{"NN"},
"regulators":	{"NNS"},
"regulatory":	{"JJ"},
"reguli":	{"NNS"},
"reguline":	{"JJ"},
"regulus":	{"NN"},
"reguluses":	{"NNS"},
"regur":	{"NN"},
"regurgitate":	{"VB","VBP"},
"regurgitated":	{"VBD","VBN"},
"regurgitates":	{"VBZ"},
"regurgitating":	{"VBG"},
"regurgitation":	{"NN"},
"rehab":	{"NN","VB","VBP"},
"rehabbed":	{"VBD","VBN"},
"rehabbing":	{"VBG"},
"rehabilitate":	{"VB","VBP"},
"rehabilitated":	{"VBD","VBN"},
"rehabilitates":	{"VBZ"},
"rehabilitating":	{"VBG"},
"rehabilitation":	{"NN"},
"rehabilitations":	{"NNS"},
"rehabilitative":	{"JJ"},
"rehabs":	{"VBZ"},
"reharmonisation":	{"NN"},
"reharmonise":	{"VB"},
"reharmonization":	{"NN"},
"reharmonize":	{"VB"},
"rehash":	{"VB","VBP","NN"},
"rehashed":	{"VBD","VBN"},
"rehashes":	{"VBZ"},
"rehashing":	{"NN","VBG"},
"rehear":	{"VB","VBP"},
"reheard":	{"VBD","VBN"},
"rehearing":	{"NN","VBG"},
"rehears":	{"VBZ"},
"rehearsal":	{"NN"},
"rehearsals":	{"NNS"},
"rehearse":	{"VB","VBP","NN"},
"rehearsed":	{"VBD","VBN"},
"rehearses":	{"VBZ"},
"rehearsing":	{"VBG"},
"reheat":	{"VB","VBP"},
"reheated":	{"VBD","VBN"},
"reheating":	{"VBG"},
"reheats":	{"VBZ"},
"reheel":	{"VB","VBP"},
"reheeled":	{"VBD","VBN"},
"reheeling":	{"VBG"},
"reheels":	{"VBZ"},
"rehnquist":	{"NN"},
"rehouse":	{"VB","VBP"},
"rehoused":	{"VBD","VBN"},
"rehouses":	{"VBZ"},
"rehousing":	{"VBG"},
"reichstein":	{"NN"},
"reid":	{"NN"},
"reification":	{"NN"},
"reificatory":	{"JJ"},
"reified":	{"VBD","VBN"},
"reifier":	{"NN"},
"reifies":	{"VBZ"},
"reify":	{"VB","VBP"},
"reifying":	{"VBG"},
"reign":	{"NN","VB","VBP"},
"reigned":	{"VBD","VBN"},
"reigning":	{"JJ","VBG"},
"reignite":	{"VB","VBP"},
"reignited":	{"VBD","VBN"},
"reignites":	{"VBZ"},
"reigniting":	{"VBG"},
"reigns":	{"NNS","VBZ"},
"reimburse":	{"VB","VBP"},
"reimburseable":	{"JJ"},
"reimbursed":	{"VBD","VBN"},
"reimbursement":	{"NN"},
"reimbursements":	{"NNS"},
"reimburses":	{"VBZ"},
"reimbursing":	{"VBG"},
"reimpose":	{"VB","VBP"},
"reimposed":	{"VBD","VBN"},
"reimposes":	{"VBZ"},
"reimposing":	{"VBG"},
"reimposition":	{"NN"},
"rein":	{"NN","VB","VBP"},
"reinbursement":	{"NN"},
"reincarceration":	{"NN"},
"reincarnate":	{"VB","VBP","JJ"},
"reincarnated":	{"VBD","VBN"},
"reincarnates":	{"VBZ"},
"reincarnating":	{"VBG"},
"reincarnation":	{"NN"},
"reincarnationism":	{"NN"},
"reincarnations":	{"NNS"},
"reincorporate":	{"VB","VBP"},
"reincorporated":	{"VBD","VBN"},
"reincorporates":	{"VBZ"},
"reincorporating":	{"VBG"},
"reincorporation":	{"NN"},
"reindeer":	{"NN","NNS"},
"reindict":	{"VB","VBP"},
"reindicted":	{"VBD","VBN"},
"reindicting":	{"VBG"},
"reindicts":	{"VBZ"},
"reined":	{"VBD","VBN"},
"reinforce":	{"VB","VBP"},
"reinforced":	{"JJ","VBD","VBN"},
"reinforcement":	{"NN"},
"reinforcements":	{"NNS"},
"reinforcer":	{"NN"},
"reinforces":	{"VBZ"},
"reinforcing":	{"VBG"},
"reinhardt":	{"NN"},
"reining":	{"VBG"},
"reinject":	{"VB","VBP"},
"reinjected":	{"VBD","VBN"},
"reinjecting":	{"VBG"},
"reinjects":	{"VBZ"},
"reins":	{"NNS","VBZ"},
"reinstall":	{"VB","VBP"},
"reinstalled":	{"VBD","VBN"},
"reinstalling":	{"VBG"},
"reinstalls":	{"VBZ"},
"reinstate":	{"VB","VBP"},
"reinstated":	{"VBD","VBN"},
"reinstatement":	{"NN"},
"reinstatements":	{"NNS"},
"reinstates":	{"VBZ"},
"reinstating":	{"VBG"},
"reinstitute":	{"VB","VBP"},
"reinstituted":	{"VBD","VBN"},
"reinstitutes":	{"VBZ"},
"reinstituting":	{"VBG"},
"reinstitution":	{"NN"},
"reinsurance":	{"NN"},
"reinsure":	{"VB","VBP"},
"reinsured":	{"VBN","VBD"},
"reinsurer":	{"NN"},
"reinsurers":	{"NNS"},
"reinsures":	{"VBZ"},
"reinsuring":	{"VBG"},
"reintegrate":	{"VB","VBP"},
"reintegrated":	{"VBD","VBN"},
"reintegrates":	{"VBZ"},
"reintegrating":	{"VBG"},
"reinterpret":	{"VB","VBP"},
"reinterpretation":	{"NN"},
"reinterpretations":	{"NNS"},
"reinterpreted":	{"VBD","VBN"},
"reinterpreting":	{"VBG"},
"reinterprets":	{"VBZ"},
"reintroduce":	{"VB","VBP"},
"reintroduced":	{"VBN","VBD"},
"reintroduces":	{"VBZ"},
"reintroducing":	{"VBG"},
"reintroduction":	{"NN"},
"reinvent":	{"VB","VBP"},
"reinvented":	{"VBD","VBN"},
"reinventing":	{"VBG"},
"reinvention":	{"NN"},
"reinventions":	{"NNS"},
"reinvents":	{"VBZ"},
"reinvest":	{"VB","VBP"},
"reinvested":	{"VBD","VBN"},
"reinvestigate":	{"VB","VBP"},
"reinvestigated":	{"VBD","VBN"},
"reinvestigates":	{"VBZ"},
"reinvestigating":	{"VBG"},
"reinvestigation":	{"NN"},
"reinvesting":	{"VBG"},
"reinvestment":	{"NN"},
"reinvests":	{"VBZ"},
"reinvigorate":	{"VB","VBP"},
"reinvigorated":	{"VBD","VBN"},
"reinvigorates":	{"VBZ"},
"reinvigorating":	{"VBG"},
"reinvigoration":	{"NN"},
"reipublicae":	{"FW"},
"reissue":	{"VB","VBP","NN"},
"reissued":	{"VBN","VBD"},
"reissues":	{"VBZ","NNS"},
"reissuing":	{"VBG"},
"reit":	{"NN"},
"reiter":	{"NN"},
"reiterate":	{"VB","VBP"},
"reiterated":	{"VBD","VBN"},
"reiterates":	{"VBZ"},
"reiterating":	{"VBG"},
"reiteration":	{"NN"},
"reiterations":	{"NNS"},
"reiterative":	{"JJ"},
"reithrodontomys":	{"NNS"},
"reits":	{"NNS"},
"reject":	{"VB","VBP","NN"},
"rejected":	{"VBD","VBN"},
"rejecting":	{"VBG"},
"rejection":	{"NN"},
"rejections":	{"NNS"},
"rejective":	{"JJ"},
"rejects":	{"VBZ","NNS"},
"rejig":	{"VB","VBP"},
"rejigged":	{"VBD","VBN"},
"rejigger":	{"VB","VBP"},
"rejiggered":	{"VBD","VBN"},
"rejiggering":	{"VBG"},
"rejiggers":	{"VBZ"},
"rejigging":	{"VBG"},
"rejigs":	{"VBZ"},
"rejoice":	{"VB","VBP"},
"rejoiced":	{"VBD","VBN"},
"rejoices":	{"VBZ"},
"rejoicing":	{"NN","VBG"},
"rejoicings":	{"NNS"},
"rejoin":	{"VB","VBP"},
"rejoinder":	{"NN"},
"rejoinders":	{"NNS"},
"rejoined":	{"VBD","VBN"},
"rejoining":	{"VBG"},
"rejoins":	{"VBZ"},
"rejuvenate":	{"VB","VBP"},
"rejuvenated":	{"VBN","VBD"},
"rejuvenates":	{"VBZ"},
"rejuvenating":	{"VBG","JJ"},
"rejuvenation":	{"NN"},
"rekindle":	{"VB","VBP"},
"rekindled":	{"VBD","VBN"},
"rekindles":	{"VBZ"},
"rekindling":	{"VBG"},
"relabel":	{"VB","VBP"},
"relabeled":	{"VBD","VBN"},
"relabeling":	{"VBG"},
"relabels":	{"VBZ"},
"relace":	{"VB","VBP"},
"relaced":	{"VBD","VBN"},
"relaces":	{"VBZ"},
"relacing":	{"VBG"},
"relafen":	{"NN"},
"relapse":	{"VB","VBP","NN"},
"relapsed":	{"VBD","VBN"},
"relapses":	{"VBZ","NNS"},
"relapsing":	{"VBG"},
"relate":	{"VB","VBP"},
"related":	{"VBN","JJ","VBD"},
"relatedness":	{"NN"},
"relates":	{"VBZ"},
"relatiative":	{"JJ"},
"relating":	{"VBG"},
"relation":	{"NN"},
"relational":	{"JJ"},
"relations":	{"NNS"},
"relationship":	{"NN"},
"relationships":	{"NNS"},
"relative":	{"JJ","NN"},
"relative-in-law":	{"NN"},
"relatively":	{"RB"},
"relatives":	{"NNS"},
"relatives-in-law":	{"NNS"},
"relativisation":	{"NN"},
"relativise":	{"VB","VBP"},
"relativised":	{"VBD","VBN"},
"relativises":	{"VBZ"},
"relativising":	{"VBG"},
"relativism":	{"NN"},
"relativist":	{"NN","JJ"},
"relativistic":	{"JJ"},
"relativistically":	{"RB"},
"relativists":	{"NNS"},
"relativity":	{"NN"},
"relativize":	{"VB","VBP"},
"relativized":	{"VBD","VBN"},
"relativizes":	{"VBZ"},
"relativizing":	{"VBG"},
"relatum":	{"NN"},
"relaunch":	{"VB","VBP","NN"},
"relaunched":	{"VBD","VBN"},
"relaunches":	{"VBZ"},
"relaunching":	{"VBG"},
"relax":	{"VB","VBP"},
"relaxant":	{"NN"},
"relaxation":	{"NN"},
"relaxed":	{"JJ","VBD","VBN"},
"relaxer":	{"NN"},
"relaxes":	{"VBZ"},
"relaxin":	{"NN"},
"relaxing":	{"VBG","JJ"},
"relay":	{"NN","VB","VBP"},
"relayed":	{"VBD","VBN"},
"relaying":	{"VBG"},
"relays":	{"NNS","VBZ"},
"relearn":	{"VB","VBP"},
"relearned":	{"VBD","VBN"},
"relearning":	{"VBG"},
"relearns":	{"VBZ"},
"release":	{"VB","VBP","NN"},
"released":	{"VBN","VBD"},
"releases":	{"VBZ","NNS"},
"releasing":	{"VBG"},
"relegate":	{"VB","VBP"},
"relegated":	{"VBD","VBN"},
"relegates":	{"VBZ"},
"relegating":	{"VBG"},
"relegation":	{"NN"},
"relent":	{"VB","VBP"},
"relented":	{"VBD","VBN"},
"relenting":	{"VBG"},
"relentless":	{"JJ"},
"relentlessly":	{"RB"},
"relentlessness":	{"NN"},
"relents":	{"VBZ"},
"relevance":	{"NN"},
"relevancy":	{"NN"},
"relevant":	{"JJ"},
"relevantly":	{"RB"},
"reliability":	{"NN"},
"reliable":	{"JJ"},
"reliableness":	{"NN"},
"reliably":	{"RB"},
"reliance":	{"NN"},
"reliant":	{"JJ"},
"relic":	{"NN"},
"relicense":	{"VB","VBP"},
"relicensed":	{"VBD","VBN"},
"relicenses":	{"VBZ"},
"relicensing":	{"VBG"},
"relics":	{"NNS"},
"relict":	{"NN"},
"relied":	{"VBN","VBD"},
"relief":	{"NN"},
"reliefs":	{"NNS"},
"relies":	{"VBZ"},
"relieve":	{"VB","VBP"},
"relieved":	{"VBN","VBD","JJ"},
"reliever":	{"NN"},
"relievers":	{"NNS"},
"relieves":	{"VBZ"},
"relieving":	{"VBG"},
"relievo":	{"NN"},
"relievos":	{"NNS"},
"religion":	{"NN"},
"religionism":	{"NN"},
"religionist":	{"NN"},
"religionists":	{"NNS"},
"religions":	{"NNS"},
"religiosity":	{"NN"},
"religious":	{"JJ"},
"religiousism":	{"NN"},
"religiously":	{"RB"},
"religiousness":	{"NN"},
"reline":	{"VB","VBP"},
"relined":	{"VBD","VBN"},
"relines":	{"VBZ"},
"relining":	{"VBG"},
"relinquish":	{"VB","VBP"},
"relinquished":	{"VBD","VBN"},
"relinquishes":	{"VBZ"},
"relinquishing":	{"VBG"},
"relinquishment":	{"NN"},
"reliquaries":	{"NNS"},
"reliquary":	{"NN"},
"relish":	{"NN","VB","VBP"},
"relished":	{"VBD","VBN"},
"relishes":	{"VBZ","NNS"},
"relishing":	{"VBG"},
"relist":	{"VB","VBP"},
"relisted":	{"VBD","VBN"},
"relistening":	{"NN"},
"relisting":	{"VBG"},
"relists":	{"VBZ"},
"relitigate":	{"VB","VBP"},
"relitigated":	{"VBD","VBN"},
"relitigates":	{"VBZ"},
"relitigating":	{"VBG"},
"relitigation":	{"NN"},
"relive":	{"VB","VBP"},
"relived":	{"VBD","VBN"},
"relives":	{"VBZ"},
"reliving":	{"VBG"},
"reload":	{"VB","VBP"},
"reloaded":	{"VBD","VBN"},
"reloading":	{"VBG"},
"reloads":	{"VBZ"},
"relocate":	{"VB","VBP"},
"relocated":	{"VBD","VBN"},
"relocates":	{"VBZ"},
"relocating":	{"VBG"},
"relocation":	{"NN"},
"relocations":	{"NNS"},
"reluctance":	{"NN"},
"reluctant":	{"JJ"},
"reluctantly":	{"RB"},
"reluctivity":	{"NN"},
"rely":	{"VB","VBP"},
"relying":	{"VBG"},
"relyric":	{"VB","VBP"},
"relyriced":	{"VBD","VBN"},
"relyricing":	{"VBG"},
"relyrics":	{"VBZ"},
"rem":	{"NN"},
"remade":	{"VBD","VBN"},
"remain":	{"VB","VBP"},
"remainder":	{"NN","VB","VBP"},
"remaindered":	{"VBD","VBN"},
"remaindering":	{"VBG"},
"remainders":	{"NNS","VBZ"},
"remained":	{"VBD","VBN"},
"remainer":	{"NN"},
"remainers":	{"NNS"},
"remaining":	{"VBG","JJ"},
"remains":	{"VBZ","NNS"},
"remake":	{"NN","VB","VBP"},
"remakes":	{"NNS","VBZ"},
"remaking":	{"VBG"},
"remand":	{"VB","VBP","NN"},
"remanded":	{"VBD","VBN"},
"remanding":	{"VBG"},
"remands":	{"VBZ"},
"remark":	{"NN","VB","VBP"},
"remarkable":	{"JJ"},
"remarkably":	{"RB"},
"remarked":	{"VBD","VBN"},
"remarket":	{"VB","VBP"},
"remarketed":	{"VBD","VBN"},
"remarketing":	{"VBG"},
"remarkets":	{"VBZ"},
"remarking":	{"VBG"},
"remarks":	{"NNS","VBZ"},
"remarque":	{"NN"},
"remarriage":	{"NN"},
"remarriages":	{"NNS"},
"remarried":	{"VBD","VBN"},
"remarries":	{"VBZ"},
"remarry":	{"VB","VBP"},
"remarrying":	{"VBG"},
"rematch":	{"NN"},
"rematches":	{"NNS"},
"rembrandt":	{"NN"},
"rembrandtesque":	{"JJ"},
"remediable":	{"JJ"},
"remedial":	{"JJ"},
"remediate":	{"VB","VBP"},
"remediated":	{"VBD","VBN"},
"remediates":	{"VBZ"},
"remediating":	{"VBG"},
"remediation":	{"NN"},
"remedied":	{"VBD","VBN"},
"remedies":	{"NNS","VBZ"},
"remedy":	{"NN","VB","VBP"},
"remedying":	{"VBG"},
"remember":	{"VB","VBP"},
"remembered":	{"VBD","VBN","JJ"},
"rememberer":	{"NN"},
"remembering":	{"VBG"},
"remembers":	{"VBZ"},
"remembrance":	{"NN"},
"remembrances":	{"NNS"},
"remicade":	{"NN"},
"remics":	{"NNS"},
"remilegia":	{"NN"},
"remilitarisation":	{"NN"},
"remilitarise":	{"VB","VBP"},
"remilitarised":	{"VBD","VBN"},
"remilitarises":	{"VBZ"},
"remilitarising":	{"VBG"},
"remilitarization":	{"NN"},
"remilitarize":	{"VB","VBP"},
"remilitarized":	{"VBD","VBN"},
"remilitarizes":	{"VBZ"},
"remilitarizing":	{"VBG"},
"remind":	{"VB","VBP"},
"reminded":	{"VBD","VBN"},
"reminder":	{"NN"},
"reminders":	{"NNS"},
"remindful":	{"JJ"},
"reminding":	{"VBG"},
"reminds":	{"VBZ"},
"reminisce":	{"VB","VBP"},
"reminisced":	{"VBD","VBN"},
"reminiscence":	{"NN"},
"reminiscences":	{"NNS"},
"reminiscent":	{"JJ"},
"reminiscently":	{"RB"},
"reminisces":	{"VBZ"},
"reminiscing":	{"VBG"},
"remise":	{"VB","VBP","NN"},
"remised":	{"VBD","VBN"},
"remises":	{"VBZ","NNS"},
"remising":	{"VBG"},
"remiss":	{"JJ"},
"remission":	{"NN"},
"remissions":	{"NNS"},
"remissly":	{"RB"},
"remissness":	{"NN"},
"remit":	{"VB","VBP","NN"},
"remitment":	{"NN"},
"remits":	{"VBZ"},
"remittal":	{"NN"},
"remittance":	{"NN"},
"remittances":	{"NNS"},
"remitted":	{"VBD","VBN"},
"remittent":	{"JJ"},
"remitting":	{"VBG"},
"remix":	{"NN","VB","VBP"},
"remixable":	{"JJ"},
"remixed":	{"VBD","VBN"},
"remixer":	{"NN"},
"remixers":	{"NNS"},
"remixes":	{"NNS","VBZ"},
"remixing":	{"VBG"},
"remixture":	{"NN"},
"remixtures":	{"NNS"},
"remnant":	{"NN"},
"remnants":	{"NNS"},
"remodel":	{"VB","VBP"},
"remodeled":	{"VBD","VBN"},
"remodeling":	{"VBG","NN"},
"remodelled":	{"VBD","VBN"},
"remodelling":	{"VBG","NN"},
"remodels":	{"VBZ"},
"remold":	{"VBP","VB","NN"},
"remolded":	{"VBD","VBN"},
"remolding":	{"VBG"},
"remolds":	{"VBZ","NNS"},
"remonstrance":	{"NN"},
"remonstrances":	{"NNS"},
"remonstrate":	{"VB","VBP"},
"remonstrated":	{"VBD","VBN"},
"remonstrates":	{"VBZ"},
"remonstrating":	{"VBG"},
"remonstration":	{"NN"},
"remonstrations":	{"NNS"},
"remora":	{"NN","NNS"},
"remoralise":	{"VB","VBP"},
"remoralised":	{"VBD","VBN"},
"remoralises":	{"VBZ"},
"remoralising":	{"VBG"},
"remoralize":	{"VB","VBP"},
"remoralized":	{"VBD","VBN"},
"remoralizes":	{"VBZ"},
"remoralizing":	{"VBG"},
"remoras":	{"NNS"},
"remorse":	{"NN"},
"remorseful":	{"JJ"},
"remorsefully":	{"RB"},
"remorsefulness":	{"NN"},
"remorseless":	{"JJ"},
"remorselessly":	{"RB"},
"remote":	{"JJ","NN"},
"remote-controlled":	{"JJ"},
"remotely":	{"RB"},
"remoteness":	{"NN"},
"remoter":	{"JJR"},
"remotest":	{"JJS"},
"remotion":	{"NN"},
"remould":	{"VB","VBP","NN"},
"remoulded":	{"VBD","VBN"},
"remoulding":	{"VBG"},
"remoulds":	{"VBZ","NNS"},
"remount":	{"VB","VBP","NN"},
"remounted":	{"VBD","VBN"},
"remounting":	{"VBG"},
"remounts":	{"VBZ"},
"removable":	{"JJ"},
"removal":	{"NN"},
"removals":	{"NNS"},
"remove":	{"VB","VBP","NN"},
"removed":	{"VBN","VBD","JJ"},
"remover":	{"NN"},
"removers":	{"NNS"},
"removes":	{"VBZ","NNS"},
"removing":	{"VBG"},
"remuda":	{"NN"},
"remunerate":	{"VB","VBP"},
"remunerated":	{"VBD","VBN"},
"remunerates":	{"VBZ"},
"remunerating":	{"VBG"},
"remuneration":	{"NN"},
"remunerations":	{"NNS"},
"remunerative":	{"JJ"},
"remunerator":	{"NN"},
"remunerators":	{"NNS"},
"remus":	{"NN"},
"ren":	{"NN"},
"renaissance":	{"NN"},
"renal":	{"JJ"},
"rename":	{"VB","VBP"},
"renamed":	{"VBN","VBD"},
"renames":	{"VBZ"},
"renaming":	{"VBG"},
"renascence":	{"NN"},
"renascent":	{"JJ"},
"renationalise":	{"VB","VBP"},
"renationalised":	{"VBD","VBN"},
"renationalises":	{"VBZ"},
"renationalising":	{"VBG"},
"renationalize":	{"VB","VBP"},
"renationalized":	{"VBD","VBN"},
"renationalizes":	{"VBZ"},
"renationalizing":	{"VBG"},
"renaturation":	{"NN"},
"rend":	{"VB","VBP"},
"rended":	{"VBD","VBN"},
"render":	{"VB","VBP"},
"rendered":	{"VBN","VBD"},
"rendering":	{"NN","VBG"},
"renderings":	{"NNS"},
"renders":	{"VBZ"},
"rendezvous":	{"NN","NNS","VB","VBP","VBZ"},
"rendezvoused":	{"VBD","VBN"},
"rendezvousing":	{"VBG"},
"rending":	{"VBG"},
"rendition":	{"NN"},
"renditions":	{"NNS"},
"rends":	{"VBZ"},
"rene":	{"NN"},
"renegade":	{"NN","JJ","VB","VBP"},
"renegaded":	{"VBD","VBN"},
"renegades":	{"NNS","VBZ"},
"renegading":	{"VBG"},
"renege":	{"VB","VBP"},
"reneged":	{"VBD","VBN"},
"reneges":	{"VBZ"},
"reneging":	{"VBG"},
"renegotiable":	{"JJ"},
"renegotiate":	{"VB","VBP"},
"renegotiated":	{"VBD","VBN"},
"renegotiates":	{"VBZ"},
"renegotiating":	{"VBG"},
"renegotiation":	{"NN"},
"renegotiations":	{"NNS"},
"renerve":	{"VB","VBP"},
"renew":	{"VB","VBP"},
"renewable":	{"JJ","NN"},
"renewables":	{"NNS"},
"renewal":	{"NN"},
"renewals":	{"NNS"},
"renewed":	{"VBN","VBD","JJ"},
"renewing":	{"VBG"},
"renews":	{"VBZ"},
"reniform":	{"JJ"},
"renin":	{"NN"},
"rennet":	{"NN"},
"rennin":	{"NN"},
"reno":	{"NN"},
"renoir":	{"NN"},
"renormalise":	{"VB","VBP"},
"renormalised":	{"VBD","VBN"},
"renormalises":	{"VBZ"},
"renormalising":	{"VBG"},
"renormalize":	{"VB","VBP"},
"renormalized":	{"VBD","VBN"},
"renormalizes":	{"VBZ"},
"renormalizing":	{"VBG"},
"renounce":	{"VB","VBP"},
"renounced":	{"VBD","VBN"},
"renouncement":	{"NN"},
"renounces":	{"VBZ"},
"renouncing":	{"VBG"},
"renovate":	{"VB","VBP"},
"renovated":	{"VBD","VBN"},
"renovates":	{"VBZ"},
"renovating":	{"VBG"},
"renovation":	{"NN"},
"renovations":	{"NNS"},
"renovator":	{"NN"},
"renovators":	{"NNS"},
"renown":	{"NN"},
"renowned":	{"JJ"},
"rensselaerite":	{"NN"},
"rent":	{"NN","VB","VBP","VBD","VBN"},
"rent-a-car":	{"NN"},
"rent-a-colonel":	{"NN"},
"rent-control":	{"NN"},
"rent-controlled":	{"JJ"},
"rent-free":	{"JJ","RB"},
"rent-rebate":	{"NN"},
"rent-roll":	{"NN"},
"rent-seeker":	{"NN"},
"rent-seekers":	{"NNS"},
"rent-seeking":	{"NN"},
"rentable":	{"JJ"},
"rental":	{"NN","JJ"},
"rentals":	{"NNS"},
"rente":	{"NN"},
"rented":	{"VBN","JJ","VBD"},
"renter":	{"NN"},
"renters":	{"NNS"},
"rentes":	{"NNS"},
"rentier":	{"NN"},
"renting":	{"VBG"},
"rents":	{"NNS","VBZ"},
"renunciant":	{"JJ"},
"renunciation":	{"NN"},
"renunciations":	{"NNS"},
"renunciative":	{"JJ"},
"reoccupation":	{"NN"},
"reoccupied":	{"VBD","VBN"},
"reoccupies":	{"VBZ"},
"reoccupy":	{"VB","VBP"},
"reoccupying":	{"VBG"},
"reoccur":	{"VB","VBP"},
"reoccurred":	{"VBD","VBN"},
"reoccurrence":	{"NN"},
"reoccurrences":	{"NNS"},
"reoccurring":	{"VBG"},
"reoccurs":	{"VBZ"},
"reoffend":	{"VB","VBP"},
"reoffended":	{"VBD","VBN"},
"reoffender":	{"NN"},
"reoffenders":	{"NNS"},
"reoffending":	{"VBG"},
"reoffends":	{"VBZ"},
"reopen":	{"VB","VBP"},
"reopened":	{"VBD","VBN"},
"reopening":	{"VBG"},
"reopens":	{"VBZ"},
"reorder":	{"VB","VBP","NN"},
"reordered":	{"VBD","VBN"},
"reordering":	{"VBG"},
"reorders":	{"VBZ","NNS"},
"reorganisation":	{"NN"},
"reorganise":	{"VB","VBP"},
"reorganised":	{"VBD","VBN"},
"reorganises":	{"VBZ"},
"reorganising":	{"VBG"},
"reorganization":	{"NN"},
"reorganizations":	{"NNS"},
"reorganize":	{"VB","VBP"},
"reorganized":	{"VBD","VBN"},
"reorganizes":	{"VBZ"},
"reorganizing":	{"VBG"},
"reorient":	{"VB","VBP"},
"reorientate":	{"VB","VBP"},
"reorientated":	{"VBD","VBN"},
"reorientates":	{"VBZ"},
"reorientating":	{"VBG"},
"reorientation":	{"NN"},
"reoriented":	{"VBN","VBD"},
"reorienting":	{"VBG"},
"reorients":	{"VBZ"},
"reoviridae":	{"NN"},
"reovirus":	{"NN"},
"rep":	{"NN"},
"repack":	{"VB","VBP"},
"repackage":	{"VB","VBP"},
"repackaged":	{"VBD","VBN"},
"repackages":	{"VBZ"},
"repackaging":	{"VBG"},
"repacked":	{"VBD","VBN"},
"repacking":	{"VBG"},
"repacks":	{"VBZ"},
"repaid":	{"VBD","VBN"},
"repaint":	{"VB","VBP"},
"repainted":	{"VBD","VBN"},
"repainting":	{"VBG"},
"repaints":	{"VBZ"},
"repair":	{"VB","VBP","NN"},
"repaired":	{"VBD","VBN"},
"repairer":	{"NN"},
"repairers":	{"NNS"},
"repairing":	{"NN","VBG"},
"repairman":	{"NN"},
"repairmen":	{"NNS"},
"repairs":	{"NNS","VBZ"},
"repand":	{"JJ"},
"reparable":	{"JJ"},
"reparation":	{"NN"},
"reparations":	{"NNS"},
"repartee":	{"NN"},
"repass":	{"VB","VBP"},
"repassage":	{"NN"},
"repassed":	{"VBD","VBN"},
"repasses":	{"VBZ"},
"repassing":	{"VBG"},
"repast":	{"NN","VB","VBP"},
"repasted":	{"VBD","VBN"},
"repasting":	{"VBG"},
"repasts":	{"NNS","VBZ"},
"repatriate":	{"VB","VBP"},
"repatriated":	{"VBD","VBN"},
"repatriates":	{"VBZ"},
"repatriating":	{"VBG"},
"repatriation":	{"NN"},
"repatriations":	{"NNS"},
"repay":	{"VB","VBP"},
"repayable":	{"JJ"},
"repaying":	{"VBG"},
"repayment":	{"NN"},
"repayments":	{"NNS"},
"repays":	{"VBZ"},
"repeal":	{"VB","VBP","NN"},
"repealed":	{"VBD","VBN"},
"repealing":	{"VBG"},
"repeals":	{"VBZ"},
"repeat":	{"VB","VBP","NN"},
"repeatable":	{"JJ"},
"repeated":	{"VBN","VBD","JJ"},
"repeatedly":	{"RB"},
"repeater":	{"NN"},
"repeaters":	{"NNS"},
"repeating":	{"VBG","JJ"},
"repeats":	{"NNS","VBZ"},
"repechage":	{"NN"},
"repel":	{"VB","VBP"},
"repellant":	{"JJ","NN"},
"repellants":	{"NNS"},
"repelled":	{"VBN","VBD"},
"repellent":	{"NN","JJ"},
"repellently":	{"RB"},
"repellents":	{"NNS"},
"repelling":	{"VBG"},
"repellingly":	{"RB"},
"repels":	{"VBZ"},
"repent":	{"VB","VBP"},
"repentance":	{"NN"},
"repentant":	{"JJ"},
"repentantly":	{"RB"},
"repented":	{"VBD","VBN"},
"repenting":	{"VBG"},
"repents":	{"VBZ"},
"repercuss":	{"VB","VBP"},
"repercussed":	{"VBD","VBN"},
"repercusses":	{"VBZ"},
"repercussing":	{"VBG"},
"repercussion":	{"NN"},
"repercussions":	{"NNS"},
"repertoire":	{"NN"},
"repertoires":	{"NNS"},
"repertories":	{"NNS"},
"repertory":	{"NN"},
"repetition":	{"NN"},
"repetitions":	{"NNS"},
"repetitious":	{"JJ"},
"repetitiously":	{"RB"},
"repetitiousness":	{"NN"},
"repetitive":	{"JJ"},
"repetitively":	{"RB"},
"repetitiveness":	{"NN"},
"rephrase":	{"VB","VBP"},
"rephrased":	{"VBD","VBN"},
"rephrases":	{"VBZ"},
"rephrasing":	{"VBG"},
"repine":	{"VB","VBP"},
"repined":	{"VBD","VBN"},
"repines":	{"VBZ"},
"repining":	{"VBG"},
"replace":	{"VB","VBP"},
"replaceability":	{"NN"},
"replaceable":	{"JJ"},
"replaced":	{"VBN","VBD"},
"replacement":	{"NN"},
"replacements":	{"NNS"},
"replaces":	{"VBZ"},
"replacing":	{"VBG"},
"replant":	{"VB","VBP"},
"replanted":	{"VBD","VBN"},
"replanting":	{"VBG"},
"replants":	{"VBZ"},
"replaster":	{"VB","VBP"},
"replastered":	{"VBD","VBN"},
"replastering":	{"VBG"},
"replasters":	{"VBZ"},
"replay":	{"NN","VB","VBP"},
"replayed":	{"VBD","VBN"},
"replaying":	{"VBG"},
"replays":	{"NNS","VBZ"},
"replenish":	{"VB","VBP"},
"replenished":	{"VBN","VBD"},
"replenishes":	{"VBZ"},
"replenishing":	{"VBG"},
"replenishment":	{"NN"},
"replete":	{"JJ"},
"repletion":	{"NN"},
"replica":	{"NN"},
"replicas":	{"NNS"},
"replicate":	{"VB","VBP"},
"replicated":	{"VBD","VBN"},
"replicates":	{"VBZ"},
"replicating":	{"VBG"},
"replication":	{"NN"},
"replications":	{"NNS"},
"replied":	{"VBD","VBN"},
"replies":	{"VBZ","NNS"},
"reply":	{"VB","NN","VBP"},
"reply-paid":	{"JJ"},
"replying":	{"VBG"},
"repo":	{"NN"},
"repoint":	{"VB","VBP"},
"repointed":	{"VBD","VBN"},
"repointing":	{"VBG","NN"},
"repoints":	{"VBZ"},
"report":	{"NN","VB","VBP"},
"reportable":	{"JJ"},
"reportage":	{"NN"},
"reported":	{"VBD","VBN"},
"reportedly":	{"RB"},
"reporter":	{"NN"},
"reporters":	{"NNS"},
"reporting":	{"VBG","NN"},
"reportorial":	{"JJ"},
"reports":	{"NNS","VBZ"},
"repos":	{"NNS"},
"repose":	{"NN","VB","VBP"},
"reposed":	{"VBD","VBN"},
"reposeful":	{"JJ"},
"reposes":	{"VBZ"},
"reposing":	{"VBG"},
"reposit":	{"VB","VBP"},
"reposited":	{"VBD","VBN"},
"repositing":	{"VBG"},
"reposition":	{"VB","VBP","NN"},
"repositioned":	{"VBD","VBN"},
"repositioning":	{"VBG"},
"repositions":	{"VBZ"},
"repositories":	{"NNS"},
"repository":	{"NN"},
"reposits":	{"VBZ"},
"repossess":	{"VB","VBP"},
"repossessed":	{"VBN","VBD"},
"repossesses":	{"VBZ"},
"repossessing":	{"VBG"},
"repossession":	{"NN"},
"repossessions":	{"NNS"},
"repot":	{"VB","VBP"},
"repots":	{"VBZ"},
"repotted":	{"VBD","VBN"},
"repotting":	{"VBG"},
"repp":	{"NN"},
"reprehend":	{"VB","VBP"},
"reprehended":	{"VBD","VBN"},
"reprehending":	{"VBG"},
"reprehends":	{"VBZ"},
"reprehensibility":	{"NN"},
"reprehensible":	{"JJ"},
"reprehensibly":	{"RB"},
"reprehension":	{"NN"},
"reprehensively":	{"RB"},
"represent":	{"VB","VBP"},
"representable":	{"JJ"},
"representation":	{"NN"},
"representational":	{"JJ"},
"representations":	{"NNS"},
"representative":	{"JJ","NN"},
"representatives":	{"NNS"},
"represented":	{"VBD","VBN"},
"representing":	{"VBG"},
"represents":	{"VBZ"},
"repress":	{"VB","VBP"},
"repressed":	{"VBD","VBN","JJ"},
"represser":	{"NN"},
"repressers":	{"NNS"},
"represses":	{"VBZ"},
"repressible":	{"JJ"},
"repressing":	{"VBG"},
"repression":	{"NN"},
"repressions":	{"NNS"},
"repressive":	{"JJ"},
"repressively":	{"RB"},
"repressiveness":	{"NN"},
"repressor":	{"NN"},
"repressors":	{"NNS"},
"reprice":	{"VB","VBP"},
"repriced":	{"VBD","VBN"},
"reprices":	{"VBZ"},
"repricing":	{"VBG"},
"reprieve":	{"NN","VB","VBP"},
"reprieved":	{"VBD","VBN"},
"reprieves":	{"NNS","VBZ"},
"reprieving":	{"VBG"},
"reprimand":	{"VB","VBP","NN"},
"reprimanded":	{"VBD","VBN"},
"reprimanding":	{"VBG"},
"reprimands":	{"VBZ"},
"reprint":	{"VB","VBP","NN"},
"reprinted":	{"VBD","VBN"},
"reprinting":	{"VBG"},
"reprints":	{"NNS","VBZ"},
"reprioritize":	{"VB","VBP"},
"reprisal":	{"NN"},
"reprisals":	{"NNS"},
"reprise":	{"NN","VB","VBP"},
"reprised":	{"VBD","VBN"},
"reprises":	{"NNS","VBZ"},
"reprising":	{"VBG"},
"reprize":	{"VB","VBP"},
"reproach":	{"NN","VB","VBP"},
"reproached":	{"VBD","VBN"},
"reproacher":	{"NN"},
"reproachers":	{"NNS"},
"reproaches":	{"NNS","VBZ"},
"reproachful":	{"JJ"},
"reproachfully":	{"RB"},
"reproaching":	{"VBG"},
"reprobate":	{"NN","JJ","VB","VBP"},
"reprobated":	{"VBD","VBN"},
"reprobates":	{"NNS","VBZ"},
"reprobating":	{"VBG"},
"reprobation":	{"NN"},
"reprocess":	{"VB","VBP"},
"reprocessed":	{"VBD","VBN"},
"reprocesses":	{"VBZ"},
"reprocessing":	{"VBG"},
"reproduce":	{"VB","VBP"},
"reproduced":	{"VBD","VBN"},
"reproducer":	{"NN"},
"reproducers":	{"NNS"},
"reproduces":	{"VBZ"},
"reproducibilities":	{"NNS"},
"reproducibility":	{"NN"},
"reproducible":	{"JJ"},
"reproducibly":	{"RB"},
"reproducing":	{"VBG"},
"reproduction":	{"NN"},
"reproductions":	{"NNS"},
"reproductive":	{"JJ"},
"reprogram":	{"VB","VBP"},
"reprogramme":	{"VB","VBP"},
"reprogrammed":	{"VBD","VBN"},
"reprogrammes":	{"VBZ"},
"reprogramming":	{"VBG"},
"reprograms":	{"VBZ"},
"reprographic":	{"JJ"},
"reproof":	{"NN","VB","VBP"},
"reproofed":	{"VBD","VBN"},
"reproofing":	{"VBG"},
"reproofs":	{"NNS","VBZ"},
"reproval":	{"NN"},
"reprove":	{"VB","VBP"},
"reproved":	{"VBD","VBN"},
"reprover":	{"NN"},
"reproves":	{"VBZ"},
"reproving":	{"VBG","JJ"},
"reprovingly":	{"RB"},
"reps":	{"NNS"},
"reptantia":	{"NN"},
"reptile":	{"NN"},
"reptiles":	{"NNS"},
"reptilia":	{"NN"},
"reptilian":	{"JJ","NN"},
"republic":	{"NN"},
"republican":	{"NN","JJ"},
"republicanism":	{"NN"},
"republicans":	{"NNS"},
"republication":	{"NN"},
"republics":	{"NNS"},
"republish":	{"VB","VBP"},
"republished":	{"VBD","VBN"},
"republishes":	{"VBZ"},
"republishing":	{"VBG"},
"repudiate":	{"VB","VBP"},
"repudiated":	{"VBD","VBN"},
"repudiates":	{"VBZ"},
"repudiating":	{"VBG"},
"repudiation":	{"NN"},
"repudiations":	{"NNS"},
"repudiative":	{"JJ"},
"repugn":	{"VB","VBP"},
"repugnance":	{"NN"},
"repugnant":	{"JJ"},
"repugned":	{"VBD","VBN"},
"repugning":	{"VBG"},
"repugns":	{"VBZ"},
"repulse":	{"VB","VBP","NN"},
"repulsed":	{"VBD","VBN"},
"repulses":	{"VBZ"},
"repulsing":	{"VBG"},
"repulsion":	{"NN"},
"repulsions":	{"NNS"},
"repulsive":	{"JJ"},
"repulsively":	{"RB"},
"repulsiveness":	{"NN"},
"repurchase":	{"NN","VB","VBP"},
"repurchased":	{"VBN","VBD"},
"repurchases":	{"NNS","VBZ"},
"repurchasing":	{"VBG"},
"repurpose":	{"VB","VBP"},
"repurposed":	{"VBD","VBN"},
"repurposes":	{"VBZ"},
"repurposing":	{"VBG"},
"reputability":	{"NN"},
"reputable":	{"JJ"},
"reputably":	{"RB"},
"reputation":	{"NN"},
"reputations":	{"NNS"},
"repute":	{"NN","VB","VBP"},
"reputed":	{"JJ","VBD","VBN"},
"reputedly":	{"RB"},
"reputes":	{"VBZ"},
"reputing":	{"VBG"},
"reqion":	{"NN"},
"requalified":	{"VBD","VBN"},
"requalifies":	{"VBZ"},
"requalify":	{"VB","VBP"},
"requalifying":	{"VBG"},
"request":	{"NN","VB","VBP"},
"requested":	{"VBN","VBD"},
"requester":	{"NN"},
"requesters":	{"NNS"},
"requesting":	{"VBG"},
"requests":	{"NNS","VBZ"},
"requicken":	{"VB","VBP"},
"requiem":	{"NN"},
"requiems":	{"NNS"},
"requiescat":	{"NN"},
"require":	{"VB","VBP"},
"required":	{"VBN","VBD","JJ"},
"requirement":	{"NN"},
"requirements":	{"NNS"},
"requires":	{"VBZ"},
"requiring":	{"VBG"},
"requisite":	{"JJ","NN"},
"requisiteness":	{"NN"},
"requisites":	{"NNS"},
"requisition":	{"NN","VB","VBP"},
"requisitioned":	{"VBD","VBN"},
"requisitioning":	{"VBG"},
"requisitions":	{"NNS","VBZ"},
"requital":	{"NN"},
"requite":	{"VB","VBP"},
"requited":	{"VBD","VBN"},
"requites":	{"VBZ"},
"requiting":	{"VBG"},
"reran":	{"VBD"},
"reread":	{"VB","VBP","VBD","VBN"},
"rereading":	{"VBG"},
"rereads":	{"VBZ"},
"rerebrace":	{"NN"},
"reredos":	{"NN"},
"reregulate":	{"VB","VBP"},
"reregulation":	{"NN"},
"rerelease":	{"NN","VB","VBP"},
"rereleased":	{"VBD","VBN"},
"rereleases":	{"NNS","VBZ"},
"rereleasing":	{"VBG"},
"reroof":	{"VB","VBP"},
"reroofed":	{"VBD","VBN"},
"reroofing":	{"VBG"},
"reroofs":	{"VBZ"},
"reroute":	{"VB","VBP"},
"rerouted":	{"VBD","VBN"},
"reroutes":	{"VBZ"},
"rerouting":	{"VBG"},
"rerun":	{"NN","VB","VBP","VBN"},
"rerunning":	{"VBG"},
"reruns":	{"NNS","VBZ"},
"res":	{"NN"},
"resale":	{"NN"},
"rescale":	{"VB","VBP"},
"rescaled":	{"VBD","VBN"},
"rescales":	{"VBZ"},
"rescaling":	{"VBG"},
"reschedulable":	{"JJ"},
"reschedule":	{"VB","VBP"},
"rescheduled":	{"VBD","VBN"},
"reschedules":	{"VBZ"},
"rescheduling":	{"VBG","NN"},
"rescind":	{"VB","VBP"},
"rescindable":	{"JJ"},
"rescinded":	{"VBD","VBN"},
"rescinding":	{"VBG"},
"rescinds":	{"VBZ"},
"rescission":	{"NN"},
"rescissions":	{"NNS"},
"rescript":	{"NN"},
"rescriptor":	{"NN"},
"rescue":	{"VB","VBP","NN"},
"rescued":	{"VBD","VBN"},
"rescuer":	{"NN"},
"rescuers":	{"NNS"},
"rescues":	{"VBZ","NNS"},
"rescuing":	{"VBG"},
"reseal":	{"VB","VBP"},
"resealable":	{"JJ"},
"resealed":	{"VBD","VBN"},
"resealing":	{"VBG"},
"reseals":	{"VBZ"},
"research":	{"NN","VB","VBP"},
"researchable":	{"JJ"},
"researched":	{"VBD","VBN"},
"researcher":	{"NN"},
"researchers":	{"NNS"},
"researches":	{"VBZ","NNS"},
"researching":	{"VBG"},
"reseat":	{"VB","VBP"},
"reseated":	{"VBD","VBN"},
"reseating":	{"VBG"},
"reseats":	{"VBZ"},
"reseau":	{"NN"},
"resect":	{"VB","VBP"},
"resectability":	{"NN"},
"resectable":	{"JJ"},
"resected":	{"VBD","VBN"},
"resecting":	{"VBG"},
"resection":	{"NN"},
"resections":	{"NNS"},
"resects":	{"VBZ"},
"reseda":	{"NN"},
"resedaceae":	{"NN"},
"reseed":	{"VB","VBP"},
"reseeded":	{"VBD","VBN"},
"reseeding":	{"VBG"},
"reseeds":	{"VBZ"},
"resell":	{"VB","VBP"},
"reseller":	{"NN"},
"resellers":	{"NNS"},
"reselling":	{"VBG"},
"resells":	{"VBZ"},
"resemblance":	{"NN"},
"resemblances":	{"NNS"},
"resemble":	{"VB","VBP"},
"resembled":	{"VBD","VBN"},
"resembles":	{"VBZ"},
"resembling":	{"VBG"},
"resend":	{"VB","VBP"},
"resending":	{"VBG"},
"resends":	{"VBZ"},
"resent":	{"VB","VBP","VBD","VBN"},
"resented":	{"VBD","VBN"},
"resentful":	{"JJ"},
"resentfully":	{"RB"},
"resenting":	{"VBG"},
"resentment":	{"NN"},
"resentments":	{"NNS"},
"resents":	{"VBZ"},
"reserpine":	{"NN"},
"reservation":	{"NN"},
"reservations":	{"NNS"},
"reserve":	{"VB","VBP","NN"},
"reserved":	{"VBN","VBD","JJ"},
"reservedly":	{"RB"},
"reservedness":	{"NN"},
"reserves":	{"NNS","VBZ"},
"reserving":	{"VBG"},
"reservist":	{"NN"},
"reservists":	{"NNS"},
"reservoir":	{"NN"},
"reservoirs":	{"NNS"},
"reset":	{"VB","VBP","VBD","VBN","NN","JJ"},
"resets":	{"VBZ","NNS"},
"resettable":	{"JJ"},
"resetting":	{"VBG"},
"resettle":	{"VB","VBP"},
"resettled":	{"VBD","VBN"},
"resettlement":	{"NN"},
"resettles":	{"VBZ"},
"resettling":	{"VBG"},
"resew":	{"VB","VBP"},
"resh":	{"NN"},
"reshape":	{"VB","VBP"},
"reshaped":	{"VBD","VBN"},
"reshapes":	{"VBZ"},
"reshaping":	{"VBG","NN"},
"reship":	{"VB","VBP"},
"reshipment":	{"NN"},
"reshipped":	{"VBD","VBN"},
"reshipping":	{"VBG"},
"reships":	{"VBZ"},
"reshoot":	{"VB","VBP"},
"reshooting":	{"VBG"},
"reshoots":	{"VBZ"},
"reshot":	{"VBD","VBN"},
"resht":	{"NN"},
"reshuffle":	{"NN","VB","VBP"},
"reshuffled":	{"VBD","VBN"},
"reshuffles":	{"NNS","VBZ"},
"reshuffling":	{"NN","VBG"},
"reshufflings":	{"NNS"},
"resid":	{"NN"},
"reside":	{"VB","VBP"},
"resided":	{"VBD","VBN"},
"residence":	{"NN"},
"residences":	{"NNS"},
"residencies":	{"NNS"},
"residency":	{"NN"},
"resident":	{"NN","JJ"},
"residential":	{"JJ"},
"residentially":	{"RB"},
"residents":	{"NNS"},
"resides":	{"VBZ"},
"residing":	{"VBG"},
"residua":	{"NNS"},
"residual":	{"JJ","NN"},
"residually":	{"RB"},
"residuals":	{"NNS"},
"residuary":	{"JJ"},
"residue":	{"NN"},
"residues":	{"NNS"},
"residuum":	{"NN"},
"resift":	{"VB","VBP"},
"resifted":	{"VBD","VBN"},
"resifting":	{"VBG"},
"resifts":	{"VBZ"},
"resign":	{"VB","VBP"},
"resignation":	{"NN"},
"resignations":	{"NNS"},
"resigned":	{"VBD","VBN","JJ"},
"resignedly":	{"RB"},
"resigning":	{"VBG"},
"resigns":	{"VBZ"},
"resile":	{"VB","VBP"},
"resiled":	{"VBD","VBN"},
"resiles":	{"VBZ"},
"resilience":	{"NN"},
"resiliency":	{"NN"},
"resilient":	{"JJ"},
"resiliently":	{"RB"},
"resiling":	{"VBG"},
"resin":	{"VB","VBP","NN"},
"resinate":	{"VB","VBP"},
"resinated":	{"VBD","VBN"},
"resinates":	{"VBZ"},
"resinating":	{"VBG"},
"resined":	{"VBD","VBN"},
"resining":	{"VBG"},
"resinlike":	{"JJ"},
"resinoid":	{"NN","JJ"},
"resinous":	{"JJ"},
"resins":	{"VBZ","NNS"},
"resiny":	{"JJ"},
"resist":	{"VB","VBP"},
"resistance":	{"NN"},
"resistances":	{"NNS"},
"resistant":	{"JJ"},
"resisted":	{"VBD","VBN"},
"resister":	{"NN"},
"resisters":	{"NNS"},
"resistible":	{"JJ"},
"resisting":	{"VBG"},
"resistive":	{"JJ"},
"resistivity":	{"NN"},
"resistless":	{"JJ"},
"resistor":	{"NN"},
"resistors":	{"NNS"},
"resists":	{"VBZ"},
"resize":	{"VB","VBP"},
"resized":	{"VBD","VBN"},
"resizes":	{"VBZ"},
"resizing":	{"VBG"},
"reskill":	{"VB","VBP"},
"reskilled":	{"VBD","VBN"},
"reskilling":	{"VBG"},
"reskills":	{"VBZ"},
"resnick":	{"NN"},
"resold":	{"VBD","VBN"},
"resole":	{"VB","VBP"},
"resoled":	{"VBD","VBN"},
"resoles":	{"VBZ"},
"resoling":	{"VBG"},
"resolute":	{"JJ"},
"resolutely":	{"RB"},
"resoluteness":	{"NN"},
"resolution":	{"NN"},
"resolutions":	{"NNS"},
"resolvable":	{"JJ"},
"resolve":	{"VB","NN","VBP"},
"resolved":	{"VBN","VBD","JJ"},
"resolvent":	{"NN","JJ"},
"resolves":	{"VBZ","NNS"},
"resolving":	{"VBG"},
"resonable":	{"JJ"},
"resonance":	{"NN"},
"resonances":	{"NNS"},
"resonant":	{"JJ"},
"resonantly":	{"RB"},
"resonate":	{"VB","VBP"},
"resonated":	{"VBD","VBN"},
"resonates":	{"VBZ"},
"resonating":	{"VBG"},
"resonator":	{"NN"},
"resonators":	{"NNS"},
"resorb":	{"VB","VBP"},
"resorbed":	{"VBD","VBN"},
"resorbing":	{"VBG"},
"resorbs":	{"VBZ"},
"resorcinol":	{"NN"},
"resorcinolphthalein":	{"NN"},
"resorption":	{"NN"},
"resort":	{"NN","VB","VBP"},
"resorted":	{"VBD","VBN"},
"resorting":	{"VBG"},
"resorts":	{"NNS","VBZ"},
"resound":	{"VB","VBP"},
"resounded":	{"VBD","VBN"},
"resounding":	{"JJ","VBG"},
"resoundingly":	{"RB"},
"resounds":	{"VBZ"},
"resource":	{"NN","VB","VBP"},
"resourced":	{"VBD","VBN"},
"resourceful":	{"JJ"},
"resourcefully":	{"RB"},
"resourcefulness":	{"NN"},
"resourceless":	{"JJ"},
"resources":	{"NNS","VBZ"},
"resourcing":	{"VBG"},
"respect":	{"NN","VB","VBP"},
"respectability":	{"NN"},
"respectable":	{"JJ"},
"respectably":	{"RB"},
"respected":	{"JJ","VBN","VBD"},
"respecter":	{"NN"},
"respecters":	{"NNS"},
"respectful":	{"JJ"},
"respectfully":	{"RB"},
"respectfulness":	{"NN"},
"respecting":	{"VBG","IN"},
"respective":	{"JJ"},
"respectively":	{"RB"},
"respects":	{"NNS","VBZ"},
"respighi":	{"NN"},
"respiration":	{"NN"},
"respirator":	{"NN"},
"respirators":	{"NNS"},
"respiratory":	{"JJ"},
"respire":	{"VB","VBP"},
"respired":	{"VBD","VBN"},
"respires":	{"VBZ"},
"respiring":	{"VBG"},
"respite":	{"NN","VB","VBP"},
"respited":	{"VBD","VBN"},
"respiteless":	{"JJ"},
"respites":	{"VBZ"},
"respiting":	{"VBG"},
"resplend":	{"VB","VBP"},
"resplendence":	{"NN"},
"resplendency":	{"NN"},
"resplendent":	{"JJ"},
"resplendently":	{"RB"},
"respond":	{"VB","VBP"},
"responded":	{"VBD","VBN"},
"respondent":	{"NN"},
"respondents":	{"NNS"},
"responder":	{"NN"},
"responders":	{"NNS"},
"responding":	{"VBG"},
"responds":	{"VBZ"},
"response":	{"NN"},
"responses":	{"NNS"},
"responsibilities":	{"NNS"},
"responsibility":	{"NN"},
"responsible":	{"JJ"},
"responsibleness":	{"NN"},
"responsiblilty":	{"NN"},
"responsibly":	{"RB"},
"responsive":	{"JJ"},
"responsively":	{"RB"},
"responsiveness":	{"NN"},
"rest":	{"NN","VB","VBP"},
"rest-cure":	{"NN"},
"rest-day":	{"NN"},
"rest-home":	{"NN"},
"rest-room":	{"NN"},
"restaff":	{"VB","VBP"},
"restaffed":	{"VBD","VBN"},
"restaffing":	{"VBG"},
"restaffs":	{"VBZ"},
"restage":	{"VB","VBP"},
"restaged":	{"VBD","VBN"},
"restages":	{"VBZ"},
"restaging":	{"VBG"},
"restart":	{"VB","VBP","NN"},
"restarted":	{"VBN","VBD"},
"restarters":	{"VBZ","NNS"},
"restarting":	{"VBG"},
"restate":	{"VB","VBP"},
"restated":	{"VBD","VBN"},
"restatement":	{"NN"},
"restatements":	{"NNS"},
"restates":	{"VBZ"},
"restating":	{"VBG"},
"restaurant":	{"NN"},
"restaurants":	{"NNS"},
"restaurateur":	{"NN"},
"restaurateurs":	{"NNS"},
"rested":	{"VBD","VBN","JJ"},
"rester":	{"NN"},
"restful":	{"JJ"},
"restfully":	{"RB"},
"restfulness":	{"NN"},
"restharrow":	{"NN"},
"resting":	{"VBG"},
"resting-place":	{"NN"},
"restitute":	{"VB","VBP"},
"restituted":	{"VBD","VBN"},
"restitutes":	{"VBZ"},
"restituting":	{"VBG"},
"restitution":	{"NN"},
"restive":	{"JJ"},
"restively":	{"RB"},
"restiveness":	{"NN"},
"restless":	{"JJ"},
"restlessly":	{"RB"},
"restlessness":	{"NN"},
"restock":	{"VB","VBP"},
"restocked":	{"VBD","VBN"},
"restocking":	{"VBG"},
"restocks":	{"VBZ"},
"restorability":	{"NN"},
"restoration":	{"NN"},
"restorations":	{"NNS"},
"restorative":	{"NN","JJ"},
"restoratives":	{"NNS"},
"restore":	{"VB","VBP"},
"restored":	{"VBN","VBD","JJ"},
"restorer":	{"NN"},
"restorers":	{"NNS"},
"restores":	{"VBZ"},
"restoril":	{"NN"},
"restoring":	{"VBG"},
"restrain":	{"VB","VBP"},
"restrained":	{"JJ","VBD","VBN"},
"restrainer":	{"NN"},
"restraining":	{"NN","VBG"},
"restrains":	{"VBZ"},
"restraint":	{"NN"},
"restraints":	{"NNS"},
"restrengthen":	{"VB","VBP"},
"restrict":	{"VB","VBP"},
"restricted":	{"VBN","JJ","VBD"},
"restricting":	{"VBG"},
"restriction":	{"NN"},
"restrictions":	{"NNS"},
"restrictive":	{"JJ"},
"restrictively":	{"RB"},
"restrictiveness":	{"NN"},
"restricts":	{"VBZ"},
"restroom":	{"NN"},
"restrooms":	{"NNS"},
"restructure":	{"VB","VBP"},
"restructured":	{"VBD","VBN"},
"restructures":	{"VBZ"},
"restructuring":	{"NN","VBG"},
"restructurings":	{"NNS"},
"rests":	{"VBZ","NNS"},
"restudied":	{"VBD","VBN"},
"restudies":	{"VBZ"},
"restudy":	{"VB","VBP"},
"restudying":	{"VBG"},
"restyle":	{"VB","VBP"},
"restyled":	{"VBD","VBN"},
"restyles":	{"VBZ"},
"restyling":	{"VBG"},
"resublime":	{"VB","VBP"},
"resublimed":	{"VBD","VBN"},
"resublimes":	{"VBZ"},
"resubliming":	{"VBG"},
"resubmit":	{"VB","VBP"},
"resubmits":	{"VBZ"},
"resubmitted":	{"VBD","VBN"},
"resubmitting":	{"VBG"},
"result":	{"NN","VB","VBP","UH"},
"resultant":	{"JJ","NN"},
"resultants":	{"NNS"},
"resulted":	{"VBD","VBN"},
"resulting":	{"VBG"},
"results":	{"NNS","VBZ"},
"resume":	{"VB","NN","VBP"},
"resumed":	{"VBD","VBN"},
"resumes":	{"VBZ","NNS"},
"resuming":	{"VBG"},
"resumption":	{"NN"},
"resupine":	{"JJ"},
"resupplied":	{"VBD","VBN"},
"resupplies":	{"VBZ"},
"resupply":	{"VB","VBP","NN"},
"resupplying":	{"VBG"},
"resurface":	{"VB","VBP"},
"resurfaced":	{"VBD","VBN"},
"resurfaces":	{"VBZ"},
"resurfacing":	{"VBG"},
"resurge":	{"VB","VBP"},
"resurged":	{"VBD","VBN"},
"resurgence":	{"NN"},
"resurgent":	{"JJ"},
"resurges":	{"VBZ"},
"resurging":	{"VBG"},
"resurrect":	{"VB","VBP"},
"resurrected":	{"VBD","VBN"},
"resurrecting":	{"VBG"},
"resurrection":	{"NN"},
"resurrects":	{"VBZ"},
"resurvey":	{"NN"},
"resuscitate":	{"VB","VBP"},
"resuscitated":	{"VBD","VBN"},
"resuscitates":	{"VBZ"},
"resuscitating":	{"VBG"},
"resuscitation":	{"NN"},
"resuscitator":	{"NN"},
"resuspend":	{"VB","VBP"},
"resuspended":	{"VBD","VBN"},
"resuspending":	{"VBG"},
"resuspends":	{"VBZ"},
"resuspension":	{"NN"},
"ret":	{"VB","VBP"},
"retablos":	{"FW"},
"retail":	{"NN","VB","VBP","RB","JJ"},
"retailed":	{"VBD","VBN"},
"retailer":	{"NN"},
"retailers":	{"NNS"},
"retailing":	{"NN","VBG"},
"retails":	{"VBZ"},
"retain":	{"VB","VBP"},
"retained":	{"VBN","VBD"},
"retainer":	{"NN"},
"retainers":	{"NNS"},
"retaining":	{"VBG"},
"retains":	{"VBZ"},
"retake":	{"VB","VBP","NN"},
"retaken":	{"VBN"},
"retakes":	{"VBZ","NNS"},
"retaking":	{"VBG","NN"},
"retaliate":	{"VB","VBP"},
"retaliated":	{"VBD","VBN"},
"retaliates":	{"VBZ"},
"retaliating":	{"VBG"},
"retaliation":	{"NN"},
"retaliator":	{"NN"},
"retaliatory":	{"JJ"},
"retama":	{"NN"},
"retard":	{"VB","VBP","NN"},
"retardant":	{"NN","JJ"},
"retardants":	{"NNS"},
"retardation":	{"NN"},
"retarded":	{"JJ","VBD","VBN"},
"retardent":	{"NN"},
"retarding":	{"VBG"},
"retards":	{"VBZ","NNS"},
"retarget":	{"VB","VBP"},
"retargeted":	{"VBD","VBN"},
"retargeting":	{"VBG"},
"retargets":	{"VBZ"},
"retch":	{"VB","VBP"},
"retched":	{"VBD","VBN"},
"retches":	{"VBZ"},
"retching":	{"VBG"},
"rete":	{"NN"},
"reteam":	{"VB","VBP"},
"reteamed":	{"VBD","VBN"},
"reteaming":	{"VBG"},
"reteams":	{"VBZ"},
"retell":	{"VB","VBP"},
"retelling":	{"VBG","NN"},
"retellings":	{"NNS"},
"retells":	{"VBZ"},
"retem":	{"NN"},
"retention":	{"NN"},
"retentive":	{"JJ"},
"retentively":	{"RB"},
"retentiveness":	{"NN"},
"retentivity":	{"NN"},
"rethink":	{"VB","VBP","NN"},
"rethinking":	{"VBG","NN"},
"rethought":	{"VBD","VBN"},
"reticence":	{"NN"},
"reticent":	{"JJ"},
"reticently":	{"RB"},
"reticle":	{"NN"},
"reticular":	{"JJ"},
"reticulate":	{"JJ","VB","VBP"},
"reticulated":	{"VBD","VBN"},
"reticulately":	{"RB"},
"reticulates":	{"VBZ"},
"reticulating":	{"VBG"},
"reticulation":	{"NN"},
"reticule":	{"NN"},
"reticulocyte":	{"NN"},
"reticulum":	{"NN"},
"retie":	{"VB","VBP"},
"retied":	{"VBD","VBN"},
"reties":	{"VBZ"},
"retina":	{"NN"},
"retinal":	{"JJ"},
"retinas":	{"NNS"},
"retinene":	{"NN"},
"retinitis":	{"NN"},
"retinoblastoma":	{"NN"},
"retinol":	{"NN"},
"retinopathy":	{"NN"},
"retinue":	{"NN"},
"retinues":	{"NNS"},
"retire":	{"VB","VBP"},
"retired":	{"JJ","VBD","VBN"},
"retiree":	{"NN"},
"retirees":	{"NNS"},
"retirement":	{"NN"},
"retirements":	{"NNS"},
"retires":	{"VBZ"},
"retiring":	{"VBG","JJ"},
"retold":	{"VBD","VBN"},
"retook":	{"VBD"},
"retool":	{"VB","VBP"},
"retooled":	{"VBD","VBN"},
"retooling":	{"NN","VBG"},
"retools":	{"VBZ"},
"retort":	{"VB","VBP","NN"},
"retorted":	{"VBD","VBN"},
"retorting":	{"VBG"},
"retorts":	{"NNS","VBZ"},
"retouch":	{"VB","VBP","NN"},
"retouchable":	{"JJ"},
"retouched":	{"VBD","VBN"},
"retoucher":	{"NN"},
"retouches":	{"VBZ"},
"retouching":	{"VBG"},
"retrace":	{"VB","VBP"},
"retraced":	{"VBD","VBN"},
"retraces":	{"VBZ"},
"retracing":	{"VBG"},
"retract":	{"VB","VBP"},
"retractable":	{"JJ"},
"retracted":	{"VBD","VBN"},
"retractile":	{"JJ"},
"retracting":	{"VBG"},
"retraction":	{"NN"},
"retractions":	{"NNS"},
"retractor":	{"NN"},
"retractors":	{"NNS"},
"retracts":	{"VBZ"},
"retrain":	{"VB","VBP"},
"retrained":	{"VBD","VBN"},
"retraining":	{"VBG","NN"},
"retrains":	{"VBZ"},
"retral":	{"JJ"},
"retrally":	{"RB"},
"retranslate":	{"VB","VBP"},
"retranslated":	{"VBD","VBN"},
"retranslates":	{"VBZ"},
"retranslating":	{"VBG"},
"retransmission":	{"NN"},
"retransmissions":	{"NNS"},
"retransmit":	{"VB","VBP"},
"retransmits":	{"VBZ"},
"retransmitted":	{"VBD","VBN"},
"retransmitting":	{"VBG"},
"retread":	{"VB","VBP","NN"},
"retreaded":	{"VBD","VBN"},
"retreading":	{"VBG"},
"retreads":	{"VBZ","NNS"},
"retreat":	{"VB","VBP","NN"},
"retreatant":	{"NN"},
"retreated":	{"VBD","VBN"},
"retreating":	{"VBG"},
"retreats":	{"NNS","VBZ"},
"retrench":	{"VB","VBP"},
"retrenched":	{"VBD","VBN"},
"retrenches":	{"VBZ"},
"retrenching":	{"VBG"},
"retrenchment":	{"NN"},
"retrenchments":	{"NNS"},
"retrial":	{"NN"},
"retrials":	{"NNS"},
"retribution":	{"NN"},
"retributive":	{"JJ"},
"retributory":	{"JJ"},
"retried":	{"VBD","VBN"},
"retries":	{"VBZ"},
"retrievable":	{"JJ"},
"retrieval":	{"NN"},
"retrieve":	{"VB","VBP"},
"retrieved":	{"VBN","VBD"},
"retriever":	{"NN"},
"retrievers":	{"NNS"},
"retrieves":	{"VBZ"},
"retrieving":	{"VBG"},
"retro":	{"JJ","NN"},
"retroactive":	{"JJ"},
"retroactively":	{"RB"},
"retroactivity":	{"NN"},
"retrofit":	{"VB","VBP","NN"},
"retrofits":	{"VBZ","NNS"},
"retrofitted":	{"VBN","VBD"},
"retrofitting":	{"NN","VBG"},
"retroflection":	{"NN"},
"retroflex":	{"JJ","NN"},
"retroflexed":	{"JJ"},
"retroflexion":	{"NN"},
"retrogradation":	{"NN"},
"retrogradations":	{"NNS"},
"retrograde":	{"JJ","VB","VBP"},
"retrograded":	{"VBD","VBN"},
"retrogradely":	{"RB"},
"retrogrades":	{"VBZ"},
"retrograding":	{"VBG"},
"retrogress":	{"VB","VBP"},
"retrogressed":	{"VBD","VBN"},
"retrogresses":	{"VBZ"},
"retrogressing":	{"VBG"},
"retrogression":	{"NN"},
"retrogressive":	{"JJ"},
"retrogressively":	{"RB"},
"retronym":	{"NN"},
"retrophyllum":	{"NN"},
"retrorocket":	{"NN"},
"retrorse":	{"JJ"},
"retros":	{"NNS"},
"retrospect":	{"NN","VB","VBP"},
"retrospected":	{"VBD","VBN"},
"retrospecting":	{"VBG"},
"retrospection":	{"NN"},
"retrospective":	{"JJ","NN"},
"retrospectively":	{"RB"},
"retrospectives":	{"NNS"},
"retrospects":	{"VBZ"},
"retrousse":	{"JJ","FW"},
"retroversion":	{"NN"},
"retrovert":	{"VB","VBP"},
"retrovir":	{"NN"},
"retroviral":	{"JJ"},
"retrovirus":	{"NN"},
"retroviruses":	{"NNS"},
"retrovision":	{"NN"},
"retry":	{"VB","VBP"},
"retrying":	{"VBG"},
"rets":	{"VBZ"},
"retsina":	{"NN"},
"retted":	{"VBD","VBN"},
"retting":	{"VBG"},
"return":	{"VB","VBP","NN","JJ"},
"returnable":	{"JJ"},
"returned":	{"VBD","VBN","JJ"},
"returnee":	{"NN"},
"returnees":	{"NNS"},
"returner":	{"NN"},
"returners":	{"NNS"},
"returning":	{"VBG"},
"returns":	{"NNS","VBZ"},
"retweet":	{"VB","VBP"},
"retweeted":	{"VBD","VBN"},
"retweeting":	{"VBG"},
"retweets":	{"VBZ"},
"retying":	{"VBG"},
"reuben":	{"NN"},
"reunification":	{"NN"},
"reunified":	{"VBD","VBN"},
"reunifies":	{"VBZ"},
"reunify":	{"VB","VBP"},
"reunifying":	{"VBG"},
"reunion":	{"NN"},
"reunions":	{"NNS"},
"reunite":	{"VB","VBP"},
"reunited":	{"VBN","VBD"},
"reunites":	{"VBZ"},
"reuniting":	{"VBG"},
"reupholster":	{"VB","VBP"},
"reupholstered":	{"VBD","VBN"},
"reupholstering":	{"VBG"},
"reupholsters":	{"VBZ"},
"reuptake":	{"NN"},
"reusable":	{"JJ"},
"reuse":	{"VB","VBP","NN"},
"reused":	{"VBD","VBN"},
"reuses":	{"VBZ"},
"reusing":	{"VBG"},
"reuter":	{"NN"},
"rev":	{"NN","VB","VBP"},
"revaluation":	{"NN"},
"revaluations":	{"NNS"},
"revalue":	{"VB","VBP"},
"revalued":	{"VBD","VBN"},
"revalues":	{"VBZ"},
"revaluing":	{"VBG"},
"revamp":	{"VB","VBP","NN"},
"revamped":	{"VBD","VBN"},
"revamping":	{"VBG","NN"},
"revamps":	{"VBZ"},
"reveal":	{"VB","VBP"},
"revealed":	{"VBD","VBN"},
"revealing":	{"VBG","JJ"},
"revealingly":	{"RB"},
"reveals":	{"VBZ"},
"reveille":	{"NN"},
"revel":	{"VB","NN","VBP"},
"revelation":	{"NN"},
"revelations":	{"NNS"},
"revelatory":	{"JJ"},
"reveled":	{"VBD","VBN"},
"reveler":	{"NN"},
"revelers":	{"NNS"},
"reveling":	{"VBG"},
"revelled":	{"VBD","VBN"},
"reveller":	{"NN"},
"revellers":	{"NNS"},
"revelling":	{"VBG"},
"revelries":	{"NNS"},
"revelry":	{"NN"},
"revels":	{"VBZ","NNS"},
"revenant":	{"NN"},
"revenge":	{"NN","VB","VBP"},
"revenged":	{"VBD","VBN"},
"revengeful":	{"JJ"},
"revengefully":	{"RB"},
"revenges":	{"VBZ"},
"revenging":	{"VBG"},
"revenue":	{"NN"},
"revenuer":	{"NN"},
"revenuers":	{"NNS"},
"revenues":	{"NNS"},
"reverberance":	{"NN"},
"reverberant":	{"JJ"},
"reverberate":	{"VB","VBP"},
"reverberated":	{"VBD","VBN"},
"reverberates":	{"VBZ"},
"reverberating":	{"VBG"},
"reverberation":	{"NN"},
"reverberations":	{"NNS"},
"reverberative":	{"JJ"},
"revere":	{"VB","VBP"},
"revered":	{"VBD","VBN","JJ"},
"reverence":	{"NN","VB","VBP"},
"reverenced":	{"VBD","VBN"},
"reverences":	{"NNS","VBZ"},
"reverencing":	{"VBG"},
"reverend":	{"NN","JJ"},
"reverent":	{"JJ"},
"reverential":	{"JJ"},
"reverentially":	{"RB"},
"reverently":	{"RB"},
"reveres":	{"VBZ"},
"reverie":	{"NN"},
"reveries":	{"NNS"},
"revering":	{"VBG"},
"revers":	{"NNS","NN"},
"reversal":	{"NN"},
"reversals":	{"NNS"},
"reverse":	{"VB","VBP","NN","JJ"},
"reverse-engineering":	{"NN"},
"reversed":	{"VBD","VBN"},
"reversely":	{"RB"},
"reverses":	{"VBZ","NNS"},
"reversibility":	{"NN"},
"reversible":	{"JJ"},
"reversibly":	{"RB"},
"reversing":	{"VBG"},
"reversion":	{"NN"},
"reversionary":	{"JJ"},
"reversioner":	{"NN"},
"reversionist":	{"NN"},
"reversions":	{"NNS"},
"reversive":	{"JJ"},
"revert":	{"VB","VBP"},
"reverted":	{"VBD","VBN"},
"revertible":	{"JJ"},
"reverting":	{"VBG"},
"reverts":	{"VBZ"},
"revery":	{"NN"},
"revet":	{"VB","VBP"},
"revetment":	{"NN"},
"revetments":	{"NNS"},
"revets":	{"VBZ"},
"revetted":	{"VBD","VBN"},
"revetting":	{"VBG"},
"review":	{"NN","VB","VBP"},
"reviewed":	{"VBN","VBD"},
"reviewer":	{"NN"},
"reviewers":	{"NNS"},
"reviewing":	{"VBG"},
"reviews":	{"NNS","VBZ"},
"revile":	{"VB","VBP"},
"reviled":	{"VBD","VBN"},
"revilement":	{"NN"},
"reviles":	{"VBZ"},
"reviling":	{"VBG"},
"revisal":	{"NN"},
"revise":	{"VB","VBP","NN"},
"revised":	{"VBN","JJ","VBD"},
"reviser":	{"NN"},
"revisers":	{"NNS"},
"revises":	{"VBZ","NNS"},
"revising":	{"VBG"},
"revision":	{"NN"},
"revisionism":	{"NN"},
"revisionist":	{"JJ","NN"},
"revisionists":	{"NNS"},
"revisions":	{"NNS"},
"revisit":	{"VB","VBP"},
"revisited":	{"VBD","VBN"},
"revisiting":	{"VBG"},
"revisits":	{"VBZ"},
"revitalisation":	{"NN"},
"revitalise":	{"VB","VBP"},
"revitalised":	{"VBD","VBN"},
"revitalises":	{"VBZ"},
"revitalising":	{"VBG"},
"revitalization":	{"NN"},
"revitalize":	{"VB","VBP"},
"revitalized":	{"VBD","VBN"},
"revitalizes":	{"VBZ"},
"revitalizing":	{"VBG"},
"revival":	{"NN"},
"revivalism":	{"NN"},
"revivalist":	{"NN","JJ"},
"revivalistic":	{"JJ"},
"revivalists":	{"NNS"},
"revivals":	{"NNS"},
"revive":	{"VB","VBP"},
"revived":	{"VBN","VBD","JJ"},
"revives":	{"VBZ"},
"revivification":	{"NN"},
"revivified":	{"VBD","VBN"},
"revivifies":	{"VBZ"},
"revivify":	{"VB","VBP"},
"revivifying":	{"VBG"},
"reviving":	{"NN","VBG"},
"revocable":	{"JJ"},
"revocation":	{"NN"},
"revocations":	{"NNS"},
"revokable":	{"JJ"},
"revoke":	{"VB","VBP"},
"revoked":	{"VBN","VBD"},
"revokes":	{"VBZ"},
"revoking":	{"VBG"},
"revolt":	{"NN","VB","VBP"},
"revolted":	{"VBD","VBN"},
"revolting":	{"JJ","VBG"},
"revoltingly":	{"RB"},
"revolts":	{"NNS","VBZ"},
"revolution":	{"NN"},
"revolutionaries":	{"NNS"},
"revolutionary":	{"JJ","NN"},
"revolutionise":	{"VB","VBP"},
"revolutionised":	{"VBD","VBN"},
"revolutionises":	{"VBZ"},
"revolutionising":	{"VBG"},
"revolutionism":	{"NN"},
"revolutionist":	{"NN","JJ"},
"revolutionists":	{"NNS"},
"revolutionize":	{"VB","VBP"},
"revolutionized":	{"VBD","VBN"},
"revolutionizes":	{"VBZ"},
"revolutionizing":	{"VBG"},
"revolutions":	{"NNS"},
"revolve":	{"VB","VBP"},
"revolved":	{"VBD","VBN"},
"revolver":	{"NN"},
"revolvers":	{"NNS"},
"revolves":	{"VBZ"},
"revolving":	{"JJ","VBG"},
"revs":	{"NNS","VBZ"},
"revue":	{"NN"},
"revues":	{"NNS"},
"revulsion":	{"NN"},
"revved":	{"VBD","VBN"},
"revving":	{"VBG"},
"rewa-rewa":	{"NN"},
"reward":	{"NN","VB","VBP"},
"rewarded":	{"VBN","VBD"},
"rewardful":	{"JJ"},
"rewarding":	{"JJ","VBG"},
"rewardingly":	{"RB"},
"rewards":	{"NNS","VBZ"},
"reweave":	{"VB","VBP"},
"rewild":	{"VB","VBP"},
"rewilded":	{"VBD","VBN"},
"rewilding":	{"NN","VBG"},
"rewilds":	{"VBZ"},
"rewire":	{"VB","VBP"},
"rewired":	{"VBD","VBN"},
"rewires":	{"VBZ"},
"rewiring":	{"VBG","NN"},
"reword":	{"VB","VBP"},
"reworded":	{"VBD","VBN"},
"rewording":	{"VBG"},
"rewords":	{"VBZ"},
"rework":	{"VB","VBP"},
"reworked":	{"VBD","VBN"},
"reworking":	{"VBG","NN"},
"reworkings":	{"NNS"},
"reworks":	{"VBZ"},
"rewrap":	{"VB","VBP"},
"rewrapped":	{"VBD","VBN"},
"rewrapping":	{"VBG"},
"rewraps":	{"VBZ"},
"rewrite":	{"VB","VBP","NN"},
"rewriter":	{"NN"},
"rewriters":	{"NNS"},
"rewrites":	{"VBZ","NNS"},
"rewriting":	{"VBG"},
"rewritten":	{"VBN"},
"rewrote":	{"VBD"},
"rewt":	{"NN"},
"reykjavik":	{"NN"},
"reynard":	{"NN"},
"reynolds":	{"NNS"},
"rh":	{"NN"},
"rh-positive":	{"JJ"},
"rhabdomancer":	{"NN"},
"rhabdomancy":	{"NN"},
"rhabdomyoma":	{"NN"},
"rhabdomyosarcoma":	{"NN"},
"rhabdosarcoma":	{"NN"},
"rhabdoviridae":	{"NN"},
"rhabdovirus":	{"NN"},
"rhadamanthus":	{"NNS"},
"rhaeto-romance":	{"NN"},
"rhaeto-romanic":	{"NN"},
"rhagades":	{"NNS"},
"rhagoletis":	{"NN"},
"rhamnaceae":	{"NN"},
"rhamnales":	{"NNS"},
"rhamnus":	{"NN"},
"rhaphe":	{"NN"},
"rhapis":	{"NN"},
"rhapsodic":	{"JJ"},
"rhapsodically":	{"RB"},
"rhapsodise":	{"VB","VBP"},
"rhapsodised":	{"VBD","VBN"},
"rhapsodises":	{"VBZ"},
"rhapsodising":	{"VBG"},
"rhapsodize":	{"VB","VBP"},
"rhapsodized":	{"VBD","VBN"},
"rhapsodizes":	{"VBZ"},
"rhapsodizing":	{"VBG"},
"rhapsody":	{"NN"},
"rhd":	{"NN"},
"rhea":	{"NN"},
"rheidae":	{"NN"},
"rheiformes":	{"NNS"},
"rheims":	{"NN"},
"rhein":	{"NN"},
"rheinland":	{"NN"},
"rhenish":	{"JJ","NN"},
"rhenium":	{"NN"},
"rheologic":	{"JJ"},
"rheological":	{"JJ"},
"rheology":	{"NN"},
"rheometer":	{"NN"},
"rheostat":	{"NN"},
"rhesis":	{"NN"},
"rhesus":	{"NN"},
"rhetoric":	{"NN"},
"rhetorical":	{"JJ"},
"rhetorically":	{"RB"},
"rhetorician":	{"NN"},
"rhetoricians":	{"NNS"},
"rheum":	{"NN"},
"rheumatic":	{"JJ","NN"},
"rheumatics":	{"NNS"},
"rheumatism":	{"NN"},
"rheumatoid":	{"JJ"},
"rheumatologist":	{"NN"},
"rheumatologists":	{"NNS"},
"rheumatology":	{"NN"},
"rheumy":	{"JJ"},
"rhexia":	{"NN"},
"rhibhus":	{"NN"},
"rhinal":	{"JJ"},
"rhincodon":	{"NN"},
"rhincodontidae":	{"NN"},
"rhine":	{"NN"},
"rhineland":	{"NN"},
"rhinencephalon":	{"NN"},
"rhinestone":	{"NN"},
"rhinestones":	{"NNS"},
"rhinion":	{"NN"},
"rhinitis":	{"NN"},
"rhino":	{"NN","NNS"},
"rhinobatidae":	{"NN"},
"rhinoceros":	{"NN","NNS"},
"rhinoceroses":	{"NNS"},
"rhinocerotidae":	{"NN"},
"rhinolaryngologist":	{"NN"},
"rhinolaryngology":	{"NN"},
"rhinolophidae":	{"NN"},
"rhinonicteris":	{"NN"},
"rhinopathy":	{"NN"},
"rhinophyma":	{"NN"},
"rhinoplasty":	{"NN"},
"rhinoptera":	{"NN"},
"rhinorrhea":	{"NN"},
"rhinos":	{"NNS"},
"rhinoscope":	{"NN"},
"rhinoscopy":	{"NN"},
"rhinosporidiosis":	{"NN"},
"rhinostenosis":	{"NN"},
"rhinotermitidae":	{"NN"},
"rhinotomy":	{"NN"},
"rhinotracheitis":	{"NN"},
"rhinovirus":	{"NN"},
"rhinovirus-receptors":	{"NNS"},
"rhipsalis":	{"NN"},
"rhiptoglossa":	{"NN"},
"rhizobacteria":	{"NN"},
"rhizobiaceae":	{"NN"},
"rhizobium":	{"NN"},
"rhizoctinia":	{"NN"},
"rhizoid":	{"JJ","NN"},
"rhizoidal":	{"JJ"},
"rhizoids":	{"NNS"},
"rhizomatous":	{"JJ"},
"rhizome":	{"NN"},
"rhizomes":	{"NNS"},
"rhizomorph":	{"NN"},
"rhizophora":	{"NN"},
"rhizophoraceae":	{"NN"},
"rhizopod":	{"NN"},
"rhizopoda":	{"NN"},
"rhizopodan":	{"NN"},
"rhizopogon":	{"NN"},
"rhizopogonaceae":	{"NN"},
"rhizopus":	{"NN"},
"rhizotomy":	{"NN"},
"rho":	{"NN"},
"rhodanthe":	{"NN"},
"rhodes":	{"NNS"},
"rhodesia":	{"NN"},
"rhodium":	{"NN"},
"rhodochrosite":	{"NN"},
"rhododendron":	{"NN"},
"rhododendrons":	{"NNS"},
"rhodolite":	{"NN"},
"rhodomontade":	{"NN"},
"rhodonite":	{"NN"},
"rhodophyceae":	{"NN"},
"rhodophyta":	{"NN"},
"rhodopsin":	{"NN"},
"rhodosphaera":	{"NN"},
"rhodymenia":	{"NN"},
"rhodymeniaceae":	{"NN"},
"rhoeadales":	{"NNS"},
"rhomb":	{"NN"},
"rhombencephalon":	{"NN"},
"rhombic":	{"JJ"},
"rhombohedral":	{"JJ"},
"rhombohedron":	{"NN"},
"rhomboid":	{"NN","JJ"},
"rhomboidal":	{"JJ"},
"rhomboids":	{"NNS"},
"rhombus":	{"NN"},
"rhombuses":	{"NNS"},
"rhonchus":	{"NN"},
"rhone":	{"NN"},
"rhone-alpes":	{"NNS"},
"rhubarb":	{"NN"},
"rhumb":	{"NN"},
"rhumba":	{"NN"},
"rhumbas":	{"NNS"},
"rhus":	{"NN"},
"rhyacotriton":	{"NN"},
"rhyme":	{"NN","VB","VBP"},
"rhymed":	{"VBD","VBN"},
"rhymeless":	{"JJ"},
"rhymer":	{"NN"},
"rhymers":	{"NNS"},
"rhymes":	{"NNS","VBZ"},
"rhymester":	{"NN"},
"rhymesters":	{"NNS"},
"rhyming":	{"VBG","JJ","NN"},
"rhynchocephalia":	{"NN"},
"rhynchoelaps":	{"NNS"},
"rhyncostylis":	{"NNS"},
"rhynia":	{"NN"},
"rhyniaceae":	{"NN"},
"rhyolite":	{"NN"},
"rhys":	{"NN"},
"rhythm":	{"NN"},
"rhythmic":	{"JJ"},
"rhythmical":	{"JJ"},
"rhythmically":	{"RB"},
"rhythmicity":	{"NN"},
"rhythms":	{"NNS"},
"rhytidectomy":	{"NN"},
"rhytidoplasty":	{"NN"},
"rial":	{"NN"},
"riant":	{"JJ"},
"riata":	{"NN"},
"rib":	{"NN","VB","VBP"},
"rib-cage":	{"NN"},
"rib-tickling":	{"JJ"},
"ribald":	{"JJ"},
"ribaldry":	{"NN"},
"riband":	{"NN"},
"ribavirin":	{"NN"},
"ribband":	{"NN"},
"ribbed":	{"JJ","VBD","VBN"},
"ribbies":	{"NNS"},
"ribbing":	{"NN","VBG"},
"ribbon":	{"NN","VB","VBP"},
"ribbon-like":	{"JJ"},
"ribboned":	{"VBD","VBN"},
"ribbonfish":	{"NN"},
"ribboning":	{"VBG"},
"ribbons":	{"NNS","VBZ"},
"ribbonwood":	{"NN"},
"ribbony":	{"JJ"},
"ribcage":	{"NN"},
"ribes":	{"NNS"},
"ribgrass":	{"NN"},
"ribhus":	{"NN"},
"ribier":	{"NN"},
"ribless":	{"JJ"},
"riblike":	{"JJ"},
"riboflavin":	{"NN"},
"ribonuclease":	{"NN"},
"ribonucleic":	{"JJ"},
"ribonucleinase":	{"NN"},
"ribose":	{"NN"},
"ribosomal":	{"JJ"},
"ribosome":	{"NN"},
"ribozyme":	{"NN"},
"ribozymes":	{"NNS"},
"ribs":	{"NNS","VBZ"},
"ribwort":	{"NN"},
"rice":	{"NN","VB","VBP"},
"rice-paper":	{"NN"},
"rice-processing":	{"JJ"},
"ricebird":	{"NN"},
"riced":	{"VBD","VBN"},
"ricegrass":	{"NN"},
"ricer":	{"NN"},
"rices":	{"VBZ","NNS"},
"rich":	{"JJ","NNS"},
"rich-affiliated":	{"JJ"},
"richardson":	{"NN"},
"riche":	{"NN"},
"richea":	{"NN"},
"richelieu":	{"NN"},
"richer":	{"JJR"},
"riches":	{"NNS"},
"richest":	{"JJS"},
"richey":	{"NN"},
"richissimos":	{"NNS"},
"richler":	{"NN"},
"richly":	{"RB"},
"richmond":	{"NN"},
"richmondena":	{"NN"},
"richness":	{"NN"},
"richterian":	{"JJ"},
"richweed":	{"NN"},
"ricin":	{"NN"},
"ricing":	{"VBG"},
"ricinus":	{"NN"},
"rick":	{"NN","VBP","VB"},
"ricked":	{"VBD","VBN"},
"rickenbacker":	{"NN"},
"ricketiness":	{"NN"},
"rickets":	{"NN"},
"rickettsia":	{"NN"},
"rickettsiaceae":	{"NN"},
"rickettsial":	{"JJ"},
"rickettsiales":	{"NNS"},
"rickettsialpox":	{"NN"},
"rickettsiosis":	{"NN"},
"rickety":	{"JJ"},
"rickey":	{"NN"},
"ricking":	{"VBG"},
"rickover":	{"NN"},
"rickrack":	{"NN"},
"ricks":	{"NNS","VBZ"},
"ricksha":	{"NN"},
"rickshaw":	{"NN"},
"rickshaws":	{"NNS"},
"rico":	{"NN"},
"ricochet":	{"VB","VBP","NN"},
"ricocheted":	{"VBD","VBN"},
"ricocheting":	{"VBG"},
"ricochets":	{"VBZ","NNS"},
"ricochetted":	{"VBD","VBN"},
"ricochetting":	{"VBG"},
"ricoing":	{"NN"},
"ricotta":	{"NN"},
"ricrac":	{"NN"},
"rictus":	{"NN"},
"rid":	{"VB","VBP","VBD","VBN","JJ"},
"riddance":	{"NN"},
"ridden":	{"VBN"},
"ridding":	{"VBG"},
"riddle":	{"NN","VB","VBP"},
"riddled":	{"JJ","VBD","VBN"},
"riddles":	{"NNS","VBZ"},
"riddling":	{"VBG"},
"ride":	{"NN","VB","VBP"},
"rider-fashion":	{"JJ"},
"riderless":	{"JJ"},
"riders":	{"NNS"},
"ridership":	{"NN"},
"rides":	{"NNS","VBZ"},
"ridge":	{"NN","VB","VBP"},
"ridge-pole":	{"NN"},
"ridge-tile":	{"NN"},
"ridged":	{"VBD","VBN","JJ"},
"ridgel":	{"NN"},
"ridgeline":	{"NN"},
"ridgeling":	{"NN"},
"ridgepole":	{"NN"},
"ridges":	{"NNS","VBZ"},
"ridgeway":	{"NN"},
"ridgil":	{"NN"},
"ridging":	{"VBG"},
"ridgling":	{"NN"},
"ridicule":	{"NN","VB","VBP"},
"ridiculed":	{"VBD","VBN"},
"ridiculer":	{"NN"},
"ridicules":	{"VBZ"},
"ridiculing":	{"VBG"},
"ridiculous":	{"JJ"},
"ridiculously":	{"RB"},
"ridiculousness":	{"NN"},
"riding":	{"VBG","NN"},
"riding-crop":	{"NN"},
"riding-school":	{"NN"},
"ridley":	{"NN"},
"rids":	{"VBZ"},
"riel":	{"NN"},
"riemann":	{"NN"},
"riemannian":	{"JJ"},
"riesman":	{"NN"},
"rifadin":	{"NN"},
"rifampin":	{"NN"},
"rife":	{"JJ"},
"riff":	{"NN","VB","VBP"},
"riffed":	{"VBD","VBN"},
"riffian":	{"NN"},
"riffing":	{"VBG"},
"riffle":	{"VB","VBP","NN"},
"riffled":	{"VBD","VBN"},
"riffles":	{"VBZ"},
"riffling":	{"VBG"},
"riffraff":	{"NN"},
"riffs":	{"NNS","VBZ"},
"rifkinesque":	{"JJ"},
"rifle":	{"NN","VB","VBP"},
"rifle-range":	{"NN"},
"rifle-shot":	{"NN"},
"rifle-shotgun":	{"NN"},
"riflebird":	{"NN"},
"rifled":	{"VBD","VBN"},
"rifleman":	{"NN"},
"riflemen":	{"NNS"},
"riflery":	{"NN"},
"rifles":	{"NNS","VBZ"},
"rifling":	{"VBG","NN"},
"rift":	{"NN","VB","VBP"},
"rifted":	{"VBD","VBN"},
"rifting":	{"VBG"},
"rifts":	{"NNS","VBZ"},
"rig":	{"VB","VBP","NN"},
"rig-veda":	{"NN"},
"rigamarole":	{"NN"},
"rigatoni":	{"NN"},
"rigel":	{"NN"},
"rigescent":	{"JJ"},
"rigged":	{"VBD","VBN"},
"rigger":	{"NN"},
"riggers":	{"NNS"},
"rigging":	{"NN","VBG"},
"right":	{"JJ","RB","NN","VB","VBP","UH"},
"right-angle":	{"NN"},
"right-angled":	{"JJ"},
"right-angles":	{"NNS"},
"right-hand":	{"JJ"},
"right-handed":	{"JJ"},
"right-handedness":	{"NN"},
"right-hander":	{"NN"},
"right-handers":	{"NNS"},
"right-minded":	{"JJ"},
"right-of-center":	{"JJ"},
"right-of-centre":	{"JJ"},
"right-to-die":	{"JJ"},
"right-wing":	{"JJ","NN"},
"right-winger":	{"NN"},
"right-wingers":	{"NNS"},
"righted":	{"VBD","VBN"},
"righteous":	{"JJ"},
"righteously":	{"RB"},
"righteousness":	{"NN"},
"rightful":	{"JJ"},
"rightfully":	{"RB"},
"rightfulness":	{"NN"},
"righting":	{"VBG"},
"rightish":	{"JJ"},
"rightism":	{"NN"},
"rightist":	{"NN","JJ"},
"rightists":	{"NNS"},
"rightly":	{"RB"},
"rightmost":	{"JJ"},
"rightness":	{"NN"},
"rights":	{"NNS","VBZ"},
"rightward":	{"JJ","RB"},
"rigid":	{"JJ"},
"rigidification":	{"NN"},
"rigidified":	{"VBD","VBN"},
"rigidifies":	{"VBZ"},
"rigidify":	{"VB","VBP"},
"rigidifying":	{"VBG"},
"rigidities":	{"NNS"},
"rigidity":	{"NN"},
"rigidly":	{"RB"},
"rigidness":	{"NN"},
"rigil":	{"NN"},
"rigmarole":	{"NN"},
"rigmaroles":	{"NNS"},
"rigor":	{"NN"},
"rigorous":	{"JJ"},
"rigorously":	{"RB"},
"rigorousness":	{"NN"},
"rigors":	{"NNS"},
"rigour":	{"NN"},
"rigourousness":	{"NN"},
"rigours":	{"NNS"},
"rigout":	{"NN"},
"rigs":	{"NNS","VBZ"},
"rigueur":	{"FW"},
"rijstafel":	{"NN"},
"rijstaffel":	{"NN"},
"rijsttaffel":	{"NN"},
"riksmaal":	{"NN"},
"riksmal":	{"NN"},
"rile":	{"VB","VBP"},
"riled":	{"VBD","VBN"},
"riles":	{"VBZ"},
"riley":	{"NN"},
"rilievo":	{"NN"},
"riling":	{"VBG"},
"rilke":	{"NN"},
"rill":	{"NN"},
"rim":	{"NN","VB","VBP"},
"rim-fire":	{"JJ"},
"rima":	{"NN"},
"rimactane":	{"NN"},
"rimbaud":	{"NN"},
"rime":	{"NN","VB","VBP"},
"rimed":	{"VBD","VBN"},
"rimeless":	{"JJ"},
"rimes":	{"VBZ"},
"riming":	{"VBG"},
"rimless":	{"JJ"},
"rimmed":	{"JJ","VBD","VBN"},
"rimming":	{"VBG"},
"rimose":	{"JJ"},
"rims":	{"VBZ","NNS"},
"rimu":	{"NN"},
"rimy":	{"JJ"},
"rind":	{"NN"},
"rinderpest":	{"NN"},
"rinds":	{"NNS"},
"ring":	{"NN","VB","VBP"},
"ring-binder":	{"NN"},
"ring-finger":	{"NN"},
"ring-labeled":	{"JJ"},
"ring-pull":	{"NN"},
"ringdove":	{"NN"},
"ringed":	{"VBD","VBN"},
"ringer":	{"NN"},
"ringers":	{"NNS"},
"ringgit":	{"NN"},
"ringhals":	{"NNS"},
"ringing":	{"NN","JJ","VBG"},
"ringings":	{"NNS"},
"ringleader":	{"NN"},
"ringleaders":	{"NNS"},
"ringlet":	{"NN"},
"ringleted":	{"JJ"},
"ringlets":	{"NNS"},
"ringlike":	{"JJ"},
"ringling":	{"NN"},
"ringmaster":	{"NN"},
"ringmasters":	{"NNS"},
"rings":	{"NNS","VBZ"},
"ringside":	{"NN","JJ"},
"ringsider":	{"NN"},
"ringsiders":	{"NNS"},
"ringtail":	{"NN"},
"ringtone":	{"NN"},
"ringtones":	{"NNS"},
"ringway":	{"NN"},
"ringworm":	{"NN"},
"rink":	{"NN"},
"rinkhals":	{"NN","NNS"},
"rinkhalses":	{"NNS"},
"rinks":	{"NNS"},
"rinse":	{"VB","VBP","NN"},
"rinsed":	{"VBD","VBN"},
"rinses":	{"VBZ","NNS"},
"rinsing":	{"VBG"},
"rio":	{"NN"},
"rioja":	{"NN"},
"riot":	{"NN","VB","VBP"},
"rioted":	{"VBD","VBN"},
"rioter":	{"NN"},
"rioters":	{"NNS"},
"rioting":	{"NN","VBG"},
"riotous":	{"JJ"},
"riotously":	{"RB"},
"riotousness":	{"NN"},
"riots":	{"NNS","VBZ"},
"rip":	{"VB","VBP","NN"},
"rip-off":	{"NN"},
"rip-offs":	{"NNS"},
"rip-roaring":	{"JJ","RB"},
"riparia":	{"NN"},
"riparian":	{"JJ"},
"ripcord":	{"NN"},
"ripcords":	{"NNS"},
"ripe":	{"JJ"},
"ripely":	{"RB"},
"ripen":	{"VB","VBP"},
"ripened":	{"VBD","VBN"},
"ripeness":	{"NN"},
"ripening":	{"NN","VBG"},
"ripens":	{"VBZ"},
"riper":	{"JJR"},
"ripest":	{"JJS"},
"riposte":	{"NN","VB","VBP"},
"riposted":	{"VBD","VBN"},
"ripostes":	{"NNS","VBZ"},
"riposting":	{"VBG"},
"ripped":	{"VBD","VBN"},
"ripper":	{"NN"},
"rippers":	{"NNS"},
"ripping":	{"VBG","JJ"},
"ripple":	{"NN","VB","VBP"},
"rippled":	{"VBD","VBN"},
"ripples":	{"NNS","VBZ"},
"rippling":	{"VBG"},
"rips":	{"VBZ","NNS"},
"ripsaw":	{"NN"},
"riptide":	{"NN"},
"riptides":	{"NNS"},
"rira":	{"NN"},
"rise":	{"NN","VB","VBP"},
"rise-perhaps":	{"RB"},
"risen":	{"VBN"},
"riser":	{"NN"},
"rises":	{"VBZ","NNS"},
"risibility":	{"NN"},
"risible":	{"JJ"},
"rising":	{"VBG","JJ","NN"},
"risings":	{"NNS"},
"risk":	{"NN","VB","VBP"},
"risk-analysis":	{"NN"},
"risk-management":	{"NN"},
"risk-taker":	{"NN"},
"risk-takers":	{"NNS"},
"risk-taking":	{"NN"},
"risked":	{"VBD","VBN"},
"riskier":	{"JJR"},
"riskiest":	{"JJS"},
"riskily":	{"RB"},
"riskiness":	{"NN"},
"risking":	{"VBG"},
"riskless":	{"JJ"},
"risklessness":	{"NN"},
"risks":	{"NNS","VBZ"},
"risky":	{"JJ"},
"risotto":	{"NN"},
"risottos":	{"NNS"},
"risque":	{"JJ"},
"rissa":	{"NN"},
"rissole":	{"NN"},
"rissoles":	{"NNS"},
"rita":	{"NN"},
"ritalin":	{"NN"},
"ritardando":	{"NN"},
"ritchie":	{"NN"},
"rite":	{"NN"},
"ritenuto":	{"JJ"},
"rites":	{"NNS"},
"ritiuality":	{"NN"},
"ritonavir":	{"NN"},
"ritorno":	{"FW"},
"rittenhouse":	{"NN"},
"ritual":	{"NN","JJ"},
"ritualise":	{"VB","VBP"},
"ritualised":	{"VBD","VBN","JJ"},
"ritualises":	{"VBZ"},
"ritualising":	{"VBG"},
"ritualism":	{"NN"},
"ritualist":	{"NN"},
"ritualistic":	{"JJ"},
"ritualists":	{"NNS"},
"ritualize":	{"VB","VBP"},
"ritualized":	{"VBD","VBN","JJ"},
"ritualizes":	{"VBZ"},
"ritualizing":	{"VBG"},
"ritually":	{"RB"},
"rituals":	{"NNS"},
"ritz":	{"NN"},
"ritzier":	{"JJR"},
"ritziest":	{"JJS"},
"ritzy":	{"JJ"},
"rival":	{"NN","VB","VBP"},
"rivaled":	{"VBD","VBN"},
"rivaling":	{"VBG"},
"rivalled":	{"VBD","VBN"},
"rivalling":	{"VBG"},
"rivalries":	{"NNS"},
"rivalrous":	{"JJ"},
"rivalry":	{"NN"},
"rivals":	{"NNS","VBZ"},
"rive":	{"VB","VBP"},
"rived":	{"VBD","VBN"},
"riven":	{"VBN","JJ"},
"river":	{"NN"},
"river-bed":	{"NN"},
"river-beds":	{"NNS"},
"rivera":	{"NN"},
"riverbank":	{"NN"},
"riverbanks":	{"NNS"},
"riverboat":	{"NN"},
"riverboats":	{"NNS"},
"riverfront":	{"NN"},
"riverine":	{"JJ"},
"rivers":	{"NNS"},
"riverside":	{"NN","JJ"},
"rives":	{"VBZ"},
"rivet":	{"NN","VB","VBP"},
"riveted":	{"VBN","VBD"},
"riveter":	{"NN"},
"riveters":	{"NNS"},
"riveting":	{"JJ","VBG"},
"rivets":	{"NNS","VBZ"},
"rivetter":	{"NN"},
"riviera":	{"NN"},
"rivina":	{"NN"},
"riving":	{"VBG"},
"rivulet":	{"NN"},
"rivulets":	{"NNS"},
"riyadh":	{"NN"},
"riyal":	{"NN"},
"rnase":	{"NN"},
"ro":	{"NN"},
"roach":	{"NN","NNS"},
"roaches":	{"NNS"},
"road":	{"NN"},
"roadbed":	{"NN"},
"roadblock":	{"NN"},
"roadblocks":	{"NNS"},
"roadhog":	{"NN"},
"roadhogs":	{"NNS"},
"roadhouse":	{"NN"},
"roadhouses":	{"NNS"},
"roadkill":	{"NN"},
"roadless":	{"JJ"},
"roadman":	{"NN"},
"roadmap":	{"NN"},
"roadmaps":	{"NNS"},
"roadmen":	{"NNS"},
"roadrunner":	{"NN"},
"roadrunners":	{"NNS"},
"roads":	{"NNS"},
"roadside":	{"NN","JJ"},
"roadsides":	{"NNS"},
"roadstead":	{"NN"},
"roadster":	{"NN"},
"roadsters":	{"NNS"},
"roadway":	{"NN"},
"roadways":	{"NNS"},
"roadworthiness":	{"NN"},
"roadworthy":	{"JJ"},
"roam":	{"VB","VBP","NN"},
"roamed":	{"VBD","VBN"},
"roamer":	{"NN"},
"roamers":	{"NNS"},
"roaming":	{"VBG","NN"},
"roams":	{"VBZ"},
"roan":	{"NN","JJ"},
"roanoke":	{"NN"},
"roans":	{"NNS"},
"roar":	{"NN","VB","VBP"},
"roared":	{"VBD","VBN"},
"roarer":	{"NN"},
"roarers":	{"NNS"},
"roaring":	{"JJ","VBG"},
"roars":	{"NNS","VBZ"},
"roast":	{"VB","VBP","NN","JJ"},
"roasted":	{"VBD","VBN"},
"roaster":	{"NN"},
"roasters":	{"NNS"},
"roasting":	{"JJ","NN","VBG"},
"roasts":	{"VBZ","NNS"},
"rob":	{"VB","VBP"},
"robalo":	{"NN"},
"robaxin":	{"NN"},
"robbed":	{"VBD","VBN"},
"robber":	{"NN"},
"robberies":	{"NNS"},
"robbers":	{"NNS"},
"robbery":	{"NN"},
"robbing":	{"VBG"},
"robbins":	{"NNS"},
"robe":	{"NN","VB","VBP"},
"robed":	{"VBD","VBN","JJ"},
"robert":	{"NN"},
"roberts":	{"NNS"},
"robertson":	{"NN"},
"robes":	{"NNS","VBZ"},
"robeson":	{"NN"},
"robin":	{"NN"},
"robing":	{"VBG"},
"robinia":	{"NN"},
"robins":	{"NNS"},
"robitussin":	{"NN"},
"roble":	{"NN"},
"robocall":	{"NN"},
"robocalls":	{"NNS"},
"robot":	{"NN"},
"robotic":	{"JJ"},
"robotics":	{"NN"},
"robotism":	{"NN"},
"robotlike":	{"JJ"},
"robots":	{"NNS"},
"robs":	{"VBZ"},
"robust":	{"JJ"},
"robustious":	{"JJ"},
"robustly":	{"RB"},
"robustness":	{"NN"},
"rocambole":	{"NN"},
"roccella":	{"NN"},
"roccellaceae":	{"NN"},
"roccus":	{"NN"},
"rocephin":	{"NN"},
"rochambeau":	{"NN"},
"rochester":	{"NN"},
"rock":	{"NN","VB","VBP"},
"rock'n'roll":	{"NN"},
"rock-and-roll":	{"NN"},
"rock-bottom":	{"JJ"},
"rock-cake":	{"NN"},
"rock-climbing":	{"NN"},
"rock-crystal":	{"NN"},
"rock-garden":	{"NN"},
"rock-gardens":	{"NNS"},
"rock-hard":	{"JJ"},
"rock-inhabiting":	{"JJ"},
"rock-like":	{"JJ"},
"rock-plant":	{"NN"},
"rock-salt":	{"NN"},
"rock-steady":	{"JJ"},
"rock-strewn":	{"JJ"},
"rockabilly":	{"NN"},
"rockbound":	{"JJ"},
"rockchuck":	{"NN"},
"rockcress":	{"NN"},
"rocked":	{"VBD","VBN"},
"rockefeller":	{"NN"},
"rocker":	{"NN"},
"rockeries":	{"NNS"},
"rockers":	{"NNS"},
"rockery":	{"NN"},
"rocket":	{"NN","VBP","VB"},
"rocket-bomb":	{"NN"},
"rocket-bombs":	{"NNS"},
"rocket-fuel":	{"NN"},
"rocketed":	{"VBD","VBN"},
"rocketing":	{"NN","VBG"},
"rocketry":	{"NN"},
"rockets":	{"NNS","VBZ"},
"rocketship":	{"NN"},
"rocketshipper":	{"NN"},
"rocketshippers":	{"NNS"},
"rocketships":	{"NNS"},
"rockfish":	{"NN"},
"rockfoil":	{"NN"},
"rockford":	{"NN"},
"rockier":	{"JJR"},
"rockiest":	{"JJS"},
"rockin":	{"JJ"},
"rockiness":	{"NN"},
"rocking":	{"VBG"},
"rocking-chair":	{"NN"},
"rocking-chairs":	{"NNS"},
"rocking-horse":	{"NN"},
"rocking-horses":	{"NNS"},
"rockingham":	{"NN"},
"rocklike":	{"JJ"},
"rockrose":	{"NN"},
"rocks":	{"NNS","VBZ"},
"rockslide":	{"NN"},
"rockstar":	{"NN"},
"rockstars":	{"NNS"},
"rockweed":	{"NN"},
"rocky":	{"JJ"},
"rococo":	{"NN","JJ"},
"rocroi":	{"NN"},
"rod":	{"NN"},
"rodder":	{"NN"},
"rodders":	{"NNS"},
"rodding":	{"NN"},
"rode":	{"VBD"},
"rodent":	{"NN","JJ"},
"rodentia":	{"NN"},
"rodents":	{"NNS"},
"rodeo":	{"NN"},
"rodeos":	{"NNS"},
"rodgers":	{"NNS"},
"rodlike":	{"JJ"},
"rodolia":	{"NN"},
"rodomontade":	{"NN"},
"rods":	{"NNS"},
"roe":	{"NN","NNS"},
"roebling":	{"NN"},
"roebuck":	{"NN"},
"roemer":	{"NN"},
"roentgen":	{"NN"},
"roentgenium":	{"NN"},
"roentgenogram":	{"NN"},
"roentgenographic":	{"JJ"},
"roentgenography":	{"NN"},
"roentgenoscope":	{"NN"},
"roes":	{"NNS"},
"rofecoxib":	{"NN"},
"rogaine":	{"NN"},
"rogation":	{"NN"},
"rogers":	{"NNS"},
"roget":	{"NN"},
"rogue":	{"NN","JJ"},
"rogueries":	{"NNS"},
"roguery":	{"NN"},
"rogues":	{"NNS"},
"roguish":	{"JJ"},
"roguishly":	{"RB"},
"roguishness":	{"NN"},
"rohypnol":	{"NN"},
"roi":	{"NN"},
"roil":	{"VB","VBP"},
"roiled":	{"VBD","VBN"},
"roiling":	{"VBG"},
"roils":	{"VBZ"},
"roily":	{"JJ"},
"roister":	{"VB","VBP"},
"roistered":	{"VBD","VBN"},
"roisterer":	{"NN"},
"roisterers":	{"NNS"},
"roistering":	{"VBG"},
"roisters":	{"VBZ"},
"rolaids":	{"NNS"},
"roland":	{"NN"},
"role":	{"NN"},
"role-play":	{"NN","VB","VBP"},
"role-played":	{"VBD","VBN"},
"role-playing":	{"VBG"},
"role-plays":	{"NNS","VBZ"},
"roles":	{"NNS"},
"rolex":	{"NN"},
"rolf":	{"NN"},
"roll":	{"NN","VB","VBP"},
"roll-call":	{"NN"},
"roll-calls":	{"NNS"},
"roll-off":	{"NN"},
"roll-on":	{"NN"},
"roll-ons":	{"NNS"},
"roll-out":	{"NN"},
"roll-outs":	{"NNS"},
"roll-up":	{"NN"},
"roll-ups":	{"NNS"},
"rollback":	{"NN"},
"rollbacks":	{"NNS"},
"rolled":	{"VBD","VBN","JJ"},
"rolled-up":	{"JJ"},
"roller":	{"NN"},
"roller-coaster":	{"NN"},
"roller-coasters":	{"NNS"},
"roller-skate":	{"NN","VB","VBP"},
"roller-skated":	{"VBD","VBN"},
"roller-skater":	{"NN"},
"roller-skating":	{"VBG","NN"},
"rollerblade":	{"NN"},
"rollerblader":	{"NN"},
"rollerblades":	{"NNS"},
"rollerblading":	{"NN"},
"rollers":	{"NNS"},
"rollick":	{"VB","VBP"},
"rollicked":	{"VBD","VBN"},
"rollicking":	{"VBG","JJ","NN","RB"},
"rollickingly":	{"RB"},
"rollicks":	{"VBZ"},
"rolling":	{"VBG","JJ"},
"rolling-mill":	{"NN"},
"rolling-mills":	{"NNS"},
"rolling-pin":	{"NN"},
"rolling-pins":	{"NNS"},
"rolling-steel":	{"NN"},
"rolling-stock":	{"NN"},
"rolling-writer":	{"NN"},
"rollmops":	{"NNS"},
"rollo":	{"NN"},
"rollover":	{"NN"},
"rollovers":	{"NNS"},
"rolls":	{"NNS","VBZ"},
"rolodex":	{"NN"},
"roly-polies":	{"NNS"},
"roly-poly":	{"JJ","NN"},
"rolypoliness":	{"NN"},
"rom":	{"NN"},
"roma":	{"NN"},
"romaine":	{"NN"},
"roman":	{"NN"},
"romanal":	{"NN"},
"romance":	{"NN","VBP","VB"},
"romanced":	{"VBD","VBN"},
"romancer":	{"NN"},
"romancers":	{"NNS"},
"romances":	{"VBZ","NNS"},
"romancing":	{"VBG"},
"romania":	{"NN"},
"romanian":	{"JJ","NN"},
"romanoff":	{"NN"},
"romantic":	{"JJ","NN"},
"romantically":	{"RB"},
"romanticisation":	{"NN"},
"romanticise":	{"VB","VBP"},
"romanticised":	{"VBD","VBN","JJ"},
"romanticises":	{"VBZ"},
"romanticising":	{"VBG"},
"romanticism":	{"NN"},
"romanticist":	{"NN"},
"romanticistic":	{"JJ"},
"romanticists":	{"NNS"},
"romanticization":	{"NN"},
"romanticize":	{"VB","VBP"},
"romanticized":	{"VBD","VBN","JJ"},
"romanticizes":	{"VBZ"},
"romanticizing":	{"VBG"},
"romantick":	{"JJ"},
"romantics":	{"NNS"},
"romberg":	{"NN"},
"rome":	{"NN"},
"rommel":	{"NN"},
"romneya":	{"NN"},
"romp":	{"VB","VBP","NN"},
"romped":	{"VBD","VBN"},
"romper":	{"NN"},
"romping":	{"VBG"},
"romps":	{"NNS","VBZ"},
"romulus":	{"NN"},
"ron":	{"NN"},
"rondeau":	{"NN"},
"rondel":	{"NN"},
"rondelet":	{"NN"},
"rondo":	{"NN"},
"rondos":	{"NNS"},
"roneograph":	{"NN"},
"ronnel":	{"NN"},
"rontgen":	{"NN"},
"rood":	{"NN"},
"rood-screen":	{"NN"},
"roof":	{"NN","VBP","VB"},
"roof-garden":	{"NN"},
"roof-gardens":	{"NNS"},
"roof-rack":	{"NN"},
"roof-racks":	{"NNS"},
"roof-top":	{"NN"},
"roof-tops":	{"NNS"},
"roof-tree":	{"NN"},
"roofed":	{"VBD","VBN","JJ"},
"roofer":	{"NN"},
"roofers":	{"NNS"},
"roofier":	{"JJR"},
"roofiest":	{"JJS"},
"roofing":	{"NN","VBG"},
"roofless":	{"JJ"},
"roofs":	{"NNS","VBZ"},
"rooftop":	{"NN"},
"rooftops":	{"NNS"},
"rooftree":	{"NN"},
"roofy":	{"JJ"},
"rooibos":	{"NN"},
"rook":	{"NN","VB","VBP"},
"rooked":	{"VBD","VBN"},
"rookery":	{"NN"},
"rookie":	{"NN"},
"rookies":	{"NNS"},
"rooking":	{"VBG"},
"rooks":	{"NNS","VBZ"},
"room":	{"NN","VBP","VB"},
"room-mate":	{"NN"},
"room-mates":	{"NNS"},
"roomed":	{"VBD","VBN"},
"roomer":	{"NN"},
"roomers":	{"NNS"},
"roomette":	{"NN"},
"roomettes":	{"NNS"},
"roomful":	{"NN"},
"roomfuls":	{"NNS"},
"roomie":	{"NN"},
"roomier":	{"JJR"},
"roomies":	{"NNS"},
"roomiest":	{"JJS"},
"roomily":	{"RB"},
"roominess":	{"NN"},
"rooming":	{"VBG"},
"rooming-house":	{"NN"},
"rooming-houses":	{"NNS"},
"roommate":	{"NN"},
"roommates":	{"NNS"},
"rooms":	{"NNS","VBZ"},
"roomy":	{"JJ"},
"rooney":	{"NN"},
"roosevelt":	{"NN"},
"rooseveltian":	{"JJ"},
"roost":	{"NN","VB","VBP"},
"roosted":	{"VBD","VBN"},
"rooster":	{"NN"},
"roosters":	{"NNS"},
"roosting":	{"VBG"},
"roosts":	{"NNS","VBZ"},
"root":	{"NN","VB","VBP"},
"root-canal":	{"NN"},
"rootage":	{"NN"},
"rootbound":	{"JJ"},
"rooted":	{"VBN","JJ","VBD"},
"rooter":	{"NN"},
"rooters":	{"NNS"},
"rooting":	{"VBG"},
"rootle":	{"VB","VBP","NN"},
"rootled":	{"VBD","VBN"},
"rootles":	{"VBZ"},
"rootless":	{"JJ","NN"},
"rootlessness":	{"NN"},
"rootlet":	{"NN"},
"rootling":	{"VBG","NNS"},
"roots":	{"NNS","VBZ"},
"rootstalk":	{"NN"},
"rootstock":	{"NN"},
"rooves":	{"NNS"},
"rope":	{"NN","VB","VBP"},
"rope-a-dope":	{"NN"},
"rope-sight":	{"NN"},
"roped":	{"VBD","VBN"},
"ropedancer":	{"NN"},
"ropedancers":	{"NNS"},
"ropemaker":	{"NN"},
"ropemakers":	{"NNS"},
"roper":	{"NN"},
"ropers":	{"NNS"},
"ropes":	{"NNS","VBZ"},
"ropewalk":	{"NN"},
"ropewalker":	{"NN"},
"ropeway":	{"NN"},
"ropey":	{"JJ"},
"rophy":	{"NN"},
"ropier":	{"JJR"},
"ropiest":	{"JJS"},
"ropiness":	{"NN"},
"roping":	{"NN","VBG"},
"ropy":	{"JJ"},
"roquette":	{"NN"},
"roridula":	{"NN"},
"roridulaceae":	{"NN"},
"rorippa":	{"NN"},
"rorqual":	{"NN"},
"rorschach":	{"NN"},
"rosacea":	{"NN"},
"rosaceae":	{"NN"},
"rosaceous":	{"JJ"},
"rosales":	{"NNS"},
"rosarian":	{"NN"},
"rosarians":	{"NNS"},
"rosaries":	{"NNS"},
"rosary":	{"NN"},
"rose":	{"VBD","NN","JJ"},
"rose-bud":	{"NN"},
"rose-colored":	{"JJ"},
"rose-coloured":	{"JJ"},
"rose-hip":	{"NN"},
"rose-hips":	{"NNS"},
"rose-tinted":	{"JJ"},
"rose-water":	{"NN"},
"rose-window":	{"NN"},
"rose-windows":	{"NNS"},
"roseate":	{"JJ"},
"rosebay":	{"NN"},
"rosebays":	{"NNS"},
"rosebud":	{"NN"},
"rosebuds":	{"NNS"},
"rosebush":	{"NN"},
"rosefish":	{"NN","NNS"},
"rosefishes":	{"NNS"},
"rosehip":	{"NN"},
"rosehips":	{"NNS"},
"roselle":	{"NN"},
"rosellinia":	{"NN"},
"rosemaling":	{"NN"},
"rosemary":	{"NN"},
"roseola":	{"NN"},
"roses":	{"NNS"},
"rosette":	{"NN"},
"rosettes":	{"NNS"},
"rosewood":	{"NN"},
"rosicrucian":	{"JJ","NN"},
"rosicrucianism":	{"NN"},
"rosidae":	{"NN"},
"rosier":	{"JJR"},
"rosiest":	{"JJS"},
"rosilla":	{"NN"},
"rosin":	{"NN","VB","VBP"},
"rosined":	{"VBD","VBN"},
"rosiness":	{"NN"},
"rosining":	{"VBG"},
"rosins":	{"NNS","VBZ"},
"rosinweed":	{"NN"},
"rosita":	{"NN"},
"rosmarinus":	{"NN"},
"rossbach":	{"NN"},
"rossi":	{"NN"},
"rossini":	{"NN"},
"rostand":	{"NN"},
"roster":	{"NN","VB","VBP"},
"rostered":	{"VBD","VBN"},
"rostering":	{"VBG"},
"rosters":	{"NNS","VBZ"},
"rostock":	{"NN"},
"rostov":	{"NN"},
"rostra":	{"NNS"},
"rostrate":	{"JJ"},
"rostrum":	{"NN"},
"rostrums":	{"NNS"},
"roswell":	{"NN"},
"rosy":	{"JJ"},
"rot":	{"VB","VBP","NN"},
"rota":	{"NN"},
"rotarian":	{"NN"},
"rotaries":	{"NNS"},
"rotary":	{"NN","JJ"},
"rotas":	{"NNS"},
"rotatable":	{"JJ"},
"rotate":	{"VB","VBP"},
"rotated":	{"VBD","VBN"},
"rotates":	{"VBZ"},
"rotating":	{"VBG"},
"rotation":	{"NN"},
"rotational":	{"JJ"},
"rotationally":	{"RB"},
"rotations":	{"NNS"},
"rotator":	{"NN"},
"rotators":	{"NNS"},
"rotatory":	{"JJ"},
"rotavirus":	{"NN"},
"rotaxane":	{"NN"},
"rote":	{"NN"},
"rotenone":	{"NN"},
"rotgut":	{"NN"},
"roth":	{"NN"},
"rothko":	{"NN"},
"rothschild":	{"NN"},
"rotifer":	{"NN"},
"rotifera":	{"NN"},
"rotisserie":	{"NN"},
"rotisseries":	{"NNS"},
"rotl":	{"NN"},
"rotogravure":	{"NN"},
"rotogravures":	{"NNS"},
"rotor":	{"NN"},
"rotors":	{"NNS"},
"rots":	{"NNS","VBZ"},
"rotted":	{"VBD","VBN"},
"rotten":	{"JJ","RB"},
"rottenly":	{"RB"},
"rottenness":	{"NN"},
"rottenstone":	{"NN"},
"rotter":	{"NN"},
"rotterdam":	{"NN"},
"rotters":	{"NNS"},
"rotting":	{"VBG"},
"rottweiler":	{"NN"},
"rottweilers":	{"NNS"},
"rotund":	{"JJ"},
"rotunda":	{"NN"},
"rotundas":	{"NNS"},
"rotundity":	{"NN"},
"rotundly":	{"RB"},
"rotundness":	{"NN"},
"rouble":	{"NN"},
"roubles":	{"NNS"},
"roue":	{"NN"},
"rouge":	{"NN","VB","VBP"},
"rouged":	{"VBD","VBN"},
"rouges":	{"VBZ"},
"rough":	{"JJ","NN","RB","VB","VBP"},
"rough-and-ready":	{"JJ"},
"rough-and-tumble":	{"JJ","NN"},
"rough-cut":	{"JJ"},
"rough-dried":	{"VBD","VBN"},
"rough-dries":	{"VBZ"},
"rough-dry":	{"VB","VBP","JJ"},
"rough-drying":	{"VBG"},
"rough-hew":	{"VB","VBP"},
"rough-hewed":	{"VBD","VBN"},
"rough-hewing":	{"VBG"},
"rough-hewn":	{"VBN","JJ"},
"rough-hews":	{"VBZ"},
"rough-house":	{"NN"},
"roughage":	{"NN"},
"roughcast":	{"NN","JJ"},
"roughed":	{"VBD","VBN"},
"roughen":	{"VB","VBP"},
"roughened":	{"VBD","VBN"},
"roughening":	{"VBG"},
"roughens":	{"VBZ"},
"rougher":	{"JJR"},
"roughest":	{"JJS"},
"roughhouse":	{"NN","VB","VBP"},
"roughhoused":	{"VBD","VBN"},
"roughhouses":	{"VBZ"},
"roughhousing":	{"VBG"},
"roughing":	{"VBG"},
"roughish":	{"JJ"},
"roughleg":	{"NN"},
"roughly":	{"RB"},
"roughneck":	{"NN"},
"roughnecks":	{"NNS"},
"roughness":	{"NN"},
"roughrider":	{"NN"},
"roughriders":	{"NNS"},
"roughs":	{"VBZ","NNS"},
"roughshod":	{"RB"},
"rouging":	{"VBG"},
"roulade":	{"NN"},
"rouleau":	{"NN"},
"roulette":	{"NN","VB","VBP"},
"rouletted":	{"VBD","VBN"},
"roulettes":	{"VBZ"},
"rouletting":	{"VBG"},
"round":	{"JJ","RP","RB","NN","VB","VBP","IN"},
"round-arm":	{"JJ","RB"},
"round-eyed":	{"JJ"},
"round-faced":	{"JJ"},
"round-shouldered":	{"JJ"},
"round-table":	{"JJ","NN"},
"round-tables":	{"NNS"},
"round-the-clock":	{"JJ"},
"round-trip":	{"JJ","NN"},
"round-trips":	{"NNS"},
"round-up":	{"NN"},
"round-ups":	{"NNS"},
"roundabout":	{"NN","JJ"},
"roundabouts":	{"NNS"},
"rounded":	{"JJ","VBD","VBN"},
"roundedness":	{"NN"},
"roundel":	{"NN"},
"roundelay":	{"NN"},
"roundels":	{"NNS"},
"rounder":	{"JJR","NN"},
"rounders":	{"NN"},
"roundest":	{"JJS"},
"roundhead":	{"NN"},
"roundheaded":	{"JJ"},
"roundhouse":	{"NN"},
"rounding":	{"NN","VBG"},
"roundish":	{"JJ"},
"roundly":	{"RB"},
"roundness":	{"NN"},
"rounds":	{"NNS","VBZ"},
"roundsman":	{"NN"},
"roundsmen":	{"NNS"},
"roundtable":	{"JJ","NN"},
"roundtables":	{"NNS"},
"roundtrip":	{"NN"},
"roundup":	{"NN"},
"roundups":	{"NNS"},
"roundworm":	{"NN"},
"roundworms":	{"NNS"},
"rourke":	{"NN"},
"rouse":	{"VB","VBP"},
"roused":	{"VBD","VBN","JJ"},
"rouser":	{"NN"},
"rousers":	{"NNS"},
"rouses":	{"VBZ"},
"rousing":	{"JJ","VBG"},
"rousseau":	{"NN"},
"roust":	{"VB","VBP"},
"roustabout":	{"NN"},
"roustabouts":	{"NNS"},
"rousted":	{"VBD","VBN"},
"rousting":	{"VBG"},
"rousts":	{"VBZ"},
"rout":	{"VB","VBP","NN"},
"route":	{"NN","VB","VBP"},
"routed":	{"VBN","VBD"},
"routemarch":	{"NN"},
"router":	{"NN"},
"routers":	{"NNS"},
"routes":	{"NNS","VBZ"},
"routine":	{"JJ","NN"},
"routinely":	{"RB"},
"routines":	{"NNS"},
"routing":	{"NN","VBG"},
"routings":	{"NNS"},
"routs":	{"VBZ","NNS"},
"roux":	{"NN","NNS"},
"rove":	{"VB","VBP","NN"},
"roved":	{"VBD","VBN"},
"rover":	{"NN"},
"rovers":	{"NNS"},
"roves":	{"VBZ"},
"roving":	{"NN","JJ","VBG"},
"rovings":	{"NNS"},
"row":	{"NN","VB","VBP"},
"row-boat":	{"NN"},
"row-boats":	{"NNS"},
"rowan":	{"NN"},
"rowanberry":	{"NN"},
"rowans":	{"NNS"},
"rowboat":	{"NN"},
"rowboats":	{"NNS"},
"rowdier":	{"JJR"},
"rowdies":	{"NNS"},
"rowdiest":	{"JJS"},
"rowdily":	{"RB"},
"rowdiness":	{"NN"},
"rowdy":	{"JJ","NN"},
"rowdyism":	{"NN"},
"rowed":	{"VBD","VBN"},
"rowel":	{"NN"},
"rower":	{"NN"},
"rowers":	{"NNS"},
"rowing":	{"NN","VBG"},
"rowing-boat":	{"NN"},
"rowing-boats":	{"NNS"},
"rowlock":	{"NN"},
"rowlocks":	{"NNS"},
"rowmate":	{"NN"},
"rowmates":	{"NNS"},
"rows":	{"NNS","VBZ"},
"royal":	{"JJ","NN"},
"royalism":	{"NN"},
"royalist":	{"NN","JJ"},
"royalists":	{"NNS"},
"royally":	{"RB"},
"royals":	{"NNS"},
"royalties":	{"NNS"},
"royalty":	{"NN"},
"rpm":	{"NN","NNS"},
"ru":	{"NN"},
"rub":	{"VB","VBP","NN"},
"rub-a-dub":	{"NN"},
"rubato":	{"NN"},
"rubbed":	{"VBD","VBN"},
"rubber":	{"NN","JJ"},
"rubber-stamp":	{"VB","VBP","NN"},
"rubber-stamped":	{"VBD","VBN"},
"rubber-stamping":	{"VBG"},
"rubber-stamps":	{"VBZ","NNS"},
"rubberise":	{"VB","VBP"},
"rubberised":	{"VBD","VBN","JJ"},
"rubberises":	{"VBZ"},
"rubberising":	{"VBG"},
"rubberize":	{"VB","VBP"},
"rubberized":	{"VBD","VBN","JJ"},
"rubberizes":	{"VBZ"},
"rubberizing":	{"VBG"},
"rubberlike":	{"JJ"},
"rubberneck":	{"VB","VBP","NN"},
"rubbernecked":	{"VBD","VBN"},
"rubbernecker":	{"NN"},
"rubberneckers":	{"NNS"},
"rubbernecking":	{"VBG","JJ"},
"rubbernecks":	{"VBZ","NNS"},
"rubbers":	{"NNS"},
"rubbery":	{"JJ"},
"rubbing":	{"NN","VBG"},
"rubbings":	{"NNS"},
"rubbish":	{"NN","VB","VBP","JJ"},
"rubbished":	{"VBD","VBN"},
"rubbishes":	{"VBZ"},
"rubbishing":	{"VBG"},
"rubbishy":	{"JJ"},
"rubble":	{"NN"},
"rubdown":	{"NN"},
"rubdowns":	{"NNS"},
"rube":	{"NN"},
"rubefacient":	{"NN","JJ"},
"rubel":	{"NN"},
"rubella":	{"NN"},
"rubenesquely":	{"JJ"},
"rubens":	{"NNS"},
"rubeola":	{"NN"},
"rubes":	{"NNS"},
"rubia":	{"NN"},
"rubiaceae":	{"NN"},
"rubiales":	{"NNS"},
"rubicelle":	{"NN"},
"rubicund":	{"JJ"},
"rubidium":	{"NN"},
"rubies":	{"NNS"},
"rubify":	{"VB","VBP"},
"rubinstein":	{"NN"},
"ruble":	{"NN"},
"rubles":	{"NNS"},
"rubor":	{"NN"},
"rubout":	{"NN"},
"rubric":	{"NN"},
"rubricate":	{"VB","VBP"},
"rubricated":	{"VBD","VBN"},
"rubricates":	{"VBZ"},
"rubricating":	{"VBG"},
"rubrication":	{"NN"},
"rubricator":	{"NN"},
"rubrics":	{"NNS"},
"rubs":	{"VBZ","NNS"},
"rubus":	{"NN"},
"ruby":	{"NN","JJ"},
"ruck":	{"NN","VB","VBP"},
"rucked":	{"VBD","VBN"},
"rucking":	{"VBG"},
"ruckle":	{"NN","VB","VBP"},
"rucks":	{"NNS","VBZ"},
"rucksack":	{"NN"},
"rucksacks":	{"NNS"},
"ruckus":	{"NN"},
"ruction":	{"NN"},
"ructions":	{"NNS"},
"rudapithecus":	{"NN"},
"rudbeckia":	{"NN"},
"rudd":	{"NN"},
"rudder":	{"NN"},
"rudderfish":	{"NN"},
"rudderless":	{"JJ"},
"rudderpost":	{"NN"},
"rudders":	{"NNS"},
"rudderstock":	{"NN"},
"ruddier":	{"JJR"},
"ruddiest":	{"JJS"},
"ruddily":	{"RB"},
"ruddiness":	{"NN"},
"ruddle":	{"NN","VB","VBP"},
"ruddled":	{"VBD","VBN"},
"ruddles":	{"NNS","VBZ"},
"ruddling":	{"VBG"},
"ruddy":	{"JJ","RB"},
"rude":	{"JJ"},
"rudely":	{"RB"},
"rudeness":	{"NN"},
"ruder":	{"JJR"},
"rudest":	{"JJS"},
"rudiment":	{"NN"},
"rudimentary":	{"JJ"},
"rudiments":	{"NNS"},
"rudolf":	{"NN"},
"rudra":	{"NN"},
"rue":	{"NN","VB","VBP"},
"rued":	{"VBD","VBN"},
"rueful":	{"JJ"},
"ruefully":	{"RB"},
"ruefulness":	{"NN"},
"rues":	{"VBZ"},
"ruf":	{"NN"},
"ruff":	{"NN","VB","VBP"},
"ruffed":	{"VBD","VBN"},
"ruffian":	{"NN"},
"ruffianism":	{"NN"},
"ruffianly":	{"JJ"},
"ruffians":	{"NNS"},
"ruffing":	{"VBG"},
"ruffle":	{"VB","VBP","NN"},
"ruffled":	{"JJ","VBD","VBN"},
"ruffles":	{"VBZ","NNS"},
"ruffling":	{"VBG"},
"ruffs":	{"NNS","VBZ"},
"rug":	{"NN"},
"ruga":	{"NN"},
"rugby":	{"NN"},
"rugelach":	{"NN"},
"rugged":	{"JJ"},
"ruggedisation":	{"NN"},
"ruggedise":	{"VB","VBP"},
"ruggedization":	{"NN"},
"ruggedize":	{"VB","VBP"},
"ruggedly":	{"RB"},
"ruggedness":	{"NN"},
"ruggelach":	{"NN"},
"rugger":	{"NN"},
"rugose":	{"JJ"},
"rugs":	{"NNS"},
"rugulah":	{"NN"},
"ruh":	{"FW"},
"ruhr":	{"NN"},
"ruin":	{"VB","NN","VBP"},
"ruination":	{"NN"},
"ruined":	{"JJ","VBD","VBN"},
"ruiner":	{"NN"},
"ruing":	{"VBG"},
"ruining":	{"VBG"},
"ruinous":	{"JJ"},
"ruinously":	{"RB"},
"ruins":	{"NNS","VBZ"},
"rule":	{"NN","VB","VBP"},
"ruled":	{"VBD","VBN","JJ"},
"rulemaking":	{"NN","JJ"},
"rulemakings":	{"NNS"},
"ruler":	{"NN"},
"rulers":	{"NNS"},
"rulership":	{"NN"},
"rules":	{"NNS","VBZ"},
"ruling":	{"NN","VBG","JJ"},
"rulings":	{"NNS"},
"ruly":	{"JJ"},
"rum":	{"NN","JJ"},
"rumania":	{"NN"},
"rumanian":	{"JJ","NN"},
"rumba":	{"NN"},
"rumbas":	{"NNS"},
"rumble":	{"VB","VBP","NN"},
"rumbled":	{"VBD","VBN"},
"rumbles":	{"VBZ","NNS"},
"rumbling":	{"JJ","NN","VBG"},
"rumblings":	{"NNS"},
"rumbustious":	{"JJ"},
"rumdum":	{"NN"},
"rumen":	{"NN"},
"rumex":	{"NN"},
"ruminant":	{"JJ","NN"},
"ruminantia":	{"NN"},
"ruminants":	{"NNS"},
"ruminate":	{"VB","VBP"},
"ruminated":	{"VBD","VBN"},
"ruminates":	{"VBZ"},
"ruminating":	{"VBG"},
"rumination":	{"NN"},
"ruminations":	{"NNS"},
"ruminative":	{"JJ"},
"ruminatively":	{"RB"},
"ruminator":	{"NN"},
"ruminators":	{"NNS"},
"rummage":	{"VB","VBP","NN"},
"rummaged":	{"VBD","VBN"},
"rummages":	{"VBZ"},
"rummaging":	{"VBG"},
"rummer":	{"NN"},
"rummy":	{"NN"},
"rumohra":	{"NN"},
"rumor":	{"NN","VB","VBP"},
"rumored":	{"VBD","VBN","JJ"},
"rumoring":	{"VBG"},
"rumormonger":	{"NN"},
"rumormongers":	{"NNS"},
"rumors":	{"NNS","VBZ"},
"rumour":	{"NN","VB","VBP"},
"rumoured":	{"VBD","VBN","JJ"},
"rumouring":	{"VBG"},
"rumourmonger":	{"NN"},
"rumourmongers":	{"NNS"},
"rumours":	{"NNS","VBZ"},
"rump":	{"NN"},
"rumpelstiltskin":	{"NN"},
"rumple":	{"VB","VBP"},
"rumpled":	{"VBD","VBN","JJ"},
"rumples":	{"VBZ"},
"rumpling":	{"VBG"},
"rumps":	{"NNS"},
"rumpus":	{"NN"},
"rumpuses":	{"NNS"},
"rumrunner":	{"NN"},
"rums":	{"NNS"},
"run":	{"VB","NN","VBN","VBP","VBD"},
"run-around":	{"NN"},
"run-down":	{"NN","JJ"},
"run-in":	{"NN"},
"run-ins":	{"NNS"},
"run-of-the-mill":	{"JJ"},
"run-off":	{"NN"},
"run-offs":	{"NNS"},
"run-on":	{"NN","JJ"},
"run-through":	{"NN"},
"run-time":	{"NN"},
"run-up":	{"NN"},
"run-ups":	{"NNS"},
"runabout":	{"NN"},
"runabouts":	{"NNS"},
"runaway":	{"JJ","NN"},
"runaways":	{"NNS"},
"runch":	{"NN"},
"runcible":	{"JJ"},
"runcinate":	{"JJ"},
"rundle":	{"NN"},
"rundown":	{"NN","JJ"},
"rundstedt":	{"NN"},
"rune":	{"NN"},
"runes":	{"NNS"},
"rung":	{"NN","VBN"},
"rungs":	{"NNS"},
"runic":	{"JJ"},
"runnel":	{"NN"},
"runnels":	{"NNS"},
"runner":	{"NN"},
"runner-up":	{"NN"},
"runners":	{"NNS"},
"runners-up":	{"NNS"},
"runnier":	{"JJR"},
"runniest":	{"JJS"},
"runniness":	{"NN"},
"running":	{"VBG","NN","JJ","RB"},
"running-board":	{"NN"},
"runny":	{"JJ"},
"runoff":	{"NN"},
"runoffs":	{"NNS"},
"runproof":	{"JJ"},
"runs":	{"VBZ","NNS"},
"runt":	{"NN"},
"runtiness":	{"NN"},
"runts":	{"NNS"},
"runty":	{"JJ"},
"runway":	{"NN"},
"runways":	{"NNS"},
"runyon":	{"NN"},
"rupee":	{"NN"},
"rupees":	{"NNS"},
"rupert":	{"NN"},
"rupestral":	{"JJ"},
"rupiah":	{"NN"},
"rupicapra":	{"NN"},
"rupicola":	{"NN"},
"rupicolous":	{"JJ"},
"ruptiliocarpon":	{"NN"},
"rupture":	{"NN","VB","VBP"},
"ruptured":	{"VBN","VBD"},
"ruptures":	{"NNS","VBZ"},
"rupturewort":	{"NN"},
"rupturing":	{"VBG"},
"rural":	{"JJ"},
"ruralism":	{"NN"},
"ruralist":	{"NN"},
"rurality":	{"NN"},
"rurally":	{"RB"},
"rus":	{"NN"},
"ruscaceae":	{"NN"},
"ruscus":	{"NN"},
"ruse":	{"NN"},
"ruses":	{"NNS"},
"rush":	{"NN","VB","VBP"},
"rush-hour":	{"JJ"},
"rush-hours":	{"NNS"},
"rushdie":	{"NN"},
"rushed":	{"VBD","VBN","JJ"},
"rusher":	{"NN"},
"rushes":	{"VBZ","NNS"},
"rushier":	{"JJR"},
"rushiest":	{"JJS"},
"rushing":	{"VBG"},
"rushlight":	{"NN"},
"rushmore":	{"NN"},
"rushy":	{"JJ"},
"rusk":	{"NN"},
"ruskin":	{"NN"},
"rusks":	{"NNS"},
"russe":	{"NN"},
"russell":	{"NN"},
"russet":	{"JJ","NN"},
"russets":	{"NNS"},
"russia":	{"NN"},
"russula":	{"NN"},
"russulaceae":	{"NN"},
"rust":	{"NN","VB","VBP"},
"rust-proof":	{"JJ","VB","VBP"},
"rust-proofed":	{"VBD","VBN"},
"rust-proofing":	{"VBG","NN"},
"rust-proofs":	{"VBZ"},
"rustbelt":	{"NN"},
"rusted":	{"VBD","VBN"},
"rustic":	{"JJ","NN"},
"rusticate":	{"VB","VBP"},
"rusticated":	{"VBD","VBN"},
"rusticates":	{"VBZ"},
"rusticating":	{"VBG"},
"rustication":	{"NN"},
"rusticism":	{"NN"},
"rusticity":	{"NN"},
"rustics":	{"NNS"},
"rustier":	{"JJR"},
"rustiest":	{"JJS"},
"rustily":	{"RB"},
"rustiness":	{"NN"},
"rusting":	{"VBG"},
"rustle":	{"VB","VBP","NN"},
"rustled":	{"VBD","VBN"},
"rustler":	{"NN"},
"rustlers":	{"NNS"},
"rustles":	{"VBZ"},
"rustless":	{"JJ"},
"rustlin":	{"NN"},
"rustling":	{"NN","VBG"},
"rustlings":	{"NNS"},
"rustproof":	{"JJ","VB","VBP"},
"rustproofing":	{"VBG","NN"},
"rustproofs":	{"VBZ"},
"rusts":	{"VBZ"},
"rusty":	{"JJ"},
"rut":	{"NN","VB","VBP"},
"ruta":	{"NN"},
"rutabaga":	{"NN"},
"rutabagas":	{"NNS"},
"rutaceae":	{"NN"},
"ruth":	{"NN"},
"ruthenium":	{"NN"},
"rutherfordium":	{"NN"},
"ruthful":	{"JJ"},
"ruthfulness":	{"NN"},
"ruthless":	{"JJ"},
"ruthlessly":	{"RB"},
"ruthlessness":	{"NN"},
"rutile":	{"NN"},
"rutilus":	{"NN"},
"rutledge":	{"NN"},
"ruts":	{"NNS","VBZ"},
"rutted":	{"JJ","VBD","VBN"},
"rutting":	{"VBG","JJ","NN"},
"ruttish":	{"JJ"},
"rutty":	{"JJ"},
"rvs":	{"NNS"},
"rwanda":	{"NN"},
"rwandan":	{"JJ","NN"},
"rya":	{"NN"},
"rydberg":	{"NN"},
"rye":	{"NN"},
"ryegrass":	{"NN"},
"rymer":	{"NN"},
"rynchopidae":	{"NN"},
"rynchops":	{"NNS"},
"rypticus":	{"NN"},
"ryukyuan":	{"NN"},
"s":	{"NN","SYM","LS"},
"s-curve":	{"NN"},
"sa":	{"NN"},
"saale":	{"NN"},
"saame":	{"NN"},
"saami":	{"NN"},
"saarinen":	{"NN"},
"sabahan":	{"JJ","NN"},
"sabal":	{"NN"},
"sabaoth":	{"NN"},
"sabaton":	{"NN"},
"sabayon":	{"NN"},
"sabbat":	{"NN"},
"sabbath":	{"NN"},
"sabbatia":	{"NN"},
"sabbatic":	{"JJ"},
"sabbatical":	{"NN","JJ"},
"sabbaticals":	{"NNS"},
"sabbatum":	{"NN"},
"sabellian":	{"NN"},
"saber":	{"NN"},
"saber-rattling":	{"NN","JJ"},
"saber-toothed":	{"JJ"},
"sabermetrics":	{"NN"},
"sabers":	{"NNS"},
"sabicu":	{"NN"},
"sabin":	{"NN"},
"sabinea":	{"NN"},
"sable":	{"NN","JJ"},
"sables":	{"NNS"},
"sabot":	{"NN"},
"sabotage":	{"VB","VBP","NN"},
"sabotaged":	{"VBD","VBN"},
"sabotages":	{"VBZ"},
"sabotaging":	{"VBG"},
"saboteur":	{"NN"},
"saboteurs":	{"NNS"},
"sabra":	{"NN"},
"sabras":	{"NNS"},
"sabre":	{"NN"},
"sabre-rattling":	{"NN"},
"sabre-toothed":	{"JJ"},
"sabres":	{"NNS"},
"sabrina":	{"NN"},
"sac":	{"NN"},
"sacadolares":	{"FW"},
"saccade":	{"NN"},
"saccadic":	{"JJ"},
"saccharase":	{"NN"},
"saccharide":	{"NN"},
"saccharification":	{"NN"},
"saccharified":	{"VBD","VBN"},
"saccharifies":	{"VBZ"},
"saccharify":	{"VB","VBP"},
"saccharifying":	{"VBG"},
"saccharin":	{"NN"},
"saccharine":	{"NN","JJ"},
"saccharinity":	{"NN"},
"saccharisation":	{"NN"},
"saccharise":	{"VB","VBP"},
"saccharised":	{"VBD","VBN"},
"saccharises":	{"VBZ"},
"saccharising":	{"VBG"},
"saccharization":	{"NN"},
"saccharize":	{"VB","VBP"},
"saccharized":	{"VBD","VBN"},
"saccharizes":	{"VBZ"},
"saccharizing":	{"VBG"},
"saccharomyces":	{"NN"},
"saccharomycetaceae":	{"NN"},
"saccharose":	{"NN"},
"saccharum":	{"NN"},
"sacco":	{"NN"},
"sacculate":	{"JJ"},
"sacculation":	{"NN"},
"saccule":	{"NN"},
"sacculi":	{"NNS"},
"sacculus":	{"NN"},
"sacerdotal":	{"JJ"},
"sacerdotalism":	{"NN"},
"saceur":	{"NN"},
"sachem":	{"NN"},
"sachems":	{"NNS"},
"sachet":	{"NN"},
"sachets":	{"NNS"},
"sachsen":	{"NN"},
"sack":	{"NN","VB","VBP"},
"sackbut":	{"NN"},
"sackcloth":	{"NN"},
"sackcloths":	{"NNS"},
"sacked":	{"VBD","VBN"},
"sacker":	{"NN"},
"sackful":	{"NN"},
"sackfuls":	{"NNS"},
"sacking":	{"NN","VBG"},
"sackings":	{"NNS"},
"sackless":	{"JJ"},
"sacks":	{"NNS","VBZ"},
"saclant":	{"NN"},
"saclike":	{"JJ"},
"sacque":	{"NN"},
"sacral":	{"JJ"},
"sacrament":	{"NN"},
"sacramental":	{"JJ"},
"sacramento":	{"NN"},
"sacraments":	{"NNS"},
"sacred":	{"JJ"},
"sacredly":	{"RB"},
"sacredness":	{"NN"},
"sacrifice":	{"NN","VB","VBP"},
"sacrificeable":	{"JJ"},
"sacrificed":	{"VBD","VBN"},
"sacrificer":	{"NN"},
"sacrifices":	{"VBZ","NNS"},
"sacrificial":	{"JJ"},
"sacrificially":	{"RB"},
"sacrificing":	{"VBG"},
"sacrificium":	{"NN"},
"sacrilege":	{"NN"},
"sacrilegious":	{"JJ"},
"sacrilegiously":	{"RB"},
"sacrilegiousness":	{"NN"},
"sacristan":	{"NN"},
"sacristans":	{"NNS"},
"sacristies":	{"NNS"},
"sacristy":	{"NN"},
"sacrosanct":	{"JJ"},
"sacrum":	{"NN"},
"sacs":	{"NNS"},
"sad":	{"JJ"},
"sadat":	{"NN"},
"saddam":	{"NN"},
"sadden":	{"VB","VBP"},
"saddened":	{"VBD","VBN","JJ"},
"saddening":	{"VBG","JJ"},
"saddens":	{"VBZ"},
"sadder":	{"JJR"},
"saddest":	{"JJS"},
"saddhu":	{"NN"},
"saddle":	{"NN","VB","VBP"},
"saddle-bag":	{"NN"},
"saddle-bags":	{"NNS"},
"saddle-sore":	{"JJ"},
"saddleback":	{"NN"},
"saddlebag":	{"NN"},
"saddlebags":	{"NNS"},
"saddlebill":	{"NN"},
"saddlebow":	{"NN"},
"saddlecloth":	{"NN"},
"saddled":	{"VBD","VBN"},
"saddler":	{"NN"},
"saddlers":	{"NNS"},
"saddlery":	{"NN"},
"saddles":	{"VBZ","NNS"},
"saddling":	{"VBG"},
"sadducean":	{"JJ"},
"sadducee":	{"NN"},
"sade":	{"NN"},
"sadhe":	{"NN"},
"sadhu":	{"NN"},
"sadhus":	{"NNS"},
"sadism":	{"NN"},
"sadist":	{"NN"},
"sadistic":	{"JJ"},
"sadistically":	{"RB"},
"sadists":	{"NNS"},
"sadleria":	{"NN"},
"sadly":	{"RB"},
"sadness":	{"NN"},
"sadomasochism":	{"NN"},
"sadomasochist":	{"NN"},
"sadomasochistic":	{"JJ"},
"sadomasochists":	{"NNS"},
"saek":	{"NN"},
"safaqis":	{"NN"},
"safar":	{"NN"},
"safari":	{"NN"},
"safaris":	{"NNS"},
"safe":	{"JJ","NN"},
"safe-conduct":	{"NN"},
"safe-conducts":	{"NNS"},
"safe-cracker":	{"NN"},
"safe-cracking":	{"JJ"},
"safe-deposit":	{"NN","JJ"},
"safe-driving":	{"JJ"},
"safebreaker":	{"NN"},
"safecracker":	{"NN"},
"safecracking":	{"JJ"},
"safeguard":	{"VB","VBP","NN"},
"safeguarded":	{"VBD","VBN"},
"safeguarding":	{"VBG"},
"safeguards":	{"NNS","VBZ"},
"safehold":	{"NN"},
"safekeeping":	{"NN"},
"safely":	{"RB"},
"safeness":	{"NN"},
"safer":	{"JJR"},
"safest":	{"JJS"},
"safeties":	{"NNS"},
"safety":	{"NN","JJ"},
"safety-belt":	{"NN"},
"safety-belts":	{"NNS"},
"safety-catch":	{"NN"},
"safety-catches":	{"NNS"},
"safety-pin":	{"NN"},
"safety-pins":	{"NNS"},
"safety-valve":	{"NN"},
"safety-valves":	{"NNS"},
"safflower":	{"NN"},
"saffron":	{"NN","JJ"},
"safranin":	{"NN"},
"safranine":	{"NN"},
"sag":	{"VB","VBP","NN"},
"saga":	{"NN"},
"sagacious":	{"JJ"},
"sagaciously":	{"RB"},
"sagaciousness":	{"NN"},
"sagacity":	{"NN"},
"sagamore":	{"NN"},
"sagas":	{"NNS"},
"sage":	{"NN","JJ"},
"sage-brush":	{"NN"},
"sagebrush":	{"NN"},
"sagely":	{"RB"},
"sages":	{"NNS"},
"sagged":	{"VBD","VBN"},
"saggier":	{"JJR"},
"saggiest":	{"JJS"},
"sagging":	{"NN","VBG"},
"saggy":	{"JJ"},
"sagina":	{"NN"},
"saginaw":	{"NN"},
"sagittal":	{"JJ"},
"sagittaria":	{"NN"},
"sagittariidae":	{"NN"},
"sagittate":	{"JJ"},
"sagittiform":	{"JJ"},
"sago":	{"NN"},
"sago-palm":	{"NN"},
"sags":	{"VBZ"},
"saguaro":	{"NN"},
"sahaptin":	{"NN"},
"sahaptino":	{"NN"},
"sahib":	{"NN"},
"sahibs":	{"NNS"},
"sahuaro":	{"NN"},
"said":	{"VBD","VBN","JJ"},
"saida":	{"NN"},
"saiga":	{"NN"},
"saigon":	{"NN"},
"sail":	{"VB","VBP","NN"},
"sailboat":	{"NN"},
"sailboats":	{"NNS"},
"sailcloth":	{"NN"},
"sailed":	{"VBD","VBN"},
"sailfish":	{"NN"},
"sailing":	{"NN","VBG"},
"sailing-boat":	{"NN"},
"sailing-boats":	{"NNS"},
"sailing-ship":	{"NN"},
"sailing-ships":	{"NNS"},
"sailings":	{"NNS"},
"sailmaker":	{"NN"},
"sailor":	{"NN"},
"sailorly":	{"JJ"},
"sailors":	{"NNS"},
"sailplane":	{"NN","VB","VBP"},
"sailplaned":	{"VBD","VBN"},
"sailplaner":	{"NN"},
"sailplaners":	{"NNS"},
"sailplanes":	{"NNS","VBZ"},
"sailplaning":	{"VBG","NN"},
"sails":	{"VBZ","NNS"},
"saimiri":	{"NN"},
"sainfoin":	{"NN"},
"saint":	{"NN","VB","VBP"},
"saint-saens":	{"NN"},
"saintdom":	{"NN"},
"sainted":	{"JJ","VBD","VBN"},
"sainthood":	{"NN"},
"sainting":	{"VBG"},
"saintless":	{"JJ"},
"saintlike":	{"JJ"},
"saintliness":	{"NN"},
"saintly":	{"JJ"},
"saintpaulia":	{"NN"},
"saints":	{"NNS","VBZ"},
"saipan":	{"NN"},
"saison":	{"NN"},
"saisons":	{"NNS"},
"saith":	{"VBZ"},
"sajama":	{"NN"},
"sakartvelo":	{"NN"},
"sake":	{"NN"},
"sakharov":	{"NN"},
"saki":	{"NN"},
"sakkara":	{"NN"},
"sako":	{"NN"},
"sakti":	{"NN"},
"saktism":	{"NN"},
"sakura":	{"NN"},
"sal":	{"NN"},
"sala":	{"NN"},
"salaah":	{"NN"},
"salaam":	{"NN","VB","VBP","UH"},
"salaamed":	{"VBD","VBN"},
"salaaming":	{"VBG"},
"salaams":	{"VBZ"},
"salaat":	{"NN"},
"salability":	{"NN"},
"salable":	{"JJ"},
"salableness":	{"NN"},
"salacious":	{"JJ"},
"salaciously":	{"RB"},
"salaciousness":	{"NN"},
"salacity":	{"NN"},
"salad":	{"NN"},
"salad-dressing":	{"NN"},
"salad-dressings":	{"NNS"},
"salad-oil":	{"NN"},
"salade":	{"NN"},
"saladin":	{"NN"},
"salads":	{"NNS"},
"salafism":	{"NN"},
"salah":	{"NN"},
"salai":	{"NN"},
"salal":	{"NN"},
"salamander":	{"NN"},
"salamanders":	{"NNS"},
"salamandra":	{"NN"},
"salamandridae":	{"NN"},
"salamandriform":	{"JJ"},
"salami":	{"NN"},
"salamis":	{"NNS"},
"salaried":	{"JJ"},
"salaries":	{"NNS"},
"salary":	{"NN"},
"salaryman":	{"NN"},
"salarymen":	{"NNS"},
"salat":	{"NN"},
"sale":	{"NN"},
"saleable":	{"JJ"},
"salem":	{"NN"},
"saleman":	{"NN"},
"salemen":	{"NNS"},
"saleratus":	{"NN"},
"salerno":	{"NN"},
"saleroom":	{"NN"},
"salerooms":	{"NNS"},
"sales":	{"NNS"},
"sales-tax":	{"NN"},
"sales-taxes":	{"NNS"},
"salesclerk":	{"NN"},
"salesclerks":	{"NNS"},
"salesgirl":	{"NN"},
"salesgirls":	{"NNS"},
"salesladies":	{"NNS"},
"saleslady":	{"NN"},
"salesman":	{"NN"},
"salesmanship":	{"NN"},
"salesmen":	{"NNS"},
"salespeople":	{"NNS"},
"salesperson":	{"NN"},
"salespersons":	{"NNS"},
"salesroom":	{"NN"},
"salesrooms":	{"NNS"},
"saleswoman":	{"NN"},
"saleswomen":	{"NNS"},
"salian":	{"NN"},
"salicaceae":	{"NN"},
"salicales":	{"NNS"},
"salicornia":	{"NN"},
"salicylate":	{"NN"},
"salicylates":	{"NNS"},
"salicylic":	{"JJ"},
"salience":	{"NN"},
"saliency":	{"NN"},
"salient":	{"JJ","NN"},
"salientia":	{"NN"},
"salientian":	{"JJ","NN"},
"salients":	{"NNS"},
"saliferous":	{"JJ"},
"salim":	{"NN"},
"salina":	{"NN"},
"salinate":	{"VB"},
"saline":	{"JJ","NN"},
"salinger":	{"NN"},
"salinity":	{"NN"},
"salinometer":	{"NN"},
"salish":	{"NN"},
"salishan":	{"NN"},
"saliva":	{"NN"},
"salivary":	{"JJ"},
"salivate":	{"VB","VBP"},
"salivated":	{"VBD","VBN"},
"salivates":	{"VBZ"},
"salivating":	{"VBG"},
"salivation":	{"NN"},
"salix":	{"NN"},
"salk":	{"NN"},
"sallet":	{"NN"},
"sallied":	{"VBD","VBN"},
"sallies":	{"NNS","VBZ"},
"sallow":	{"JJ","NN","VB","VBP"},
"sallowed":	{"VBD","VBN"},
"sallower":	{"JJR"},
"sallowest":	{"JJS"},
"sallowing":	{"VBG"},
"sallowish":	{"JJ"},
"sallowness":	{"NN"},
"sallows":	{"VBZ","NNS"},
"sallowy":	{"JJ"},
"sally":	{"NN","VB","VBP"},
"sallying":	{"VBG"},
"salmacis":	{"NN"},
"salmagundi":	{"NN"},
"salmi":	{"NN"},
"salmo":	{"NN"},
"salmon":	{"NN","NNS"},
"salmonberry":	{"NN"},
"salmonella":	{"NN"},
"salmonellosis":	{"NN"},
"salmonid":	{"NN"},
"salmonidae":	{"NN"},
"salmwood":	{"NN"},
"salol":	{"NN"},
"salomon":	{"NN"},
"salon":	{"NN"},
"salons":	{"NNS"},
"saloon":	{"NN"},
"saloonkeeper":	{"NN"},
"saloons":	{"NNS"},
"salp":	{"NN"},
"salpa":	{"NN"},
"salpichroa":	{"NN"},
"salpidae":	{"NN"},
"salpiglossis":	{"NN"},
"salpinctes":	{"NN"},
"salpingectomy":	{"NN"},
"salpingitis":	{"NN"},
"salpinx":	{"NN"},
"salsa":	{"NN"},
"salsas":	{"NNS"},
"salsify":	{"NN"},
"salsilla":	{"NN"},
"salsola":	{"NN"},
"salt":	{"NN","JJ","VB","VBP"},
"salt-cellar":	{"NN"},
"salt-cellars":	{"NNS"},
"salt-lick":	{"NN"},
"salt-mine":	{"NN"},
"salt-pan":	{"NN"},
"salt-shaker":	{"NN"},
"salt-shakers":	{"NNS"},
"saltate":	{"VB","VBP"},
"saltated":	{"VBD","VBN"},
"saltates":	{"VBZ"},
"saltating":	{"VBG"},
"saltation":	{"NN"},
"saltbox":	{"NN"},
"saltbush":	{"NN"},
"saltcellar":	{"NN"},
"salted":	{"VBD","VBN","JJ"},
"salter":	{"NN"},
"saltier":	{"JJR"},
"saltiest":	{"JJS"},
"saltine":	{"NN"},
"saltines":	{"NNS"},
"saltiness":	{"NN"},
"salting":	{"VBG"},
"saltire":	{"NN"},
"saltish":	{"JJ"},
"saltlike":	{"JJ"},
"saltpan":	{"NN"},
"saltpeter":	{"NN"},
"saltpetre":	{"NN"},
"salts":	{"VBZ","NNS"},
"saltshaker":	{"NN"},
"saltwater":	{"JJ"},
"saltworks":	{"NN","NNS"},
"saltwort":	{"NN"},
"salty":	{"JJ"},
"salubrious":	{"JJ"},
"salubriousness":	{"NN"},
"salubrity":	{"NN"},
"saluki":	{"NN"},
"salutaris":	{"FW"},
"salutary":	{"JJ"},
"salutation":	{"NN"},
"salutations":	{"NNS"},
"salutatorian":	{"NN"},
"salutatory":	{"JJ","NN"},
"salute":	{"VB","VBP","NN"},
"saluted":	{"VBD","VBN"},
"saluter":	{"NN"},
"salutes":	{"NNS","VBZ"},
"saluting":	{"VBG"},
"salvador":	{"NN"},
"salvadora":	{"NN"},
"salvadoraceae":	{"NN"},
"salvadoran":	{"JJ","NN"},
"salvadorian":	{"NN"},
"salvage":	{"VB","VBP","NN"},
"salvageable":	{"JJ"},
"salvaged":	{"VBD","VBN"},
"salvager":	{"NN"},
"salvages":	{"VBZ","NNS"},
"salvaging":	{"VBG","NN"},
"salvation":	{"NN"},
"salve":	{"NN","VB","VBP"},
"salved":	{"VBD","VBN"},
"salvelinus":	{"NN"},
"salver":	{"NN"},
"salverform":	{"JJ"},
"salvers":	{"NNS"},
"salves":	{"NNS","VBZ"},
"salvia":	{"NN"},
"salvific":	{"JJ"},
"salving":	{"VBG"},
"salvinia":	{"NN"},
"salviniaceae":	{"NN"},
"salvinorin":	{"NN"},
"salvo":	{"NN"},
"salvoes":	{"NNS"},
"salvor":	{"NN"},
"salvors":	{"NNS"},
"salvos":	{"NNS"},
"salwar":	{"NN"},
"salzburg":	{"NN"},
"sam":	{"VB","VBP"},
"sama-veda":	{"NN"},
"saman":	{"NN"},
"samanala":	{"NN"},
"samara":	{"NN"},
"samarang":	{"NN"},
"samarcand":	{"NN"},
"samaria":	{"NN"},
"samaritans":	{"NNS"},
"samarium":	{"NN"},
"samarkand":	{"NN"},
"samarskite":	{"NN"},
"samba":	{"NN","VB","VBP"},
"sambaed":	{"VBD","VBN"},
"sambaing":	{"VBG"},
"sambar":	{"NN"},
"sambas":	{"NNS","VBZ"},
"sambre":	{"NN"},
"sambuca":	{"NN"},
"sambucus":	{"NN"},
"sambur":	{"NN"},
"same":	{"JJ","PRP","RB"},
"same-sex":	{"JJ"},
"samekh":	{"NN"},
"sameness":	{"NN"},
"samhita":	{"NN"},
"sami":	{"NN"},
"samia":	{"NN"},
"samiel":	{"NN"},
"samisen":	{"NN"},
"samite":	{"NN"},
"samizdat":	{"NN"},
"sammed":	{"VBD","VBN"},
"samming":	{"VBG"},
"samnite":	{"NN"},
"samoa":	{"NN"},
"samolus":	{"NN"},
"samosa":	{"NN"},
"samosas":	{"NNS"},
"samovar":	{"NN"},
"samovars":	{"NNS"},
"sampan":	{"NN"},
"sampans":	{"NNS"},
"samphire":	{"NN"},
"sample":	{"NN","VB","VBP"},
"sampled":	{"VBD","VBN"},
"sampler":	{"NN"},
"samplers":	{"NNS"},
"samples":	{"NNS","VBZ"},
"sampling":	{"NN","VBG"},
"samplings":	{"NNS"},
"sampson":	{"NN"},
"sams":	{"VBZ"},
"samsara":	{"NN"},
"samson":	{"NN"},
"samuel":	{"NN"},
"samurai":	{"NN","NNS","JJ"},
"sanaa":	{"NN"},
"sanatarium":	{"NN"},
"sanative":	{"JJ"},
"sanatoria":	{"NNS"},
"sanatorium":	{"NN"},
"sanatoriums":	{"NNS"},
"sanchez":	{"NN"},
"sanctification":	{"NN"},
"sanctified":	{"JJ","VBD","VBN"},
"sanctifies":	{"VBZ"},
"sanctify":	{"VB","VBP"},
"sanctifying":	{"VBG"},
"sanctimonious":	{"JJ"},
"sanctimoniously":	{"RB"},
"sanctimoniousness":	{"NN"},
"sanctimony":	{"NN"},
"sanction":	{"NN","VB","VBP"},
"sanctionative":	{"JJ"},
"sanctioned":	{"VBD","VBN"},
"sanctioning":	{"VBG"},
"sanctions":	{"NNS","VBZ"},
"sanctitude":	{"NN"},
"sanctity":	{"NN"},
"sanctorum":	{"FW"},
"sanctuaries":	{"NNS"},
"sanctuary":	{"NN"},
"sanctum":	{"NN"},
"sanctums":	{"NNS"},
"sand":	{"NN","VBP","VB"},
"sand-bar":	{"NN"},
"sand-bars":	{"NNS"},
"sand-blind":	{"JJ"},
"sand-castle":	{"NN"},
"sand-castles":	{"NNS"},
"sand-dune":	{"NN"},
"sand-fly":	{"NN"},
"sand-pit":	{"NN"},
"sand-pits":	{"NNS"},
"sand-shoes":	{"NNS"},
"sand-yacht":	{"NN"},
"sandal":	{"NN"},
"sandalled":	{"JJ"},
"sandals":	{"NNS"},
"sandalwood":	{"NN"},
"sandarac":	{"NN"},
"sandarach":	{"NN"},
"sandbag":	{"NN","VB","VBP"},
"sandbagged":	{"VBD","VBN"},
"sandbagger":	{"NN"},
"sandbaggers":	{"NNS"},
"sandbagging":	{"VBG"},
"sandbags":	{"NNS","VBZ"},
"sandbank":	{"NN"},
"sandbanks":	{"NNS"},
"sandbar":	{"NN"},
"sandbars":	{"NNS"},
"sandberry":	{"NN"},
"sandblast":	{"NN","VB","VBP"},
"sandblasted":	{"VBD","VBN"},
"sandblaster":	{"NN"},
"sandblasting":	{"VBG"},
"sandblasts":	{"VBZ"},
"sandbox":	{"NN"},
"sandboxes":	{"NNS"},
"sandboy":	{"NN"},
"sandbur":	{"NN"},
"sandburg":	{"NN"},
"sandcastle":	{"NN"},
"sandcastles":	{"NNS"},
"sanded":	{"VBD","VBN"},
"sander":	{"NN"},
"sanderling":	{"NN"},
"sanders":	{"NNS"},
"sandfish":	{"NN"},
"sandfly":	{"NN"},
"sandglass":	{"NN"},
"sandgrouse":	{"NN"},
"sandhi":	{"NN"},
"sandhopper":	{"NN"},
"sandier":	{"JJR"},
"sandiest":	{"JJS"},
"sandification":	{"NN"},
"sandiness":	{"NN"},
"sanding":	{"VBG"},
"sandinista":	{"NN"},
"sandler":	{"NN"},
"sandlike":	{"JJ"},
"sandlot":	{"NN"},
"sandman":	{"NN"},
"sandpaper":	{"NN","VB","VBP"},
"sandpapered":	{"VBD","VBN"},
"sandpapering":	{"VBG"},
"sandpapers":	{"VBZ"},
"sandpapery":	{"JJ"},
"sandpile":	{"NN"},
"sandpiper":	{"NN"},
"sandpipers":	{"NNS"},
"sandpit":	{"NN"},
"sandpits":	{"NNS"},
"sandril":	{"NN"},
"sands":	{"NNS","VBZ"},
"sandspur":	{"NN"},
"sandstone":	{"NN"},
"sandstones":	{"NNS"},
"sandstorm":	{"NN"},
"sandstorms":	{"NNS"},
"sandwich":	{"NN","VBP","VB"},
"sandwiched":	{"VBD","VBN","JJ"},
"sandwiches":	{"NNS","VBZ"},
"sandwiching":	{"VBG"},
"sandwichman":	{"NN"},
"sandwort":	{"NN"},
"sandy":	{"JJ"},
"sane":	{"JJ"},
"sanely":	{"RB"},
"saneness":	{"NN"},
"saner":	{"JJR"},
"sanest":	{"JJS"},
"sanfoin":	{"NN"},
"sang":	{"VBD"},
"sang-froid":	{"NN"},
"sangapenum":	{"NN"},
"sangaree":	{"NN"},
"sangay":	{"NN"},
"sanger":	{"NN"},
"sangiovanni":	{"NNS"},
"sango":	{"NN"},
"sangoma":	{"NN"},
"sangraal":	{"NN"},
"sangria":	{"NN"},
"sanguification":	{"NN"},
"sanguinaria":	{"NN"},
"sanguinary":	{"JJ"},
"sanguine":	{"JJ"},
"sanguinely":	{"RB"},
"sanguineness":	{"NN"},
"sanguineous":	{"JJ"},
"sanguineum":	{"NN"},
"sanguinity":	{"NN"},
"sanicle":	{"NN"},
"sanicula":	{"NN"},
"sanies":	{"NN"},
"sanious":	{"JJ"},
"sanipractor":	{"NN"},
"sanitaire":	{"FW"},
"sanitaria":	{"NNS"},
"sanitariness":	{"NN"},
"sanitarium":	{"NN"},
"sanitariums":	{"NNS"},
"sanitary":	{"JJ"},
"sanitate":	{"VB","VBP"},
"sanitated":	{"VBD","VBN"},
"sanitates":	{"VBZ"},
"sanitating":	{"VBG"},
"sanitation":	{"NN"},
"sanitationist":	{"NN"},
"sanitationists":	{"NNS"},
"sanitisation":	{"NN"},
"sanitise":	{"VB","VBP"},
"sanitised":	{"VBD","VBN"},
"sanitises":	{"VBZ"},
"sanitising":	{"VBG"},
"sanitization":	{"NN"},
"sanitize":	{"VB","VBP"},
"sanitized":	{"VBD","VBN"},
"sanitizes":	{"VBZ"},
"sanitizing":	{"VBG"},
"sanity":	{"NN"},
"sank":	{"VBD"},
"sannup":	{"NN"},
"sannyasi":	{"NN"},
"sannyasin":	{"NN"},
"sansevieria":	{"NN"},
"santalaceae":	{"NN"},
"santalales":	{"NNS"},
"santalum":	{"NN"},
"santee":	{"NN"},
"santiago":	{"NN"},
"santimi":	{"NNS"},
"santims":	{"NN"},
"santolina":	{"NN"},
"sanvitalia":	{"NN"},
"sanyasi":	{"NN"},
"saone":	{"NN"},
"sap":	{"NN","VB","VBP"},
"saphar":	{"NN"},
"saphead":	{"NN"},
"sapid":	{"JJ"},
"sapidity":	{"NN"},
"sapidness":	{"NN"},
"sapien":	{"NN"},
"sapience":	{"NN"},
"sapiens":	{"NN"},
"sapient":	{"JJ"},
"sapiential":	{"JJ"},
"sapiently":	{"RB"},
"sapindaceae":	{"NN"},
"sapindales":	{"NNS"},
"sapindus":	{"NN"},
"sapir":	{"NN"},
"sapless":	{"JJ"},
"sapling":	{"NN"},
"saplings":	{"NNS"},
"sapodilla":	{"NN"},
"saponaceous":	{"JJ"},
"saponaria":	{"NN"},
"saponifiable":	{"JJ"},
"saponification":	{"NN"},
"saponified":	{"VBD","VBN"},
"saponifier":	{"NN"},
"saponifies":	{"VBZ"},
"saponify":	{"VB","VBP"},
"saponifying":	{"VBG"},
"saponin":	{"NN"},
"saponins":	{"NNS"},
"saporous":	{"JJ"},
"sapota":	{"NN"},
"sapotaceae":	{"NN"},
"sapote":	{"NN"},
"sapped":	{"VBN","VBD"},
"sapper":	{"NN"},
"sappers":	{"NNS"},
"sapphic":	{"JJ"},
"sapphire":	{"NN","JJ"},
"sapphires":	{"NNS"},
"sapphirine":	{"JJ","NN"},
"sapphism":	{"NN"},
"sappho":	{"NN"},
"sapping":	{"VBG"},
"sapporo":	{"NN"},
"sappy":	{"JJ"},
"sapraemia":	{"NN"},
"sapremia":	{"NN"},
"saprobe":	{"NN"},
"saprobic":	{"JJ"},
"saprolegnia":	{"NN"},
"saprolegniales":	{"NNS"},
"saprolite":	{"NN"},
"sapropel":	{"NN"},
"saprophagous":	{"JJ"},
"saprophyte":	{"NN"},
"saprophytic":	{"JJ"},
"saprozoic":	{"JJ"},
"saps":	{"NNS","VBZ"},
"sapsago":	{"NN"},
"sapsucker":	{"NN"},
"sapwood":	{"NN"},
"saqqara":	{"NN"},
"saqqarah":	{"NN"},
"saquinavir":	{"NN"},
"saraband":	{"NN"},
"sarafem":	{"NN"},
"saragossa":	{"NN"},
"sarah":	{"NN"},
"sarajevo":	{"NN"},
"sarakin":	{"FW"},
"saran":	{"NN"},
"sarape":	{"NN"},
"sarasota":	{"NN"},
"sarasvati":	{"NN"},
"saratoga":	{"NN"},
"saratov":	{"NN"},
"sarawak":	{"NN"},
"sarawakian":	{"JJ","NN"},
"sarazen":	{"NN"},
"sarcasm":	{"NN"},
"sarcastic":	{"JJ"},
"sarcastically":	{"RB"},
"sarcenet":	{"NN"},
"sarcobatus":	{"NN"},
"sarcocephalus":	{"NN"},
"sarcochilus":	{"NN"},
"sarcocystidean":	{"NN"},
"sarcocystieian":	{"NN"},
"sarcocystis":	{"NN"},
"sarcodes":	{"NNS"},
"sarcodina":	{"NN"},
"sarcodine":	{"NN"},
"sarcodinian":	{"NN"},
"sarcoid":	{"JJ","NN"},
"sarcoidosis":	{"NN"},
"sarcolemma":	{"NN"},
"sarcolemmal":	{"JJ"},
"sarcolemmic":	{"JJ"},
"sarcolemnous":	{"JJ"},
"sarcoma":	{"NN"},
"sarcomas":	{"NNS"},
"sarcomere":	{"NN"},
"sarcophaga":	{"NN"},
"sarcophagi":	{"NNS"},
"sarcophagus":	{"NN"},
"sarcophaguses":	{"NNS"},
"sarcophilus":	{"NN"},
"sarcoplasm":	{"NN"},
"sarcoptes":	{"NNS"},
"sarcoptid":	{"NN"},
"sarcoptidae":	{"NN"},
"sarcorhamphus":	{"NN"},
"sarcoscyphaceae":	{"NN"},
"sarcosine":	{"NN"},
"sarcosomal":	{"JJ"},
"sarcosomataceae":	{"NN"},
"sarcosome":	{"NN"},
"sarcosporidia":	{"NN"},
"sarcosporidian":	{"NN"},
"sarcostemma":	{"NN"},
"sarcostyle":	{"NN"},
"sard":	{"NN"},
"sarda":	{"NN"},
"sardegna":	{"NN"},
"sardina":	{"NN"},
"sardine":	{"NN","NNS"},
"sardines":	{"NNS"},
"sardinia":	{"NN"},
"sardinops":	{"NNS"},
"sardis":	{"NN"},
"sardius":	{"NN"},
"sardonic":	{"JJ"},
"sardonically":	{"RB"},
"sardonyx":	{"NN"},
"saree":	{"NN"},
"sargasso":	{"NN"},
"sargassum":	{"NN"},
"sari":	{"NN"},
"sarin":	{"NN"},
"saris":	{"NNS"},
"sarnoff":	{"NN"},
"sarong":	{"NN"},
"sarongs":	{"NNS"},
"saroyan":	{"NN"},
"sarpanitu":	{"NN"},
"sarpedon":	{"NN"},
"sarracenia":	{"NN"},
"sarraceniaceae":	{"NN"},
"sarraceniales":	{"NNS"},
"sars":	{"NNS"},
"sarsaparilla":	{"NN"},
"sarsenet":	{"NN"},
"sartor":	{"NN"},
"sartorial":	{"JJ"},
"sartorially":	{"RB"},
"sartorius":	{"NN"},
"sartre":	{"NN"},
"sash":	{"NN","VB","VBP"},
"sasha":	{"NN"},
"sashay":	{"VB","VBP"},
"sashayed":	{"VBD","VBN"},
"sashaying":	{"VBG"},
"sashays":	{"VBZ"},
"sashed":	{"VBD","VBN"},
"sashes":	{"NNS","VBZ"},
"sashimi":	{"NN"},
"sashing":	{"VBG"},
"saskatchewan":	{"NN"},
"saskatoon":	{"NN"},
"sass":	{"NN","VB","VBP"},
"sassabies":	{"NNS"},
"sassaby":	{"NN"},
"sassafras":	{"NN"},
"sassed":	{"VBD","VBN"},
"sasses":	{"VBZ"},
"sassing":	{"VBG"},
"sassy":	{"JJ"},
"sat":	{"VBD","VBN"},
"satang":	{"NN"},
"satanic":	{"JJ"},
"satanically":	{"RB"},
"satanism":	{"NN"},
"satanist":	{"NN","JJ"},
"satanists":	{"NNS"},
"satanophobia":	{"NN"},
"satchel":	{"NN"},
"satchels":	{"NNS"},
"satchmo":	{"NN"},
"sate":	{"VB","VBP"},
"sated":	{"VBD","VBN","JJ"},
"sateen":	{"NN"},
"satellite":	{"NN","JJ"},
"satellite-dish":	{"NN"},
"satellites":	{"NNS"},
"sates":	{"VBZ"},
"satiable":	{"JJ"},
"satiate":	{"VB","VBP"},
"satiated":	{"JJ","VBD","VBN"},
"satiates":	{"VBZ"},
"satiating":	{"VBG"},
"satiation":	{"NN"},
"satie":	{"NN"},
"satiety":	{"NN"},
"satin":	{"NN","JJ"},
"satin-covered":	{"JJ"},
"satinet":	{"NN"},
"satinette":	{"NN"},
"sating":	{"VBG"},
"satinleaf":	{"NN"},
"satinpod":	{"NN"},
"satins":	{"NNS"},
"satinwood":	{"NN"},
"satiny":	{"JJ"},
"satire":	{"NN"},
"satires":	{"NNS"},
"satiric":	{"JJ"},
"satirical":	{"JJ"},
"satirically":	{"RB"},
"satirise":	{"VB","VBP"},
"satirised":	{"VBD","VBN"},
"satirises":	{"VBZ"},
"satirising":	{"VBG"},
"satirist":	{"NN"},
"satirists":	{"NNS"},
"satirize":	{"VB","VBP"},
"satirized":	{"VBD","VBN"},
"satirizes":	{"VBZ"},
"satirizing":	{"VBG"},
"satisfaction":	{"NN"},
"satisfactions":	{"NNS"},
"satisfactorily":	{"RB"},
"satisfactoriness":	{"NN"},
"satisfactory":	{"JJ"},
"satisfiable":	{"JJ"},
"satisfice":	{"VB","VBP"},
"satisficed":	{"VBD","VBN"},
"satisficer":	{"NN"},
"satisfices":	{"VBZ"},
"satisficing":	{"VBG"},
"satisfied":	{"VBN","JJ","VBD"},
"satisfier":	{"NN"},
"satisfies":	{"VBZ"},
"satisfy":	{"VB","VBP"},
"satisfying":	{"JJ","VBG"},
"satisfyingly":	{"RB"},
"satori":	{"NN"},
"satrap":	{"NN"},
"satsuma":	{"NN"},
"satsumas":	{"NNS"},
"saturate":	{"VBP","NN","VB"},
"saturated":	{"JJ","VBN","VBD"},
"saturates":	{"VBZ","NNS"},
"saturating":	{"VBG"},
"saturation":	{"NN"},
"satureia":	{"NN"},
"satureja":	{"NN"},
"saturn":	{"NN"},
"saturnalia":	{"NN","NNS"},
"saturnalias":	{"NNS"},
"saturnia":	{"NN"},
"saturniid":	{"NN"},
"saturniidae":	{"NN"},
"saturnine":	{"JJ"},
"saturnism":	{"NN"},
"satyagraha":	{"NN"},
"satyr":	{"NN"},
"satyriasis":	{"NN"},
"satyric":	{"JJ"},
"satyrical":	{"JJ"},
"satyridae":	{"NN"},
"satyrs":	{"NNS"},
"sauce":	{"NN","VB","VBP"},
"sauce-boat":	{"NN"},
"sauce-boats":	{"NNS"},
"sauceboat":	{"NN"},
"sauced":	{"VBD","VBN"},
"saucepan":	{"NN"},
"saucepans":	{"NNS"},
"saucepot":	{"NN"},
"saucer":	{"NN"},
"saucer-shaped":	{"JJ"},
"saucers":	{"NNS"},
"sauces":	{"NNS","VBZ"},
"saucier":	{"JJR"},
"sauciest":	{"JJS"},
"saucily":	{"RB"},
"sauciness":	{"NN"},
"saucing":	{"VBG"},
"saucy":	{"JJ"},
"sauerbraten":	{"NN"},
"sauerkraut":	{"NN"},
"sauk":	{"NN"},
"saul":	{"NN"},
"sauna":	{"NN"},
"saunas":	{"NNS"},
"saunter":	{"VB","VBP","NN"},
"sauntered":	{"VBD","VBN"},
"saunterer":	{"NN"},
"sauntering":	{"VBG"},
"saunters":	{"VBZ"},
"saurel":	{"NN"},
"sauria":	{"NN"},
"saurian":	{"NN","JJ"},
"saurischia":	{"NN"},
"saurischian":	{"NN"},
"sauromalus":	{"NN"},
"sauropod":	{"NN"},
"sauropoda":	{"NN"},
"sauropodomorpha":	{"NN"},
"sauropterygia":	{"NN"},
"saurosuchus":	{"NN"},
"saururaceae":	{"NN"},
"saururus":	{"NN"},
"saury":	{"NN"},
"sausage":	{"NN"},
"sausage-dog":	{"NN"},
"sausage-dogs":	{"NNS"},
"sausage-meat":	{"NN"},
"sausages":	{"NNS"},
"saussure":	{"NN"},
"saussurea":	{"NN"},
"saute":	{"JJ","VB","VBP"},
"sauteed":	{"VBD","VBN"},
"sauteing":	{"VBG"},
"sauterne":	{"NN"},
"sautes":	{"VBZ"},
"sauvignon":	{"NN","JJ"},
"savage":	{"JJ","NN","VB","VBP"},
"savaged":	{"VBD","VBN"},
"savagely":	{"RB"},
"savageness":	{"NN"},
"savageries":	{"NNS"},
"savagery":	{"NN"},
"savages":	{"NNS","VBZ"},
"savaging":	{"VBG"},
"savanna":	{"NN"},
"savannah":	{"NN"},
"savannahs":	{"NNS"},
"savannas":	{"NNS"},
"savant":	{"NN"},
"savants":	{"NNS"},
"savara":	{"NN"},
"savarin":	{"NN"},
"save":	{"VB","VBP","NN","IN"},
"save-all":	{"NN"},
"saved":	{"VBN","VBD"},
"saveloy":	{"NN"},
"saver":	{"NN"},
"savers":	{"NNS"},
"saves":	{"VBZ","NNS"},
"saving":	{"VBG","NN"},
"savings":	{"NNS"},
"savings-and-loan":	{"NN"},
"savings-and-loans":	{"NN"},
"savior":	{"NN"},
"saviors":	{"NNS"},
"saviour":	{"NN"},
"saviours":	{"NNS"},
"savitar":	{"NN"},
"savoir-faire":	{"NN"},
"savonarola":	{"NN"},
"savor":	{"VB","NN","VBP"},
"savored":	{"VBD","VBN"},
"savories":	{"NNS"},
"savoriness":	{"NN"},
"savoring":	{"VBG"},
"savorless":	{"JJ"},
"savorlessness":	{"NN"},
"savors":	{"VBZ"},
"savory":	{"NN","JJ"},
"savour":	{"NN","VBP","VB"},
"savoured":	{"VBD","VBN"},
"savouries":	{"NNS"},
"savouring":	{"VBG"},
"savourless":	{"JJ"},
"savourlessness":	{"NN"},
"savours":	{"VBZ"},
"savoury":	{"JJ","NN"},
"savoy":	{"NN"},
"savoyard":	{"NN"},
"savvied":	{"VBD","VBN"},
"savvier":	{"JJR"},
"savvies":	{"VBZ"},
"savviest":	{"JJS"},
"savvy":	{"NN","JJ","VB","VBP"},
"savvying":	{"VBG"},
"saw":	{"VBD","NN","VB","VBP"},
"saw-horse":	{"NN"},
"sawalisch":	{"NN"},
"sawan":	{"NN"},
"sawbill":	{"NN"},
"sawbones":	{"NN","NNS"},
"sawbuck":	{"NN"},
"sawdust":	{"NN"},
"sawed":	{"VBD","VBN"},
"sawfish":	{"NN"},
"sawfly":	{"NN"},
"sawhorse":	{"NN"},
"sawing":	{"VBG"},
"sawm":	{"NN"},
"sawmill":	{"NN"},
"sawmills":	{"NNS"},
"sawn":	{"VBN"},
"sawpit":	{"NN"},
"saws":	{"VBZ","NNS"},
"sawtimber":	{"NN"},
"sawtooth":	{"JJ"},
"sawwort":	{"NN"},
"sawyer":	{"NN"},
"sawyers":	{"NNS"},
"sax":	{"NN"},
"saxatile":	{"JJ"},
"saxe":	{"NN"},
"saxe-coburg-gotha":	{"NN"},
"saxe-gothea":	{"NN"},
"saxegothea":	{"NN"},
"saxes":	{"NNS"},
"saxhorn":	{"NN"},
"saxicola":	{"NN"},
"saxicoline":	{"JJ"},
"saxicolous":	{"JJ"},
"saxifraga":	{"NN"},
"saxifragaceae":	{"NN"},
"saxifrage":	{"NN"},
"saxist":	{"NN"},
"saxitoxin":	{"NN"},
"saxon":	{"JJ","NN"},
"saxony":	{"NN"},
"saxophone":	{"NN"},
"saxophones":	{"NNS"},
"saxophonist":	{"NN"},
"saxophonists":	{"NNS"},
"say":	{"VBP","VB","NN","UH"},
"say-so":	{"NN"},
"sayanci":	{"NN"},
"sayda":	{"NN"},
"sayeret":	{"NN"},
"saying":	{"VBG","NN"},
"sayings":	{"NNS"},
"sayonara":	{"NN","UH"},
"sayornis":	{"NN"},
"says":	{"VBZ"},
"sazerac":	{"NN"},
"sb":	{"NN"},
"sba":	{"NN"},
"sbcs-type":	{"JJ"},
"sbe":	{"NN"},
"sbw":	{"NN"},
"sc":	{"NN"},
"scab":	{"NN","JJ","VB","VBP"},
"scabbard":	{"NN"},
"scabbards":	{"NNS"},
"scabbed":	{"VBN","VBD"},
"scabbier":	{"JJR"},
"scabbiest":	{"JJS"},
"scabbing":	{"VBG"},
"scabby":	{"JJ"},
"scabicide":	{"NN"},
"scabies":	{"NN"},
"scabiosa":	{"NN"},
"scabious":	{"NN"},
"scablands":	{"NNS"},
"scabrous":	{"JJ"},
"scabs":	{"NNS","VBZ"},
"scad":	{"NN","NNS"},
"scads":	{"NNS"},
"scaffold":	{"NN","VB","VBP"},
"scaffolded":	{"VBD","VBN"},
"scaffolding":	{"NN","VBG"},
"scaffolds":	{"NNS","VBZ"},
"scag":	{"NN"},
"scalability":	{"NN"},
"scalable":	{"JJ"},
"scalage":	{"NN"},
"scalar":	{"JJ","NN"},
"scalawag":	{"NN"},
"scalawags":	{"NNS"},
"scald":	{"VB","VBP","NN"},
"scalded":	{"VBD","VBN"},
"scalding":	{"VBG","JJ"},
"scalds":	{"VBZ","NNS"},
"scale":	{"NN","VB","VBP"},
"scale-up":	{"NN"},
"scale-ups":	{"NNS"},
"scaled":	{"JJ","VBD","VBN"},
"scaled-down":	{"JJ"},
"scaleless":	{"JJ"},
"scalelike":	{"JJ"},
"scalene":	{"JJ","NN"},
"scalenus":	{"NN"},
"scaler":	{"NN"},
"scales":	{"NNS","VBZ"},
"scaley":	{"JJ"},
"scalic":	{"JJ"},
"scaliness":	{"NN"},
"scaling":	{"NN","VBG"},
"scallion":	{"NN"},
"scallions":	{"NNS"},
"scallop":	{"NN","VB","VBP"},
"scalloped":	{"JJ","VBD","VBN"},
"scallopine":	{"NN"},
"scalloping":	{"VBG"},
"scallopini":	{"NNS"},
"scallops":	{"NNS","VBZ"},
"scallywag":	{"NN"},
"scallywags":	{"NNS"},
"scalp":	{"NN","VB","VBP"},
"scalped":	{"VBD","VBN"},
"scalpel":	{"NN"},
"scalpels":	{"NNS"},
"scalper":	{"NN"},
"scalpers":	{"NNS"},
"scalping":	{"VBG"},
"scalps":	{"NNS","VBZ"},
"scaly":	{"JJ"},
"scam":	{"NN","VB","VBP"},
"scammed":	{"VBD","VBN"},
"scammer":	{"NN"},
"scammers":	{"NNS"},
"scamming":	{"VBG"},
"scammony":	{"NN"},
"scammonyroot":	{"NN"},
"scamp":	{"NN","VB","VBP"},
"scamped":	{"VBD","VBN"},
"scamper":	{"VB","VBP","NN"},
"scampered":	{"VBD","VBN"},
"scampering":	{"VBG"},
"scampers":	{"VBZ"},
"scampi":	{"NN"},
"scamping":	{"VBG"},
"scampo":	{"NN"},
"scamps":	{"NNS","VBZ"},
"scams":	{"NNS","VBZ"},
"scan":	{"VB","NN","VBP"},
"scandal":	{"NN"},
"scandalisation":	{"NN"},
"scandalise":	{"VB","VBP"},
"scandalised":	{"VBD","VBN"},
"scandalises":	{"VBZ"},
"scandalising":	{"VBG"},
"scandalization":	{"NN"},
"scandalize":	{"VB","VBP"},
"scandalized":	{"VBD","VBN"},
"scandalizes":	{"VBZ"},
"scandalizing":	{"VBG"},
"scandalmonger":	{"NN"},
"scandalmongering":	{"NN"},
"scandalmongers":	{"NNS"},
"scandalous":	{"JJ"},
"scandalously":	{"RB"},
"scandalousness":	{"NN"},
"scandals":	{"NNS"},
"scandanavian":	{"JJ"},
"scandent":	{"JJ"},
"scandentia":	{"NN"},
"scandinavia":	{"NN"},
"scandinavian":	{"JJ","NN"},
"scandium":	{"NN"},
"scanned":	{"VBD","VBN"},
"scanner":	{"NN"},
"scanners":	{"NNS"},
"scanning":	{"NN","JJ","VBG"},
"scans":	{"VBZ","NNS"},
"scansion":	{"NN"},
"scant":	{"JJ","VB","VBP","RB"},
"scanted":	{"VBD","VBN"},
"scantier":	{"JJR"},
"scantiest":	{"JJS"},
"scantily":	{"RB"},
"scantiness":	{"NN"},
"scanting":	{"VBG"},
"scantling":	{"NN"},
"scants":	{"VBZ"},
"scanty":	{"JJ"},
"scape":	{"NN"},
"scapegoat":	{"NN","VB","VBP"},
"scapegoated":	{"VBD","VBN"},
"scapegoating":	{"VBG","NN"},
"scapegoats":	{"NNS","VBZ"},
"scapegrace":	{"NN"},
"scaphiopus":	{"NNS"},
"scaphocephaly":	{"NN"},
"scaphoid":	{"JJ"},
"scaphopod":	{"NN"},
"scaphopoda":	{"NN"},
"scaphosepalum":	{"NN"},
"scapose":	{"JJ"},
"scapula":	{"NN"},
"scapulae":	{"NNS"},
"scapular":	{"NN","JJ"},
"scapulars":	{"NNS"},
"scapulary":	{"NN"},
"scapulohumeral":	{"JJ"},
"scar":	{"NN","VB","VBP"},
"scarab":	{"NN"},
"scarabaean":	{"NN"},
"scarabaeid":	{"NN"},
"scarabaeidae":	{"NN"},
"scarabaeus":	{"NN"},
"scaramouch":	{"NN"},
"scaramouche":	{"NN"},
"scarborough":	{"NN"},
"scarce":	{"JJ","RB"},
"scarcely":	{"RB"},
"scarceness":	{"NN"},
"scarcer":	{"JJR"},
"scarcest":	{"JJS"},
"scarcities":	{"NNS"},
"scarcity":	{"NN"},
"scardinius":	{"NN"},
"scare":	{"VB","VBP","NN"},
"scarecrow":	{"NN"},
"scarecrowish":	{"JJ"},
"scarecrows":	{"NNS"},
"scared":	{"VBN","VBD","JJ"},
"scaremonger":	{"NN"},
"scaremongering":	{"NN"},
"scaremongers":	{"NNS"},
"scarer":	{"NN"},
"scares":	{"NNS","VBZ"},
"scarey":	{"JJ"},
"scarf":	{"NN","VB","VBP"},
"scarface":	{"NN"},
"scarfed":	{"VBD","VBN"},
"scarfing":	{"VBG"},
"scarfpin":	{"NN"},
"scarfs":	{"NNS","VBZ"},
"scaridae":	{"NN"},
"scarier":	{"JJR"},
"scariest":	{"JJS"},
"scarified":	{"VBD","VBN"},
"scarifies":	{"VBZ"},
"scarify":	{"VB","VBP"},
"scarifying":	{"VBG"},
"scarily":	{"RB"},
"scaring":	{"VBG"},
"scarlatina":	{"NN"},
"scarlet":	{"JJ","NN"},
"scarlets":	{"NNS"},
"scarp":	{"NN","VB","VBP"},
"scarped":	{"VBD","VBN"},
"scarper":	{"VB","VBP"},
"scarpered":	{"VBD","VBN"},
"scarpering":	{"VBG"},
"scarpers":	{"VBZ"},
"scarping":	{"VBG"},
"scarps":	{"NNS","VBZ"},
"scarred":	{"JJ","VBD","VBN"},
"scarring":	{"VBG"},
"scars":	{"NNS","VBZ"},
"scartella":	{"NN"},
"scarves":	{"NNS"},
"scary":	{"JJ"},
"scat":	{"VB","VBP","NN"},
"scathe":	{"VB","VBP","NN"},
"scathed":	{"VBD","VBN"},
"scathes":	{"VBZ"},
"scathing":	{"JJ","VBG"},
"scathingly":	{"RB"},
"scatological":	{"JJ"},
"scatology":	{"NN"},
"scatophagy":	{"NN"},
"scats":	{"VBZ"},
"scatted":	{"VBD","VBN"},
"scatter":	{"VB","VBP","NN"},
"scatter-brain":	{"NN"},
"scatter-brained":	{"JJ"},
"scatter-brains":	{"NNS"},
"scatter-gun":	{"NN","JJ"},
"scatter-guns":	{"NNS"},
"scatterbrain":	{"NN"},
"scatterbrained":	{"JJ"},
"scatterbrains":	{"NNS"},
"scattered":	{"VBN","JJ","VBD"},
"scattergood":	{"NN"},
"scattergun":	{"NN","JJ"},
"scatterguns":	{"NNS"},
"scattering":	{"VBG","NN"},
"scatterings":	{"NNS"},
"scatters":	{"VBZ"},
"scattershot":	{"JJ"},
"scattier":	{"JJR"},
"scattiest":	{"JJS"},
"scattily":	{"RB"},
"scattiness":	{"NN"},
"scatting":	{"VBG"},
"scatty":	{"JJ"},
"scaup":	{"NN"},
"scauper":	{"NN"},
"scavenge":	{"VB","VBP"},
"scavenged":	{"VBD","VBN"},
"scavenger":	{"NN"},
"scavengers":	{"NNS"},
"scavenges":	{"VBZ"},
"scavenging":	{"VBG"},
"scd":	{"NN"},
"sceliphron":	{"NN"},
"sceloglaux":	{"NN"},
"sceloporus":	{"NN"},
"scenario":	{"NN"},
"scenarios":	{"NNS"},
"scenarist":	{"NN"},
"scenarists":	{"NNS"},
"scend":	{"VB","VBP","NN"},
"scended":	{"VBD","VBN"},
"scending":	{"VBG"},
"scends":	{"VBZ"},
"scene":	{"NN"},
"scene-shifter":	{"NN"},
"sceneries":	{"NNS"},
"scenery":	{"NN"},
"scenes":	{"NNS"},
"sceneshifter":	{"NN"},
"scenic":	{"JJ"},
"scenically":	{"RB"},
"scent":	{"NN","VB","VBP"},
"scented":	{"VBD","VBN","JJ"},
"scenting":	{"VBG"},
"scentless":	{"JJ"},
"scents":	{"NNS","VBZ"},
"scepter":	{"NN"},
"sceptered":	{"NN"},
"scepters":	{"NNS"},
"sceptic":	{"NN"},
"sceptical":	{"JJ"},
"sceptically":	{"RB"},
"scepticism":	{"NN"},
"sceptics":	{"NNS"},
"sceptre":	{"NN"},
"sceptred":	{"JJ"},
"sceptres":	{"NNS"},
"scet":	{"NN"},
"schadenfreude":	{"NN"},
"schaefer":	{"NN"},
"schaffneria":	{"NN"},
"schedule":	{"NN","VB","VBP"},
"scheduled":	{"VBN","JJ","VBD"},
"scheduler":	{"NN"},
"schedules":	{"NNS","VBZ"},
"scheduling":	{"NN","VBG"},
"scheele":	{"NN"},
"scheelite":	{"NN"},
"schefflera":	{"NN"},
"scheldt":	{"NN"},
"schema":	{"NN"},
"schemas":	{"NNS"},
"schemata":	{"NNS"},
"schematic":	{"JJ"},
"schematically":	{"RB"},
"schematisation":	{"NN"},
"schematise":	{"VB","VBP"},
"schematised":	{"VBD","VBN"},
"schematises":	{"VBZ"},
"schematising":	{"VBG"},
"schematization":	{"NN"},
"schematize":	{"VB","VBP"},
"schematized":	{"VBD","VBN"},
"schematizes":	{"VBZ"},
"schematizing":	{"VBG"},
"scheme":	{"NN","VB","VBP"},
"schemed":	{"VBD","VBN"},
"schemer":	{"NN"},
"schemers":	{"NNS"},
"schemes":	{"NNS","VBZ"},
"scheming":	{"JJ","VBG"},
"schemozzle":	{"NN"},
"schenectady":	{"NN"},
"scheol":	{"NN"},
"scheringplough":	{"NN"},
"scherzo":	{"NN"},
"scherzos":	{"NNS"},
"scheuchzeriaceae":	{"NN"},
"schiaparelli":	{"NN"},
"schiller":	{"NN"},
"schilling":	{"NN"},
"schillings":	{"NNS"},
"schindler":	{"NN"},
"schinus":	{"NN"},
"schipperke":	{"NN"},
"schism":	{"NN"},
"schismatic":	{"JJ"},
"schismatical":	{"JJ"},
"schismatically":	{"RB"},
"schisms":	{"NNS"},
"schist":	{"NN"},
"schistorrhachis":	{"NN"},
"schistosoma":	{"NN"},
"schistosomatidae":	{"NN"},
"schistosome":	{"NN"},
"schistosomiasis":	{"NN"},
"schizachyrium":	{"NN"},
"schizaea":	{"NN"},
"schizaeaceae":	{"NN"},
"schizanthus":	{"NN"},
"schizocarp":	{"NN"},
"schizogony":	{"NN"},
"schizoid":	{"JJ","NN"},
"schizoids":	{"NNS"},
"schizomycete":	{"NN"},
"schizomycetes":	{"NNS"},
"schizomycetic":	{"JJ"},
"schizomycetous":	{"JJ"},
"schizopetalon":	{"NN"},
"schizophragma":	{"NN"},
"schizophrenia":	{"NN"},
"schizophrenic":	{"JJ","NN"},
"schizophrenically":	{"RB"},
"schizophrenics":	{"NNS"},
"schizophyceae":	{"NN"},
"schizophyta":	{"NN"},
"schizopoda":	{"NN"},
"schizosaccharomyces":	{"NN"},
"schizosaccharomycetaceae":	{"NN"},
"schizothymia":	{"NN"},
"schleiden":	{"NN"},
"schlemiel":	{"NN"},
"schlep":	{"VB","VBP","NN"},
"schlepped":	{"VBD","VBN"},
"schlepper":	{"NN"},
"schlepping":	{"VBG"},
"schleps":	{"VBZ","NNS"},
"schlesien":	{"NN"},
"schlesinger":	{"NN"},
"schliemann":	{"NN"},
"schlimazel":	{"NN"},
"schlock":	{"NN"},
"schlockmeister":	{"NN"},
"schlumbergera":	{"NN"},
"schmaltz":	{"NN"},
"schmaltzier":	{"JJR"},
"schmaltziest":	{"JJS"},
"schmaltzy":	{"JJ"},
"schmalz":	{"NN"},
"schmalzier":	{"JJR"},
"schmalziest":	{"JJS"},
"schmalzy":	{"JJ"},
"schmear":	{"NN"},
"schmeer":	{"NN"},
"schmegegge":	{"NN"},
"schmidt":	{"NN"},
"schmo":	{"NN"},
"schmoes":	{"NNS"},
"schmoose":	{"NN","VB"},
"schmooze":	{"VB","VBP"},
"schmoozed":	{"VBD","VBN"},
"schmoozer":	{"NN"},
"schmoozes":	{"VBZ"},
"schmoozing":	{"VBG"},
"schmuck":	{"NN"},
"schnabel":	{"NN"},
"schnabelian":	{"JJ"},
"schnapps":	{"NN"},
"schnaps":	{"NN"},
"schnauzer":	{"NN"},
"schnecken":	{"NN"},
"schnittlaugh":	{"NN"},
"schnitzel":	{"NN"},
"schnook":	{"NN"},
"schnooks":	{"NNS"},
"schnorchel":	{"NN"},
"schnorkel":	{"NN"},
"schnorr":	{"VB","VBP"},
"schnorrer":	{"NN"},
"schnoz":	{"NN"},
"schnozzle":	{"NN"},
"schoenberg":	{"NN"},
"scholar":	{"NN"},
"scholarism":	{"NN"},
"scholarly":	{"JJ"},
"scholars":	{"NNS"},
"scholarship":	{"NN"},
"scholarships":	{"NNS"},
"scholastic":	{"JJ","NN"},
"scholastically":	{"RB"},
"scholasticism":	{"NN"},
"scholastics":	{"NNS"},
"scholia":	{"NN"},
"scholiast":	{"NN"},
"scholium":	{"NN"},
"schomburgkia":	{"NN"},
"schonbein":	{"NN"},
"schonberg":	{"NN"},
"school":	{"NN","VB","VBP"},
"school-age":	{"JJ"},
"school-aged":	{"JJ"},
"school-days":	{"NNS"},
"school-leaver":	{"NN"},
"school-leavers":	{"NNS"},
"school-marm":	{"NN"},
"school-marms":	{"NNS"},
"schoolbag":	{"NN"},
"schoolbags":	{"NNS"},
"schoolbook":	{"NN"},
"schoolbooks":	{"NNS"},
"schoolboy":	{"NN","JJ"},
"schoolboyish":	{"JJ"},
"schoolboys":	{"NNS"},
"schoolchild":	{"NN"},
"schoolchildren":	{"NNS"},
"schoolcraft":	{"NN"},
"schooldays":	{"NNS"},
"schooled":	{"VBD","VBN","JJ"},
"schoolfellow":	{"NN"},
"schoolfellows":	{"NNS"},
"schoolfriend":	{"NN"},
"schoolgirl":	{"NN"},
"schoolgirlish":	{"JJ"},
"schoolgirls":	{"NNS"},
"schoolhouse":	{"NN"},
"schoolhouses":	{"NNS"},
"schooling":	{"NN","VBG"},
"schoolman":	{"NN"},
"schoolmarm":	{"NN"},
"schoolmarms":	{"NNS"},
"schoolmaster":	{"NN"},
"schoolmasters":	{"NNS"},
"schoolmate":	{"NN"},
"schoolmates":	{"NNS"},
"schoolmen":	{"NNS"},
"schoolmistress":	{"NN"},
"schoolmistresses":	{"NNS"},
"schoolroom":	{"NN"},
"schoolrooms":	{"NNS"},
"schools":	{"NNS","VBZ"},
"schoolteacher":	{"NN"},
"schoolteachers":	{"NNS"},
"schooltime":	{"NN"},
"schoolwide":	{"JJ"},
"schoolwork":	{"NN"},
"schoolyard":	{"NN"},
"schoolyards":	{"NNS"},
"schooner":	{"NN"},
"schooners":	{"NNS"},
"schopenhauer":	{"NN"},
"schorl":	{"NN"},
"schottische":	{"NN"},
"schrod":	{"NN"},
"schrodinger":	{"NN"},
"schtick":	{"NN"},
"schtickl":	{"NN"},
"schticks":	{"NNS"},
"schtik":	{"NN"},
"schtikl":	{"NN"},
"schubert":	{"NN"},
"schulz":	{"NN"},
"schumacher":	{"NN"},
"schumann":	{"NN"},
"schumpeter":	{"NN"},
"schuss":	{"NN","VB","VBP"},
"schutzstaffel":	{"NN"},
"schwa":	{"NN"},
"schwann":	{"NN"},
"schwarzwald":	{"NN"},
"schwas":	{"NNS"},
"schweitzer":	{"NN"},
"schweiz":	{"NN"},
"sci-fi":	{"JJ","NN"},
"sciadopityaceae":	{"NN"},
"sciadopitys":	{"NNS"},
"sciaena":	{"NN"},
"sciaenid":	{"NN"},
"sciaenidae":	{"NN"},
"sciaenops":	{"NNS"},
"sciara":	{"NN"},
"sciarid":	{"NN"},
"sciaridae":	{"NN"},
"sciatic":	{"JJ"},
"sciatica":	{"NN","JJ"},
"scid":	{"NN"},
"science":	{"NN"},
"sciences":	{"NNS"},
"scienter":	{"RB","NN"},
"scientific":	{"JJ"},
"scientifically":	{"RB"},
"scientist":	{"NN"},
"scientists":	{"NNS"},
"scientology":	{"NN"},
"scilla":	{"NN"},
"scimitar":	{"NN"},
"scimitars":	{"NNS"},
"scincella":	{"NN"},
"scincid":	{"NN"},
"scincidae":	{"NN"},
"scincus":	{"NN"},
"scindapsus":	{"NN"},
"scintilla":	{"NN"},
"scintillant":	{"JJ"},
"scintillate":	{"VB","VBP"},
"scintillated":	{"VBD","VBN"},
"scintillates":	{"VBZ"},
"scintillating":	{"VBG","JJ"},
"scintillation":	{"NN"},
"sciolism":	{"NN"},
"sciolist":	{"NN"},
"sciolistic":	{"JJ"},
"sciolists":	{"NNS"},
"scion":	{"NN"},
"scions":	{"NNS"},
"scipio":	{"NN"},
"scirpus":	{"NN"},
"scission":	{"NN"},
"scissor":	{"NN","VB","VBP"},
"scissored":	{"VBD","VBN"},
"scissoring":	{"VBG"},
"scissors":	{"NNS","VBZ"},
"scissortail":	{"NN"},
"scissure":	{"NN"},
"sciuridae":	{"NN"},
"sciuromorpha":	{"NN"},
"sciurus":	{"NN"},
"sclaff":	{"VB","VBP","NN"},
"sclera":	{"NN"},
"scleranthus":	{"NN"},
"scleredema":	{"NN"},
"sclerite":	{"NN"},
"scleritis":	{"NN"},
"scleroderma":	{"NN"},
"sclerodermataceae":	{"NN"},
"sclerodermatales":	{"NNS"},
"sclerometer":	{"NN"},
"scleropages":	{"NNS"},
"scleroparei":	{"NN"},
"scleroprotein":	{"NN"},
"sclerosed":	{"JJ"},
"sclerosis":	{"NN"},
"sclerotic":	{"JJ"},
"sclerotinia":	{"NN"},
"sclerotiniaceae":	{"NN"},
"sclerotium":	{"NN"},
"sclerotomy":	{"NN"},
"sclk":	{"NN"},
"scnt":	{"NN"},
"scoff":	{"VB","VBP","NN"},
"scoffed":	{"VBD","VBN"},
"scoffer":	{"NN"},
"scoffers":	{"NNS"},
"scoffing":	{"VBG","JJ"},
"scoffingly":	{"RB"},
"scofflaw":	{"NN"},
"scofflaws":	{"NNS"},
"scoffs":	{"VBZ"},
"scofield":	{"NN"},
"scoke":	{"NN"},
"scold":	{"VB","VBP","NN"},
"scolded":	{"VBD","VBN"},
"scolder":	{"NN"},
"scolding":	{"NN","VBG"},
"scoldings":	{"NNS"},
"scolds":	{"VBZ","NNS"},
"scolion":	{"NN"},
"scoliosis":	{"NN"},
"scollop":	{"NN","VB","VBP"},
"scolloped":	{"VBD","VBN"},
"scolloping":	{"VBG","NN"},
"scollops":	{"VBZ"},
"scolopacidae":	{"NN"},
"scolopax":	{"NN"},
"scolopendrium":	{"NN"},
"scolymus":	{"NN"},
"scolytidae":	{"NN"},
"scolytus":	{"NN"},
"scomber":	{"NN"},
"scomberesocidae":	{"NN"},
"scomberesox":	{"NN"},
"scomberomorus":	{"NN"},
"scombresocidae":	{"NN"},
"scombresox":	{"NN"},
"scombridae":	{"NN"},
"scombroid":	{"NN"},
"scombroidea":	{"NN"},
"sconce":	{"NN"},
"sconces":	{"NNS"},
"scone":	{"NN"},
"scones":	{"NNS"},
"scoop":	{"NN","VB","VBP"},
"scooped":	{"VBD","VBN"},
"scoopful":	{"NN"},
"scooping":	{"VBG"},
"scoops":	{"NNS","VBZ"},
"scoot":	{"VB","VBP"},
"scooted":	{"VBD","VBN"},
"scooter":	{"NN"},
"scooters":	{"NNS"},
"scooting":	{"VBG"},
"scoots":	{"VBZ"},
"scop":	{"NN"},
"scopal":	{"JJ"},
"scope":	{"NN","VB","VBP"},
"scoped":	{"VBD","VBN"},
"scopes":	{"NNS","VBZ"},
"scophthalmus":	{"NN"},
"scoping":	{"VBG"},
"scopolamine":	{"NN"},
"scopolia":	{"NN"},
"scops":	{"NNS"},
"scorbutic":	{"JJ"},
"scorbutus":	{"NN"},
"scorch":	{"VB","VBP","NN"},
"scorched":	{"JJ","VBD","VBN"},
"scorcher":	{"NN"},
"scorches":	{"VBZ","NNS"},
"scorching":	{"VBG","JJ","RB"},
"score":	{"NN","VB","VBP"},
"score-board":	{"NN"},
"score-boards":	{"NNS"},
"score-card":	{"NN"},
"score-cards":	{"NNS"},
"scoreboard":	{"NN"},
"scoreboards":	{"NNS"},
"scorecard":	{"NN"},
"scorecards":	{"NNS"},
"scored":	{"VBD","VBN"},
"scorekeeper":	{"NN"},
"scorekeepers":	{"NNS"},
"scorekeeping":	{"NN"},
"scoreless":	{"JJ"},
"scorer":	{"NN"},
"scorers":	{"NNS"},
"scores":	{"NNS","VBZ"},
"scoria":	{"NN"},
"scoring":	{"VBG","NN"},
"scorn":	{"NN","VB","VBP"},
"scorned":	{"VBD","VBN"},
"scorner":	{"NN"},
"scornful":	{"JJ"},
"scornfully":	{"RB"},
"scorning":	{"VBG"},
"scorns":	{"VBZ"},
"scorpaena":	{"NN"},
"scorpaenid":	{"NN"},
"scorpaenidae":	{"NN"},
"scorpaenoid":	{"NN"},
"scorpaenoidea":	{"NN"},
"scorper":	{"NN"},
"scorpio":	{"NN"},
"scorpion":	{"NN"},
"scorpionfish":	{"NN"},
"scorpionida":	{"NN"},
"scorpions":	{"NNS"},
"scorpionweed":	{"NN"},
"scorpius":	{"NN"},
"scorzonera":	{"NN"},
"scot":	{"NN"},
"scot-free":	{"RB"},
"scotch":	{"NN","VB","VBP"},
"scotched":	{"VBD","VBN"},
"scotches":	{"NNS","VBZ"},
"scotching":	{"VBG"},
"scotchman":	{"NN"},
"scoter":	{"NN","NNS"},
"scoters":	{"NNS"},
"scotland":	{"NN"},
"scotoma":	{"NN"},
"scotomatous":	{"JJ"},
"scots":	{"JJ","NN"},
"scott":	{"NN"},
"scottie":	{"NN"},
"scottish":	{"JJ","NN"},
"scotty":	{"NN"},
"scoundrel":	{"NN"},
"scoundrelly":	{"JJ"},
"scoundrels":	{"NNS"},
"scour":	{"VB","VBP"},
"scoured":	{"VBD","VBN"},
"scourer":	{"NN"},
"scourers":	{"NNS"},
"scourge":	{"NN","VB","VBP"},
"scourged":	{"VBD","VBN"},
"scourger":	{"NN"},
"scourges":	{"NNS","VBZ"},
"scourging":	{"VBG"},
"scouring":	{"VBG"},
"scours":	{"VBZ"},
"scout":	{"NN","VB","VBP"},
"scouted":	{"VBD","VBN"},
"scouter":	{"NN"},
"scouters":	{"NNS"},
"scouting":	{"NN","VBG"},
"scoutmaster":	{"NN"},
"scouts":	{"VBZ","NNS"},
"scow":	{"NN"},
"scowl":	{"NN","VB","VBP"},
"scowled":	{"VBD","VBN"},
"scowling":	{"VBG"},
"scowls":	{"NNS","VBZ"},
"scpo":	{"NN"},
"scr":	{"NN"},
"scrabble":	{"VB","VBP","NN"},
"scrabbled":	{"VBD","VBN"},
"scrabbles":	{"VBZ"},
"scrabbling":	{"VBG"},
"scrabbly":	{"JJ"},
"scrag":	{"NN","VB","VBP"},
"scragged":	{"VBD","VBN"},
"scraggier":	{"JJR"},
"scraggiest":	{"JJS"},
"scragging":	{"VBG"},
"scragglier":	{"JJR"},
"scraggliest":	{"JJS"},
"scraggly":	{"JJ"},
"scraggy":	{"JJ"},
"scrags":	{"NNS","VBZ"},
"scram":	{"VB","VBP"},
"scramble":	{"VB","VBP","NN"},
"scrambled":	{"VBD","VBN"},
"scrambler":	{"NN"},
"scramblers":	{"NNS"},
"scrambles":	{"VBZ","NNS"},
"scrambling":	{"NN","VBG"},
"scrammed":	{"VBD","VBN"},
"scramming":	{"VBG"},
"scrams":	{"VBZ"},
"scranch":	{"VB","VBP"},
"scranton":	{"NN"},
"scrap":	{"NN","VB","VBP"},
"scrap-book":	{"NN"},
"scrap-books":	{"NNS"},
"scrap-heap":	{"NN"},
"scrap-yard":	{"NN"},
"scrapbook":	{"NN"},
"scrapbooks":	{"NNS"},
"scrape":	{"VB","VBP","NN"},
"scraped":	{"VBD","VBN"},
"scraper":	{"NN"},
"scrapers":	{"NNS"},
"scrapes":	{"VBZ","NNS"},
"scrapheap":	{"NN"},
"scrapie":	{"NN"},
"scraping":	{"NN","VBG"},
"scrapings":	{"NNS"},
"scrapped":	{"VBN","VBD"},
"scrapper":	{"NN"},
"scrappers":	{"NNS"},
"scrappily":	{"RB"},
"scrappiness":	{"NN"},
"scrapping":	{"NN","VBG"},
"scrapple":	{"NN"},
"scrappy":	{"JJ"},
"scraps":	{"NNS","VBZ"},
"scratch":	{"VB","VBP","NN","JJ"},
"scratched":	{"VBD","VBN"},
"scratcher":	{"NN"},
"scratches":	{"VBZ","NNS"},
"scratchier":	{"JJR"},
"scratchiest":	{"JJS"},
"scratchily":	{"RB"},
"scratchiness":	{"NN"},
"scratching":	{"VBG"},
"scratchpad":	{"NN"},
"scratchpads":	{"NNS"},
"scratchy":	{"JJ"},
"scrawl":	{"VB","VBP","NN"},
"scrawled":	{"VBD","VBN"},
"scrawler":	{"NN"},
"scrawling":	{"VBG"},
"scrawls":	{"VBZ","NNS"},
"scrawnier":	{"JJR"},
"scrawniest":	{"JJS"},
"scrawniness":	{"NN"},
"scrawny":	{"JJ"},
"screak":	{"VB","VBP","NN"},
"screakily":	{"RB"},
"screaky":	{"JJ"},
"scream":	{"VB","VBP","NN"},
"screamed":	{"VBD","VBN"},
"screamer":	{"NN"},
"screamers":	{"NNS"},
"screaming":	{"VBG","JJ"},
"screamingly":	{"RB"},
"screams":	{"VBZ","NNS"},
"scree":	{"NN"},
"screech":	{"VB","VBP","NN"},
"screech-owl":	{"NN"},
"screeched":	{"VBD","VBN"},
"screecher":	{"NN"},
"screeches":	{"VBZ","NNS"},
"screeching":	{"VBG"},
"screechy":	{"JJ"},
"screed":	{"NN"},
"screeds":	{"NNS"},
"screen":	{"NN","VB","VBP"},
"screened":	{"VBN","VBD"},
"screener":	{"NN"},
"screeners":	{"NNS"},
"screening":	{"NN","VBG"},
"screenings":	{"NNS"},
"screenland":	{"NN"},
"screenplay":	{"NN"},
"screenplays":	{"NNS"},
"screens":	{"NNS","VBZ"},
"screenwriter":	{"NN"},
"screenwriters":	{"NNS"},
"screes":	{"NNS"},
"screw":	{"NN","VB","VBP"},
"screw-top":	{"JJ"},
"screw-topped":	{"JJ"},
"screwball":	{"NN"},
"screwballer":	{"NN"},
"screwballs":	{"NNS"},
"screwbean":	{"NN"},
"screwdriver":	{"NN"},
"screwdrivers":	{"NNS"},
"screwed":	{"VBD","VBN","JJ"},
"screwed-up":	{"JJ"},
"screwier":	{"JJR"},
"screwiest":	{"JJS"},
"screwing":	{"VBG"},
"screws":	{"NNS","VBZ"},
"screwup":	{"NN"},
"screwy":	{"JJ"},
"scriabin":	{"NN"},
"scribble":	{"VB","VBP","NN"},
"scribbled":	{"VBN","VBD"},
"scribbler":	{"NN"},
"scribblers":	{"NNS"},
"scribbles":	{"VBZ","NNS"},
"scribbling":	{"VBG","NN"},
"scribbling-block":	{"NN"},
"scribblings":	{"NNS"},
"scribe":	{"NN","VB","VBP"},
"scribed":	{"VBD","VBN"},
"scriber":	{"NN"},
"scribes":	{"NNS","VBZ"},
"scribing":	{"VBG"},
"scried":	{"VBD","VBN"},
"scries":	{"VBZ"},
"scrim":	{"NN"},
"scrimmage":	{"NN","VB","VBP"},
"scrimmaged":	{"VBD","VBN"},
"scrimmages":	{"NNS","VBZ"},
"scrimmaging":	{"VBG"},
"scrimp":	{"VB","VBP"},
"scrimped":	{"VBD","VBN"},
"scrimping":	{"VBG"},
"scrimps":	{"VBZ"},
"scrimpy":	{"JJ"},
"scrimshank":	{"VB","VBP"},
"scrimshanker":	{"NN"},
"scrimshaw":	{"NN"},
"scrimy":	{"JJ"},
"scrip":	{"NN"},
"scripps":	{"NNS"},
"script":	{"NN","VB","VBP"},
"script-writer":	{"NN"},
"script-writers":	{"NNS"},
"scripted":	{"JJ","VBD","VBN"},
"scripting":	{"VBG"},
"scriptorium":	{"NN"},
"scripts":	{"NNS","VBZ"},
"scriptural":	{"JJ"},
"scripture":	{"NN"},
"scriptures":	{"NNS"},
"scriptwriter":	{"NN"},
"scriptwriters":	{"NNS"},
"scrivened":	{"JJ"},
"scrivener":	{"NN"},
"scrod":	{"NN"},
"scrofula":	{"NN"},
"scrofulous":	{"JJ"},
"scroll":	{"NN","VB","VBP"},
"scrolled":	{"VBD","VBN"},
"scrolling":	{"VBG"},
"scrolls":	{"NNS","VBZ"},
"scrooge":	{"NN"},
"scrooges":	{"NNS"},
"scrophularia":	{"NN"},
"scrophulariaceae":	{"NN"},
"scrophulariales":	{"NNS"},
"scrota":	{"NNS"},
"scrotal":	{"JJ"},
"scrotum":	{"NN"},
"scrotums":	{"NNS"},
"scrounge":	{"VB","VBP","NN"},
"scrounged":	{"VBD","VBN"},
"scrounger":	{"NN"},
"scroungers":	{"NNS"},
"scrounges":	{"VBZ"},
"scrounging":	{"VBG"},
"scrub":	{"NN","VB","VBP"},
"scrubbed":	{"VBD","VBN"},
"scrubber":	{"NN"},
"scrubbers":	{"NNS"},
"scrubbier":	{"JJR"},
"scrubbiest":	{"JJS"},
"scrubbiness":	{"NN"},
"scrubbing":	{"VBG"},
"scrubbird":	{"NN"},
"scrubby":	{"JJ"},
"scrubland":	{"NN"},
"scrublands":	{"NNS"},
"scrubs":	{"NNS","VBZ"},
"scruff":	{"NN"},
"scruffier":	{"JJR"},
"scruffiest":	{"JJS"},
"scruffily":	{"RB"},
"scruffiness":	{"NN"},
"scruffy":	{"JJ"},
"scrum":	{"NN","VB","VBP"},
"scrummage":	{"NN"},
"scrummages":	{"NNS"},
"scrummed":	{"VBD","VBN"},
"scrumming":	{"VBG"},
"scrumptious":	{"JJ"},
"scrumptiously":	{"RB"},
"scrumpy":	{"NN"},
"scrums":	{"NNS","VBZ"},
"scrunch":	{"VB","VBP","NN"},
"scrunched":	{"VBD","VBN"},
"scrunches":	{"VBZ"},
"scrunching":	{"VBG"},
"scruple":	{"NN","VB","VBP"},
"scrupled":	{"VBD","VBN"},
"scruples":	{"NNS","VBZ"},
"scrupling":	{"VBG"},
"scrupulosity":	{"NN"},
"scrupulous":	{"JJ"},
"scrupulously":	{"RB"},
"scrupulousness":	{"NN"},
"scrutin":	{"FW"},
"scrutineer":	{"NN"},
"scrutineers":	{"NNS"},
"scrutinise":	{"VB","VBP"},
"scrutinised":	{"VBD","VBN"},
"scrutiniser":	{"NN"},
"scrutinises":	{"VBZ"},
"scrutinising":	{"VBG"},
"scrutinize":	{"VB","VBP"},
"scrutinized":	{"VBD","VBN"},
"scrutinizer":	{"NN"},
"scrutinizes":	{"VBZ"},
"scrutinizing":	{"VBG"},
"scrutiny":	{"NN"},
"scry":	{"VB","VBP"},
"scrying":	{"VBG"},
"scsi":	{"NN"},
"scuba":	{"NN"},
"scud":	{"VB","VBP","NN"},
"scudded":	{"VBD","VBN"},
"scudding":	{"VBG"},
"scuds":	{"VBZ"},
"scuff":	{"VB","VBP","NN"},
"scuffed":	{"VBD","VBN","JJ"},
"scuffer":	{"NN"},
"scuffing":	{"VBG"},
"scuffle":	{"NN","VB","VBP"},
"scuffled":	{"VBD","VBN"},
"scuffles":	{"NNS","VBZ"},
"scuffling":	{"VBG","JJ"},
"scuffs":	{"VBZ"},
"scull":	{"NN","VB","VBP"},
"sculled":	{"VBD","VBN"},
"sculler":	{"NN"},
"sculleries":	{"NNS"},
"scullers":	{"NNS"},
"scullery":	{"NN"},
"sculling":	{"VBG"},
"scullion":	{"NN"},
"sculls":	{"NNS","VBZ"},
"sculpin":	{"NN"},
"sculpt":	{"VB","VBP"},
"sculpted":	{"VBD","VBN","JJ"},
"sculpting":	{"VBG"},
"sculptor":	{"NN"},
"sculptors":	{"NNS"},
"sculptress":	{"NN"},
"sculptresses":	{"NNS"},
"sculpts":	{"VBZ"},
"sculptural":	{"JJ"},
"sculpture":	{"NN","VB","VBP"},
"sculptured":	{"JJ","VBD","VBN"},
"sculpturer":	{"NN"},
"sculptures":	{"NNS","VBZ"},
"sculpturesque":	{"JJ"},
"sculpturing":	{"VBG"},
"scum":	{"NN","VB","VBP"},
"scumble":	{"VB","VBP"},
"scummed":	{"VBD","VBN"},
"scummier":	{"JJR"},
"scummiest":	{"JJS"},
"scumming":	{"VBG"},
"scummy":	{"JJ"},
"scums":	{"VBZ"},
"scunner":	{"NN"},
"scup":	{"NN"},
"scupper":	{"NN","VB","VBP"},
"scuppered":	{"VBD","VBN"},
"scuppering":	{"VBG"},
"scuppernong":	{"NN"},
"scuppers":	{"NNS","VBZ"},
"scurf":	{"NN"},
"scurfy":	{"JJ"},
"scurried":	{"VBD","VBN"},
"scurries":	{"VBZ","NNS"},
"scurrility":	{"NN"},
"scurrilous":	{"JJ"},
"scurrilously":	{"RB"},
"scurry":	{"VB","VBP","NN"},
"scurrying":	{"VBG"},
"scurvily":	{"RB"},
"scurvy":	{"NN","JJ"},
"scut":	{"NN"},
"scutcheon":	{"NN"},
"scute":	{"NN"},
"scutellaria":	{"NN"},
"scutigera":	{"NN"},
"scutigerella":	{"NN"},
"scutigeridae":	{"NN"},
"scuttle":	{"VB","VBP","NN"},
"scuttlebutt":	{"NN"},
"scuttled":	{"VBD","VBN"},
"scuttles":	{"NNS","VBZ"},
"scuttling":	{"VBG"},
"scyliorhinidae":	{"NN"},
"scyphozoa":	{"NN"},
"scyphozoan":	{"NN"},
"scyphus":	{"NN"},
"scythe":	{"NN","VB","VBP"},
"scythed":	{"VBD","VBN"},
"scythes":	{"NNS","VBZ"},
"scythia":	{"NN"},
"scythian":	{"JJ","NN"},
"scything":	{"VBG"},
"sd":	{"NN"},
"se":	{"RB","FW"},
"sea":	{"NN"},
"sea-borne":	{"JJ"},
"sea-bream":	{"NN"},
"sea-breeze":	{"NN"},
"sea-breezes":	{"NNS"},
"sea-coast":	{"NN"},
"sea-cow":	{"NN"},
"sea-damp":	{"JJ"},
"sea-dog":	{"NN"},
"sea-dogs":	{"NNS"},
"sea-duty":	{"NN"},
"sea-ear":	{"NN"},
"sea-food":	{"NN"},
"sea-green":	{"JJ","NN"},
"sea-horse":	{"NN"},
"sea-horses":	{"NNS"},
"sea-kale":	{"NN"},
"sea-legs":	{"NNS"},
"sea-level":	{"NN"},
"sea-lion":	{"NN"},
"sea-lions":	{"NNS"},
"sea-pink":	{"NN"},
"sea-poose":	{"NN"},
"sea-shore":	{"NN"},
"sea-urchin":	{"NN"},
"sea-urchins":	{"NNS"},
"sea-wall":	{"NN"},
"sea-walls":	{"NNS"},
"sea-way":	{"NN"},
"sea-ways":	{"NNS"},
"seabag":	{"NN"},
"seabed":	{"NN"},
"seabird":	{"NN"},
"seabirds":	{"NNS"},
"seaboard":	{"NN"},
"seaboards":	{"NNS"},
"seaborg":	{"NN"},
"seaborgium":	{"NN"},
"seaborne":	{"JJ"},
"seacoast":	{"NN"},
"seadog":	{"NN"},
"seadogs":	{"NNS"},
"seafarer":	{"NN"},
"seafarers":	{"NNS"},
"seafaring":	{"JJ","NN"},
"seafoam":	{"NN"},
"seafood":	{"NN"},
"seafowl":	{"NN"},
"seafront":	{"NN"},
"seafronts":	{"NNS"},
"seagirt":	{"JJ"},
"seagoing":	{"JJ"},
"seagrass":	{"NN"},
"seagull":	{"NN"},
"seagulls":	{"NNS"},
"seahorse":	{"NN"},
"seahorses":	{"NNS"},
"seal":	{"NN","VB","VBP"},
"sealant":	{"NN"},
"sealants":	{"NNS"},
"sealed":	{"JJ","VBN","VBD"},
"sealer":	{"NN"},
"sealift":	{"NN"},
"sealing":	{"NN","VBG"},
"seals":	{"VBZ","NNS"},
"sealskin":	{"NN"},
"sealyham":	{"NN"},
"seam":	{"NN","VB","VBP"},
"seaman":	{"NN"},
"seamanlike":	{"JJ"},
"seamanly":	{"JJ"},
"seamanship":	{"NN"},
"seamed":	{"VBD","VBN","JJ"},
"seamen":	{"NNS"},
"seamier":	{"JJR"},
"seamiest":	{"JJS"},
"seaming":	{"VBG"},
"seamless":	{"JJ"},
"seamlessly":	{"RB"},
"seamount":	{"NN"},
"seams":	{"VBZ","NNS"},
"seamster":	{"NN"},
"seamstress":	{"NN"},
"seamstresses":	{"NNS"},
"seamy":	{"JJ"},
"seanad":	{"NN"},
"seance":	{"NN"},
"seances":	{"NNS"},
"seaplane":	{"NN"},
"seaplanes":	{"NNS"},
"seaport":	{"NN"},
"seaports":	{"NNS"},
"sear":	{"VB","VBP","NN","JJ"},
"search":	{"NN","VB","VBP"},
"search-parties":	{"NNS"},
"search-party":	{"NN"},
"search-warrant":	{"NN"},
"search-warrants":	{"NNS"},
"searched":	{"VBD","VBN"},
"searcher":	{"NN"},
"searchers":	{"NNS"},
"searches":	{"NNS","VBZ"},
"searching":	{"VBG","NN","JJ"},
"searchingly":	{"RB"},
"searchings":	{"NNS"},
"searchlight":	{"NN"},
"searchlights":	{"NNS"},
"seared":	{"VBD","VBN"},
"searing":	{"JJ","VBG"},
"searobin":	{"NN"},
"sears":	{"VBZ"},
"seas":	{"NNS"},
"seascape":	{"NN"},
"seascapes":	{"NNS"},
"seashell":	{"NN"},
"seashells":	{"NNS"},
"seashore":	{"NN"},
"seashores":	{"NNS"},
"seasick":	{"JJ"},
"seasickness":	{"NN"},
"seaside":	{"NN","JJ"},
"seasnail":	{"NN"},
"season":	{"NN","VBP","VB"},
"season-ticket":	{"NN"},
"season-tickets":	{"NNS"},
"seasonable":	{"JJ"},
"seasonableness":	{"NN"},
"seasonably":	{"RB"},
"seasonal":	{"JJ"},
"seasonality":	{"NN"},
"seasonally":	{"RB"},
"seasoned":	{"JJ","VBD","VBN"},
"seasoner":	{"NN"},
"seasoning":	{"NN","VBG"},
"seasonings":	{"NNS"},
"seasons":	{"NNS","VBZ"},
"seat":	{"NN","VB","VBP"},
"seat-back":	{"JJ"},
"seat-belt":	{"NN"},
"seated":	{"VBN","VBD","JJ"},
"seating":	{"NN","VBG"},
"seatrout":	{"NN"},
"seats":	{"NNS","VBZ"},
"seattle":	{"NN"},
"seattlites":	{"NNS"},
"seawall":	{"NN"},
"seawalls":	{"NNS"},
"seaward":	{"JJ","RB"},
"seawards":	{"RB"},
"seawater":	{"NN"},
"seaway":	{"NN"},
"seaways":	{"NNS"},
"seaweed":	{"NN"},
"seaweeds":	{"NNS"},
"seaworthiness":	{"NN"},
"seaworthy":	{"JJ"},
"sebaceous":	{"JJ"},
"sebastian":	{"NN"},
"sebastiana":	{"NN"},
"sebastodes":	{"NNS"},
"sebastopol":	{"NN"},
"sebe":	{"NN"},
"seborrhea":	{"NN"},
"sebs":	{"NNS"},
"sebum":	{"NN"},
"sec":	{"NN"},
"sec.":	{"NN","NNS"},
"secale":	{"NN"},
"secant":	{"NN"},
"secants":	{"NNS"},
"secateurs":	{"NNS"},
"secco":	{"NN","FW"},
"secede":	{"VB","VBP"},
"seceded":	{"VBD","VBN"},
"secedes":	{"VBZ"},
"seceding":	{"VBG"},
"secern":	{"VB","VBP"},
"secernment":	{"NN"},
"secession":	{"NN"},
"secessionism":	{"NN"},
"secessionist":	{"NN"},
"secessionists":	{"NNS"},
"sechuana":	{"NN"},
"seckel":	{"NN"},
"seclude":	{"VB","VBP"},
"secluded":	{"VBD","VBN","JJ"},
"secludes":	{"VBZ"},
"secluding":	{"VBG"},
"seclusion":	{"NN"},
"secobarbital":	{"NN"},
"seconal":	{"NN"},
"second":	{"JJ","RB","NN","VBP","VB"},
"second-best":	{"JJ","NN"},
"second-class":	{"JJ","RB","NN"},
"second-degree":	{"JJ"},
"second-floor":	{"JJ","NN"},
"second-guess":	{"VB","VBP"},
"second-guessed":	{"VBD","VBN"},
"second-guesses":	{"VBZ"},
"second-guessing":	{"VBG"},
"second-hand":	{"JJ","RB"},
"second-in-command":	{"NN"},
"second-rate":	{"JJ"},
"second-string":	{"JJ"},
"secondarily":	{"RB"},
"secondary":	{"JJ"},
"seconded":	{"VBD","VBN"},
"seconder":	{"NN"},
"seconders":	{"NNS"},
"secondhand":	{"JJ"},
"seconding":	{"VBG"},
"secondly":	{"RB"},
"secondment":	{"NN"},
"secondments":	{"NNS"},
"secondo":	{"NN"},
"seconds":	{"NNS","VBZ"},
"secotiaceae":	{"NN"},
"secotiales":	{"NNS"},
"secpar":	{"NN"},
"secrecy":	{"NN"},
"secret":	{"JJ","NN"},
"secretaire":	{"NN"},
"secretarial":	{"JJ"},
"secretariat":	{"NN"},
"secretariate":	{"NN"},
"secretariats":	{"NNS"},
"secretaries":	{"NNS"},
"secretaries-general":	{"NNS"},
"secretary":	{"NN"},
"secretary-general":	{"NN"},
"secretaryship":	{"NN"},
"secretase":	{"NN"},
"secrete":	{"VB","VBP"},
"secreted":	{"VBD","VBN"},
"secreter":	{"NN"},
"secretes":	{"VBZ"},
"secretin":	{"NN"},
"secreting":	{"VBG"},
"secretion":	{"NN"},
"secretions":	{"NNS"},
"secretive":	{"JJ"},
"secretively":	{"RB"},
"secretiveness":	{"NN"},
"secretly":	{"RB"},
"secretor":	{"NN"},
"secretory":	{"JJ"},
"secrets":	{"NNS"},
"sect":	{"NN"},
"sectarian":	{"JJ","NN"},
"sectarianism":	{"NN"},
"sectaries":	{"NNS"},
"sectarist":	{"NN"},
"sectary":	{"NN"},
"section":	{"NN","VB","VBP"},
"sectional":	{"JJ"},
"sectionalisation":	{"NN"},
"sectionalise":	{"VB","VBP"},
"sectionalised":	{"JJ","VBD","VBN"},
"sectionalises":	{"VBZ"},
"sectionalising":	{"VBG"},
"sectionalism":	{"NN"},
"sectionalization":	{"NN"},
"sectionalize":	{"VB","VBP"},
"sectionalized":	{"JJ","VBD","VBN"},
"sectionalizes":	{"VBZ"},
"sectionalizing":	{"VBG"},
"sectioned":	{"VBD","VBN"},
"sectioning":	{"VBG"},
"sections":	{"NNS","VBZ"},
"sector":	{"NN"},
"sectorial":	{"JJ"},
"sectors":	{"NNS"},
"sects":	{"NNS"},
"secular":	{"JJ"},
"secularisation":	{"NN"},
"secularise":	{"VB","VBP"},
"secularised":	{"VBD","VBN"},
"secularises":	{"VBZ"},
"secularising":	{"VBG"},
"secularism":	{"NN"},
"secularist":	{"NN"},
"secularists":	{"NNS"},
"secularization":	{"NN"},
"secularize":	{"VB","VBP"},
"secularized":	{"VBD","VBN"},
"secularizes":	{"VBZ"},
"secularizing":	{"VBG"},
"secundigravida":	{"NN"},
"secure":	{"JJ","VB","VBP"},
"secured":	{"VBN","VBD","JJ"},
"securely":	{"RB"},
"secureness":	{"NN"},
"securer":	{"NN"},
"secures":	{"VBZ"},
"securing":	{"VBG"},
"securities":	{"NNS"},
"securitization":	{"NN"},
"security":	{"NN"},
"sed":	{"NN"},
"sedalia":	{"NN"},
"sedan":	{"NN"},
"sedan-chair":	{"NN"},
"sedan-chairs":	{"NNS"},
"sedans":	{"NNS"},
"sedate":	{"JJ","VB","VBP"},
"sedated":	{"VBD","VBN"},
"sedately":	{"RB"},
"sedateness":	{"NN"},
"sedates":	{"VBZ"},
"sedating":	{"VBG"},
"sedation":	{"NN"},
"sedative":	{"NN","JJ"},
"sedatives":	{"NNS"},
"sedentary":	{"JJ"},
"sedge":	{"NN"},
"sedges":	{"NNS"},
"sedgy":	{"JJ"},
"sediment":	{"NN"},
"sedimentary":	{"JJ"},
"sedimentation":	{"NN"},
"sediments":	{"NNS"},
"sedition":	{"NN"},
"seditious":	{"JJ"},
"seditiously":	{"RB"},
"sedna":	{"NN"},
"sedona":	{"NN"},
"seduce":	{"VB","VBP"},
"seduced":	{"VBD","VBN"},
"seducer":	{"NN"},
"seducers":	{"NNS"},
"seduces":	{"VBZ"},
"seducing":	{"VBG"},
"seduction":	{"NN"},
"seductions":	{"NNS"},
"seductive":	{"JJ"},
"seductively":	{"RB"},
"seductiveness":	{"NN"},
"seductress":	{"NN"},
"seductresses":	{"NNS"},
"sedulity":	{"NN"},
"sedulous":	{"JJ"},
"sedulously":	{"RB"},
"sedulousness":	{"NN"},
"sedum":	{"NN"},
"seduzione":	{"FW"},
"see":	{"VB","VBP","NN"},
"see-saw":	{"NN","VB","VBP","JJ"},
"see-sawed":	{"VBD","VBN"},
"see-sawing":	{"VBG"},
"see-saws":	{"NNS","VBZ"},
"see-through":	{"JJ"},
"seeable":	{"JJ"},
"seed":	{"NN","VBP","VB"},
"seed-bed":	{"NN"},
"seed-beds":	{"NNS"},
"seed-cake":	{"NN"},
"seed-cakes":	{"NNS"},
"seed-capital":	{"JJ"},
"seed-pearl":	{"NN"},
"seed-pearls":	{"NNS"},
"seedbed":	{"NN"},
"seedbeds":	{"NNS"},
"seedcake":	{"NN"},
"seedcakes":	{"NNS"},
"seedcase":	{"NN"},
"seedcoat":	{"NN"},
"seedcoats":	{"NNS"},
"seeded":	{"VBD","VBN"},
"seeder":	{"NN"},
"seeders":	{"NNS"},
"seedier":	{"JJR"},
"seediest":	{"JJS"},
"seediness":	{"NN"},
"seeding":	{"VBG","NN"},
"seedless":	{"JJ"},
"seedling":	{"NN"},
"seedlings":	{"NNS"},
"seedman":	{"NN"},
"seedpod":	{"NN"},
"seedpods":	{"NNS"},
"seeds":	{"NNS","VBZ"},
"seedsman":	{"NN"},
"seedsmen":	{"NNS"},
"seedtime":	{"NN"},
"seedy":	{"JJ"},
"seeing":	{"VBG","IN","NN"},
"seek":	{"VB","VBP"},
"seeker":	{"NN"},
"seekers":	{"NNS"},
"seeking":	{"VBG"},
"seekingly":	{"RB"},
"seeks":	{"VBZ"},
"seel":	{"VB","VBP"},
"seeled":	{"VBD","VBN"},
"seeling":	{"VBG"},
"seels":	{"VBZ"},
"seem":	{"VB","VBP"},
"seemed":	{"VBD","VBN"},
"seeming":	{"JJ","VBG"},
"seemingly":	{"RB"},
"seemlier":	{"JJR"},
"seemliest":	{"JJS"},
"seemliness":	{"NN"},
"seemly":	{"JJ"},
"seems":	{"VBZ"},
"seen":	{"VBN"},
"seep":	{"VB","VBP","NN"},
"seepage":	{"NN"},
"seepages":	{"NNS"},
"seeped":	{"VBD","VBN"},
"seeping":	{"VBG"},
"seeps":	{"VBZ","NNS"},
"seer":	{"NN"},
"seers":	{"NNS"},
"seersucker":	{"NN"},
"sees":	{"VBZ"},
"seesaw":	{"NN","VB","VBP","JJ"},
"seesawed":	{"VBD","VBN"},
"seesawing":	{"VBG"},
"seesaws":	{"NNS","VBZ"},
"seethe":	{"VB","VBP"},
"seethed":	{"VBD","VBN"},
"seethes":	{"VBZ"},
"seething":	{"JJ","VBG"},
"segal":	{"NN"},
"segment":	{"NN","VBP","VB"},
"segmental":	{"JJ"},
"segmentally":	{"RB"},
"segmentation":	{"NN"},
"segmented":	{"JJ","VBD","VBN"},
"segmenting":	{"VBG"},
"segments":	{"NNS","VBZ"},
"segno":	{"NN"},
"segovia":	{"NN"},
"segregate":	{"VB","VBP"},
"segregated":	{"VBD","VBN","JJ"},
"segregates":	{"VBZ"},
"segregating":	{"VBG"},
"segregation":	{"NN"},
"segregationism":	{"NN"},
"segregationist":	{"NN","JJ"},
"segregationists":	{"NNS"},
"segregator":	{"NN"},
"segue":	{"VB","VBP","NN"},
"segued":	{"VBD","VBN"},
"segueing":	{"VBG"},
"segues":	{"VBZ","NNS"},
"segway":	{"NN"},
"sei":	{"NN"},
"seiche":	{"NN"},
"seidel":	{"NN"},
"seige":	{"NN"},
"seigneur":	{"NN"},
"seigneury":	{"NN"},
"seignior":	{"NN"},
"seigniorage":	{"NN"},
"seigniory":	{"NN"},
"seine":	{"NN","VB","VBP"},
"seined":	{"VBD","VBN"},
"seines":	{"NNS","VBZ"},
"seining":	{"VBG"},
"seisho":	{"FW"},
"seism":	{"NN"},
"seismal":	{"JJ"},
"seismic":	{"JJ"},
"seismogram":	{"NN"},
"seismograph":	{"NN"},
"seismographic":	{"JJ"},
"seismographies":	{"NNS"},
"seismographs":	{"NNS"},
"seismography":	{"NN"},
"seismologic":	{"JJ"},
"seismological":	{"JJ"},
"seismologist":	{"NN"},
"seismologists":	{"NNS"},
"seismology":	{"NN"},
"seismosaur":	{"NN"},
"seismosaurus":	{"NN"},
"seiurus":	{"NN"},
"seize":	{"VB","VBP"},
"seized":	{"VBD","VBN"},
"seizer":	{"NN"},
"seizers":	{"NNS"},
"seizes":	{"VBZ","NNS"},
"seizing":	{"NN","VBG"},
"seizure":	{"NN"},
"seizures":	{"NNS"},
"sekhet":	{"NN"},
"selachian":	{"NN"},
"selachii":	{"NN"},
"selaginella":	{"NN"},
"selaginellaceae":	{"NN"},
"selaginellales":	{"NNS"},
"selar":	{"NN"},
"selcraig":	{"NN"},
"seldom":	{"RB"},
"select":	{"VB","JJ","VBP"},
"selected":	{"VBN","VBD","JJ"},
"selecting":	{"VBG"},
"selection":	{"NN"},
"selections":	{"NNS"},
"selective":	{"JJ"},
"selectively":	{"RB"},
"selectiveness":	{"NN"},
"selectivity":	{"NN"},
"selectman":	{"NN"},
"selectmen":	{"NNS"},
"selector":	{"NN"},
"selectors":	{"NNS"},
"selects":	{"VBZ"},
"selectwoman":	{"NN"},
"selenarctos":	{"NNS"},
"selene":	{"NN"},
"selenicereus":	{"NNS"},
"selenipedium":	{"NN"},
"selenium":	{"NN"},
"selenolatry":	{"NN"},
"selenology":	{"NN"},
"seles":	{"NNS"},
"seleucus":	{"NN"},
"self":	{"NN"},
"self-abnegation":	{"NN"},
"self-absorbed":	{"JJ"},
"self-absorption":	{"NN"},
"self-abuse":	{"NN"},
"self-accusation":	{"NN"},
"self-acting":	{"JJ"},
"self-activating":	{"JJ"},
"self-addressed":	{"JJ"},
"self-adhesive":	{"JJ"},
"self-administered":	{"JJ"},
"self-administration":	{"NN"},
"self-aggrandisement":	{"NN"},
"self-aggrandising":	{"JJ"},
"self-aggrandizement":	{"NN"},
"self-aggrandizing":	{"JJ"},
"self-analysis":	{"NN"},
"self-annihilation":	{"NN"},
"self-appointed":	{"JJ"},
"self-asserting":	{"JJ"},
"self-assertion":	{"NN"},
"self-assertive":	{"JJ"},
"self-assertiveness":	{"NN"},
"self-assurance":	{"NN"},
"self-assured":	{"JJ"},
"self-aware":	{"JJ"},
"self-awareness":	{"NN"},
"self-balancing":	{"JJ"},
"self-betrayal":	{"NN"},
"self-censorship":	{"NN"},
"self-centered":	{"JJ"},
"self-centeredness":	{"NN"},
"self-centred":	{"JJ"},
"self-certainty":	{"NN"},
"self-chosen":	{"JJ"},
"self-collected":	{"JJ"},
"self-colored":	{"JJ"},
"self-coloured":	{"JJ"},
"self-command":	{"NN"},
"self-complacency":	{"NN"},
"self-complacent":	{"JJ"},
"self-completion":	{"NN"},
"self-conceited":	{"JJ"},
"self-conceitedly":	{"RB"},
"self-concern":	{"NN"},
"self-condemnation":	{"NN"},
"self-confessed":	{"JJ"},
"self-confidence":	{"NN"},
"self-confident":	{"JJ"},
"self-congratulation":	{"NN"},
"self-congratulatory":	{"JJ"},
"self-conscious":	{"JJ"},
"self-consciously":	{"RB"},
"self-consciousness":	{"NN"},
"self-consistent":	{"JJ"},
"self-constituted":	{"JJ"},
"self-consuming":	{"JJ"},
"self-contained":	{"JJ"},
"self-contemplation":	{"NN"},
"self-content":	{"JJ"},
"self-contradiction":	{"NN"},
"self-contradictory":	{"JJ"},
"self-control":	{"NN"},
"self-correcting":	{"JJ"},
"self-crimination":	{"NN"},
"self-critical":	{"JJ"},
"self-criticism":	{"NN"},
"self-cultivation":	{"NN"},
"self-damaging":	{"JJ"},
"self-deal":	{"VB","VBP"},
"self-dealed":	{"VBD","VBN"},
"self-dealing":	{"NN","VBG"},
"self-deals":	{"VBZ"},
"self-deceit":	{"NN"},
"self-deceived":	{"JJ"},
"self-deceiving":	{"JJ"},
"self-deception":	{"NN"},
"self-declared":	{"JJ"},
"self-defeat":	{"NN"},
"self-defeating":	{"JJ"},
"self-defence":	{"NN"},
"self-defense":	{"NN"},
"self-definition":	{"NN"},
"self-deluded":	{"JJ"},
"self-delusion":	{"NN"},
"self-denial":	{"NN"},
"self-denying":	{"JJ"},
"self-deprecating":	{"JJ"},
"self-deprecation":	{"NN"},
"self-depreciation":	{"NN"},
"self-described":	{"JJ"},
"self-designated":	{"JJ"},
"self-destruct":	{"VB","VBP","JJ"},
"self-destructed":	{"VBD","VBN"},
"self-destructing":	{"VBG"},
"self-destruction":	{"NN"},
"self-destructive":	{"JJ"},
"self-destructs":	{"VBZ"},
"self-determination":	{"NN"},
"self-diagnostic":	{"JJ"},
"self-dictate":	{"NN"},
"self-digestion":	{"NN"},
"self-directed":	{"JJ"},
"self-direction":	{"NN"},
"self-discipline":	{"NN"},
"self-disciplined":	{"JJ"},
"self-discovery":	{"NN"},
"self-disgust":	{"NN"},
"self-distrust":	{"NN"},
"self-doubt":	{"NN"},
"self-dramatization":	{"NN"},
"self-drive":	{"JJ"},
"self-educated":	{"JJ"},
"self-education":	{"NN"},
"self-effacement":	{"NN"},
"self-effacing":	{"JJ"},
"self-employed":	{"JJ","NNS"},
"self-employment":	{"NN"},
"self-enclosed":	{"JJ"},
"self-energizing":	{"JJ"},
"self-enforced":	{"JJ"},
"self-established":	{"JJ"},
"self-esteem":	{"NN"},
"self-evident":	{"JJ"},
"self-evidently":	{"RB"},
"self-examination":	{"NN"},
"self-examining":	{"JJ"},
"self-exile":	{"NN"},
"self-experimentation":	{"NN"},
"self-explanatory":	{"JJ"},
"self-expression":	{"NN"},
"self-extinguishing":	{"JJ"},
"self-feeder":	{"NN"},
"self-fertilisation":	{"NN"},
"self-fertilised":	{"JJ"},
"self-fertilization":	{"NN"},
"self-fertilized":	{"JJ"},
"self-financed":	{"JJ"},
"self-flagellation":	{"NN"},
"self-forgetful":	{"JJ"},
"self-fulfilling":	{"JJ"},
"self-fulfillment":	{"NN"},
"self-funding":	{"NN"},
"self-generated":	{"JJ"},
"self-giving":	{"JJ"},
"self-governing":	{"JJ"},
"self-government":	{"NN"},
"self-gratification":	{"NN"},
"self-hatred":	{"NN"},
"self-heal":	{"NN"},
"self-help":	{"NN"},
"self-hypnosis":	{"NN"},
"self-identification":	{"NN"},
"self-identified":	{"VBD","VBN"},
"self-identifies":	{"VBZ"},
"self-identify":	{"VB","VBP"},
"self-identifying":	{"VBG"},
"self-identity":	{"NN"},
"self-image":	{"NN"},
"self-images":	{"NNS"},
"self-importance":	{"NN"},
"self-important":	{"JJ"},
"self-imposed":	{"JJ"},
"self-improvement":	{"NN"},
"self-incrimination":	{"NN"},
"self-induced":	{"JJ"},
"self-inductance":	{"NN"},
"self-induction":	{"NN"},
"self-indulgence":	{"NN"},
"self-indulgent":	{"JJ"},
"self-indulgently":	{"RB"},
"self-inflicted":	{"JJ"},
"self-insurance":	{"NN"},
"self-interest":	{"NN"},
"self-interested":	{"JJ"},
"self-involved":	{"JJ"},
"self-judging":	{"JJ"},
"self-justification":	{"NN"},
"self-knowledge":	{"NN"},
"self-limited":	{"JJ"},
"self-loader":	{"NN"},
"self-loading":	{"JJ"},
"self-locking":	{"JJ"},
"self-love":	{"NN"},
"self-loving":	{"JJ"},
"self-luminous":	{"JJ"},
"self-made":	{"JJ"},
"self-managing":	{"JJ"},
"self-mastery":	{"NN"},
"self-mortification":	{"NN"},
"self-moving":	{"JJ"},
"self-multilation":	{"NN"},
"self-observation":	{"NN"},
"self-opinionated":	{"JJ"},
"self-ordained":	{"JJ"},
"self-organisation":	{"NN"},
"self-organization":	{"NN"},
"self-pacification":	{"NN"},
"self-perceived":	{"JJ"},
"self-perpetuating":	{"JJ"},
"self-pity":	{"JJ"},
"self-pitying":	{"JJ"},
"self-policing":	{"JJ"},
"self-pollinated":	{"JJ"},
"self-pollinating":	{"JJ"},
"self-pollination":	{"NN"},
"self-portrait":	{"NN"},
"self-portraits":	{"NNS"},
"self-possessed":	{"JJ"},
"self-possession":	{"NN"},
"self-praise":	{"NN"},
"self-prescribed":	{"JJ"},
"self-preservation":	{"NN"},
"self-pride":	{"NN"},
"self-proclaimed":	{"JJ"},
"self-produced":	{"JJ"},
"self-professed":	{"JJ"},
"self-promotion":	{"NN"},
"self-propelled":	{"JJ"},
"self-propelling":	{"JJ"},
"self-protection":	{"NN"},
"self-published":	{"JJ"},
"self-punishment":	{"NN"},
"self-realisation":	{"NN"},
"self-realization":	{"NN"},
"self-realized":	{"JJ"},
"self-redefinition":	{"NN"},
"self-referent":	{"JJ"},
"self-referential":	{"JJ"},
"self-reform":	{"NN"},
"self-reformation":	{"NN"},
"self-regard":	{"NN"},
"self-regulating":	{"JJ"},
"self-regulation":	{"NN"},
"self-regulator":	{"NN"},
"self-regulatory":	{"JJ"},
"self-reliance":	{"NN"},
"self-reliant":	{"JJ"},
"self-renewal":	{"NN"},
"self-renewing":	{"JJ"},
"self-renunciation":	{"NN"},
"self-reproach":	{"NN"},
"self-reproof":	{"NN"},
"self-respect":	{"NN"},
"self-respectful":	{"JJ"},
"self-respecting":	{"JJ"},
"self-restraining":	{"JJ"},
"self-restraint":	{"NN"},
"self-righteous":	{"JJ"},
"self-righteously":	{"RB"},
"self-righteousness":	{"NN"},
"self-rule":	{"NN"},
"self-sacrifice":	{"NN"},
"self-sacrificing":	{"JJ"},
"self-satisfaction":	{"NN"},
"self-satisfied":	{"JJ"},
"self-screening":	{"JJ"},
"self-scrutiny":	{"NN"},
"self-sealing":	{"JJ"},
"self-seeded":	{"JJ"},
"self-seeker":	{"NN"},
"self-seeking":	{"JJ","NN"},
"self-serve":	{"NN"},
"self-service":	{"JJ","NN"},
"self-serving":	{"JJ"},
"self-sowed":	{"JJ"},
"self-sown":	{"JJ"},
"self-splicing":	{"JJ"},
"self-starter":	{"NN"},
"self-starters":	{"NNS"},
"self-starting":	{"JJ"},
"self-stimulation":	{"NN"},
"self-study":	{"NN"},
"self-styled":	{"JJ"},
"self-sufficiency":	{"NN"},
"self-sufficient":	{"JJ"},
"self-sufficing":	{"JJ"},
"self-suggestion":	{"NN"},
"self-supporting":	{"JJ"},
"self-sustained":	{"JJ"},
"self-sustaining":	{"JJ"},
"self-taught":	{"JJ"},
"self-tender":	{"NN"},
"self-tilth":	{"NN"},
"self-torment":	{"NN"},
"self-torture":	{"NN"},
"self-unloading":	{"JJ"},
"self-victimized":	{"JJ"},
"self-whispered":	{"JJ"},
"self-will":	{"NN"},
"self-willed":	{"JJ"},
"self-winding":	{"JJ"},
"self-worship":	{"NN"},
"self-worth":	{"NN"},
"selfies":	{"NNS"},
"selfish":	{"JJ"},
"selfishly":	{"RB"},
"selfishness":	{"NN"},
"selfless":	{"JJ"},
"selflessly":	{"RB"},
"selflessness":	{"NN"},
"selfsame":	{"JJ"},
"selfsameness":	{"NN"},
"seljuk":	{"JJ","NN"},
"selkirk":	{"NN"},
"selkup":	{"NN"},
"sell":	{"VB","VBP","NN"},
"sell-off":	{"NN"},
"sell-offs":	{"NNS"},
"sell-order":	{"JJ"},
"sell-through":	{"JJ","NN"},
"sellable":	{"JJ"},
"selle":	{"NN"},
"seller":	{"NN"},
"sellers":	{"NNS"},
"sellin":	{"NN"},
"selling":	{"VBG","NN"},
"selling-point":	{"NN"},
"selling-points":	{"NNS"},
"selloff":	{"NN"},
"selloffs":	{"NNS"},
"sellotape":	{"VB","VBP"},
"sellotaped":	{"VBD","VBN"},
"sellotapes":	{"VBZ"},
"sellotaping":	{"VBG"},
"sellout":	{"NN"},
"sells":	{"VBZ"},
"selma":	{"NN"},
"selsyn":	{"NN"},
"seltzer":	{"NN"},
"selva":	{"NN"},
"selvage":	{"NN"},
"selvedge":	{"NN"},
"selves":	{"NNS"},
"semantic":	{"JJ"},
"semantically":	{"RB"},
"semanticist":	{"NN"},
"semantics":	{"NN"},
"semaphore":	{"NN","VB","VBP"},
"semaphored":	{"VBD","VBN"},
"semaphores":	{"NNS","VBZ"},
"semaphoring":	{"VBG"},
"semarang":	{"NN"},
"semasiology":	{"NN"},
"semblance":	{"NN"},
"semen":	{"NN"},
"semester":	{"NN"},
"semesters":	{"NNS"},
"semestral":	{"JJ"},
"semestrial":	{"JJ"},
"semi":	{"NN"},
"semi-abstraction":	{"NN"},
"semi-abstractions":	{"NNS"},
"semi-ambiguous":	{"JJ"},
"semi-annual":	{"JJ"},
"semi-annually":	{"RB"},
"semi-arid":	{"JJ"},
"semi-automatic":	{"JJ","NN"},
"semi-automatise":	{"VB","VBP"},
"semi-automatize":	{"VB","VBP"},
"semi-autonomous":	{"JJ"},
"semi-catatonic":	{"JJ"},
"semi-celebrities":	{"NNS"},
"semi-circle":	{"NN"},
"semi-city":	{"JJ"},
"semi-climber":	{"NN"},
"semi-climbing":	{"JJ"},
"semi-conductor":	{"NN"},
"semi-conductors":	{"NNS"},
"semi-conscious":	{"JJ"},
"semi-controlled":	{"JJ"},
"semi-dry":	{"JJ"},
"semi-erect":	{"JJ"},
"semi-evergreen":	{"JJ"},
"semi-finalist":	{"NN"},
"semi-finalists":	{"NNS"},
"semi-finished":	{"JJ"},
"semi-formal":	{"JJ"},
"semi-gelatinous":	{"JJ"},
"semi-gloss":	{"NN","JJ"},
"semi-independent":	{"JJ"},
"semi-inflated":	{"JJ"},
"semi-isolated":	{"JJ"},
"semi-liquefied":	{"JJ"},
"semi-literate":	{"JJ"},
"semi-local":	{"JJ"},
"semi-major":	{"JJ"},
"semi-minor":	{"JJ"},
"semi-nude":	{"JJ"},
"semi-obscure":	{"JJ"},
"semi-precious":	{"JJ"},
"semi-private":	{"JJ"},
"semi-processed":	{"JJ"},
"semi-professional":	{"JJ","NN"},
"semi-professionally":	{"RB"},
"semi-prostrate":	{"JJ"},
"semi-public":	{"JJ"},
"semi-retired":	{"JJ"},
"semi-rigid":	{"JJ"},
"semi-serious":	{"JJ"},
"semi-skilled":	{"JJ"},
"semi-special":	{"JJ"},
"semi-statist":	{"JJ"},
"semi-sterile":	{"JJ"},
"semi-tuberous":	{"JJ"},
"semi-upright":	{"JJ"},
"semi-wild":	{"JJ"},
"semiabstract":	{"JJ"},
"semiabstraction":	{"NN"},
"semiabstractions":	{"NNS"},
"semiannual":	{"JJ"},
"semiannually":	{"RB"},
"semiaquatic":	{"JJ"},
"semiarid":	{"JJ"},
"semiautobiographical":	{"JJ"},
"semiautomatic":	{"JJ","NN"},
"semibreve":	{"NN"},
"semibreves":	{"NNS"},
"semicentenary":	{"JJ","NN"},
"semicentennial":	{"JJ","NN"},
"semicircle":	{"NN"},
"semicircular":	{"JJ"},
"semicolon":	{"NN"},
"semicoma":	{"NN"},
"semicomatose":	{"JJ"},
"semiconducting":	{"JJ"},
"semiconductive":	{"JJ"},
"semiconductor":	{"NN"},
"semiconductors":	{"NNS"},
"semiconscious":	{"JJ"},
"semiconsciousness":	{"NN"},
"semidark":	{"JJ"},
"semidarkness":	{"NN"},
"semidesert":	{"NN"},
"semidetached":	{"JJ"},
"semidiameter":	{"NN"},
"semidrying":	{"JJ"},
"semiempirical":	{"JJ"},
"semiepiphyte":	{"NN"},
"semifinal":	{"NN","JJ"},
"semifinalist":	{"NN"},
"semifinalists":	{"NNS"},
"semifinals":	{"NNS"},
"semifinished":	{"JJ"},
"semifluidity":	{"NN"},
"semiformal":	{"JJ"},
"semigloss":	{"NN","JJ"},
"semihard":	{"JJ"},
"semiliquid":	{"JJ"},
"semiliterate":	{"JJ"},
"semilunar":	{"JJ"},
"semimonthly":	{"JJ"},
"seminal":	{"JJ"},
"seminar":	{"NN"},
"seminarian":	{"NN"},
"seminarians":	{"NNS"},
"seminaries":	{"NNS"},
"seminarist":	{"NN"},
"seminars":	{"NNS"},
"seminary":	{"NN"},
"seminiferous":	{"JJ"},
"seminole":	{"NN"},
"seminoma":	{"NN"},
"seminude":	{"JJ"},
"semiofficial":	{"JJ"},
"semiologist":	{"NN"},
"semiologists":	{"NNS"},
"semiology":	{"NN"},
"semiopaque":	{"JJ"},
"semiotic":	{"JJ"},
"semiotical":	{"JJ"},
"semiotician":	{"NN"},
"semioticians":	{"NNS"},
"semiotics":	{"NN"},
"semiparasite":	{"NN"},
"semiparasitic":	{"JJ"},
"semipermanent":	{"JJ"},
"semipermeable":	{"JJ"},
"semipolitical":	{"JJ"},
"semiprecious":	{"JJ"},
"semiprivate":	{"JJ"},
"semipro":	{"NN","JJ"},
"semiprofessional":	{"JJ","NN"},
"semipublic":	{"JJ"},
"semiquantitative":	{"JJ"},
"semiquaver":	{"NN"},
"semirigid":	{"JJ"},
"semis":	{"NNS"},
"semisecret":	{"JJ"},
"semiskilled":	{"JJ"},
"semisoft":	{"JJ"},
"semisolid":	{"JJ"},
"semisweet":	{"JJ"},
"semisynthetic":	{"JJ"},
"semiterrestrial":	{"JJ"},
"semitone":	{"NN"},
"semitones":	{"NNS"},
"semitrailer":	{"NN"},
"semitrance":	{"NN"},
"semitransparency":	{"NN"},
"semitransparent":	{"JJ"},
"semitropic":	{"JJ"},
"semitropical":	{"JJ"},
"semitropics":	{"NN"},
"semiurban":	{"JJ"},
"semivowel":	{"NN"},
"semiweekly":	{"JJ","NN","RB"},
"semolina":	{"NN"},
"sempatch":	{"NN"},
"semper":	{"RB","FW"},
"sempiternal":	{"JJ"},
"sempiternity":	{"NN"},
"sempstress":	{"NN"},
"sen":	{"NN","NNS"},
"senate":	{"NN"},
"senator":	{"NN"},
"senatorial":	{"JJ"},
"senators":	{"NNS"},
"senatorship":	{"NN"},
"send":	{"VB","VBP"},
"send-off":	{"NN"},
"send-offs":	{"NNS"},
"send-up":	{"NN"},
"send-ups":	{"NNS"},
"sendee":	{"NN"},
"sender":	{"NN"},
"senders":	{"NNS"},
"sending":	{"VBG"},
"sends":	{"VBZ"},
"sene":	{"NN"},
"seneca":	{"NN"},
"senecan":	{"JJ"},
"senecio":	{"NN"},
"senefelder":	{"NN"},
"senega":	{"NN"},
"senegal":	{"NN"},
"senesce":	{"VB","VBP"},
"senescence":	{"NN"},
"senescent":	{"JJ"},
"seneschal":	{"NN"},
"senhor":	{"NN"},
"senile":	{"JJ"},
"senilis":	{"NNS"},
"senility":	{"NN"},
"senior":	{"JJ","NN"},
"seniority":	{"NN"},
"seniors":	{"NNS"},
"seniti":	{"NN"},
"senna":	{"NN"},
"sennacherib":	{"NN"},
"sennenhunde":	{"NN"},
"sennett":	{"NN"},
"sennit":	{"NN"},
"senor":	{"NN"},
"senora":	{"NN"},
"senores":	{"NNS"},
"senorita":	{"NN"},
"sensate":	{"JJ"},
"sensately":	{"RB"},
"sensation":	{"NN"},
"sensational":	{"JJ"},
"sensationalise":	{"VB","VBP"},
"sensationalised":	{"VBD","VBN"},
"sensationalises":	{"VBZ"},
"sensationalising":	{"VBG"},
"sensationalism":	{"NN"},
"sensationalist":	{"NN","JJ"},
"sensationalistic":	{"JJ"},
"sensationalize":	{"VB","VBP"},
"sensationalized":	{"VBD","VBN"},
"sensationalizes":	{"VBZ"},
"sensationalizing":	{"VBG"},
"sensationally":	{"RB"},
"sensations":	{"NNS"},
"sense":	{"NN","VB","VBP"},
"sense-organ":	{"NN"},
"sense-organs":	{"NNS"},
"sensed":	{"VBD","VBN"},
"senseless":	{"JJ"},
"senselessly":	{"RB"},
"senselessness":	{"NN"},
"senses":	{"NNS","VBZ"},
"sensibilise":	{"VB","VBP"},
"sensibilities":	{"NNS"},
"sensibility":	{"NN"},
"sensibilize":	{"VB","VBP"},
"sensible":	{"JJ"},
"sensibleness":	{"NN"},
"sensibly":	{"RB"},
"sensify":	{"VB","VBP"},
"sensing":	{"NN","JJ","VBG"},
"sensitisation":	{"NN"},
"sensitise":	{"VB","VBP"},
"sensitised":	{"VBD","VBN"},
"sensitiser":	{"NN"},
"sensitises":	{"VBZ"},
"sensitising":	{"VBG"},
"sensitive":	{"JJ","NN"},
"sensitive-area":	{"NN"},
"sensitively":	{"RB"},
"sensitiveness":	{"NN"},
"sensitives":	{"NNS"},
"sensitivities":	{"NNS"},
"sensitivity":	{"NN"},
"sensitization":	{"NN"},
"sensitize":	{"VB","VBP"},
"sensitized":	{"VBD","VBN"},
"sensitizer":	{"NN"},
"sensitizes":	{"VBZ"},
"sensitizing":	{"VBG"},
"sensitometer":	{"NN"},
"sensor":	{"NN"},
"sensorial":	{"JJ"},
"sensorimotor":	{"JJ"},
"sensorineural":	{"JJ"},
"sensorium":	{"NN"},
"sensors":	{"NNS"},
"sensory":	{"JJ"},
"sensual":	{"JJ"},
"sensualise":	{"VB","VBP"},
"sensualism":	{"NN"},
"sensualist":	{"NN"},
"sensualists":	{"NNS"},
"sensuality":	{"NN"},
"sensualize":	{"VB","VBP"},
"sensually":	{"RB"},
"sensualness":	{"NN"},
"sensuous":	{"JJ"},
"sensuously":	{"RB"},
"sensuousness":	{"NN"},
"sent":	{"VBD","VBN"},
"sente":	{"NN"},
"sentence":	{"NN","VB","VBP"},
"sentenced":	{"VBN","VBD"},
"sentences":	{"NNS","VBZ"},
"sentencing":	{"VBG","NN"},
"sentencings":	{"NNS"},
"sentential":	{"JJ"},
"sententious":	{"JJ"},
"sententiously":	{"RB"},
"sentience":	{"NN"},
"sentiency":	{"NN"},
"sentient":	{"JJ"},
"sentiment":	{"NN"},
"sentimental":	{"JJ"},
"sentimentalisation":	{"NN"},
"sentimentalise":	{"VB","VBP"},
"sentimentalised":	{"VBD","VBN"},
"sentimentalises":	{"VBZ"},
"sentimentalising":	{"VBG"},
"sentimentalism":	{"NN"},
"sentimentalist":	{"NN"},
"sentimentalists":	{"NNS"},
"sentimentality":	{"NN"},
"sentimentalization":	{"NN"},
"sentimentalize":	{"VB","VBP"},
"sentimentalized":	{"VBD","VBN"},
"sentimentalizes":	{"VBZ"},
"sentimentalizing":	{"VBG"},
"sentimentally":	{"RB"},
"sentiments":	{"NNS"},
"sentinel":	{"NN","VB","VBP"},
"sentineled":	{"VBD","VBN"},
"sentineling":	{"VBG"},
"sentinelled":	{"VBD","VBN"},
"sentinelling":	{"VBG"},
"sentinels":	{"NNS","VBZ"},
"sentries":	{"NNS"},
"sentry":	{"NN"},
"sentry-box":	{"NN"},
"sentry-boxes":	{"NNS"},
"seoul":	{"NN"},
"sepal":	{"NN"},
"sepaline":	{"JJ"},
"sepaloid":	{"JJ"},
"sepals":	{"NNS"},
"separability":	{"NN"},
"separable":	{"JJ"},
"separably":	{"RB"},
"separate":	{"JJ","VB","VBP"},
"separate-buy":	{"JJ"},
"separate-buys":	{"NNS"},
"separated":	{"VBN","VBD","JJ"},
"separately":	{"RB"},
"separateness":	{"NN"},
"separates":	{"VBZ","NNS"},
"separating":	{"VBG"},
"separation":	{"NN"},
"separationism":	{"NN"},
"separationist":	{"NN"},
"separations":	{"NNS"},
"separatism":	{"NN"},
"separatist":	{"NN","JJ"},
"separatists":	{"NNS"},
"separative":	{"JJ"},
"separator":	{"NN"},
"separators":	{"NNS"},
"separatrix":	{"NN"},
"sephardi":	{"NN"},
"sepia":	{"NN","JJ"},
"sepiidae":	{"NN"},
"sepiolite":	{"NN"},
"seppuku":	{"NN"},
"sepsis":	{"NN"},
"sept":	{"NN"},
"septa":	{"NNS"},
"septal":	{"JJ"},
"septate":	{"JJ"},
"septation":	{"NN"},
"septectomy":	{"NN"},
"septenary":	{"NN","JJ"},
"septet":	{"NN"},
"septets":	{"NNS"},
"septette":	{"NN"},
"septic":	{"JJ"},
"septicaemia":	{"NN"},
"septicemia":	{"NN"},
"septicemic":	{"JJ"},
"septillion":	{"NN"},
"septobasidiaceae":	{"NN"},
"septobasidium":	{"NN"},
"septrional":	{"JJ"},
"septuagenarian":	{"NN","JJ"},
"septuagenarians":	{"NNS"},
"septum":	{"NN"},
"septums":	{"NNS"},
"septuple":	{"JJ"},
"sepulcher":	{"NN","VB","VBP"},
"sepulchered":	{"VBD","VBN"},
"sepulchering":	{"VBG"},
"sepulchers":	{"NNS","VBZ"},
"sepulchral":	{"JJ"},
"sepulchre":	{"NN","VB","VBP"},
"sepulchred":	{"VBD","VBN"},
"sepulchres":	{"NNS","VBZ"},
"sepulchring":	{"VBG"},
"sepulture":	{"NN"},
"seq":	{"NN"},
"sequel":	{"NN"},
"sequela":	{"NN"},
"sequella":	{"NN"},
"sequels":	{"NNS"},
"sequenator":	{"NN"},
"sequence":	{"NN","VB","VBP"},
"sequenced":	{"VBD","VBN"},
"sequencer":	{"NN"},
"sequencers":	{"NNS"},
"sequences":	{"NNS","VBZ"},
"sequencing":	{"VBG","NN"},
"sequent":	{"JJ"},
"sequential":	{"JJ"},
"sequentially":	{"RB"},
"sequester":	{"VB","VBP","NN"},
"sequestered":	{"JJ","VBD","VBN"},
"sequestering":	{"VBG"},
"sequesters":	{"VBZ"},
"sequestrate":	{"VB","VBP"},
"sequestrated":	{"VBD","VBN"},
"sequestrates":	{"VBZ"},
"sequestrating":	{"VBG"},
"sequestration":	{"NN"},
"sequin":	{"NN"},
"sequined":	{"JJ"},
"sequinned":	{"JJ"},
"sequins":	{"NNS"},
"sequoia":	{"NN"},
"sequoiadendron":	{"NN"},
"sequoias":	{"NNS"},
"sequoya":	{"NN"},
"ser":	{"NN"},
"sera":	{"NNS"},
"seraglio":	{"NN"},
"seraglios":	{"NNS"},
"serail":	{"NN"},
"serape":	{"NN"},
"seraph":	{"NN"},
"seraphic":	{"JJ"},
"seraphical":	{"JJ"},
"seraphim":	{"NNS"},
"seraphs":	{"NNS"},
"serax":	{"NN"},
"serb":	{"NN"},
"serbia":	{"NN"},
"serbian":	{"JJ","NN"},
"serdica":	{"NN"},
"sere":	{"JJ"},
"serenade":	{"NN","VB","VBP"},
"serenaded":	{"VBD","VBN"},
"serenades":	{"NNS","VBZ"},
"serenading":	{"VBG"},
"serendipitous":	{"JJ"},
"serendipity":	{"NN"},
"serene":	{"JJ"},
"serenely":	{"RB"},
"sereness":	{"NN"},
"serengeti":	{"NN"},
"serenity":	{"NN"},
"serenoa":	{"NN"},
"serer":	{"NN"},
"serf":	{"NN"},
"serfdom":	{"NN"},
"serfhood":	{"NN"},
"serflike":	{"JJ"},
"serfs":	{"NNS"},
"serge":	{"NN"},
"sergeant":	{"NN"},
"sergeant-major":	{"NN"},
"sergeant-majors":	{"NNS"},
"sergeants":	{"NNS"},
"serger":	{"NN"},
"serial":	{"JJ","NN"},
"serialisation":	{"NN"},
"serialisations":	{"NNS"},
"serialise":	{"VB","VBP"},
"serialised":	{"VBD","VBN"},
"serialises":	{"VBZ"},
"serialising":	{"VBG"},
"serialism":	{"NN"},
"serialization":	{"NN"},
"serializations":	{"NNS"},
"serialize":	{"VB","VBP"},
"serialized":	{"VBD","VBN"},
"serializes":	{"VBZ"},
"serializing":	{"VBG"},
"serially":	{"RB"},
"serials":	{"NNS"},
"seriatim":	{"RB"},
"sericeous":	{"JJ"},
"sericocarpus":	{"NN"},
"sericterium":	{"NN"},
"serictery":	{"NN"},
"sericultural":	{"JJ"},
"sericulture":	{"NN"},
"sericulturist":	{"NN"},
"seriema":	{"NN"},
"series":	{"NN","NNS"},
"serif":	{"NN"},
"serigraph":	{"NN"},
"serigraphy":	{"NN"},
"serin":	{"NN"},
"serine":	{"NN"},
"serinus":	{"NN"},
"seriocomedy":	{"NN"},
"seriocomic":	{"JJ"},
"seriocomical":	{"JJ"},
"seriola":	{"NN"},
"serious":	{"JJ"},
"serious-minded":	{"JJ"},
"serious-mindedness":	{"NN"},
"seriously":	{"RB"},
"seriousness":	{"NN"},
"seriph":	{"NN"},
"seriphidium":	{"NN"},
"seriphus":	{"NN"},
"serjeant":	{"NN"},
"serjeant-at-arms":	{"NN"},
"serjeant-at-law":	{"NN"},
"serjeants-at-arms":	{"NNS"},
"serjeants-at-law":	{"NNS"},
"serkin":	{"NN"},
"serloin":	{"NN"},
"sermon":	{"NN"},
"sermonise":	{"VB","VBP"},
"sermonised":	{"VBD","VBN"},
"sermoniser":	{"NN"},
"sermonises":	{"VBZ"},
"sermonising":	{"VBG"},
"sermonize":	{"VB","VBP"},
"sermonized":	{"VBD","VBN"},
"sermonizer":	{"NN"},
"sermonizes":	{"VBZ"},
"sermonizing":	{"VBG"},
"sermons":	{"NNS"},
"serologic":	{"JJ"},
"serological":	{"JJ"},
"serologist":	{"NN"},
"serology":	{"NN"},
"serosa":	{"NN"},
"serotine":	{"NN"},
"serotonin":	{"NN"},
"serous":	{"JJ"},
"serow":	{"NN"},
"serpasil":	{"NN"},
"serpens":	{"NNS"},
"serpent":	{"NN"},
"serpentes":	{"NNS"},
"serpentine":	{"JJ","NN"},
"serpents":	{"NNS"},
"serra":	{"NN"},
"serranid":	{"NN"},
"serranidae":	{"NN"},
"serranus":	{"NN"},
"serrasalmus":	{"NN"},
"serrate":	{"JJ","VB","VBP"},
"serrated":	{"VBD","VBN","JJ"},
"serrates":	{"VBZ"},
"serratia":	{"NN"},
"serrating":	{"VBG"},
"serration":	{"NN"},
"serratula":	{"NN"},
"serratus":	{"NN"},
"serried":	{"JJ"},
"serrulate":	{"JJ"},
"sertraline":	{"NN"},
"sertularia":	{"NN"},
"sertularian":	{"NN"},
"serum":	{"NN"},
"serums":	{"NNS"},
"serval":	{"NN","NNS"},
"servals":	{"NNS"},
"servant":	{"NN"},
"servants":	{"NNS"},
"serve":	{"VB","NN","VBP"},
"served":	{"VBN","VBD"},
"server":	{"NN"},
"servers":	{"NNS"},
"serves":	{"VBZ","NNS"},
"service":	{"NN","VB","VBP"},
"serviceability":	{"NN"},
"serviceable":	{"JJ"},
"serviceableness":	{"NN"},
"serviceberry":	{"NN"},
"serviced":	{"VBD","VBN"},
"serviceman":	{"NN"},
"servicemember":	{"NN"},
"servicemembers":	{"NNS"},
"servicemen":	{"NNS"},
"servicers":	{"NNS"},
"services":	{"NNS","VBZ"},
"servicewoman":	{"NN"},
"servicewomen":	{"NNS"},
"servicing":	{"NN","VBG"},
"serviette":	{"NN"},
"serviettes":	{"NNS"},
"servile":	{"JJ"},
"servilely":	{"RB"},
"servility":	{"NN"},
"serving":	{"VBG","NN","JJ"},
"servings":	{"NNS"},
"servitor":	{"NN"},
"servitors":	{"NNS"},
"servitude":	{"NN"},
"servo":	{"NN"},
"servomechanical":	{"JJ"},
"servomechanism":	{"NN"},
"servos":	{"NNS"},
"servosystem":	{"NN"},
"serzone":	{"NN"},
"sesame":	{"NN"},
"sesamoid":	{"JJ"},
"sesamum":	{"NN"},
"sesbania":	{"NN"},
"seseli":	{"NN"},
"sesotho":	{"NN"},
"sesquicentennial":	{"NN","JJ"},
"sesquipedalia":	{"NN"},
"sesquipedalian":	{"NN"},
"sesquipedality":	{"NN"},
"sess":	{"NN"},
"sessile":	{"JJ"},
"session":	{"NN","JJ"},
"sessions":	{"NNS"},
"sestet":	{"NN"},
"set":	{"VBN","VBD","NN","VB","VBP","JJ"},
"set-apart":	{"JJ"},
"set-aside":	{"JJ","NN"},
"set-asides":	{"NNS"},
"set-to":	{"NN"},
"set-top":	{"JJ"},
"set-tos":	{"NNS"},
"set-up":	{"NN"},
"set-ups":	{"NNS"},
"seta":	{"NN"},
"setaceous":	{"JJ"},
"setaria":	{"NN"},
"setback":	{"NN"},
"setbacks":	{"NNS"},
"seth":	{"NN"},
"setline":	{"NN"},
"setoff":	{"NN"},
"seton":	{"NN"},
"setophaga":	{"NN"},
"setose":	{"JJ"},
"sets":	{"NNS","VBZ"},
"setscrew":	{"NN"},
"setsw":	{"NN"},
"setswana":	{"NN"},
"sett":	{"NN"},
"settee":	{"NN"},
"settees":	{"NNS"},
"setter":	{"NN"},
"setters":	{"NNS"},
"setterwort":	{"NN"},
"setting":	{"VBG","NN"},
"settings":	{"NNS"},
"settle":	{"VB","VBP","NN"},
"settled":	{"VBN","VBD","JJ"},
"settlement":	{"NN"},
"settlements":	{"NNS"},
"settler":	{"NN"},
"settlers":	{"NNS"},
"settles":	{"VBZ","NNS"},
"settling":	{"VBG","NN"},
"settlings":	{"NNS"},
"settlor":	{"NN"},
"setts":	{"NNS"},
"setubal":	{"NN"},
"setup":	{"NN"},
"setups":	{"NNS"},
"seurat":	{"NN"},
"sevastopol":	{"NN"},
"seven":	{"CD","LS","NN"},
"sevenfold":	{"JJ","RB"},
"sevens":	{"NNS"},
"seventeen":	{"CD","NN"},
"seventeenth":	{"JJ","NN"},
"seventh":	{"JJ","NN"},
"seventhly":	{"RB"},
"seventies":	{"NNS"},
"seventieth":	{"JJ","NN"},
"seventy":	{"NN","CD"},
"seventy-eight":	{"NN"},
"seventy-fifth":	{"JJ","NN"},
"sever":	{"VB","VBP"},
"severable":	{"JJ"},
"several":	{"DT","JJ"},
"severally":	{"RB"},
"severalty":	{"NN"},
"severance":	{"NN","JJ"},
"severe":	{"JJ"},
"severed":	{"VBD","VBN"},
"severely":	{"RB"},
"severeness":	{"NN"},
"severer":	{"JJR"},
"severest":	{"JJS"},
"severing":	{"VBG"},
"severity":	{"NN"},
"severly":	{"RB"},
"severs":	{"VBZ"},
"sevilla":	{"NN"},
"seville":	{"NN"},
"sevin":	{"NN"},
"sew":	{"VB","VBP"},
"sewage":	{"NN"},
"seward":	{"NN"},
"sewed":	{"VBD","VBN"},
"sewellel":	{"NN"},
"sewer":	{"NN"},
"sewerage":	{"NN"},
"sewers":	{"NNS"},
"sewing":	{"NN","VBG"},
"sewn":	{"VBN"},
"sews":	{"VBZ"},
"sex":	{"NN","VB","VBP"},
"sex-change":	{"JJ","NN"},
"sex-discrimination":	{"NN"},
"sex-education":	{"NN"},
"sexagenarian":	{"JJ","NN"},
"sexagenarians":	{"NNS"},
"sexagesimal":	{"JJ"},
"sexcapade":	{"NN"},
"sexed":	{"VBD","VBN","JJ"},
"sexes":	{"NNS","VBZ"},
"sexier":	{"JJR"},
"sexiest":	{"JJS"},
"sexiness":	{"NN"},
"sexing":	{"VBG"},
"sexism":	{"NN"},
"sexist":	{"JJ","NN"},
"sexists":	{"NNS"},
"sexless":	{"JJ"},
"sexlessness":	{"NN"},
"sexologist":	{"NN"},
"sexologists":	{"NNS"},
"sexology":	{"NN"},
"sexploitation":	{"NN"},
"sexpot":	{"NN"},
"sexpots":	{"NNS"},
"sext":	{"NN","VB","VBP"},
"sextant":	{"NN"},
"sextants":	{"NNS"},
"sexted":	{"VBD","VBN"},
"sextet":	{"NN"},
"sextets":	{"NNS"},
"sextette":	{"NN"},
"sextillion":	{"NN"},
"sexting":	{"VBG","NN"},
"sexton":	{"NN"},
"sextons":	{"NNS"},
"sexts":	{"VBZ"},
"sextuple":	{"JJ","NN","VB","VBP"},
"sextupled":	{"VBD","VBN"},
"sextuples":	{"VBZ"},
"sextuplet":	{"NN"},
"sextuplets":	{"NNS"},
"sextupling":	{"VBG"},
"sexual":	{"JJ"},
"sexualise":	{"VB","VBP"},
"sexualised":	{"VBD","VBN"},
"sexualises":	{"VBZ"},
"sexualising":	{"VBG"},
"sexuality":	{"NN"},
"sexualize":	{"VB","VBP"},
"sexualized":	{"VBD","VBN"},
"sexualizes":	{"VBZ"},
"sexualizing":	{"VBG"},
"sexually":	{"RB"},
"sexy":	{"JJ"},
"seyhan":	{"NN"},
"seymour":	{"NN"},
"sezession":	{"NN"},
"sfax":	{"NN"},
"sforzando":	{"NN"},
"sg":	{"NN"},
"sgml":	{"NN"},
"sgraffito":	{"NN"},
"sh":	{"UH"},
"sha":	{"MD"},
"shaaban":	{"NN"},
"shabbier":	{"JJR"},
"shabbiest":	{"JJS"},
"shabbily":	{"RB"},
"shabbiness":	{"NN"},
"shabby":	{"JJ"},
"shabu":	{"NN"},
"shack":	{"NN","VB","VBP"},
"shacked":	{"VBN","VBD"},
"shacking":	{"VBG"},
"shackle":	{"NN","VB","VBP"},
"shackled":	{"VBD","VBN"},
"shackles":	{"NNS","VBZ"},
"shackling":	{"VBG"},
"shacks":	{"NNS","VBZ"},
"shad":	{"NN","NNS"},
"shadberry":	{"NN"},
"shadblow":	{"NN"},
"shadbush":	{"NN"},
"shaddock":	{"NN"},
"shade":	{"NN","VB","VBP"},
"shaded":	{"JJ","VBD","VBN"},
"shades":	{"NNS","VBZ"},
"shadflower":	{"NN"},
"shadfly":	{"NN"},
"shadier":	{"JJR"},
"shadiest":	{"JJS"},
"shadily":	{"RB"},
"shadiness":	{"NN"},
"shading":	{"NN","VBG"},
"shadings":	{"NNS"},
"shadow":	{"NN","VB","VBP","JJ"},
"shadow-box":	{"VB","VBP"},
"shadow-boxed":	{"VBD","VBN"},
"shadow-boxes":	{"VBZ"},
"shadow-boxing":	{"NN","VBG"},
"shadowed":	{"VBD","VBN"},
"shadower":	{"NN"},
"shadowgraph":	{"NN"},
"shadowiness":	{"NN"},
"shadowing":	{"NN","VBG"},
"shadowland":	{"NN"},
"shadows":	{"NNS","VBZ"},
"shadowy":	{"JJ"},
"shady":	{"JJ"},
"shaffner":	{"NN"},
"shaft":	{"NN","VB","VBP"},
"shafted":	{"VBD","VBN"},
"shafting":	{"VBG"},
"shafts":	{"NNS","VBZ"},
"shag":	{"NN","VB","VBP","JJ"},
"shagbark":	{"NN"},
"shagged":	{"JJ","VBD","VBN"},
"shaggily":	{"RB"},
"shagginess":	{"NN"},
"shagging":	{"VBG"},
"shaggy":	{"JJ"},
"shaggy-dog":	{"JJ"},
"shaggymane":	{"NN"},
"shags":	{"NNS","VBZ"},
"shah":	{"NN"},
"shahada":	{"NN"},
"shahadah":	{"NN"},
"shaheed":	{"NN"},
"shahn":	{"NN"},
"shaitan":	{"NN"},
"shakable":	{"JJ"},
"shake":	{"VB","NN","VBP"},
"shake-up":	{"NN"},
"shake-ups":	{"NNS"},
"shakeable":	{"JJ"},
"shakedown":	{"NN"},
"shakedowns":	{"NNS"},
"shaken":	{"VBN","JJ"},
"shakeout":	{"NN"},
"shakeouts":	{"NNS"},
"shaker":	{"NN","JJ"},
"shakers":	{"NNS"},
"shakes":	{"VBZ","NNS"},
"shakespeare":	{"NN"},
"shakespearean":	{"JJ","NN"},
"shakespearian":	{"JJ","NN"},
"shakeup":	{"NN"},
"shakeups":	{"NNS"},
"shakier":	{"JJR"},
"shakiest":	{"JJS"},
"shakily":	{"RB"},
"shakiness":	{"NN"},
"shaking":	{"VBG","NN"},
"shako":	{"NN"},
"shakti":	{"NN"},
"shaktism":	{"NN"},
"shaktist":	{"NN"},
"shaky":	{"JJ"},
"shale":	{"NN"},
"shale-oil":	{"NN"},
"shales":	{"NNS"},
"shall":	{"MD"},
"shallon":	{"NN"},
"shallot":	{"NN"},
"shallots":	{"NNS"},
"shallow":	{"JJ","VB","VBP"},
"shallowed":	{"VBD","VBN"},
"shallower":	{"JJR"},
"shallowest":	{"JJS"},
"shallowing":	{"VBG"},
"shallowly":	{"RB"},
"shallowness":	{"NN"},
"shallows":	{"VBZ","NNS"},
"shallu":	{"NN"},
"shalom":	{"UH"},
"shalt":	{"MD"},
"shalwar":	{"NN"},
"sham":	{"NN","JJ","VB","VBP"},
"shaman":	{"NN"},
"shamanism":	{"NN"},
"shamanist":	{"JJ","NN"},
"shamanistic":	{"JJ"},
"shamans":	{"NNS"},
"shamble":	{"VB","VBP","NN"},
"shambled":	{"VBD","VBN"},
"shambles":	{"VBZ","NN"},
"shambling":	{"VBG","NN","JJ"},
"shambolic":	{"JJ"},
"shambolically":	{"RB"},
"shame":	{"NN","VB","VBP"},
"shamed":	{"VBD","VBN"},
"shamefaced":	{"JJ"},
"shamefacedly":	{"RB"},
"shamefacedness":	{"NN"},
"shameful":	{"JJ"},
"shamefully":	{"RB"},
"shamefulness":	{"NN"},
"shameless":	{"JJ"},
"shamelessly":	{"RB"},
"shamelessness":	{"NN"},
"shames":	{"VBZ"},
"shaming":	{"VBG"},
"shamisen":	{"NN"},
"shammed":	{"VBD","VBN"},
"shammer":	{"NN"},
"shammers":	{"NNS"},
"shammies":	{"NNS"},
"shamming":	{"VBG"},
"shammy":	{"NN"},
"shampoo":	{"NN","VB","VBP"},
"shampooed":	{"VBD","VBN"},
"shampooing":	{"VBG"},
"shampoos":	{"NNS","VBZ"},
"shamrock":	{"NN"},
"shamrocks":	{"NNS"},
"shams":	{"NNS","VBZ"},
"shamus":	{"NN"},
"shan":	{"NN"},
"shandies":	{"NNS"},
"shandong":	{"NN"},
"shandy":	{"NN"},
"shandygaff":	{"NN"},
"shang":	{"NN"},
"shanghai":	{"VB","VBP"},
"shanghaied":	{"VBD","VBN"},
"shanghaier":	{"NN"},
"shanghaiing":	{"VBG"},
"shanghais":	{"VBZ"},
"shangri-la":	{"NN"},
"shank":	{"NN"},
"shankar":	{"NN"},
"shanks":	{"NNS"},
"shannon":	{"NN"},
"shanny":	{"NN"},
"shanties":	{"NNS"},
"shantung":	{"NN"},
"shanty":	{"NN"},
"shantytown":	{"NN"},
"shantytowns":	{"NNS"},
"shape":	{"NN","VB","VBP"},
"shape-shift":	{"VB","VBP"},
"shape-shifted":	{"VBD","VBN"},
"shape-shifter":	{"NN"},
"shape-shifters":	{"NNS"},
"shape-shifting":	{"VBG","NN","JJ"},
"shape-shifts":	{"VBZ"},
"shaped":	{"VBN","VBD","JJ"},
"shapeless":	{"JJ"},
"shapelessly":	{"RB"},
"shapelessness":	{"NN"},
"shapelier":	{"JJR"},
"shapeliest":	{"JJS"},
"shapeliness":	{"NN"},
"shapely":	{"JJ"},
"shaper":	{"NN"},
"shapers":	{"NNS"},
"shapes":	{"NNS","VBZ"},
"shapeshift":	{"VB","VBP"},
"shapeshifted":	{"VBD","VBN"},
"shapeshifter":	{"NN"},
"shapeshifters":	{"NNS"},
"shapeshifting":	{"VBG","JJ","NN"},
"shapeshifts":	{"VBZ"},
"shaping":	{"VBG"},
"shard":	{"NN"},
"shards":	{"NNS"},
"share":	{"NN","VB","VBP"},
"share-out":	{"NN"},
"sharecrop":	{"VB","VBP"},
"sharecropped":	{"VBD","VBN"},
"sharecropper":	{"NN"},
"sharecroppers":	{"NNS"},
"sharecropping":	{"VBG"},
"sharecrops":	{"VBZ"},
"shared":	{"VBN","VBD"},
"shareholder":	{"NN"},
"shareholders":	{"NNS"},
"shareholding":	{"NN"},
"shareholdings":	{"NNS"},
"shareowner":	{"NN"},
"shareowners":	{"NNS"},
"sharer":	{"NN"},
"sharers":	{"NNS"},
"shares":	{"NNS","VBZ"},
"shareware":	{"NN"},
"shari":	{"NN"},
"sharia":	{"NN"},
"shariah":	{"NN"},
"sharing":	{"VBG","NN"},
"shark":	{"NN","NNS"},
"shark-skin":	{"NN"},
"sharks":	{"NNS"},
"sharkskin":	{"NN"},
"sharksucker":	{"NN"},
"sharp":	{"JJ","RB","NN","VB","VBP"},
"sharp-eared":	{"JJ"},
"sharp-eyed":	{"JJ"},
"sharp-nosed":	{"JJ"},
"sharp-set":	{"JJ"},
"sharp-witted":	{"JJ"},
"sharped":	{"VBD","VBN"},
"sharpen":	{"VB","VBP"},
"sharpened":	{"VBD","VBN"},
"sharpener":	{"NN"},
"sharpeners":	{"NNS"},
"sharpening":	{"VBG"},
"sharpens":	{"VBZ"},
"sharper":	{"JJR","NN"},
"sharpest":	{"JJS"},
"sharpie":	{"NN"},
"sharpies":	{"NNS"},
"sharping":	{"VBG"},
"sharply":	{"RB"},
"sharpness":	{"NN"},
"sharps":	{"VBZ","NNS"},
"sharpshoot":	{"VB","VBP"},
"sharpshooter":	{"NN"},
"sharpshooters":	{"NNS"},
"sharpy":	{"NN"},
"shashlik":	{"NN"},
"shasta":	{"NN"},
"shastan":	{"NN"},
"shat":	{"VBD","VBN"},
"shatter":	{"VB","VBP"},
"shattered":	{"JJ","VBD","VBN"},
"shattering":	{"NN","JJ","VBG"},
"shatteringly":	{"RB"},
"shatterproof":	{"JJ"},
"shatters":	{"VBZ"},
"shave":	{"VB","VBP","NN"},
"shaved":	{"VBD","VBN"},
"shaven":	{"JJ"},
"shaver":	{"NN"},
"shavers":	{"NNS"},
"shaves":	{"VBZ","NNS"},
"shaving":	{"NN","VBG"},
"shavings":	{"NNS"},
"shavous":	{"NN"},
"shavuoth":	{"NN"},
"shaw":	{"NN"},
"shawl":	{"NN"},
"shawls":	{"NNS"},
"shawm":	{"NN"},
"shawn":	{"NN"},
"shawnee":	{"NN"},
"shawwal":	{"NN"},
"shay":	{"NN"},
"shays":	{"NNS"},
"shaytan":	{"NN"},
"she":	{"PRP","NN"},
"she-bop":	{"VB","VBP"},
"she-goat":	{"NN"},
"shea":	{"NN"},
"sheaf":	{"NN","VB","VBP"},
"sheafed":	{"VBD","VBN"},
"sheafing":	{"VBG"},
"sheafs":	{"NNS","VBZ"},
"shear":	{"VB","VBP"},
"sheared":	{"VBD","VBN"},
"shearer":	{"NN"},
"shearing":	{"NN","VBG"},
"shears":	{"NNS","VBZ"},
"shearwater":	{"NN"},
"sheatfish":	{"NN"},
"sheath":	{"NN"},
"sheathe":	{"VB","VBP"},
"sheathed":	{"VBD","VBN"},
"sheathes":	{"VBZ"},
"sheathing":	{"NN","VBG"},
"sheaths":	{"NNS"},
"shebang":	{"NN"},
"shebat":	{"NN"},
"shebeen":	{"NN"},
"shed":	{"VB","VBD","VBN","VBP","NN"},
"shedder":	{"NN"},
"shedding":	{"VBG"},
"sheds":	{"VBZ","NNS"},
"sheehan":	{"NN"},
"sheen":	{"NN"},
"sheenies":	{"NNS"},
"sheeny":	{"JJ","NN"},
"sheep":	{"NN","NNS"},
"sheep-dip":	{"NN"},
"sheep-dips":	{"NNS"},
"sheep-dog":	{"NN"},
"sheep-dogs":	{"NNS"},
"sheep-fold":	{"NN"},
"sheep-tick":	{"NN"},
"sheepcote":	{"NN"},
"sheepdog":	{"NN"},
"sheepdogs":	{"NNS"},
"sheepe":	{"NNS"},
"sheepfold":	{"NN"},
"sheepherder":	{"NN"},
"sheepish":	{"JJ"},
"sheepishly":	{"RB"},
"sheepishness":	{"NN"},
"sheeplike":	{"JJ"},
"sheepman":	{"NN"},
"sheepmen":	{"NNS"},
"sheeprun":	{"NN"},
"sheepshank":	{"NN"},
"sheepshead":	{"NN"},
"sheepshearing":	{"NN"},
"sheepskin":	{"NN"},
"sheepskins":	{"NNS"},
"sheepwalk":	{"NN"},
"sheer":	{"JJ","RB","VB","VBP","NN"},
"sheered":	{"JJ","VBD","VBN"},
"sheerer":	{"JJR"},
"sheerest":	{"JJS"},
"sheering":	{"VBG"},
"sheerly":	{"RB"},
"sheerness":	{"NN"},
"sheers":	{"VBZ"},
"sheesha":	{"NN"},
"sheet":	{"NN","VB","VBP"},
"sheet-fed":	{"JJ"},
"sheeted":	{"VBD","VBN"},
"sheeting":	{"NN","VBG"},
"sheetlike":	{"JJ"},
"sheetrock":	{"NN"},
"sheets":	{"NNS","VBZ"},
"sheffield":	{"NN"},
"shegetz":	{"NN"},
"sheik":	{"NN"},
"sheika":	{"NN"},
"sheikdom":	{"NN"},
"sheikdoms":	{"NNS"},
"sheikh":	{"NN"},
"sheikha":	{"NN"},
"sheikhdom":	{"NN"},
"sheikhdoms":	{"NNS"},
"sheikhs":	{"NNS"},
"sheiks":	{"NNS"},
"sheila":	{"NN"},
"shekel":	{"NN"},
"shekels":	{"NNS"},
"shelby":	{"NN"},
"sheldrake":	{"NN","NNS"},
"shelduck":	{"NN","NNS"},
"shelf":	{"NN"},
"shelf-life":	{"NN"},
"shelf-mark":	{"NN"},
"shelfful":	{"NN"},
"shelflike":	{"JJ"},
"shelfy":	{"JJ"},
"shell":	{"NN","VB","VBP"},
"shell-flower":	{"NN"},
"shell-less":	{"JJ"},
"shellac":	{"NN","VB","VBP"},
"shellacked":	{"VBD","VBN"},
"shellacking":	{"VBG","NN"},
"shellacs":	{"VBZ"},
"shellbark":	{"NN"},
"shelled":	{"JJ","VBD","VBN"},
"sheller":	{"NN"},
"shellfire":	{"NN"},
"shellfish":	{"NN","NNS"},
"shellflower":	{"NN"},
"shelling":	{"NN","VBG"},
"shellproof":	{"JJ"},
"shells":	{"NNS","VBZ"},
"shellshock":	{"NN"},
"shellshocked":	{"JJ"},
"shelly":	{"JJ"},
"shelter":	{"NN","VB","VBP"},
"shelterbelt":	{"NN"},
"sheltered":	{"VBD","VBN","JJ"},
"sheltering":	{"VBG"},
"shelters":	{"NNS","VBZ"},
"shelve":	{"VB","VBP"},
"shelved":	{"VBD","VBN"},
"shelver":	{"NN"},
"shelves":	{"NNS","VBZ"},
"shelvier":	{"JJR"},
"shelviest":	{"JJS"},
"shelving":	{"NN","VBG"},
"shelvy":	{"JJ"},
"shem":	{"NN"},
"shema":	{"NN"},
"shemozzle":	{"NN"},
"shenanigan":	{"NN"},
"shenanigans":	{"NNS"},
"shenzhen":	{"NN"},
"shepard":	{"NN"},
"shepherd":	{"NN","VB","VBP"},
"shepherded":	{"VBD","VBN"},
"shepherdess":	{"NN"},
"shepherdesses":	{"NNS"},
"shepherding":	{"VBG"},
"shepherds":	{"NNS","VBZ"},
"sheraton":	{"NN"},
"sherbert":	{"NN"},
"sherbet":	{"NN"},
"sherbets":	{"NNS"},
"sherd":	{"NN"},
"sherds":	{"NNS"},
"sheridan":	{"NN"},
"sheriff":	{"NN"},
"sheriffs":	{"NNS"},
"sherlock":	{"NN"},
"sherman":	{"NN"},
"sherries":	{"NNS"},
"sherrington":	{"NN"},
"sherry":	{"NN"},
"sherwood":	{"NN"},
"shevchenko":	{"NN"},
"shew":	{"VB","VBP"},
"shewe":	{"NN"},
"shewed":	{"VBD","VBN"},
"shewing":	{"VBG"},
"shews":	{"VBZ"},
"shf":	{"NN"},
"shh":	{"UH"},
"shiatsu":	{"NN"},
"shibah":	{"NN"},
"shibboleth":	{"NN"},
"shibboleths":	{"NNS"},
"shied":	{"VBD","VBN"},
"shield":	{"NN","VB","VBP"},
"shielded":	{"VBD","VBN"},
"shielder":	{"NN"},
"shielding":	{"VBG"},
"shields":	{"NNS","VBZ"},
"shies":	{"VBZ","NNS"},
"shift":	{"VB","VBP","NN"},
"shifted":	{"VBN","VBD"},
"shifter":	{"NN"},
"shifters":	{"NNS"},
"shiftier":	{"JJR"},
"shiftiest":	{"JJS"},
"shiftily":	{"RB"},
"shiftiness":	{"NN"},
"shifting":	{"VBG"},
"shiftless":	{"JJ"},
"shiftlessness":	{"NN"},
"shifts":	{"NNS","VBZ"},
"shifty":	{"JJ"},
"shigella":	{"NN"},
"shigellosis":	{"NN"},
"shih":	{"NN"},
"shih-tzu":	{"NN"},
"shiitake":	{"NN","NNS"},
"shiksa":	{"NN"},
"shikse":	{"NN"},
"shill":	{"NN","VB","VBP"},
"shillalah":	{"NN"},
"shilled":	{"VBD","VBN"},
"shillelagh":	{"NN"},
"shilling":	{"NN","VBG"},
"shillings":	{"NNS"},
"shills":	{"NNS","VBZ"},
"shilly-shallied":	{"VBD","VBN"},
"shilly-shallies":	{"VBZ","NNS"},
"shilly-shally":	{"VB","VBP","RB","JJ","NN"},
"shilly-shallying":	{"VBG"},
"shillyshallied":	{"VBD","VBN"},
"shillyshallies":	{"VBZ","NNS"},
"shillyshally":	{"VB","VBP","RB","JJ","NN"},
"shillyshallying":	{"VBG"},
"shiloh":	{"NN"},
"shim":	{"NN","VB","VBP"},
"shimmed":	{"VBD","VBN"},
"shimmer":	{"VB","VBP","NN"},
"shimmered":	{"VBD","VBN"},
"shimmering":	{"VBG"},
"shimmers":	{"VBZ"},
"shimmery":	{"JJ"},
"shimmied":	{"VBD","VBN"},
"shimmies":	{"VBZ"},
"shimming":	{"VBG"},
"shimmy":	{"VB","VBP"},
"shimmying":	{"VBG"},
"shims":	{"NNS","VBZ"},
"shin":	{"NN","VBP","VB"},
"shina":	{"NN"},
"shinbone":	{"NN"},
"shinbones":	{"NNS"},
"shindig":	{"NN"},
"shindigs":	{"NNS"},
"shindy":	{"NN"},
"shine":	{"VB","VBP","NN"},
"shined":	{"VBD","VBN"},
"shiner":	{"NN"},
"shiners":	{"NNS"},
"shines":	{"VBZ","NNS"},
"shing":	{"NN"},
"shingle":	{"NN","VB","VBP"},
"shingled":	{"VBD","VBN","JJ"},
"shingler":	{"NN"},
"shinglers":	{"NNS"},
"shingles":	{"NNS","VBZ","NN"},
"shingling":	{"VBG"},
"shingly":	{"JJ"},
"shingon":	{"NN"},
"shinier":	{"JJR"},
"shiniest":	{"JJS"},
"shininess":	{"NN"},
"shining":	{"JJ","VBG"},
"shiningly":	{"RB"},
"shinleaf":	{"NN"},
"shinned":	{"VBD","VBN"},
"shinney":	{"NN"},
"shinnied":	{"VBD","VBN"},
"shinnies":	{"VBZ"},
"shinning":	{"VBG"},
"shinny":	{"VB","VBP"},
"shinnying":	{"VBG"},
"shinpad":	{"NN"},
"shinplaster":	{"NN"},
"shins":	{"NNS","VBZ"},
"shintoism":	{"NN"},
"shiny":	{"JJ"},
"ship":	{"NN","VB","VBP"},
"ship-breaker":	{"NN"},
"ship-canal":	{"NN"},
"shipboard":	{"JJ","NN"},
"shipbuilder":	{"NN"},
"shipbuilders":	{"NNS"},
"shipbuilding":	{"NN"},
"shipload":	{"NN"},
"shiploads":	{"NNS"},
"shipman":	{"NN"},
"shipmate":	{"NN"},
"shipmates":	{"NNS"},
"shipment":	{"NN"},
"shipments":	{"NNS"},
"shipowner":	{"NN"},
"shipowners":	{"NNS"},
"shipped":	{"VBN","VBD"},
"shipper":	{"NN"},
"shippers":	{"NNS"},
"shipping":	{"NN","VBG"},
"ships":	{"NNS","VBZ"},
"shipsets":	{"NNS"},
"shipshape":	{"JJ"},
"shipside":	{"NN"},
"shipway":	{"NN"},
"shipworm":	{"NN"},
"shipwreck":	{"NN","VBP","VB"},
"shipwrecked":	{"VBD","VBN"},
"shipwrecking":	{"VBG"},
"shipwrecks":	{"NNS","VBZ"},
"shipwright":	{"NN"},
"shipwrights":	{"NNS"},
"shipyard":	{"NN"},
"shipyards":	{"NNS"},
"shire":	{"NN"},
"shirer":	{"NN"},
"shires":	{"NNS"},
"shirk":	{"VB","VBP"},
"shirked":	{"VBD","VBN"},
"shirker":	{"NN"},
"shirkers":	{"NNS"},
"shirking":	{"VBG"},
"shirks":	{"VBZ"},
"shirr":	{"VB","VBP"},
"shirred":	{"VBD","VBN"},
"shirring":	{"VBG","NN"},
"shirrs":	{"VBZ"},
"shirt":	{"NN"},
"shirt-front":	{"NN"},
"shirt-pocket":	{"NN"},
"shirt-tail":	{"NN"},
"shirt-tails":	{"NNS"},
"shirtdress":	{"NN"},
"shirtfront":	{"NN"},
"shirtfronts":	{"NNS"},
"shirtier":	{"JJR"},
"shirtiest":	{"JJS"},
"shirtily":	{"RB"},
"shirtiness":	{"NN"},
"shirting":	{"NN"},
"shirtless":	{"JJ"},
"shirtlifter":	{"NN"},
"shirtmaker":	{"NN"},
"shirts":	{"NNS"},
"shirtsleeve":	{"NN"},
"shirtsleeves":	{"NNS"},
"shirttail":	{"NN"},
"shirttails":	{"NNS"},
"shirtwaist":	{"NN"},
"shirtwaister":	{"NN"},
"shirty":	{"JJ"},
"shish":	{"NN"},
"shisha":	{"NN"},
"shit":	{"NN","UH","VB","VBP","VBD","VBN"},
"shite":	{"UH","NN","JJ"},
"shithead":	{"NN"},
"shitless":	{"JJ"},
"shitlist":	{"NN"},
"shitload":	{"NN"},
"shitloads":	{"NNS"},
"shits":	{"NNS","VBZ"},
"shittah":	{"NN"},
"shitted":	{"VBD","VBN"},
"shitter":	{"NN"},
"shittier":	{"JJR"},
"shittiest":	{"JJS"},
"shittily":	{"RB"},
"shittim":	{"NN"},
"shittimwood":	{"NN"},
"shittiness":	{"NN"},
"shitting":	{"VBG"},
"shitty":	{"JJ"},
"shitwork":	{"NN"},
"shiv":	{"NN"},
"shiva":	{"NN"},
"shivah":	{"NN"},
"shivaism":	{"NN"},
"shivaist":	{"NN"},
"shivaree":	{"NN"},
"shiver":	{"VB","VBP","NN"},
"shivered":	{"VBD","VBN"},
"shivering":	{"JJ","NN","VBG"},
"shivers":	{"VBZ","NNS"},
"shivery":	{"JJ"},
"shlemiel":	{"NN"},
"shlep":	{"VB","VB","NN"},
"shlepper":	{"NN"},
"shlimazel":	{"NN"},
"shlock":	{"NN"},
"shlockmeister":	{"NN"},
"shmaltz":	{"NN"},
"shmaltzy":	{"NN"},
"shmear":	{"NN"},
"shmegegge":	{"NN"},
"shmo":	{"NN"},
"shmooze":	{"NN","VB","VBP"},
"shmuck":	{"NN"},
"shnook":	{"NN"},
"shnorrer":	{"NN"},
"sho":	{"JJ","NN"},
"shoal":	{"NN","VB","VBP"},
"shoaled":	{"VBD","VBN"},
"shoaling":	{"VBG"},
"shoals":	{"NNS","VBZ"},
"shoaly":	{"JJ"},
"shoat":	{"NN"},
"shock":	{"NN","VB","VBP","JJ"},
"shock-headed":	{"JJ"},
"shock-proof":	{"JJ"},
"shockable":	{"JJ"},
"shocked":	{"VBN","JJ","VBD"},
"shocker":	{"NN"},
"shockers":	{"NNS"},
"shocking":	{"JJ","VBG"},
"shockingly":	{"RB"},
"shockley":	{"NN"},
"shockproof":	{"JJ"},
"shocks":	{"NNS","VBZ"},
"shockwave":	{"NN"},
"shod":	{"JJ","VBD","VBN"},
"shodden":	{"JJ"},
"shoddier":	{"JJR"},
"shoddiest":	{"JJS"},
"shoddily":	{"RB"},
"shoddiness":	{"NN"},
"shoddy":	{"JJ","NN"},
"shoe":	{"NN","VB","VBP"},
"shoe-horn":	{"NN"},
"shoe-horns":	{"NNS"},
"shoe-lace":	{"NN"},
"shoe-shop":	{"NN"},
"shoe-string":	{"NN","JJ"},
"shoe-strings":	{"NNS"},
"shoe-tree":	{"NN"},
"shoebill":	{"NN"},
"shoebird":	{"NN"},
"shoeblack":	{"NN"},
"shoebox":	{"NN"},
"shoeboxes":	{"NNS"},
"shoeful":	{"NN"},
"shoehorn":	{"NN","VB","VBP"},
"shoehorned":	{"VBD","VBN"},
"shoehorning":	{"VBG"},
"shoehorns":	{"NNS","VBZ"},
"shoeing":	{"VBG"},
"shoelace":	{"NN"},
"shoelaces":	{"NNS"},
"shoeless":	{"JJ"},
"shoemaker":	{"NN"},
"shoemakers":	{"NNS"},
"shoemaking":	{"NN"},
"shoes":	{"NNS","VBZ"},
"shoeshine":	{"NN"},
"shoestring":	{"NN","JJ"},
"shoestrings":	{"NNS"},
"shoetree":	{"NN"},
"shofar":	{"NN"},
"shogi":	{"NN"},
"shogun":	{"NN"},
"shogunate":	{"NN"},
"shoji":	{"NN"},
"shone":	{"VBD","VBN"},
"shoo":	{"UH","VB","VBP"},
"shoo-in":	{"NN"},
"shoo-ins":	{"NNS"},
"shooed":	{"VBD","VBN"},
"shoofly":	{"NN"},
"shooing":	{"VBG"},
"shook":	{"VBD"},
"shoos":	{"VBZ"},
"shoot":	{"VB","NN","VBP","UH"},
"shoot-down":	{"NN"},
"shoot-em-up":	{"NN"},
"shoot-em-ups":	{"NNS"},
"shoot-out":	{"NN"},
"shoot-outs":	{"NNS"},
"shooter":	{"NN"},
"shooters":	{"NNS"},
"shooting":	{"NN","VBG"},
"shooting-brake":	{"NN"},
"shooting-galleries":	{"NNS"},
"shooting-gallery":	{"NN"},
"shooting-stick":	{"NN"},
"shootings":	{"NNS"},
"shoots":	{"VBZ","NNS"},
"shop":	{"NN","VB","VBP"},
"shop-assistant":	{"NN"},
"shop-assistants":	{"NNS"},
"shop-floor":	{"NN"},
"shop-soiled":	{"JJ"},
"shop-steward":	{"NN"},
"shop-stewards":	{"NNS"},
"shopaholic":	{"NN"},
"shopaholics":	{"NNS"},
"shopfloor":	{"NN"},
"shopfront":	{"NN"},
"shophar":	{"NN"},
"shopkeeper":	{"NN"},
"shopkeepers":	{"NNS"},
"shoplift":	{"VB","VBP"},
"shoplifted":	{"VBD","VBN"},
"shoplifter":	{"NN"},
"shoplifters":	{"NNS"},
"shoplifting":	{"VBG","NN"},
"shoplifts":	{"VBZ"},
"shopowner":	{"NN"},
"shopowners":	{"NNS"},
"shopped":	{"VBD","VBN"},
"shopper":	{"NN"},
"shoppers":	{"NNS"},
"shopping":	{"NN","VBG"},
"shops":	{"NNS","VBZ"},
"shopsoiled":	{"JJ"},
"shopwalker":	{"NN"},
"shopwindow":	{"NN"},
"shopworn":	{"JJ"},
"shore":	{"NN","VB","VBP"},
"shorea":	{"NN"},
"shorebird":	{"NN"},
"shored":	{"VBD","VBN"},
"shoreline":	{"NN"},
"shorelines":	{"NNS"},
"shores":	{"NNS","VBZ"},
"shoreward":	{"JJ","RB"},
"shorewards":	{"RB"},
"shoring":	{"VBG"},
"shorn":	{"VBN","JJ"},
"short":	{"JJ","RB","NN","VB","VBP"},
"short-change":	{"VB","VBP"},
"short-changed":	{"VBD","VBN","JJ"},
"short-changes":	{"VBZ"},
"short-changing":	{"VBG"},
"short-circuit":	{"VB","VBP","NN"},
"short-circuited":	{"VBD","VBN"},
"short-circuiting":	{"VBG"},
"short-circuits":	{"VBZ","NNS"},
"short-contact":	{"JJ"},
"short-cut":	{"NN"},
"short-cuts":	{"NNS"},
"short-handed":	{"JJ"},
"short-haul":	{"JJ"},
"short-list":	{"NN","VB","VBP"},
"short-listed":	{"VBD","VBN"},
"short-listing":	{"VBG"},
"short-lists":	{"NNS","VBZ"},
"short-lived":	{"JJ"},
"short-order":	{"JJ"},
"short-range":	{"JJ"},
"short-sighted":	{"JJ"},
"short-sightedly":	{"RB"},
"short-sightedness":	{"NN"},
"short-staffed":	{"JJ"},
"short-stop":	{"NN"},
"short-stops":	{"NNS"},
"short-story":	{"NN"},
"short-tempered":	{"JJ"},
"short-term":	{"JJ","RB"},
"short-time":	{"JJ"},
"short-wave":	{"NN"},
"short-winded":	{"JJ"},
"shortage":	{"NN"},
"shortages":	{"NNS"},
"shortbread":	{"NN"},
"shortbreads":	{"NNS"},
"shortcake":	{"NN"},
"shortcoming":	{"NN"},
"shortcomings":	{"NNS"},
"shortcut":	{"NN"},
"shortcuts":	{"NNS"},
"shorted":	{"VBD","VBN"},
"shorten":	{"VB","VBP"},
"shortened":	{"VBD","VBN"},
"shortener":	{"NN"},
"shortening":	{"NN","VBG"},
"shortenings":	{"NNS"},
"shortens":	{"VBZ"},
"shorter":	{"JJR"},
"shortest":	{"JJS"},
"shortfall":	{"NN"},
"shortfalls":	{"NNS"},
"shortgrass":	{"NN"},
"shorthand":	{"NN"},
"shorthanded":	{"JJ"},
"shorthorn":	{"NN"},
"shortia":	{"NN"},
"shorting":	{"VBG"},
"shortish":	{"JJ"},
"shortlist":	{"NN","VB","VBP"},
"shortlisted":	{"VBD","VBN"},
"shortlisting":	{"VBG"},
"shortlists":	{"NNS","VBZ"},
"shortly":	{"RB"},
"shortner":	{"NN"},
"shortness":	{"NN"},
"shorts":	{"NNS","VBZ"},
"shortsighted":	{"JJ"},
"shortsightedness":	{"NN"},
"shortstop":	{"NN"},
"shortstops":	{"NNS"},
"shoshoni":	{"NN"},
"shoshonian":	{"NN"},
"shostakovich":	{"NN"},
"shot":	{"NN","JJ","VBN","VBD"},
"shot-up":	{"JJ"},
"shote":	{"NN"},
"shotgun":	{"NN"},
"shotguns":	{"NNS"},
"shots":	{"NNS"},
"should":	{"MD"},
"shoulder":	{"NN","VB","VBP"},
"shoulder-bag":	{"NN"},
"shoulder-bags":	{"NNS"},
"shoulder-blade":	{"NN"},
"shoulder-blades":	{"NNS"},
"shoulder-high":	{"JJ","RB"},
"shoulder-strap":	{"NN"},
"shoulder-straps":	{"NNS"},
"shoulder-to-shoulder":	{"RB"},
"shouldered":	{"VBD","VBN"},
"shouldering":	{"VBG"},
"shoulders":	{"NNS","VBZ"},
"shout":	{"VB","NN","VBP"},
"shout-out":	{"NN"},
"shout-outs":	{"NNS"},
"shouted":	{"VBD","VBN"},
"shouter":	{"NN"},
"shouting":	{"VBG","NN"},
"shoutout":	{"NN"},
"shoutouts":	{"NNS"},
"shouts":	{"VBZ","NNS"},
"shove":	{"VB","VBP","NN"},
"shoved":	{"VBD","VBN"},
"shovel":	{"NN","VB","VBP"},
"shovelboard":	{"NN"},
"shoveled":	{"VBD","VBN"},
"shoveler":	{"NN"},
"shovelful":	{"NN"},
"shovelfuls":	{"NNS"},
"shovelhead":	{"NN"},
"shoveling":	{"VBG"},
"shovelled":	{"VBD","VBN"},
"shoveller":	{"NN"},
"shovelling":	{"VBG"},
"shovels":	{"VBZ","NNS"},
"shover":	{"NN"},
"shoves":	{"VBZ","NNS"},
"shoving":	{"VBG"},
"show":	{"NN","VB","VBP"},
"show-biz":	{"NN"},
"show-down":	{"NN"},
"show-downs":	{"NNS"},
"show-off":	{"NN"},
"show-offs":	{"NNS"},
"show-piece":	{"NN"},
"show-pieces":	{"NNS"},
"show-stopper":	{"NN"},
"show-stoppers":	{"NNS"},
"show-stopping":	{"JJ"},
"showboat":	{"NN"},
"showcase":	{"NN","VB","VBP"},
"showcased":	{"VBD","VBN"},
"showcases":	{"VBZ","NNS"},
"showcasing":	{"VBG"},
"showdown":	{"NN"},
"showdowns":	{"NNS"},
"showed":	{"VBD"},
"shower":	{"NN","VB","VBP"},
"shower-proof":	{"JJ"},
"showered":	{"VBN","VBD"},
"showerhead":	{"NN"},
"showering":	{"VBG"},
"showers":	{"NNS","VBZ"},
"showery":	{"JJ"},
"showgirl":	{"NN"},
"showgirls":	{"NNS"},
"showground":	{"NN"},
"showgrounds":	{"NNS"},
"showier":	{"JJR"},
"showiest":	{"JJS"},
"showily":	{"RB"},
"showin":	{"NN"},
"showiness":	{"NN"},
"showing":	{"VBG","NN"},
"showings":	{"NNS"},
"showjumping":	{"NN"},
"showman":	{"NN"},
"showmanship":	{"NN"},
"showmen":	{"NNS"},
"shown":	{"VBN"},
"showpiece":	{"NN"},
"showpieces":	{"NNS"},
"showplace":	{"NN"},
"showplaces":	{"NNS"},
"showroom":	{"NN"},
"showrooms":	{"NNS"},
"shows":	{"VBZ","NNS"},
"showstopper":	{"NN"},
"showstopping":	{"JJ"},
"showtime":	{"NN"},
"showy":	{"JJ"},
"shrank":	{"VBD"},
"shrapnel":	{"NN"},
"shred":	{"NN","VB","VBP"},
"shredded":	{"VBD","VBN"},
"shredder":	{"NN"},
"shredders":	{"NNS"},
"shredding":	{"VBG"},
"shreds":	{"NNS","VBZ"},
"shreveport":	{"NN"},
"shrew":	{"NN"},
"shrewd":	{"JJ"},
"shrewder":	{"JJR"},
"shrewdest":	{"JJS"},
"shrewdly":	{"RB"},
"shrewdness":	{"NN"},
"shrewish":	{"JJ"},
"shrewishly":	{"RB"},
"shrewishness":	{"NN"},
"shrewmouse":	{"NN"},
"shrews":	{"NNS"},
"shriek":	{"VB","VBP","NN"},
"shrieked":	{"VBD","VBN"},
"shrieking":	{"NN","VBG"},
"shrieks":	{"VBZ","NNS"},
"shrift":	{"NN"},
"shrike":	{"NN"},
"shrill":	{"JJ","VB","VBP"},
"shrilled":	{"VBD","VBN"},
"shriller":	{"JJR"},
"shrillest":	{"JJS"},
"shrilling":	{"JJ","NN","VBG"},
"shrillness":	{"NN"},
"shrills":	{"VBZ"},
"shrilly":	{"RB"},
"shrimp":	{"NN","NNS","VB","VBP"},
"shrimp-fish":	{"NN"},
"shrimped":	{"VBD","VBN"},
"shrimper":	{"NN"},
"shrimpers":	{"NNS"},
"shrimpfish":	{"NN"},
"shrimping":	{"VBG","NN"},
"shrimps":	{"NNS","VBZ"},
"shrimpy":	{"JJ"},
"shrine":	{"NN","VB","VBP"},
"shrined":	{"VBD","VBN"},
"shrines":	{"NNS","VBZ"},
"shrining":	{"VBG"},
"shrink":	{"VB","VBP","NN"},
"shrink-wrap":	{"VB","VBP","NN"},
"shrink-wrapped":	{"VBD","VBN","JJ"},
"shrink-wrapping":	{"VBG"},
"shrink-wraps":	{"VBZ"},
"shrinkable":	{"JJ"},
"shrinkage":	{"NN"},
"shrinking":	{"VBG"},
"shrinks":	{"VBZ","NNS"},
"shrive":	{"VB","VBP"},
"shrived":	{"VBD","VBN"},
"shrivel":	{"VB","VBP"},
"shriveled":	{"JJ","VBD","VBN"},
"shriveling":	{"VBG"},
"shrivelled":	{"VBD","VBN","JJ"},
"shrivelling":	{"VBG"},
"shrivels":	{"VBZ","VBZ"},
"shriven":	{"VBN"},
"shrives":	{"VBZ"},
"shriving":	{"VBG"},
"shroud":	{"NN","VB","VBP"},
"shrouded":	{"VBD","VBN","JJ"},
"shrouding":	{"VBG"},
"shrouds":	{"NNS","VBZ"},
"shrove":	{"VBD"},
"shrovetide":	{"NN"},
"shrub":	{"NN"},
"shrub-covered":	{"JJ"},
"shrubberies":	{"NNS"},
"shrubbery":	{"NN"},
"shrubby":	{"JJ"},
"shrublet":	{"NN"},
"shrubs":	{"NNS"},
"shrug":	{"VB","VBP","NN"},
"shrugged":	{"VBD","VBN"},
"shrugging":	{"VBG"},
"shrugs":	{"VBZ","NNS"},
"shrunk":	{"VBD","VBN"},
"shrunken":	{"JJ"},
"shtick":	{"NN"},
"shtickl":	{"NN"},
"shtik":	{"NN"},
"shtikl":	{"NN"},
"shtup":	{"NN"},
"shu":	{"NN"},
"shua":	{"NN"},
"shuck":	{"NN","VB","VBP"},
"shucked":	{"VBD","VBN"},
"shucking":	{"VBG"},
"shucks":	{"UH","NNS","VBZ"},
"shudder":	{"VB","VBP","NN"},
"shuddered":	{"VBD","VBN"},
"shuddering":	{"JJ","VBG"},
"shudderingly":	{"RB"},
"shudders":	{"VBZ","NNS"},
"shuddery":	{"JJ"},
"shudra":	{"NN"},
"shuffle":	{"VB","VBP","NN"},
"shuffleboard":	{"NN"},
"shuffled":	{"VBD","VBN"},
"shuffler":	{"NN"},
"shuffles":	{"VBZ"},
"shuffling":	{"VBG"},
"shufti":	{"NN"},
"shuha":	{"JJ"},
"shui":	{"NN"},
"shumac":	{"NN"},
"shun":	{"VB","VBP"},
"shunned":	{"VBD","VBN"},
"shunning":	{"VBG"},
"shuns":	{"VBZ"},
"shunt":	{"VB","VBP","NN"},
"shunted":	{"VBN","VBD"},
"shunter":	{"NN"},
"shunting":	{"VBG"},
"shunts":	{"VBZ","NNS"},
"shush":	{"UH","VB","VBP"},
"shushed":	{"VBD","VBN"},
"shushes":	{"VBZ"},
"shushing":	{"VBG"},
"shut":	{"VB","VBP","VBD","VBN","JJ"},
"shut-down":	{"NN"},
"shut-downs":	{"NNS"},
"shut-eye":	{"NN"},
"shut-in":	{"NN"},
"shut-ins":	{"NNS"},
"shutdown":	{"NN"},
"shutdowns":	{"NNS"},
"shuteye":	{"NN"},
"shutoff":	{"NN"},
"shutout":	{"NN"},
"shutouts":	{"NNS"},
"shuts":	{"VBZ"},
"shutter":	{"NN","VB","VBP"},
"shutterbug":	{"NN"},
"shuttered":	{"JJ","VBD","VBN"},
"shuttering":	{"VBG"},
"shutters":	{"NNS","VBZ"},
"shutting":	{"NN","VBG"},
"shuttle":	{"NN","VB","VBP"},
"shuttlecock":	{"NN","VB","VBP"},
"shuttlecocked":	{"VBD","VBN"},
"shuttlecocking":	{"VBG"},
"shuttlecocks":	{"NNS","VBZ"},
"shuttled":	{"VBD","VBN"},
"shuttles":	{"NNS","VBZ"},
"shuttling":	{"VBG"},
"shvartze":	{"NN"},
"shwa":	{"NN"},
"shy":	{"JJ","VB","VBP","NN"},
"shyer":	{"JJR"},
"shyest":	{"JJS"},
"shying":	{"VBG"},
"shylock":	{"NN"},
"shylockian":	{"JJ"},
"shyly":	{"RB"},
"shyness":	{"NN"},
"shyster":	{"NN"},
"shysters":	{"NNS"},
"si":	{"NN"},
"sial":	{"NN"},
"sialadenitis":	{"NN"},
"sialia":	{"NN"},
"sialidae":	{"NN"},
"sialis":	{"NN"},
"sialolith":	{"NN"},
"siam":	{"NN"},
"siamang":	{"NN"},
"siamese":	{"JJ","NN"},
"sian":	{"NN"},
"sib":	{"NN"},
"siberia":	{"NN"},
"siberian":	{"JJ","NN"},
"sibilant":	{"JJ","NN"},
"sibilate":	{"VB","VBP"},
"sibilation":	{"NN"},
"sibine":	{"NN"},
"sibling":	{"NN"},
"siblings":	{"NNS"},
"sibyl":	{"NN"},
"sibyllic":	{"JJ"},
"sibylline":	{"JJ"},
"sic":	{"RB","VB","VBP"},
"sicario":	{"NN"},
"sicarios":	{"NNS"},
"siccative":	{"NN","JJ"},
"sicced":	{"VBD","VBN"},
"siccing":	{"VBG"},
"sicilia":	{"NN"},
"sicilian":	{"JJ","NN"},
"sicilians":	{"NNS"},
"sicily":	{"NN"},
"sick":	{"JJ","NN","NNS","VB","VBP"},
"sick-bay":	{"NN"},
"sick-bays":	{"NNS"},
"sick-bed":	{"NN"},
"sick-beds":	{"NNS"},
"sick-leave":	{"NN"},
"sick-pay":	{"NN"},
"sickbag":	{"NN"},
"sickbags":	{"NNS"},
"sickbay":	{"NN"},
"sickbays":	{"NNS"},
"sickbed":	{"NN"},
"sickbeds":	{"NNS"},
"sicked":	{"VBD","VBN"},
"sicken":	{"VB","VBP"},
"sickened":	{"VBN","VBD"},
"sickening":	{"JJ","VBG"},
"sickeningly":	{"RB"},
"sickeningness":	{"NN"},
"sickens":	{"VBZ"},
"sicker":	{"JJR"},
"sickest":	{"JJS"},
"sicking":	{"VBG"},
"sickish":	{"JJ"},
"sickle":	{"NN"},
"sicklepod":	{"NN"},
"sickles":	{"NNS"},
"sicklier":	{"JJR"},
"sickliest":	{"JJS"},
"sickly":	{"JJ","RB"},
"sickness":	{"NN"},
"sickroom":	{"NN"},
"sickrooms":	{"NNS"},
"sicks":	{"VBZ"},
"sics":	{"VBZ"},
"sid":	{"NN"},
"sida":	{"NN"},
"sidalcea":	{"NN"},
"siddhartha":	{"NN"},
"side":	{"NN","JJ","VB","VBP"},
"side-by-side":	{"RB","NN"},
"side-car":	{"NN"},
"side-cars":	{"NNS"},
"side-dish":	{"NN"},
"side-dishes":	{"NNS"},
"side-drum":	{"NN"},
"side-effect":	{"NN"},
"side-effects":	{"NNS"},
"side-issue":	{"NN"},
"side-issues":	{"NNS"},
"side-on":	{"JJ","RB"},
"side-road":	{"NN"},
"side-roads":	{"NNS"},
"side-saddle":	{"NN","JJ","RB"},
"side-show":	{"NN"},
"side-shows":	{"NNS"},
"side-slip":	{"NN","VB","VBP"},
"side-slipped":	{"VBD","VBN"},
"side-slipping":	{"VBG"},
"side-slips":	{"NNS","VBZ"},
"side-splitting":	{"JJ"},
"side-step":	{"VB","VBP","NN"},
"side-stepped":	{"VBD","VBN"},
"side-steps":	{"VBZ","NNS"},
"side-street":	{"NN"},
"side-streets":	{"NNS"},
"side-stroke":	{"NN"},
"side-track":	{"VB","VBP"},
"side-tracked":	{"VBD","VBN"},
"side-tracking":	{"VBG"},
"side-tracks":	{"VBZ"},
"side-view":	{"NN"},
"side-views":	{"NNS"},
"side-wheeler":	{"NN"},
"side-wheelers":	{"NNS"},
"side-whiskers":	{"NNS"},
"side-winder":	{"NN"},
"sidearm":	{"NN"},
"sidearms":	{"NNS"},
"sidebar":	{"NN"},
"sidebars":	{"NNS"},
"sideboard":	{"NN"},
"sideboards":	{"NNS"},
"sideburns":	{"NNS"},
"sidecar":	{"NN"},
"sidecars":	{"NNS"},
"sidechairs":	{"NNS"},
"sided":	{"VBD","VBN","JJ"},
"sidekick":	{"NN"},
"sidekicks":	{"NNS"},
"sidelight":	{"NN"},
"sidelights":	{"NNS"},
"sideline":	{"NN","VBP","VB"},
"sidelined":	{"VBD","VBN"},
"sidelines":	{"NNS","VBZ"},
"sidelining":	{"VBG"},
"sidelong":	{"JJ","RB"},
"sideman":	{"NN"},
"sidemen":	{"NNS"},
"sidereal":	{"JJ"},
"siderite":	{"NN"},
"sideritis":	{"NN"},
"sideroblast":	{"NN"},
"siderocyte":	{"NN"},
"sideropenia":	{"NN"},
"siderophilin":	{"NN"},
"siderosis":	{"NN"},
"sides":	{"NNS","VBZ"},
"sides-wipe":	{"NN"},
"sidesaddle":	{"NN","RB"},
"sideshow":	{"NN"},
"sideshows":	{"NNS"},
"sideslip":	{"NN"},
"sidesplitter":	{"NN"},
"sidesplitting":	{"JJ"},
"sidesplittingly":	{"RB"},
"sidestep":	{"VB","VBP","NN"},
"sidestepped":	{"VBD","VBN"},
"sidestepping":	{"VBG","NN"},
"sidesteps":	{"VBZ","NNS"},
"sidestreet":	{"NN"},
"sidestroke":	{"NN"},
"sideswipe":	{"NN","VB","VBP"},
"sideswiped":	{"VBD","VBN"},
"sideswipes":	{"NNS","VBZ"},
"sideswiping":	{"VBG"},
"sidetrack":	{"VB","VBP"},
"sidetracked":	{"VBD","VBN"},
"sidetracking":	{"VBG"},
"sidetracks":	{"VBZ"},
"sidewalk":	{"NN"},
"sidewalks":	{"NNS"},
"sidewall":	{"NN"},
"sideward":	{"JJ","RB"},
"sidewards":	{"RB"},
"sideways":	{"JJ","RB"},
"sidewinder":	{"NN"},
"sidewise":	{"RB"},
"siding":	{"NN","VBG"},
"sidings":	{"NNS"},
"sidle":	{"VB","VBP"},
"sidled":	{"VBD","VBN"},
"sidles":	{"VBZ"},
"sidling":	{"VBG"},
"sidney":	{"NN"},
"sidon":	{"NN"},
"sie":	{"NN"},
"siebel":	{"NN"},
"sieben":	{"FW"},
"siege":	{"NN","VB","VBP"},
"sieged":	{"VBD","VBN"},
"siegel":	{"NN"},
"sieges":	{"NNS","VBZ"},
"siegfried":	{"NN"},
"sieging":	{"VBG"},
"siemens":	{"NN","NNS"},
"siena":	{"NN"},
"sienna":	{"NN"},
"sierra":	{"NN"},
"sierras":	{"NNS"},
"siesta":	{"NN"},
"siestas":	{"NNS"},
"sieve":	{"NN","VB","VBP"},
"sieved":	{"VBD","VBN"},
"sieverts":	{"NNS"},
"sieves":	{"NNS","VBZ"},
"sieving":	{"VBG"},
"sif":	{"NN"},
"sift":	{"VB","VBP"},
"sifted":	{"VBD","VBN"},
"sifter":	{"NN"},
"sifters":	{"NNS"},
"sifting":	{"NN","VBG"},
"sifts":	{"VBZ"},
"sigeh":	{"NN"},
"sigh":	{"VB","VBP","NN"},
"sighed":	{"VBD","VBN"},
"sighing":	{"VBG"},
"sighs":	{"VBZ","NNS"},
"sight":	{"NN","VB","VBP"},
"sight-read":	{"VB","VBP","VBD","VBN"},
"sight-reader":	{"NN"},
"sight-readers":	{"NNS"},
"sight-reading":	{"VBG","NN"},
"sight-reads":	{"VBZ"},
"sight-seeing":	{"NN","JJ"},
"sighted":	{"JJ","VBD","VBN"},
"sightedness":	{"NN"},
"sighting":	{"NN","VBG"},
"sightings":	{"NNS"},
"sightless":	{"JJ"},
"sightlessness":	{"NN"},
"sightly":	{"JJ"},
"sights":	{"NNS","VBZ"},
"sightsaw":	{"VBD"},
"sightsee":	{"VB","VBP"},
"sightseeing":	{"VBG","NN","JJ"},
"sightseen":	{"VBN"},
"sightseer":	{"NN"},
"sightseers":	{"NNS"},
"sightsees":	{"VBZ"},
"sigint":	{"NN"},
"sigma":	{"NN"},
"sigmodon":	{"NN"},
"sigmoid":	{"JJ"},
"sigmoidal":	{"JJ"},
"sigmoidally":	{"RB"},
"sigmoidectomy":	{"NN"},
"sigmoidoscope":	{"NN"},
"sigmoidoscopy":	{"NN"},
"sign":	{"NN","VB","VBP"},
"signage":	{"NN"},
"signal":	{"NN","VB","VBP","JJ"},
"signal-box":	{"NN"},
"signal-boxes":	{"NNS"},
"signaled":	{"VBD","VBN"},
"signaler":	{"NN"},
"signalers":	{"NNS"},
"signaling":	{"NN","VBG"},
"signalisation":	{"NN"},
"signalise":	{"VB","VBP"},
"signalised":	{"VBD","VBN"},
"signalises":	{"VBZ"},
"signalising":	{"VBG"},
"signalization":	{"NN"},
"signalize":	{"VB","VBP"},
"signalized":	{"VBD","VBN"},
"signalizes":	{"VBZ"},
"signalizing":	{"VBG"},
"signalled":	{"VBD","VBN"},
"signaller":	{"NN"},
"signallers":	{"NNS"},
"signalling":	{"NN","VBG"},
"signally":	{"RB"},
"signalman":	{"NN"},
"signalmen":	{"NNS"},
"signals":	{"NNS","VBZ"},
"signatories":	{"NNS"},
"signatory":	{"NN"},
"signature":	{"NN"},
"signatures":	{"NNS"},
"signboard":	{"NN"},
"signboards":	{"NNS"},
"signed":	{"VBD","JJ","VBN"},
"signer":	{"NN"},
"signers":	{"NNS"},
"signet":	{"NN","VB","VBP"},
"signeted":	{"VBD","VBN"},
"signeting":	{"VBG"},
"signets":	{"NNS","VBZ"},
"significance":	{"NN"},
"significant":	{"JJ"},
"significantly":	{"RB"},
"signification":	{"NN"},
"significations":	{"NNS"},
"significative":	{"JJ"},
"signified":	{"VBD","VBN"},
"signifier":	{"NN"},
"signifies":	{"VBZ"},
"signify":	{"VB","VBP"},
"signifying":	{"VBG"},
"signing":	{"VBG","NN"},
"signings":	{"NNS"},
"signior":	{"NN"},
"signor":	{"NN"},
"signora":	{"NN"},
"signore":	{"NN"},
"signorina":	{"NN"},
"signory":	{"NN"},
"signpost":	{"NN","VB","VBP"},
"signposted":	{"VBD","VBN"},
"signposting":	{"VBG"},
"signposts":	{"NNS","VBZ"},
"signs":	{"NNS","VBZ"},
"sigue":	{"FW"},
"sigurd":	{"NN"},
"sigyn":	{"NN"},
"sih":	{"NN"},
"sihasapa":	{"NN"},
"sika":	{"NN"},
"sikh":	{"JJ","NN"},
"sikkim":	{"NN"},
"sikorsky":	{"NN"},
"silage":	{"NN"},
"sild":	{"NN"},
"sildenafil":	{"NN"},
"silence":	{"NN","VB","VBP"},
"silenced":	{"VBD","VBN"},
"silencer":	{"NN"},
"silencers":	{"NNS"},
"silences":	{"VBZ","NNS"},
"silencing":	{"VBG"},
"silene":	{"NN"},
"silent":	{"JJ"},
"silently":	{"RB"},
"silents":	{"NNS"},
"silenus":	{"NN"},
"silesia":	{"NN"},
"silex":	{"NN"},
"silhouette":	{"NN","VB","VBP"},
"silhouetted":	{"VBD","VBN","JJ"},
"silhouettes":	{"NNS","VBZ"},
"silica":	{"NN"},
"silicate":	{"NN"},
"silicates":	{"NNS"},
"siliceous":	{"JJ"},
"silicide":	{"NN"},
"silicious":	{"JJ"},
"silicle":	{"NN"},
"silicon":	{"NN"},
"silicone":	{"NN"},
"silicosis":	{"NN"},
"siliqua":	{"NN"},
"silique":	{"NN"},
"silk":	{"NN","VB","VBP"},
"silk-stocking":	{"JJ","NN"},
"silke":	{"NN"},
"silked":	{"VBD","VBN"},
"silken":	{"JJ"},
"silkgrass":	{"NN"},
"silkier":	{"JJR"},
"silkiest":	{"JJS"},
"silkily":	{"RB"},
"silkiness":	{"NN"},
"silking":	{"VBG"},
"silklike":	{"JJ"},
"silks":	{"NNS","VBZ"},
"silkscreen":	{"NN","VB","VBP"},
"silkweed":	{"NN"},
"silkwood":	{"NN"},
"silkworm":	{"NN"},
"silkworms":	{"NNS"},
"silky":	{"JJ"},
"sill":	{"NN"},
"sillabub":	{"NN"},
"sillaginidae":	{"NN"},
"sillago":	{"NN"},
"sillier":	{"JJR"},
"silliest":	{"JJS"},
"silliness":	{"NN"},
"sills":	{"NNS"},
"silly":	{"JJ","NN"},
"silo":	{"NN"},
"silos":	{"NNS"},
"siloxane":	{"NN"},
"silphium":	{"NN"},
"silt":	{"NN","VB","VBP"},
"silted":	{"VBD","VBN"},
"siltier":	{"JJR"},
"siltiest":	{"JJS"},
"silting":	{"VBG"},
"silts":	{"VBZ"},
"siltstone":	{"NN"},
"silty":	{"JJ"},
"silurid":	{"NN"},
"siluridae":	{"NN"},
"siluriformes":	{"NNS"},
"silurus":	{"NN"},
"silva":	{"NN"},
"silvan":	{"JJ"},
"silvanus":	{"NN"},
"silvas":	{"FW"},
"silver":	{"NN","JJ","VB","VBP"},
"silver-fish":	{"NN","NNS"},
"silver-haired":	{"JJ"},
"silver-plated":	{"JJ"},
"silver-tongued":	{"JJ"},
"silverback":	{"NN"},
"silverberry":	{"NN"},
"silvered":	{"VBD","VBN","JJ"},
"silverfish":	{"NN","NNS"},
"silverfishes":	{"NNS"},
"silvering":	{"VBG"},
"silverish":	{"JJ"},
"silverman":	{"NN"},
"silvern":	{"JJ"},
"silverpoint":	{"NN"},
"silverrod":	{"NN"},
"silvers":	{"NNS","VBZ"},
"silverside":	{"NN"},
"silversides":	{"NNS"},
"silversmith":	{"NN"},
"silversmiths":	{"NNS"},
"silverspot":	{"NN"},
"silverstein":	{"NN"},
"silversword":	{"NN"},
"silvertip":	{"NN"},
"silvervine":	{"NN"},
"silverware":	{"NN"},
"silverweed":	{"NN"},
"silverwork":	{"NN"},
"silverworker":	{"NN"},
"silvery":	{"JJ"},
"silvex":	{"NN"},
"silvia":	{"NN"},
"silviculture":	{"NN"},
"silybum":	{"NN"},
"sima":	{"NN"},
"simal":	{"NN"},
"simarouba":	{"NN"},
"simaroubaceae":	{"NN"},
"simazine":	{"NN"},
"simenon":	{"NN"},
"simeon":	{"NN"},
"simian":	{"JJ","NN"},
"similar":	{"JJ"},
"similarities":	{"NNS"},
"similarity":	{"NN"},
"similarly":	{"RB"},
"simile":	{"NN"},
"similes":	{"NNS"},
"similiar":	{"JJ"},
"similitude":	{"NN"},
"simmer":	{"VB","VBP","NN"},
"simmered":	{"VBD","VBN"},
"simmering":	{"VBG"},
"simmers":	{"VBZ"},
"simnel":	{"NN"},
"simoleons":	{"NNS"},
"simonise":	{"VB","VBP"},
"simonize":	{"VB","VBP"},
"simony":	{"NN"},
"simoom":	{"NN"},
"simoon":	{"NN"},
"simper":	{"VB","VBP","NN"},
"simpered":	{"VBD","VBN"},
"simperer":	{"NN"},
"simperers":	{"NNS"},
"simpering":	{"VBG"},
"simperingly":	{"RB"},
"simpers":	{"VBZ","NNS"},
"simple":	{"JJ","NN"},
"simple-minded":	{"JJ"},
"simple-mindedness":	{"NN"},
"simpleness":	{"NN"},
"simpler":	{"JJR"},
"simples":	{"NNS"},
"simplest":	{"JJS"},
"simpleton":	{"NN"},
"simpletons":	{"NNS"},
"simplex":	{"JJ","NN"},
"simplexes":	{"NNS"},
"simplices":	{"NNS"},
"simpliciter":	{"FW"},
"simplicitude":	{"NN"},
"simplicity":	{"NN"},
"simplification":	{"NN"},
"simplifications":	{"NNS"},
"simplified":	{"VBD","VBN","JJ"},
"simplifies":	{"VBZ"},
"simplify":	{"VB","VBP"},
"simplifying":	{"VBG"},
"simplism":	{"NN"},
"simplistic":	{"JJ"},
"simplistically":	{"RB"},
"simply":	{"RB"},
"simpson":	{"NN"},
"simulacra":	{"NNS"},
"simulacrum":	{"NN"},
"simulate":	{"VB","VBP"},
"simulated":	{"JJ","VBD","VBN"},
"simulates":	{"VBZ"},
"simulating":	{"VBG"},
"simulation":	{"NN"},
"simulations":	{"NNS"},
"simulator":	{"NN"},
"simulators":	{"NNS"},
"simulcast":	{"NN","VB","VBP","VBD","VBN"},
"simulcasting":	{"VBG"},
"simulcasts":	{"NNS","VBZ"},
"simuliidae":	{"NN"},
"simulium":	{"NN"},
"simultaneity":	{"NN"},
"simultaneous":	{"JJ"},
"simultaneously":	{"RB"},
"simultaneousness":	{"NN"},
"simvastatin":	{"NN"},
"sin":	{"NN","VB","VBP"},
"sinai":	{"NN"},
"sinanthropus":	{"NN"},
"sinapis":	{"NN"},
"sinapism":	{"NN"},
"sinatra":	{"NN"},
"since":	{"CC","IN","RB"},
"sincere":	{"JJ"},
"sincerely":	{"RB"},
"sincerity":	{"NN"},
"sinciput":	{"NN"},
"sinclair":	{"NN"},
"sind":	{"NN"},
"sindhi":	{"NN"},
"sine":	{"NN"},
"sinecure":	{"NN"},
"sinecures":	{"NNS"},
"sinequan":	{"NN"},
"sinew":	{"NN"},
"sinews":	{"NNS"},
"sinewy":	{"JJ"},
"sinful":	{"JJ"},
"sinfully":	{"RB"},
"sinfulness":	{"NN"},
"sing":	{"VB","VBP"},
"sing-song":	{"JJ","NN"},
"sing-songs":	{"NNS"},
"singa-long":	{"NN"},
"singa-longs":	{"NNS"},
"singable":	{"JJ"},
"singalong":	{"NN"},
"singalongs":	{"NNS"},
"singan":	{"NN"},
"singe":	{"VB","VBP","NN"},
"singed":	{"VBD","VBN"},
"singeing":	{"VBG"},
"singer":	{"NN"},
"singer-songwriter":	{"NN"},
"singer-songwriters":	{"NNS"},
"singers":	{"NNS"},
"singes":	{"VBZ","NNS"},
"singh":	{"NN"},
"singing":	{"VBG","NN"},
"single":	{"JJ","NN","VB","VBP"},
"single-breasted":	{"JJ"},
"single-decker":	{"NN","JJ"},
"single-deckers":	{"NNS"},
"single-foot":	{"NN","VB","VBP"},
"single-footed":	{"VBD","VBN"},
"single-footing":	{"VBG"},
"single-foots":	{"VBZ"},
"single-handed":	{"JJ","RB"},
"single-handedly":	{"RB"},
"single-market":	{"JJ","NN"},
"single-minded":	{"JJ"},
"single-mindedly":	{"RB"},
"single-mindedness":	{"NN"},
"single-parent":	{"JJ"},
"single-payer":	{"JJ"},
"single-sex":	{"JJ"},
"singled":	{"VBD","VBN"},
"singleness":	{"NN"},
"singles":	{"NNS","VBZ"},
"singlestick":	{"NN"},
"singlet":	{"NN"},
"singleton":	{"NN"},
"singlets":	{"NNS"},
"singling":	{"VBG"},
"singly":	{"RB"},
"sings":	{"VBZ"},
"singsong":	{"JJ","NN"},
"singsongs":	{"NNS"},
"singular":	{"JJ","NN"},
"singularisation":	{"NN"},
"singularise":	{"VB","VBP"},
"singularised":	{"VBD","VBN"},
"singularises":	{"VBZ"},
"singularising":	{"VBG"},
"singularities":	{"NNS"},
"singularity":	{"NN"},
"singularization":	{"NN"},
"singularize":	{"VB","VBP"},
"singularized":	{"VBD","VBN"},
"singularizes":	{"VBZ"},
"singularizing":	{"VBG"},
"singularly":	{"RB"},
"singultus":	{"NN"},
"sinister":	{"JJ"},
"sinistral":	{"JJ"},
"sinistrality":	{"NN"},
"sinistrorsal":	{"JJ"},
"sinistrorse":	{"JJ"},
"sink":	{"VB","NN","VBP","JJ"},
"sinkable":	{"JJ"},
"sinker":	{"NN"},
"sinkhole":	{"NN"},
"sinkiang":	{"NN"},
"sinking":	{"NN","JJ","VBG"},
"sinking-fund":	{"NN"},
"sinkings":	{"NNS"},
"sinks":	{"VBZ","NNS"},
"sinkt":	{"FW"},
"sinless":	{"JJ"},
"sinlessness":	{"NN"},
"sinned":	{"VBD","VBN"},
"sinner":	{"NN"},
"sinners":	{"NNS"},
"sinning":	{"VBG"},
"sinningia":	{"NN"},
"sinologist":	{"NN"},
"sinologists":	{"NNS"},
"sinology":	{"NN"},
"sinoper":	{"NN"},
"sinopia":	{"NN"},
"sinopis":	{"NN"},
"sinornis":	{"NN"},
"sins":	{"NNS","VBZ"},
"sinter":	{"NN","VB","VBP"},
"sintered":	{"VBD","VBN"},
"sintering":	{"VBG","NN"},
"sinters":	{"VBZ"},
"sinuate":	{"JJ"},
"sinuosity":	{"NN"},
"sinuous":	{"JJ"},
"sinuously":	{"RB"},
"sinuousness":	{"NN"},
"sinus":	{"NN"},
"sinuses":	{"NNS"},
"sinusitis":	{"NN"},
"sinusoid":	{"NN"},
"sinusoidal":	{"JJ"},
"sinusoidally":	{"RB"},
"sinusoids":	{"NNS"},
"siouan":	{"JJ","NN"},
"sioux":	{"NN"},
"sip":	{"VB","VBP","NN"},
"siphon":	{"NN","VB","VBP"},
"siphonaptera":	{"NN"},
"siphoned":	{"VBD","VBN"},
"siphoning":	{"VBG"},
"siphonophora":	{"NN"},
"siphonophore":	{"NN"},
"siphons":	{"VBZ","NNS"},
"sipped":	{"VBD","VBN"},
"sipper":	{"NN"},
"sippers":	{"NNS"},
"sipping":	{"NN","VBG"},
"sips":	{"VBZ","NNS"},
"sipuncula":	{"NN"},
"sipunculid":	{"NN"},
"siqueiros":	{"NNS"},
"sir":	{"NN"},
"sirach":	{"NN"},
"siracusa":	{"NN"},
"sirc":	{"NN"},
"sirdar":	{"NN"},
"sire":	{"NN","VB","VBP"},
"sired":	{"VBD","VBN"},
"siren":	{"NN"},
"sirenia":	{"NN"},
"sirenian":	{"NN"},
"sirenidae":	{"NN"},
"sirens":	{"NNS"},
"sires":	{"NNS","VBZ"},
"siriasis":	{"NN"},
"siring":	{"VBG"},
"siris":	{"NN"},
"sirius":	{"NN"},
"sirloin":	{"NN"},
"sirloins":	{"NNS"},
"sirocco":	{"NN"},
"siroccos":	{"NNS"},
"sirrah":	{"NN"},
"sirs":	{"NNS"},
"sirup":	{"NN"},
"sis":	{"NN"},
"sisal":	{"NN"},
"sise":	{"NN"},
"sisham":	{"NN"},
"siskin":	{"NN"},
"sison":	{"NN"},
"sissies":	{"NNS"},
"sissified":	{"JJ"},
"sissiness":	{"NN"},
"sissoo":	{"NN"},
"sissu":	{"NN"},
"sissy":	{"NN","JJ"},
"sissyish":	{"JJ"},
"sister":	{"NN","JJ"},
"sister-in-law":	{"NN"},
"sisterhood":	{"NN"},
"sisterlike":	{"JJ"},
"sisterly":	{"JJ"},
"sisters":	{"NNS"},
"sisters-in-law":	{"NNS"},
"sistership":	{"NN"},
"sistrurus":	{"NN"},
"sisyphean":	{"JJ"},
"sisyridae":	{"NN"},
"sisyrinchium":	{"NN"},
"sit":	{"VB","VBP"},
"sit-down":	{"NN","JJ"},
"sit-in":	{"NN"},
"sit-ins":	{"NNS"},
"sit-up":	{"NN"},
"sit-ups":	{"NNS"},
"sita":	{"NN"},
"sitar":	{"NN"},
"sitars":	{"NNS"},
"sitcom":	{"NN"},
"sitcoms":	{"NNS"},
"site":	{"NN","VB","VBP"},
"sited":	{"VBD","VBN"},
"sites":	{"NNS","VBZ"},
"siting":	{"VBG"},
"sitka":	{"NN"},
"sitophylus":	{"NN"},
"sitotroga":	{"NN"},
"sits":	{"VBZ"},
"sitsang":	{"NN"},
"sitta":	{"NN"},
"sitter":	{"NN"},
"sitters":	{"NNS"},
"sittidae":	{"NN"},
"sitting":	{"VBG","NN"},
"sittings":	{"NNS"},
"situ":	{"FW"},
"situate":	{"VB","VBP"},
"situated":	{"VBD","VBN","JJ"},
"situates":	{"VBZ"},
"situating":	{"VBG"},
"situation":	{"NN"},
"situations":	{"NNS"},
"situs":	{"NN","NNS"},
"sitwell":	{"NN"},
"sium":	{"NN"},
"siva":	{"NN"},
"sivaism":	{"NN"},
"sivapithecus":	{"NN"},
"siwan":	{"NN"},
"six":	{"CD","NN"},
"six-figure":	{"JJ"},
"six-footer":	{"NN"},
"six-footers":	{"NNS"},
"six-pack":	{"NN"},
"six-packs":	{"NNS"},
"six-shooter":	{"NN"},
"six-shooters":	{"NNS"},
"sixer":	{"NN"},
"sixfold":	{"RB","JJ"},
"sixpence":	{"NN"},
"sixpences":	{"NNS"},
"sixpenny":	{"JJ"},
"sixsome":	{"NN"},
"sixteen":	{"CD","NN"},
"sixteenth":	{"JJ","NN"},
"sixth":	{"JJ","NN"},
"sixth-form":	{"NN"},
"sixth-former":	{"NN"},
"sixth-formers":	{"NNS"},
"sixth-forms":	{"NNS"},
"sixthly":	{"RB"},
"sixties":	{"NNS"},
"sixtieth":	{"NN","JJ"},
"sixty":	{"NN","CD"},
"sizable":	{"JJ"},
"size":	{"NN","VBP","VB"},
"sizeable":	{"JJ"},
"sizeableness":	{"NN"},
"sized":	{"VBD","VBN","JJ"},
"sizenine":	{"JJ"},
"sizes":	{"NNS","VBZ"},
"sizing":	{"NN","VBG"},
"sizzle":	{"VB","VBP","NN"},
"sizzled":	{"VBD","VBN"},
"sizzles":	{"VBZ"},
"sizzling":	{"VBG","JJ"},
"sk-ampicillin":	{"NN"},
"skag":	{"NN"},
"skagerak":	{"NN"},
"skagerrak":	{"NN"},
"skagit":	{"NN"},
"skagway":	{"NN"},
"skanda":	{"NN"},
"skank":	{"NN"},
"skanky":	{"JJ"},
"skate":	{"NN","VB","VBP","NNS"},
"skateboard":	{"NN","VB","VBP"},
"skateboarded":	{"VBD","VBN"},
"skateboarder":	{"NN"},
"skateboarders":	{"NNS"},
"skateboarding":	{"NN","VBG"},
"skateboards":	{"NNS","VBZ"},
"skated":	{"VBD","VBN"},
"skater":	{"NN"},
"skaters":	{"NNS"},
"skates":	{"NNS","VBZ"},
"skating":	{"VBG","NN"},
"skating-rink":	{"NN"},
"skating-rinks":	{"NNS"},
"skaw":	{"NN"},
"skeat":	{"NN"},
"skedaddle":	{"VB","VBP"},
"skedaddled":	{"VBD","VBN"},
"skedaddles":	{"VBZ"},
"skedaddling":	{"VBG"},
"skeet":	{"NN"},
"skeg":	{"NN"},
"skein":	{"NN"},
"skeins":	{"NNS"},
"skeletal":	{"JJ"},
"skeleton":	{"NN","JJ"},
"skeletons":	{"NNS"},
"skep":	{"NN"},
"skepful":	{"NN"},
"skeptic":	{"NN","JJ"},
"skeptical":	{"JJ"},
"skeptically":	{"RB"},
"skepticism":	{"NN"},
"skeptics":	{"NNS"},
"sketch":	{"NN","VB","VBP"},
"sketch-book":	{"NN"},
"sketch-books":	{"NNS"},
"sketch-map":	{"NN"},
"sketch-maps":	{"NNS"},
"sketch-pad":	{"NN"},
"sketch-pads":	{"NNS"},
"sketchbook":	{"NN"},
"sketchbooks":	{"NNS"},
"sketched":	{"VBD","VBN"},
"sketcher":	{"NN"},
"sketches":	{"NNS","VBZ"},
"sketchier":	{"JJR"},
"sketchiest":	{"JJS"},
"sketchily":	{"RB"},
"sketchiness":	{"NN"},
"sketching":	{"VBG"},
"sketchy":	{"JJ"},
"skew":	{"VB","VBP","JJ","NN"},
"skew-whiff":	{"JJ"},
"skewed":	{"VBD","VBN","JJ"},
"skewer":	{"NN","VB","VBP"},
"skewered":	{"VBD","VBN"},
"skewering":	{"VBG"},
"skewers":	{"NNS","VBZ"},
"skewing":	{"VBG"},
"skewness":	{"NN"},
"skews":	{"VBZ"},
"ski":	{"NN","VB","JJ","VBP"},
"ski-bob":	{"NN"},
"ski-bobs":	{"NNS"},
"ski-joring":	{"NN"},
"ski-jump":	{"NN"},
"ski-jumping":	{"NN"},
"ski-jumps":	{"NNS"},
"ski-lift":	{"NN"},
"ski-lifts":	{"NNS"},
"ski-plane":	{"NN"},
"ski-planes":	{"NNS"},
"skiagram":	{"NN"},
"skiagraph":	{"NN"},
"skiagraphy":	{"NN"},
"skibob":	{"NN"},
"skid":	{"NN","VB","VBP"},
"skid-pan":	{"NN"},
"skid-row":	{"NN"},
"skidded":	{"VBD","VBN"},
"skidder":	{"NN"},
"skidding":	{"VBG"},
"skiddy":	{"JJ"},
"skidpan":	{"NN"},
"skids":	{"NNS","VBZ"},
"skied":	{"VBD","VBN"},
"skier":	{"NN"},
"skiers":	{"NNS"},
"skies":	{"NNS","VBZ"},
"skiff":	{"NN"},
"skiffle":	{"NN"},
"skiffs":	{"NNS"},
"skiing":	{"NN","VBG"},
"skilfully":	{"RB"},
"skill":	{"NN"},
"skill-dilution":	{"JJ"},
"skilled":	{"JJ"},
"skillet":	{"NN"},
"skilletfish":	{"NN"},
"skillets":	{"NNS"},
"skillful":	{"JJ"},
"skillfully":	{"RB"},
"skillfulness":	{"NN"},
"skills":	{"NNS"},
"skilly":	{"NN"},
"skim":	{"VB","VBP"},
"skim-milk":	{"NN"},
"skimmed":	{"VBD","VBN"},
"skimmer":	{"NN"},
"skimmers":	{"NNS"},
"skimming":	{"VBG"},
"skimp":	{"VB","VBP"},
"skimped":	{"VBD","VBN"},
"skimpier":	{"JJR"},
"skimpiest":	{"JJS"},
"skimpily":	{"RB"},
"skimpiness":	{"NN"},
"skimping":	{"VBG"},
"skimps":	{"VBZ"},
"skimpy":	{"JJ"},
"skims":	{"VBZ"},
"skin":	{"NN","VBP","VB"},
"skin-care":	{"NN"},
"skin-deep":	{"JJ"},
"skin-dive":	{"NN","VB"},
"skin-diver":	{"NN"},
"skin-diving":	{"NN"},
"skin-flick":	{"NN"},
"skin-graft":	{"NN"},
"skin-tight":	{"JJ"},
"skincare":	{"NN"},
"skinflint":	{"NN"},
"skinflints":	{"NNS"},
"skinful":	{"NN"},
"skinhead":	{"NN"},
"skinheads":	{"NNS"},
"skink":	{"NN"},
"skinless":	{"JJ"},
"skinned":	{"JJ","VBD","VBN"},
"skinner":	{"NN"},
"skinnerian":	{"JJ","NN"},
"skinnerish":	{"JJ"},
"skinnier":	{"JJR"},
"skinniest":	{"JJS"},
"skinnin":	{"NN"},
"skinniness":	{"NN"},
"skinning":	{"VBG"},
"skinny":	{"JJ"},
"skinny-dip":	{"VB","VBP"},
"skinny-dipped":	{"VBD","VBN"},
"skinny-dipper":	{"NN"},
"skinny-dipping":	{"VBG","NN"},
"skinny-dips":	{"VBZ"},
"skins":	{"NNS","VBZ"},
"skint":	{"JJ"},
"skintight":	{"JJ"},
"skip":	{"VB","NN","VBP"},
"skipjack":	{"NN","NNS"},
"skipjacks":	{"NNS"},
"skipped":	{"VBD","VBN"},
"skipper":	{"NN","VB","VBP"},
"skippered":	{"VBD","VBN"},
"skippering":	{"VBG"},
"skippers":	{"NNS","VBZ"},
"skipping":	{"VBG"},
"skips":	{"VBZ","NNS"},
"skirl":	{"VB","VBP","NN"},
"skirled":	{"VBD","VBN"},
"skirling":	{"VBG"},
"skirls":	{"VBZ"},
"skirmish":	{"NN","VB","VBP"},
"skirmished":	{"VBD","VBN"},
"skirmisher":	{"NN"},
"skirmishers":	{"NNS"},
"skirmishes":	{"NNS","VBZ"},
"skirmishing":	{"NN","VBG"},
"skirret":	{"NN"},
"skirt":	{"NN","VB","VBP"},
"skirted":	{"VBD","VBN"},
"skirting":	{"NN","VBG"},
"skirting-board":	{"NN"},
"skirting-boards":	{"NNS"},
"skirtings":	{"NNS"},
"skirts":	{"NNS","VBZ"},
"skis":	{"NNS","VBZ"},
"skit":	{"NN"},
"skits":	{"NNS"},
"skitter":	{"VB","VBP"},
"skittered":	{"VBD","VBN"},
"skittering":	{"VBG"},
"skitters":	{"VBZ"},
"skittish":	{"JJ"},
"skittishly":	{"RB"},
"skittishness":	{"NN"},
"skittle":	{"NN","VB","VBP"},
"skittled":	{"VBD","VBN"},
"skittles":	{"NNS","VBZ"},
"skittling":	{"VBG"},
"skive":	{"VB","VBP"},
"skived":	{"VBD","VBN"},
"skiver":	{"NN"},
"skivers":	{"NNS"},
"skives":	{"VBZ"},
"skiving":	{"VBG"},
"skivvied":	{"VBD","VBN"},
"skivvies":	{"NNS","VBZ"},
"skivvy":	{"NN","VB","VBP"},
"skivvying":	{"VBG"},
"skopos":	{"NN"},
"skua":	{"NN"},
"skuld":	{"NN"},
"skulduggery":	{"NN"},
"skulk":	{"VB","VBP"},
"skulked":	{"VBD","VBN"},
"skulker":	{"NN"},
"skulkers":	{"NNS"},
"skulking":	{"VBG"},
"skulks":	{"VBZ"},
"skull":	{"NN"},
"skull-and-crossbones":	{"NN"},
"skull-cap":	{"NN"},
"skull-caps":	{"NNS"},
"skullcap":	{"NN"},
"skullcaps":	{"NNS"},
"skullduggery":	{"NN"},
"skulls":	{"NNS"},
"skunk":	{"NN","VB","VBP"},
"skunk-weed":	{"NN"},
"skunkbush":	{"NN"},
"skunked":	{"VBD","VBN"},
"skunking":	{"VBG"},
"skunks":	{"NNS","VBZ"},
"skunkweed":	{"NN"},
"sky":	{"NN","VB","VBP"},
"sky-blue":	{"JJ","NN"},
"sky-diver":	{"NN"},
"sky-divers":	{"NNS"},
"sky-diving":	{"NN"},
"sky-high":	{"JJ","RB"},
"sky-rocket":	{"VB","VBP"},
"sky-rocketed":	{"VBD","VBN"},
"sky-rocketing":	{"VBG"},
"sky-rockets":	{"VBZ"},
"sky-writing":	{"NN"},
"skybolt":	{"NN"},
"skybox":	{"NN"},
"skycap":	{"NN"},
"skycaps":	{"NNS"},
"skydive":	{"VB","VBP"},
"skydiver":	{"NN"},
"skydivers":	{"NNS"},
"skydiving":	{"NN"},
"skye":	{"NN"},
"skyhook":	{"NN"},
"skying":	{"VBG"},
"skyjack":	{"VB","VBP"},
"skyjacked":	{"VBD","VBN"},
"skyjacker":	{"NN"},
"skyjackers":	{"NNS"},
"skyjacking":	{"VBG"},
"skyjacks":	{"VBZ"},
"skylab":	{"NN"},
"skylark":	{"NN","VB","VBP"},
"skylarked":	{"VBD","VBN"},
"skylarking":	{"VBG"},
"skylarks":	{"NNS","VBZ"},
"skylight":	{"NN"},
"skylights":	{"NNS"},
"skyline":	{"NN"},
"skylines":	{"NNS"},
"skyrocket":	{"VB","VBP"},
"skyrocketed":	{"VBD","VBN"},
"skyrocketing":	{"VBG"},
"skyrockets":	{"VBZ"},
"skysail":	{"NN"},
"skyscraper":	{"NN"},
"skyscrapers":	{"NNS"},
"skywalk":	{"NN"},
"skyward":	{"JJ","RB"},
"skywards":	{"RB"},
"skywave":	{"NN"},
"skyway":	{"NN"},
"skywriting":	{"NN"},
"sl":	{"NN"},
"slab":	{"NN"},
"slabber":	{"VB","VBP"},
"slabs":	{"NNS"},
"slack":	{"JJ","VB","VBP","NN"},
"slacked":	{"VBD","VBN"},
"slacken":	{"VB","VBP"},
"slackened":	{"VBD","VBN"},
"slackening":	{"VBG","NN"},
"slackens":	{"VBZ"},
"slacker":	{"JJR"},
"slackest":	{"JJS"},
"slacking":	{"VBG","JJ","NN"},
"slackly":	{"RB"},
"slackness":	{"NN"},
"slacks":	{"NNS","VBZ"},
"sladang":	{"NN"},
"slag":	{"NN","VB","VBP"},
"slag-heap":	{"NN"},
"slag-heaps":	{"NNS"},
"slagged":	{"VBD","VBN"},
"slagging":	{"VBG"},
"slagheap":	{"NN"},
"slagheaps":	{"NNS"},
"slags":	{"NNS","VBZ"},
"slain":	{"VBN"},
"slake":	{"VB","VBP"},
"slaked":	{"VBD","VBN"},
"slakes":	{"VBZ"},
"slaking":	{"VBG"},
"slalom":	{"NN"},
"slaloms":	{"NNS"},
"slam":	{"VB","VBP","NN"},
"slam-bang":	{"JJ","RB"},
"slam-dunk":	{"NN","VB","VBP"},
"slam-dunked":	{"VBD","VBN"},
"slam-dunking":	{"VBG"},
"slam-dunks":	{"NNS","VBZ"},
"slammed":	{"VBD","VBN"},
"slammer":	{"NN"},
"slamming":	{"VBG"},
"slams":	{"VBZ"},
"slander":	{"NN","VB","VBP"},
"slandered":	{"VBD","VBN"},
"slanderer":	{"NN"},
"slanderers":	{"NNS"},
"slandering":	{"VBG"},
"slanderous":	{"JJ"},
"slanderously":	{"RB"},
"slanders":	{"NNS","VBZ"},
"slang":	{"NN","VB","VBP"},
"slanged":	{"VBD","VBN"},
"slangily":	{"RB"},
"slanginess":	{"NN"},
"slanging":	{"VBG"},
"slangs":	{"VBZ"},
"slanguage":	{"NN"},
"slangy":	{"JJ"},
"slant":	{"VB","VBP","NN"},
"slanted":	{"JJ","VBD","VBN"},
"slanting":	{"VBG"},
"slantingly":	{"RB"},
"slants":	{"VBZ","NNS"},
"slantways":	{"RB","JJ"},
"slantwise":	{"RB","JJ"},
"slap":	{"VB","VBP","NN","RB"},
"slap-bang":	{"RB"},
"slap-up":	{"JJ"},
"slapdash":	{"JJ","RB"},
"slaphappy":	{"JJ"},
"slapped":	{"VBD","VBN"},
"slapper":	{"NN"},
"slappers":	{"NNS"},
"slapping":	{"VBG"},
"slaps":	{"VBZ","NNS"},
"slapshot":	{"NN"},
"slapstick":	{"NN"},
"slash":	{"VB","VBP","NN"},
"slashed":	{"VBD","VBN"},
"slasher":	{"NN","JJ"},
"slashes":	{"VBZ","NNS"},
"slashing":	{"VBG","JJ","NN"},
"slask":	{"NN"},
"slat":	{"NN","VB","VBP"},
"slate":	{"NN","VB","VBP"},
"slate-grey":	{"JJ","NN"},
"slated":	{"VBN","VBD"},
"slater":	{"NN"},
"slates":	{"VBZ"},
"slatey":	{"JJ"},
"slather":	{"VB","VBP"},
"slathered":	{"VBD","VBN"},
"slathering":	{"VBG"},
"slathers":	{"VBZ"},
"slating":	{"NN","VBG"},
"slats":	{"NNS","VBZ"},
"slatted":	{"JJ","VBD","VBN"},
"slattern":	{"NN"},
"slatternliness":	{"NN"},
"slatternly":	{"JJ"},
"slatterns":	{"NNS"},
"slatting":	{"VBG"},
"slaty":	{"JJ"},
"slaughter":	{"NN","VB","VBP"},
"slaughtered":	{"VBD","VBN","JJ"},
"slaughterer":	{"NN"},
"slaughterhouse":	{"NN"},
"slaughterhouses":	{"NNS"},
"slaughtering":	{"VBG"},
"slaughterous":	{"JJ"},
"slaughters":	{"NNS","VBZ"},
"slave":	{"NN","VBP","VB"},
"slave-driver":	{"NN"},
"slave-drivers":	{"NNS"},
"slave-owners":	{"NNS"},
"slave-trade":	{"NN"},
"slave-traffic":	{"NN"},
"slaved":	{"VBD","VBN"},
"slaveholder":	{"NN"},
"slaveholders":	{"NNS"},
"slaveholding":	{"JJ","NN"},
"slaveless":	{"JJ"},
"slavelike":	{"JJ"},
"slaveowner":	{"NN"},
"slaveowners":	{"NNS"},
"slaver":	{"VB","VBP","NN"},
"slavered":	{"VBD","VBN"},
"slavering":	{"VBG"},
"slavers":	{"VBZ","NNS"},
"slavery":	{"NN"},
"slaves":	{"NNS","VBZ"},
"slavey":	{"NN"},
"slavic":	{"JJ","NN"},
"slaving":	{"VBG"},
"slavish":	{"JJ"},
"slavishly":	{"RB"},
"slavishness":	{"NN"},
"slaw":	{"NN"},
"slay":	{"VB","VBP"},
"slayer":	{"NN"},
"slayers":	{"NNS"},
"slaying":	{"VBG","NN"},
"slayings":	{"NNS"},
"slays":	{"VBZ"},
"sle":	{"NN"},
"sleaze":	{"NN"},
"sleazebag":	{"NN"},
"sleazier":	{"JJR"},
"sleaziest":	{"JJS"},
"sleazily":	{"RB"},
"sleaziness":	{"NN"},
"sleazy":	{"JJ"},
"sled":	{"NN","VB","VBP"},
"sledded":	{"VBD","VBN"},
"sledder":	{"NN"},
"sledding":	{"NN","VBG"},
"sledge":	{"NN","VBP","VB"},
"sledge-hammer":	{"NN","VB","VBP"},
"sledge-hammered":	{"VBD","VBN"},
"sledge-hammering":	{"VBG"},
"sledge-hammers":	{"NNS","VBZ"},
"sledged":	{"VBD","VBN"},
"sledgehammer":	{"NN","VB","VBP"},
"sledgehammered":	{"VBD","VBN"},
"sledgehammering":	{"VBG"},
"sledgehammers":	{"NNS","VBZ"},
"sledges":	{"NNS","VBZ"},
"sledging":	{"VBG"},
"sleds":	{"NNS","VBZ"},
"sleek":	{"JJ","VBP","VB"},
"sleek-headed":	{"JJ"},
"sleeked":	{"VBD","VBN"},
"sleeker":	{"JJR"},
"sleekest":	{"JJS"},
"sleeking":	{"VBG"},
"sleekly":	{"RB"},
"sleekness":	{"NN"},
"sleeks":	{"VBZ"},
"sleep":	{"NN","VB","VBP"},
"sleep-over":	{"NN"},
"sleep-overs":	{"NNS"},
"sleepaway":	{"JJ","NN"},
"sleepaways":	{"NNS"},
"sleeper":	{"NN"},
"sleepers":	{"NNS"},
"sleepier":	{"JJR"},
"sleepiest":	{"JJS"},
"sleepily":	{"RB"},
"sleepiness":	{"NN"},
"sleeping":	{"VBG","NN","JJ"},
"sleeping-bag":	{"NN"},
"sleeping-bags":	{"NNS"},
"sleeping-car":	{"NN"},
"sleeping-cars":	{"NNS"},
"sleeping-pill":	{"NN"},
"sleeping-pills":	{"NNS"},
"sleepless":	{"JJ"},
"sleeplessly":	{"RB"},
"sleeplessness":	{"NN"},
"sleepover":	{"NN"},
"sleepovers":	{"NNS"},
"sleeps":	{"VBZ","NNS"},
"sleepwalk":	{"NN","VB","VBP"},
"sleepwalked":	{"VBD","VBN"},
"sleepwalker":	{"NN"},
"sleepwalkers":	{"NNS"},
"sleepwalking":	{"NN","VBG"},
"sleepwalks":	{"VBZ"},
"sleepwear":	{"NN"},
"sleepy":	{"JJ"},
"sleepyhead":	{"NN"},
"sleepyheaded":	{"JJ"},
"sleepyheads":	{"NNS"},
"sleet":	{"NN","VB","VBP"},
"sleeted":	{"VBD","VBN"},
"sleeting":	{"VBG"},
"sleets":	{"VBZ"},
"sleety":	{"JJ"},
"sleeve":	{"NN"},
"sleeveless":	{"JJ"},
"sleeves":	{"NNS"},
"sleigh":	{"NN","VB","VBP"},
"sleighed":	{"VBD","VBN"},
"sleighing":	{"VBG"},
"sleighs":	{"NNS","VBZ"},
"sleight":	{"NN"},
"slender":	{"JJ"},
"slenderer":	{"JJR"},
"slenderest":	{"JJS"},
"slenderise":	{"VB","VBP"},
"slenderize":	{"VB","VBP"},
"slenderly":	{"RB"},
"slenderness":	{"NN"},
"slept":	{"VBD","VBN"},
"sleuth":	{"NN","VB","VBP"},
"sleuthed":	{"VBD","VBN"},
"sleuthhound":	{"NN"},
"sleuthing":	{"NN","VBG"},
"sleuths":	{"NNS","VBZ"},
"slew":	{"VBP","VB","VBD","NN"},
"slewed":	{"VBD","VBN"},
"slewing":	{"VBG"},
"slews":	{"VBZ"},
"slezsko":	{"NN"},
"slice":	{"NN","VB","VBP"},
"sliced":	{"VBD","VBN","JJ"},
"slicer":	{"NN"},
"slicers":	{"NNS"},
"slices":	{"NNS","VBZ"},
"slicing":	{"VBG"},
"slick":	{"JJ","NN","VB","VBP"},
"slicked":	{"VBD","VBN"},
"slicker":	{"NN","JJR"},
"slickers":	{"NNS"},
"slickest":	{"JJS"},
"slicking":	{"VBG"},
"slickly":	{"RB"},
"slickness":	{"NN"},
"slicks":	{"NNS","VBZ"},
"slid":	{"VBD","VBN"},
"slide":	{"NN","VB","VBP"},
"slide-rule":	{"NN"},
"slide-rules":	{"NNS"},
"slider":	{"NN"},
"slides":	{"NNS","VBZ"},
"slideway":	{"NN"},
"sliding":	{"VBG"},
"slight":	{"JJ","VB","VBP","NN"},
"slighted":	{"VBD","VBN"},
"slighter":	{"JJR"},
"slightest":	{"JJS"},
"slighting":	{"JJ","VBG"},
"slightingly":	{"RB"},
"slightly":	{"RB"},
"slightness":	{"NN"},
"slights":	{"VBZ","NNS"},
"slim":	{"JJ","VB","VBP"},
"slime":	{"NN","VB","VBP"},
"slimed":	{"VBD","VBN"},
"slimes":	{"VBZ"},
"slimier":	{"JJR"},
"slimiest":	{"JJS"},
"sliminess":	{"NN"},
"sliming":	{"VBG"},
"slimly":	{"RB"},
"slimmed":	{"VBD","VBN"},
"slimmed-down":	{"JJ"},
"slimmer":	{"JJR","NN"},
"slimmers":	{"NNS"},
"slimmest":	{"JJS"},
"slimming":	{"VBG","NN","JJ"},
"slimness":	{"NN"},
"slims":	{"VBZ"},
"slimy":	{"JJ"},
"sling":	{"NN","VB","VBP"},
"slingback":	{"NN"},
"slinger":	{"NN"},
"slingers":	{"NNS"},
"slinging":	{"NN","VBG"},
"slings":	{"NNS","VBZ"},
"slingshot":	{"NN"},
"slingshots":	{"NNS"},
"slink":	{"VB","VBP"},
"slinkier":	{"JJR"},
"slinkiest":	{"JJS"},
"slinkiness":	{"NN"},
"slinking":	{"VBG"},
"slinkingly":	{"RB"},
"slinks":	{"VBZ"},
"slinky":	{"JJ"},
"slip":	{"NN","VB","VBP"},
"slip-case":	{"NN"},
"slip-on":	{"JJ","NN"},
"slip-ons":	{"NNS"},
"slip-over":	{"NN","JJ"},
"slip-road":	{"NN"},
"slip-roads":	{"NNS"},
"slip-up":	{"NN"},
"slip-ups":	{"NNS"},
"slipcover":	{"NN"},
"slipcovers":	{"NNS"},
"slipknot":	{"NN"},
"slipknots":	{"NNS"},
"slipover":	{"NN"},
"slippage":	{"NN"},
"slippages":	{"NNS"},
"slipped":	{"VBD","VBN"},
"slipper":	{"NN"},
"slippered":	{"JJ"},
"slipperier":	{"JJR"},
"slipperiest":	{"JJS"},
"slipperiness":	{"NN"},
"slippers":	{"NNS"},
"slipperwort":	{"NN"},
"slippery":	{"JJ"},
"slippier":	{"JJR"},
"slippiest":	{"JJS"},
"slipping":	{"VBG"},
"slippy":	{"JJ"},
"slips":	{"NNS","VBZ"},
"slipshod":	{"JJ"},
"slipstick":	{"NN"},
"slipstream":	{"NN"},
"slipway":	{"NN"},
"slipways":	{"NNS"},
"slit":	{"VB","VBP","NN","VBD","VBN"},
"slither":	{"VB","VBP"},
"slithered":	{"VBD","VBN"},
"slithering":	{"VBG"},
"slithers":	{"VBZ"},
"slithery":	{"JJ"},
"slits":	{"VBZ","NNS"},
"slitter":	{"NN"},
"slitters":	{"NNS"},
"slitting":	{"VBG"},
"sliver":	{"NN","VB","VBP"},
"slivered":	{"VBD","VBN"},
"slivering":	{"VBG"},
"slivers":	{"NNS","VBZ"},
"slivery":	{"JJ"},
"slivovitz":	{"NN"},
"slo-bid":	{"NN"},
"slo-mo":	{"JJ","NN"},
"sloanea":	{"NN"},
"slob":	{"NN","VB","VBP"},
"slobbed":	{"VBD","VBN"},
"slobber":	{"VB","VBP","NN"},
"slobbered":	{"VBD","VBN"},
"slobberer":	{"NN"},
"slobbering":	{"VBG"},
"slobbers":	{"VBZ"},
"slobbery":	{"JJ"},
"slobbing":	{"VBG"},
"slobs":	{"NNS","VBZ"},
"slocum":	{"NN"},
"sloe":	{"NN"},
"sloes":	{"NNS"},
"slog":	{"VB","VBP","NN"},
"slogan":	{"NN"},
"sloganeer":	{"NN","VB","VBP"},
"sloganeered":	{"VBD","VBN"},
"sloganeering":	{"VBG","NN"},
"sloganeers":	{"NNS","VBZ"},
"slogans":	{"NNS"},
"slogged":	{"VBD","VBN"},
"slogger":	{"NN"},
"sloggers":	{"NNS"},
"slogging":	{"VBG"},
"slogs":	{"VBZ"},
"sloop":	{"NN"},
"sloops":	{"NNS"},
"slop":	{"VB","VBP","NN"},
"slop-bucket":	{"NN"},
"slop-seller":	{"NN"},
"slope":	{"NN","VB","VBP"},
"sloped":	{"VBD","VBN"},
"slopes":	{"VBZ","NNS"},
"sloping":	{"JJ","VBG"},
"slopingly":	{"RB"},
"slopped":	{"VBD","VBN"},
"sloppier":	{"JJR"},
"sloppiest":	{"JJS"},
"sloppily":	{"RB"},
"sloppiness":	{"NN"},
"slopping":	{"VBG"},
"slopping-out":	{"NN"},
"sloppy":	{"JJ"},
"slops":	{"NNS","VBZ"},
"slopseller":	{"NN"},
"slopshop":	{"NN"},
"slosh":	{"VB","VBP"},
"sloshed":	{"JJ","VBD","VBN"},
"sloshes":	{"VBZ"},
"sloshing":	{"VBG"},
"slot":	{"NN","VB","VBP"},
"slot-machine":	{"NN"},
"slot-machines":	{"NNS"},
"sloth":	{"NN"},
"slothful":	{"JJ"},
"slothfulness":	{"NN"},
"sloths":	{"NNS"},
"slots":	{"NNS","VBZ"},
"slotted":	{"VBN","VBD","JJ"},
"slotting":	{"VBG"},
"slouch":	{"VB","VBP","NN"},
"slouched":	{"VBD","VBN"},
"sloucher":	{"NN"},
"slouches":	{"VBZ"},
"slouchily":	{"RB"},
"slouching":	{"VBG"},
"slouchingly":	{"RB"},
"slouchy":	{"JJ"},
"slough":	{"NN","VB","VBP"},
"sloughed":	{"VBD","VBN"},
"sloughing":	{"VBG"},
"sloughs":	{"NNS","VBZ"},
"sloughy":	{"JJ"},
"slovakia":	{"NN"},
"sloven":	{"NN"},
"slovene":	{"NN"},
"slovenia":	{"NN"},
"slovenian":	{"JJ","NN"},
"slovenija":	{"NN"},
"slovenliness":	{"NN"},
"slovenly":	{"JJ"},
"slow":	{"JJ","VB","VBP","RB"},
"slow-down":	{"NN"},
"slow-downs":	{"NNS"},
"slow-motion":	{"JJ"},
"slow-witted":	{"JJ"},
"slow-wittedness":	{"NN"},
"slowball":	{"NN"},
"slowcoach":	{"NN"},
"slowdown":	{"NN"},
"slowdowns":	{"NNS"},
"slowed":	{"VBD","VBN"},
"slower":	{"JJR","RBR"},
"slowest":	{"JJS","RBS"},
"slowing":	{"VBG"},
"slowly":	{"RB"},
"slowness":	{"NN"},
"slowpoke":	{"NN"},
"slows":	{"VBZ"},
"slowworm":	{"NN"},
"sls":	{"NN"},
"slub":	{"NN","VB","VBP","JJ"},
"slubbed":	{"VBD","VBN"},
"slubbing":	{"VBG"},
"slubs":	{"NNS","VBZ"},
"sludge":	{"NN"},
"sludge-covered":	{"JJ"},
"sludges":	{"NNS"},
"sludgier":	{"JJR"},
"sludgiest":	{"JJS"},
"sludgy":	{"JJ"},
"slue":	{"VB","VBP","NN"},
"slug":	{"NN","VB","VBP"},
"slugabed":	{"NN"},
"slugfest":	{"NN"},
"sluggard":	{"NN","JJ"},
"sluggardliness":	{"NN"},
"sluggardly":	{"RB"},
"sluggardness":	{"NN"},
"slugged":	{"VBD","VBN"},
"slugger":	{"NN"},
"sluggers":	{"NNS"},
"slugging":	{"VBG"},
"sluggish":	{"JJ"},
"sluggishly":	{"RB"},
"sluggishness":	{"NN"},
"slugline":	{"NN"},
"sluglines":	{"NNS"},
"slugs":	{"NNS","VBZ"},
"sluice":	{"NN","VB","VBP"},
"sluiced":	{"VBD","VBN"},
"sluicegate":	{"NN"},
"sluicehouse":	{"NN"},
"sluices":	{"NNS","VBZ"},
"sluiceway":	{"NN"},
"sluicing":	{"VBG"},
"slum":	{"NN","VB","VBP"},
"slumber":	{"VB","VBP","NN"},
"slumbered":	{"VBD","VBN"},
"slumberer":	{"NN"},
"slumberers":	{"NNS"},
"slumbering":	{"VBG"},
"slumberous":	{"JJ"},
"slumbers":	{"VBZ","NNS"},
"slumbery":	{"JJ"},
"slumgullion":	{"NN"},
"slumlord":	{"NN"},
"slummed":	{"VBD","VBN"},
"slummier":	{"JJR"},
"slummiest":	{"JJS"},
"slumming":	{"VBG"},
"slummy":	{"JJ"},
"slump":	{"VB","VBP","NN"},
"slumped":	{"VBD","VBN"},
"slumping":	{"VBG"},
"slumps":	{"NNS","VBZ"},
"slums":	{"VBZ","NNS"},
"slung":	{"VBD","VBN"},
"slunk":	{"VBD","VBN"},
"slur":	{"VB","VBP","NN"},
"slurp":	{"VB","VBP","NN"},
"slurped":	{"VBD","VBN"},
"slurping":	{"VBG"},
"slurps":	{"VBZ","NNS"},
"slurred":	{"VBD","VBN"},
"slurries":	{"NNS"},
"slurring":	{"VBG"},
"slurry":	{"NN"},
"slurs":	{"NNS","VBZ"},
"slush":	{"NN","VB","VBP"},
"slushed":	{"VBD","VBN"},
"slushes":	{"VBZ"},
"slushier":	{"JJR"},
"slushiest":	{"JJS"},
"slushing":	{"VBG"},
"slushy":	{"JJ"},
"slut":	{"NN"},
"sluts":	{"NNS"},
"sluttish":	{"JJ"},
"sluttishness":	{"NN"},
"slutty":	{"JJ"},
"sly":	{"JJ"},
"slyboots":	{"NNS"},
"slyer":	{"JJR"},
"slyest":	{"JJS"},
"slyly":	{"RB"},
"slyness":	{"NN"},
"sm":	{"NN"},
"smack":	{"VB","VBP","NN","RB"},
"smackdown":	{"NN"},
"smackdowns":	{"NNS"},
"smacked":	{"VBD","VBN"},
"smacker":	{"NN"},
"smackers":	{"NNS"},
"smacking":	{"VBG","NN","JJ"},
"smacks":	{"VBZ","NNS"},
"small":	{"JJ","RB","NN"},
"small-fry":	{"NN","NNS"},
"small-minded":	{"JJ"},
"small-mindedly":	{"RB"},
"small-mindedness":	{"NN"},
"small-scale":	{"JJ"},
"small-screen":	{"NN"},
"small-time":	{"JJ"},
"small-timer":	{"NN"},
"small-timers":	{"NNS"},
"small-town":	{"JJ"},
"smaller":	{"JJR"},
"smallest":	{"JJS"},
"smalley":	{"NN"},
"smallholder":	{"NN"},
"smallholders":	{"NNS"},
"smallholding":	{"NN"},
"smallholdings":	{"NNS"},
"smallish":	{"JJ"},
"smallmouth":	{"NN"},
"smallness":	{"NN"},
"smallpox":	{"NN"},
"smalls":	{"NNS"},
"smalltown":	{"JJ"},
"smaltite":	{"NN"},
"smarm":	{"NN","VB","VBP"},
"smarmier":	{"JJR"},
"smarmiest":	{"JJS"},
"smarmily":	{"RB"},
"smarminess":	{"NN"},
"smarmy":	{"JJ"},
"smart":	{"JJ","VB","VBP","NN"},
"smarta":	{"NN"},
"smarted":	{"VBD","VBN"},
"smarten":	{"VB","VBP"},
"smartened":	{"VBD","VBN"},
"smartening":	{"VBG"},
"smartens":	{"VBZ"},
"smarter":	{"JJR"},
"smartest":	{"JJS"},
"smarting":	{"VBG"},
"smartly":	{"RB"},
"smartness":	{"NN"},
"smartphone":	{"NN"},
"smarts":	{"VBZ"},
"smartwatch":	{"NN"},
"smartwatches":	{"NNS"},
"smash":	{"VB","VBP","NN"},
"smashed":	{"JJ","VBD","VBN"},
"smasher":	{"NN"},
"smashers":	{"NNS"},
"smashes":	{"VBZ","NNS"},
"smashing":	{"JJ","VBG"},
"smashingly":	{"RB"},
"smatter":	{"NN","VB","VBP"},
"smattered":	{"VBD","VBN"},
"smattering":	{"NN","VBG"},
"smatters":	{"VBZ"},
"smear":	{"NN","VB","VBP"},
"smeared":	{"VBD","VBN"},
"smearier":	{"JJR"},
"smeariest":	{"JJS"},
"smearing":	{"VBG"},
"smears":	{"NNS","VBZ"},
"smeary":	{"JJ"},
"smegma":	{"NN"},
"smell":	{"NN","VB","VBP"},
"smelled":	{"VBD","VBN"},
"smellier":	{"JJR"},
"smelliest":	{"JJS"},
"smelliness":	{"NN"},
"smelling":	{"NN","VBG"},
"smelling-salts":	{"NNS"},
"smells":	{"VBZ","NNS"},
"smelly":	{"JJ"},
"smelt":	{"VB","VBP","VBD","VBN","NN","NNS"},
"smelted":	{"VBD","VBN"},
"smelter":	{"NN"},
"smelters":	{"NNS"},
"smeltery":	{"NN"},
"smelting":	{"VBG","NN"},
"smelts":	{"VBZ","NNS"},
"smetana":	{"NN"},
"smew":	{"NN"},
"smidge":	{"NN"},
"smidgen":	{"NN"},
"smidgens":	{"NNS"},
"smidgeon":	{"NN"},
"smidgin":	{"NN"},
"smidgins":	{"NNS"},
"smilacaceae":	{"NN"},
"smilax":	{"NN"},
"smile":	{"NN","VB","VBP"},
"smiled":	{"VBD","VBN"},
"smiledon":	{"NN"},
"smiler":	{"NN"},
"smiles":	{"NNS","VBZ"},
"smiley":	{"NN","JJ"},
"smiling":	{"VBG","JJ"},
"smilingly":	{"RB"},
"smilo":	{"NN"},
"smirch":	{"VB","VBP","NN"},
"smirched":	{"VBD","VBN"},
"smirches":	{"VBZ","NNS"},
"smirching":	{"VBG"},
"smirk":	{"NN","VB","VBP"},
"smirked":	{"VBD","VBN"},
"smirker":	{"NN"},
"smirking":	{"VBG"},
"smirks":	{"NNS","VBZ"},
"smitane":	{"NN"},
"smite":	{"VB","VBP"},
"smites":	{"VBZ"},
"smith":	{"NN"},
"smithereens":	{"NNS"},
"smithies":	{"NNS"},
"smithy":	{"NN"},
"smiting":	{"VBG"},
"smitten":	{"VBN","JJ"},
"smock":	{"NN","VB","VBP"},
"smocked":	{"VBD","VBN","JJ"},
"smocking":	{"NN","VBG"},
"smocks":	{"NNS","VBZ"},
"smog":	{"NN"},
"smoggier":	{"JJR"},
"smoggiest":	{"JJS"},
"smogginess":	{"NN"},
"smoggy":	{"JJ"},
"smogs":	{"NNS"},
"smokable":	{"JJ"},
"smoke":	{"NN","VB","VBP"},
"smoke-bomb":	{"NN"},
"smoke-bombs":	{"NNS"},
"smoke-free":	{"JJ"},
"smoke-grenade":	{"NN"},
"smoke-grenades":	{"NNS"},
"smoke-stack":	{"NN"},
"smoke-stacks":	{"NNS"},
"smoked":	{"VBD","VBN","JJ"},
"smokehouse":	{"NN"},
"smokeless":	{"JJ"},
"smoker":	{"NN"},
"smokers":	{"NNS"},
"smokes":	{"NNS","VBZ"},
"smokescreen":	{"NN"},
"smokescreens":	{"NNS"},
"smokestack":	{"NN"},
"smokestacks":	{"NNS"},
"smokier":	{"JJR"},
"smokiest":	{"JJS"},
"smoking":	{"VBG","NN","JJ"},
"smoking-jacket":	{"NN"},
"smoking-jackets":	{"NNS"},
"smoking-room":	{"NN"},
"smoking-rooms":	{"NNS"},
"smoky":	{"JJ"},
"smolder":	{"VB","VBP"},
"smoldered":	{"VBD","VBN"},
"smoldering":	{"VBG"},
"smolderingly":	{"RB"},
"smolders":	{"VBZ"},
"smolensk":	{"NN"},
"smollett":	{"NN"},
"smooch":	{"VB","VBP","NN"},
"smooched":	{"VBD","VBN"},
"smooches":	{"VBZ"},
"smooching":	{"VBG"},
"smooth":	{"JJ","VB","VBP","NN"},
"smooth-faced":	{"JJ"},
"smooth-running":	{"JJ"},
"smooth-shaven":	{"JJ"},
"smooth-spoken":	{"JJ"},
"smooth-talk":	{"VB","VBP"},
"smooth-talked":	{"VBD","VBN"},
"smooth-talker":	{"NN"},
"smooth-talking":	{"VBG","JJ"},
"smooth-talks":	{"VBZ"},
"smooth-tongued":	{"JJ"},
"smoothbark":	{"NN"},
"smoothbore":	{"NN"},
"smoothed":	{"VBD","VBN"},
"smoothen":	{"VB","VBP"},
"smoothened":	{"VBD","VBN"},
"smoothening":	{"VBG"},
"smoothens":	{"VBZ"},
"smoother":	{"JJR","NN"},
"smoothest":	{"JJS"},
"smoothhound":	{"NN"},
"smoothie":	{"NN"},
"smoothies":	{"NNS"},
"smoothing":	{"VBG"},
"smoothly":	{"RB"},
"smoothness":	{"NN"},
"smooths":	{"VBZ"},
"smoothy":	{"NN"},
"smorgasbord":	{"NN"},
"smote":	{"VBD"},
"smother":	{"VB","VBP"},
"smothered":	{"VBD","VBN","JJ"},
"smotherer":	{"NN"},
"smothering":	{"JJ","VBG"},
"smothers":	{"VBZ"},
"smoulder":	{"VB","VBP"},
"smouldered":	{"VBD","VBN"},
"smouldering":	{"VBG","JJ"},
"smoulderingly":	{"RB"},
"smoulders":	{"VBZ"},
"smsgt":	{"NN"},
"smudge":	{"NN","VB","VBP"},
"smudged":	{"VBD","VBN"},
"smudges":	{"NNS","VBZ"},
"smudgier":	{"JJR"},
"smudgiest":	{"JJS"},
"smudging":	{"VBG"},
"smudgy":	{"JJ"},
"smug":	{"JJ"},
"smugger":	{"JJR"},
"smuggest":	{"JJS"},
"smuggle":	{"VB","VBP"},
"smuggled":	{"VBD","VBN"},
"smuggler":	{"NN"},
"smugglers":	{"NNS"},
"smuggles":	{"VBZ"},
"smuggling":	{"NN","VBG"},
"smugly":	{"RB"},
"smugness":	{"NN"},
"smut":	{"NN","VB","VBP"},
"smutch":	{"VB","VBP","NN"},
"smutchier":	{"JJR"},
"smutchiest":	{"JJS"},
"smutchy":	{"JJ"},
"smuts":	{"NNS","VBZ"},
"smutted":	{"VBD","VBN"},
"smuttier":	{"JJR"},
"smuttiest":	{"JJS"},
"smuttily":	{"RB"},
"smuttiness":	{"NN"},
"smutting":	{"VBG"},
"smutty":	{"JJ"},
"smyrna":	{"NN"},
"smyrnium":	{"NN"},
"smyth":	{"NN"},
"sn":	{"NN"},
"snack":	{"NN","VBP","VB"},
"snack-bar":	{"NN"},
"snack-bars":	{"NNS"},
"snack-food":	{"NN"},
"snacked":	{"VBD","VBN"},
"snacker":	{"NN"},
"snacking":	{"VBG"},
"snacks":	{"NNS","VBZ"},
"snaffle":	{"VB","VBP","NN"},
"snaffled":	{"VBD","VBN"},
"snaffles":	{"VBZ","NNS"},
"snaffling":	{"VBG"},
"snafu":	{"NN","JJ","VB","VBP"},
"snafued":	{"VBD","VBN"},
"snafuing":	{"VBG"},
"snafus":	{"NNS","VBZ"},
"snag":	{"NN","VB","VBP"},
"snagged":	{"VBN","VBD"},
"snagging":	{"VBG"},
"snags":	{"NNS","VBZ"},
"snail":	{"NN"},
"snail-flower":	{"NN"},
"snailfish":	{"NN"},
"snailflower":	{"NN"},
"snails":	{"NNS"},
"snake":	{"NN","VB","VBP"},
"snake-bite":	{"NN"},
"snake-bites":	{"NNS"},
"snake-charmer":	{"NN"},
"snake-charmers":	{"NNS"},
"snake-fish":	{"NN"},
"snake-head":	{"NN"},
"snake-like":	{"JJ"},
"snake-oil":	{"JJ","NN"},
"snake-rail":	{"JJ"},
"snakeberry":	{"NN"},
"snakebird":	{"NN"},
"snakebite":	{"NN"},
"snakebites":	{"NNS"},
"snakeblenny":	{"NN"},
"snaked":	{"VBD","VBN"},
"snakefish":	{"NN"},
"snakefly":	{"NN"},
"snakehead":	{"NN"},
"snakelike":	{"NN"},
"snakeroot":	{"NN"},
"snakes":	{"NNS","VBZ"},
"snakeskin":	{"NN"},
"snakestrike":	{"NN"},
"snakeweed":	{"NN"},
"snakewood":	{"NN"},
"snaking":	{"VBG"},
"snaky":	{"JJ"},
"snap":	{"VB","VBP","NN","JJ","UH","RB"},
"snap-on":	{"JJ"},
"snapback":	{"NN"},
"snapdragon":	{"NN"},
"snapdragons":	{"NNS"},
"snapline":	{"NN"},
"snapped":	{"VBD","VBN"},
"snapper":	{"NN"},
"snappers":	{"NNS"},
"snappier":	{"JJR"},
"snappiest":	{"JJS"},
"snapping":	{"VBG"},
"snappish":	{"JJ"},
"snappishly":	{"RB"},
"snappishness":	{"NN"},
"snappy":	{"JJ"},
"snaps":	{"NNS","VBZ"},
"snapshot":	{"NN"},
"snapshots":	{"NNS"},
"snare":	{"NN","VB","VBP"},
"snared":	{"VBD","VBN"},
"snarer":	{"NN"},
"snares":	{"NNS","VBZ"},
"snarf":	{"VB","VBP"},
"snarfed":	{"VBD","VBN"},
"snarfing":	{"VBG"},
"snarfs":	{"VBZ"},
"snaring":	{"VBG"},
"snarl":	{"VB","VBP","NN"},
"snarl-up":	{"NN"},
"snarl-ups":	{"NNS"},
"snarled":	{"VBD","VBN"},
"snarling":	{"VBG"},
"snarls":	{"NNS","VBZ"},
"snarly":	{"JJ"},
"snatch":	{"VB","NN","VBP"},
"snatched":	{"VBD","VBN"},
"snatcher":	{"NN"},
"snatchers":	{"NNS"},
"snatches":	{"NNS","VBZ"},
"snatching":	{"VBG"},
"snazzier":	{"JJR"},
"snazziest":	{"JJS"},
"snazzy":	{"JJ"},
"snead":	{"NN"},
"sneak":	{"VB","VBP","NN","JJ"},
"sneaked":	{"VBD","VBN"},
"sneaker":	{"NN"},
"sneakers":	{"NNS"},
"sneakier":	{"JJR"},
"sneakiest":	{"JJS"},
"sneakily":	{"RB"},
"sneakiness":	{"NN"},
"sneaking":	{"JJ","VBG"},
"sneakingly":	{"RB"},
"sneaks":	{"VBZ","NNS"},
"sneaky":	{"JJ"},
"sneer":	{"VB","VBP","NN"},
"sneered":	{"VBD","VBN"},
"sneerer":	{"NN"},
"sneering":	{"JJ","VBG"},
"sneeringly":	{"RB"},
"sneers":	{"VBZ","NNS"},
"sneeze":	{"VB","VBP","NN"},
"sneezed":	{"VBD","VBN"},
"sneezer":	{"NN"},
"sneezes":	{"VBZ","NNS"},
"sneezeweed":	{"NN"},
"sneezewort":	{"NN"},
"sneezing":	{"VBG"},
"sneezy":	{"JJ"},
"snellen":	{"NN"},
"snick":	{"VB","VBP","NN"},
"snicked":	{"VBD","VBN"},
"snicker":	{"VB","VBP","NN"},
"snickerdoodle":	{"NN"},
"snickerdoodles":	{"NNS"},
"snickered":	{"VBD","VBN"},
"snickering":	{"VBG"},
"snickers":	{"VBZ","NNS"},
"snickersnee":	{"NN"},
"snicking":	{"VBG"},
"snicks":	{"VBZ","NNS"},
"snide":	{"JJ"},
"snidely":	{"RB"},
"snideness":	{"NN"},
"sniff":	{"VB","VBP","NN"},
"sniffed":	{"VBD","VBN"},
"sniffer":	{"NN"},
"sniffers":	{"NNS"},
"sniffier":	{"JJR"},
"sniffiest":	{"JJS"},
"sniffily":	{"RB"},
"sniffing":	{"VBG","NN"},
"sniffle":	{"VBP","NN","VB"},
"sniffled":	{"VBD","VBN"},
"sniffler":	{"NN"},
"sniffles":	{"VBZ","NNS"},
"sniffling":	{"VBG"},
"sniffly":	{"RB"},
"sniffs":	{"VBZ","NNS"},
"sniffy":	{"JJ"},
"snifter":	{"NN"},
"snifters":	{"NNS"},
"snigger":	{"VB","VBP","NN"},
"sniggered":	{"VBD","VBN"},
"sniggering":	{"VBG"},
"sniggeringly":	{"RB"},
"sniggers":	{"VBZ","NNS"},
"snip":	{"VB","VBP","NN"},
"snipe":	{"VB","VBP","NN","NNS"},
"sniped":	{"VBD","VBN"},
"snipefish":	{"NN"},
"sniper":	{"NN"},
"snipers":	{"NNS"},
"snipes":	{"NNS","VBZ"},
"sniping":	{"NN","VBG"},
"snipped":	{"VBD","VBN"},
"snippet":	{"NN"},
"snippets":	{"NNS"},
"snipping":	{"VBG"},
"snippy":	{"JJ"},
"snips":	{"NNS","VBZ"},
"snit":	{"NN"},
"snitch":	{"VB","VBP","NN"},
"snitched":	{"VBD","VBN"},
"snitcher":	{"NN"},
"snitches":	{"VBZ","NNS"},
"snitching":	{"VBG"},
"snivel":	{"VB","VBP","NN"},
"sniveled":	{"VBD","VBN"},
"sniveler":	{"NN"},
"sniveling":	{"VBG","JJ"},
"snivelled":	{"VBD","VBN"},
"sniveller":	{"NN"},
"snivelling":	{"VBG","JJ"},
"snivels":	{"VBZ","NNS"},
"snob":	{"NN"},
"snobbery":	{"NN"},
"snobbier":	{"JJR"},
"snobbiest":	{"JJS"},
"snobbish":	{"JJ"},
"snobbishly":	{"RB"},
"snobbishness":	{"NN"},
"snobbism":	{"NN"},
"snobby":	{"JJ"},
"snobs":	{"NNS"},
"snoek":	{"NN"},
"snog":	{"VB","VBP","NN"},
"snogged":	{"VBD","VBN"},
"snogging":	{"VBG","NN"},
"snogs":	{"VBZ","NNS"},
"snood":	{"NN","VB","VBP"},
"snook":	{"NN"},
"snooker":	{"NN","VBP","VB"},
"snookered":	{"VBD","VBN"},
"snookering":	{"VBG"},
"snookers":	{"VBZ"},
"snoop":	{"VB","VBP","NN"},
"snooped":	{"VBD","VBN"},
"snooper":	{"NN"},
"snoopers":	{"NNS"},
"snoopiness":	{"NN"},
"snooping":	{"VBG"},
"snoops":	{"VBZ"},
"snoopy":	{"JJ"},
"snoot":	{"NN"},
"snootier":	{"JJR"},
"snootiest":	{"JJS"},
"snootily":	{"RB"},
"snootiness":	{"NN"},
"snooty":	{"JJ"},
"snooze":	{"NN","VB","VBP"},
"snoozed":	{"VBD","VBN"},
"snoozes":	{"NNS","VBZ"},
"snoozing":	{"VBG"},
"snore":	{"VB","VBP","NN"},
"snored":	{"VBD","VBN"},
"snorer":	{"NN"},
"snorers":	{"NNS"},
"snores":	{"VBZ","NNS"},
"snoring":	{"VBG"},
"snorkel":	{"NN","VB","VBP"},
"snorkeled":	{"VBD","VBN"},
"snorkeling":	{"VBG","NN"},
"snorkelled":	{"VBD","VBN"},
"snorkelling":	{"VBG","NN"},
"snorkels":	{"NNS","VBZ"},
"snorkle":	{"NN"},
"snort":	{"VB","VBP","NN"},
"snorted":	{"VBD","VBN"},
"snorter":	{"NN"},
"snorting":	{"VBG"},
"snorts":	{"NNS","VBZ"},
"snorty":	{"JJ"},
"snot":	{"NN"},
"snot-nosed":	{"JJ"},
"snottier":	{"JJR"},
"snottiest":	{"JJS"},
"snotty":	{"JJ"},
"snotty-nosed":	{"JJ"},
"snout":	{"NN"},
"snouts":	{"NNS"},
"snow":	{"NN","VB","VBP"},
"snow-blind":	{"JJ"},
"snow-blower":	{"NN"},
"snow-capped":	{"JJ"},
"snow-covered":	{"JJ"},
"snow-drift":	{"NN"},
"snow-drifts":	{"NNS"},
"snow-fence":	{"NN"},
"snow-field":	{"NN"},
"snow-fields":	{"NNS"},
"snow-goose":	{"NN"},
"snow-leopard":	{"NN"},
"snow-line":	{"NN"},
"snow-shed":	{"NN"},
"snow-white":	{"JJ"},
"snowball":	{"NN","VB","VBP"},
"snowballed":	{"VBD","VBN"},
"snowballing":	{"VBG"},
"snowballs":	{"NNS","VBZ"},
"snowbank":	{"NN"},
"snowbell":	{"NN"},
"snowberry":	{"NN"},
"snowbird":	{"NN"},
"snowbirds":	{"NNS"},
"snowboard":	{"NN"},
"snowboarder":	{"NN"},
"snowboarders":	{"NNS"},
"snowboarding":	{"NN"},
"snowboards":	{"NNS"},
"snowbound":	{"JJ"},
"snowcap":	{"NN"},
"snowdrift":	{"NN"},
"snowdrifts":	{"NNS"},
"snowdrop":	{"NN"},
"snowdrops":	{"NNS"},
"snowed":	{"VBD","VBN"},
"snowfall":	{"NN"},
"snowfalls":	{"NNS"},
"snowfield":	{"NN"},
"snowfields":	{"NNS"},
"snowflake":	{"NN"},
"snowflakes":	{"NNS"},
"snowier":	{"JJR"},
"snowiest":	{"JJS"},
"snowing":	{"VBG"},
"snowman":	{"NN"},
"snowmen":	{"NNS"},
"snowmobile":	{"NN"},
"snowmobiles":	{"NNS"},
"snowplough":	{"NN"},
"snowploughs":	{"NNS"},
"snowplow":	{"NN"},
"snowplows":	{"NNS"},
"snows":	{"NNS","VBZ"},
"snowshoe":	{"NN"},
"snowshoes":	{"NNS"},
"snowstorm":	{"NN"},
"snowstorms":	{"NNS"},
"snowsuit":	{"NN"},
"snowy":	{"JJ"},
"snp":	{"NN"},
"snub":	{"VB","VBP","NN","JJ"},
"snub-nosed":	{"JJ"},
"snubbed":	{"VBD","VBN"},
"snubbing":	{"VBG"},
"snubs":	{"VBZ","NNS"},
"snuck":	{"VBD","VBN"},
"snuff":	{"NN","VB","VBP"},
"snuff-box":	{"NN"},
"snuff-boxes":	{"NNS"},
"snuffbox":	{"NN"},
"snuffboxes":	{"NNS"},
"snuffed":	{"VBD","VBN"},
"snuffer":	{"NN"},
"snuffers":	{"NNS"},
"snuffing":	{"VBG"},
"snuffle":	{"VB","VBP","NN"},
"snuffled":	{"VBD","VBN"},
"snuffler":	{"NN"},
"snuffles":	{"VBZ"},
"snuffling":	{"VBG"},
"snuffly":	{"JJ"},
"snuffs":	{"VBZ"},
"snug":	{"JJ","VBP","NN","VB"},
"snugged":	{"VBD","VBN"},
"snugger":	{"JJR"},
"snuggery":	{"NN"},
"snuggest":	{"JJS"},
"snugging":	{"VBG"},
"snuggle":	{"VB","VBP"},
"snuggled":	{"VBD","VBN"},
"snuggles":	{"VBZ"},
"snuggling":	{"VBG"},
"snugly":	{"RB"},
"snugness":	{"NN"},
"snugs":	{"NNS","VBZ"},
"so":	{"RB","CC","IN","NN"},
"so-and-so":	{"NN"},
"so-and-sos":	{"NNS"},
"so-called":	{"JJ"},
"so-so":	{"JJ","RB"},
"soak":	{"VB","NN","VBP"},
"soakage":	{"NN"},
"soaked":	{"JJ","VBD","VBN"},
"soaker":	{"NN"},
"soaking":	{"NN","JJ","VBG"},
"soaks":	{"VBZ"},
"soap":	{"NN","VBP","VB"},
"soap-bubble":	{"NN"},
"soap-bubbles":	{"NNS"},
"soap-flakes":	{"NNS"},
"soap-rock":	{"NN"},
"soap-weed":	{"NN"},
"soapberry":	{"NN"},
"soapbox":	{"NN"},
"soapboxes":	{"NNS"},
"soaped":	{"VBD","VBN"},
"soapfish":	{"NN"},
"soapier":	{"JJR"},
"soapiest":	{"JJS"},
"soapiness":	{"NN"},
"soaping":	{"VBG"},
"soaprock":	{"NN"},
"soaps":	{"NNS","VBZ"},
"soapstone":	{"NN"},
"soapsuds":	{"NNS"},
"soapweed":	{"NN"},
"soapwort":	{"NN"},
"soapy":	{"JJ"},
"soar":	{"VB","VBP"},
"soared":	{"VBD","VBN"},
"soaring":	{"VBG","JJ"},
"soars":	{"VBZ"},
"soave":	{"NN"},
"sob":	{"VB","VBP","NN"},
"sob-stories":	{"NNS"},
"sob-story":	{"NN"},
"sob-stuff":	{"NN"},
"sob-wallow":	{"NN"},
"soba":	{"NN"},
"sobbed":	{"VBD","VBN"},
"sobbing":	{"NN","VBG"},
"sobbingly":	{"RB"},
"sober":	{"JJ","VB","VBP"},
"sobered":	{"VBD","VBN"},
"sobering":	{"VBG","JJ"},
"soberly":	{"RB"},
"soberness":	{"NN"},
"sobers":	{"VBZ"},
"sobersided":	{"JJ"},
"sobersides":	{"NN"},
"sobralia":	{"NN"},
"sobre":	{"FW"},
"sobriety":	{"NN"},
"sobriquet":	{"NN"},
"sobriquets":	{"NNS"},
"sobs":	{"VBZ","NNS"},
"socage":	{"NN"},
"socal":	{"JJ"},
"soccer":	{"NN"},
"sociability":	{"NN"},
"sociable":	{"JJ"},
"sociableness":	{"NN"},
"sociably":	{"RB"},
"social":	{"JJ","NN"},
"social-climbing":	{"JJ","NN"},
"social-register":	{"JJ"},
"social-security":	{"NN"},
"social-services":	{"NNS"},
"social-studies":	{"NN"},
"socialisation":	{"NN"},
"socialise":	{"VB","VBP"},
"socialised":	{"VBD","VBN"},
"socialiser":	{"NN"},
"socialises":	{"VBZ"},
"socialising":	{"VBG","NN"},
"socialism":	{"NN"},
"socialist":	{"JJ","NN"},
"socialistic":	{"JJ"},
"socialists":	{"NNS"},
"socialite":	{"NN"},
"socialites":	{"NNS"},
"sociality":	{"NN"},
"socialization":	{"NN"},
"socialize":	{"VB","VBP"},
"socialized":	{"VBD","VBN"},
"socializer":	{"NN"},
"socializes":	{"VBZ"},
"socializing":	{"VBG","NN"},
"socially":	{"RB"},
"societal":	{"JJ"},
"societies":	{"NNS"},
"society":	{"NN"},
"socinian":	{"NN"},
"socinus":	{"NN"},
"socio-economic":	{"JJ"},
"socio-political":	{"JJ"},
"sociobiologic":	{"JJ"},
"sociobiological":	{"JJ"},
"sociobiologically":	{"RB"},
"sociobiologist":	{"NN"},
"sociobiology":	{"NN"},
"sociocultural":	{"JJ"},
"socioeconomic":	{"JJ"},
"socioeconomically":	{"RB"},
"sociolinguist":	{"NN"},
"sociolinguistic":	{"JJ"},
"sociolinguistically":	{"RB"},
"sociolinguistics":	{"NN"},
"sociological":	{"JJ"},
"sociologically":	{"RB"},
"sociologist":	{"NN"},
"sociologists":	{"NNS"},
"sociology":	{"NN"},
"sociomedical":	{"JJ"},
"sociometry":	{"NN"},
"sociopath":	{"NN"},
"sociopathic":	{"JJ"},
"sociopathology":	{"NN"},
"sociopaths":	{"NNS"},
"sociopolitical":	{"JJ"},
"sock":	{"NN","VB","VBP"},
"socked":	{"VBD","VBN"},
"socket":	{"NN","VB","VBP"},
"socketed":	{"VBD","VBN"},
"socketing":	{"VBG"},
"sockets":	{"NNS","VBZ"},
"sockeye":	{"NN"},
"socking":	{"VBG"},
"socks":	{"NNS","VBZ"},
"socle":	{"NN"},
"socrates":	{"NNS"},
"sod":	{"NN","VB","VBP"},
"soda":	{"NN"},
"soda-fountain":	{"NN"},
"soda-fountains":	{"NNS"},
"soda-water":	{"NN"},
"soda-waters":	{"NNS"},
"sodalist":	{"NN"},
"sodalite":	{"NN"},
"sodality":	{"NN"},
"sodas":	{"NNS"},
"sodbuster":	{"NN"},
"sodded":	{"VBD","VBN"},
"sodden":	{"JJ","VB","VBP"},
"soddened":	{"VBD","VBN"},
"soddening":	{"VBG"},
"soddenly":	{"RB"},
"soddenness":	{"NN"},
"soddens":	{"VBZ"},
"soddies":	{"NNS"},
"sodding":	{"VBG","JJ"},
"soddish":	{"JJ"},
"sodium":	{"NN","JJ"},
"sodoku":	{"NN"},
"sodomise":	{"VB","VBP"},
"sodomist":	{"NN"},
"sodomite":	{"NN"},
"sodomites":	{"NNS"},
"sodomize":	{"VB","VBP"},
"sodomy":	{"NN"},
"sods":	{"NNS","VBZ"},
"soe":	{"NN"},
"sofa":	{"NN"},
"sofar":	{"NN"},
"sofas":	{"NNS"},
"soffit":	{"NN"},
"sofia":	{"NN"},
"sofrito":	{"NN"},
"soft":	{"JJ"},
"soft-boiled":	{"JJ"},
"soft-core":	{"JJ"},
"soft-cover":	{"NN","JJ"},
"soft-covers":	{"NNS"},
"soft-finned":	{"JJ"},
"soft-headed":	{"JJ"},
"soft-hearted":	{"JJ"},
"soft-heartedness":	{"NN"},
"soft-pedal":	{"VB","VBP"},
"soft-pedaled":	{"VBD","VBN"},
"soft-pedaling":	{"VBG"},
"soft-pedalled":	{"VBD","VBN"},
"soft-pedalling":	{"VBG"},
"soft-pedals":	{"VBZ"},
"soft-rock":	{"JJ"},
"soft-sell":	{"JJ"},
"soft-shell":	{"JJ","NN"},
"soft-soap":	{"VB","VBP"},
"soft-soaped":	{"VBD","VBN"},
"soft-soaping":	{"VBG"},
"soft-soaps":	{"VBZ"},
"soft-spoken":	{"JJ"},
"softback":	{"NN"},
"softbacks":	{"NNS"},
"softball":	{"NN"},
"softballs":	{"NNS"},
"softcore":	{"JJ"},
"softcover":	{"NN"},
"softcovers":	{"NNS"},
"soften":	{"VB","VBP"},
"softened":	{"VBD","VBN"},
"softener":	{"NN"},
"softeners":	{"NNS"},
"softening":	{"NN","VBG"},
"softens":	{"VBZ"},
"softer":	{"JJR"},
"softest":	{"JJS"},
"softheaded":	{"JJ"},
"softhearted":	{"JJ"},
"softheartedness":	{"NN"},
"softie":	{"NN"},
"softies":	{"NNS"},
"softish":	{"JJ"},
"softly":	{"RB"},
"softness":	{"NN"},
"software":	{"NN"},
"softwood":	{"NN"},
"softwoods":	{"NNS"},
"softy":	{"NN"},
"soggier":	{"JJR"},
"soggiest":	{"JJS"},
"soggily":	{"RB"},
"sogginess":	{"NN"},
"soggy":	{"JJ"},
"soh":	{"NN"},
"soigne":	{"JJ"},
"soignee":	{"JJ"},
"soil":	{"NN","VB","VBP"},
"soilborne":	{"JJ"},
"soiled":	{"JJ","VBD","VBN"},
"soiling":	{"VBG"},
"soils":	{"NNS","VBZ"},
"soilure":	{"NN"},
"soiree":	{"NN"},
"soirees":	{"NNS"},
"soixante-neuf":	{"NN"},
"soja":	{"NN"},
"sojourn":	{"NN","VB","VBP"},
"sojourned":	{"VBD","VBN"},
"sojourner":	{"NN"},
"sojourners":	{"NNS"},
"sojourning":	{"VBG"},
"sojourns":	{"NNS","VBZ"},
"sokaiya":	{"NN"},
"sokoro":	{"NN"},
"sol":	{"NN"},
"solace":	{"NN","VB","VBP"},
"solaced":	{"VBD","VBN"},
"solacement":	{"NN"},
"solaces":	{"VBZ"},
"solacing":	{"VBG"},
"solan":	{"NN"},
"solanaceae":	{"NN"},
"solanaceous":	{"JJ"},
"solandra":	{"NN"},
"solanopteris":	{"NNS"},
"solanum":	{"NN"},
"solar":	{"JJ"},
"solarheated":	{"JJ"},
"solaria":	{"NNS"},
"solarisation":	{"NN"},
"solarise":	{"VB","VBP"},
"solarium":	{"NN"},
"solariums":	{"NNS"},
"solarization":	{"NN"},
"solarize":	{"VB","VBP"},
"solastalgia":	{"NN"},
"solastalgias":	{"NNS"},
"sold":	{"VBN","VBD"},
"sold-out":	{"JJ"},
"solder":	{"NN","VB","VBP"},
"soldered":	{"VBD","VBN"},
"solderer":	{"NN"},
"soldering":	{"NN","VBG"},
"soldering-iron":	{"NN"},
"soldering-irons":	{"NNS"},
"solders":	{"VBZ"},
"soldier":	{"NN","VBP","VB"},
"soldier-fish":	{"NN"},
"soldier-like":	{"JJ"},
"soldiered":	{"VBD","VBN"},
"soldierfish":	{"NN"},
"soldiering":	{"NN","VBG"},
"soldierlike":	{"JJ"},
"soldierly":	{"JJ"},
"soldiers":	{"NNS","VBZ"},
"soldiership":	{"NN"},
"soldiery":	{"NN"},
"soldout":	{"NN"},
"sole":	{"JJ","NN","NNS","VB","VBP"},
"solea":	{"NN"},
"solecism":	{"NN"},
"solecisms":	{"NNS"},
"soled":	{"VBD","VBN","JJ"},
"soledad":	{"NN"},
"soleidae":	{"NN"},
"soleirolia":	{"NN"},
"soleless":	{"JJ"},
"solely":	{"RB"},
"solemn":	{"JJ"},
"solemnisation":	{"NN"},
"solemnise":	{"VB","VBP"},
"solemnised":	{"VBD","VBN"},
"solemnises":	{"VBZ"},
"solemnising":	{"VBG"},
"solemnities":	{"NNS"},
"solemnity":	{"NN"},
"solemnization":	{"NN"},
"solemnize":	{"VB","VBP"},
"solemnized":	{"VBD","VBN"},
"solemnizes":	{"VBZ"},
"solemnizing":	{"VBG"},
"solemnly":	{"RB"},
"solemnness":	{"NN"},
"solenichthyes":	{"NNS"},
"solenidae":	{"NN"},
"solenoid":	{"NN"},
"solenopsis":	{"NN"},
"solenostemon":	{"NN"},
"soles":	{"NNS","VBZ"},
"soleus":	{"NN"},
"solfa":	{"NN"},
"solfege":	{"NN"},
"solfeggio":	{"NN"},
"solferino":	{"NN"},
"solicit":	{"VB","VBP"},
"solicitation":	{"NN"},
"solicitations":	{"NNS"},
"solicited":	{"VBD","VBN"},
"soliciting":	{"VBG","NN"},
"solicitor":	{"NN"},
"solicitors":	{"NNS"},
"solicitorship":	{"NN"},
"solicitous":	{"JJ"},
"solicitously":	{"RB"},
"solicitousness":	{"NN"},
"solicits":	{"VBZ"},
"solicitude":	{"NN"},
"solid":	{"JJ","NN"},
"solid-state":	{"JJ"},
"solidago":	{"NN"},
"solidarity":	{"NN"},
"solidi":	{"NNS"},
"solidification":	{"NN"},
"solidified":	{"VBD","VBN"},
"solidifies":	{"VBZ"},
"solidify":	{"VB","VBP"},
"solidifying":	{"VBG"},
"solidity":	{"NN"},
"solidly":	{"RB"},
"solidness":	{"NN"},
"solids":	{"NNS"},
"solidus":	{"NN"},
"soliloquies":	{"NNS"},
"soliloquise":	{"VB","VBP"},
"soliloquised":	{"VBD","VBN"},
"soliloquises":	{"VBZ"},
"soliloquising":	{"VBG"},
"soliloquize":	{"VB","VBP"},
"soliloquized":	{"VBD","VBN"},
"soliloquizes":	{"VBZ"},
"soliloquizing":	{"VBG"},
"soliloquy":	{"NN"},
"soling":	{"VBG"},
"solingen":	{"NN"},
"solipsism":	{"NN"},
"solitaire":	{"NN"},
"solitaires":	{"NNS"},
"solitaries":	{"NNS"},
"solitarily":	{"RB"},
"solitariness":	{"NN"},
"solitary":	{"JJ","NN"},
"soliton":	{"NN"},
"solitude":	{"NN"},
"solitudinarian":	{"NN"},
"solleret":	{"NN"},
"solmisation":	{"NN"},
"solmization":	{"NN"},
"solo":	{"NN","RB","JJ","VB","VBP"},
"soloed":	{"VBD","VBN"},
"soloing":	{"VBG"},
"soloist":	{"NN"},
"soloists":	{"NNS"},
"solomon":	{"NN"},
"solomonic":	{"JJ"},
"solon":	{"NN"},
"solos":	{"NNS","VBZ"},
"solresol":	{"NN"},
"solstice":	{"NN"},
"solstices":	{"NNS"},
"solubility":	{"NN"},
"soluble":	{"JJ"},
"solubleness":	{"NN"},
"solute":	{"NN","JJ"},
"solution":	{"NN"},
"solutionism":	{"NN"},
"solutions":	{"NNS"},
"solvability":	{"NN"},
"solvable":	{"JJ"},
"solvate":	{"VB","VBP","NN"},
"solvated":	{"VBD","VBN"},
"solvates":	{"VBZ"},
"solvating":	{"VBG"},
"solvation":	{"NN"},
"solvay":	{"NN"},
"solve":	{"VB","VBP"},
"solved":	{"VBN","VBD"},
"solvency":	{"NN"},
"solvent":	{"JJ","NN"},
"solvents":	{"NNS"},
"solver":	{"NN"},
"solvers":	{"NNS"},
"solves":	{"VBZ"},
"solving":	{"VBG"},
"solzhenitsyn":	{"NN"},
"som":	{"NN"},
"soma":	{"NN"},
"somaesthesia":	{"NN"},
"somaesthesis":	{"NN"},
"somali":	{"JJ","NN"},
"somalia":	{"NN"},
"soman":	{"NN"},
"somataesthesis":	{"NN"},
"somateria":	{"NN"},
"somatesthesia":	{"NN"},
"somatic":	{"JJ"},
"somatogenetic":	{"JJ"},
"somatogenic":	{"JJ"},
"somatosense":	{"NN"},
"somatosensory":	{"JJ"},
"somatostatin":	{"NN"},
"somatotrophin":	{"NN"},
"somatotropin":	{"NN"},
"somatotype":	{"NN"},
"somber":	{"JJ","NN"},
"somberly":	{"RB"},
"somberness":	{"NN"},
"sombre":	{"JJ"},
"sombrely":	{"RB"},
"sombreness":	{"NN"},
"sombrero":	{"NN"},
"sombreros":	{"NNS"},
"some":	{"DT","PRP","RB"},
"somebody":	{"PRP","NN"},
"someday":	{"RB"},
"somehow":	{"RB","WRB"},
"someone":	{"PRP","NN"},
"someplace":	{"RB"},
"somersault":	{"NN","VB","VBP"},
"somersaulted":	{"VBD","VBN"},
"somersaulting":	{"VBG"},
"somersaults":	{"NNS","VBZ"},
"somerset":	{"NN"},
"somesthesia":	{"NN"},
"somesthesis":	{"NN"},
"somethin":	{"NN"},
"something":	{"NN"},
"sometime":	{"RB","JJ"},
"sometimes":	{"RB"},
"someway":	{"RB"},
"somewhat":	{"RB"},
"somewhere":	{"RB"},
"somewheres":	{"RB"},
"somite":	{"NN"},
"sommelier":	{"NN"},
"somnambulate":	{"VB"},
"somnambulates":	{"VBZ"},
"somnambulation":	{"NN"},
"somnambulism":	{"NN"},
"somnambulist":	{"NN"},
"somnambulists":	{"NNS"},
"somniferous":	{"JJ"},
"somnific":	{"JJ"},
"somniloquism":	{"NN"},
"somniloquist":	{"NN"},
"somniloquists":	{"NNS"},
"somniloquy":	{"NN"},
"somnolence":	{"NN"},
"somnolent":	{"JJ"},
"somnolently":	{"RB"},
"sompin":	{"NN"},
"somrai":	{"NN"},
"son":	{"NN"},
"son-in-law":	{"NN"},
"son-of-a-bitch":	{"NN"},
"sonant":	{"JJ"},
"sonar":	{"NN"},
"sonata":	{"NN"},
"sonatas":	{"NNS"},
"sonatina":	{"NN"},
"sonchus":	{"NNS"},
"sondheim":	{"NN"},
"sone":	{"NN"},
"song":	{"NN"},
"song-book":	{"NN"},
"song-books":	{"NNS"},
"song-writer":	{"NN"},
"song-writers":	{"NNS"},
"song-writing":	{"NN"},
"songbird":	{"NN"},
"songbirds":	{"NNS"},
"songbook":	{"NN"},
"songbooks":	{"NNS"},
"songful":	{"JJ"},
"songfulness":	{"NN"},
"songlike":	{"JJ"},
"songs":	{"NNS"},
"songster":	{"NN"},
"songsters":	{"NNS"},
"songstress":	{"NN"},
"songstresses":	{"NNS"},
"songwriter":	{"NN"},
"songwriters":	{"NNS"},
"songwriting":	{"NN"},
"sonic":	{"JJ"},
"sonnet":	{"NN"},
"sonneteer":	{"NN"},
"sonnets":	{"NNS"},
"sonny":	{"NN"},
"sonobuoy":	{"NN"},
"sonofabitch":	{"NN"},
"sonogram":	{"NN"},
"sonograms":	{"NNS"},
"sonograph":	{"NN"},
"sonography":	{"NN"},
"sonometer":	{"NN"},
"sonorities":	{"NNS"},
"sonority":	{"NN"},
"sonorous":	{"JJ"},
"sonorously":	{"RB"},
"sonorousness":	{"NN"},
"sons":	{"NNS"},
"sons-in-law":	{"NNS"},
"sons-of-a-bitches":	{"NNS"},
"sonsie":	{"JJ"},
"sonsy":	{"JJ"},
"sontag":	{"NN"},
"soochong":	{"NN"},
"soon":	{"RB"},
"sooner":	{"RBR"},
"soonest":	{"RBS"},
"soot":	{"NN","VB","VBP"},
"sooted":	{"VBD","VBN"},
"sooth":	{"NN","JJ"},
"soothe":	{"VB","VBP"},
"soothed":	{"VBD","VBN"},
"soothes":	{"VBZ"},
"soothing":	{"JJ","VBG"},
"soothingly":	{"RB"},
"soothly":	{"RB"},
"soothsaid":	{"VBD","VBN"},
"soothsay":	{"VB","VBP"},
"soothsayer":	{"NN"},
"soothsayers":	{"NNS"},
"soothsaying":	{"VBG","NN"},
"soothsays":	{"VBZ"},
"sootiness":	{"NN"},
"sooting":	{"VBG"},
"soots":	{"VBZ"},
"sooty":	{"JJ"},
"sop":	{"NN","VB","VBP"},
"soph":	{"NN"},
"sophia":	{"NN"},
"sophie":	{"NN"},
"sophism":	{"NN"},
"sophisms":	{"NNS"},
"sophist":	{"NN"},
"sophistic":	{"JJ"},
"sophistical":	{"JJ"},
"sophisticate":	{"NN","VB","VBP"},
"sophisticated":	{"JJ","VBD","VBN"},
"sophisticates":	{"NNS","VBZ"},
"sophisticating":	{"VBG"},
"sophistication":	{"NN"},
"sophistries":	{"NNS"},
"sophistry":	{"NN"},
"sophists":	{"NNS"},
"sophocles":	{"NNS"},
"sophomore":	{"NN"},
"sophomores":	{"NNS"},
"sophomoric":	{"JJ"},
"sophonias":	{"NN"},
"sophora":	{"NN"},
"sopor":	{"NN"},
"soporiferous":	{"JJ"},
"soporific":	{"JJ","NN"},
"sopped":	{"VBD","VBN"},
"soppier":	{"JJR"},
"soppiest":	{"JJS"},
"sopping":	{"JJ","RB","VBG"},
"soppy":	{"JJ"},
"sopranino":	{"JJ"},
"soprano":	{"NN","JJ","RB"},
"sopranos":	{"NNS"},
"sops":	{"NNS","VBZ"},
"sorb":	{"NN"},
"sorbate":	{"NN"},
"sorbefacient":	{"JJ"},
"sorbent":	{"NN"},
"sorbet":	{"NN"},
"sorbets":	{"NNS"},
"sorbian":	{"NN"},
"sorbus":	{"NN"},
"sorcerer":	{"NN"},
"sorcerers":	{"NNS"},
"sorceress":	{"NN"},
"sorceresses":	{"NNS"},
"sorcerous":	{"JJ"},
"sorcery":	{"NN"},
"sordid":	{"JJ"},
"sordidly":	{"RB"},
"sordidness":	{"NN"},
"sordino":	{"NN"},
"sore":	{"JJ","NN"},
"sorehead":	{"NN"},
"soreheads":	{"NNS"},
"sorely":	{"RB"},
"soreness":	{"NN"},
"sorensen":	{"NN"},
"sorenson":	{"NN"},
"sorer":	{"JJR"},
"sores":	{"NNS"},
"sorest":	{"JJS"},
"sorex":	{"NN"},
"sorgho":	{"NN"},
"sorghum":	{"NN"},
"sorgo":	{"NN"},
"soricidae":	{"NN"},
"soring":	{"VBG"},
"sorkin":	{"NN"},
"sororal":	{"JJ"},
"sororities":	{"NNS"},
"sorority":	{"NN"},
"sorption":	{"NN"},
"sorrel":	{"NN","JJ"},
"sorrier":	{"JJR"},
"sorriest":	{"JJS"},
"sorriness":	{"NN"},
"sorrow":	{"NN","VB","VBP"},
"sorrowed":	{"VBD","VBN"},
"sorrower":	{"NN"},
"sorrowful":	{"JJ"},
"sorrowfully":	{"RB"},
"sorrowfulness":	{"NN"},
"sorrowing":	{"VBG","NN"},
"sorrows":	{"NNS","VBZ"},
"sorry":	{"JJ","UH"},
"sort":	{"NN","VB","VBP"},
"sorted":	{"JJ","VBD","VBN"},
"sorter":	{"NN"},
"sorters":	{"NNS"},
"sortie":	{"NN","VB","VBP"},
"sortied":	{"VBD","VBN"},
"sortieing":	{"VBG"},
"sorties":	{"NNS","VBZ"},
"sorting":	{"VBG"},
"sortition":	{"NN"},
"sorts":	{"NNS","VBZ"},
"sorus":	{"NN"},
"sot":	{"NN"},
"soteriological":	{"JJ"},
"soteriology":	{"NN"},
"sothis":	{"NN"},
"sotho":	{"JJ","NN"},
"sottish":	{"JJ"},
"sottishly":	{"RB"},
"sottishness":	{"NN"},
"sou":	{"NN"},
"sou'wester":	{"NN"},
"sou'westers":	{"NNS"},
"souari":	{"NN"},
"soubise":	{"NN"},
"soubrette":	{"NN"},
"soubriquet":	{"NN"},
"soubriquets":	{"NNS"},
"souchong":	{"NN"},
"soudan":	{"NN"},
"souffle":	{"NN"},
"souffles":	{"NNS"},
"soufflot":	{"NN"},
"sough":	{"VB","VBP","NN"},
"soughed":	{"VBD","VBN"},
"soughing":	{"VBG"},
"soughingly":	{"RB"},
"soughs":	{"VBZ"},
"sought":	{"VBD","VBN"},
"sought-after":	{"JJ"},
"souk":	{"NN"},
"souks":	{"NNS"},
"soul":	{"NN"},
"soul-destroying":	{"JJ"},
"soul-searching":	{"NN"},
"soul-stirring":	{"JJ"},
"soulful":	{"JJ"},
"soulfully":	{"RB"},
"soulfulness":	{"NN"},
"soulless":	{"JJ"},
"soullessly":	{"RB"},
"soullessness":	{"NN"},
"soulmate":	{"NN"},
"soulmates":	{"NNS"},
"souls":	{"NNS"},
"sound":	{"NN","JJ","RB","VB","VBP"},
"sound-proof":	{"JJ","VB","VBP"},
"sound-proofed":	{"VBD","VBN"},
"sound-proofing":	{"VBG","NN"},
"sound-proofs":	{"VBZ"},
"sound-wave":	{"NN"},
"sound-waves":	{"NNS"},
"soundable":	{"JJ"},
"soundboard":	{"NN"},
"soundbox":	{"NN"},
"sounded":	{"VBD","VBN"},
"sounder":	{"NN"},
"sounders":	{"NNS"},
"sounding":	{"VBG","NN","JJ"},
"sounding-board":	{"NN"},
"sounding-boards":	{"NNS"},
"soundings":	{"NNS"},
"soundless":	{"JJ"},
"soundlessly":	{"RB"},
"soundlessness":	{"NN"},
"soundly":	{"RB"},
"soundman":	{"NN"},
"soundness":	{"NN"},
"soundproof":	{"JJ","VB","VBP"},
"soundproofed":	{"VBD","VBN"},
"soundproofing":	{"VBG","NN"},
"soundproofs":	{"VBZ"},
"sounds":	{"VBZ","NNS"},
"soundstage":	{"NN"},
"soundstages":	{"NNS"},
"soundtrack":	{"NN"},
"soundtracks":	{"NNS"},
"soundwave":	{"NN"},
"soundwaves":	{"NNS"},
"soup":	{"NN","VB","VBP"},
"soup-kitchen":	{"NN"},
"soup-kitchens":	{"NNS"},
"soup-plate":	{"NN"},
"soup-plates":	{"NNS"},
"soup-strainer":	{"NN"},
"soup-to-nuts":	{"JJ"},
"soupcon":	{"NN"},
"souped":	{"VBD","VBN"},
"souped-up":	{"JJ"},
"soupfin":	{"NN"},
"soupiness":	{"NN"},
"souping":	{"VBG"},
"soups":	{"NNS","VBZ"},
"soupspoon":	{"NN"},
"soupy":	{"JJ"},
"sour":	{"JJ","VB","VBP"},
"sourball":	{"NN"},
"source":	{"NN","VB","VBP"},
"sourced":	{"VBD","VBN"},
"sources":	{"NNS","VBZ"},
"sourcing":	{"NN","VBG"},
"sourdine":	{"NN"},
"sourdough":	{"NN"},
"soured":	{"VBD","VBN"},
"souring":	{"VBG"},
"sourish":	{"JJ"},
"sourly":	{"RB"},
"sourness":	{"NN"},
"sourpuss":	{"NN"},
"sours":	{"VBZ"},
"soursop":	{"NN"},
"sourwood":	{"NN"},
"sousa":	{"NN"},
"sousaphone":	{"NN"},
"souse":	{"VB","VBP","NN"},
"soused":	{"VBD","VBN","JJ"},
"souses":	{"VBZ","NNS"},
"sousing":	{"VBG"},
"souslik":	{"NN"},
"sousse":	{"NN"},
"soutache":	{"NN"},
"soutane":	{"NN"},
"south":	{"NN","JJ","RB"},
"south-east":	{"NN","JJ","RB"},
"south-eastern":	{"JJ"},
"south-southeast":	{"NN","JJ","RB"},
"south-southwest":	{"NN","JJ","RB"},
"south-west":	{"NN","JJ","RB"},
"southampton":	{"NN"},
"southbound":	{"JJ","RB"},
"southcentral":	{"NN"},
"southeast":	{"NN","JJ","RB"},
"southeaster":	{"NN"},
"southeasterly":	{"JJ","RB"},
"southeastern":	{"JJ"},
"southeasters":	{"NNS"},
"southeastward":	{"JJ","RB"},
"southeastwardly":	{"RB"},
"southeastwards":	{"RB"},
"souther":	{"NN"},
"southerlies":	{"NNS"},
"southerly":	{"JJ","RB","NN"},
"southern":	{"JJ"},
"southerner":	{"NN"},
"southerners":	{"NNS"},
"southernism":	{"NN"},
"southernisms":	{"NNS"},
"southernmost":	{"JJ"},
"southernness":	{"NN"},
"southernwood":	{"NN"},
"southey":	{"NN"},
"southland":	{"NN"},
"southmost":	{"JJ"},
"southpaw":	{"NN"},
"southpaws":	{"NNS"},
"southward":	{"JJ","RB"},
"southwards":	{"RB"},
"southwest":	{"NN","JJ","RB"},
"southwester":	{"NN"},
"southwesterly":	{"JJ","RB"},
"southwestern":	{"JJ"},
"southwesters":	{"NNS"},
"southwestward":	{"JJ","RB"},
"southwestwardly":	{"RB"},
"southwestwards":	{"RB"},
"soutine":	{"NN"},
"souvenir":	{"NN"},
"souvenirs":	{"NNS"},
"souvlaki":	{"NN"},
"souvlakia":	{"NN"},
"souza":	{"NN"},
"sovereign":	{"JJ","NN"},
"sovereigns":	{"NNS"},
"sovereignty":	{"NN"},
"soviet":	{"NN","JJ"},
"sovietise":	{"VB","VBP"},
"sovietised":	{"VBD","VBN"},
"sovietises":	{"VBZ"},
"sovietising":	{"VBG"},
"sovietism":	{"NN"},
"sovietize":	{"VB","VBP"},
"sovietized":	{"VBD","VBN"},
"sovietizes":	{"VBZ"},
"sovietizing":	{"VBG"},
"sovietologist":	{"NN"},
"soviets":	{"NNS"},
"sow":	{"VB","VBP","NN"},
"sowbane":	{"NN"},
"sowbelly":	{"NN"},
"sowbread":	{"NN"},
"sowed":	{"VBD","VBN"},
"sower":	{"NN"},
"sowers":	{"NNS"},
"soweto":	{"NN"},
"sowing":	{"VBG","NN"},
"sown":	{"VBN"},
"sows":	{"VBZ","NNS"},
"soxhlet":	{"NN"},
"soy":	{"NN"},
"soya":	{"NN"},
"soybean":	{"NN"},
"soybeans":	{"NNS"},
"soymilk":	{"NN"},
"sozzled":	{"JJ"},
"sp":	{"NN"},
"spa":	{"NN"},
"space":	{"NN","VB","VBP"},
"space-age":	{"JJ","NN"},
"space-bar":	{"NN"},
"space-bars":	{"NNS"},
"space-time":	{"NN"},
"spaceborne":	{"JJ"},
"spacecraft":	{"NN","NNS"},
"spaced":	{"VBD","VBN"},
"spaced-out":	{"JJ"},
"spacefaring":	{"NN","JJ"},
"spaceflight":	{"NN"},
"spaceier":	{"JJR"},
"spaceiest":	{"JJS"},
"spaceman":	{"NN"},
"spacemen":	{"NNS"},
"spacer":	{"NN"},
"spacers":	{"NNS"},
"spaces":	{"NNS","VBZ"},
"spaceship":	{"NN"},
"spaceships":	{"NNS"},
"spacesuit":	{"NN"},
"spacesuits":	{"NNS"},
"spacewalk":	{"NN","VB","VBP"},
"spacewalked":	{"VBD","VBN"},
"spacewalker":	{"NN"},
"spacewalkers":	{"NNS"},
"spacewalking":	{"VBG"},
"spacewalks":	{"NNS","VBZ"},
"spaceward":	{"RB"},
"spacewards":	{"RB"},
"spacey":	{"JJ"},
"spacial":	{"JJ"},
"spacing":	{"NN","VBG"},
"spaciotemporal":	{"JJ"},
"spacious":	{"JJ"},
"spaciously":	{"RB"},
"spaciousness":	{"NN"},
"spackle":	{"NN","VB","VBP"},
"spackled":	{"VBD","VBN"},
"spackles":	{"VBZ"},
"spackling":	{"VBG"},
"spacy":	{"JJ"},
"spade":	{"NN"},
"spadefish":	{"NN"},
"spadefoot":	{"NN"},
"spadeful":	{"NN"},
"spades":	{"NNS"},
"spadework":	{"NN"},
"spadix":	{"NN"},
"spaghetti":	{"NN"},
"spaghettini":	{"NN"},
"spahnie":	{"NN"},
"spain":	{"NN"},
"spalacidae":	{"NN"},
"spalax":	{"NN"},
"spall":	{"NN","VB","VBP"},
"spallanzani":	{"NN"},
"spallation":	{"NN"},
"spam":	{"NN","VB","VBP"},
"spammed":	{"VBD","VBN"},
"spammer":	{"NN"},
"spamming":	{"VBG","NN"},
"spams":	{"VBZ"},
"span":	{"NN","VBP","VB"},
"spandau":	{"NN"},
"spandex":	{"NN"},
"spandrel":	{"NN"},
"spandrels":	{"NNS"},
"spandril":	{"NN"},
"spang":	{"RB"},
"spangle":	{"NN","VB","VBP"},
"spangled":	{"VBD","VBN","JJ"},
"spangles":	{"NNS","VBZ"},
"spangling":	{"VBG"},
"spangly":	{"JJ"},
"spaniard":	{"NN"},
"spaniel":	{"NN"},
"spaniels":	{"NNS"},
"spank":	{"VB","VBP","NN"},
"spanked":	{"VBD","VBN"},
"spanker":	{"NN"},
"spanking":	{"NN","JJ","VBG","RB"},
"spankings":	{"NNS"},
"spanks":	{"VBZ","NNS"},
"spanned":	{"VBN","VBD"},
"spanner":	{"NN"},
"spanners":	{"NNS"},
"spanning":	{"NN","VBG"},
"spans":	{"VBZ","NNS"},
"spar":	{"NN","VB","VBP"},
"sparaxis":	{"NN"},
"spare":	{"JJ","VB","VBP","NN"},
"spare-part":	{"NN"},
"spare-parts":	{"NNS"},
"spared":	{"VBD","VBN"},
"sparely":	{"RB"},
"spareness":	{"NN"},
"sparer":	{"NN"},
"sparerib":	{"NN"},
"spareribs":	{"NNS"},
"spares":	{"NNS","VBZ"},
"sparganiaceae":	{"NN"},
"sparganium":	{"NN"},
"sparge":	{"VB","VBP"},
"sparged":	{"VBD","VBN"},
"sparger":	{"NN"},
"sparges":	{"VBZ"},
"sparging":	{"VBG"},
"sparid":	{"NN"},
"sparidae":	{"NN"},
"sparing":	{"JJ","VBG"},
"sparingly":	{"RB"},
"spark":	{"NN","VB","VBP"},
"spark-plug":	{"NN"},
"spark-plugs":	{"NNS"},
"sparked":	{"VBD","VBN"},
"sparker":	{"NN"},
"sparking":	{"VBG"},
"sparking-plug":	{"NN"},
"sparking-plugs":	{"NNS"},
"sparkle":	{"VB","VBP","NN"},
"sparkleberry":	{"NN"},
"sparkled":	{"VBD","VBN"},
"sparkler":	{"NN"},
"sparklers":	{"NNS"},
"sparkles":	{"VBZ","NNS"},
"sparkling":	{"VBG","JJ"},
"sparkly":	{"JJ"},
"sparks":	{"NNS","VBZ"},
"sparlings":	{"NNS"},
"sparmannia":	{"NN"},
"sparred":	{"VBD","VBN"},
"sparring":	{"NN","VBG"},
"sparring-partner":	{"NN"},
"sparring-partners":	{"NNS"},
"sparrow":	{"NN"},
"sparrow-hawk":	{"NN"},
"sparrows":	{"NNS"},
"spars":	{"NNS","VBZ"},
"sparse":	{"JJ"},
"sparsely":	{"RB"},
"sparseness":	{"NN"},
"sparsity":	{"NN"},
"sparta":	{"NN"},
"spartan":	{"NN","JJ"},
"spartina":	{"NN"},
"spartium":	{"NN"},
"spas":	{"NNS"},
"spasm":	{"NN"},
"spasmodic":	{"JJ"},
"spasmodically":	{"RB"},
"spasmolysis":	{"NN"},
"spasmolytic":	{"NN"},
"spasms":	{"NNS"},
"spassky":	{"NN"},
"spastic":	{"JJ","NN"},
"spasticity":	{"NN"},
"spastics":	{"NNS"},
"spat":	{"NN","VB","VBP","VBD","VBN"},
"spatangoida":	{"NN"},
"spatchcock":	{"NN","VB","VBP"},
"spatchcocked":	{"VBD","VBN"},
"spatchcocking":	{"VBG"},
"spatchcocks":	{"VBZ"},
"spate":	{"NN"},
"spates":	{"NNS"},
"spathe":	{"NN"},
"spathiphyllum":	{"NN"},
"spatial":	{"JJ"},
"spatiality":	{"NN"},
"spatially":	{"RB"},
"spatiotemporal":	{"JJ"},
"spats":	{"NNS","VBZ"},
"spatted":	{"VBD","VBN"},
"spatter":	{"VB","VBP","NN"},
"spatterdock":	{"NN"},
"spattered":	{"VBD","VBN"},
"spattering":	{"NN","VBG"},
"spatters":	{"VBZ","NNS"},
"spatting":	{"VBG"},
"spatula":	{"NN"},
"spatulas":	{"NNS"},
"spatulate":	{"JJ"},
"spavin":	{"NN"},
"spavined":	{"JJ"},
"spawl":	{"NN"},
"spawn":	{"NN","VB","VBP"},
"spawned":	{"VBD","VBN"},
"spawner":	{"NN"},
"spawning":	{"VBG"},
"spawns":	{"VBZ"},
"spay":	{"VB","VBP"},
"spayed":	{"VBD","VBN"},
"spaying":	{"VBG"},
"spays":	{"VBZ"},
"speak":	{"VB","VBP"},
"speak-easies":	{"NNS"},
"speak-easy":	{"NN"},
"speakable":	{"JJ"},
"speakeasies":	{"NNS"},
"speakeasy":	{"NN"},
"speaker":	{"NN"},
"speakerphone":	{"NN"},
"speakerphones":	{"NNS"},
"speakers":	{"NNS"},
"speakership":	{"NN"},
"speaking":	{"VBG","NN"},
"speaks":	{"VBZ"},
"spear":	{"NN","VB","VBP"},
"speared":	{"VBD","VBN"},
"spearfish":	{"NN"},
"spearhead":	{"VB","VBP","NN"},
"spearheaded":	{"VBD","VBN"},
"spearheading":	{"VBG"},
"spearheads":	{"VBZ"},
"spearing":	{"VBG"},
"spearmint":	{"NN"},
"spears":	{"NNS","VBZ"},
"spec":	{"NN"},
"special":	{"JJ","NN"},
"specialisation":	{"NN"},
"specialisations":	{"NNS"},
"specialise":	{"VB","VBP"},
"specialised":	{"VBD","VBN","JJ"},
"specialiser":	{"NN"},
"specialises":	{"VBZ"},
"specialising":	{"VBG"},
"specialism":	{"NN"},
"specialisms":	{"NNS"},
"specialist":	{"NN"},
"specialistic":	{"JJ"},
"specialists":	{"NNS"},
"specialities":	{"NNS"},
"speciality":	{"NN"},
"specialization":	{"NN"},
"specializations":	{"NNS"},
"specialize":	{"VB","VBP"},
"specialized":	{"JJ","VBD","VBN"},
"specializer":	{"NN"},
"specializes":	{"VBZ"},
"specializing":	{"VBG"},
"specially":	{"RB"},
"specialness":	{"NN"},
"specials":	{"NNS"},
"specialties":	{"NNS"},
"specialty":	{"NN"},
"speciate":	{"VB","VBP"},
"speciation":	{"NN"},
"specie":	{"NN"},
"species":	{"NNS","NN"},
"specifiable":	{"JJ"},
"specific":	{"JJ","NN"},
"specifically":	{"RB"},
"specification":	{"NN"},
"specifications":	{"NNS"},
"specificity":	{"NN"},
"specifics":	{"NNS"},
"specified":	{"VBD","VBN"},
"specifier":	{"NN"},
"specifies":	{"VBZ"},
"specify":	{"VB","VBP"},
"specifying":	{"VBG"},
"specimen":	{"NN"},
"specimens":	{"NNS"},
"specimentalia":	{"NN"},
"speciosum":	{"NN"},
"specious":	{"JJ"},
"speciously":	{"RB"},
"speciousness":	{"NN"},
"speck":	{"NN","VB","VBP"},
"specked":	{"VBD","VBN"},
"specking":	{"VBG"},
"speckle":	{"NN","VB","VBP"},
"speckled":	{"JJ","VBD","VBN"},
"speckles":	{"NNS","VBZ"},
"speckless":	{"JJ"},
"speckling":	{"VBG"},
"specks":	{"NNS","VBZ"},
"specs":	{"NNS"},
"spectacle":	{"NN"},
"spectacled":	{"JJ"},
"spectacles":	{"NNS"},
"spectacular":	{"JJ","NN"},
"spectacularly":	{"RB"},
"spectaculars":	{"NNS"},
"spectate":	{"VB","VBP"},
"spectated":	{"VBD","VBN"},
"spectates":	{"VBZ"},
"spectating":	{"VBG"},
"spectator":	{"NN"},
"spectators":	{"NNS"},
"specter":	{"NN"},
"specters":	{"NNS"},
"spectinomycin":	{"NN"},
"spector":	{"NN"},
"spectra":	{"NNS"},
"spectral":	{"JJ"},
"spectrally":	{"RB"},
"spectre":	{"NN"},
"spectres":	{"NNS"},
"spectrogram":	{"NN"},
"spectrograph":	{"NN"},
"spectrographic":	{"JJ"},
"spectrographically":	{"RB"},
"spectrometer":	{"NN"},
"spectrometric":	{"JJ"},
"spectrometry":	{"NN"},
"spectrophotometer":	{"NN"},
"spectrophotometric":	{"JJ"},
"spectroscope":	{"NN"},
"spectroscopic":	{"JJ"},
"spectroscopical":	{"JJ"},
"spectroscopy":	{"NN"},
"spectrum":	{"NN"},
"spectrums":	{"NNS"},
"specular":	{"JJ"},
"speculate":	{"VB","VBP"},
"speculated":	{"VBD","VBN"},
"speculates":	{"VBZ"},
"speculating":	{"VBG"},
"speculation":	{"NN"},
"speculations":	{"NNS"},
"speculative":	{"JJ"},
"speculatively":	{"RB"},
"speculativeness":	{"NN"},
"speculator":	{"NN"},
"speculators":	{"NNS"},
"speculum":	{"NN"},
"sped":	{"VBD","VBN"},
"speech":	{"NN"},
"speech-day":	{"NN"},
"speech-days":	{"NNS"},
"speech-reading":	{"NN"},
"speeches":	{"NNS"},
"speechified":	{"VBD","VBN"},
"speechifier":	{"NN"},
"speechifies":	{"VBZ"},
"speechify":	{"VB","VBP"},
"speechifying":	{"VBG"},
"speechless":	{"JJ"},
"speechlessly":	{"RB"},
"speechlessness":	{"NN"},
"speechmaker":	{"NN"},
"speechmaking":	{"NN"},
"speechwriter":	{"NN"},
"speechwriters":	{"NNS"},
"speed":	{"NN","VB","VBP"},
"speed-indicator":	{"NN"},
"speed-indicators":	{"NNS"},
"speed-reading":	{"NN"},
"speed-up":	{"NN"},
"speedboat":	{"NN"},
"speedboats":	{"NNS"},
"speeded":	{"VBD","VBN"},
"speeder":	{"NN"},
"speeders":	{"NNS"},
"speedier":	{"JJR"},
"speediest":	{"JJS"},
"speedily":	{"RB"},
"speediness":	{"NN"},
"speeding":	{"VBG","NN"},
"speedometer":	{"NN"},
"speedometers":	{"NNS"},
"speeds":	{"NNS","VBZ"},
"speedskater":	{"NN"},
"speedup":	{"NN"},
"speedway":	{"NN"},
"speedways":	{"NNS"},
"speedwell":	{"NN"},
"speedy":	{"JJ"},
"speer":	{"NN"},
"speke":	{"NN"},
"spelaeological":	{"JJ"},
"spelaeologist":	{"NN"},
"spelaeologists":	{"NNS"},
"spelaeology":	{"NN"},
"speleological":	{"JJ"},
"speleologist":	{"NN"},
"speleologists":	{"NNS"},
"speleology":	{"NN"},
"spell":	{"NN","VB","VBP"},
"spell-check":	{"VB","VBP"},
"spell-checked":	{"VBD","VBN"},
"spell-checker":	{"NN"},
"spell-checkers":	{"NNS"},
"spell-checking":	{"VBG"},
"spell-checks":	{"VBZ"},
"spellbind":	{"VB","VBP"},
"spellbinder":	{"NN"},
"spellbinders":	{"NNS"},
"spellbinding":	{"JJ","VBG"},
"spellbinds":	{"VBZ"},
"spellbound":	{"JJ","VBD","VBN"},
"spelldown":	{"NN"},
"spelled":	{"VBD","VBN"},
"speller":	{"NN"},
"spellers":	{"NNS"},
"spelling":	{"NN","VBG"},
"spellings":	{"NNS"},
"spells":	{"VBZ","NNS"},
"spelt":	{"VBD","VBN"},
"spelter":	{"NN"},
"spelunk":	{"VB","VBP"},
"spelunked":	{"VBD","VBN"},
"spelunker":	{"NN"},
"spelunkers":	{"NNS"},
"spelunking":	{"VBG","NN"},
"spelunks":	{"VBZ"},
"spencer":	{"NN"},
"spend":	{"VB","VBP"},
"spendable":	{"JJ"},
"spender":	{"NN"},
"spenders":	{"NNS"},
"spending":	{"NN","VBG"},
"spends":	{"VBZ"},
"spendthrift":	{"NN","JJ"},
"spendthrifts":	{"NNS"},
"spengler":	{"NN"},
"spenglerian":	{"JJ"},
"spenser":	{"NN"},
"spent":	{"VBD","VBN","JJ"},
"spergula":	{"NN"},
"spergularia":	{"NN"},
"sperm":	{"NN","NNS"},
"spermaceti":	{"NN"},
"spermatic":	{"JJ"},
"spermatid":	{"NN"},
"spermatocele":	{"NN"},
"spermatocide":	{"NN"},
"spermatocyte":	{"NN"},
"spermatogenesis":	{"NN"},
"spermatophyta":	{"NN"},
"spermatophyte":	{"NN"},
"spermatozoa":	{"NNS"},
"spermatozoan":	{"NN"},
"spermatozoid":	{"NN"},
"spermatozoon":	{"NN"},
"spermicidal":	{"JJ"},
"spermicide":	{"NN"},
"spermicides":	{"NNS"},
"spermophile":	{"NN"},
"spermophilus":	{"NN"},
"spermous":	{"JJ"},
"sperms":	{"NNS"},
"sperry":	{"NN"},
"spew":	{"VB","VBP"},
"spewed":	{"VBD","VBN"},
"spewer":	{"NN"},
"spewing":	{"VBG"},
"spews":	{"VBZ"},
"spf":	{"NN"},
"sphacelate":	{"VB","VBP"},
"sphacele":	{"NN"},
"sphacelotheca":	{"NN"},
"sphacelus":	{"NN"},
"sphaeralcea":	{"NN"},
"sphaeriaceae":	{"NN"},
"sphaeriales":	{"NNS"},
"sphaerobolaceae":	{"NN"},
"sphaerocarpaceae":	{"NN"},
"sphaerocarpales":	{"NNS"},
"sphaerocarpos":	{"NN"},
"sphaerocarpus":	{"NN"},
"sphagna":	{"NNS"},
"sphagnales":	{"NNS"},
"sphagnum":	{"NN"},
"sphagnums":	{"NNS"},
"sphalerite":	{"NN"},
"sphecidae":	{"NN"},
"sphecius":	{"NN"},
"sphecoid":	{"NN"},
"sphecoidea":	{"NN"},
"sphecotheres":	{"NNS"},
"sphenion":	{"NN"},
"spheniscidae":	{"NN"},
"sphenisciformes":	{"NNS"},
"spheniscus":	{"NN"},
"sphenodon":	{"NN"},
"sphenoid":	{"JJ","NN"},
"sphenopsida":	{"NN"},
"sphere":	{"NN","VB","VBP"},
"sphered":	{"VBD","VBN"},
"spheres":	{"VBZ","NNS"},
"spheric":	{"JJ"},
"spherical":	{"JJ"},
"spherically":	{"RB"},
"sphericalness":	{"NN"},
"sphericity":	{"NN"},
"sphering":	{"VBG"},
"spherocyte":	{"NN"},
"spheroid":	{"NN"},
"spheroidal":	{"JJ"},
"spheroids":	{"NNS"},
"spherometer":	{"NN"},
"spherule":	{"NN"},
"spherules":	{"NNS"},
"sphincter":	{"NN"},
"sphincters":	{"NNS"},
"sphingid":	{"NN"},
"sphingidae":	{"NN"},
"sphingine":	{"JJ"},
"sphinx":	{"NN"},
"sphygmomanometer":	{"NN"},
"sphynxes":	{"NNS"},
"sphyraena":	{"NN"},
"sphyraenidae":	{"NN"},
"sphyrapicus":	{"NN"},
"sphyrna":	{"NN"},
"sphyrnidae":	{"NN"},
"spic":	{"NN"},
"spic-and-span":	{"JJ"},
"spica":	{"NN"},
"spicate":	{"JJ"},
"spiccato":	{"NN"},
"spice":	{"NN","VB","VBP"},
"spiceberry":	{"NN"},
"spicebush":	{"NN"},
"spiced":	{"JJ","VBD","VBN"},
"spicemill":	{"NN"},
"spicery":	{"NN"},
"spices":	{"NNS","VBZ"},
"spicier":	{"JJR"},
"spiciest":	{"JJS"},
"spicily":	{"RB"},
"spiciness":	{"NN"},
"spicing":	{"VBG"},
"spick":	{"JJ"},
"spick-and-span":	{"JJ"},
"spics":	{"NNS"},
"spicule":	{"NN"},
"spiculum":	{"NN"},
"spicy":	{"JJ"},
"spider":	{"NN","VB","VBP"},
"spider-man":	{"NN"},
"spider-men":	{"NNS"},
"spidered":	{"VBD","VBN"},
"spiderflower":	{"NN"},
"spidering":	{"VBG"},
"spiderish":	{"JJ"},
"spiderlike":	{"JJ","RB"},
"spiderly":	{"JJ"},
"spiders":	{"NNS","VBZ"},
"spiderweb":	{"NN"},
"spiderwebs":	{"NNS"},
"spiderwort":	{"NN"},
"spidery":	{"JJ"},
"spied":	{"VBD","VBN"},
"spiegel":	{"NN"},
"spiegeleisen":	{"NN"},
"spiel":	{"NN","VB","VBP"},
"spielberg":	{"NN"},
"spieled":	{"VBD","VBN"},
"spieling":	{"VBG"},
"spiels":	{"NNS","VBZ"},
"spies":	{"NNS","VBZ"},
"spiff":	{"NN"},
"spiffing":	{"JJ"},
"spiffy":	{"JJ"},
"spigot":	{"NN"},
"spigots":	{"NNS"},
"spik":	{"NN"},
"spike":	{"NN","VB","VBP"},
"spiked":	{"JJ","VBD","VBN"},
"spikelet":	{"NN"},
"spikelike":	{"JJ"},
"spikemoss":	{"NN"},
"spikenard":	{"NN"},
"spikes":	{"NNS","VBZ"},
"spikier":	{"JJR"},
"spikiest":	{"JJS"},
"spikiness":	{"NN"},
"spiking":	{"VBG"},
"spiky":	{"JJ"},
"spile":	{"NN"},
"spill":	{"VB","VBP","NN"},
"spillage":	{"NN"},
"spillages":	{"NNS"},
"spillane":	{"NN"},
"spilled":	{"VBD","VBN"},
"spiller":	{"NN"},
"spillikin":	{"NN"},
"spillikins":	{"NNS"},
"spilling":	{"VBG","NN"},
"spillover":	{"NN"},
"spillovers":	{"NNS"},
"spills":	{"NNS","VBZ"},
"spillway":	{"NN"},
"spilogale":	{"NN"},
"spilt":	{"VBD","VBN"},
"spin":	{"VB","VBP","NN"},
"spin-dried":	{"VBD","VBN"},
"spin-dries":	{"VBZ"},
"spin-dry":	{"VB","VBP"},
"spin-drying":	{"VBG"},
"spin-off":	{"NN"},
"spin-offs":	{"NNS"},
"spinach":	{"NN"},
"spinacia":	{"NN"},
"spinal":	{"JJ"},
"spinally":	{"RB"},
"spindle":	{"NN","VB","VBP"},
"spindle-legged":	{"JJ"},
"spindleberry":	{"NN"},
"spindled":	{"VBD","VBN"},
"spindlelegs":	{"NNS","NN"},
"spindles":	{"NNS","VBZ"},
"spindleshanks":	{"NNS"},
"spindlier":	{"JJR"},
"spindliest":	{"JJS"},
"spindling":	{"VBG"},
"spindly":	{"JJ"},
"spindrift":	{"NN"},
"spine":	{"NN"},
"spine-chiller":	{"NN"},
"spine-chillers":	{"NNS"},
"spine-chilling":	{"JJ"},
"spinel":	{"NN"},
"spineless":	{"JJ"},
"spinelessness":	{"NN"},
"spinet":	{"NN"},
"spininess":	{"NN"},
"spinmeister":	{"NN"},
"spinnability":	{"NN"},
"spinnable":	{"JJ"},
"spinnaker":	{"NN"},
"spinnbar":	{"JJ"},
"spinnbarkeit":	{"NN"},
"spinner":	{"NN"},
"spinneret":	{"NN"},
"spinners":	{"NNS"},
"spinney":	{"NN"},
"spinneys":	{"NNS"},
"spinning":	{"VBG","NN","JJ"},
"spinoff":	{"NN","JJ"},
"spinoffs":	{"NNS"},
"spinose":	{"JJ"},
"spinous":	{"JJ"},
"spins":	{"VBZ","NNS"},
"spinster":	{"NN"},
"spinsterhood":	{"NN"},
"spinsters":	{"NNS"},
"spinus":	{"NN"},
"spiny":	{"JJ"},
"spiracle":	{"NN"},
"spiraea":	{"NN"},
"spiral":	{"NN","JJ","VB","VBP"},
"spiraled":	{"VBD","VBN"},
"spiraling":	{"JJ","VBG"},
"spiralled":	{"VBD","VBN"},
"spiralling":	{"VBG","JJ"},
"spirally":	{"RB"},
"spirals":	{"NNS","VBZ"},
"spirant":	{"JJ","NN"},
"spiranthes":	{"NNS"},
"spire":	{"NN","VB","VBP"},
"spirea":	{"NN"},
"spired":	{"VBD","VBN"},
"spires":	{"NNS","VBZ"},
"spirilla":	{"NN"},
"spirillaceae":	{"NN"},
"spirillum":	{"NN"},
"spiring":	{"VBG"},
"spirit":	{"NN","VBP","VB"},
"spirit-lamp":	{"NN"},
"spirit-level":	{"NN"},
"spirit-levels":	{"NNS"},
"spirited":	{"JJ","VBD","VBN"},
"spiritedly":	{"RB"},
"spiritedness":	{"NN"},
"spiriting":	{"VBG"},
"spiritism":	{"NN"},
"spiritless":	{"JJ"},
"spiritlessness":	{"NN"},
"spirito":	{"NN"},
"spiritous":	{"JJ"},
"spirits":	{"NNS","VBZ"},
"spiritual":	{"JJ","NN"},
"spiritualisation":	{"NN"},
"spiritualise":	{"VB","VBP"},
"spiritualism":	{"NN"},
"spiritualist":	{"NN"},
"spiritualistic":	{"JJ"},
"spiritualists":	{"NNS"},
"spirituality":	{"NN"},
"spiritualization":	{"NN"},
"spiritualize":	{"VB","VBP"},
"spiritually":	{"RB"},
"spirituals":	{"NNS"},
"spiritualty":	{"NN"},
"spirituous":	{"JJ"},
"spirochaeta":	{"NN"},
"spirochaetaceae":	{"NN"},
"spirochaetales":	{"NNS"},
"spirochaete":	{"NN"},
"spirochete":	{"NN"},
"spirodela":	{"NN"},
"spirogram":	{"NN"},
"spirograph":	{"NN"},
"spirogyra":	{"NN"},
"spirometer":	{"NN"},
"spirometry":	{"NN"},
"spironolactone":	{"NN"},
"spirt":	{"VB","VBP","NN"},
"spirted":	{"VBD","VBN"},
"spirting":	{"VBG"},
"spirts":	{"VBZ","NNS"},
"spirula":	{"NN"},
"spirulidae":	{"NN"},
"spit":	{"VB","VBP","NN","VBD","VBN"},
"spitball":	{"NN"},
"spitballs":	{"NNS"},
"spite":	{"NN","VB","VBP"},
"spited":	{"VBD","VBN"},
"spiteful":	{"JJ"},
"spitefully":	{"RB"},
"spitefulness":	{"NN"},
"spites":	{"VBZ"},
"spitfire":	{"NN"},
"spiting":	{"VBG"},
"spits":	{"VBZ","NNS"},
"spitsbergen":	{"NN"},
"spitter":	{"NN"},
"spitting":	{"VBG"},
"spittle":	{"NN"},
"spittlebug":	{"NN"},
"spittoon":	{"NN"},
"spittoons":	{"NNS"},
"spitz":	{"NN"},
"spitzbergen":	{"NN"},
"spiv":	{"NN"},
"spivish":	{"JJ"},
"spivs":	{"NNS"},
"spizella":	{"NN"},
"splanchnic":	{"JJ"},
"splash":	{"VB","VBP","NN"},
"splash-down":	{"NN"},
"splash-guard":	{"NN"},
"splashboard":	{"NN"},
"splashdown":	{"NN"},
"splashdowns":	{"NNS"},
"splashed":	{"VBD","VBN"},
"splasher":	{"NN"},
"splashes":	{"NNS","VBZ"},
"splashiness":	{"NN"},
"splashing":	{"VBG"},
"splashy":	{"JJ"},
"splat":	{"NN","VBP","VB"},
"splats":	{"VBZ"},
"splatted":	{"VBD","VBN"},
"splatter":	{"VB","VBP","NN"},
"splattered":	{"VBD","VBN"},
"splattering":	{"VBG"},
"splatters":	{"VBZ"},
"splatting":	{"VBG"},
"splay":	{"VB","VBP","JJ"},
"splay-footed":	{"NN"},
"splayed":	{"VBD","VBN"},
"splayfoot":	{"NN"},
"splayfooted":	{"JJ"},
"splaying":	{"VBG"},
"splays":	{"VBZ"},
"spleen":	{"NN"},
"spleens":	{"NNS"},
"spleenwort":	{"NN"},
"splendid":	{"JJ"},
"splendidly":	{"RB"},
"splendiferous":	{"JJ"},
"splendor":	{"NN"},
"splendors":	{"NNS"},
"splendour":	{"NN"},
"splendours":	{"NNS"},
"splenectomy":	{"NN"},
"splenetic":	{"JJ"},
"splenic":	{"JJ"},
"splenitis":	{"NN"},
"splenius":	{"NN"},
"splenomegaly":	{"NN"},
"splice":	{"VB","VBP","NN"},
"spliced":	{"VBD","VBN"},
"splicer":	{"NN"},
"splicers":	{"NNS"},
"splices":	{"VBZ","NNS"},
"splicing":	{"VBG"},
"spliff":	{"NN"},
"spliffs":	{"NNS"},
"spline":	{"NN","VB","VBP"},
"splined":	{"VBD","VBN"},
"splines":	{"NNS","VBZ"},
"splining":	{"VBG"},
"splint":	{"NN","VB","VBP"},
"splinted":	{"VBD","VBN"},
"splinter":	{"NN","VB","VBP"},
"splintered":	{"VBD","VBN"},
"splintering":	{"VBG"},
"splinterless":	{"JJ"},
"splinterproof":	{"JJ"},
"splinters":	{"NNS","VBZ"},
"splintery":	{"JJ"},
"splinting":	{"VBG"},
"splints":	{"NNS","VBZ"},
"split":	{"NN","VBN","VB","VBD","JJ","VBP"},
"split-level":	{"JJ"},
"splits":	{"NNS","VBZ"},
"splitsaw":	{"NN"},
"splitsville":	{"NN"},
"splitter":	{"NN"},
"splitting":	{"VBG","JJ","NN"},
"splitworm":	{"NN"},
"splodge":	{"NN"},
"splodges":	{"NNS"},
"splodgy":	{"JJ"},
"splosh":	{"VB","VBP","NN"},
"splotch":	{"NN","VB","VBP"},
"splotched":	{"VBD","VBN"},
"splotches":	{"NNS","VBZ"},
"splotching":	{"VBG"},
"splurge":	{"VB","VBP","NN"},
"splurged":	{"VBD","VBN"},
"splurges":	{"VBZ","NNS"},
"splurging":	{"VBG"},
"splutter":	{"VB","VBP","NN"},
"spluttered":	{"VBD","VBN"},
"spluttering":	{"VBG"},
"splutters":	{"NNS","VBZ"},
"spock":	{"NN"},
"spodoptera":	{"NN"},
"spodumene":	{"NN"},
"spoil":	{"VB","NN","VBP"},
"spoilable":	{"JJ"},
"spoilage":	{"NN"},
"spoilation":	{"NN"},
"spoiled":	{"JJ","VBD","VBN"},
"spoiler":	{"NN"},
"spoilers":	{"NNS"},
"spoilery":	{"JJ"},
"spoiling":	{"VBG"},
"spoils":	{"NNS","VBZ"},
"spoilsport":	{"NN"},
"spoilsports":	{"NNS"},
"spoilt":	{"VBD","VBN","JJ"},
"spokane":	{"NN"},
"spoke":	{"VBD","NN","VB","VBP"},
"spoked":	{"VBD","VBN"},
"spoken":	{"VBN","JJ"},
"spokes":	{"NNS","VBZ"},
"spokeshave":	{"NN"},
"spokesman":	{"NN"},
"spokesmen":	{"NNS"},
"spokespeople":	{"NNS"},
"spokesperson":	{"NN"},
"spokespersons":	{"NNS"},
"spokeswoman":	{"NN"},
"spokeswomen":	{"NNS"},
"spokewoman":	{"NN"},
"spoking":	{"VBG"},
"spoliation":	{"NN"},
"spondaic":	{"JJ"},
"spondee":	{"NN"},
"spondias":	{"NN"},
"spondylarthritis":	{"NN"},
"spondylitis":	{"NN"},
"spondylolisthesis":	{"NN"},
"spondylopathy":	{"NN"},
"sponge":	{"NN","VB","VBP"},
"sponge-bag":	{"NN"},
"sponge-bags":	{"NNS"},
"sponge-cake":	{"NN"},
"sponge-cakes":	{"NNS"},
"sponge-pudding":	{"NN"},
"sponge-puddings":	{"NNS"},
"sponged":	{"VBD","VBN"},
"spongefly":	{"NN"},
"spongelike":	{"JJ"},
"sponger":	{"NN"},
"spongers":	{"NNS"},
"sponges":	{"NNS","VBZ"},
"spongier":	{"JJR"},
"spongiest":	{"JJS"},
"spongillafly":	{"NN"},
"sponginess":	{"NN"},
"sponging":	{"NN","VBG"},
"spongioblast":	{"NN"},
"spongioblastoma":	{"NN"},
"spongy":	{"JJ"},
"sponsor":	{"NN","VB","VBP"},
"sponsored":	{"VBN","VBD"},
"sponsoring":	{"VBG"},
"sponsors":	{"NNS","VBZ"},
"sponsorship":	{"NN"},
"sponsorships":	{"NNS"},
"spontaneity":	{"NN"},
"spontaneous":	{"JJ"},
"spontaneously":	{"RB"},
"spontaneousness":	{"NN"},
"spoof":	{"NN","VB","VBP"},
"spoofed":	{"VBD","VBN"},
"spoofing":	{"VBG"},
"spoofs":	{"NNS","VBZ"},
"spook":	{"NN","VB","VBP"},
"spooked":	{"VBD","VBN","JJ"},
"spookier":	{"JJR"},
"spookiest":	{"JJS"},
"spookily":	{"RB"},
"spookiness":	{"NN"},
"spooking":	{"VBG"},
"spooks":	{"VBZ","NNS"},
"spooky":	{"JJ"},
"spool":	{"NN","VB","VBP"},
"spooled":	{"VBD","VBN"},
"spooling":	{"VBG"},
"spools":	{"NNS","VBZ"},
"spoon":	{"NN","VB","VBP"},
"spoon-fed":	{"JJ","VBD","VBN"},
"spoon-feed":	{"VB","VBP"},
"spoon-feeding":	{"VBG"},
"spoon-feeds":	{"VBZ"},
"spoonbill":	{"NN"},
"spoonbills":	{"NNS"},
"spoondrift":	{"NN"},
"spooned":	{"VBD","VBN"},
"spoonerism":	{"NN"},
"spoonerisms":	{"NNS"},
"spoonflower":	{"NN"},
"spoonful":	{"NN"},
"spoonfuls":	{"NNS"},
"spooning":	{"VBG"},
"spoons":	{"VBZ","NNS"},
"spoor":	{"NN"},
"sporadic":	{"JJ"},
"sporadically":	{"RB"},
"sporangiophore":	{"NN"},
"sporangium":	{"NN"},
"sporanox":	{"NN"},
"spore":	{"NN"},
"spores":	{"NNS"},
"spork":	{"NN"},
"sporobolus":	{"NN"},
"sporocarp":	{"NN"},
"sporogenous":	{"JJ"},
"sporophore":	{"NN"},
"sporophyl":	{"NN"},
"sporophyll":	{"NN"},
"sporophyte":	{"NN"},
"sporotrichosis":	{"NN"},
"sporozoa":	{"NN"},
"sporozoan":	{"NN"},
"sporozoite":	{"NN"},
"sporran":	{"NN"},
"sporrans":	{"NNS"},
"sport":	{"NN","VBP","VB"},
"sportdom":	{"NN"},
"sported":	{"VBD","VBN"},
"sportfishing":	{"NN"},
"sportier":	{"JJR"},
"sportiest":	{"JJS"},
"sportif":	{"FW"},
"sportily":	{"RB"},
"sportiness":	{"NN"},
"sporting":	{"JJ","VBG"},
"sportingly":	{"RB"},
"sportive":	{"JJ"},
"sportively":	{"RB"},
"sportiveness":	{"NN"},
"sports":	{"NNS","VBZ","NN"},
"sports-editor":	{"NN"},
"sports-editors":	{"NNS"},
"sportscast":	{"NN"},
"sportscaster":	{"NN"},
"sportscasters":	{"NNS"},
"sportscasts":	{"NNS"},
"sportsman":	{"NN"},
"sportsmanlike":	{"JJ"},
"sportsmanship":	{"NN"},
"sportsmen":	{"NNS"},
"sportswear":	{"NN"},
"sportswoman":	{"NN"},
"sportswomen":	{"NNS"},
"sportswriter":	{"NN"},
"sportswriters":	{"NNS"},
"sporty":	{"JJ"},
"sporulate":	{"VB","VBP"},
"sporulated":	{"VBD","VBN"},
"sporulates":	{"VBZ"},
"sporulating":	{"VBG"},
"sporulation":	{"NN"},
"spot":	{"NN","VB","VBP","JJ"},
"spot-check":	{"NN","VB","VBP"},
"spot-checked":	{"VBD","VBN"},
"spot-checking":	{"NN","VBG"},
"spot-checks":	{"NNS","VBZ"},
"spot-on":	{"JJ"},
"spot-weld":	{"VB","VBP","NN"},
"spot-welded":	{"VBD","VBN"},
"spot-welder":	{"NN"},
"spot-welding":	{"VBG"},
"spot-welds":	{"VBZ","NNS"},
"spotless":	{"JJ"},
"spotlessly":	{"RB"},
"spotlessness":	{"NN"},
"spotlight":	{"NN","VB","VBP"},
"spotlighted":	{"VBD","VBN"},
"spotlighting":	{"VBG"},
"spotlights":	{"NNS","VBZ"},
"spotlit":	{"VBD","VBN","JJ"},
"spots":	{"NNS","VBZ"},
"spotsylvania":	{"NN"},
"spotted":	{"VBD","VBN","JJ"},
"spotter":	{"NN"},
"spotters":	{"NNS"},
"spottier":	{"JJR"},
"spottiest":	{"JJS"},
"spotting":	{"NN","VBG"},
"spotty":	{"JJ"},
"spousal":	{"JJ"},
"spouse":	{"NN"},
"spouses":	{"NNS"},
"spout":	{"NN","VB","VBP"},
"spouted":	{"VBD","JJ","VBN"},
"spouter":	{"NN"},
"spouting":	{"NN","VBG"},
"spouts":	{"NNS","VBZ"},
"sprachgefuhl":	{"NN"},
"sprag":	{"NN"},
"spraguea":	{"NN"},
"sprain":	{"VB","VBP","NN"},
"sprained":	{"VBD","VBN","JJ"},
"spraining":	{"VBG"},
"sprains":	{"NNS","VBZ"},
"sprang":	{"VBD"},
"sprat":	{"NN"},
"sprats":	{"NNS"},
"sprawl":	{"VB","VBP","NN"},
"sprawled":	{"VBD","VBN","JJ"},
"sprawler":	{"NN"},
"sprawling":	{"JJ","VBG"},
"sprawls":	{"VBZ"},
"sprawly":	{"JJ"},
"spray":	{"NN","VB","VBP"},
"spray-gun":	{"NN"},
"spray-guns":	{"NNS"},
"sprayed":	{"VBD","VBN"},
"sprayer":	{"NN"},
"sprayers":	{"NNS"},
"spraying":	{"NN","VBG"},
"sprays":	{"NNS","VBZ"},
"spread":	{"VBD","VBN","VB","VBP","NN"},
"spread-eagle":	{"VB","VBP"},
"spread-eagled":	{"VBD","VBN","JJ","RB"},
"spread-eagles":	{"VBZ"},
"spread-eagling":	{"VBG"},
"spread-out":	{"JJ"},
"spreadeagled":	{"JJ","RB"},
"spreader":	{"NN"},
"spreadhead":	{"NN"},
"spreading":	{"VBG"},
"spreads":	{"VBZ","NNS"},
"spreadsheet":	{"NN"},
"spreadsheets":	{"NNS"},
"sprechgesang":	{"NN"},
"sprechstimme":	{"NN"},
"spree":	{"NN"},
"sprees":	{"NNS"},
"sprier":	{"JJR"},
"spriest":	{"JJS"},
"sprig":	{"NN","VB","VBP"},
"sprigged":	{"JJ","VBD","VBN"},
"sprigger":	{"NN"},
"sprigging":	{"VBG"},
"sprightlier":	{"JJR"},
"sprightliest":	{"JJS"},
"sprightliness":	{"NN"},
"sprightly":	{"JJ"},
"sprigs":	{"NNS","VBZ"},
"sprigtail":	{"NN"},
"spring":	{"NN","VB","VBP"},
"spring-clean":	{"VB","VBP","NN"},
"spring-cleaned":	{"VBD","VBN"},
"spring-cleaning":	{"VBG","NN"},
"spring-cleans":	{"VBZ"},
"spring-loaded":	{"JJ"},
"spring-tide":	{"NN"},
"spring-tides":	{"NNS"},
"springboard":	{"NN"},
"springboards":	{"NNS"},
"springbok":	{"NN","NNS"},
"springboks":	{"NNS"},
"springbuck":	{"NN","NNS"},
"springbucks":	{"NNS"},
"springer":	{"NN"},
"springfield":	{"NN"},
"springier":	{"JJR"},
"springiest":	{"JJS"},
"springiness":	{"NN"},
"springing":	{"VBG"},
"springless":	{"JJ"},
"springlike":	{"JJ"},
"springs":	{"NNS","VBZ"},
"springtail":	{"NN"},
"springtide":	{"NN"},
"springtime":	{"NN"},
"springy":	{"JJ"},
"sprinkle":	{"VB","VBP","NN"},
"sprinkled":	{"VBD","VBN"},
"sprinkler":	{"NN"},
"sprinklers":	{"NNS"},
"sprinkles":	{"VBZ","NNS"},
"sprinkling":	{"NN","VBG"},
"sprint":	{"VB","VBP","NN"},
"sprinted":	{"VBD","VBN"},
"sprinter":	{"NN"},
"sprinters":	{"NNS"},
"sprinting":	{"VBG"},
"sprints":	{"NNS","VBZ"},
"sprit":	{"NN"},
"sprite":	{"NN"},
"sprites":	{"NNS"},
"spritsail":	{"NN"},
"spritz":	{"VB","VBP","NN"},
"spritzed":	{"VBD","VBN"},
"spritzer":	{"NN"},
"spritzers":	{"NNS"},
"spritzes":	{"VBZ"},
"spritzing":	{"VBG"},
"sprocket":	{"NN"},
"sprocket-wheel":	{"NN"},
"sprockets":	{"NNS"},
"sprog":	{"NN"},
"sprogs":	{"NNS"},
"sprout":	{"VB","VBP","NN"},
"sprouted":	{"VBD","VBN"},
"sprouting":	{"VBG"},
"sprouts":	{"NNS","VBZ"},
"spruce":	{"VB","VBP","JJ","NN"},
"spruced":	{"VBD","VBN"},
"sprucely":	{"RB"},
"spruceness":	{"NN"},
"spruces":	{"VBZ","NNS"},
"sprucing":	{"VBG"},
"sprue":	{"NN"},
"sprung":	{"VBN","JJ"},
"spry":	{"JJ"},
"spryly":	{"RB"},
"spryness":	{"NN"},
"spud":	{"NN"},
"spuds":	{"NNS"},
"spue":	{"VB","VBP"},
"spume":	{"NN"},
"spumoni":	{"NN"},
"spumy":	{"JJ"},
"spun":	{"VBD","VBN"},
"spunk":	{"NN"},
"spunkier":	{"JJR"},
"spunkiest":	{"JJS"},
"spunky":	{"JJ"},
"spur":	{"NN","VB","VBP"},
"spur-of-the-moment":	{"JJ"},
"spurge":	{"NN"},
"spurious":	{"JJ"},
"spuriously":	{"RB"},
"spuriousness":	{"NN"},
"spurn":	{"VB","VBP","NN"},
"spurned":	{"VBD","VBN"},
"spurner":	{"NN"},
"spurning":	{"VBG"},
"spurns":	{"VBZ","NNS"},
"spurred":	{"VBN","VBD","JJ"},
"spurring":	{"VBG"},
"spurs":	{"VBZ","NNS"},
"spurt":	{"VB","VBP","NN"},
"spurted":	{"VBD","VBN"},
"spurting":	{"VBG"},
"spurts":	{"NNS","VBZ"},
"sputnik":	{"NN"},
"sputniks":	{"NNS"},
"sputter":	{"VB","VBP","NN"},
"sputtered":	{"VBD","VBN"},
"sputtering":	{"VBG"},
"sputters":	{"VBZ","NNS"},
"sputum":	{"NN"},
"spy":	{"NN","VB","VBP"},
"spycatcher":	{"NN"},
"spyeria":	{"NN"},
"spyglass":	{"NN"},
"spyglasses":	{"NNS"},
"spyhole":	{"NN"},
"spyholes":	{"NNS"},
"spying":	{"VBG"},
"spymaster":	{"NN"},
"spymasters":	{"NNS"},
"spyware":	{"NN"},
"sq":	{"NN"},
"sq.":	{"NN"},
"squab":	{"NN","JJ","NNS"},
"squabble":	{"VB","VBP","NN"},
"squabbled":	{"VBD","VBN"},
"squabbler":	{"NN"},
"squabbles":	{"NNS","VBZ"},
"squabbling":	{"VBG"},
"squabby":	{"JJ"},
"squabs":	{"NNS"},
"squad":	{"NN"},
"squaddie":	{"NN"},
"squaddies":	{"NNS"},
"squaddy":	{"NN"},
"squadron":	{"NN"},
"squadrons":	{"NNS"},
"squadroom":	{"NN"},
"squads":	{"NNS"},
"squalid":	{"JJ"},
"squalidae":	{"NN"},
"squalidly":	{"RB"},
"squalidness":	{"NN"},
"squall":	{"NN","VB","VBP"},
"squalled":	{"VBD","VBN"},
"squalling":	{"VBG"},
"squalls":	{"NNS","VBZ"},
"squally":	{"JJ"},
"squalor":	{"NN"},
"squalus":	{"NNS"},
"squama":	{"NN"},
"squamata":	{"NN"},
"squamous":	{"JJ"},
"squamule":	{"NN"},
"squamulose":	{"JJ"},
"squander":	{"VBP","VB"},
"squandered":	{"VBD","VBN"},
"squanderer":	{"NN"},
"squandering":	{"VBG"},
"squandermania":	{"NN"},
"squanders":	{"VBZ"},
"square":	{"JJ","NN","VB","VBP","RB"},
"square-bashing":	{"NN"},
"square-rigged":	{"JJ"},
"square-shouldered":	{"JJ"},
"square-toed":	{"JJ"},
"squared":	{"JJ","VBD","VBN"},
"squarefoot":	{"JJ"},
"squarely":	{"RB"},
"squareness":	{"NN"},
"squares":	{"NNS","VBZ"},
"squaretail":	{"NN"},
"squaring":	{"VBG"},
"squarish":	{"JJ"},
"squark":	{"NN"},
"squash":	{"VB","VBP","NN"},
"squashed":	{"VBD","VBN","JJ"},
"squashes":	{"VBZ","NNS"},
"squashing":	{"VBG"},
"squashy":	{"JJ"},
"squat":	{"VB","VBP","NN","JJ"},
"squatina":	{"NN"},
"squatinidae":	{"NN"},
"squatness":	{"NN"},
"squats":	{"VBZ","NNS"},
"squatted":	{"VBD","VBN"},
"squatter":	{"NN","JJR"},
"squatters":	{"NNS"},
"squattest":	{"JJS"},
"squattiness":	{"NN"},
"squatting":	{"VBG"},
"squatty":	{"JJ"},
"squaw":	{"NN"},
"squawbush":	{"NN"},
"squawk":	{"VB","VBP","NN"},
"squawked":	{"VBD","VBN"},
"squawker":	{"NN"},
"squawking":	{"VBG"},
"squawks":	{"VBZ","NNS"},
"squawky":	{"JJ"},
"squawroot":	{"NN"},
"squaws":	{"NNS"},
"squeak":	{"NN","VB","VBP"},
"squeaked":	{"VBD","VBN"},
"squeaker":	{"NN"},
"squeakier":	{"JJR"},
"squeakiest":	{"JJS"},
"squeakily":	{"RB"},
"squeakiness":	{"NN"},
"squeaking":	{"VBG"},
"squeaks":	{"NNS","VBZ"},
"squeaky":	{"JJ"},
"squeaky-clean":	{"JJ"},
"squeal":	{"NN","VB","VBP"},
"squealed":	{"VBD","VBN"},
"squealer":	{"NN"},
"squealing":	{"VBG"},
"squeals":	{"NNS","VBZ"},
"squeamish":	{"JJ"},
"squeamishly":	{"RB"},
"squeamishness":	{"NN"},
"squeegee":	{"NNS","VB","VBP"},
"squeegeed":	{"VBD","VBN"},
"squeegeeing":	{"VBG"},
"squeegees":	{"NNS","VBZ"},
"squeezability":	{"NN"},
"squeezable":	{"JJ"},
"squeeze":	{"VB","NN","VBP"},
"squeezed":	{"VBD","VBN"},
"squeezer":	{"NN"},
"squeezers":	{"NNS"},
"squeezes":	{"VBZ","NNS"},
"squeezing":	{"VBG"},
"squelch":	{"VB","VBP","NN"},
"squelched":	{"VBD","VBN"},
"squelcher":	{"NN"},
"squelches":	{"VBZ"},
"squelching":	{"VBG"},
"squib":	{"NN","VB","VBP"},
"squibbed":	{"VBD","VBN"},
"squibbing":	{"VBG"},
"squibs":	{"NNS","VBZ"},
"squid":	{"NN","NNS"},
"squids":	{"NNS"},
"squiffier":	{"JJR"},
"squiffiest":	{"JJS"},
"squiffy":	{"JJ"},
"squiggle":	{"NN"},
"squiggles":	{"NNS"},
"squiggly":	{"JJ"},
"squill":	{"NN"},
"squilla":	{"NN"},
"squillidae":	{"NN"},
"squinch":	{"NN","VB","VBP"},
"squinched":	{"VBD","VBN"},
"squint":	{"VB","VBP","NN","RB","JJ"},
"squint-eyed":	{"JJ"},
"squinted":	{"VBD","VBN"},
"squinter":	{"NN"},
"squinting":	{"VBG"},
"squints":	{"VBZ","NNS"},
"squinty":	{"JJ"},
"squire":	{"NN","VB","VBP"},
"squirearchy":	{"NN"},
"squired":	{"VBD","VBN"},
"squires":	{"NNS","VBZ"},
"squiring":	{"VBG"},
"squirm":	{"VB","VBP","NN"},
"squirmed":	{"VBD","VBN"},
"squirmer":	{"NN"},
"squirming":	{"NN","VBG"},
"squirms":	{"VBZ"},
"squirmy":	{"JJ"},
"squirrel":	{"NN","VB","VBP"},
"squirreled":	{"VBD","VBN"},
"squirrelfish":	{"NN"},
"squirreling":	{"VBG"},
"squirrelled":	{"VBD","VBN"},
"squirrelling":	{"VBG"},
"squirrels":	{"NNS","VBZ"},
"squirt":	{"VB","VBP","NN"},
"squirted":	{"VBD","VBN"},
"squirter":	{"NN"},
"squirting":	{"VBG"},
"squirts":	{"VBZ","NNS"},
"squish":	{"VB","VBP","NN"},
"squished":	{"VBD","VBN"},
"squishes":	{"VBZ"},
"squishier":	{"JJR"},
"squishiest":	{"JJS"},
"squishing":	{"VBG"},
"squishy":	{"JJ"},
"sr.":	{"NN"},
"sravana":	{"NN"},
"srbija":	{"NN"},
"srelease":	{"NN"},
"sreserve":	{"NN"},
"ss":	{"NN"},
"ssa":	{"NN"},
"sse":	{"NN"},
"ssi":	{"NN"},
"sspe":	{"NN"},
"ssri":	{"NN"},
"sss":	{"NN"},
"sssshoo":	{"NN"},
"ssw":	{"NN"},
"st":	{"NN","NNS"},
"st-story":	{"NN"},
"stNtmen":	{"NNS"},
"stab":	{"VB","VBP","NN"},
"stabbed":	{"VBD","VBN"},
"stabber":	{"NN"},
"stabbers":	{"NNS"},
"stabbing":	{"JJ","VBG","NN"},
"stabbings":	{"NNS"},
"stabile":	{"NN","JJ"},
"stabilisation":	{"NN"},
"stabilise":	{"VB","VBP"},
"stabilised":	{"VBD","VBN"},
"stabiliser":	{"NN"},
"stabilisers":	{"NNS"},
"stabilises":	{"VBZ"},
"stabilising":	{"VBG"},
"stability":	{"NN"},
"stabilization":	{"NN"},
"stabilize":	{"VB","VBP"},
"stabilized":	{"VBD","VBN"},
"stabilizer":	{"NN"},
"stabilizers":	{"NNS"},
"stabilizes":	{"VBZ"},
"stabilizing":	{"VBG"},
"stable":	{"JJ","NN","VB","VBP"},
"stable-boy":	{"NN"},
"stable-boys":	{"NNS"},
"stable-lad":	{"NN"},
"stable-lads":	{"NNS"},
"stableboy":	{"NN"},
"stableboys":	{"NNS"},
"stabled":	{"VBD","VBN"},
"stableman":	{"NN"},
"stablemate":	{"NN"},
"stablemates":	{"NNS"},
"stableness":	{"NN"},
"stables":	{"NNS","VBZ"},
"stabling":	{"NN","VBG"},
"stably":	{"RB"},
"stabroek":	{"NN"},
"stabs":	{"NNS","VBZ"},
"staccato":	{"JJ","NN","RB"},
"staccatos":	{"NNS"},
"stachyose":	{"NN"},
"stachys":	{"NNS"},
"stack":	{"NN","VB","VBP"},
"stacked":	{"VBN","JJ","VBD"},
"stacker":	{"NN"},
"stackers":	{"NNS"},
"stacking":	{"VBG"},
"stacks":	{"NNS","VBZ"},
"stacte":	{"NN"},
"staddle":	{"NN"},
"stadia":	{"NNS"},
"stadium":	{"NN"},
"stadiums":	{"NNS"},
"stael":	{"NN"},
"staf":	{"NN"},
"staff":	{"NN","NNS","VB","VBP"},
"staffa":	{"NN"},
"staffed":	{"VBN","VBD","JJ"},
"staffer":	{"NN"},
"staffers":	{"NNS"},
"staffing":	{"NN","VBG"},
"staffs":	{"NNS","VBZ"},
"stag":	{"NN","JJ","VB","VBP"},
"stag-beetle":	{"NN"},
"stag-parties":	{"NNS"},
"stag-party":	{"NN"},
"stage":	{"NN","VB","VBP"},
"stage-coach":	{"NN"},
"stage-coaches":	{"NNS"},
"stage-manage":	{"VB","VBP"},
"stage-managed":	{"VBD","VBN"},
"stage-manager":	{"NN"},
"stage-managers":	{"NNS"},
"stage-manages":	{"VBZ"},
"stage-managing":	{"VBG"},
"stage-plays":	{"NNS"},
"stage-struck":	{"JJ"},
"stage-whisper":	{"NN"},
"stage-whispers":	{"NNS"},
"stagecoach":	{"NN"},
"stagecoaches":	{"NNS"},
"stagecraft":	{"NN"},
"staged":	{"VBD","VBN"},
"stagehand":	{"NN"},
"stagehands":	{"NNS"},
"stagemate":	{"NN"},
"stager":	{"NN"},
"stages":	{"NNS","VBZ"},
"stagey":	{"JJ"},
"stagflation":	{"NN"},
"stagflationary":	{"JJ"},
"stagged":	{"VBD","VBN"},
"stagger":	{"VB","VBP","NN"},
"staggerbush":	{"NN"},
"staggered":	{"VBD","JJ","VBN"},
"staggerer":	{"NN"},
"staggering":	{"JJ","VBG"},
"staggeringly":	{"RB"},
"staggers":	{"NNS","VBZ"},
"stagging":	{"VBG"},
"staghead":	{"NN"},
"staghound":	{"NN"},
"stagier":	{"JJR"},
"stagiest":	{"JJS"},
"stagily":	{"RB"},
"staginess":	{"NN"},
"staging":	{"NN","VBG"},
"stagings":	{"NNS"},
"stagira":	{"NN"},
"stagirus":	{"NN"},
"stagnancy":	{"NN"},
"stagnant":	{"JJ"},
"stagnate":	{"VB","VBP"},
"stagnated":	{"VBD","VBN"},
"stagnates":	{"VBZ"},
"stagnating":	{"VBG"},
"stagnation":	{"NN"},
"stags":	{"NNS","VBZ"},
"stagy":	{"JJ"},
"staid":	{"JJ"},
"staidly":	{"RB"},
"staidness":	{"NN"},
"stain":	{"VB","VBP","NN"},
"stainability":	{"NN"},
"stainable":	{"JJ"},
"stained":	{"JJ","VBD","VBN"},
"stained-glass":	{"NN"},
"stainer":	{"NN"},
"stainers":	{"NNS"},
"staining":	{"VBG"},
"stainless":	{"JJ"},
"stains":	{"VBZ","NNS"},
"stair":	{"NN"},
"stair-carpet":	{"NN"},
"stair-rod":	{"NN"},
"staircase":	{"NN"},
"staircases":	{"NNS"},
"stairhead":	{"NN"},
"stairs":	{"NNS"},
"stairway":	{"NN"},
"stairways":	{"NNS"},
"stairwell":	{"NN"},
"stairwells":	{"NNS"},
"stake":	{"NN","VB","VBP"},
"stake-out":	{"NN"},
"stake-outs":	{"NNS"},
"staked":	{"VBD","VBN"},
"stakeholder":	{"NN"},
"stakeholders":	{"NNS"},
"stakeout":	{"NN"},
"stakeouts":	{"NNS"},
"stakes":	{"NNS","VBZ"},
"staking":	{"VBG"},
"stalactite":	{"NN"},
"stalactites":	{"NNS"},
"stalagmite":	{"NN"},
"stalagmites":	{"NNS"},
"stale":	{"JJ","VB","VBP"},
"stale-cigarette":	{"NN"},
"staled":	{"VBD","VBN"},
"stalemate":	{"NN","VB","VBP"},
"stalemated":	{"JJ","VBD","VBN"},
"stalemates":	{"NNS","VBZ"},
"stalemating":	{"VBG"},
"staleness":	{"NN"},
"staler":	{"JJR"},
"stales":	{"VBZ"},
"stalest":	{"JJS"},
"stalin":	{"NN"},
"stalinabad":	{"NN"},
"staling":	{"VBG"},
"stalinism":	{"NN"},
"stalinist":	{"JJ","NN"},
"stalino":	{"NN"},
"stalk":	{"NN","VB","VBP"},
"stalked":	{"JJ","VBD","VBN"},
"stalker":	{"NN"},
"stalkers":	{"NNS"},
"stalking":	{"NN","VBG"},
"stalkless":	{"JJ"},
"stalks":	{"NNS","VBZ"},
"stall":	{"NN","VB","VBP"},
"stall-fed":	{"JJ","VBD","VBN"},
"stall-feed":	{"VB","VBP"},
"stall-feeding":	{"VBG"},
"stall-feeds":	{"VBZ"},
"stall-holder":	{"NN"},
"stall-holders":	{"NNS"},
"stalled":	{"VBN","VBD"},
"stalling":	{"NN","VBG"},
"stallion":	{"NN"},
"stalls":	{"NNS","VBZ"},
"stalwart":	{"JJ","NN"},
"stalwartly":	{"RB"},
"stalwartness":	{"NN"},
"stalwarts":	{"NNS"},
"stamboul":	{"NN"},
"stambul":	{"NN"},
"stamen":	{"NN"},
"stamens":	{"NNS"},
"stamina":	{"NN"},
"staminate":	{"JJ"},
"stammel":	{"NN"},
"stammer":	{"VB","VBP","NN"},
"stammered":	{"VBD","VBN"},
"stammerer":	{"NN"},
"stammerers":	{"NNS"},
"stammering":	{"NN","VBG"},
"stammers":	{"VBZ"},
"stamp":	{"NN","VB","VBP"},
"stamp-collecting":	{"NN"},
"stamp-collector":	{"NN"},
"stamp-collectors":	{"NNS"},
"stamp-duty":	{"NN"},
"stamped":	{"VBN","VBD","JJ"},
"stampede":	{"NN","VB","VBP"},
"stampeded":	{"VBD","VBN"},
"stampedes":	{"NNS","VBZ"},
"stampeding":	{"VBG"},
"stamper":	{"NN"},
"stamping":	{"NN","VBG"},
"stamping-ground":	{"NN"},
"stamping-grounds":	{"NNS"},
"stampings":	{"NNS"},
"stamps":	{"NNS","VBZ"},
"stance":	{"NN"},
"stances":	{"NNS"},
"stanch":	{"VB","VBP"},
"stanched":	{"VBD","VBN"},
"stanches":	{"VBZ"},
"stanching":	{"VBG"},
"stanchion":	{"NN"},
"stanchions":	{"NNS"},
"stanchly":	{"RB"},
"stand":	{"VB","NN","VBP"},
"stand-alone":	{"JJ"},
"stand-by":	{"NN","JJ"},
"stand-bys":	{"NNS"},
"stand-in":	{"NN"},
"stand-ins":	{"NNS"},
"stand-off":	{"NN"},
"stand-offish":	{"JJ"},
"stand-offishly":	{"RB"},
"stand-offishness":	{"NN"},
"stand-offs":	{"NNS"},
"stand-out":	{"NN"},
"stand-outs":	{"NNS"},
"stand-up":	{"JJ","NN"},
"standard":	{"NN","JJ"},
"standard-bearer":	{"NN"},
"standard-bearers":	{"NNS"},
"standard-issue":	{"JJ"},
"standardisation":	{"NN"},
"standardise":	{"VB","VBP"},
"standardised":	{"VBD","VBN"},
"standardiser":	{"NN"},
"standardises":	{"VBZ"},
"standardising":	{"VBG"},
"standardization":	{"NN"},
"standardize":	{"VB","VBP"},
"standardized":	{"VBD","VBN"},
"standardizer":	{"NN"},
"standardizes":	{"VBZ"},
"standardizing":	{"VBG"},
"standards":	{"NNS"},
"standby":	{"NN","JJ"},
"standbys":	{"NNS"},
"standdown":	{"NN"},
"standee":	{"NN"},
"standees":	{"NNS"},
"stander":	{"NN"},
"standing":	{"VBG","NN","JJ"},
"standing-room":	{"NN"},
"standings":	{"NNS"},
"standish":	{"NN"},
"standoff":	{"NN"},
"standoffish":	{"JJ"},
"standoffishly":	{"RB"},
"standoffishness":	{"NN"},
"standoffs":	{"NNS"},
"standout":	{"NN","JJ"},
"standouts":	{"NNS"},
"standpat":	{"JJ"},
"standpipe":	{"NN"},
"standpipes":	{"NNS"},
"standpoint":	{"NN"},
"standpoints":	{"NNS"},
"stands":	{"VBZ","NNS"},
"standstill":	{"NN"},
"standup":	{"JJ","NN"},
"stanford":	{"NN"},
"stanhope":	{"NN"},
"stanhopea":	{"NN"},
"stank":	{"VBD"},
"stanley":	{"NN"},
"stanleya":	{"NN"},
"stannic":	{"JJ"},
"stannite":	{"NN"},
"stannous":	{"JJ"},
"stanton":	{"NN"},
"stanza":	{"NN"},
"stanzas":	{"NNS"},
"stapedectomy":	{"NN"},
"stapedes":	{"NNS"},
"stapedial":	{"JJ"},
"stapelia":	{"NN"},
"stapes":	{"NN","NNS"},
"staph":	{"NN"},
"staphylaceae":	{"NN"},
"staphylea":	{"NN"},
"staphylinidae":	{"NN"},
"staphylococcal":	{"NN","JJ"},
"staphylococci":	{"NNS"},
"staphylococcus":	{"NN"},
"staple":	{"NN","VB","VBP","JJ"},
"stapled":	{"VBD","VBN"},
"staplegun":	{"NN"},
"stapler":	{"NN"},
"staplers":	{"NNS"},
"staples":	{"VBZ","NNS"},
"stapling":	{"VBG"},
"star":	{"NN","VB","VBP"},
"star-dust":	{"NN"},
"star-gazer":	{"NN"},
"star-gazers":	{"NNS"},
"star-studded":	{"JJ"},
"starboard":	{"JJ","NN"},
"starch":	{"NN","VB","VBP"},
"starched":	{"VBN","JJ","VBD"},
"starches":	{"VBZ","NNS"},
"starchier":	{"JJR"},
"starchiest":	{"JJS"},
"starchily":	{"RB"},
"starchiness":	{"NN"},
"starching":	{"VBG"},
"starchless":	{"JJ"},
"starchlike":	{"JJ"},
"starchy":	{"JJ"},
"stardom":	{"NN"},
"stardust":	{"NN"},
"stare":	{"VB","NN","VBP"},
"stared":	{"VBD","VBN"},
"starer":	{"NN"},
"stares":	{"VBZ","NNS"},
"starets":	{"NN"},
"starfish":	{"NN","NNS"},
"starflower":	{"NN"},
"stargaze":	{"VB","VBP"},
"stargazed":	{"VBD","VBN"},
"stargazer":	{"NN"},
"stargazers":	{"NNS"},
"stargazes":	{"VBZ"},
"stargazing":	{"NN","VBG"},
"staring":	{"VBG"},
"stark":	{"JJ","RB"},
"starker":	{"JJR"},
"starkers":	{"JJ"},
"starkest":	{"JJS"},
"starkey":	{"NN"},
"starkly":	{"RB"},
"starkness":	{"NN"},
"starless":	{"JJ"},
"starlet":	{"NN"},
"starlets":	{"NNS"},
"starlight":	{"NN"},
"starlike":	{"JJ"},
"starling":	{"NN"},
"starlings":	{"NNS"},
"starlit":	{"JJ"},
"starred":	{"VBD","VBN","JJ"},
"starring":	{"VBG"},
"starry":	{"JJ"},
"starry-eyed":	{"JJ"},
"stars":	{"NNS","VBZ"},
"starscape":	{"NN"},
"starscapes":	{"NNS"},
"starship":	{"NN"},
"starstruck":	{"JJ"},
"start":	{"VB","NN","VBP"},
"start-up":	{"JJ","NN"},
"start-ups":	{"NNS"},
"started":	{"VBD","VBN"},
"starter":	{"NN"},
"starters":	{"NNS"},
"starting":	{"VBG","NN"},
"starting-block":	{"NN"},
"starting-blocks":	{"NNS"},
"starting-gate":	{"NN"},
"starting-gates":	{"NNS"},
"starting-point":	{"NN"},
"starting-post":	{"NN"},
"starting-price":	{"NN"},
"startle":	{"VB","VBP"},
"startled":	{"JJ","VBD","VBN"},
"startles":	{"VBZ"},
"startling":	{"JJ","VBG"},
"startlingly":	{"RB"},
"starts":	{"VBZ","NNS"},
"startsy":	{"NNS"},
"startup":	{"NN"},
"startups":	{"NNS"},
"starvation":	{"NN"},
"starve":	{"VB","VBP"},
"starved":	{"VBD","VBN"},
"starveling":	{"NN"},
"starves":	{"VBZ"},
"starving":	{"JJ","VBG"},
"starwort":	{"NN"},
"stash":	{"VB","VBP","NN"},
"stashed":	{"VBD","VBN"},
"stashes":	{"VBZ","NNS"},
"stashing":	{"VBG"},
"stasis":	{"NN"},
"stat":	{"NN"},
"statant":	{"JJ"},
"state":	{"NN","VB","VBP","JJ"},
"state-of-the-art":	{"JJ"},
"statecraft":	{"NN"},
"stated":	{"VBD","VBN","JJ"},
"statehood":	{"NN"},
"statehooders":	{"NNS"},
"statehouse":	{"NN"},
"statehouses":	{"NNS"},
"stateless":	{"JJ"},
"statelessness":	{"NN"},
"statelier":	{"JJR"},
"stateliest":	{"JJS"},
"stateliness":	{"NN"},
"stately":	{"JJ"},
"statement":	{"NN","VB","VBP"},
"statemented":	{"VBD","VBN"},
"statementing":	{"VBG"},
"statements":	{"NNS","VBZ"},
"stater":	{"NN"},
"stateroom":	{"NN"},
"staterooms":	{"NNS"},
"states":	{"NNS","VBZ"},
"stateside":	{"JJ","RB"},
"statesman":	{"NN"},
"statesmanlike":	{"JJ"},
"statesmanly":	{"RB"},
"statesmanship":	{"NN"},
"statesmen":	{"NNS"},
"stateswoman":	{"NN"},
"stateswomen":	{"NNS"},
"statewide":	{"JJ","RB"},
"static":	{"JJ","NN"},
"statice":	{"NN"},
"statics":	{"NN"},
"statin":	{"NN"},
"stating":	{"VBG"},
"station":	{"NN","VB","VBP"},
"stationariness":	{"NN"},
"stationary":	{"JJ"},
"stationed":	{"VBN","VBD"},
"stationer":	{"NN"},
"stationers":	{"NNS"},
"stationery":	{"NN"},
"stationing":	{"VBG"},
"stationmaster":	{"NN"},
"stationmasters":	{"NNS"},
"stations":	{"NNS","VBZ"},
"statism":	{"NN"},
"statist":	{"JJ"},
"statistic":	{"NN"},
"statistical":	{"JJ"},
"statistically":	{"RB"},
"statistician":	{"NN"},
"statisticians":	{"NNS"},
"statistics":	{"NNS","NN"},
"stative":	{"JJ"},
"stator":	{"NN"},
"stats":	{"NNS","NN"},
"statu":	{"FW"},
"statuary":	{"NN","JJ"},
"statue":	{"NN"},
"statues":	{"NNS"},
"statuesque":	{"JJ"},
"statuette":	{"NN"},
"statuettes":	{"NNS"},
"stature":	{"NN"},
"status":	{"NN"},
"statute":	{"NN"},
"statutes":	{"NNS"},
"statuto":	{"NN"},
"statutorily":	{"RB"},
"statutory":	{"JJ"},
"staunch":	{"JJ","VB","VBP"},
"staunched":	{"VBD","VBN"},
"stauncher":	{"JJR"},
"staunches":	{"VBZ"},
"staunchest":	{"JJS"},
"staunching":	{"VBG"},
"staunchly":	{"RB"},
"staunchness":	{"NN"},
"staurikosaur":	{"NN"},
"staurikosaurus":	{"NN"},
"stavanger":	{"NN"},
"stave":	{"NN","VB","VBP"},
"staved":	{"VBD","VBN"},
"staves":	{"NNS","VBZ"},
"staving":	{"VBG"},
"stay":	{"VB","NN","VBP"},
"stay-at-home":	{"JJ","NN"},
"stay-at-homes":	{"NNS"},
"stayed":	{"VBD","VBN"},
"stayer":	{"NN"},
"stayers":	{"NNS"},
"staying":	{"VBG"},
"staying-power":	{"NN"},
"stayman":	{"NN"},
"stays":	{"VBZ","NNS"},
"staysail":	{"NN"},
"std":	{"NN"},
"stead":	{"NN"},
"steadfast":	{"JJ"},
"steadfastly":	{"RB"},
"steadfastness":	{"NN"},
"steadied":	{"VBD","VBN"},
"steadier":	{"JJR"},
"steadies":	{"NNS","VBZ"},
"steadiest":	{"JJS"},
"steadily":	{"RB"},
"steadiness":	{"NN"},
"steady":	{"JJ","RB","NN","VB","VBP","UH"},
"steadying":	{"VBG"},
"steak":	{"NN"},
"steak-house":	{"NN"},
"steak-houses":	{"NNS"},
"steakhouse":	{"NN"},
"steakhouses":	{"NNS"},
"steaks":	{"NNS"},
"steal":	{"VBP","NN","VB"},
"stealer":	{"NN"},
"stealing":	{"VBG","NN"},
"steals":	{"VBZ","NNS"},
"stealth":	{"NN"},
"stealthier":	{"JJR"},
"stealthiest":	{"JJS"},
"stealthily":	{"RB"},
"stealthiness":	{"NN"},
"stealthy":	{"JJ"},
"steam":	{"NN","VBP","VB"},
"steam-engine":	{"NN"},
"steam-shovel":	{"NN"},
"steamboat":	{"NN"},
"steamboatman":	{"NN"},
"steamboats":	{"NNS"},
"steamed":	{"VBD","VBN"},
"steamer":	{"NN"},
"steamers":	{"NNS"},
"steamfitter":	{"NN"},
"steamier":	{"JJR"},
"steamiest":	{"JJS"},
"steamily":	{"JJ"},
"steaminess":	{"NN"},
"steaming":	{"RB","VBG"},
"steamroll":	{"VB","VBP"},
"steamroller":	{"NN","VB","VBP"},
"steamrollered":	{"VBD","VBN"},
"steamrollering":	{"VBG"},
"steamrollers":	{"NNS","VBZ"},
"steams":	{"VBZ"},
"steamship":	{"NN"},
"steamships":	{"NNS"},
"steamy":	{"JJ"},
"stearic":	{"JJ"},
"stearin":	{"NN"},
"steatite":	{"NN"},
"steatocystoma":	{"NN"},
"steatopygia":	{"NN"},
"steatornis":	{"NN"},
"steatornithidae":	{"NN"},
"steatorrhea":	{"NN"},
"steed":	{"NN"},
"steeds":	{"NNS"},
"steel":	{"NN","VB","VBP"},
"steele":	{"NN"},
"steeled":	{"VBD","VBN"},
"steelier":	{"JJR"},
"steeliest":	{"JJS"},
"steeling":	{"VBG"},
"steelmaker":	{"NN"},
"steelmakers":	{"NNS"},
"steelmaking":	{"NN"},
"steelman":	{"NN"},
"steels":	{"NNS","VBZ"},
"steelworker":	{"NN"},
"steelworkers":	{"NNS"},
"steelworks":	{"NN","NNS"},
"steely":	{"JJ"},
"steelyard":	{"NN"},
"steenbok":	{"NN"},
"steep":	{"JJ","VB","VBP"},
"steeped":	{"VBN","VBD"},
"steepen":	{"VB","VBP"},
"steepened":	{"VBD","VBN"},
"steepening":	{"VBG"},
"steepens":	{"VBZ"},
"steeper":	{"JJR"},
"steepest":	{"JJS"},
"steeping":	{"VBG"},
"steepish":	{"JJ"},
"steeple":	{"NN"},
"steeplechase":	{"NN"},
"steeplechaser":	{"NN"},
"steeplechasers":	{"NNS"},
"steeplechases":	{"NNS"},
"steeplejack":	{"NN"},
"steeplejacks":	{"NNS"},
"steeples":	{"NNS"},
"steeply":	{"RB"},
"steepness":	{"NN"},
"steeps":	{"VBZ"},
"steer":	{"VB","VBP","NN"},
"steerable":	{"JJ"},
"steerage":	{"NN"},
"steerage-way":	{"NN"},
"steerageway":	{"NN"},
"steered":	{"VBD","VBN"},
"steerer":	{"NN"},
"steerers":	{"NNS"},
"steering":	{"NN","VBG","JJ"},
"steers":	{"VBZ","NNS"},
"steersman":	{"NN"},
"steersmen":	{"NNS"},
"stefan":	{"NN"},
"steffens":	{"NNS"},
"steganography":	{"NN"},
"steganopus":	{"NN"},
"stegocephalia":	{"NN"},
"stegosaur":	{"NN"},
"stegosaurus":	{"NN"},
"steichen":	{"NN"},
"stein":	{"NN"},
"steinbeck":	{"NN"},
"steinberg":	{"NN"},
"steinbok":	{"NN"},
"steinem":	{"NN"},
"steiner":	{"NN"},
"steinman":	{"NN"},
"steinmetz":	{"NN"},
"stela":	{"NN"},
"stele":	{"NN"},
"stelis":	{"NN"},
"stella":	{"NN"},
"stellar":	{"JJ"},
"stellaria":	{"NN"},
"stellate":	{"JJ"},
"steller":	{"NN"},
"stellite":	{"NN"},
"stem":	{"NN","VB","VBP"},
"stemless":	{"JJ"},
"stemma":	{"NN"},
"stemmatic":	{"JJ"},
"stemmatics":	{"NN"},
"stemmatology":	{"NN"},
"stemmed":	{"VBD","VBN","JJ"},
"stemmer":	{"NN"},
"stemming":	{"VBG"},
"stems":	{"VBZ","NNS"},
"stench":	{"NN"},
"stenches":	{"NNS"},
"stencil":	{"NN","VB","VBP"},
"stenciled":	{"VBD","VBN"},
"stenciling":	{"VBG"},
"stencilled":	{"VBD","VBN"},
"stencilling":	{"VBG"},
"stencils":	{"NNS","VBZ"},
"stendhal":	{"NN"},
"stengel":	{"NN"},
"steno":	{"NN"},
"stenocarpus":	{"NN"},
"stenochlaena":	{"NN"},
"stenograph":	{"NN","VB","VBP"},
"stenographer":	{"NN"},
"stenographers":	{"NNS"},
"stenographic":	{"JJ"},
"stenographical":	{"JJ"},
"stenography":	{"NN"},
"stenopelmatidae":	{"NN"},
"stenopelmatus":	{"NN"},
"stenopterygius":	{"NN"},
"stenos":	{"NNS"},
"stenosed":	{"JJ"},
"stenosis":	{"NN"},
"stenotaphrum":	{"NN"},
"stenotic":	{"JJ"},
"stenotomus":	{"NN"},
"stenotus":	{"NN"},
"stent":	{"NN"},
"stenting":	{"NN"},
"stentings":	{"NNS"},
"stentor":	{"NN"},
"stentorian":	{"JJ"},
"stents":	{"NNS"},
"steoreotyped":	{"JJ"},
"step":	{"NN","VB","VBP"},
"step-aunt":	{"NN"},
"step-aunts":	{"NNS"},
"step-brother":	{"NN"},
"step-brothers":	{"NNS"},
"step-by-step":	{"JJ"},
"step-child":	{"NN"},
"step-children":	{"NNS"},
"step-daughter":	{"NN"},
"step-daughters":	{"NNS"},
"step-down":	{"NN"},
"step-father":	{"NN"},
"step-fathers":	{"NNS"},
"step-in":	{"NN"},
"step-mother":	{"NN"},
"step-mothers":	{"NNS"},
"step-parent":	{"NN"},
"step-parents":	{"NNS"},
"step-sister":	{"NN"},
"step-sisters":	{"NNS"},
"step-son":	{"NN"},
"step-sons":	{"NNS"},
"step-up":	{"NN"},
"stepbrother":	{"NN"},
"stepbrothers":	{"NNS"},
"stepchild":	{"NN"},
"stepchildren":	{"NNS"},
"stepdad":	{"NN"},
"stepdads":	{"NNS"},
"stepdaughter":	{"NN"},
"stepdaughters":	{"NNS"},
"stepfather":	{"NN"},
"stepfathers":	{"NNS"},
"stepgrandmother":	{"NN"},
"stephanion":	{"NN"},
"stephanomeria":	{"NN"},
"stephanotis":	{"NN"},
"stephead":	{"NN"},
"stephen":	{"NN"},
"stephenson":	{"NN"},
"stepladder":	{"NN"},
"stepladders":	{"NNS"},
"stepmother":	{"NN"},
"stepmothers":	{"NNS"},
"stepparent":	{"NN"},
"stepparents":	{"NNS"},
"steppe":	{"NN"},
"stepped":	{"VBD","VBN"},
"stepper":	{"NN"},
"steppes":	{"NNS"},
"stepping":	{"VBG","NN"},
"stepping-stone":	{"NN"},
"stepping-stones":	{"NNS"},
"steppingstone":	{"NN"},
"steprelationship":	{"NN"},
"steps":	{"NNS","VBZ"},
"stepsister":	{"NN"},
"stepsisters":	{"NNS"},
"stepson":	{"NN"},
"stepsons":	{"NNS"},
"stept":	{"VBD","VBN"},
"stepwise":	{"RB"},
"steradian":	{"NN"},
"stercobilinogen":	{"NN"},
"stercolith":	{"NN"},
"stercorariidae":	{"NN"},
"stercorarius":	{"NN"},
"sterculia":	{"NN"},
"sterculiaceae":	{"NN"},
"stereo":	{"NN","JJ"},
"stereophonic":	{"JJ"},
"stereophony":	{"NN"},
"stereos":	{"NNS"},
"stereoscope":	{"NN"},
"stereoscopic":	{"JJ"},
"stereoscopy":	{"NN"},
"stereospondyli":	{"NN"},
"stereotype":	{"NN","VB","VBP"},
"stereotyped":	{"JJ","VBD","VBN"},
"stereotypes":	{"NNS","VBZ"},
"stereotypic":	{"JJ"},
"stereotypical":	{"JJ"},
"stereotypically":	{"RB"},
"stereotyping":	{"VBG","NN"},
"sterile":	{"JJ"},
"sterileness":	{"NN"},
"sterilisation":	{"NN"},
"sterilisations":	{"NNS"},
"sterilise":	{"VB","VBP"},
"sterilised":	{"VBD","VBN"},
"steriliser":	{"NN"},
"sterilisers":	{"NNS"},
"sterilises":	{"VBZ"},
"sterilising":	{"VBG"},
"sterility":	{"NN"},
"sterilization":	{"NN"},
"sterilizations":	{"NNS"},
"sterilize":	{"VB","VBP"},
"sterilized":	{"VBD","VBN"},
"sterilizer":	{"NN"},
"sterilizers":	{"NNS"},
"sterilizes":	{"VBZ"},
"sterilizing":	{"VBG"},
"sterios":	{"NNS"},
"sterling":	{"NN","JJ"},
"stern":	{"JJ","NN"},
"sterna":	{"NNS"},
"sternal":	{"JJ"},
"sterner":	{"JJR"},
"sternest":	{"JJS"},
"sterninae":	{"NN"},
"sternly":	{"RB"},
"sternness":	{"NN"},
"sternocleidomastoid":	{"NN"},
"sternotherus":	{"NN"},
"sternpost":	{"NN"},
"sterns":	{"NNS"},
"sternum":	{"NN"},
"sternums":	{"NNS"},
"sternutation":	{"NN"},
"sternutative":	{"JJ"},
"sternutator":	{"NN"},
"sternutatory":	{"JJ"},
"sternwheeler":	{"NN"},
"steroid":	{"NN"},
"steroidal":	{"NN"},
"steroids":	{"NNS"},
"sterol":	{"NN"},
"sterope":	{"NN"},
"stertor":	{"NN"},
"stertorous":	{"JJ"},
"stertorously":	{"RB"},
"stet":	{"VB","VBP"},
"stethoscope":	{"NN"},
"stethoscopes":	{"NNS"},
"stets":	{"VBZ"},
"stetson":	{"NN"},
"stetsons":	{"NNS"},
"stetted":	{"VBD","VBN"},
"stetting":	{"VBG"},
"steuben":	{"NN"},
"stevedore":	{"NN","VB","VBP"},
"stevedored":	{"VBD","VBN"},
"stevedores":	{"NNS","VBZ"},
"stevedoring":	{"VBG"},
"stevens":	{"NNS"},
"stevenson":	{"NN"},
"stevia":	{"NN"},
"stew":	{"NN","VB","VBP"},
"steward":	{"NN","VB","VBP"},
"stewarded":	{"VBD","VBN"},
"stewardess":	{"NN"},
"stewardesses":	{"NNS"},
"stewarding":	{"VBG"},
"stewards":	{"NNS","VBZ"},
"stewardship":	{"NN"},
"stewart":	{"NN"},
"stewed":	{"JJ","VBD","VBN"},
"stewing":	{"NN","VBG"},
"stewpan":	{"NN"},
"stews":	{"NNS","VBZ"},
"sth":	{"NN"},
"sthene":	{"NN"},
"stheno":	{"NN"},
"stibnite":	{"NN"},
"stichaeidae":	{"NN"},
"sticherus":	{"NN"},
"stick":	{"VB","NN","VBP"},
"stick-in-the-mud":	{"NN"},
"stick-in-the-muds":	{"NNS"},
"stick-on":	{"JJ"},
"stick-up":	{"NN"},
"stickball":	{"NN"},
"sticker":	{"NN"},
"stickers":	{"NNS"},
"stickier":	{"JJR"},
"stickiest":	{"JJS"},
"stickily":	{"RB"},
"stickiness":	{"NN"},
"sticking":	{"VBG"},
"sticking-plaster":	{"NN"},
"sticking-plasters":	{"NNS"},
"stickle":	{"VB","VBP"},
"stickleback":	{"NN"},
"sticklebacks":	{"NNS"},
"stickled":	{"VBD","VBN"},
"stickler":	{"NN"},
"sticklers":	{"NNS"},
"stickles":	{"VBZ"},
"sticklike":	{"JJ"},
"stickling":	{"VBG"},
"stickman":	{"NN"},
"stickpin":	{"NN"},
"stickpins":	{"NNS"},
"sticks":	{"NNS","VBZ"},
"sticktight":	{"NN"},
"stickup":	{"NN"},
"stickweed":	{"NN"},
"sticky":	{"JJ"},
"stictomys":	{"NNS"},
"stictopelia":	{"NN"},
"stieglitz":	{"NN"},
"sties":	{"NNS"},
"stiff":	{"JJ","NN","RB","VB","VBP"},
"stiff-necked":	{"JJ"},
"stiffed":	{"VBD","VBN"},
"stiffen":	{"VB","VBP"},
"stiffened":	{"VBD","VBN"},
"stiffener":	{"NN"},
"stiffening":	{"NN","VBG"},
"stiffens":	{"VBZ","NNS"},
"stiffer":	{"JJR"},
"stiffest":	{"JJS"},
"stiffing":	{"JJ","NN","VBG"},
"stiffly":	{"RB"},
"stiffnecked":	{"JJ"},
"stiffness":	{"NN"},
"stiffs":	{"NNS","VBZ"},
"stifle":	{"VB","VBP"},
"stifled":	{"VBD","VBN"},
"stifler":	{"NN"},
"stifles":	{"VBZ"},
"stifling":	{"JJ","VBG"},
"stiflingly":	{"RB"},
"stigma":	{"NN"},
"stigmas":	{"NNS"},
"stigmata":	{"NNS"},
"stigmatic":	{"JJ"},
"stigmatisation":	{"NN"},
"stigmatise":	{"VB","VBP"},
"stigmatised":	{"VBD","VBN","JJ"},
"stigmatises":	{"VBZ"},
"stigmatising":	{"VBG"},
"stigmatism":	{"NN"},
"stigmatist":	{"NN"},
"stigmatization":	{"NN"},
"stigmatize":	{"VB","VBP"},
"stigmatized":	{"VBD","VBN","JJ"},
"stigmatizes":	{"VBZ"},
"stigmatizing":	{"VBG"},
"stilbesterol":	{"NN"},
"stilbestrol":	{"NN"},
"stilboestrol":	{"NN"},
"stile":	{"NN"},
"stiles":	{"NNS"},
"stiletto":	{"NN"},
"stilettos":	{"NNS"},
"still":	{"RB","JJ","NN","VB","VBP"},
"stillbirth":	{"NN"},
"stillbirths":	{"NNS"},
"stillborn":	{"JJ"},
"stilled":	{"VBD","VBN"},
"stiller":	{"JJR"},
"stillest":	{"JJS"},
"stillier":	{"JJR"},
"stilliest":	{"JJS"},
"stilling":	{"VBG"},
"stillness":	{"NN"},
"stillroom":	{"NN"},
"stills":	{"VBZ","NNS"},
"stilly":	{"RB","JJ"},
"stilt":	{"NN","VB","VBP"},
"stiltbird":	{"NN"},
"stilted":	{"JJ","VBD","VBN"},
"stiltedly":	{"RB"},
"stilting":	{"VBG"},
"stilts":	{"NNS","VBZ"},
"stilwell":	{"NN"},
"stim":	{"NN","VB","VBP"},
"stimmed":	{"VBD","VBN"},
"stimming":	{"VBG"},
"stims":	{"NNS","VBZ"},
"stimulant":	{"NN","JJ"},
"stimulants":	{"NNS"},
"stimulate":	{"VB","VBP"},
"stimulated":	{"VBD","VBN"},
"stimulates":	{"VBZ"},
"stimulating":	{"JJ","VBG"},
"stimulation":	{"NN"},
"stimulative":	{"JJ"},
"stimulator":	{"NN"},
"stimulators":	{"NNS"},
"stimulatory":	{"JJ"},
"stimuli":	{"NNS"},
"stimulus":	{"NN"},
"sting":	{"VB","VBP","NN"},
"stinger":	{"NN"},
"stingers":	{"NNS"},
"stingier":	{"JJR"},
"stingiest":	{"JJS"},
"stingily":	{"RB"},
"stinginess":	{"NN"},
"stinging":	{"JJ","VBG"},
"stingless":	{"JJ"},
"stingray":	{"NN"},
"stingrays":	{"NNS"},
"stings":	{"NNS","VBZ"},
"stingy":	{"JJ"},
"stink":	{"VB","VBP","NN"},
"stink-bomb":	{"NN"},
"stinkbird":	{"NN"},
"stinker":	{"NN"},
"stinkers":	{"NNS"},
"stinkhorn":	{"NN"},
"stinkier":	{"JJR"},
"stinkiest":	{"JJS"},
"stinkin":	{"JJ"},
"stinkiness":	{"NN"},
"stinking":	{"VBG","JJ","RB"},
"stinkpot":	{"NN"},
"stinkpotters":	{"NNS"},
"stinks":	{"VBZ"},
"stinkweed":	{"NN"},
"stinky":	{"JJ"},
"stint":	{"NN","VB","VBP"},
"stinted":	{"VBD","VBN"},
"stinter":	{"NN"},
"stinting":	{"VBG"},
"stints":	{"NNS","VBZ"},
"stipe":	{"NN"},
"stipend":	{"NN"},
"stipendiary":	{"JJ","NN"},
"stipends":	{"NNS"},
"stipple":	{"VB","VBP"},
"stippled":	{"VBD","VBN","JJ"},
"stippler":	{"NN"},
"stipples":	{"VBZ"},
"stippling":	{"VBG","NN"},
"stipulate":	{"VB","VBP"},
"stipulated":	{"VBD","VBN"},
"stipulates":	{"VBZ"},
"stipulating":	{"VBG"},
"stipulation":	{"NN"},
"stipulations":	{"NNS"},
"stipulatory":	{"JJ"},
"stipule":	{"NN"},
"stir":	{"NN","VB","VBP"},
"stir-fried":	{"VBD","VBN"},
"stir-fries":	{"VBZ","NNS"},
"stir-fry":	{"VB","VBP","NN","JJ"},
"stir-frying":	{"VBG"},
"stirk":	{"NN"},
"stirke":	{"NN"},
"stirred":	{"VBD","VBN"},
"stirrer":	{"NN"},
"stirrers":	{"NNS"},
"stirring":	{"VBG","JJ","NN"},
"stirringly":	{"RB"},
"stirrings":	{"NNS"},
"stirrup":	{"NN"},
"stirrup-cup":	{"NN"},
"stirrup-pump":	{"NN"},
"stirrups":	{"NNS"},
"stirs":	{"VBZ","NNS"},
"stitch":	{"NN","VB","VBP"},
"stitched":	{"VBD","VBN"},
"stitcher":	{"NN"},
"stitchery":	{"NN"},
"stitches":	{"NNS","VBZ"},
"stitching":	{"NN","VBG"},
"stitchwort":	{"NN"},
"stizidae":	{"NN"},
"stizolobium":	{"NN"},
"stizostedion":	{"NN"},
"stm":	{"NN"},
"stoat":	{"NN"},
"stoats":	{"NNS"},
"stob":	{"NN"},
"stochastic":	{"JJ"},
"stochastically":	{"RB"},
"stochasticity":	{"NN"},
"stock":	{"NN","VB","VBP","JJ"},
"stock-car":	{"NN"},
"stock-cars":	{"NNS"},
"stock-conspiracy":	{"NN"},
"stock-cube":	{"NN"},
"stock-cubes":	{"NNS"},
"stock-in-trade":	{"NN"},
"stock-market":	{"NN"},
"stock-pot":	{"NN"},
"stock-still":	{"JJ","RB"},
"stockade":	{"NN","VB","VBP"},
"stockaded":	{"VBD","VBN"},
"stockades":	{"NNS","VBZ"},
"stockading":	{"VBG"},
"stockbroker":	{"NN"},
"stockbrokerage":	{"NN"},
"stockbrokers":	{"NNS"},
"stockbroking":	{"NN"},
"stocked":	{"VBD","VBN"},
"stocker":	{"NN"},
"stockfish":	{"NN","NNS"},
"stockfishes":	{"NNS"},
"stockholder":	{"NN"},
"stockholders":	{"NNS"},
"stockholding":	{"NN"},
"stockholdings":	{"NNS"},
"stockholm":	{"NN"},
"stockhorn":	{"NN"},
"stockier":	{"JJR"},
"stockiest":	{"JJS"},
"stockily":	{"RB"},
"stockiness":	{"NN"},
"stockinet":	{"NN"},
"stockinette":	{"NN"},
"stocking":	{"NN","VBG"},
"stockinged":	{"JJ"},
"stockings":	{"NNS"},
"stockist":	{"NN"},
"stockists":	{"NNS"},
"stockjobber":	{"NN"},
"stockjobbers":	{"NNS"},
"stockman":	{"NN"},
"stockmen":	{"NNS"},
"stockpile":	{"NN","VB","VBP"},
"stockpiled":	{"VBD","VBN"},
"stockpiles":	{"NNS","VBZ"},
"stockpiling":	{"VBG","NN"},
"stockpot":	{"NN"},
"stockpots":	{"NNS"},
"stockroom":	{"NN"},
"stockrooms":	{"NNS"},
"stocks":	{"NNS","VBZ"},
"stocktake":	{"VB","VBP","NN"},
"stocktaken":	{"VBN"},
"stocktaker":	{"NN"},
"stocktakes":	{"VBZ","NNS"},
"stocktaking":	{"NN","VBG"},
"stockton":	{"NN"},
"stocktook":	{"VBD"},
"stocky":	{"JJ"},
"stockyard":	{"NN"},
"stockyards":	{"NNS"},
"stodge":	{"NN"},
"stodgier":	{"JJR"},
"stodgiest":	{"JJS"},
"stodgily":	{"RB"},
"stodginess":	{"NN"},
"stodgy":	{"JJ"},
"stoep":	{"NN"},
"stogey":	{"NN"},
"stogie":	{"NN"},
"stogies":	{"NNS"},
"stogy":	{"NN"},
"stoic":	{"JJ","NN"},
"stoical":	{"JJ"},
"stoically":	{"RB"},
"stoichiometric":	{"JJ"},
"stoichiometry":	{"NN"},
"stoicism":	{"NN"},
"stoics":	{"NNS"},
"stoke":	{"VB","VBP","NN"},
"stoked":	{"JJ","VBD","VBN"},
"stokehold":	{"NN"},
"stokehole":	{"NN"},
"stoker":	{"NN"},
"stokers":	{"NNS"},
"stokes":	{"VBZ"},
"stokesia":	{"NN"},
"stoking":	{"VBG"},
"stole":	{"VBD","NN"},
"stolen":	{"VBN","JJ"},
"stoles":	{"NNS"},
"stolid":	{"JJ"},
"stolidity":	{"NN"},
"stolidly":	{"RB"},
"stolidness":	{"NN"},
"stolon":	{"NN"},
"stoloniferous":	{"JJ"},
"stoma":	{"NN"},
"stomach":	{"NN","VB","VBP"},
"stomach-ache":	{"NN"},
"stomach-aches":	{"NNS"},
"stomach-churning":	{"JJ"},
"stomach-pump":	{"NN"},
"stomachache":	{"NN"},
"stomachaches":	{"NNS"},
"stomachal":	{"JJ"},
"stomached":	{"VBD","VBN"},
"stomacher":	{"NN"},
"stomachic":	{"JJ"},
"stomaching":	{"VBG"},
"stomachs":	{"VBZ","NNS"},
"stomachwise":	{"RB"},
"stomack":	{"NN"},
"stomatal":	{"JJ"},
"stomate":	{"NN"},
"stomatitis":	{"NN"},
"stomatopod":	{"NN"},
"stomatopoda":	{"NN"},
"stomatous":	{"JJ"},
"stomp":	{"VB","VBP","NN"},
"stomped":	{"VBD","VBN"},
"stomper":	{"NN"},
"stomping":	{"VBG","JJ"},
"stomps":	{"VBZ"},
"stone":	{"NN","VB","VBP","NNS"},
"stone-blind":	{"JJ"},
"stone-broke":	{"JJ"},
"stone-cold":	{"JJ"},
"stone-dead":	{"JJ"},
"stone-deaf":	{"JJ"},
"stone-face":	{"NN"},
"stone-fruit":	{"NN"},
"stone-root":	{"NN"},
"stone-throwing":	{"NN"},
"stonechat":	{"NN"},
"stonecress":	{"NN"},
"stonecrop":	{"NN"},
"stonecutter":	{"NN"},
"stoned":	{"JJ","VBD","VBN"},
"stoneface":	{"NN"},
"stonefish":	{"NN"},
"stonefly":	{"NN"},
"stonehenge":	{"NN"},
"stoneless":	{"JJ"},
"stonelike":	{"JJ"},
"stonemason":	{"NN"},
"stonemasons":	{"NNS"},
"stoner":	{"NN"},
"stoneroot":	{"NN"},
"stoners":	{"NNS"},
"stones":	{"NNS","VBZ"},
"stonewall":	{"VB","VBP"},
"stonewalled":	{"VBD","VBN"},
"stonewaller":	{"NN"},
"stonewalling":	{"VBG","NN"},
"stonewalls":	{"VBZ"},
"stoneware":	{"NN"},
"stonewash":	{"VB","VBP"},
"stonework":	{"NN"},
"stonewort":	{"NN"},
"stonier":	{"JJR"},
"stoniest":	{"JJS"},
"stonily":	{"RB"},
"stoning":	{"NN","VBG"},
"stony":	{"JJ"},
"stonyhearted":	{"JJ"},
"stood":	{"VBD","VBN"},
"stooge":	{"NN"},
"stooges":	{"NNS"},
"stool":	{"NN","VB","VBP"},
"stooled":	{"VBD","VBN"},
"stoolie":	{"NN"},
"stooling":	{"VBG"},
"stoolpigeon":	{"NN"},
"stools":	{"NNS","VBZ"},
"stoop":	{"VB","VBP","NN"},
"stooped":	{"VBD","VBN","JJ"},
"stooper":	{"NN"},
"stooping":	{"VBG","JJ"},
"stoops":	{"VBZ","NNS"},
"stop":	{"VB","NN","VBP"},
"stop-and-go":	{"JJ"},
"stop-go":	{"JJ"},
"stop-light":	{"NN"},
"stop-lights":	{"NNS"},
"stop-loss":	{"JJ"},
"stop-press":	{"NN"},
"stop-watch":	{"NN"},
"stop-watches":	{"NNS"},
"stop-work":	{"JJ"},
"stopcock":	{"NN"},
"stopcocks":	{"NNS"},
"stope":	{"NN","VB","VBP"},
"stoped":	{"VBD","VBN"},
"stopes":	{"NNS","VBZ"},
"stopgap":	{"NN"},
"stopgaps":	{"NNS"},
"stoping":	{"VBG"},
"stoplight":	{"NN"},
"stoplights":	{"NNS"},
"stopover":	{"NN"},
"stopovers":	{"NNS"},
"stoppable":	{"JJ"},
"stoppage":	{"NN"},
"stoppages":	{"NNS"},
"stoppard":	{"NN"},
"stopped":	{"VBD","VBN"},
"stopper":	{"NN","VB","VBP"},
"stoppered":	{"VBD","VBN"},
"stoppering":	{"VBG"},
"stoppers":	{"NNS","VBZ"},
"stopping":	{"VBG","NN"},
"stopple":	{"NN","VB"},
"stops":	{"VBZ","NNS"},
"stopwatch":	{"NN"},
"stopwatches":	{"NNS"},
"storability":	{"NN"},
"storage":	{"NN"},
"storax":	{"NN"},
"store":	{"NN","VB","VBP"},
"stored":	{"VBN","VBD"},
"storefront":	{"NN"},
"storefronts":	{"NNS"},
"storehouse":	{"NN"},
"storehouses":	{"NNS"},
"storekeeper":	{"NN"},
"storekeepers":	{"NNS"},
"storeria":	{"NN"},
"storeroom":	{"NN"},
"storerooms":	{"NNS"},
"stores":	{"NNS","VBZ"},
"storey":	{"NN"},
"storeyed":	{"JJ"},
"storeys":	{"NNS"},
"storied":	{"JJ","VBD","VBN"},
"stories":	{"NNS","VBZ"},
"storing":	{"VBG"},
"stork":	{"NN"},
"storks":	{"NNS"},
"storksbill":	{"NN"},
"storm":	{"NN","VB","VBP"},
"storm-bound":	{"JJ"},
"storm-centre":	{"NN"},
"storm-cloud":	{"NN"},
"storm-clouds":	{"NNS"},
"storm-door":	{"NN"},
"storm-doors":	{"NNS"},
"storm-lantern":	{"NN"},
"storm-lanterns":	{"NNS"},
"storm-tossed":	{"JJ"},
"storm-trooper":	{"NN"},
"storm-troopers":	{"NNS"},
"storm-window":	{"NN"},
"storm-windows":	{"NNS"},
"stormbound":	{"JJ"},
"stormcloud":	{"NN"},
"stormclouds":	{"NNS"},
"stormed":	{"VBD","VBN"},
"stormier":	{"JJR"},
"stormiest":	{"JJS"},
"stormily":	{"RB"},
"storminess":	{"NN"},
"storming":	{"VBG"},
"stormproof":	{"JJ"},
"storms":	{"NNS","VBZ"},
"stormtrooper":	{"NN"},
"stormtroopers":	{"NNS"},
"stormy":	{"JJ"},
"story":	{"NN","VB","VBP"},
"story-book":	{"NN","JJ"},
"story-books":	{"NNS"},
"story-line":	{"NN"},
"story-lines":	{"NNS"},
"story-teller":	{"NN"},
"story-tellers":	{"NNS"},
"story-telling":	{"NN"},
"storybook":	{"NN","JJ"},
"storybooks":	{"NNS"},
"storying":	{"VBG"},
"storyline":	{"NN"},
"storylines":	{"NNS"},
"storyteller":	{"NN"},
"storytellers":	{"NNS"},
"storytelling":	{"NN"},
"stotinka":	{"NN"},
"stoup":	{"NN"},
"stout":	{"NN","JJ"},
"stout-hearted":	{"JJ"},
"stouter":	{"JJR"},
"stoutest":	{"JJS"},
"stouthearted":	{"JJ"},
"stoutheartedness":	{"NN"},
"stoutly":	{"RB"},
"stoutness":	{"NN"},
"stouts":	{"NNS"},
"stove":	{"NN","VBD","VBN"},
"stovepipe":	{"NN"},
"stovepipes":	{"NNS"},
"stover":	{"NN"},
"stoves":	{"NNS"},
"stow":	{"VB","VBP"},
"stowage":	{"NN"},
"stowaway":	{"NN"},
"stowaways":	{"NNS"},
"stowe":	{"NN"},
"stowed":	{"VBD","VBN"},
"stowing":	{"NN","VBG"},
"stows":	{"VBZ"},
"stp":	{"NN"},
"strabismus":	{"NN"},
"strabotomy":	{"NN"},
"stracciatella":	{"NN"},
"stracciatellas":	{"NNS"},
"strad":	{"NN"},
"stradavarius":	{"NN"},
"straddle":	{"VB","VBP"},
"straddled":	{"VBD","VBN"},
"straddles":	{"VBZ"},
"straddling":	{"VBG"},
"stradivari":	{"NN"},
"strafe":	{"VB","VBP"},
"strafed":	{"VBD","VBN"},
"strafer":	{"NN"},
"strafes":	{"VBZ"},
"strafing":	{"VBG"},
"straggle":	{"VB","VBP"},
"straggled":	{"VBD","VBN"},
"straggler":	{"NN"},
"stragglers":	{"NNS"},
"straggles":	{"VBZ"},
"straggling":	{"JJ","VBG"},
"stragglingly":	{"RB"},
"straggly":	{"JJ"},
"straight":	{"JJ","RB","NN"},
"straight-arm":	{"VB","VBP","NN","JJ"},
"straight-armed":	{"VBD","VBN"},
"straight-arming":	{"VBG"},
"straight-arms":	{"VBZ"},
"straight-backed":	{"JJ","RB"},
"straight-billed":	{"JJ"},
"straight-edge":	{"NN"},
"straight-from-the-shoulder":	{"JJ"},
"straight-laced":	{"JJ"},
"straight-line":	{"JJ"},
"straight-out":	{"JJ"},
"straightarrow":	{"JJ"},
"straightaway":	{"NN","RB"},
"straightedge":	{"NN"},
"straighten":	{"VB","VBP"},
"straightened":	{"VBD","VBN"},
"straightener":	{"NN"},
"straighteners":	{"NNS"},
"straightening":	{"VBG"},
"straightens":	{"VBZ"},
"straighter":	{"JJR"},
"straightest":	{"JJS"},
"straightforward":	{"JJ"},
"straightforwardly":	{"RB"},
"straightforwardness":	{"NN"},
"straightjacket":	{"NN"},
"straightjackets":	{"NNS"},
"straightness":	{"NN"},
"straights":	{"NNS"},
"straightway":	{"RB"},
"strain":	{"NN","VB","VBP"},
"strained":	{"VBD","VBN","JJ"},
"strainer":	{"NN"},
"strainers":	{"NNS"},
"straining":	{"VBG"},
"strains":	{"NNS","VBZ"},
"strait":	{"NN","JJ"},
"strait-laced":	{"JJ"},
"straiten":	{"VB","VBP"},
"straitjacket":	{"NN"},
"straitjackets":	{"NNS"},
"straitlaced":	{"JJ"},
"straits":	{"NNS"},
"strake":	{"NN"},
"stramonium":	{"NN"},
"strand":	{"NN","VB","VBP"},
"stranded":	{"JJ","VBD","VBN"},
"stranding":	{"VBG"},
"strands":	{"NNS","VBZ"},
"strange":	{"JJ"},
"strangely":	{"RB"},
"strangeness":	{"NN"},
"stranger":	{"NN","JJR"},
"strangers":	{"NNS"},
"strangest":	{"JJS"},
"strangle":	{"VB","VBP"},
"strangled":	{"VBD","VBN","JJ"},
"stranglehold":	{"NN"},
"strangler":	{"NN"},
"stranglers":	{"NNS"},
"strangles":	{"NNS","VBZ"},
"strangling":	{"VBG","NN"},
"strangulate":	{"VB","VBP"},
"strangulation":	{"NN"},
"strap":	{"NN","VB","VBP"},
"strapado":	{"NN"},
"straphanger":	{"NN"},
"strapless":	{"JJ"},
"straplike":	{"JJ"},
"strappado":	{"NN"},
"strapped":	{"VBN","VBD","JJ"},
"strapper":	{"NN"},
"strapping":	{"JJ","VBG"},
"straps":	{"VBZ","NNS"},
"strasbourg":	{"NN"},
"strassburg":	{"NN"},
"strasser":	{"NN"},
"strata":	{"NNS"},
"stratagem":	{"NN"},
"stratagems":	{"NNS"},
"strategian":	{"NN"},
"strategic":	{"JJ"},
"strategical":	{"JJ"},
"strategically":	{"RB"},
"strategics":	{"NN"},
"strategies":	{"NNS"},
"strategise":	{"VB","VBP"},
"strategised":	{"VBD","VBN"},
"strategises":	{"VBZ"},
"strategising":	{"VBG"},
"strategist":	{"NN"},
"strategists":	{"NNS"},
"strategize":	{"VB","VBP"},
"strategized":	{"VBD","VBN"},
"strategizes":	{"VBZ"},
"strategizing":	{"VBG"},
"strategy":	{"NN"},
"stratification":	{"NN"},
"stratified":	{"JJ","VBD","VBN"},
"stratifies":	{"VBZ"},
"stratify":	{"VB","VBP"},
"stratifying":	{"VBG"},
"stratigraphy":	{"NN"},
"stratocracy":	{"NN"},
"stratosphere":	{"NN"},
"stratospheric":	{"JJ"},
"stratum":	{"NN"},
"stratus":	{"NN"},
"strauss":	{"NN"},
"stravinskian":	{"JJ"},
"stravinsky":	{"NN"},
"stravinskyan":	{"JJ"},
"straw":	{"NN","JJ"},
"straw-colored":	{"JJ"},
"straw-coloured":	{"JJ"},
"straw-hat":	{"JJ","NN"},
"straw-hats":	{"NNS"},
"strawberries":	{"NNS"},
"strawberry":	{"NN"},
"strawberry-mark":	{"NN"},
"strawboard":	{"NN"},
"strawflower":	{"NN"},
"strawhat":	{"JJ","NN"},
"strawhats":	{"NNS"},
"straws":	{"NNS"},
"strawworm":	{"NN"},
"stray":	{"VB","VBP","JJ","NN"},
"strayed":	{"VBD","VBN"},
"strayer":	{"NN"},
"straying":	{"VBG"},
"strays":	{"NNS","VBZ"},
"streak":	{"NN","VB","VBP"},
"streaked":	{"VBD","VBN"},
"streaker":	{"NN"},
"streakers":	{"NNS"},
"streakier":	{"JJR"},
"streakiest":	{"JJS"},
"streaking":	{"VBG"},
"streaks":	{"NNS","VBZ"},
"streaky":	{"JJ"},
"stream":	{"NN","VB","VBP"},
"stream-of-consciousness":	{"NN"},
"streambed":	{"NN"},
"streamed":	{"VBD","VBN"},
"streamer":	{"NN"},
"streamers":	{"NNS"},
"streaming":	{"NN","VBG"},
"streamlet":	{"NN"},
"streamline":	{"VB","VBP"},
"streamlined":	{"JJ","VBD","VBN"},
"streamliner":	{"NN"},
"streamlines":	{"VBZ"},
"streamlining":	{"VBG","NN"},
"streams":	{"NNS","VBZ"},
"streams-of-consciousness":	{"NNS"},
"streamside":	{"NN"},
"streep":	{"NN"},
"street":	{"NN"},
"street-girl":	{"NN"},
"street-wise":	{"JJ"},
"streetcar":	{"NN"},
"streetcars":	{"NNS"},
"streetfighter":	{"NN"},
"streetlight":	{"NN"},
"streetlights":	{"NNS"},
"streets":	{"NNS"},
"streetwalker":	{"NN"},
"streetwalkers":	{"NNS"},
"streetwalking":	{"NN","JJ"},
"streetwise":	{"JJ"},
"streisand":	{"NN"},
"strekelia":	{"NN"},
"strelitzia":	{"NN"},
"strelitziaceae":	{"NN"},
"strength":	{"NN"},
"strengthen":	{"VB","VBP"},
"strengthened":	{"VBD","VBN"},
"strengthener":	{"NN"},
"strengthening":	{"VBG","NN","JJ"},
"strengthens":	{"VBZ","NNS"},
"strengths":	{"NNS"},
"strenuosity":	{"NN"},
"strenuous":	{"JJ"},
"strenuously":	{"RB"},
"strenuousness":	{"NN"},
"strep":	{"NN"},
"strepera":	{"NN"},
"strepsiceros":	{"NNS"},
"strepsirhini":	{"NN"},
"streptobacillus":	{"NN"},
"streptocarpus":	{"NNS"},
"streptococcal":	{"JJ"},
"streptococci":	{"NNS"},
"streptococcic":	{"JJ"},
"streptococcus":	{"NN"},
"streptodornase":	{"NN"},
"streptokinase":	{"NN"},
"streptolysin":	{"NN"},
"streptomyces":	{"NN"},
"streptomycetaceae":	{"NN"},
"streptomycin":	{"NN"},
"streptopelia":	{"NN"},
"streptosolen":	{"NN"},
"streptothricin":	{"NN"},
"stress":	{"NN","VB","VBP"},
"stressed":	{"JJ","VBD","VBN"},
"stresses":	{"VBZ","NNS"},
"stressful":	{"JJ"},
"stressing":	{"VBG"},
"stressor":	{"NN"},
"stressors":	{"NNS"},
"stretch":	{"VB","VBP","NN","JJ"},
"stretchability":	{"NN"},
"stretchable":	{"JJ"},
"stretched":	{"VBD","VBN","JJ"},
"stretcher":	{"NN","VB","VBP"},
"stretcher-bearer":	{"NN"},
"stretcher-bearers":	{"NNS"},
"stretchered":	{"VBD","VBN"},
"stretchering":	{"VBG"},
"stretchers":	{"NNS","VBZ"},
"stretches":	{"VBZ","NNS"},
"stretchier":	{"JJR"},
"stretchiest":	{"JJS"},
"stretchiness":	{"NN"},
"stretching":	{"VBG"},
"stretchy":	{"JJ"},
"streusel":	{"NN"},
"strew":	{"VB","VBP"},
"strewed":	{"VBD","VBN"},
"strewing":	{"VBG"},
"strewn":	{"VBN","JJ"},
"strews":	{"VBZ"},
"stria":	{"NN"},
"striate":	{"JJ","VB","VBP"},
"striated":	{"JJ","VBD","VBN"},
"striates":	{"VBZ"},
"striating":	{"VBG"},
"striation":	{"NN"},
"striations":	{"NNS"},
"striatum":	{"NN"},
"stricken":	{"JJ","VBN"},
"strickland":	{"NN"},
"strickle":	{"NN","VB","VBP"},
"strickled":	{"VBD","VBN"},
"strickles":	{"NNS","VBZ"},
"strickling":	{"VBG"},
"strict":	{"JJ"},
"stricter":	{"JJR"},
"strictest":	{"JJS"},
"strictly":	{"RB"},
"strictness":	{"NN"},
"stricture":	{"NN"},
"strictures":	{"NNS"},
"stridden":	{"VBN"},
"stride":	{"VB","VBP","NN"},
"stridence":	{"NN"},
"stridency":	{"NN"},
"strident":	{"JJ"},
"stridently":	{"RB"},
"strider":	{"NN"},
"strides":	{"VBZ","NNS"},
"striding":	{"VBG"},
"stridor":	{"NN"},
"stridulate":	{"VB","VBP"},
"stridulated":	{"VBD","VBN"},
"stridulates":	{"VBZ"},
"stridulating":	{"VBG"},
"stridulation":	{"NN"},
"strife":	{"NN"},
"strigidae":	{"NN"},
"strigiformes":	{"NNS"},
"strike":	{"NN","VB","VBP"},
"strike-breaker":	{"NN"},
"strike-breakers":	{"NNS"},
"strike-breaking":	{"NN"},
"strike-force":	{"NN"},
"strikebound":	{"JJ"},
"strikebreaker":	{"NN"},
"strikebreakers":	{"NNS"},
"strikebreaking":	{"NN"},
"strikeout":	{"NN"},
"strikeouts":	{"NNS"},
"striker":	{"NN"},
"strikers":	{"NNS"},
"strikes":	{"NNS","VBZ"},
"striking":	{"JJ","VBG"},
"strikingly":	{"RB"},
"strikingness":	{"NN"},
"strindberg":	{"NN"},
"string":	{"NN","VB","VBP"},
"stringed":	{"JJ"},
"stringency":	{"NN"},
"stringent":	{"JJ"},
"stringently":	{"RB"},
"stringer":	{"NN"},
"stringers":	{"NNS"},
"stringier":	{"JJR"},
"stringiest":	{"JJS"},
"stringing":	{"VBG"},
"strings":	{"NNS","VBZ"},
"stringy":	{"JJ"},
"stringybark":	{"NN"},
"strip":	{"VB","VBP","NN"},
"strip-mine":	{"VB","VBP"},
"strip-mined":	{"VBD","VBN"},
"strip-mines":	{"VBZ"},
"strip-mining":	{"VBG"},
"strip-search":	{"VB","VBP","NN"},
"strip-searched":	{"VBD","VBN"},
"strip-searches":	{"VBZ","NNS"},
"strip-searching":	{"VBG"},
"strip-tease":	{"NN"},
"strip-teases":	{"NNS"},
"stripe":	{"NN","VB","VBP"},
"striped":	{"JJ","VBD","VBN"},
"striper":	{"NN"},
"stripes":	{"NNS","VBZ"},
"striping":	{"VBG"},
"stripling":	{"NN"},
"striplings":	{"NNS"},
"stripped":	{"VBD","VBN"},
"stripper":	{"NN"},
"strippers":	{"NNS"},
"stripping":	{"VBG"},
"strips":	{"NNS","VBZ"},
"striptease":	{"NN"},
"stripteaser":	{"NN"},
"stripteases":	{"NNS"},
"stripy":	{"JJ"},
"strive":	{"VB","VBP"},
"striven":	{"VBN"},
"striver":	{"NN"},
"strivers":	{"NNS"},
"strives":	{"VBZ"},
"striving":	{"NN","VBG"},
"strivings":	{"NNS"},
"strix":	{"NN"},
"strobe":	{"NN"},
"strobes":	{"NNS"},
"strobile":	{"NN"},
"strobilomyces":	{"NN"},
"strobilus":	{"NN"},
"stroboscope":	{"NN"},
"stroboscopic":	{"JJ"},
"strode":	{"VBD"},
"stroheim":	{"NN"},
"stroke":	{"NN","VB","VBP"},
"stroked":	{"VBD","VBN"},
"strokes":	{"NNS","VBZ"},
"stroking":	{"VBG"},
"stroll":	{"VB","VBP","NN"},
"strolled":	{"VBD","VBN"},
"stroller":	{"NN"},
"strollers":	{"NNS"},
"strolling":	{"JJ","VBG"},
"strolls":	{"VBZ","NNS"},
"stroma":	{"NN"},
"stromateid":	{"NN"},
"stromateidae":	{"NN"},
"strombidae":	{"NN"},
"strombus":	{"NN"},
"strong":	{"JJ"},
"strong-arm":	{"JJ","VB","VBP"},
"strong-armed":	{"VBD","VBN"},
"strong-armer":	{"NN"},
"strong-arming":	{"VBG"},
"strong-arms":	{"VBZ"},
"strong-boned":	{"JJ"},
"strong-box":	{"NN"},
"strong-boxes":	{"NNS"},
"strong-minded":	{"JJ"},
"strong-willed":	{"JJ"},
"strongbox":	{"NN"},
"strongboxes":	{"NNS"},
"stronger":	{"JJR"},
"strongest":	{"JJS"},
"stronghearted":	{"JJ"},
"stronghold":	{"NN"},
"strongholds":	{"NNS"},
"strongly":	{"RB"},
"strongman":	{"NN"},
"strongmen":	{"NNS"},
"strongroom":	{"NN"},
"strongrooms":	{"NNS"},
"strongylodon":	{"NN"},
"strontianite":	{"NN"},
"strontium":	{"NN"},
"strop":	{"NN","VB","VBP"},
"strophanthin":	{"NN"},
"strophanthus":	{"NN"},
"stropharia":	{"NN"},
"strophariaceae":	{"NN"},
"strophe":	{"NN"},
"stropped":	{"VBD","VBN"},
"stroppier":	{"JJR"},
"stroppiest":	{"JJS"},
"stroppiness":	{"NN"},
"stropping":	{"NN","VBG"},
"stroppy":	{"JJ"},
"strops":	{"NNS","VBZ"},
"stroud":	{"NN"},
"strove":	{"VBD"},
"struck":	{"VBD","VBN","JJ"},
"structively":	{"RB"},
"structural":	{"JJ"},
"structuralism":	{"NN"},
"structuralist":	{"JJ","NN"},
"structuralists":	{"NNS"},
"structurally":	{"RB"},
"structure":	{"NN","VB","VBP"},
"structured":	{"JJ","VBD","VBN"},
"structures":	{"NNS","VBZ"},
"structuring":	{"VBG","NN"},
"strudel":	{"NN"},
"strudels":	{"NNS"},
"struggle":	{"NN","VB","VBP"},
"struggled":	{"VBD","VBN"},
"struggler":	{"NN"},
"struggles":	{"NNS","VBZ"},
"struggling":	{"VBG","JJ"},
"strum":	{"VB","VBP","NN"},
"struma":	{"NN"},
"strummed":	{"VBD","VBN"},
"strumming":	{"VBG"},
"strumpet":	{"NN"},
"strumpets":	{"NNS"},
"strums":	{"VBZ"},
"strung":	{"VBD","VBN"},
"strung-out":	{"JJ"},
"strut":	{"NN","VB","VBP"},
"struthio":	{"NN"},
"struthiomimus":	{"NN"},
"struthionidae":	{"NN"},
"struthioniformes":	{"NNS"},
"struts":	{"NNS","VBZ"},
"strutted":	{"VBD","VBN"},
"strutting":	{"NN","VBG"},
"strychnine":	{"NN"},
"strymon":	{"NN"},
"sts":	{"NN"},
"stuart":	{"NN"},
"stub":	{"NN","VB","VBP"},
"stubbed":	{"VBN","VBD"},
"stubbiness":	{"NN"},
"stubbing":	{"VBG"},
"stubble":	{"NN"},
"stubbly":	{"JJ"},
"stubborn":	{"JJ"},
"stubbornly":	{"RB"},
"stubbornness":	{"NN"},
"stubbs":	{"NNS"},
"stubby":	{"JJ"},
"stubs":	{"NNS","VBZ"},
"stucco":	{"NN","VB","VBP"},
"stuccoed":	{"VBD","VBN","JJ"},
"stuccoes":	{"NNS","VBZ"},
"stuccoing":	{"VBG"},
"stuccos":	{"NNS","VBZ"},
"stuck":	{"VBN","VBD","JJ"},
"stuck-up":	{"JJ"},
"stuckey":	{"NN"},
"stud":	{"NN","VB","VBP"},
"stud-book":	{"NN"},
"stud-books":	{"NNS"},
"studbook":	{"NN"},
"studbooks":	{"NNS"},
"studded":	{"JJ","VBD","VBN"},
"studding":	{"VBG"},
"student":	{"NN"},
"students":	{"NNS"},
"studentship":	{"NN"},
"studhorse":	{"NN"},
"studia":	{"FW"},
"studied":	{"VBD","VBN","JJ"},
"studies":	{"NNS","VBZ"},
"studio":	{"NN"},
"studios":	{"NNS"},
"studious":	{"JJ"},
"studiously":	{"RB"},
"studiousness":	{"NN"},
"studs":	{"VBZ","NNS"},
"Study":	{"NN","VB","VBP"},
"study":	{"NN","VB","VBP"},
"studying":	{"VBG"},
"stuff":	{"NN","VB","VBP"},
"stuffed":	{"JJ","VBD","VBN"},
"stuffer":	{"NN"},
"stuffier":	{"JJR"},
"stuffiest":	{"JJS"},
"stuffily":	{"RB"},
"stuffiness":	{"NN"},
"stuffing":	{"NN","VBG"},
"stuffs":	{"VBZ"},
"stuffy":	{"JJ"},
"stultification":	{"NN"},
"stultified":	{"VBD","VBN"},
"stultifies":	{"VBZ"},
"stultify":	{"VB","VBP"},
"stultifying":	{"VBG","JJ"},
"stumble":	{"VB","VBP","NN"},
"stumblebum":	{"NN"},
"stumbled":	{"VBD","VBN"},
"stumbler":	{"NN"},
"stumbles":	{"VBZ","NNS"},
"stumbling":	{"VBG"},
"stumbling-block":	{"NN"},
"stumbling-blocks":	{"NNS"},
"stump":	{"NN","VB","VBP"},
"stumpage":	{"NN"},
"stumped":	{"VBD","VBN","JJ"},
"stumper":	{"NN"},
"stumpers":	{"NNS"},
"stumpier":	{"JJR"},
"stumpiest":	{"JJS"},
"stumpiness":	{"NN"},
"stumping":	{"VBG"},
"stumpknocker":	{"NN"},
"stumps":	{"NNS","VBZ"},
"stumpy":	{"JJ"},
"stun":	{"VB","VBP"},
"stung":	{"JJ","VBD","VBN"},
"stunk":	{"NN","JJ","VBN"},
"stunned":	{"VBN","VBD","JJ"},
"stunner":	{"NN"},
"stunners":	{"NNS"},
"stunning":	{"JJ","VBG"},
"stunningly":	{"RB"},
"stuns":	{"VBZ"},
"stunt":	{"NN","VB","VBP"},
"stunted":	{"VBD","VBN","JJ"},
"stuntedness":	{"NN"},
"stunting":	{"VBG"},
"stunts":	{"VBZ","NNS"},
"stupa":	{"NN"},
"stupe":	{"NN"},
"stupefaction":	{"NN"},
"stupefied":	{"JJ","VBD","VBN"},
"stupefies":	{"VBZ"},
"stupefy":	{"VB","VBP"},
"stupefying":	{"VBG","JJ"},
"stupefyingly":	{"RB"},
"stupendous":	{"JJ"},
"stupendously":	{"RB"},
"stupid":	{"JJ","NN"},
"stupider":	{"JJR"},
"stupidest":	{"JJS"},
"stupidities":	{"NNS"},
"stupidity":	{"NN"},
"stupidly":	{"RB"},
"stupor":	{"NN"},
"stuporous":	{"JJ"},
"stupors":	{"NNS"},
"sturdier":	{"JJR"},
"sturdiest":	{"JJS"},
"sturdily":	{"RB"},
"sturdiness":	{"NN"},
"sturdy":	{"JJ"},
"sturgeon":	{"NN","NNS"},
"sturmabteilung":	{"NN"},
"sturnella":	{"NN"},
"sturnidae":	{"NN"},
"sturnus":	{"NN"},
"stutter":	{"VB","VBP","NN"},
"stuttered":	{"VBD","VBN"},
"stutterer":	{"NN"},
"stutterers":	{"NNS"},
"stuttering":	{"VBG","NN"},
"stutters":	{"VBZ","NNS"},
"stuttgart":	{"NN"},
"stuyvesant":	{"NN"},
"sty":	{"NN"},
"stye":	{"NN"},
"styes":	{"NNS"},
"style":	{"NN","VBP","VB"},
"styled":	{"VBN","VBD","JJ"},
"styleless":	{"JJ"},
"stylemark":	{"NN"},
"styler":	{"NN"},
"styles":	{"NNS","VBZ"},
"stylet":	{"NN"},
"styling":	{"NN","VBG"},
"stylisation":	{"NN"},
"stylise":	{"VB","VBP"},
"stylised":	{"JJ"},
"stylish":	{"JJ"},
"stylishly":	{"RB"},
"stylishness":	{"NN"},
"stylist":	{"NN"},
"stylistic":	{"JJ"},
"stylistically":	{"RB"},
"stylists":	{"NNS"},
"stylite":	{"NN"},
"stylization":	{"NN"},
"stylize":	{"VB","VBP"},
"stylized":	{"JJ","VBD","VBN"},
"stylizes":	{"VBZ"},
"stylizing":	{"VBG"},
"stylomecon":	{"NN"},
"stylophorum":	{"NN"},
"stylopodium":	{"NN"},
"stylostixis":	{"NNS"},
"stylus":	{"NN"},
"styluses":	{"NNS"},
"stymie":	{"VB","VBP","NN"},
"stymied":	{"VBN","VBD"},
"stymieing":	{"VBG"},
"stymies":	{"VBZ","NNS"},
"stymy":	{"NN","VB","VBP"},
"styphelia":	{"NN"},
"stypsis":	{"NN"},
"styptic":	{"JJ","NN"},
"styracaceae":	{"NN"},
"styracosaur":	{"NN"},
"styracosaurus":	{"NN"},
"styrax":	{"NN"},
"styrene":	{"NN"},
"styrenes":	{"NNS"},
"styrofoam":	{"NN"},
"styron":	{"NN"},
"styryl-lithium":	{"NN"},
"suability":	{"NN"},
"suable":	{"JJ"},
"suasible":	{"JJ"},
"suasion":	{"NN"},
"suave":	{"JJ"},
"suavely":	{"RB"},
"suaveness":	{"NN"},
"suaver":	{"JJR"},
"suavest":	{"JJS"},
"suavity":	{"NN"},
"sub":	{"NN","VB","VBP"},
"sub-chiefdom":	{"NN"},
"sub-continent":	{"NN"},
"sub-continents":	{"NNS"},
"sub-group":	{"NN"},
"sub-groups":	{"NNS"},
"sub-interval":	{"NN"},
"sub-minimum":	{"JJ"},
"sub-normal":	{"JJ","NNS"},
"sub-par":	{"JJ"},
"sub-rosa":	{"JJ"},
"sub-section":	{"NN"},
"sub-sections":	{"NNS"},
"sub-station":	{"NN"},
"sub-stations":	{"NNS"},
"sub-therapeutic":	{"JJ"},
"sub-total":	{"NN"},
"sub-totals":	{"NNS"},
"sub-zero":	{"JJ"},
"subacid":	{"JJ"},
"subacute":	{"JJ"},
"subalpine":	{"NN"},
"subaltern":	{"NN"},
"subalterns":	{"NNS"},
"subaquatic":	{"JJ"},
"subaqueous":	{"JJ"},
"subarctic":	{"JJ"},
"subartesian":	{"JJ"},
"subaru":	{"NN"},
"subassemblies":	{"NNS"},
"subassembly":	{"NN"},
"subatomic":	{"JJ"},
"subbase":	{"NN"},
"subbed":	{"VBD","VBN"},
"subbing":	{"VBG"},
"subcategory":	{"NN"},
"subchief":	{"NN"},
"subchiefs":	{"NNS"},
"subclass":	{"NN"},
"subclavian":	{"NN","JJ"},
"subclinical":	{"JJ"},
"subcommittee":	{"NN"},
"subcommittees":	{"NNS"},
"subcompact":	{"NN"},
"subcompacts":	{"NNS"},
"subconscious":	{"JJ","NN"},
"subconsciously":	{"RB"},
"subconsciousness":	{"NN"},
"subcontinent":	{"NN"},
"subcontinents":	{"NNS"},
"subcontract":	{"NN","VB","VBP"},
"subcontracted":	{"VBD","VBN"},
"subcontracting":	{"NN","VBG"},
"subcontractor":	{"NN"},
"subcontractors":	{"NNS"},
"subcontracts":	{"NNS","VBZ"},
"subcortical":	{"JJ"},
"subculture":	{"NN"},
"subcultures":	{"NNS"},
"subcutaneous":	{"JJ"},
"subcutaneously":	{"RB"},
"subdeacon":	{"NN"},
"subdirector":	{"NN"},
"subdirectory":	{"NN"},
"subdivide":	{"VB","VBP"},
"subdivided":	{"VBD","VBN"},
"subdivider":	{"NN"},
"subdivides":	{"VBZ"},
"subdividing":	{"VBG"},
"subdivision":	{"NN"},
"subdivisions":	{"NNS"},
"subdominant":	{"NN","JJ"},
"subduable":	{"JJ"},
"subduction":	{"NN"},
"subdue":	{"VB","VBP"},
"subdued":	{"JJ","VBD","VBN"},
"subduedness":	{"NN"},
"subduer":	{"NN"},
"subdues":	{"VBZ"},
"subduing":	{"VBG"},
"subdural":	{"JJ"},
"subedit":	{"VB","VBP"},
"subedited":	{"VBD","VBN"},
"subediting":	{"VBG"},
"subeditor":	{"NN"},
"subedits":	{"VBZ"},
"subfamily":	{"NN"},
"subfigure":	{"NN"},
"subfigures":	{"NNS"},
"subfolder":	{"NN"},
"subfolders":	{"NNS"},
"subfusc":	{"JJ","NN"},
"subgenus":	{"NN"},
"subgross":	{"JJ"},
"subgroup":	{"NN"},
"subgroups":	{"NNS"},
"subhead":	{"NN"},
"subheading":	{"NN"},
"subheadings":	{"NNS"},
"subhuman":	{"JJ"},
"subhumanity":	{"NN"},
"subindustry":	{"NN"},
"subjacent":	{"JJ"},
"subject":	{"NN","JJ","VB","VBP"},
"subject-matter":	{"NN"},
"subjected":	{"VBN","VBD"},
"subjecting":	{"VBG"},
"subjection":	{"NN"},
"subjective":	{"JJ"},
"subjectively":	{"RB"},
"subjectiveness":	{"NN"},
"subjectivism":	{"NN"},
"subjectivist":	{"NN"},
"subjectivists":	{"NNS"},
"subjectivity":	{"NN"},
"subjects":	{"NNS","VBZ"},
"subjoin":	{"VB","VBP"},
"subjoining":	{"VBG"},
"subjugable":	{"JJ"},
"subjugate":	{"VB","VBP"},
"subjugated":	{"VBD","VBN"},
"subjugates":	{"VBZ"},
"subjugating":	{"VBG"},
"subjugation":	{"NN"},
"subjugator":	{"NN"},
"subjunction":	{"NN"},
"subjunctive":	{"JJ","NN"},
"subjunctives":	{"NNS"},
"subkingdom":	{"NN"},
"sublease":	{"VB","VBP","NN"},
"subleased":	{"VBD","VBN"},
"subleases":	{"VBZ"},
"subleasing":	{"VBG"},
"sublet":	{"VB","VBP","VBD","VBN","NN"},
"sublets":	{"VBZ","NNS"},
"subletting":	{"VBG"},
"sublicense":	{"VB","VBP","NN"},
"sublieutenant":	{"NN"},
"sublieutenants":	{"NNS"},
"sublimate":	{"VB","VBP","NN"},
"sublimated":	{"NN","VBD","VBN"},
"sublimates":	{"VBZ"},
"sublimating":	{"VBG"},
"sublimation":	{"NN"},
"sublimaze":	{"NN"},
"sublime":	{"JJ","NN","VB","VBP"},
"sublimed":	{"JJ","VBD","VBN"},
"sublimely":	{"RB"},
"sublimeness":	{"NN"},
"sublimes":	{"VBZ"},
"subliminal":	{"JJ"},
"subliminally":	{"RB"},
"subliming":	{"VBG"},
"sublimity":	{"NN"},
"sublingual":	{"JJ"},
"subliterary":	{"JJ"},
"sublittoral":	{"JJ"},
"sublunar":	{"JJ"},
"sublunary":	{"JJ"},
"subluxate":	{"VB","VBP"},
"subluxation":	{"NN"},
"submachine":	{"NN"},
"submarine":	{"NN","JJ","VB","VBP"},
"submarined":	{"VBD","VBN"},
"submariner":	{"NN"},
"submariners":	{"NNS"},
"submarines":	{"NNS","VBZ"},
"submarining":	{"VBG"},
"submaxilla":	{"NN"},
"submediant":	{"NN"},
"submenu":	{"NN"},
"submerge":	{"VB","VBP"},
"submerged":	{"JJ","VBD","VBN"},
"submergence":	{"NN"},
"submerges":	{"VBZ"},
"submergible":	{"JJ"},
"submerging":	{"VBG"},
"submerse":	{"VB","VBP"},
"submersed":	{"JJ","VBD","VBN"},
"submerses":	{"VBZ"},
"submersible":	{"JJ","NN"},
"submersing":	{"VBG"},
"submersion":	{"NN"},
"subminimum":	{"JJ","NN"},
"submission":	{"NN"},
"submissions":	{"NNS"},
"submissive":	{"JJ"},
"submissively":	{"RB"},
"submissiveness":	{"NN"},
"submit":	{"VB","VBP"},
"submits":	{"VBZ"},
"submitted":	{"VBN","VBD"},
"submitter":	{"NN"},
"submitting":	{"VBG"},
"submucosa":	{"NN"},
"subnational":	{"JJ"},
"subnormal":	{"JJ","NNS"},
"subnormality":	{"NN"},
"subocean":	{"JJ"},
"suboceanic":	{"JJ"},
"subocular":	{"JJ"},
"suborbital":	{"JJ"},
"suborder":	{"NN"},
"subordinate":	{"JJ","NN","VB","VBP"},
"subordinated":	{"VBN","VBD","JJ"},
"subordinateness":	{"NN"},
"subordinates":	{"VBZ","NNS"},
"subordinating":	{"VBG"},
"subordination":	{"NN"},
"subordinative":	{"JJ"},
"subordinator":	{"NN"},
"suborn":	{"VB","VBP"},
"subornation":	{"NN"},
"suborned":	{"VBD","VBN"},
"suborner":	{"NN"},
"suborning":	{"VBG"},
"suborns":	{"VBZ"},
"subpackage":	{"NN"},
"subpackages":	{"NNS"},
"subpar":	{"JJ","NN"},
"subparagraph":	{"NN"},
"subpart":	{"NN"},
"subparts":	{"NNS"},
"subphylum":	{"NN"},
"subplot":	{"NN"},
"subplots":	{"NNS"},
"subpoena":	{"NN","VB","VBP"},
"subpoenaed":	{"VBD","VBN"},
"subpoenaing":	{"VBG"},
"subpoenas":	{"NNS","VBZ"},
"subpopulation":	{"NN"},
"subprogram":	{"NN"},
"subreddit":	{"NN"},
"subreddits":	{"NNS"},
"subrogate":	{"VB","VBP"},
"subrogation":	{"NN"},
"subroutine":	{"NN"},
"subroutines":	{"NNS"},
"subs":	{"NNS","VBZ"},
"subscribe":	{"VB","VBP"},
"subscribed":	{"VBD","VBN"},
"subscriber":	{"NN"},
"subscribers":	{"NNS"},
"subscribes":	{"VBZ"},
"subscribing":	{"VBG"},
"subscript":	{"NN","JJ"},
"subscription":	{"NN"},
"subscriptions":	{"NNS"},
"subscripts":	{"NNS"},
"subsection":	{"NN"},
"subsections":	{"NNS"},
"subsequence":	{"NN"},
"subsequent":	{"JJ"},
"subsequently":	{"RB"},
"subsequentness":	{"NN"},
"subserve":	{"VB","VBP"},
"subservience":	{"NN"},
"subservient":	{"JJ","NN"},
"subserviently":	{"RB"},
"subservientness":	{"NN"},
"subset":	{"NN"},
"subsets":	{"NNS"},
"subshrub":	{"NN"},
"subsidary":	{"JJ"},
"subside":	{"VB","VBP"},
"subsided":	{"VBD","VBN"},
"subsidence":	{"NN"},
"subsides":	{"VBZ","NNS"},
"subsidiaries":	{"NNS"},
"subsidiarity":	{"NN"},
"subsidiary":	{"NN","JJ"},
"subsidies":	{"NNS"},
"subsiding":	{"VBG"},
"subsidisation":	{"NN"},
"subsidise":	{"VB","VBP"},
"subsidised":	{"VBD","VBN","JJ"},
"subsidiser":	{"NN"},
"subsidises":	{"VBZ"},
"subsidising":	{"VBG","NN"},
"subsidization":	{"NN"},
"subsidize":	{"VB","VBP"},
"subsidized":	{"VBD","VBN","JJ"},
"subsidizer":	{"NN"},
"subsidizes":	{"VBZ"},
"subsidizing":	{"VBG","NN"},
"subsidy":	{"NN"},
"subsist":	{"VB","VBP"},
"subsisted":	{"VBD","VBN"},
"subsistence":	{"NN","JJ"},
"subsistent":	{"JJ"},
"subsister":	{"NN"},
"subsisting":	{"VBG"},
"subsists":	{"VBZ"},
"subskill":	{"NN"},
"subskills":	{"NNS"},
"subsoil":	{"NN","VB","VBP"},
"subsoiled":	{"VBD","VBN"},
"subsoiling":	{"VBG"},
"subsoils":	{"VBZ"},
"subsonic":	{"JJ"},
"subspace":	{"NN"},
"subspaces":	{"NNS"},
"subspecies":	{"NN","NNS"},
"substance":	{"NN"},
"substances":	{"NNS"},
"substandard":	{"JJ"},
"substantial":	{"JJ"},
"substantiality":	{"NN"},
"substantially":	{"RB"},
"substantialness":	{"NN"},
"substantiate":	{"VB","VBP"},
"substantiated":	{"VBD","VBN"},
"substantiates":	{"VBZ"},
"substantiating":	{"VBG"},
"substantiation":	{"NN"},
"substantiative":	{"JJ"},
"substantival":	{"JJ"},
"substantive":	{"JJ","NN"},
"substantively":	{"RB"},
"substation":	{"NN"},
"substations":	{"NNS"},
"substerilization":	{"NN"},
"substitutability":	{"NN"},
"substitutable":	{"JJ"},
"substitute":	{"NN","VB","VBP"},
"substituted":	{"VBN","VBD"},
"substitutes":	{"VBZ","NNS"},
"substituting":	{"VBG"},
"substitution":	{"NN"},
"substitutionary":	{"JJ"},
"substitutions":	{"NNS"},
"substrata":	{"NNS"},
"substrate":	{"NN"},
"substrates":	{"NNS"},
"substratum":	{"NN"},
"substring":	{"NN"},
"substructure":	{"NN"},
"subsume":	{"VB","VBP"},
"subsumed":	{"VBD","VBN"},
"subsumes":	{"VBZ"},
"subsuming":	{"VBG"},
"subsumption":	{"NN"},
"subsurface":	{"JJ","NN"},
"subsystem":	{"NN"},
"subsystems":	{"NNS"},
"subtend":	{"VB","VBP"},
"subtended":	{"VBD","VBN"},
"subtending":	{"VBG"},
"subtends":	{"VBZ"},
"subterfuge":	{"NN"},
"subterfuges":	{"NNS"},
"subterminal":	{"JJ"},
"subterranean":	{"JJ"},
"subterraneous":	{"JJ"},
"subtest":	{"NN"},
"subtests":	{"NNS"},
"subtext":	{"NN"},
"subtexts":	{"NNS"},
"subthalamus":	{"NN"},
"subtilin":	{"NN"},
"subtilisation":	{"NN"},
"subtilise":	{"VB","VBP"},
"subtiliser":	{"NN"},
"subtilization":	{"NN"},
"subtilize":	{"VB","VBP"},
"subtilizer":	{"NN"},
"subtitle":	{"NN","VB","VBP"},
"subtitled":	{"VBD","VBN","JJ"},
"subtitles":	{"VBZ","NNS"},
"subtitling":	{"VBG"},
"subtle":	{"JJ"},
"subtler":	{"JJR"},
"subtlest":	{"JJS"},
"subtleties":	{"NNS"},
"subtlety":	{"NN"},
"subtly":	{"RB"},
"subtonic":	{"NN"},
"subtopia":	{"NN"},
"subtotal":	{"NN"},
"subtotals":	{"NNS"},
"subtract":	{"VB","VBP"},
"subtracted":	{"VBD","VBN"},
"subtracter":	{"NN"},
"subtracting":	{"VBG"},
"subtraction":	{"NN"},
"subtractions":	{"NNS"},
"subtractive":	{"JJ"},
"subtracts":	{"VBZ"},
"subtrahend":	{"NN"},
"subtreasury":	{"NN"},
"subtropic":	{"JJ"},
"subtropical":	{"JJ"},
"subtropics":	{"NNS"},
"subtweet":	{"NN","VB","VBP"},
"subtweeted":	{"VBD","VBN"},
"subtweeting":	{"VBG","NN"},
"subtweets":	{"NNS","VBZ"},
"subtype":	{"NN"},
"subtypes":	{"NNS"},
"subtypical":	{"JJ"},
"subularia":	{"NN"},
"subunit":	{"NN"},
"suburb":	{"NN"},
"suburban":	{"JJ"},
"suburbanise":	{"VB"},
"suburbanised":	{"VBD","VBN"},
"suburbanises":	{"VBZ"},
"suburbanising":	{"VBG"},
"suburbanite":	{"NN"},
"suburbanites":	{"NNS"},
"suburbanize":	{"VB","VBP"},
"suburbanized":	{"VBD","VBN"},
"suburbanizes":	{"VBZ"},
"suburbanizing":	{"VBG"},
"suburbia":	{"NN"},
"suburbs":	{"NNS"},
"subvention":	{"NN"},
"subventionary":	{"JJ"},
"subventions":	{"NNS"},
"subversion":	{"NN"},
"subversive":	{"JJ","NN"},
"subversively":	{"RB"},
"subversiveness":	{"NN"},
"subversives":	{"NNS"},
"subvert":	{"VB","VBP"},
"subverted":	{"VBD","VBN"},
"subverter":	{"NN"},
"subverting":	{"VBG"},
"subverts":	{"VBZ"},
"subvocalise":	{"VB","VBP"},
"subvocaliser":	{"NN"},
"subvocalize":	{"VB","VBP"},
"subvocalizer":	{"NN"},
"subway":	{"NN"},
"subways":	{"NNS"},
"subwoofer":	{"NN"},
"subzero":	{"JJ"},
"succade":	{"NN"},
"succedaneum":	{"NN"},
"succeed":	{"VB","VBP"},
"succeeded":	{"VBN","VBD"},
"succeeder":	{"NN"},
"succeeding":	{"JJ","VBG"},
"succeeds":	{"VBZ"},
"success":	{"NN"},
"successes":	{"NNS"},
"successful":	{"JJ"},
"successfully":	{"RB"},
"successfulness":	{"NN"},
"succession":	{"NN"},
"successive":	{"JJ"},
"successively":	{"RB"},
"successiveness":	{"NN"},
"successor":	{"NN"},
"successors":	{"NNS"},
"successorship":	{"NN"},
"succinct":	{"JJ"},
"succinctly":	{"RB"},
"succinctness":	{"NN"},
"succinic":	{"JJ"},
"succinylcholine":	{"NN"},
"succor":	{"NN","VB","VBP"},
"succored":	{"VBD","VBN"},
"succorer":	{"NN"},
"succoring":	{"VBG"},
"succors":	{"VBZ"},
"succory":	{"NN"},
"succos":	{"NN"},
"succotash":	{"NN"},
"succour":	{"NN","VB","VBP"},
"succoured":	{"VBD","VBN"},
"succourer":	{"NN"},
"succouring":	{"VBG"},
"succours":	{"VBZ"},
"succuba":	{"NN"},
"succubi":	{"NNS"},
"succubus":	{"NN"},
"succulence":	{"NN"},
"succulency":	{"NN"},
"succulent":	{"JJ","NN"},
"succulents":	{"NNS"},
"succumb":	{"VB","VBP"},
"succumbed":	{"VBD","VBN"},
"succumbing":	{"VBG"},
"succumbs":	{"VBZ"},
"succus":	{"NN"},
"succuss":	{"VB","VBP"},
"succussion":	{"NN"},
"such":	{"JJ","PDT","PRP"},
"suchlike":	{"JJ","DT","PRP"},
"suck":	{"VB","NN","VBP"},
"sucked":	{"VBD","VBN"},
"sucker":	{"NN","VBP","VB"},
"suckered":	{"VBD","VBN"},
"suckerfish":	{"NN"},
"suckering":	{"VBG"},
"suckers":	{"NNS","VBZ"},
"sucking":	{"VBG"},
"suckle":	{"VB","VBP"},
"suckled":	{"VBD","VBN"},
"suckles":	{"VBZ"},
"suckling":	{"VBG","NN"},
"sucklings":	{"NNS"},
"sucks":	{"VBZ"},
"sucralfate":	{"NN"},
"sucrase":	{"NN"},
"sucre":	{"NN"},
"sucrose":	{"NN"},
"suction":	{"NN","VB","VBP"},
"suctioned":	{"VBD","VBN"},
"suctioning":	{"VBG"},
"suctions":	{"VBZ"},
"suctorial":	{"JJ"},
"sudanese":	{"JJ","NN"},
"sudate":	{"VB","VBP"},
"sudation":	{"NN"},
"sudatorium":	{"NN"},
"sudatory":	{"NN"},
"sudbury":	{"NN"},
"sudden":	{"JJ"},
"suddenly":	{"RB"},
"suddenness":	{"NN"},
"sudoku":	{"NN"},
"sudor":	{"NN"},
"sudorific":	{"JJ"},
"sudra":	{"NN"},
"suds":	{"NNS"},
"sudsing":	{"NN"},
"sudsy":	{"JJ"},
"sue":	{"VB","VBP"},
"sued":	{"VBD","VBN"},
"suede":	{"NN"},
"suer":	{"NN"},
"sues":	{"VBZ"},
"suet":	{"NN"},
"suety":	{"JJ"},
"suey":	{"NN"},
"suez":	{"NN"},
"suffer":	{"VB","VBP"},
"sufferable":	{"JJ"},
"sufferance":	{"NN"},
"suffered":	{"VBD","VBN"},
"sufferer":	{"NN"},
"sufferers":	{"NNS"},
"suffering":	{"VBG","NN"},
"sufferings":	{"NNS"},
"suffers":	{"VBZ"},
"suffice":	{"VB","VBP"},
"sufficed":	{"VBD","VBN"},
"sufficent":	{"JJ"},
"suffices":	{"VBZ"},
"sufficiency":	{"NN"},
"sufficient":	{"JJ"},
"sufficiently":	{"RB"},
"sufficing":	{"VBG"},
"suffix":	{"NN","VB","VBP"},
"suffixal":	{"JJ"},
"suffixation":	{"NN"},
"suffixed":	{"VBD","VBN"},
"suffixes":	{"VBZ","NNS"},
"suffixing":	{"VBG"},
"suffixion":	{"NN"},
"suffocate":	{"VB","VBP"},
"suffocated":	{"VBN","VBD","JJ"},
"suffocates":	{"VBZ"},
"suffocating":	{"VBG","JJ"},
"suffocation":	{"NN"},
"suffocative":	{"JJ"},
"suffragan":	{"JJ","NN"},
"suffragans":	{"NNS"},
"suffrage":	{"NN"},
"suffragette":	{"NN"},
"suffragettes":	{"NNS"},
"suffragism":	{"NN"},
"suffragist":	{"NN"},
"suffragists":	{"NNS"},
"suffrutescent":	{"JJ"},
"suffrutex":	{"NN"},
"suffuse":	{"VB","VBP"},
"suffused":	{"VBD","VBN"},
"suffuses":	{"VBZ"},
"suffusing":	{"VBG"},
"suffusion":	{"NN"},
"suffusive":	{"JJ"},
"sugar":	{"NN","VBP","VB"},
"sugar-beet":	{"NN"},
"sugar-cane":	{"NN"},
"sugar-coated":	{"JJ"},
"sugar-daddies":	{"NNS"},
"sugar-daddy":	{"NN"},
"sugar-growing":	{"JJ","NN"},
"sugar-lump":	{"NN"},
"sugar-lumps":	{"NNS"},
"sugar-maple":	{"NN"},
"sugar-tongs":	{"NNS"},
"sugarberry":	{"NN"},
"sugarcane":	{"NN"},
"sugarcoat":	{"VB","VBP"},
"sugared":	{"JJ","VBD","VBN"},
"sugariness":	{"NN"},
"sugaring":	{"VBG"},
"sugarless":	{"JJ"},
"sugarloaf":	{"NN"},
"sugarplum":	{"NN"},
"sugars":	{"NNS","VBZ"},
"sugary":	{"JJ"},
"suggest":	{"VB","VBP"},
"suggested":	{"VBD","VBN"},
"suggester":	{"NN"},
"suggestibility":	{"NN"},
"suggestible":	{"JJ"},
"suggesting":	{"VBG"},
"suggestion":	{"NN"},
"suggestions":	{"NNS"},
"suggestive":	{"JJ"},
"suggestively":	{"RB"},
"suggestiveness":	{"NN"},
"suggests":	{"VBZ"},
"sugi":	{"NN"},
"suharto":	{"NN"},
"suhthuhn":	{"JJ"},
"suicidal":	{"JJ"},
"suicidally":	{"RB"},
"suicide":	{"NN"},
"suicides":	{"NNS"},
"suidae":	{"NN"},
"suillus":	{"NN"},
"suing":	{"VBG"},
"suisse":	{"NN"},
"suit":	{"NN","VB","VBP"},
"suitability":	{"NN"},
"suitable":	{"JJ"},
"suitableness":	{"NN"},
"suitably":	{"RB"},
"suitcase":	{"NN"},
"suitcases":	{"NNS"},
"suite":	{"NN"},
"suited":	{"VBN","VBD","JJ"},
"suites":	{"NNS"},
"suiting":	{"NN","VBG"},
"suitings":	{"NNS"},
"suitor":	{"NN"},
"suitors":	{"NNS"},
"suits":	{"NNS","VBZ"},
"suject":	{"JJ"},
"sukarno":	{"NN"},
"sukiyaki":	{"NN"},
"suksdorfia":	{"NN"},
"sukur":	{"NN"},
"sula":	{"NN"},
"sulamite":	{"NN"},
"sulamyd":	{"NN"},
"sulawesi":	{"NN"},
"sulcate":	{"JJ"},
"sulcus":	{"NN"},
"sulfa":	{"NN","JJ"},
"sulfacetamide":	{"NN"},
"sulfadiazine":	{"NN"},
"sulfamethazine":	{"NN"},
"sulfamethoxazole":	{"NN"},
"sulfamezathine":	{"NN"},
"sulfanilamide":	{"NN"},
"sulfapyridine":	{"NN"},
"sulfaquinoxaline":	{"NN"},
"sulfate":	{"NN","VB","VBP"},
"sulfated":	{"VBD","VBN"},
"sulfates":	{"NNS","VBZ"},
"sulfating":	{"VBG"},
"sulfide":	{"NN"},
"sulfisoxazole":	{"NN"},
"sulfonamide":	{"NN"},
"sulfonate":	{"NN"},
"sulfonylurea":	{"NN"},
"sulfonylureas":	{"NNS"},
"sulfur":	{"NN","VB","VBP"},
"sulfur-dioxide":	{"NN"},
"sulfured":	{"VBD","VBN"},
"sulfuret":	{"NN","VB","VBP"},
"sulfureted":	{"VBD","VBN"},
"sulfureting":	{"VBG"},
"sulfurets":	{"VBZ"},
"sulfuretted":	{"VBD","VBN"},
"sulfuretting":	{"VBG"},
"sulfuric":	{"JJ"},
"sulfuring":	{"VBG"},
"sulfurization":	{"NN"},
"sulfurize":	{"VB","VBP"},
"sulfurized":	{"VBD","VBN"},
"sulfurizes":	{"VBZ"},
"sulfurizing":	{"VBG"},
"sulfurous":	{"JJ"},
"sulfurs":	{"VBZ"},
"sulidae":	{"NN"},
"sulindac":	{"NN"},
"sulk":	{"VB","VBP","NN"},
"sulked":	{"VBD","VBN"},
"sulkier":	{"JJR"},
"sulkiest":	{"JJS"},
"sulkily":	{"RB"},
"sulkiness":	{"NN"},
"sulking":	{"VBG"},
"sulks":	{"VBZ","NNS"},
"sulky":	{"JJ"},
"sulla":	{"NN"},
"sullen":	{"JJ"},
"sullenly":	{"RB"},
"sullenness":	{"NN"},
"sullied":	{"VBD","VBN"},
"sullies":	{"VBZ"},
"sullivan":	{"NN"},
"sully":	{"VB","VBP"},
"sullying":	{"VBG"},
"sulpha":	{"NN"},
"sulphate":	{"NN","VB","VBP"},
"sulphated":	{"VBD","VBN"},
"sulphates":	{"NNS","VBZ"},
"sulphating":	{"VBG"},
"sulphide":	{"NN"},
"sulphides":	{"NNS"},
"sulphur":	{"NN"},
"sulphured":	{"JJ"},
"sulphuretted":	{"JJ"},
"sulphuric":	{"JJ"},
"sulphurous":	{"JJ"},
"sultan":	{"NN"},
"sultana":	{"NN"},
"sultanas":	{"NNS"},
"sultanate":	{"NN"},
"sultans":	{"NNS"},
"sultrier":	{"JJR"},
"sultriest":	{"JJS"},
"sultrily":	{"RB"},
"sultriness":	{"NN"},
"sultry":	{"JJ"},
"sulzberger":	{"NN"},
"sum":	{"NN","VB","VBP"},
"sumac":	{"NN"},
"sumach":	{"NN"},
"sumatra":	{"NN"},
"sumerology":	{"NN"},
"summaries":	{"NNS"},
"summarily":	{"RB"},
"summarisation":	{"NN"},
"summarise":	{"VB","VBP"},
"summarised":	{"VBD","VBN"},
"summarises":	{"VBZ"},
"summarising":	{"VBG"},
"summarization":	{"NN"},
"summarize":	{"VB","VBP"},
"summarized":	{"VBD","VBN"},
"summarizes":	{"VBZ"},
"summarizing":	{"VBG"},
"summary":	{"NN","JJ"},
"summate":	{"VB","VBP"},
"summated":	{"VBD","VBN"},
"summates":	{"VBZ"},
"summating":	{"VBG"},
"summation":	{"NN"},
"summational":	{"JJ"},
"summations":	{"NNS"},
"summative":	{"JJ"},
"summed":	{"VBD","VBN"},
"summer":	{"NN","VBP","JJ","VB"},
"summer-house":	{"NN"},
"summer-houses":	{"NNS"},
"summer-long":	{"JJ","RB"},
"summer-time":	{"NN"},
"summered":	{"VBD","VBN"},
"summerhouse":	{"NN"},
"summerhouses":	{"NNS"},
"summering":	{"VBG"},
"summers":	{"NNS","VBZ"},
"summersault":	{"NN","VB","VBP"},
"summerset":	{"NN"},
"summertime":	{"NN"},
"summery":	{"JJ"},
"summing":	{"VBG"},
"summing-up":	{"NN"},
"summings-up":	{"NNS"},
"summit":	{"NN"},
"summiteer":	{"NN"},
"summiteers":	{"NNS"},
"summitry":	{"NN"},
"summits":	{"NNS"},
"summon":	{"VB","VBP"},
"summoned":	{"VBD","VBN"},
"summoning":	{"VBG"},
"summons":	{"NNS","VBZ","NN","VB","VBP"},
"summonsed":	{"VBD","VBN"},
"summonses":	{"NNS","VBZ"},
"summonsing":	{"VBG"},
"sumner":	{"NN"},
"sumo":	{"NN"},
"sump":	{"NN"},
"sumps":	{"NNS"},
"sumpsimus":	{"NN"},
"sumpter":	{"NN"},
"sumptuary":	{"JJ"},
"sumptuosity":	{"NN"},
"sumptuous":	{"JJ"},
"sumptuously":	{"RB"},
"sumptuousness":	{"NN"},
"sums":	{"NNS","VBZ"},
"sun":	{"NN","VB","VBP"},
"sun-baked":	{"JJ"},
"sun-blind":	{"NN"},
"sun-drenched":	{"JJ"},
"sun-dried":	{"JJ"},
"sun-glasses":	{"NNS"},
"sun-god":	{"NN"},
"sun-hat":	{"NN"},
"sun-hats":	{"NNS"},
"sun-kissed":	{"JJ"},
"sun-lamp":	{"NN"},
"sun-lamps":	{"NNS"},
"sun-ray":	{"NN"},
"sun-roof":	{"NN"},
"sun-roofs":	{"NNS"},
"sun-suit":	{"NN"},
"sun-tan":	{"NN","JJ"},
"sun-tanned":	{"JJ"},
"sun-tans":	{"NNS"},
"sun-up":	{"NN"},
"sun-worship":	{"NN"},
"sun-worshipper":	{"NN"},
"sun-worshippers":	{"NNS"},
"sunbaked":	{"JJ"},
"sunbathe":	{"VB","VBP"},
"sunbathed":	{"VBD","VBN"},
"sunbather":	{"NN"},
"sunbathers":	{"NNS"},
"sunbathes":	{"VBZ"},
"sunbathing":	{"VBG","NN"},
"sunbeam":	{"NN"},
"sunbeams":	{"NNS"},
"sunbelt":	{"NN"},
"sunberries":	{"NNS"},
"sunberry":	{"NN"},
"sunblind":	{"NN"},
"sunblock":	{"NN"},
"sunblocks":	{"NNS"},
"sunbonnet":	{"NN"},
"sunbonnets":	{"NNS"},
"sunburn":	{"NN","VB","VBP"},
"sunburned":	{"JJ","VBD","VBN"},
"sunburning":	{"VBG"},
"sunburns":	{"NNS","VBZ"},
"sunburnt":	{"JJ","VBD","VBN"},
"sunburst":	{"NN"},
"sunbursts":	{"NNS"},
"sunchoke":	{"NN"},
"sundacarpus":	{"NNS"},
"sundae":	{"NN"},
"sundaes":	{"NNS"},
"sundanese":	{"NN"},
"sunder":	{"VB","VBP","NN"},
"sunderable":	{"JJ"},
"sunderance":	{"NN"},
"sundered":	{"VBD","VBN"},
"sunderer":	{"NN"},
"sundering":	{"VBG"},
"sunderland":	{"NN"},
"sunderment":	{"NN"},
"sunders":	{"VBZ"},
"sundew":	{"NN"},
"sundial":	{"NN"},
"sundials":	{"NNS"},
"sundog":	{"NN"},
"sundown":	{"NN"},
"sundowner":	{"NN"},
"sundowners":	{"NNS"},
"sundowning":	{"NN"},
"sundowns":	{"NNS"},
"sundrenched":	{"JJ"},
"sundress":	{"NN"},
"sundresses":	{"NNS"},
"sundries":	{"NNS"},
"sundrops":	{"NNS"},
"sundry":	{"JJ"},
"sunfish":	{"NN","NNS"},
"sunflower":	{"NN"},
"sunflowers":	{"NNS"},
"sung":	{"VBN"},
"sunglasses":	{"NNS"},
"sunhat":	{"NN"},
"sunhats":	{"NNS"},
"sunk":	{"VBD","VBN","JJ"},
"sunken":	{"JJ"},
"sunlamp":	{"NN"},
"sunlamps":	{"NNS"},
"sunless":	{"JJ"},
"sunlight":	{"NN"},
"sunlit":	{"JJ"},
"sunned":	{"VBD","VBN"},
"sunni":	{"NN"},
"sunnier":	{"JJR"},
"sunniest":	{"JJS"},
"sunnily":	{"RB"},
"sunniness":	{"NN"},
"sunning":	{"VBG"},
"sunnite":	{"NN"},
"sunny":	{"JJ"},
"sunporch":	{"NN"},
"sunray":	{"NN","JJ"},
"sunrise":	{"NN"},
"sunrises":	{"NNS"},
"sunroof":	{"NN"},
"sunroofs":	{"NNS"},
"sunroom":	{"NN"},
"sunrose":	{"NN"},
"suns":	{"NNS","VBZ"},
"sunscreen":	{"NN"},
"sunscreens":	{"NNS"},
"sunset":	{"NN"},
"sunsets":	{"NNS"},
"sunshade":	{"NN"},
"sunshades":	{"NNS"},
"sunshield":	{"NN"},
"sunshine":	{"NN"},
"sunshiny":	{"JJ"},
"sunspot":	{"NN"},
"sunspots":	{"NNS"},
"sunstone":	{"NN"},
"sunstroke":	{"NN"},
"sunstruck":	{"JJ"},
"sunsuit":	{"NN"},
"sunt":	{"FW"},
"suntan":	{"NN","JJ"},
"suntanned":	{"JJ"},
"suntans":	{"NNS"},
"suntrap":	{"NN"},
"suntraps":	{"NNS"},
"sunup":	{"NN"},
"suomi":	{"NN"},
"sup":	{"VB","VBP","NN"},
"super":	{"JJ","NN","RB","VB","VBP"},
"super-Earth":	{"NN"},
"super-Earths":	{"NNS"},
"super-committee":	{"NN"},
"super-committees":	{"NNS"},
"super-duper":	{"JJ"},
"super-ego":	{"NN"},
"super-egos":	{"NNS"},
"super-fast":	{"JJ"},
"super-injunction":	{"NN"},
"super-injunctions":	{"NNS"},
"super-slick":	{"JJ"},
"super-slow":	{"NN","JJ"},
"superable":	{"JJ"},
"superabound":	{"VB","VBP"},
"superabounded":	{"VBD","VBN"},
"superabounding":	{"VBG"},
"superabounds":	{"VBZ"},
"superabsorbent":	{"JJ"},
"superabundance":	{"NN"},
"superabundant":	{"JJ"},
"superabundantly":	{"RB"},
"superachiever":	{"NN"},
"superachievers":	{"NNS"},
"superactive":	{"JJ"},
"superactivities":	{"NNS"},
"superactivity":	{"NN"},
"superacute":	{"JJ"},
"superadd":	{"VB","VBP"},
"superadded":	{"VBD","VBN"},
"superadding":	{"VBG"},
"superaddition":	{"NN"},
"superadditional":	{"JJ"},
"superadditions":	{"NNS"},
"superadds":	{"VBZ"},
"superaerodynamics":	{"NN"},
"superagencies":	{"NNS"},
"superagency":	{"NN"},
"superagent":	{"NN"},
"superagents":	{"NNS"},
"superalloy":	{"NN"},
"superalloys":	{"NNS"},
"superaltar":	{"NN"},
"superaltars":	{"NNS"},
"superaltern":	{"NN"},
"superalterns":	{"NNS"},
"superambitious":	{"JJ"},
"superannuable":	{"JJ"},
"superannuate":	{"VB","VBP"},
"superannuated":	{"JJ","VBD","VBN"},
"superannuates":	{"VBZ"},
"superannuating":	{"VBG"},
"superannuation":	{"NN"},
"superathlete":	{"NN"},
"superathletes":	{"NNS"},
"superatom":	{"NN"},
"superatoms":	{"NNS"},
"superb":	{"JJ"},
"superbad":	{"JJ"},
"superbank":	{"NN"},
"superbanks":	{"NNS"},
"superbazaar":	{"NN"},
"superbazaars":	{"NNS"},
"superbia":	{"NN"},
"superbike":	{"NN"},
"superbikes":	{"NNS"},
"superbitch":	{"NN"},
"superbitches":	{"NNS"},
"superbities":	{"NNS"},
"superbity":	{"NN"},
"superblock":	{"NN"},
"superblocks":	{"NNS"},
"superbly":	{"RB"},
"superbness":	{"NN"},
"superboard":	{"NN"},
"superboards":	{"NNS"},
"superbold":	{"JJ"},
"superbomb":	{"NN"},
"superbomber":	{"NN"},
"superbombers":	{"NNS"},
"superbombs":	{"NNS"},
"superbrain":	{"NN"},
"superbrains":	{"NNS"},
"superbrat":	{"NN"},
"superbrats":	{"NNS"},
"superbright":	{"JJ"},
"superbug":	{"NN"},
"superbugs":	{"NNS"},
"superbureaucrat":	{"NN"},
"superbureaucrats":	{"NNS"},
"supercabinet":	{"NN"},
"supercabinets":	{"NNS"},
"supercalender":	{"NN","VB","VBP"},
"supercalendered":	{"VBD","VBN"},
"supercalendering":	{"VBG"},
"supercalenders":	{"NNS","VBZ"},
"supercalifragilisticexpialidocious":	{"JJ"},
"supercar":	{"NN"},
"supercargo":	{"NN"},
"supercargoes":	{"NNS"},
"supercargoship":	{"NN"},
"supercarrier":	{"NN"},
"supercarriers":	{"NNS"},
"supercars":	{"NNS"},
"supercautious":	{"JJ"},
"supercede":	{"VB","VBP"},
"superceded":	{"VBD","VBN"},
"supercedes":	{"VBZ"},
"superceding":	{"VBG"},
"supercelestial":	{"JJ"},
"supercell":	{"NN"},
"supercenter":	{"NN"},
"supercenters":	{"NNS"},
"supercharge":	{"VB","VBP"},
"supercharged":	{"JJ","VBD","VBN"},
"supercharger":	{"NN"},
"superchargers":	{"NNS"},
"supercharges":	{"VBZ"},
"supercharging":	{"VBG"},
"supercherie":	{"NN"},
"supercheries":	{"NNS"},
"superchic":	{"JJ"},
"superchurch":	{"NN"},
"superchurches":	{"NNS"},
"supercilia":	{"NNS"},
"superciliaries":	{"NNS"},
"superciliary":	{"JJ","NN"},
"supercilious":	{"JJ"},
"superciliously":	{"RB"},
"superciliousness":	{"NN"},
"supercilium":	{"NN"},
"supercities":	{"NNS"},
"supercity":	{"NN"},
"supercivilised":	{"JJ"},
"supercivilized":	{"JJ"},
"superclass":	{"NN","VB","VBP"},
"superclassed":	{"VBD","VBN"},
"superclasses":	{"NNS","VBZ"},
"superclassing":	{"VBG"},
"superclean":	{"JJ"},
"superclub":	{"NN"},
"superclubs":	{"NNS"},
"supercluster":	{"NN"},
"superclusters":	{"NNS"},
"supercoil":	{"NN","VB","VBP"},
"supercoiled":	{"VBD","VBN"},
"supercoiling":	{"VBG"},
"supercoils":	{"NNS","VBZ"},
"supercold":	{"JJ"},
"supercollider":	{"NN"},
"supercolliders":	{"NNS"},
"supercolossal":	{"JJ"},
"supercolumnar":	{"JJ"},
"supercolumniation":	{"NN"},
"supercommittee":	{"NN"},
"supercommittees":	{"NNS"},
"supercomputer":	{"NN"},
"supercomputers":	{"NNS"},
"superconduct":	{"VB","VBP"},
"superconducted":	{"VBD","VBN"},
"superconducting":	{"VBG"},
"superconductivity":	{"NN"},
"superconductor":	{"NN"},
"superconductors":	{"NNS"},
"superconducts":	{"VBZ"},
"superconfidence":	{"NN"},
"superconfident":	{"JJ"},
"supercontinent":	{"NN"},
"supercontinents":	{"NNS"},
"superconvenient":	{"JJ"},
"supercool":	{"VB","VBP"},
"supercooled":	{"VBD","VBN"},
"supercooling":	{"VBG"},
"supercools":	{"VBZ"},
"supercop":	{"NN"},
"supercops":	{"NNS"},
"supercover":	{"NN"},
"supercow":	{"NN"},
"supercows":	{"NNS"},
"supercriminal":	{"NN","JJ"},
"supercriminals":	{"NNS"},
"supercritical":	{"JJ"},
"supercurrent":	{"NN"},
"supercute":	{"JJ"},
"superdaintier":	{"JJR"},
"superdaintiest":	{"JJS"},
"superdainty":	{"JJ"},
"superdelegate":	{"NN"},
"superdelegates":	{"NNS"},
"superdeluxe":	{"JJ"},
"superdense":	{"JJ"},
"superdiplomat":	{"NN"},
"superdiplomats":	{"NNS"},
"superdominant":	{"JJ","NN"},
"superdominants":	{"NNS"},
"supered":	{"VBD","VBN"},
"supereffective":	{"JJ"},
"superefficiency":	{"NN"},
"superefficient":	{"JJ"},
"superego":	{"NN"},
"superegoist":	{"NN","JJ"},
"superegoists":	{"NNS"},
"superegos":	{"NNS"},
"superelastic":	{"JJ"},
"superelevate":	{"VB","VBP"},
"superelevated":	{"VBD","VBN","JJ"},
"superelevates":	{"VBZ"},
"superelevating":	{"VBG"},
"superelevation":	{"NN"},
"superelite":	{"JJ"},
"supereminence":	{"NN"},
"supereminent":	{"JJ"},
"supereminently":	{"RB"},
"superenrollment":	{"NN"},
"supererogant":	{"JJ"},
"supererogate":	{"VB","VBP"},
"supererogated":	{"VBD","VBN"},
"supererogates":	{"VBZ"},
"supererogating":	{"VBG"},
"supererogation":	{"NN"},
"supererogative":	{"JJ"},
"supererogatory":	{"JJ"},
"superessential":	{"JJ"},
"superette":	{"NN"},
"superettes":	{"NNS"},
"superevident":	{"JJ"},
"superexalt":	{"VB","VBP"},
"superexaltation":	{"NN"},
"superexalted":	{"VBD","VBN"},
"superexalting":	{"VBG"},
"superexalts":	{"VBZ"},
"superexcellence":	{"NN"},
"superexcellent":	{"JJ"},
"superexpensive":	{"JJ"},
"superexpress":	{"NN","JJ"},
"superexpresses":	{"NNS"},
"superfamilies":	{"NNS"},
"superfamily":	{"NN"},
"superfan":	{"NN"},
"superfans":	{"NNS"},
"superfarm":	{"NN"},
"superfarms":	{"NNS"},
"superfast":	{"JJ"},
"superfatted":	{"JJ"},
"superfecta":	{"NN"},
"superfecundation":	{"NN"},
"superfemale":	{"NN"},
"superfemales":	{"NNS"},
"superfetate":	{"VB","VBP"},
"superfetated":	{"VBD","VBN"},
"superfetates":	{"VBZ"},
"superfetating":	{"VBG"},
"superfetation":	{"NN"},
"superfetations":	{"NNS"},
"superficial":	{"JJ"},
"superficialise":	{"VB","VBP"},
"superficialised":	{"VBD","VBN"},
"superficialises":	{"VBZ"},
"superficialising":	{"VBG"},
"superficialities":	{"NNS"},
"superficiality":	{"NN"},
"superficialize":	{"VB","VBP"},
"superficialized":	{"VBD","VBN"},
"superficializes":	{"VBZ"},
"superficializing":	{"VBG"},
"superficially":	{"RB"},
"superficialness":	{"NN"},
"superficies":	{"NN","NNS"},
"superfine":	{"JJ"},
"superfineness":	{"NN"},
"superfirm":	{"NN","JJ"},
"superfirms":	{"NNS"},
"superfit":	{"JJ"},
"superfix":	{"NN","VB","VBP"},
"superfixed":	{"VBD","VBN"},
"superfixes":	{"NNS","VBZ"},
"superfixing":	{"VBG"},
"superflack":	{"NN"},
"superflacks":	{"NNS"},
"superfluid":	{"NN","JJ"},
"superfluidities":	{"NNS"},
"superfluidity":	{"NN"},
"superfluids":	{"NNS"},
"superfluities":	{"NNS"},
"superfluity":	{"NN"},
"superfluous":	{"JJ"},
"superfluously":	{"RB"},
"superflux":	{"NN"},
"superfluxes":	{"NNS"},
"superfoetation":	{"NN"},
"superfoetations":	{"NNS"},
"superfood":	{"NN"},
"superfoods":	{"NNS"},
"superfrontal":	{"NN"},
"superfrontals":	{"NNS"},
"superfund":	{"NN"},
"superfunds":	{"NNS"},
"superfuse":	{"VB","VBP"},
"superfused":	{"VBD","VBN"},
"superfuses":	{"VBZ"},
"superfusing":	{"VBG"},
"superfusion":	{"NN"},
"superfusions":	{"NNS"},
"supergene":	{"NN","JJ"},
"supergenes":	{"NNS"},
"supergiant":	{"NN"},
"supergiants":	{"NNS"},
"superglacial":	{"JJ"},
"superglue":	{"NN","VB","VBP"},
"superglued":	{"VBD","VBN"},
"superglues":	{"NNS","VBZ"},
"supergluing":	{"VBG"},
"supergood":	{"JJ"},
"supergovernment":	{"NN"},
"supergovernments":	{"NNS"},
"supergraphics":	{"NN"},
"supergrass":	{"NN"},
"supergrasses":	{"NNS"},
"supergravities":	{"NNS"},
"supergravity":	{"NN"},
"supergroup":	{"NN"},
"supergroups":	{"NNS"},
"supergrowth":	{"NN"},
"supergrowths":	{"NNS"},
"supergun":	{"NN"},
"superguns":	{"NNS"},
"superharden":	{"VB","VBP"},
"superhardened":	{"VBD","VBN"},
"superhardening":	{"VBG"},
"superhardens":	{"VBZ"},
"superheat":	{"NN","VB","VBP"},
"superheated":	{"VBD","VBN","JJ"},
"superheater":	{"NN"},
"superheaters":	{"NNS"},
"superheating":	{"VBG","NN"},
"superheats":	{"VBZ"},
"superheavy":	{"JJ"},
"superheavyweight":	{"JJ","NN"},
"superheavyweights":	{"NNS"},
"superhelical":	{"JJ"},
"superhelically":	{"RB"},
"superhelices":	{"NNS"},
"superhelix":	{"NN"},
"superhelixes":	{"NNS"},
"superhero":	{"NN"},
"superheroes":	{"NNS"},
"superheroic":	{"JJ"},
"superheroine":	{"NN"},
"superheroines":	{"NNS"},
"superhet":	{"NN"},
"superheterodyne":	{"NN","JJ"},
"superhets":	{"NNS"},
"superhigh":	{"JJ"},
"superhighway":	{"NN"},
"superhighways":	{"NNS"},
"superhit":	{"NN"},
"superhits":	{"NNS"},
"superhive":	{"NN"},
"superhives":	{"NNS"},
"superhot":	{"JJ"},
"superhuman":	{"JJ"},
"superhumanise":	{"VB","VBP"},
"superhumanised":	{"VBD","VBN"},
"superhumanises":	{"VBZ"},
"superhumanising":	{"VBG"},
"superhumanity":	{"NN"},
"superhumanize":	{"VB","VBP"},
"superhumanized":	{"VBD","VBN"},
"superhumanizes":	{"VBZ"},
"superhumanizing":	{"VBG"},
"superhumanly":	{"RB"},
"superhumanness":	{"NN"},
"superhumeral":	{"NN"},
"superhumerals":	{"NNS"},
"superhype":	{"NN"},
"superimportant":	{"JJ"},
"superimposable":	{"JJ"},
"superimpose":	{"VB","VBP"},
"superimposed":	{"VBD","VBN","JJ"},
"superimposes":	{"VBZ"},
"superimposing":	{"VBG"},
"superimposition":	{"NN"},
"superincumbent":	{"JJ"},
"superindividual":	{"JJ"},
"superinduce":	{"VB","VBP"},
"superinduced":	{"VBD","VBN"},
"superinduces":	{"VBZ"},
"superinducing":	{"VBG"},
"superinduction":	{"NN"},
"superinfect":	{"VB","VBP"},
"superinfected":	{"VBD","VBN"},
"superinfecting":	{"VBG"},
"superinfection":	{"NN"},
"superinfections":	{"NNS"},
"superinfects":	{"VBZ"},
"supering":	{"VBG"},
"superinsulated":	{"JJ"},
"superintend":	{"VB","VBP"},
"superintended":	{"VBD","VBN"},
"superintendence":	{"NN"},
"superintendencies":	{"NNS"},
"superintendency":	{"NN"},
"superintendent":	{"NN"},
"superintendents":	{"NNS"},
"superintending":	{"VBG"},
"superintends":	{"VBZ"},
"superintensity":	{"NN"},
"superior":	{"JJ","NN"},
"superiorities":	{"NNS"},
"superiority":	{"NN"},
"superiors":	{"NNS"},
"superiorship":	{"NN"},
"superiorships":	{"NNS"},
"superjacent":	{"JJ"},
"superjet":	{"NN"},
"superjets":	{"NNS"},
"superjock":	{"NN"},
"superjocks":	{"NNS"},
"superjumbo":	{"NN"},
"superjumbos":	{"NNS"},
"superkingdom":	{"NN"},
"superkingdoms":	{"NNS"},
"superlain":	{"VBN"},
"superlarge":	{"JJ"},
"superlative":	{"JJ","NN"},
"superlatively":	{"RB"},
"superlatives":	{"NNS"},
"superlawyer":	{"NN"},
"superlawyers":	{"NNS"},
"superlay":	{"VBD"},
"superlie":	{"VB","VBP"},
"superlies":	{"VBZ"},
"superlight":	{"JJ"},
"superliner":	{"NN"},
"superliners":	{"NNS"},
"superload":	{"NN"},
"superloads":	{"NNS"},
"superlobbyist":	{"NN"},
"superlobbyists":	{"NNS"},
"superlong":	{"JJ"},
"superloo":	{"NN"},
"superloos":	{"NNS"},
"superloyalist":	{"NN"},
"superloyalists":	{"NNS"},
"superluminal":	{"JJ"},
"superlunar":	{"JJ"},
"superlunary":	{"JJ","NN"},
"superluxuries":	{"NNS"},
"superluxurious":	{"JJ"},
"superlying":	{"VBG"},
"supermachine":	{"NN"},
"supermachines":	{"NNS"},
"supermacho":	{"JJ"},
"supermajorities":	{"NNS"},
"supermajority":	{"NN"},
"supermale":	{"NN"},
"supermales":	{"NNS"},
"superman":	{"NN"},
"supermarket":	{"NN"},
"supermarketeer":	{"NN"},
"supermarketer":	{"NN"},
"supermarkets":	{"NNS"},
"supermart":	{"NN"},
"supermarts":	{"NNS"},
"supermasculine":	{"JJ"},
"supermassive":	{"JJ"},
"supermax":	{"NN","JJ"},
"supermaxes":	{"NNS"},
"supermembrane":	{"NN"},
"supermembranes":	{"NNS"},
"supermen":	{"NNS"},
"supermex":	{"NN"},
"supermicro":	{"NN"},
"supermicrobe":	{"NN"},
"supermicrobes":	{"NNS"},
"supermicros":	{"NNS"},
"supermilitant":	{"NN"},
"supermilitants":	{"NNS"},
"supermind":	{"NN"},
"superminds":	{"NNS"},
"supermini":	{"NN"},
"superminis":	{"NNS"},
"superminister":	{"NN"},
"superministers":	{"NNS"},
"supermodel":	{"NN"},
"supermodels":	{"NNS"},
"supermodern":	{"JJ"},
"supermolecule":	{"NN"},
"supermom":	{"NN"},
"supermoms":	{"NNS"},
"supermoto":	{"NN"},
"supermotos":	{"NNS"},
"supermundane":	{"JJ"},
"supernacular":	{"JJ"},
"supernal":	{"JJ"},
"supernannies":	{"NNS"},
"supernanny":	{"NN"},
"supernatant":	{"JJ","NN"},
"supernatants":	{"NNS"},
"supernate":	{"NN"},
"supernates":	{"NNS"},
"supernation":	{"NN"},
"supernational":	{"JJ"},
"supernationalism":	{"NN"},
"supernationalist":	{"NN"},
"supernationalists":	{"NNS"},
"supernationally":	{"RB"},
"supernatural":	{"JJ","NN"},
"supernaturalise":	{"VB","VBP"},
"supernaturalised":	{"VBD","VBN"},
"supernaturalises":	{"VBZ"},
"supernaturalising":	{"VBG"},
"supernaturalism":	{"NN"},
"supernaturalist":	{"JJ"},
"supernaturalistic":	{"JJ"},
"supernaturalize":	{"VB","VBP"},
"supernaturalized":	{"VBD","VBN"},
"supernaturalizes":	{"VBZ"},
"supernaturalizing":	{"VBG"},
"supernaturally":	{"RB"},
"supernaturalness":	{"NN"},
"supernaturals":	{"NNS"},
"supernature":	{"NN"},
"supernatures":	{"NNS"},
"supernormal":	{"JJ"},
"supernova":	{"NN"},
"supernovae":	{"NNS"},
"supernovas":	{"NNS"},
"supernumeraries":	{"NNS"},
"supernumerary":	{"JJ","NN"},
"supernurse":	{"NN"},
"supernurses":	{"NNS"},
"supernutrient":	{"NN"},
"supernutrients":	{"NNS"},
"supernutrition":	{"NN"},
"superoctave":	{"NN"},
"superoctaves":	{"NNS"},
"superorder":	{"NN"},
"superorders":	{"NNS"},
"superordinal":	{"JJ"},
"superordinary":	{"JJ"},
"superordinate":	{"JJ","NN","VB","VBP"},
"superordinated":	{"VBD","VBN"},
"superordinates":	{"NNS","VBZ"},
"superordinating":	{"VBG"},
"superordination":	{"NN"},
"superorganic":	{"JJ"},
"superorganicism":	{"NN"},
"superorganicist":	{"NN"},
"superorganicists":	{"NNS"},
"superorgasm":	{"NN"},
"superorgasms":	{"NNS"},
"superovulate":	{"VB","VBP"},
"superovulated":	{"VBD","VBN"},
"superovulates":	{"VBZ"},
"superovulating":	{"VBG"},
"superovulation":	{"NN"},
"superoxide":	{"NN"},
"superparasite":	{"NN"},
"superparasitism":	{"NN"},
"superparticle":	{"NN"},
"superparticles":	{"NNS"},
"superpatriot":	{"NN"},
"superpatriotic":	{"JJ"},
"superpatriotism":	{"NN"},
"superpeople":	{"NNS"},
"superperson":	{"NN"},
"superpersonal":	{"JJ"},
"superpersons":	{"NNS"},
"superphenomena":	{"NNS"},
"superphenomenon":	{"NN"},
"superphone":	{"NN"},
"superphones":	{"NNS"},
"superphosphate":	{"NN"},
"superphosphates":	{"NNS"},
"superphyla":	{"NNS"},
"superphylum":	{"NN"},
"superphysical":	{"JJ"},
"superpimp":	{"NN"},
"superpimps":	{"NNS"},
"superplane":	{"NN"},
"superplanes":	{"NNS"},
"superplastic":	{"JJ","NN"},
"superplasticities":	{"NNS"},
"superplasticity":	{"NN"},
"superplastics":	{"NNS"},
"superplayer":	{"NN"},
"superplayers":	{"NNS"},
"superpolite":	{"JJ"},
"superpolymer":	{"NN"},
"superpolymers":	{"NNS"},
"superport":	{"NN"},
"superports":	{"NNS"},
"superposable":	{"JJ"},
"superpose":	{"VB","VBP"},
"superposed":	{"VBD","VBN","JJ"},
"superposes":	{"VBZ"},
"superposing":	{"VBG"},
"superposition":	{"NN"},
"superpower":	{"NN"},
"superpowerful":	{"JJ"},
"superpowers":	{"NNS"},
"superpredator":	{"NN"},
"superpredators":	{"NNS"},
"superpremium":	{"JJ","NN"},
"superpremiums":	{"NNS"},
"superpro":	{"NN"},
"superprofit":	{"NN"},
"superprofits":	{"NNS"},
"superpros":	{"NNS"},
"superquality":	{"JJ"},
"superrace":	{"NN"},
"superraces":	{"NNS"},
"superreal":	{"JJ","NN"},
"superrealism":	{"NN"},
"superrealist":	{"NN","JJ"},
"superrealists":	{"NNS"},
"superreals":	{"NNS"},
"superrefine":	{"VB","VBP"},
"superrefined":	{"VBD","VBN"},
"superrefines":	{"VBZ"},
"superrefining":	{"VBG"},
"superregional":	{"JJ"},
"superrich":	{"JJ","NNS"},
"superroad":	{"NN"},
"superroads":	{"NNS"},
"superromantic":	{"JJ"},
"supers":	{"NNS","VBZ"},
"supersafe":	{"JJ"},
"supersafety":	{"NN"},
"supersale":	{"NN"},
"supersales":	{"NNS"},
"supersalesman":	{"NN"},
"supersalesmen":	{"NNS"},
"supersalt":	{"NN"},
"supersalts":	{"NNS"},
"supersaturate":	{"VB","VBP"},
"supersaturated":	{"VBD","VBN","JJ"},
"supersaturates":	{"VBZ"},
"supersaturating":	{"VBG"},
"supersaturation":	{"NN"},
"supersaur":	{"NN"},
"supersaver":	{"NN"},
"supersavers":	{"NNS"},
"superscalar":	{"JJ","NN"},
"superscalars":	{"NNS"},
"superscale":	{"JJ"},
"superschool":	{"NN"},
"superschools":	{"NNS"},
"superscout":	{"NN"},
"superscouts":	{"NNS"},
"superscreen":	{"NN"},
"superscreens":	{"NNS"},
"superscribe":	{"VB","VBP"},
"superscribed":	{"VBD","VBN"},
"superscribes":	{"VBZ"},
"superscribing":	{"VBG"},
"superscript":	{"JJ","NN"},
"superscription":	{"NN"},
"superscriptions":	{"NNS"},
"superscripts":	{"NNS"},
"supersecrecy":	{"NN"},
"supersecret":	{"JJ"},
"supersede":	{"VB","VBP"},
"supersedeas":	{"NN"},
"supersedeases":	{"NNS"},
"superseded":	{"VBD","VBN"},
"supersedere":	{"NN"},
"supersederes":	{"NNS"},
"supersedes":	{"VBZ"},
"superseding":	{"VBG"},
"supersedure":	{"NN"},
"supersedures":	{"NNS"},
"supersell":	{"VB","VBP"},
"superseller":	{"NN"},
"supersellers":	{"NNS"},
"superselling":	{"VBG"},
"supersells":	{"VBZ"},
"supersensible":	{"JJ"},
"supersensibly":	{"RB"},
"supersensitised":	{"JJ"},
"supersensitive":	{"JJ"},
"supersensitivity":	{"NN"},
"supersensitized":	{"JJ"},
"supersensory":	{"JJ"},
"supersensual":	{"JJ"},
"supersession":	{"NN"},
"supersessions":	{"NNS"},
"supersessive":	{"JJ"},
"supersex":	{"NN"},
"supersexes":	{"NNS"},
"supersexuality":	{"NN"},
"supersharp":	{"JJ"},
"supershow":	{"NN"},
"supershows":	{"NNS"},
"supersinger":	{"NN"},
"supersingers":	{"NNS"},
"supersize":	{"JJ","VB","VBP"},
"supersized":	{"VBD","VBN","JJ"},
"supersizes":	{"VBZ"},
"supersizing":	{"VBG"},
"superslasher":	{"NN"},
"supersleuth":	{"NN"},
"supersleuths":	{"NNS"},
"superslow":	{"NN","JJ"},
"supersmart":	{"JJ"},
"supersmooth":	{"JJ"},
"supersoft":	{"JJ"},
"supersold":	{"VBD","VBN"},
"supersonic":	{"JJ"},
"supersonically":	{"RB"},
"supersonics":	{"NN"},
"supersound":	{"NN"},
"supersounds":	{"NNS"},
"superspecial":	{"JJ","NN"},
"superspecialist":	{"NN"},
"superspecialists":	{"NNS"},
"superspecials":	{"NNS"},
"superspecies":	{"NNS"},
"superspectacle":	{"NN"},
"superspectacles":	{"NNS"},
"superspeed":	{"JJ","NN"},
"superspeeds":	{"NNS"},
"superspies":	{"NNS"},
"superspy":	{"NN"},
"superstar":	{"NN"},
"superstars":	{"NNS"},
"superstate":	{"NN"},
"superstates":	{"NNS"},
"superstimulate":	{"VB","VBP"},
"superstimulated":	{"VBD","VBN"},
"superstimulates":	{"VBZ"},
"superstimulating":	{"VBG"},
"superstition":	{"NN"},
"superstitions":	{"NNS"},
"superstitious":	{"JJ"},
"superstitiously":	{"RB"},
"superstitiousness":	{"NN"},
"superstock":	{"NN"},
"superstocks":	{"NNS"},
"superstore":	{"NN"},
"superstores":	{"NNS"},
"superstorm":	{"NN"},
"superstorms":	{"NNS"},
"superstrata":	{"NNS"},
"superstrate":	{"NN","VB","VBP"},
"superstrated":	{"VBD","VBN"},
"superstrates":	{"NNS","VBZ"},
"superstrating":	{"VBG"},
"superstratum":	{"NN"},
"superstratums":	{"NNS"},
"superstrength":	{"NN"},
"superstrengths":	{"NNS"},
"superstrike":	{"NN"},
"superstring":	{"NN"},
"superstrings":	{"NNS"},
"superstrong":	{"JJ"},
"superstruct":	{"VB","VBP"},
"superstructed":	{"VBD","VBN"},
"superstructing":	{"VBG"},
"superstruction":	{"NN"},
"superstructions":	{"NNS"},
"superstructive":	{"JJ"},
"superstructs":	{"VBZ"},
"superstructural":	{"JJ"},
"superstructure":	{"NN"},
"superstructures":	{"NNS"},
"superstud":	{"NN"},
"superstuds":	{"NNS"},
"supersubtle":	{"JJ"},
"supersubtlety":	{"NN"},
"supersurgeon":	{"NN"},
"supersurgeons":	{"NNS"},
"supersweet":	{"JJ"},
"supersymmetric":	{"JJ"},
"supersymmetrically":	{"RB"},
"supersymmetry":	{"NN"},
"supersystem":	{"NN"},
"supersystems":	{"NNS"},
"supertall":	{"JJ","NN"},
"supertalls":	{"NNS"},
"supertanker":	{"NN"},
"supertankers":	{"NNS"},
"supertax":	{"NN"},
"superteacher":	{"NN"},
"superteachers":	{"NNS"},
"superterranean":	{"JJ"},
"superterrific":	{"JJ"},
"superthick":	{"JJ"},
"superthin":	{"JJ"},
"superthriller":	{"NN"},
"superthrillers":	{"NNS"},
"supertight":	{"JJ"},
"supertitle":	{"NN"},
"supertitles":	{"NNS"},
"supertonic":	{"NN"},
"supertram":	{"NN"},
"supertruck":	{"NN"},
"supertrucks":	{"NNS"},
"supertwist":	{"NN"},
"supertwister":	{"NN"},
"supertwisters":	{"NNS"},
"supertwists":	{"NNS"},
"supervene":	{"VB","VBP"},
"supervened":	{"VBN","VBD"},
"supervenes":	{"VBZ"},
"supervenient":	{"JJ"},
"supervening":	{"VBG"},
"supervention":	{"NN"},
"supervillain":	{"NN"},
"supervillains":	{"NNS"},
"supervirile":	{"JJ"},
"supervirtuosi":	{"NNS"},
"supervirtuoso":	{"NN"},
"supervirtuosos":	{"NNS"},
"supervirulent":	{"JJ"},
"supervisal":	{"JJ"},
"supervise":	{"VB","VBP"},
"supervised":	{"VBD","VBN"},
"supervisee":	{"NN"},
"supervisees":	{"NNS"},
"supervises":	{"VBZ"},
"supervising":	{"VBG"},
"supervision":	{"NN"},
"supervisions":	{"NNS"},
"supervisor":	{"NN"},
"supervisors":	{"NNS"},
"supervisory":	{"JJ"},
"supervolute":	{"JJ"},
"supervote":	{"NN"},
"supervotes":	{"NNS"},
"supervoting":	{"JJ"},
"superwave":	{"NN"},
"superwaves":	{"NNS"},
"superweapon":	{"NN"},
"superweapons":	{"NNS"},
"superweed":	{"NN"},
"superweeds":	{"NNS"},
"superwide":	{"JJ","NN"},
"superwides":	{"NNS"},
"superwife":	{"NN"},
"superwives":	{"NNS"},
"superwoman":	{"NN"},
"superwomen":	{"NNS"},
"supinate":	{"VB","VBP"},
"supination":	{"NN"},
"supinator":	{"NN"},
"supine":	{"JJ","RB"},
"supinely":	{"RB"},
"supped":	{"VBD","VBN"},
"supper":	{"NN"},
"supper-time":	{"NN"},
"supperless":	{"JJ"},
"suppers":	{"NNS"},
"suppertime":	{"NN"},
"supping":	{"VBG"},
"supplant":	{"VB","VBP"},
"supplanted":	{"VBD","VBN"},
"supplanter":	{"NN"},
"supplanting":	{"VBG"},
"supplants":	{"VBZ"},
"supple":	{"JJ"},
"supplejack":	{"NN"},
"supplely":	{"RB"},
"supplement":	{"NN","VB","VBP"},
"supplemental":	{"JJ"},
"supplementary":	{"JJ"},
"supplementation":	{"NN"},
"supplemented":	{"VBD","VBN"},
"supplementing":	{"VBG"},
"supplements":	{"NNS","VBZ"},
"suppleness":	{"NN"},
"suppler":	{"JJR"},
"supplest":	{"JJS"},
"suppliant":	{"NN","JJ"},
"supplicant":	{"NN"},
"supplicants":	{"NNS"},
"supplicate":	{"VB","VBP"},
"supplicated":	{"VBD","VBN"},
"supplicates":	{"VBZ"},
"supplicating":	{"VBG"},
"supplication":	{"NN"},
"supplications":	{"NNS"},
"supplicatory":	{"JJ"},
"supplied":	{"JJ","VBD","VBN"},
"supplier":	{"NN"},
"suppliers":	{"NNS"},
"supplies":	{"NNS","VBZ"},
"supply":	{"NN","VB","VBP"},
"supply-and-demand":	{"NN"},
"supplying":	{"VBG"},
"support":	{"NN","VB","VBP"},
"supportable":	{"JJ"},
"supported":	{"VBN","VBD"},
"supporter":	{"NN"},
"supporters":	{"NNS"},
"supporting":	{"VBG","JJ"},
"supportive":	{"JJ"},
"supports":	{"VBZ","NNS"},
"supposable":	{"JJ"},
"supposal":	{"NN"},
"suppose":	{"VB","VBP"},
"supposed":	{"VBN","VBD","JJ"},
"supposedly":	{"RB"},
"supposes":	{"VBZ"},
"supposing":	{"VBG","IN","CC"},
"supposition":	{"NN"},
"suppositional":	{"JJ"},
"suppositions":	{"NNS"},
"suppositious":	{"JJ"},
"suppositiously":	{"RB"},
"suppositiousness":	{"NN"},
"supposititious":	{"JJ"},
"suppositories":	{"NNS"},
"suppository":	{"NN"},
"suppress":	{"VB","VBP"},
"suppressant":	{"NN"},
"suppressants":	{"NNS"},
"suppressed":	{"VBD","VBN","JJ"},
"suppresses":	{"VBZ"},
"suppressing":	{"VBG"},
"suppression":	{"NN"},
"suppressive":	{"JJ"},
"suppressor":	{"NN"},
"suppressors":	{"NNS"},
"suppurate":	{"VB","VBP"},
"suppurated":	{"VBD","VBN"},
"suppurates":	{"VBZ"},
"suppurating":	{"VBG"},
"suppuration":	{"NN"},
"suppurative":	{"JJ","NN"},
"supra":	{"RB"},
"supra-personal":	{"JJ"},
"suprainfection":	{"NN"},
"supranational":	{"JJ"},
"supranationalism":	{"NN"},
"supranormal":	{"JJ"},
"supraocular":	{"JJ"},
"supraorbital":	{"JJ"},
"suprarenalectomy":	{"NN"},
"suprasegmental":	{"JJ"},
"supraventricular":	{"JJ"},
"supremacism":	{"NN"},
"supremacist":	{"NN"},
"supremacists":	{"NNS"},
"supremacy":	{"NN"},
"suprematism":	{"NN"},
"suprematist":	{"NN"},
"supreme":	{"JJ"},
"supremely":	{"RB"},
"supremo":	{"NN"},
"supremos":	{"NNS"},
"sups":	{"VBZ","NNS"},
"sura":	{"NN"},
"surbase":	{"NN"},
"surcease":	{"NN","VB","VBP"},
"surcharge":	{"NN","VB","VBP"},
"surcharged":	{"VBD","VBN"},
"surcharges":	{"VBZ","NNS"},
"surcharging":	{"VBG"},
"surcoat":	{"NN"},
"surd":	{"NN"},
"sure":	{"JJ","RB"},
"sure-fire":	{"JJ"},
"sure-footed":	{"JJ"},
"sure-footedly":	{"RB"},
"sure-footedness":	{"NN"},
"sure-handed":	{"JJ"},
"surefire":	{"JJ"},
"surefooted":	{"JJ"},
"surefootedly":	{"RB"},
"surefootedness":	{"NN"},
"surely":	{"RB"},
"sureness":	{"NN"},
"surer":	{"JJR"},
"surest":	{"JJS"},
"sureties":	{"NNS"},
"surety":	{"NN"},
"surf":	{"NN","VB","VBP"},
"surface":	{"NN","VB","VBP","JJ"},
"surface-active":	{"JJ"},
"surface-to-air":	{"JJ"},
"surfaced":	{"VBD","VBN"},
"surfaceness":	{"NN"},
"surfaces":	{"NNS","VBZ"},
"surfacing":	{"VBG"},
"surfactant":	{"NN","JJ"},
"surfactants":	{"NNS"},
"surfbird":	{"NN"},
"surfboard":	{"NN"},
"surfboarder":	{"NN"},
"surfboarders":	{"NNS"},
"surfboarding":	{"NN"},
"surfboards":	{"NNS"},
"surfboat":	{"NN"},
"surfed":	{"VBD","VBN"},
"surfeit":	{"NN","VB","VBP"},
"surfeited":	{"VBD","VBN"},
"surfeiting":	{"VBG"},
"surfeits":	{"VBZ"},
"surfer":	{"NN"},
"surfers":	{"NNS"},
"surffish":	{"NN"},
"surficial":	{"JJ"},
"surfing":	{"NN","VBG"},
"surfperch":	{"NN"},
"surfriding":	{"NN"},
"surfs":	{"VBZ"},
"surge":	{"VB","VBP","NN"},
"surged":	{"VBD","VBN"},
"surgeon":	{"NN"},
"surgeonfish":	{"NN"},
"surgeons":	{"NNS"},
"surgeries":	{"NNS"},
"surgery":	{"NN"},
"surges":	{"NNS","VBZ"},
"surgical":	{"JJ"},
"surgically":	{"RB"},
"surgicenter":	{"NN"},
"surgicenters":	{"NNS"},
"surging":	{"VBG"},
"suricata":	{"NN"},
"suricate":	{"NN"},
"surimi":	{"NN"},
"surlier":	{"JJR"},
"surliest":	{"JJS"},
"surlily":	{"RB"},
"surliness":	{"NN"},
"surly":	{"JJ"},
"surmisable":	{"JJ"},
"surmisal":	{"NN"},
"surmise":	{"VB","VBP","NN"},
"surmised":	{"VBD","VBN"},
"surmises":	{"VBZ","NNS"},
"surmising":	{"VBG"},
"surmontil":	{"NN"},
"surmount":	{"VB","VBP"},
"surmountable":	{"JJ"},
"surmounted":	{"VBD","VBN"},
"surmounter":	{"NN"},
"surmounting":	{"VBG"},
"surmounts":	{"VBZ"},
"surmullet":	{"NN"},
"surname":	{"NN","VB","VBP"},
"surnamed":	{"VBD","VBN"},
"surnames":	{"NNS","VBZ"},
"surnaming":	{"VBG"},
"surnia":	{"NN"},
"surpass":	{"VB","VBP"},
"surpassed":	{"VBD","VBN"},
"surpasses":	{"VBZ"},
"surpassing":	{"JJ","VBG"},
"surpassingly":	{"RB"},
"surplice":	{"NN"},
"surpliced":	{"JJ"},
"surplices":	{"NNS"},
"surplus":	{"NN","JJ"},
"surplusage":	{"NN"},
"surpluses":	{"NNS"},
"surprint":	{"NN"},
"surprisal":	{"NN"},
"surprise":	{"NN","VB","VBP","JJ"},
"surprised":	{"VBN","VBD","JJ"},
"surprisedly":	{"RB"},
"surpriser":	{"NN"},
"surprises":	{"NNS","VBZ"},
"surprising":	{"JJ","VBG"},
"surprisingly":	{"RB"},
"surprisingness":	{"NN"},
"surreal":	{"JJ"},
"surrealism":	{"NN"},
"surrealist":	{"JJ","NN"},
"surrealistic":	{"JJ"},
"surrealistically":	{"RB"},
"surrealists":	{"NNS"},
"surrealities":	{"NNS"},
"surreality":	{"NN"},
"surrebuttal":	{"NN"},
"surrebutter":	{"NN"},
"surrejoinder":	{"NN"},
"surrender":	{"VB","VBP","NN"},
"surrendered":	{"VBD","VBN"},
"surrenderer":	{"NN"},
"surrendering":	{"VBG"},
"surrenders":	{"VBZ","NNS"},
"surreptitious":	{"JJ"},
"surreptitiously":	{"RB"},
"surreptitiousness":	{"NN"},
"surrey":	{"NN"},
"surreys":	{"NNS"},
"surrogacy":	{"NN"},
"surrogate":	{"NN","JJ","VB","VBP"},
"surrogated":	{"VBD","VBN"},
"surrogates":	{"NNS","VBZ"},
"surrogating":	{"VBG"},
"surround":	{"VB","NN","VBP"},
"surrounded":	{"VBN","VBD"},
"surrounding":	{"VBG","JJ"},
"surroundings":	{"NNS"},
"surrounds":	{"VBZ","NNS"},
"surtax":	{"NN"},
"surtitle":	{"NN"},
"surtitles":	{"NNS"},
"surtout":	{"NN"},
"surveil":	{"VB","VBP"},
"surveillance":	{"NN"},
"surveille":	{"VB","VBP"},
"surveilled":	{"VBD","VBN"},
"surveilling":	{"VBG"},
"surveils":	{"VBZ"},
"survey":	{"NN","VB","VBP"},
"surveyed":	{"VBN","VBD"},
"surveying":	{"VBG","NN"},
"surveyor":	{"NN"},
"surveyors":	{"NNS"},
"surveys":	{"VBZ","NNS"},
"survivability":	{"NN"},
"survivable":	{"JJ"},
"survival":	{"NN"},
"survivalist":	{"NN"},
"survivalists":	{"NNS"},
"survivals":	{"NNS"},
"survive":	{"VB","VBP"},
"survived":	{"VBN","VBD"},
"survives":	{"VBZ"},
"surviving":	{"VBG"},
"survivor":	{"NN"},
"survivors":	{"NNS"},
"surya":	{"NN"},
"sus":	{"VB","VBP","NN","JJ"},
"susa":	{"NN"},
"susah":	{"NN"},
"susanna":	{"NN"},
"susceptibilities":	{"NNS"},
"susceptibility":	{"NN"},
"susceptible":	{"JJ"},
"susceptibleness":	{"NN"},
"susceptor":	{"NN"},
"susceptors":	{"NNS"},
"sushi":	{"NN"},
"susian":	{"NN"},
"susiana":	{"NN"},
"suslik":	{"NN"},
"suspect":	{"VB","VBP","NN","JJ"},
"suspected":	{"VBN","VBD","JJ"},
"suspecting":	{"VBG"},
"suspects":	{"NNS","VBZ"},
"suspend":	{"VB","VBP"},
"suspended":	{"VBN","VBD"},
"suspender":	{"NN"},
"suspenders":	{"NNS"},
"suspending":	{"VBG"},
"suspends":	{"VBZ"},
"suspense":	{"NN"},
"suspenseful":	{"JJ"},
"suspension":	{"NN"},
"suspensions":	{"NNS"},
"suspensive":	{"JJ"},
"suspensor":	{"NN"},
"suspensories":	{"NNS"},
"suspensory":	{"NN","JJ"},
"suspicion":	{"NN"},
"suspicions":	{"NNS"},
"suspicious":	{"JJ"},
"suspiciously":	{"RB"},
"suspiciousness":	{"NN"},
"suspiration":	{"NN"},
"suspire":	{"VB","VBP"},
"susquehanna":	{"NN"},
"sussed":	{"VBD","VBN"},
"susses":	{"VBZ"},
"sussex":	{"NN"},
"sussing":	{"VBG"},
"sustain":	{"VB","VBP"},
"sustainability":	{"NN"},
"sustainable":	{"JJ"},
"sustainably":	{"RB"},
"sustained":	{"VBN","VBD","JJ"},
"sustainer":	{"NN"},
"sustaining":	{"VBG"},
"sustainment":	{"NN"},
"sustains":	{"VBZ"},
"sustenance":	{"NN"},
"sustentacular":	{"JJ"},
"sustentation":	{"NN"},
"susurrant":	{"JJ"},
"susurrate":	{"VB","VBP"},
"susurrated":	{"VBD","VBN"},
"susurrates":	{"VBZ"},
"susurrating":	{"VBG"},
"susurration":	{"NN"},
"susurrous":	{"JJ"},
"susurrus":	{"NN"},
"sutherland":	{"NN"},
"sutler":	{"NN"},
"sutra":	{"NN"},
"suttee":	{"NN"},
"sutura":	{"NN"},
"suture":	{"NN","VB","VBP"},
"sutured":	{"VBD","VBN"},
"sutures":	{"NNS","VBZ"},
"suturing":	{"VBG"},
"suvivors":	{"NNS"},
"suzerain":	{"NN"},
"suzerainty":	{"NN"},
"svalbard":	{"NN"},
"svedberg":	{"NN"},
"svelte":	{"JJ"},
"sverdrup":	{"NN"},
"sverige":	{"NN"},
"svizzera":	{"NN"},
"svoboda":	{"NN"},
"svr":	{"NN"},
"swab":	{"NN","VB","VBP"},
"swabbed":	{"VBD","VBN"},
"swabbing":	{"NN","VBG"},
"swabs":	{"NNS","VBZ"},
"swad":	{"NN"},
"swaddle":	{"VB","VBP"},
"swaddled":	{"VBD","VBN"},
"swaddles":	{"VBZ"},
"swaddling":	{"VBG"},
"swaddling-clothes":	{"NNS"},
"swag":	{"NN"},
"swage":	{"NN","VB","VBP"},
"swaged":	{"VBD","VBN"},
"swager":	{"NN"},
"swages":	{"NNS","VBZ"},
"swagger":	{"VB","VBP","NN"},
"swagger-cane":	{"NN"},
"swagger-stick":	{"NN"},
"swaggered":	{"VBD","VBN"},
"swaggerer":	{"NN"},
"swaggering":	{"VBG"},
"swaggeringly":	{"RB"},
"swaggers":	{"VBZ"},
"swaggie":	{"NN"},
"swaging":	{"VBG"},
"swagman":	{"NN"},
"swagmen":	{"NNS"},
"swahili":	{"NN"},
"swain":	{"NN"},
"swains":	{"NNS"},
"swainsona":	{"NN"},
"swale":	{"NN"},
"swallow":	{"VB","VBP","NN"},
"swallow-dive":	{"NN"},
"swallowed":	{"VBD","VBN"},
"swallowing":	{"VBG"},
"swallows":	{"VBZ","NNS"},
"swallowtail":	{"NN"},
"swallowwort":	{"NN"},
"swam":	{"VBD"},
"swami":	{"NN"},
"swammerdam":	{"NN"},
"swamp":	{"NN","VB","VBP"},
"swamped":	{"VBN","VBD"},
"swamphen":	{"NN"},
"swampier":	{"JJR"},
"swampiest":	{"JJS"},
"swamping":	{"VBG"},
"swampland":	{"NN"},
"swamplands":	{"NNS"},
"swamps":	{"NNS","VBZ"},
"swampy":	{"JJ"},
"swan":	{"NN","VB","VBP"},
"swan-dive":	{"NN"},
"swan-necked":	{"JJ"},
"swan-song":	{"NN"},
"swanflower":	{"NN"},
"swank":	{"VB","VBP","NN"},
"swanked":	{"VBD","VBN"},
"swankier":	{"JJR"},
"swankiest":	{"JJS"},
"swanking":	{"VBG"},
"swanks":	{"VBZ"},
"swanky":	{"JJ"},
"swanlike":	{"JJ"},
"swanned":	{"VBD","VBN"},
"swanning":	{"VBG"},
"swans":	{"VBZ","NNS"},
"swansea":	{"NN"},
"swanson":	{"NN"},
"swap":	{"VB","VBP","NN"},
"swapped":	{"VBN","VBD"},
"swapping":	{"VBG"},
"swaps":	{"NNS","VBZ"},
"sward":	{"NN"},
"swarm":	{"NN","VB","VBP"},
"swarmed":	{"VBD","VBN"},
"swarming":	{"VBG"},
"swarms":	{"NNS","VBZ"},
"swart":	{"JJ"},
"swarthier":	{"JJR"},
"swarthiest":	{"JJS"},
"swarthiness":	{"NN"},
"swarthy":	{"JJ"},
"swash":	{"NN","VB","VBP"},
"swashbuckler":	{"NN"},
"swashbucklers":	{"NNS"},
"swashbuckling":	{"JJ"},
"swastika":	{"NN"},
"swastikas":	{"NNS"},
"swat":	{"VB","VBP","NN"},
"swatch":	{"NN"},
"swatches":	{"NNS"},
"swath":	{"NN"},
"swathe":	{"NN","VB","VBP"},
"swathed":	{"VBD","VBN"},
"swathes":	{"NNS","VBZ"},
"swathing":	{"VBG"},
"swaths":	{"NNS"},
"swats":	{"VBZ","NNS"},
"swatted":	{"VBD","VBN"},
"swatter":	{"NN"},
"swatters":	{"NNS"},
"swatting":	{"VBG"},
"sway":	{"VB","VBP","NN"},
"swayback":	{"NN"},
"swaybacked":	{"JJ"},
"swayed":	{"VBD","VBN"},
"swayer":	{"NN"},
"swaying":	{"VBG"},
"sways":	{"VBZ"},
"swear":	{"VB","NN","VBP"},
"swear-word":	{"NN"},
"swear-words":	{"NNS"},
"swearer":	{"NN"},
"swearers":	{"NNS"},
"swearing":	{"NN","VBG"},
"swearing-in":	{"NN"},
"swears":	{"VBZ","NNS"},
"swearword":	{"NN"},
"swearwords":	{"NNS"},
"sweat":	{"NN","VB","VBP"},
"sweat-band":	{"NN"},
"sweat-bands":	{"NNS"},
"sweat-gland":	{"NN"},
"sweat-glands":	{"NNS"},
"sweat-shirt":	{"NN"},
"sweat-shirts":	{"NNS"},
"sweat-shop":	{"NN"},
"sweat-suits":	{"NNS"},
"sweatband":	{"NN"},
"sweatbands":	{"NNS"},
"sweatbox":	{"NN"},
"sweated":	{"VBD","VBN","JJ"},
"sweater":	{"NN"},
"sweaters":	{"NNS"},
"sweatful":	{"JJ"},
"sweathouse":	{"NN"},
"sweathruna":	{"FW"},
"sweatier":	{"JJR"},
"sweatiest":	{"JJS"},
"sweating":	{"VBG","NN"},
"sweatpants":	{"NNS"},
"sweats":	{"NNS","VBZ"},
"sweatshirt":	{"NN"},
"sweatshirts":	{"NNS"},
"sweatshop":	{"NN"},
"sweatshops":	{"NNS"},
"sweatsuit":	{"NN"},
"sweatsuits":	{"NNS"},
"sweaty":	{"JJ"},
"swede":	{"NN"},
"sweden":	{"NN"},
"swedenborg":	{"NN"},
"swedes":	{"NNS"},
"sweep":	{"VB","VBP","NN"},
"sweeper":	{"NN"},
"sweepers":	{"NNS"},
"sweeping":	{"JJ","VBG"},
"sweepingly":	{"RB"},
"sweepings":	{"NNS"},
"sweeps":	{"NNS","VBZ"},
"sweepstake":	{"NN"},
"sweepstakes":	{"NNS"},
"sweet":	{"JJ","NN"},
"sweet-and-sour":	{"JJ"},
"sweet-scented":	{"JJ"},
"sweet-smelling":	{"JJ"},
"sweet-talk":	{"VB","VBP"},
"sweet-talked":	{"VBD","VBN"},
"sweet-talking":	{"VBG"},
"sweet-talks":	{"VBZ"},
"sweet-william":	{"NN"},
"sweetbread":	{"NN"},
"sweetbreads":	{"NNS"},
"sweetbriar":	{"NN"},
"sweetbrier":	{"NN"},
"sweeten":	{"VB","VBP"},
"sweetened":	{"VBD","VBN"},
"sweetener":	{"NN"},
"sweeteners":	{"NNS"},
"sweetening":	{"NN","VBG"},
"sweetenings":	{"NNS"},
"sweetens":	{"VBZ","NNS"},
"sweeter":	{"JJR"},
"sweetest":	{"JJS"},
"sweetheart":	{"NN"},
"sweethearts":	{"NNS"},
"sweetie":	{"NN"},
"sweeties":	{"NNS"},
"sweetish":	{"JJ"},
"sweetleaf":	{"NN"},
"sweetly":	{"RB"},
"sweetmeat":	{"NN"},
"sweetmeats":	{"NNS"},
"sweetness":	{"NN"},
"sweetpea":	{"NN"},
"sweetpeas":	{"NNS"},
"sweets":	{"NNS"},
"sweetsop":	{"NN"},
"swell":	{"VB","VBP","NN","JJ"},
"swelled":	{"VBD","VBN"},
"swellen":	{"VBN"},
"swellhead":	{"NN"},
"swelling":	{"VBG","NN"},
"swellings":	{"NNS"},
"swells":	{"VBZ"},
"swelter":	{"VB","VBP"},
"sweltered":	{"VBD","VBN"},
"sweltering":	{"JJ","VBG"},
"swelters":	{"VBZ"},
"sweltry":	{"JJ"},
"swept":	{"VBN","VBD"},
"swept-back":	{"JJ"},
"swept-wing":	{"JJ"},
"swertia":	{"NN"},
"swerve":	{"VB","VBP","NN"},
"swerved":	{"VBD","VBN"},
"swerves":	{"VBZ","NNS"},
"swerving":	{"VBG"},
"swietinia":	{"NN"},
"swift":	{"JJ","NN"},
"swift-footed":	{"JJ"},
"swifter":	{"JJR"},
"swiftest":	{"JJS"},
"swiftlet":	{"NN"},
"swiftly":	{"RB"},
"swiftness":	{"NN"},
"swifts":	{"NNS"},
"swig":	{"VB","VBP","NN"},
"swigged":	{"VBD","VBN"},
"swigging":	{"VBG"},
"swigs":	{"VBZ","NNS"},
"swill":	{"VB","VBP","NN"},
"swilled":	{"VBD","VBN"},
"swilling":	{"VBG"},
"swills":	{"VBZ"},
"swim":	{"VB","NN","VBP"},
"swimmer":	{"NN"},
"swimmeret":	{"NN"},
"swimmers":	{"NNS"},
"swimming":	{"VBG","NN"},
"swimmingly":	{"RB"},
"swims":	{"VBZ","NNS"},
"swimsuit":	{"NN"},
"swimsuits":	{"NNS"},
"swimwear":	{"NN"},
"swinburne":	{"NN"},
"swindle":	{"VB","VBP","NN"},
"swindled":	{"VBD","VBN"},
"swindler":	{"NN"},
"swindlers":	{"NNS"},
"swindles":	{"VBZ","NNS"},
"swindling":	{"VBG"},
"swine":	{"NN","NNS"},
"swineherd":	{"NN"},
"swines":	{"NNS"},
"swing":	{"VB","VBP","NN"},
"swinge":	{"VB","VBP"},
"swinged":	{"VBD","VBN"},
"swingeing":	{"JJ","VBG"},
"swinger":	{"NN"},
"swingers":	{"NNS"},
"swinges":	{"VBZ"},
"swingier":	{"JJR"},
"swingiest":	{"JJS"},
"swinging":	{"VBG","JJ"},
"swingletree":	{"NN"},
"swings":	{"NNS","VBZ"},
"swingy":	{"JJ"},
"swinish":	{"JJ"},
"swipe":	{"VB","VBP","NN"},
"swiped":	{"VBD","VBN"},
"swipes":	{"NNS","VBZ"},
"swiping":	{"VBG"},
"swirl":	{"VB","VBP","NN"},
"swirled":	{"VBD","VBN"},
"swirling":	{"VBG"},
"swirls":	{"NNS","VBZ"},
"swish":	{"VB","VBP","JJ"},
"swished":	{"VBD","VBN"},
"swishes":	{"VBZ"},
"swishier":	{"JJR"},
"swishiest":	{"JJS"},
"swishing":	{"VBG"},
"swishy":	{"JJ"},
"swissmade":	{"JJ"},
"switch":	{"NN","VB","VBP"},
"switch-blade":	{"NN"},
"switch-hit":	{"VB","VBP","NN"},
"switch-hitter":	{"NN"},
"switch-ivy":	{"NN"},
"switch-man":	{"NN"},
"switch-men":	{"NNS"},
"switch-over":	{"NN"},
"switch-yard":	{"NN"},
"switchblade":	{"NN"},
"switchblades":	{"NNS"},
"switchboard":	{"NN"},
"switchboards":	{"NNS"},
"switched":	{"VBD","VBN"},
"switched-on":	{"JJ"},
"switcher":	{"NN"},
"switcheroo":	{"NN"},
"switchers":	{"NNS"},
"switches":	{"NNS","VBZ"},
"switchgear":	{"NN"},
"switching":	{"VBG"},
"switchman":	{"NN"},
"swither":	{"NN"},
"switzerland":	{"NN"},
"swivel":	{"NN","VB","VBP"},
"swiveled":	{"VBD","VBN"},
"swiveling":	{"VBG"},
"swivelled":	{"VBD","VBN"},
"swivelling":	{"VBG"},
"swivels":	{"NNS","VBZ"},
"swivet":	{"NN"},
"swiz":	{"NN"},
"swizzle":	{"NN"},
"swizzle-stick":	{"NN"},
"swob":	{"NN","VB","VBP"},
"swobbed":	{"VBD","VBN"},
"swobbing":	{"VBG"},
"swobs":	{"NNS","VBZ"},
"swollen":	{"VBN","JJ"},
"swoon":	{"VB","VBP","NN"},
"swooned":	{"VBD","VBN"},
"swooning":	{"VBG"},
"swoons":	{"VBZ"},
"swoop":	{"VB","VBP","NN"},
"swooped":	{"VBD","VBN"},
"swooping":	{"VBG"},
"swoops":	{"VBZ","NNS"},
"swoosh":	{"VB","VBP","NN"},
"swooshed":	{"VBD","VBN"},
"swooshes":	{"VBZ","NNS"},
"swooshing":	{"VBG"},
"swop":	{"VB","VBP","NN"},
"sword":	{"NN"},
"sword-dance":	{"NN"},
"sword-play":	{"NN"},
"sword-stick":	{"NN"},
"sworde":	{"NN"},
"swordfish":	{"NN","NNS"},
"swordlike":	{"JJ"},
"swordplay":	{"NN"},
"swords":	{"NNS"},
"swordsman":	{"NN"},
"swordsmanship":	{"NN"},
"swordsmen":	{"NNS"},
"swordtail":	{"NN"},
"swore":	{"VBD"},
"sworn":	{"VBN","JJ"},
"swot":	{"VB","VBP","NN"},
"swots":	{"VBZ","NNS"},
"swotted":	{"VBD","VBN"},
"swotting":	{"VBG"},
"swum":	{"VBN"},
"swung":	{"VBD","VBN"},
"sybarite":	{"NN","JJ"},
"sybaritic":	{"JJ"},
"sybaritical":	{"JJ"},
"sybaritically":	{"RB"},
"sybaritism":	{"NN"},
"sybase":	{"NN"},
"sycamore":	{"NN"},
"sycamores":	{"NNS"},
"syconium":	{"NN"},
"sycophancy":	{"NN"},
"sycophant":	{"NN"},
"sycophantic":	{"JJ"},
"sycophantically":	{"RB"},
"sycophantishness":	{"NN"},
"sycophants":	{"NNS"},
"sydenham":	{"NN"},
"syllabary":	{"NN"},
"syllabic":	{"JJ"},
"syllabically":	{"RB"},
"syllabicate":	{"VB","VBP"},
"syllabication":	{"NN"},
"syllabicity":	{"NN"},
"syllabification":	{"NN"},
"syllabified":	{"VBD","VBN"},
"syllabifies":	{"VBZ"},
"syllabify":	{"VB","VBP"},
"syllabifying":	{"VBG"},
"syllabise":	{"VB","VBP"},
"syllabize":	{"VB","VBP"},
"syllable":	{"NN","VB","VBP"},
"syllabled":	{"JJ","VBD","VBN"},
"syllables":	{"NNS","VBZ"},
"syllabling":	{"VBG"},
"syllabub":	{"NN"},
"syllabus":	{"NN"},
"syllabuses":	{"NNS"},
"syllepsis":	{"NN"},
"syllogise":	{"VB","VBP"},
"syllogiser":	{"NN"},
"syllogism":	{"NN"},
"syllogist":	{"NN"},
"syllogistic":	{"JJ"},
"syllogize":	{"VB","VBP"},
"syllogizer":	{"NN"},
"sylph":	{"NN"},
"sylphlike":	{"JJ"},
"sylva":	{"NN"},
"sylvan":	{"JJ"},
"sylvanite":	{"NN"},
"sylvanus":	{"NN"},
"sylvia":	{"NN"},
"sylviidae":	{"NN"},
"sylviinae":	{"NN"},
"sylvilagus":	{"NN"},
"sylvine":	{"NN"},
"sylvite":	{"NN"},
"symbiosis":	{"NN"},
"symbiotic":	{"JJ"},
"symbiotically":	{"RB"},
"symbol":	{"NN"},
"symbolatry":	{"NN"},
"symbolic":	{"JJ"},
"symbolical":	{"JJ"},
"symbolically":	{"RB"},
"symbolisation":	{"NN"},
"symbolise":	{"VB","VBP"},
"symbolised":	{"VBD","VBN"},
"symboliser":	{"NN"},
"symbolises":	{"VBZ"},
"symbolising":	{"VBG"},
"symbolism":	{"NN"},
"symbolist":	{"NN","JJ"},
"symbolistic":	{"JJ"},
"symbolistical":	{"JJ"},
"symbolistically":	{"RB"},
"symbolists":	{"NNS"},
"symbolization":	{"NN"},
"symbolize":	{"VB","VBP"},
"symbolized":	{"VBD","VBN"},
"symbolizer":	{"NN"},
"symbolizes":	{"VBZ"},
"symbolizing":	{"VBG"},
"symbology":	{"NN"},
"symbololatry":	{"NN"},
"symbols":	{"NNS"},
"symmetric":	{"JJ"},
"symmetrical":	{"JJ"},
"symmetrically":	{"RB"},
"symmetricalness":	{"NN"},
"symmetries":	{"NNS"},
"symmetrise":	{"VB","VBP"},
"symmetrize":	{"VB","VBP"},
"symmetry":	{"NN"},
"symonds":	{"NNS"},
"symons":	{"NNS"},
"sympathectomy":	{"NN"},
"sympathetic":	{"JJ"},
"sympathetically":	{"RB"},
"sympathies":	{"NNS"},
"sympathique":	{"FW"},
"sympathise":	{"VB","VBP"},
"sympathised":	{"VBD","VBN"},
"sympathiser":	{"NN"},
"sympathisers":	{"NNS"},
"sympathises":	{"VBZ"},
"sympathising":	{"VBG"},
"sympathize":	{"VB","VBP"},
"sympathized":	{"VBD","VBN"},
"sympathizer":	{"NN"},
"sympathizers":	{"NNS"},
"sympathizes":	{"VBZ"},
"sympathizing":	{"VBG"},
"sympathomimetic":	{"JJ","NN"},
"sympathomimetics":	{"NNS"},
"sympathy":	{"NN"},
"sympatric":	{"JJ"},
"sympatry":	{"NN"},
"sympetalous":	{"JJ"},
"symphalangus":	{"NN"},
"symphilid":	{"NN"},
"symphonic":	{"JJ"},
"symphonies":	{"NNS"},
"symphonious":	{"JJ"},
"symphonist":	{"NN"},
"symphony":	{"NN"},
"symphoricarpos":	{"NNS"},
"symphyla":	{"NN"},
"symphysion":	{"NN"},
"symphysis":	{"NN"},
"symphytum":	{"NN"},
"symplocaceae":	{"NN"},
"symplocarpus":	{"NN"},
"symploce":	{"NN"},
"symplocus":	{"NN"},
"symposia":	{"NNS"},
"symposiarch":	{"NN"},
"symposiast":	{"NN"},
"symposium":	{"NN"},
"symposiums":	{"NNS"},
"symptom":	{"NN"},
"symptomatic":	{"JJ"},
"symptomatically":	{"RB"},
"symptomless":	{"JJ"},
"symptoms":	{"NNS"},
"synaeresis":	{"NN"},
"synaesthesia":	{"NN"},
"synaesthetic":	{"JJ"},
"synagogue":	{"NN"},
"synagogues":	{"NNS"},
"synagrops":	{"NNS"},
"synanceja":	{"NN"},
"synapse":	{"NN"},
"synapses":	{"NNS"},
"synapsid":	{"NN"},
"synapsida":	{"NN"},
"synapsis":	{"NN"},
"synaptic":	{"JJ"},
"synaptomys":	{"NNS"},
"sync":	{"NN","VB","VBP"},
"syncarp":	{"NN"},
"syncarpous":	{"JJ"},
"syncategorem":	{"NN"},
"syncategorematic":	{"JJ"},
"syncategoreme":	{"NN"},
"synce":	{"IN"},
"synced":	{"VBD","VBN"},
"synces":	{"VBZ"},
"synch":	{"NN","VB","VBP"},
"synched":	{"VBD","VBN"},
"synches":	{"VBZ"},
"synching":	{"VBG"},
"synchotron":	{"JJ"},
"synchro":	{"NN"},
"synchrocyclotron":	{"NN"},
"synchroflash":	{"NN"},
"synchromesh":	{"NN","JJ"},
"synchronal":	{"JJ"},
"synchroneity":	{"NN"},
"synchronic":	{"JJ"},
"synchronicity":	{"NN"},
"synchronisation":	{"NN"},
"synchronise":	{"VB","VBP"},
"synchronised":	{"VBD","VBN"},
"synchroniser":	{"NN"},
"synchronisers":	{"NNS"},
"synchronises":	{"VBZ"},
"synchronising":	{"VBG"},
"synchronism":	{"NN"},
"synchronization":	{"NN"},
"synchronize":	{"VB","VBP"},
"synchronized":	{"JJ","VBD","VBN"},
"synchronizer":	{"NN"},
"synchronizers":	{"NNS"},
"synchronizes":	{"VBZ"},
"synchronizing":	{"VBG"},
"synchronoscope":	{"NN"},
"synchronous":	{"JJ"},
"synchronously":	{"RB"},
"synchrony":	{"NN"},
"synchroscope":	{"NN"},
"synchrotron":	{"NN"},
"synchytriaceae":	{"NN"},
"synchytrium":	{"NN"},
"syncing":	{"VBG"},
"synclinal":	{"JJ"},
"syncopate":	{"VB","VBP"},
"syncopated":	{"VBD","VBN","JJ"},
"syncopates":	{"VBZ"},
"syncopating":	{"VBG"},
"syncopation":	{"NN"},
"syncopations":	{"NNS"},
"syncopator":	{"NN"},
"syncope":	{"NN"},
"syncretic":	{"NN"},
"syncretical":	{"JJ"},
"syncretise":	{"VB"},
"syncretism":	{"NN"},
"syncretistic":	{"JJ"},
"syncretistical":	{"JJ"},
"syncretize":	{"VB"},
"syncytium":	{"NN"},
"syndactylism":	{"NN"},
"syndactyly":	{"NN"},
"syndciated":	{"VBN"},
"syndetic":	{"JJ"},
"syndic":	{"NN"},
"syndicalism":	{"NN"},
"syndicalist":	{"NN","JJ"},
"syndicalists":	{"NNS"},
"syndicate":	{"NN","VB","VBP"},
"syndicated":	{"VBD","VBN"},
"syndicates":	{"NNS","VBZ"},
"syndicating":	{"VBG"},
"syndication":	{"NN"},
"syndicator":	{"NN"},
"syndicators":	{"NNS"},
"syndrome":	{"NN"},
"syndromes":	{"NNS"},
"synecdoche":	{"NN"},
"synecdochic":	{"JJ"},
"synecdochical":	{"JJ"},
"synechia":	{"NN"},
"synentognathi":	{"NN"},
"synercus":	{"NNS"},
"syneresis":	{"NN"},
"synergetic":	{"JJ"},
"synergetics":	{"NNS"},
"synergies":	{"NNS"},
"synergism":	{"NN"},
"synergist":	{"NN","JJ"},
"synergistic":	{"JJ"},
"synergistically":	{"RB"},
"synergy":	{"NN"},
"synesthesia":	{"NN"},
"synesthetic":	{"JJ"},
"synezesis":	{"NN"},
"syngeries":	{"NNS"},
"syngnathidae":	{"NN"},
"syngnathus":	{"NNS"},
"syngonium":	{"NN"},
"synizesis":	{"NN"},
"synod":	{"NN"},
"synodontidae":	{"NN"},
"synods":	{"NNS"},
"synoecious":	{"JJ"},
"synoicous":	{"JJ"},
"synonym":	{"NN"},
"synonymist":	{"NN"},
"synonymity":	{"NN"},
"synonymous":	{"JJ"},
"synonymously":	{"RB"},
"synonymousness":	{"NN"},
"synonyms":	{"NNS"},
"synonymy":	{"NN"},
"synopses":	{"NNS"},
"synopsis":	{"NN"},
"synoptic":	{"JJ","NN"},
"synoptical":	{"JJ"},
"synovia":	{"NN"},
"synovial":	{"JJ"},
"synovitis":	{"NN"},
"synovium":	{"NN"},
"synsemantic":	{"JJ"},
"synset":	{"NN"},
"syntactic":	{"JJ"},
"syntactical":	{"JJ"},
"syntactically":	{"RB"},
"syntactician":	{"NN"},
"syntagm":	{"NN"},
"syntagma":	{"NN"},
"syntagmatic":	{"JJ"},
"syntax":	{"NN"},
"synth-pop":	{"NN"},
"syntheses":	{"NNS"},
"synthesis":	{"NN"},
"synthesise":	{"VB","VBP"},
"synthesised":	{"VBD","VBN","JJ"},
"synthesiser":	{"NN"},
"synthesisers":	{"NNS"},
"synthesises":	{"VBZ"},
"synthesising":	{"VBG"},
"synthesist":	{"NN"},
"synthesize":	{"VB","VBP"},
"synthesized":	{"JJ","VBD","VBN"},
"synthesizer":	{"NN"},
"synthesizers":	{"NNS"},
"synthesizes":	{"VBZ"},
"synthesizine":	{"NN"},
"synthesizing":	{"VBG"},
"synthetic":	{"JJ"},
"synthetical":	{"JJ"},
"synthetically":	{"RB"},
"synthetics":	{"NNS"},
"synthetism":	{"NN"},
"syph":	{"NN"},
"syphilis":	{"NN"},
"syphilitic":	{"JJ","NN"},
"syphon":	{"NN","VB","VBP"},
"syphoned":	{"VBD","VBN"},
"syphoning":	{"VBG"},
"syphons":	{"NNS","VBZ"},
"syracuse":	{"NN"},
"syria":	{"NN"},
"syrian":	{"JJ","NN"},
"syringa":	{"NN"},
"syringe":	{"NN","VB","VBP"},
"syringed":	{"VBD","VBN"},
"syringes":	{"NNS","VBZ"},
"syringing":	{"VBG"},
"syrinx":	{"NN"},
"syrinxes":	{"NNS"},
"syrrhaptes":	{"NNS"},
"syrup":	{"NN"},
"syrupy":	{"JJ"},
"system":	{"NN"},
"systematic":	{"JJ"},
"systematically":	{"RB"},
"systematics":	{"NN"},
"systematisation":	{"NN"},
"systematise":	{"VB","VBP"},
"systematised":	{"VBD","VBN"},
"systematiser":	{"NN"},
"systematises":	{"VBZ"},
"systematising":	{"VBG"},
"systematism":	{"NN"},
"systematist":	{"NN"},
"systematization":	{"NN"},
"systematize":	{"VB","VBP"},
"systematized":	{"VBD","VBN"},
"systematizer":	{"NN"},
"systematizes":	{"VBZ"},
"systematizing":	{"VBG"},
"systemic":	{"JJ"},
"systemise":	{"VB","VBP"},
"systemiser":	{"NN"},
"systemization":	{"NN"},
"systemize":	{"VB","VBP"},
"systemizer":	{"NN"},
"systems":	{"NNS"},
"systemwide":	{"JJ"},
"systole":	{"NN"},
"systolic":	{"JJ"},
"syzygium":	{"NN"},
"syzygy":	{"NN"},
"szechuan":	{"NN"},
"szechwan":	{"NN"},
"szell":	{"NN"},
"szilard":	{"NN"},
"t":	{"NN","SYM","LS"},
"t-bar":	{"NN"},
"t-helper":	{"NN"},
"tRNA":	{"NN"},
"ta":	{"UH"},
"taal":	{"NN"},
"tab":	{"NN","VB","VBP"},
"tab-lifter":	{"NN"},
"tabanidae":	{"NN"},
"tabard":	{"NN"},
"tabards":	{"NNS"},
"tabasco":	{"NN"},
"tabbed":	{"VBD","VBN"},
"tabbies":	{"NNS"},
"tabbing":	{"VBG"},
"tabbouleh":	{"NN"},
"tabby":	{"NN","JJ"},
"tabby-cat":	{"NN"},
"tabernacle":	{"NN"},
"tabernacles":	{"NNS"},
"tabernaemontana":	{"NN"},
"tabes":	{"NN","NNS"},
"tabetic":	{"JJ"},
"tabi":	{"NN","NNS"},
"tabis":	{"NNS"},
"tablature":	{"NN"},
"table":	{"NN","VB","VBP"},
"table-cloth":	{"NN"},
"table-cloths":	{"NNS"},
"table-knife":	{"NN"},
"table-linen":	{"NN"},
"table-mat":	{"NN"},
"table-talk":	{"NN"},
"table-tennis":	{"NN"},
"table-top":	{"JJ","NN"},
"table-tops":	{"NNS"},
"table-turning":	{"NN"},
"tableau":	{"NN"},
"tableaux":	{"NNS"},
"tablecloth":	{"NN"},
"tablecloths":	{"NNS"},
"tabled":	{"VBD","VBN"},
"tablefork":	{"NN"},
"tableland":	{"NN"},
"tablelands":	{"NNS"},
"tablemate":	{"NN"},
"tablemodel":	{"NN"},
"tables":	{"NNS","VBZ"},
"tablespoon":	{"NN"},
"tablespoonful":	{"NN"},
"tablespoonfuls":	{"NNS"},
"tablespoons":	{"NNS"},
"tablet":	{"NN"},
"tabletop":	{"JJ"},
"tablets":	{"NNS"},
"tableware":	{"NN"},
"tabling":	{"VBG"},
"tabloid":	{"NN","JJ"},
"tabloids":	{"NNS"},
"taboo":	{"JJ","NN","VB","VBP"},
"tabooed":	{"VBD","VBN"},
"tabooing":	{"VBG"},
"tabooli":	{"NN"},
"taboos":	{"NNS","VBZ"},
"tabor":	{"NN"},
"tabora":	{"NN"},
"taboret":	{"NN"},
"tabour":	{"NN"},
"tabouret":	{"NN"},
"tabriz":	{"NN"},
"tabs":	{"NNS","VBZ"},
"tabu":	{"NN","JJ","VB","VBP"},
"tabued":	{"VBD","VBN"},
"tabuing":	{"VBG"},
"tabuk":	{"NN"},
"tabula":	{"NN"},
"tabular":	{"JJ"},
"tabularise":	{"VB","VBP"},
"tabularize":	{"VB","VBP"},
"tabulate":	{"VB","VBP"},
"tabulated":	{"VBD","VBN"},
"tabulates":	{"VBZ"},
"tabulating":	{"VBG"},
"tabulation":	{"NN"},
"tabulations":	{"NNS"},
"tabulator":	{"NN"},
"tabulators":	{"NNS"},
"tabun":	{"NN"},
"tabus":	{"NNS","VBZ"},
"tacamahac":	{"NN"},
"tacca":	{"NN"},
"taccaceae":	{"NN"},
"tach":	{"NN"},
"tacheometer":	{"NN"},
"tachinidae":	{"NN"},
"tachistoscope":	{"NN"},
"tachogram":	{"NN"},
"tachograph":	{"NN"},
"tachographs":	{"NNS"},
"tachometer":	{"NN"},
"tachometers":	{"NNS"},
"tachyarrhythmia":	{"NN"},
"tachycardia":	{"NN"},
"tachyglossidae":	{"NN"},
"tachyglossus":	{"NN"},
"tachygraphy":	{"NN"},
"tachylite":	{"NN"},
"tachymeter":	{"NN"},
"tachypleus":	{"NN"},
"tacit":	{"JJ"},
"tacitly":	{"RB"},
"taciturn":	{"JJ"},
"taciturnity":	{"NN"},
"taciturnly":	{"RB"},
"tacitus":	{"NN"},
"tack":	{"NN","VB","VBP"},
"tacked":	{"VBD","VBN"},
"tacker":	{"NN"},
"tackier":	{"JJR"},
"tackiest":	{"JJS"},
"tackily":	{"RB"},
"tackiness":	{"NN"},
"tacking":	{"VBG"},
"tackle":	{"NN","VB","VBP"},
"tackled":	{"VBD","VBN"},
"tackler":	{"NN"},
"tacklers":	{"NNS"},
"tackles":	{"VBZ","NNS"},
"tackling":	{"VBG"},
"tacks":	{"NNS","VBZ"},
"tacky":	{"JJ"},
"taco":	{"NN"},
"tacoma":	{"NN"},
"taconite":	{"NN"},
"tacos":	{"NNS"},
"tact":	{"NN"},
"tactful":	{"JJ"},
"tactfully":	{"RB"},
"tactfulness":	{"NN"},
"tactic":	{"NN"},
"tactical":	{"JJ"},
"tactically":	{"RB"},
"tactician":	{"NN"},
"tacticians":	{"NNS"},
"tactics":	{"NNS"},
"tactile":	{"JJ"},
"tactility":	{"NN"},
"tactless":	{"JJ"},
"tactlessly":	{"RB"},
"tactlessness":	{"NN"},
"tactual":	{"JJ"},
"tactually":	{"RB"},
"tad":	{"NN"},
"tadalafil":	{"NN"},
"tadarida":	{"NN"},
"tadorna":	{"NN"},
"tadpole":	{"NN"},
"tadpoles":	{"NNS"},
"tadzhikistan":	{"NN"},
"tae":	{"FW"},
"taegu":	{"NN"},
"taekwondo":	{"NN"},
"tael":	{"NN"},
"taenia":	{"NN"},
"taeniidae":	{"NN"},
"taffeta":	{"NN"},
"taffies":	{"NNS"},
"taffrail":	{"NN"},
"taffy":	{"NN"},
"tag":	{"NN","VB","VBP"},
"tagalog":	{"NN"},
"tagalong":	{"NN","JJ"},
"tagalongs":	{"NNS"},
"tagamet":	{"NN"},
"tagasaste":	{"NN"},
"tageteste":	{"NN"},
"tagged":	{"VBD","VBN"},
"tagger":	{"NN"},
"taggers":	{"NNS"},
"tagging":	{"NN","VBG"},
"tagliatelle":	{"NN"},
"tagline":	{"NN"},
"taglines":	{"NNS"},
"tags":	{"NNS","VBZ"},
"tagua":	{"NN"},
"taguan":	{"NN"},
"tagus":	{"NN"},
"tahini":	{"NN"},
"tahiti":	{"NN"},
"taichi":	{"NN"},
"taichichuan":	{"NN"},
"taichung":	{"NN"},
"taif":	{"NN"},
"tail":	{"NN","VB","VBP","JJ"},
"tail-board":	{"NN"},
"tail-end":	{"NN"},
"tail-gate":	{"NN","VB","VBP"},
"tail-lamp":	{"NN"},
"tail-lamps":	{"NNS"},
"tail-light":	{"NN"},
"tail-lights":	{"NNS"},
"tail-spin":	{"NN"},
"tailback":	{"NN"},
"tailbacks":	{"NNS"},
"tailboard":	{"NN"},
"tailboards":	{"NNS"},
"tailcoat":	{"NN"},
"tailcoats":	{"NNS"},
"tailed":	{"VBD","VBN","JJ"},
"tailfin":	{"NN"},
"tailflower":	{"NN"},
"tailgate":	{"NN","VB","VBP"},
"tailgated":	{"VBD","VBN"},
"tailgater":	{"NN"},
"tailgates":	{"NNS","VBZ"},
"tailgating":	{"VBG","NN"},
"tailin":	{"NN"},
"tailing":	{"NN","VBG"},
"tailless":	{"JJ"},
"taillight":	{"NN"},
"taillike":	{"JJ"},
"tailor":	{"NN","VB","VBP"},
"tailor-made":	{"JJ","VBD","VBN"},
"tailor-make":	{"VB","VBP"},
"tailor-makes":	{"VBZ"},
"tailor-making":	{"VBG"},
"tailorbird":	{"NN"},
"tailored":	{"VBD","VBN","JJ"},
"tailoring":	{"NN","VBG"},
"tailors":	{"NNS","VBZ"},
"tailpiece":	{"NN"},
"tailpieces":	{"NNS"},
"tailpipe":	{"NN"},
"tailpipes":	{"NNS"},
"tailplane":	{"NN"},
"tailrace":	{"NN"},
"tails":	{"NNS","VBZ"},
"tailspin":	{"NN"},
"tailstock":	{"NN"},
"tailwind":	{"NN"},
"tailwinds":	{"NNS"},
"tailwort":	{"NN"},
"taint":	{"VB","VBP","NN"},
"tainted":	{"JJ","VBD","VBN"},
"tainting":	{"VBG"},
"taints":	{"VBZ"},
"taipan":	{"NN"},
"taipeh":	{"NN"},
"taipei":	{"NN"},
"taira":	{"NN"},
"tait":	{"NN"},
"taiwan":	{"NN"},
"taiwanese":	{"JJ","NN"},
"taiyuan":	{"NN"},
"taj":	{"NN"},
"tajiki":	{"NN"},
"tajikistan":	{"NN"},
"taka":	{"NN"},
"takahe":	{"NN"},
"takakkaw":	{"NN"},
"take":	{"VB","VBP","NN"},
"take-away":	{"JJ","NN"},
"take-home":	{"JJ"},
"take-in":	{"NN"},
"take-off":	{"NN"},
"take-offs":	{"NNS"},
"take-out":	{"NN","JJ"},
"take-over":	{"NN"},
"take-up":	{"NN","JJ"},
"takeaway":	{"NN"},
"takeaways":	{"NNS"},
"takedown":	{"JJ"},
"takelma":	{"NN"},
"taken":	{"VBN","JJ"},
"takeoff":	{"NN"},
"takeoffs":	{"NNS"},
"takeout":	{"NN","JJ"},
"takeouts":	{"NNS"},
"takeover":	{"NN"},
"takeovers":	{"NNS"},
"taker":	{"NN"},
"takers":	{"NNS"},
"takes":	{"VBZ","NNS"},
"takilman":	{"NN"},
"takin":	{"NN"},
"taking":	{"VBG","JJ","NN"},
"takingly":	{"RB"},
"takingness":	{"NN"},
"takings":	{"NNS"},
"tala":	{"NN"},
"talapoin":	{"NN"},
"talaria":	{"NN"},
"talbot":	{"NN"},
"talc":	{"NN"},
"talcum":	{"NN"},
"tale":	{"NN"},
"taleban":	{"NN"},
"talebearer":	{"NN"},
"talebearing":	{"NN"},
"talent":	{"NN"},
"talent-scout":	{"NN"},
"talent-scouts":	{"NNS"},
"talent-spotter":	{"NN"},
"talent-spotters":	{"NNS"},
"talented":	{"JJ"},
"talentless":	{"JJ"},
"talentlessness":	{"NN"},
"talents":	{"NNS"},
"tales":	{"NNS"},
"taleteller":	{"NN"},
"talien":	{"NN"},
"talinum":	{"NN"},
"taliped":	{"JJ"},
"talipes":	{"NN"},
"talipot":	{"NN"},
"talisman":	{"NN"},
"talismanic":	{"JJ"},
"talismans":	{"NNS"},
"talk":	{"VB","NN","VBP"},
"talk-show":	{"NN"},
"talk-shows":	{"NNS"},
"talkative":	{"JJ"},
"talkatively":	{"RB"},
"talkativeness":	{"NN"},
"talked":	{"VBD","VBN"},
"talker":	{"NN"},
"talkers":	{"NNS"},
"talkfest":	{"NN"},
"talkie":	{"NN"},
"talkies":	{"NNS"},
"talkily":	{"RB"},
"talkin":	{"NN"},
"talking":	{"VBG","NN"},
"talking-point":	{"NN"},
"talking-points":	{"NNS"},
"talking-to":	{"NN"},
"talking-tos":	{"NNS"},
"talks":	{"NNS","VBZ"},
"talky":	{"JJ"},
"tall":	{"JJ"},
"tall-tale":	{"NN"},
"tallahassee":	{"NN"},
"tallapoosa":	{"NN"},
"tallboy":	{"NN"},
"tallboys":	{"NNS"},
"tallchief":	{"NN"},
"taller":	{"JJR"},
"tallest":	{"JJS"},
"talleyrand":	{"NN"},
"tallgrass":	{"NN"},
"tallied":	{"VBD","VBN"},
"tallies":	{"VBZ","NNS"},
"tallin":	{"NN"},
"tallis":	{"NN"},
"tallish":	{"JJ"},
"tallith":	{"NN"},
"tallness":	{"NN"},
"tallow":	{"NN"},
"tally":	{"NN","VB","VBP"},
"tallyho":	{"UH"},
"tallying":	{"VBG"},
"tallyman":	{"NN"},
"tallymen":	{"NNS"},
"tallywoman":	{"NN"},
"tallywomen":	{"NNS"},
"talmud":	{"NN"},
"talon":	{"NN"},
"taloned":	{"JJ"},
"talons":	{"NNS"},
"talpidae":	{"NN"},
"talus":	{"NN"},
"talwin":	{"NN"},
"tam":	{"NN"},
"tam-o'-shanter":	{"NN"},
"tam-tam":	{"NN"},
"tamable":	{"JJ"},
"tamale":	{"NN"},
"tamandu":	{"NN"},
"tamandua":	{"NN"},
"tamanoir":	{"NN"},
"tamarack":	{"NN"},
"tamarao":	{"NN"},
"tamarau":	{"NN"},
"tamaricaceae":	{"NN"},
"tamarillo":	{"NN"},
"tamarin":	{"NN"},
"tamarind":	{"NN"},
"tamarindo":	{"NN"},
"tamarinds":	{"NNS"},
"tamarindus":	{"NN"},
"tamarisk":	{"NN"},
"tamarisks":	{"NNS"},
"tamarix":	{"NN"},
"tambac":	{"NN"},
"tambala":	{"NN"},
"tambien":	{"NN"},
"tambocor":	{"NN"},
"tambour":	{"NN","VB","VBP"},
"tamboured":	{"VBD","VBN"},
"tambourine":	{"NN"},
"tambourines":	{"NNS"},
"tambouring":	{"VBG"},
"tambours":	{"NNS","VBZ"},
"tamburlaine":	{"NN"},
"tame":	{"JJ","VB","VBP"},
"tameable":	{"JJ"},
"tamed":	{"VBD","VBN"},
"tamely":	{"RB"},
"tameness":	{"NN"},
"tamer":	{"JJR","NN"},
"tamerlane":	{"NN"},
"tamers":	{"NNS"},
"tames":	{"VBZ"},
"tamest":	{"JJS"},
"tamias":	{"NNS"},
"tamiasciurus":	{"NN"},
"tamil":	{"JJ","NN"},
"taming":	{"VBG"},
"tamm":	{"NN"},
"tammany":	{"NN"},
"tammerfors":	{"NNS"},
"tammies":	{"NNS"},
"tammy":	{"NN"},
"tamoxifen":	{"NN"},
"tamp":	{"VB","VBP"},
"tamped":	{"VBD","VBN"},
"tamper":	{"VB","VBP"},
"tamper-evident":	{"JJ"},
"tamper-proof":	{"JJ"},
"tamper-resistant":	{"JJ"},
"tampere":	{"NN"},
"tampered":	{"VBD","VBN"},
"tampering":	{"NN","VBG"},
"tampers":	{"VBZ"},
"tampico":	{"NN"},
"tamping":	{"VBG"},
"tampion":	{"NN"},
"tampon":	{"NN"},
"tamponade":	{"NN"},
"tamponage":	{"NN"},
"tampons":	{"NNS"},
"tamps":	{"VBZ"},
"tamus":	{"NN"},
"tan":	{"VB","VBP","NN","JJ"},
"tanacetum":	{"NN"},
"tanach":	{"NN"},
"tanager":	{"NN"},
"tanakh":	{"NN"},
"tanbark":	{"NN"},
"tancred":	{"VBD","VBN"},
"tandearil":	{"NN"},
"tandem":	{"NN"},
"tandems":	{"NNS"},
"tandoor":	{"NN"},
"tandy":	{"NN"},
"tanekaha":	{"NN"},
"taney":	{"NN"},
"tang":	{"NN","VB","VBP"},
"tanga":	{"NN"},
"tange":	{"NN"},
"tanged":	{"VBD","VBN"},
"tangelo":	{"NN"},
"tangency":	{"NN"},
"tangent":	{"NN"},
"tangential":	{"JJ"},
"tangentially":	{"RB"},
"tangents":	{"NNS"},
"tangere":	{"JJ"},
"tangerine":	{"NN","JJ"},
"tangerines":	{"NNS"},
"tangibility":	{"NN"},
"tangible":	{"JJ"},
"tangibleness":	{"NN"},
"tangibly":	{"RB"},
"tangier":	{"JJR"},
"tangiest":	{"JJS"},
"tanginess":	{"NN"},
"tanging":	{"VBG"},
"tangle":	{"VB","VBP","NN"},
"tanglebush":	{"NN"},
"tangled":	{"JJ","VBD","VBN"},
"tangles":	{"VBZ","NNS"},
"tangling":	{"VBG"},
"tangly":	{"JJ"},
"tango":	{"NN","VBP","VB"},
"tangoed":	{"VBD","VBN"},
"tangoing":	{"VBG"},
"tangor":	{"NN"},
"tangos":	{"NNS","VBZ"},
"tangram":	{"NN"},
"tangs":	{"VBZ"},
"tangshan":	{"NN"},
"tanguy":	{"NN"},
"tangy":	{"JJ"},
"tank":	{"NN","VB","VBP"},
"tanka":	{"NN"},
"tankage":	{"NN"},
"tankard":	{"NN"},
"tankards":	{"NNS"},
"tanked":	{"VBN","VBD","JJ"},
"tanker":	{"NN"},
"tankers":	{"NNS"},
"tankful":	{"NN"},
"tanking":	{"VBG"},
"tanks":	{"NNS","VBZ"},
"tanned":	{"JJ","VBD","VBN"},
"tannenberg":	{"NN"},
"tanner":	{"NN"},
"tanneries":	{"NNS"},
"tanners":	{"NNS"},
"tannery":	{"NN"},
"tannia":	{"NN"},
"tannic":	{"JJ"},
"tannin":	{"NN"},
"tanning":	{"NN","VBG"},
"tannish":	{"JJ"},
"tanoan":	{"NN"},
"tans":	{"NNS","VBZ"},
"tansy":	{"NN"},
"tantalise":	{"VB","VBP"},
"tantalised":	{"VBD","VBN"},
"tantaliser":	{"NN"},
"tantalises":	{"VBZ"},
"tantalising":	{"JJ","VBG"},
"tantalite":	{"NN"},
"tantalization":	{"NN"},
"tantalize":	{"VB","VBP"},
"tantalized":	{"VBD","VBN"},
"tantalizer":	{"NN"},
"tantalizes":	{"VBZ"},
"tantalizing":	{"JJ","VBG"},
"tantalizingly":	{"RB"},
"tantalum":	{"NN"},
"tantalus":	{"NN"},
"tantamount":	{"JJ"},
"tantilla":	{"NN"},
"tantra":	{"NN"},
"tantric":	{"JJ"},
"tantrik":	{"JJ"},
"tantrism":	{"NN"},
"tantrist":	{"NN"},
"tantrum":	{"NN"},
"tantrums":	{"NNS"},
"tanzania":	{"NN"},
"tanzim":	{"NN"},
"tao":	{"NN"},
"taoism":	{"NN"},
"taoist":	{"JJ","NN"},
"tap":	{"NN","VB","VBP"},
"tap-dance":	{"NN","VB","VBP"},
"tap-danced":	{"VBD","VBN"},
"tap-dancer":	{"NN"},
"tap-dancers":	{"NNS"},
"tap-dances":	{"NNS","VBZ"},
"tap-dancing":	{"VBG","NN"},
"tap-off":	{"NN"},
"tap-root":	{"NN"},
"tap-tap":	{"NN"},
"tap-water":	{"NN"},
"tapa":	{"NN"},
"tape":	{"NN","VB","VBP"},
"tape-measure":	{"NN"},
"tape-measures":	{"NNS"},
"tape-record":	{"VB","VBP"},
"tape-recorded":	{"VBD","VBN","JJ"},
"tape-recorder":	{"NN"},
"tape-recorders":	{"NNS"},
"tape-recording":	{"VBG","NN"},
"tape-recordings":	{"NNS"},
"tape-records":	{"VBZ"},
"taped":	{"VBN","VBD"},
"tapeline":	{"NN"},
"tapenade":	{"NN"},
"taper":	{"NN","VB","VBP"},
"tapered":	{"JJ","VBD","VBN"},
"tapering":	{"JJ","VBG"},
"tapers":	{"NNS","VBZ"},
"tapes":	{"NNS","VBZ"},
"tapestried":	{"JJ"},
"tapestries":	{"NNS"},
"tapestry":	{"NN"},
"tapeworm":	{"NN"},
"tapeworms":	{"NNS"},
"taphephobia":	{"NN"},
"taphouse":	{"NN"},
"taping":	{"VBG"},
"tapioca":	{"NN"},
"tapir":	{"NN","NNS"},
"tapiridae":	{"NN"},
"tapirs":	{"NNS"},
"tapirus":	{"NN"},
"tapis":	{"NN"},
"tapotement":	{"NN"},
"tappa":	{"NN"},
"tappan":	{"NN"},
"tapped":	{"VBN","VBD"},
"tapper":	{"NN"},
"tappers":	{"NNS"},
"tappet":	{"NN"},
"tappets":	{"NNS"},
"tapping":	{"NN","VBG"},
"taproom":	{"NN"},
"taproot":	{"NN"},
"taps":	{"NNS","VBZ"},
"tapster":	{"NN"},
"tar":	{"NN","VB","VBP"},
"tara":	{"NN"},
"tarabulus":	{"NN"},
"taracahitian":	{"NN"},
"taradiddle":	{"NN"},
"taragon":	{"NN"},
"tarahumara":	{"NN"},
"taraktagenos":	{"NNS"},
"taraktogenos":	{"NNS"},
"tarantara":	{"NN"},
"tarantella":	{"NN"},
"tarantelle":	{"NN"},
"tarantino":	{"NN"},
"tarantism":	{"NN"},
"tarantula":	{"NN"},
"tarantulas":	{"NNS"},
"tarawa":	{"NN"},
"taraxacum":	{"NN"},
"tarbell":	{"NN"},
"tarboosh":	{"NN"},
"tardier":	{"JJR"},
"tardiest":	{"JJS"},
"tardigrada":	{"NN"},
"tardigrade":	{"NN"},
"tardily":	{"RB"},
"tardiness":	{"NN"},
"tardive":	{"JJ"},
"tardy":	{"JJ"},
"tare":	{"NN"},
"target":	{"NN","VB","VBP"},
"target-hunting":	{"JJ"},
"target-language":	{"NN"},
"targeted":	{"VBN","JJ","VBD"},
"targeting":	{"VBG"},
"targets":	{"NNS","VBZ"},
"targo":	{"JJ"},
"tarheel":	{"NN"},
"taricha":	{"NN"},
"tariff":	{"NN","VB","VBP"},
"tariffed":	{"VBD","VBN"},
"tariffing":	{"VBG"},
"tariffless":	{"JJ"},
"tariffs":	{"NNS","VBZ"},
"tarkovsky":	{"NN"},
"tarmac":	{"NN","VB","VBP"},
"tarmacadam":	{"NN"},
"tarmacked":	{"VBD","VBN"},
"tarmacking":	{"VBG"},
"tarmacs":	{"VBZ"},
"tarn":	{"NN"},
"tarnish":	{"VB","VBP","NN"},
"tarnished":	{"VBD","VBN","JJ"},
"tarnishes":	{"VBZ"},
"tarnishing":	{"VBG"},
"tarns":	{"NNS"},
"taro":	{"NN"},
"taros":	{"NNS"},
"tarot":	{"NN"},
"tarp":	{"NN"},
"tarpan":	{"NN"},
"tarpapered":	{"JJ"},
"tarpaulin":	{"NN"},
"tarpaulins":	{"NNS"},
"tarpon":	{"NN","NNS"},
"tarpons":	{"NNS"},
"tarps":	{"NNS"},
"tarquin":	{"NN"},
"tarquinius":	{"NN"},
"tarradiddle":	{"NN"},
"tarragon":	{"NN"},
"tarred":	{"VBN","VBD","JJ"},
"tarriance":	{"NN"},
"tarried":	{"VBD","VBN"},
"tarrier":	{"JJR"},
"tarries":	{"VBZ"},
"tarriest":	{"JJS"},
"tarrietia":	{"NN"},
"tarring":	{"VBG"},
"tarry":	{"VB","VBP","JJ"},
"tarrying":	{"VBG"},
"tars":	{"VBZ"},
"tarsal":	{"JJ","NN"},
"tarsi":	{"NNS"},
"tarsier":	{"NN"},
"tarsiidae":	{"NN"},
"tarsioidea":	{"NN"},
"tarsitis":	{"NN"},
"tarsius":	{"NN"},
"tarsus":	{"NN"},
"tart":	{"JJ","NN","VBP","VB"},
"tartan":	{"NN","JJ"},
"tartans":	{"NNS"},
"tartar":	{"NN"},
"tartare":	{"NN"},
"tartarean":	{"JJ"},
"tartaric":	{"JJ"},
"tartars":	{"NNS"},
"tartarus":	{"NN"},
"tartary":	{"NN"},
"tarted":	{"VBD","VBN"},
"tarting":	{"VBG"},
"tartlet":	{"NN"},
"tartly":	{"RB"},
"tartness":	{"NN"},
"tartrate":	{"NN"},
"tarts":	{"NNS","VBZ"},
"tartu":	{"NN"},
"tartufe":	{"NN"},
"tartuffe":	{"NN"},
"tarweed":	{"NN"},
"tarwood":	{"NN"},
"tarzan":	{"NN"},
"tase":	{"VB","VBP"},
"tased":	{"VBD","VBN"},
"taser":	{"VB","VBP","NN"},
"tasered":	{"VBD","VBN"},
"tasering":	{"VBG"},
"tasers":	{"VBZ","NNS"},
"tases":	{"VBZ"},
"tashkent":	{"NN"},
"tashmit":	{"NN"},
"tashmitum":	{"NN"},
"tasing":	{"VBG"},
"task":	{"NN","VB","VBP"},
"task-force":	{"NN"},
"tasked":	{"VBD","VBN"},
"taskent":	{"NN"},
"taskforce":	{"NN"},
"taskforces":	{"NNS"},
"tasking":	{"VBG"},
"taskmaster":	{"NN"},
"taskmasters":	{"NNS"},
"taskmistress":	{"NN"},
"tasks":	{"NNS","VBZ"},
"tasman":	{"NN"},
"tasmania":	{"NN"},
"tasse":	{"NN"},
"tassel":	{"NN","VB","VBP"},
"tasseled":	{"VBD","VBN","JJ"},
"tasseling":	{"VBG"},
"tasselled":	{"VBD","VBN","JJ"},
"tasselling":	{"VBG"},
"tassels":	{"NNS","VBZ"},
"tasset":	{"NN"},
"taste":	{"NN","VB","VBP"},
"tastebud":	{"NN"},
"tasted":	{"VBD","VBN"},
"tasteful":	{"JJ"},
"tastefully":	{"RB"},
"tastefulness":	{"NN"},
"tasteless":	{"JJ","NN"},
"tastelessly":	{"RB"},
"tastelessness":	{"NN"},
"taster":	{"NN"},
"tasters":	{"NNS"},
"tastes":	{"NNS","VBZ"},
"tastier":	{"JJR"},
"tastiest":	{"JJS"},
"tastily":	{"RB"},
"tastiness":	{"NN"},
"tasting":	{"NN","VBG"},
"tastings":	{"NNS"},
"tasty":	{"JJ"},
"tat":	{"NN","VB","VBP"},
"tatahumara":	{"NN"},
"tatary":	{"NN"},
"tate":	{"NN"},
"tater":	{"NN"},
"tatou":	{"NN"},
"tatouay":	{"NN"},
"tats":	{"VBZ"},
"tatted":	{"VBD","VBN"},
"tatter":	{"NN","VB","VBP"},
"tatterdemalion":	{"JJ","NN"},
"tattered":	{"JJ","VBD","VBN"},
"tattering":	{"VBG"},
"tatters":	{"NNS","VBZ"},
"tattier":	{"JJR"},
"tattiest":	{"JJS"},
"tattily":	{"RB"},
"tattiness":	{"NN"},
"tatting":	{"NN","VBG"},
"tattle":	{"VB","VBP","NN"},
"tattle-tale":	{"NN"},
"tattle-tales":	{"NNS"},
"tattled":	{"VBD","VBN"},
"tattler":	{"NN"},
"tattlers":	{"NNS"},
"tattles":	{"VBZ"},
"tattletale":	{"NN"},
"tattletales":	{"NNS"},
"tattling":	{"VBG"},
"tattoo":	{"NN","VB","VBP"},
"tattooed":	{"VBD","VBN","JJ"},
"tattooing":	{"VBG"},
"tattoos":	{"NNS","VBZ"},
"tatty":	{"JJ"},
"tatu":	{"NN"},
"tatum":	{"NN"},
"tau":	{"NN"},
"taught":	{"VBD","VBN"},
"taunt":	{"VB","VBP","NN"},
"taunted":	{"VBD","VBN"},
"taunting":	{"VBG","NN"},
"tauntingly":	{"RB"},
"taunts":	{"VBZ","NNS"},
"tauon":	{"NN"},
"taupe":	{"JJ","NN"},
"taurine":	{"JJ","NN"},
"tauromachy":	{"NN"},
"taurotragus":	{"NN"},
"taurus":	{"NN"},
"taut":	{"JJ"},
"tauten":	{"VB","VBP"},
"tautened":	{"VBD","VBN"},
"tautening":	{"VBG"},
"tautens":	{"VBZ"},
"tauter":	{"JJR"},
"tautest":	{"JJS"},
"tautly":	{"RB"},
"tautness":	{"NN"},
"tautog":	{"NN"},
"tautoga":	{"NN"},
"tautogolabrus":	{"NN"},
"tautologic":	{"JJ"},
"tautological":	{"JJ"},
"tautologies":	{"NNS"},
"tautologous":	{"JJ"},
"tautology":	{"NN"},
"tavern":	{"NN"},
"taverns":	{"NNS"},
"taw":	{"NN"},
"tawdrier":	{"JJR"},
"tawdriest":	{"JJS"},
"tawdrily":	{"RB"},
"tawdriness":	{"NN"},
"tawdry":	{"JJ"},
"tawney":	{"NN"},
"tawniness":	{"NN"},
"tawny":	{"JJ"},
"tawse":	{"NN"},
"tax":	{"NN","VB","VBP"},
"tax-deductible":	{"JJ"},
"tax-deferred":	{"JJ"},
"tax-free":	{"JJ","RB"},
"taxability":	{"NN"},
"taxable":	{"JJ"},
"taxaceae":	{"NN"},
"taxales":	{"NNS"},
"taxation":	{"NN"},
"taxed":	{"VBD","VBN"},
"taxer":	{"NN"},
"taxes":	{"NNS","VBZ"},
"taxfree":	{"JJ"},
"taxi":	{"NN","VB","VBP"},
"taxi-cab":	{"NN"},
"taxi-ways":	{"NNS"},
"taxicab":	{"NN"},
"taxicabs":	{"NNS"},
"taxidea":	{"NN"},
"taxidermist":	{"NN"},
"taxidermists":	{"NNS"},
"taxidermy":	{"NN"},
"taxidriver":	{"NN"},
"taxied":	{"VBD","VBN"},
"taxies":	{"NNS","VBZ"},
"taxiing":	{"VBG"},
"taximan":	{"NN"},
"taximen":	{"NNS"},
"taximeter":	{"NN"},
"taxing":	{"JJ","VBG"},
"taxis":	{"NNS","VBZ"},
"taxistand":	{"NN"},
"taxiway":	{"NN"},
"taxiways":	{"NNS"},
"taxlow":	{"NN"},
"taxman":	{"NN"},
"taxmen":	{"NNS"},
"taxodiaceae":	{"NN"},
"taxodium":	{"NN"},
"taxon":	{"NN"},
"taxonomer":	{"NN"},
"taxonomic":	{"JJ"},
"taxonomical":	{"JJ"},
"taxonomically":	{"RB"},
"taxonomies":	{"NNS"},
"taxonomist":	{"NN"},
"taxonomists":	{"NNS"},
"taxonomy":	{"NN"},
"taxophytina":	{"NN"},
"taxopsida":	{"NN"},
"taxpayer":	{"NN"},
"taxpayers":	{"NNS"},
"taxpaying":	{"JJ"},
"taxus":	{"NN"},
"taxying":	{"VBG"},
"tay":	{"NN"},
"tay-sachs":	{"JJ"},
"tayalic":	{"NN"},
"tayassu":	{"NN"},
"tayassuidae":	{"NN"},
"taylor":	{"NN"},
"tayra":	{"NN"},
"taze":	{"VB","VBP"},
"tazed":	{"VBD","VBN"},
"tazes":	{"VBZ"},
"tazicef":	{"NN"},
"tazing":	{"VBG"},
"tbilisi":	{"NN"},
"tbit":	{"NN"},
"tc":	{"NN"},
"tce":	{"NN"},
"tchad":	{"NN"},
"tchaikovsky":	{"NN"},
"tchotchke":	{"NN"},
"tchotchkeleh":	{"NN"},
"tdt":	{"NN"},
"te":	{"NN"},
"tea":	{"NN"},
"tea-bag":	{"NN"},
"tea-bags":	{"NNS"},
"tea-break":	{"NN"},
"tea-breaks":	{"NNS"},
"tea-caddies":	{"NNS"},
"tea-caddy":	{"NN"},
"tea-chest":	{"NN"},
"tea-chests":	{"NNS"},
"tea-cloth":	{"NN"},
"tea-cloths":	{"NNS"},
"tea-cosies":	{"NNS"},
"tea-cosy":	{"NN"},
"tea-cup":	{"NN"},
"tea-cups":	{"NNS"},
"tea-drinking":	{"NN"},
"tea-leaf":	{"NN"},
"tea-leaves":	{"NNS"},
"tea-parties":	{"NNS"},
"tea-party":	{"NN"},
"tea-room":	{"NN"},
"tea-rooms":	{"NNS"},
"tea-scented":	{"JJ"},
"tea-service":	{"NN"},
"tea-services":	{"NNS"},
"tea-set":	{"NN"},
"tea-sets":	{"NNS"},
"tea-shop":	{"NN"},
"tea-shops":	{"NNS"},
"tea-strainer":	{"NN"},
"tea-table":	{"NN"},
"tea-things":	{"NNS"},
"tea-time":	{"NN"},
"tea-towel":	{"NN"},
"tea-towels":	{"NNS"},
"tea-tray":	{"NN"},
"tea-trays":	{"NNS"},
"tea-trolley":	{"NN"},
"tea-trolleys":	{"NNS"},
"tea-urn":	{"NN"},
"tea-urns":	{"NNS"},
"tea-wagon":	{"NN"},
"tea-wagons":	{"NNS"},
"teabag":	{"NN"},
"teabags":	{"NNS"},
"teaberry":	{"NN"},
"teacake":	{"NN"},
"teacakes":	{"NNS"},
"teacart":	{"NN"},
"teach":	{"VB","VBP"},
"Teach":	{"VB","VBP"},
"teach-in":	{"NN"},
"teach-ins":	{"NNS"},
"teachable":	{"JJ"},
"teacher":	{"NN"},
"teachers":	{"NNS"},
"teachership":	{"NN"},
"teaches":	{"VBZ"},
"teaching":	{"VBG","NN"},
"teachings":	{"NNS"},
"teachy":	{"JJ"},
"teacup":	{"NN"},
"teacupful":	{"NN"},
"teacups":	{"NNS"},
"teahouse":	{"NN"},
"teahouses":	{"NNS"},
"teak":	{"NN"},
"teakettle":	{"NN"},
"teakettles":	{"NNS"},
"teakwood":	{"NN"},
"teal":	{"NN","NNS"},
"team":	{"NN","VB","VBP"},
"team-mate":	{"NN"},
"team-mates":	{"NNS"},
"teamed":	{"VBD","VBN"},
"teaming":	{"VBG"},
"teammate":	{"NN"},
"teammates":	{"NNS"},
"teammember":	{"NN"},
"teammembers":	{"NNS"},
"teamplayer":	{"NN"},
"teams":	{"NNS","VBZ"},
"teamster":	{"NN"},
"teamsters":	{"NNS"},
"teamwork":	{"NN"},
"teamworking":	{"NN"},
"teapot":	{"NN"},
"teapots":	{"NNS"},
"tear":	{"VB","VBP","NN"},
"tear-jerker":	{"NN"},
"tear-jerkers":	{"NNS"},
"tearaway":	{"NN"},
"tearaways":	{"NNS"},
"teardrop":	{"NN"},
"teardrops":	{"NNS"},
"tearful":	{"JJ"},
"tearfully":	{"RB"},
"tearfulness":	{"NN"},
"teargas":	{"NN"},
"tearing":	{"VBG"},
"tearjerker":	{"NN"},
"tearjerkers":	{"NNS"},
"tearless":	{"JJ"},
"tearoom":	{"NN"},
"tearooms":	{"NNS"},
"tears":	{"NNS","VBZ"},
"tearsheet":	{"NN"},
"teary":	{"JJ"},
"teas":	{"NNS"},
"teasdale":	{"NN"},
"tease":	{"VB","VBP","NN"},
"teased":	{"VBD","VBN"},
"teasel":	{"NN"},
"teasels":	{"NNS"},
"teaser":	{"NN"},
"teasers":	{"NNS"},
"teases":	{"VBZ","NNS"},
"teashop":	{"NN"},
"teashops":	{"NNS"},
"teasing":	{"VBG","JJ"},
"teasingly":	{"RB"},
"teaspoon":	{"NN"},
"teaspoonful":	{"NN"},
"teaspoonfuls":	{"NNS"},
"teaspoons":	{"NNS"},
"teat":	{"NN"},
"teatime":	{"NN"},
"teats":	{"NNS"},
"teazel":	{"NN"},
"teazels":	{"NNS"},
"teazle":	{"NN"},
"teazles":	{"NNS"},
"tebaldi":	{"NN"},
"tebet":	{"NN"},
"tebibit":	{"NN"},
"tebibyte":	{"NN"},
"tebuthiuron":	{"NN"},
"tec":	{"NN"},
"tech":	{"NN"},
"techie":	{"NN"},
"techier":	{"JJR"},
"techies":	{"NNS"},
"techiest":	{"JJS"},
"techily":	{"RB"},
"techiness":	{"NN"},
"technetium":	{"NN"},
"technical":	{"JJ","NN"},
"technicalities":	{"NNS"},
"technicality":	{"NN"},
"technically":	{"RB"},
"technicals":	{"NNS"},
"technician":	{"NN"},
"technicians":	{"NNS"},
"technicolor":	{"NN"},
"technique":	{"NN"},
"techniques":	{"NNS"},
"techno":	{"NN"},
"technobabble":	{"NN"},
"technocracies":	{"NNS"},
"technocracy":	{"NN"},
"technocrat":	{"NN"},
"technocratic":	{"JJ"},
"technocrats":	{"NNS"},
"technological":	{"JJ"},
"technologically":	{"RB"},
"technologies":	{"NNS"},
"technologise":	{"VB","VBP"},
"technologist":	{"NN"},
"technologists":	{"NNS"},
"technologize":	{"VB","VBP"},
"technologized":	{"VBD","VBN"},
"technologizes":	{"VBZ"},
"technologizing":	{"VBG"},
"technology":	{"NN"},
"technolology":	{"NN"},
"technophile":	{"NN","JJ"},
"technophilia":	{"NN"},
"technophiliac":	{"JJ"},
"technophilic":	{"JJ"},
"technophobe":	{"NN"},
"technophobes":	{"NNS"},
"technophobia":	{"NN"},
"technophobic":	{"JJ"},
"techs":	{"NNS"},
"techy":	{"NN","JJ"},
"tecophilaeacea":	{"NN"},
"tectaria":	{"NN"},
"tectona":	{"NN"},
"tectonic":	{"JJ"},
"tectonics":	{"NN"},
"tecum":	{"FW"},
"tecumseh":	{"NN"},
"tecumtha":	{"NN"},
"tedder":	{"NN"},
"teddies":	{"NNS"},
"teddy":	{"NN"},
"teddy-bear":	{"NN"},
"teddy-bears":	{"NNS"},
"tedious":	{"JJ"},
"tediously":	{"RB"},
"tediousness":	{"NN"},
"tedium":	{"NN"},
"tee":	{"NN","VB","VBP"},
"teed":	{"VBD","VBN"},
"teeing":	{"VBG"},
"teem":	{"VB","VBP"},
"teemed":	{"VBD","VBN"},
"teeming":	{"VBG","JJ"},
"teemingness":	{"NN"},
"teems":	{"VBZ"},
"teen":	{"NN","JJ"},
"teen-age":	{"JJ"},
"teenage":	{"JJ"},
"teenaged":	{"JJ"},
"teenager":	{"NN"},
"teenagers":	{"NNS"},
"teenier":	{"JJR"},
"teeniest":	{"JJS"},
"teens":	{"NNS"},
"teensier":	{"JJR"},
"teensiest":	{"JJS"},
"teensy":	{"JJ"},
"teensy-weensier":	{"JJR"},
"teensy-weensiest":	{"JJS"},
"teensy-weensy":	{"JJ"},
"teeny":	{"JJ"},
"teeny-weenier":	{"JJR"},
"teeny-weeniest":	{"JJS"},
"teeny-weeny":	{"JJ"},
"teepee":	{"NN"},
"teepees":	{"NNS"},
"tees":	{"NNS","VBZ"},
"teeter":	{"VB","VBP"},
"teeter-totter":	{"NN","VB","VBP"},
"teeterboard":	{"NN"},
"teetered":	{"VBD","VBN"},
"teetering":	{"VBG"},
"teeters":	{"VBZ"},
"teeth":	{"NNS"},
"teethe":	{"VB","VBP"},
"teethed":	{"VBD","VBN"},
"teethes":	{"VBZ"},
"teething":	{"VBG","NN"},
"teetotal":	{"JJ"},
"teetotaler":	{"NN"},
"teetotalers":	{"NNS"},
"teetotaling":	{"NN"},
"teetotalism":	{"NN"},
"teetotalist":	{"NN"},
"teetotaller":	{"NN"},
"teetotallers":	{"NNS"},
"teetotum":	{"NN"},
"teff":	{"NN"},
"tefillin":	{"NN"},
"teg":	{"NN"},
"tegu":	{"NN"},
"tegucigalpa":	{"NN"},
"tegular":	{"JJ"},
"tegument":	{"NN"},
"teheran":	{"NN"},
"tehran":	{"NN"},
"teiid":	{"NN","JJ"},
"teju":	{"NN"},
"tekki":	{"NN"},
"tektite":	{"NN"},
"tektites":	{"NNS"},
"telamon":	{"NN"},
"telanthera":	{"NN"},
"telco":	{"NN"},
"tele-processing":	{"JJ"},
"tele-surgery":	{"NN"},
"telecast":	{"NN","VB","VBP","VBD","VBN"},
"telecasted":	{"VBD","VBN"},
"telecaster":	{"NN"},
"telecasting":	{"VBG"},
"telecasts":	{"NNS","VBZ"},
"telecines":	{"NNS"},
"telecom":	{"NN"},
"telecommerce":	{"NN"},
"telecommunication":	{"NN"},
"telecommunications":	{"NNS","NN"},
"telecommuter":	{"NN"},
"telecommuters":	{"NNS"},
"telecommuting":	{"NN"},
"telecoms":	{"NN","NNS"},
"teleconference":	{"NN","VB","VBP"},
"teleconferenced":	{"VBD","VBN"},
"teleconferences":	{"NNS","VBZ"},
"teleconferencing":	{"VBG","NN"},
"telecontroller":	{"NN"},
"telecopier":	{"NN"},
"telefax":	{"NN"},
"telefilm":	{"NN"},
"telefono":	{"NN","VBP","VB"},
"telegnosis":	{"NN"},
"telegnostic":	{"JJ"},
"telegram":	{"NN"},
"telegrams":	{"NNS"},
"telegraph":	{"NN","VB","VBP"},
"telegraphed":	{"VBD","VBN"},
"telegrapher":	{"NN"},
"telegraphers":	{"NNS"},
"telegraphese":	{"NN"},
"telegraphic":	{"JJ"},
"telegraphically":	{"RB"},
"telegraphing":	{"VBG"},
"telegraphist":	{"NN"},
"telegraphists":	{"NNS"},
"telegraphs":	{"NNS","VBZ"},
"telegraphy":	{"NN"},
"telekinesis":	{"NN"},
"telemann":	{"NN"},
"telemark":	{"NN"},
"telemarketer":	{"NN"},
"telemarketers":	{"NNS"},
"telemarketing":	{"NN"},
"telemeter":	{"NN","VB","VBP"},
"telemetering":	{"VBG"},
"telemeters":	{"NNS","VBZ"},
"telemetric":	{"JJ"},
"telemetrically":	{"RB"},
"telemetry":	{"NN"},
"telencephalon":	{"NN"},
"telenovela":	{"NN"},
"telenovelas":	{"NNS"},
"teleological":	{"JJ"},
"teleologist":	{"NN"},
"teleology":	{"NN"},
"teleost":	{"NN","JJ"},
"teleostan":	{"NN"},
"teleostei":	{"NN"},
"telepath":	{"NN"},
"telepathic":	{"JJ"},
"telepathically":	{"RB"},
"telepathise":	{"VB","VBP"},
"telepathist":	{"NN"},
"telepathize":	{"VB","VBP"},
"telepathy":	{"NN"},
"telephone":	{"NN","VB","VBP"},
"telephoned":	{"VBD","VBN"},
"telephoner":	{"NN"},
"telephones":	{"NNS","VBZ"},
"telephonic":	{"JJ"},
"telephoning":	{"VBG"},
"telephonist":	{"NN"},
"telephonists":	{"NNS"},
"telephony":	{"NN"},
"telephoto":	{"JJ"},
"telephotograph":	{"NN","VB","VBP"},
"telephotographic":	{"JJ"},
"telephotography":	{"NN"},
"teleport":	{"VB","VBP"},
"teleportation":	{"NN"},
"teleprinter":	{"NN"},
"teleprinters":	{"NNS"},
"teleprocessing":	{"NN"},
"teleprompter":	{"NN"},
"teleprompters":	{"NNS"},
"telerobotics":	{"NN"},
"telescope":	{"NN","VB","VBP"},
"telescoped":	{"VBD","VBN"},
"telescopes":	{"NNS","VBZ"},
"telescopic":	{"JJ"},
"telescopically":	{"RB"},
"telescoping":	{"VBG"},
"telescopist":	{"NN"},
"telescopium":	{"NN"},
"telescopy":	{"NN"},
"teleselling":	{"NN"},
"telesystem":	{"NN"},
"telesystems":	{"NNS"},
"telethermometer":	{"NN"},
"teletype":	{"NN"},
"teletypes":	{"NNS"},
"teletypewriter":	{"NN"},
"teletypewriters":	{"NNS"},
"televangelism":	{"NN"},
"televangelist":	{"NN"},
"televangelists":	{"NNS"},
"televise":	{"VB","VBP"},
"televised":	{"VBN","VBD"},
"televises":	{"VBZ"},
"televising":	{"VBG"},
"television":	{"NN"},
"televisions":	{"NNS"},
"teleworker":	{"NN"},
"teleworkers":	{"NNS"},
"teleworking":	{"NN"},
"telex":	{"NN","VB","VBP"},
"telexed":	{"VBD","VBN"},
"telexes":	{"NNS","VBZ"},
"telexing":	{"VBG"},
"telfer":	{"NN"},
"telferage":	{"NN"},
"teliospore":	{"NN"},
"tell":	{"VB","VBP"},
"tell-tale":	{"JJ"},
"teller":	{"NN"},
"tellers":	{"NNS"},
"tellies":	{"NNS"},
"tellima":	{"NN"},
"telling":	{"VBG","JJ","NN"},
"tellingly":	{"RB"},
"tellings":	{"NNS"},
"tells":	{"VBZ"},
"telltale":	{"JJ","NN"},
"tellurian":	{"JJ","NN"},
"telluric":	{"JJ"},
"telluride":	{"NN"},
"tellurium":	{"NN"},
"tellus":	{"NN"},
"telly":	{"NN"},
"telocentric":	{"JJ"},
"telomerase":	{"NN"},
"telomere":	{"NN"},
"telomeric":	{"JJ"},
"telopea":	{"NN"},
"telophase":	{"NN"},
"telos":	{"NN"},
"telosporidia":	{"NN"},
"telpher":	{"NN"},
"telpherage":	{"NN"},
"telsontail":	{"NN"},
"telugu":	{"NN"},
"temazepam":	{"NN"},
"temblor":	{"NN"},
"temblors":	{"NNS"},
"temerarious":	{"JJ"},
"temerity":	{"NN"},
"temnospondyli":	{"NN"},
"temp":	{"NN","VBP","VB"},
"tempeh":	{"NN"},
"temper":	{"NN","VB","VBP"},
"tempera":	{"NN"},
"temperament":	{"NN"},
"temperamental":	{"JJ"},
"temperamentally":	{"RB"},
"temperaments":	{"NNS"},
"temperance":	{"NN"},
"temperate":	{"JJ"},
"temperately":	{"RB"},
"temperateness":	{"NN"},
"temperature":	{"NN"},
"temperatures":	{"NNS"},
"tempered":	{"JJ","VBD","VBN"},
"tempering":	{"VBG"},
"tempers":	{"VBZ","NNS"},
"tempest":	{"NN"},
"tempests":	{"NNS"},
"tempestuous":	{"JJ"},
"tempestuously":	{"RB"},
"tempestuousness":	{"NN"},
"temping":	{"VBG"},
"templar":	{"NN"},
"template":	{"NN"},
"templates":	{"NNS"},
"temple":	{"NN"},
"temples":	{"NNS"},
"templet":	{"NN"},
"templetonia":	{"NN"},
"tempo":	{"NN"},
"temporal":	{"JJ"},
"temporalis":	{"NN"},
"temporality":	{"NN"},
"temporally":	{"RB"},
"temporalty":	{"NN"},
"temporarily":	{"RB"},
"temporariness":	{"NN"},
"temporary":	{"JJ","NN"},
"tempore":	{"RB"},
"temporise":	{"VB","VBP"},
"temporised":	{"VBD","VBN"},
"temporiser":	{"NN"},
"temporises":	{"VBZ"},
"temporising":	{"VBG","NN"},
"temporisingly":	{"RB"},
"temporize":	{"VB","VBP"},
"temporized":	{"VBD","VBN"},
"temporizer":	{"NN"},
"temporizes":	{"VBZ"},
"temporizing":	{"VBG","NN"},
"temporizingly":	{"RB"},
"tempos":	{"NNS"},
"tempra":	{"NN"},
"temps":	{"NNS","VBZ"},
"tempt":	{"VB","VBP"},
"temptable":	{"JJ"},
"temptation":	{"NN"},
"temptations":	{"NNS"},
"tempted":	{"VBD","VBN"},
"tempter":	{"NN"},
"tempters":	{"NNS"},
"tempting":	{"VBG","JJ"},
"temptingly":	{"RB"},
"temptingness":	{"NN"},
"temptress":	{"NN"},
"temptresses":	{"NNS"},
"tempts":	{"VBZ"},
"tempura":	{"NN"},
"temuco":	{"NN"},
"temujin":	{"NN"},
"ten":	{"CD","NN"},
"tenability":	{"NN"},
"tenable":	{"JJ"},
"tenableness":	{"NN"},
"tenacious":	{"JJ"},
"tenaciously":	{"RB"},
"tenaciousness":	{"NN"},
"tenacity":	{"NN"},
"tenancies":	{"NNS"},
"tenancy":	{"NN"},
"tenant":	{"NN","VB","VBP"},
"tenanted":	{"VBD","VBN"},
"tenanting":	{"VBG"},
"tenantries":	{"NNS"},
"tenantry":	{"NN"},
"tenants":	{"NNS","VBZ"},
"tench":	{"NN","NNS"},
"tend":	{"VB","VBP"},
"tended":	{"VBD","VBN"},
"tendencially":	{"RB"},
"tendencies":	{"NNS"},
"tendencious":	{"JJ"},
"tendenciously":	{"RB"},
"tendenciousness":	{"NN"},
"tendency":	{"NN"},
"tendentially":	{"RB"},
"tendentious":	{"JJ"},
"tendentiously":	{"RB"},
"tendentiousness":	{"NN"},
"tender":	{"JJ","NN","VB","VBP"},
"tendered":	{"VBD","VBN"},
"tenderer":	{"JJR"},
"tenderest":	{"JJS"},
"tenderfoot":	{"NN"},
"tendergreen":	{"NN"},
"tenderhearted":	{"JJ"},
"tenderheartedness":	{"NN"},
"tendering":	{"VBG","NN"},
"tenderisation":	{"NN"},
"tenderise":	{"VB","VBP"},
"tenderised":	{"VBD","VBN"},
"tenderiser":	{"NN"},
"tenderisers":	{"NNS"},
"tenderises":	{"VBZ"},
"tenderising":	{"VBG"},
"tenderization":	{"NN"},
"tenderize":	{"VB","VBP"},
"tenderized":	{"VBD","VBN"},
"tenderizer":	{"NN"},
"tenderizers":	{"NNS"},
"tenderizes":	{"VBZ"},
"tenderizing":	{"VBG"},
"tenderloin":	{"NN"},
"tenderly":	{"RB"},
"tenderness":	{"NN"},
"tenders":	{"NNS","VBZ"},
"tending":	{"VBG"},
"tendinitis":	{"NN"},
"tendinous":	{"JJ"},
"tendon":	{"NN"},
"tendonitis":	{"NN"},
"tendons":	{"NNS"},
"tendosynovitis":	{"NN"},
"tendrac":	{"NN"},
"tendril":	{"NN"},
"tendrils":	{"NNS"},
"tends":	{"VBZ"},
"tenebrific":	{"JJ"},
"tenebrionid":	{"NN"},
"tenebrionidae":	{"NN"},
"tenebrious":	{"JJ"},
"tenebriousness":	{"NN"},
"tenebrosity":	{"NN"},
"tenebrous":	{"JJ"},
"tenebrousness":	{"NN"},
"tenement":	{"NN"},
"tenements":	{"NNS"},
"tenesmus":	{"NN"},
"tenet":	{"NN"},
"tenets":	{"NNS"},
"tenfold":	{"RB","JJ"},
"tenge":	{"NN"},
"tenia":	{"NN"},
"tenner":	{"NN"},
"tennessean":	{"NN"},
"tennessee":	{"NN"},
"tennis":	{"NN"},
"tenno":	{"NN"},
"tennyson":	{"NN"},
"tenon":	{"NN"},
"tenonitis":	{"NN"},
"tenor":	{"NN","JJ"},
"tenoretic":	{"NN"},
"tenorist":	{"NN"},
"tenormin":	{"NN"},
"tenoroon":	{"NN"},
"tenors":	{"NNS"},
"tenosynovitis":	{"NN"},
"tenpence":	{"NN"},
"tenpin":	{"NN"},
"tenpins":	{"NNS"},
"tenpounder":	{"NN"},
"tenrec":	{"NN"},
"tenrecidae":	{"NN"},
"tens":	{"NNS"},
"tense":	{"JJ","NN","VBP","VB"},
"tensed":	{"VBD","VBN"},
"tensely":	{"RB"},
"tenseness":	{"NN"},
"tenser":	{"JJR"},
"tenses":	{"VBZ","NNS"},
"tensest":	{"JJS"},
"tensile":	{"JJ"},
"tensimeter":	{"NN"},
"tensing":	{"VBG"},
"tensiometer":	{"NN"},
"tension":	{"NN"},
"tensional":	{"JJ"},
"tensionless":	{"JJ"},
"tensions":	{"NNS"},
"tensity":	{"NN"},
"tensor":	{"NN"},
"tenspot":	{"NN"},
"tent":	{"NN","VB","VBP"},
"tent-fly":	{"NN"},
"tent-peg":	{"NN"},
"tent-pole":	{"NN"},
"tent-poles":	{"NNS"},
"tentacle":	{"NN"},
"tentacled":	{"JJ"},
"tentacles":	{"NNS"},
"tentacular":	{"JJ"},
"tentaculata":	{"NN"},
"tentative":	{"JJ"},
"tentatively":	{"RB"},
"tentativeness":	{"NN"},
"tented":	{"VBD","VBN","JJ"},
"tenter":	{"NN"},
"tenterhook":	{"NN"},
"tenterhooks":	{"NNS"},
"tenth":	{"NN","JJ"},
"tenthly":	{"RB"},
"tenthredinidae":	{"NN"},
"tenths":	{"NNS"},
"tenting":	{"VBG"},
"tentmaker":	{"NN"},
"tentorium":	{"NN"},
"tentpole":	{"NN"},
"tentpoles":	{"NNS"},
"tents":	{"NNS","VBZ"},
"tenuity":	{"NN"},
"tenuous":	{"JJ"},
"tenuously":	{"RB"},
"tenuousness":	{"NN"},
"tenure":	{"NN"},
"tenured":	{"JJ"},
"tepal":	{"NN"},
"tepee":	{"NN"},
"tepees":	{"NNS"},
"tephrosia":	{"NN"},
"tepic":	{"NN"},
"tepid":	{"JJ"},
"tepidity":	{"NN"},
"tepidly":	{"RB"},
"tepidness":	{"NN"},
"teppanyaki":	{"NN"},
"tepper":	{"NN"},
"tequila":	{"NN"},
"tequilas":	{"NNS"},
"tera":	{"NN"},
"terabit":	{"NN"},
"terabyte":	{"NN"},
"teraflop":	{"NN"},
"teraflops":	{"NNS"},
"terahertz":	{"NN","NNS"},
"teratogen":	{"NN"},
"teratogenesis":	{"NN"},
"teratogenic":	{"JJ"},
"teratologies":	{"NNS"},
"teratology":	{"NN"},
"teratoma":	{"NN"},
"terazosin":	{"NN"},
"terbinafine":	{"NN"},
"terbium":	{"NN"},
"terce":	{"NN"},
"tercel":	{"NN"},
"tercelet":	{"NN"},
"tercentenaries":	{"NNS"},
"tercentenary":	{"NN"},
"tercentennial":	{"NN","JJ"},
"tercet":	{"NN"},
"terebella":	{"NN"},
"terebellidae":	{"NN"},
"terebinth":	{"NN"},
"teredines":	{"NNS"},
"teredinid":	{"NN"},
"teredinidae":	{"NN"},
"teredo":	{"NN"},
"teredos":	{"NNS"},
"terefah":	{"JJ"},
"terence":	{"NN"},
"teres":	{"NN"},
"teresa":	{"NN"},
"tereshkova":	{"NN"},
"terete":	{"JJ"},
"tergiversant":	{"NN"},
"tergiversate":	{"VB","VBP"},
"tergiversated":	{"VBD","VBN"},
"tergiversates":	{"VBZ"},
"tergiversating":	{"VBG"},
"tergiversation":	{"NN"},
"tergiversator":	{"NN"},
"tergiversatory":	{"JJ"},
"teriyaki":	{"NN","JJ"},
"term":	{"NN","VB","VBP"},
"termagant":	{"NN"},
"termed":	{"VBD","VBN"},
"termer":	{"NN"},
"terminable":	{"JJ"},
"terminal":	{"JJ","NN"},
"terminally":	{"RB"},
"terminals":	{"NNS"},
"terminate":	{"VB","VBP"},
"terminated":	{"VBD","VBN"},
"terminates":	{"VBZ"},
"terminating":	{"VBG"},
"termination":	{"NN"},
"terminations":	{"NNS"},
"terminative":	{"JJ"},
"terminator":	{"NN"},
"terminators":	{"NNS"},
"terming":	{"VBG"},
"termini":	{"NNS"},
"terminological":	{"JJ"},
"terminologically":	{"RB"},
"terminologies":	{"NNS"},
"terminology":	{"NN"},
"terminus":	{"NN"},
"termite":	{"NN"},
"termites":	{"NNS"},
"termitidae":	{"NN"},
"terms":	{"NNS","VBZ"},
"tern":	{"NN"},
"ternary":	{"JJ"},
"ternate":	{"JJ"},
"ternately":	{"RB"},
"ternational":	{"JJ"},
"ternion":	{"NN"},
"terns":	{"NNS"},
"terpene":	{"NN"},
"terpenes":	{"NNS"},
"terpsichore":	{"NN"},
"terpsichorean":	{"JJ"},
"terra":	{"NN"},
"terrace":	{"NN","VB","VBP"},
"terraced":	{"VBN","JJ","VBD"},
"terraces":	{"NNS","VBZ"},
"terracing":	{"VBG","NN"},
"terrain":	{"NN"},
"terrains":	{"NNS"},
"terram":	{"FW"},
"terramycin":	{"NN"},
"terranomics":	{"NNS"},
"terrapene":	{"NN"},
"terrapin":	{"NN"},
"terrapins":	{"NNS"},
"terraria":	{"NNS"},
"terrarium":	{"NN"},
"terrariums":	{"NNS"},
"terrazzo":	{"NN"},
"terrene":	{"JJ"},
"terreplein":	{"NN"},
"terrestial":	{"JJ"},
"terrestrial":	{"JJ"},
"terrestrialisation":	{"NN"},
"terrestriality":	{"NN"},
"terrestrially":	{"RB"},
"terrible":	{"JJ"},
"terribleness":	{"NN"},
"terribly":	{"RB"},
"terrier":	{"NN"},
"terriers":	{"NNS"},
"terrietia":	{"NN"},
"terrific":	{"JJ"},
"terrifically":	{"RB"},
"terrified":	{"JJ","VBD","VBN"},
"terrifies":	{"VBZ"},
"terrify":	{"VB","VBP"},
"terrifying":	{"JJ","VBG"},
"terrifyingly":	{"RB"},
"terrine":	{"NN"},
"territoire":	{"FW"},
"territorial":	{"JJ","NN"},
"territorialisation":	{"NN"},
"territorialise":	{"VB","VBP"},
"territorialised":	{"VBD","VBN"},
"territorialises":	{"VBZ"},
"territorialising":	{"VBG"},
"territoriality":	{"NN"},
"territorialization":	{"NN"},
"territorialize":	{"VB","VBP"},
"territorialized":	{"VBD","VBN"},
"territorializes":	{"VBZ"},
"territorializing":	{"VBG"},
"territorially":	{"RB"},
"territorials":	{"NNS"},
"territories":	{"NNS"},
"territory":	{"NN"},
"terror":	{"NN"},
"terror-stricken":	{"JJ"},
"terror-struck":	{"JJ"},
"terrorisation":	{"NN"},
"terrorise":	{"VB","VBP"},
"terrorised":	{"VBD","VBN"},
"terrorises":	{"VBZ"},
"terrorising":	{"VBG"},
"terrorism":	{"NN"},
"terrorist":	{"NN"},
"terroristic":	{"JJ"},
"terrorists":	{"NNS"},
"terrorization":	{"NN"},
"terrorize":	{"VB","VBP"},
"terrorized":	{"VBD","VBN"},
"terrorizes":	{"VBZ"},
"terrorizing":	{"VBG"},
"terrors":	{"NNS"},
"terry":	{"NN"},
"terrycloth":	{"NN"},
"terse":	{"JJ"},
"tersely":	{"RB"},
"terseness":	{"NN"},
"tertian":	{"JJ"},
"tertiary":	{"JJ"},
"tertigravida":	{"NN"},
"tertullian":	{"NN"},
"terzetti":	{"NNS"},
"terzetto":	{"NN"},
"terzettos":	{"NNS"},
"tessella":	{"NN"},
"tessellate":	{"VB","VBP"},
"tessellated":	{"JJ","VBD","VBN"},
"tessellates":	{"VBZ"},
"tessellating":	{"VBG"},
"tessellation":	{"NN"},
"tessera":	{"NN"},
"tesseract":	{"NN"},
"tessin":	{"NN"},
"test":	{"NN","VB","VBP"},
"test-bed":	{"NN"},
"test-drive":	{"VB","VBP"},
"test-driven":	{"VBN"},
"test-drives":	{"VBZ"},
"test-driving":	{"VBG"},
"test-drove":	{"VBD"},
"test-market":	{"VB","VBP"},
"test-marketed":	{"VBD","VBN"},
"test-marketing":	{"VBG"},
"test-markets":	{"VBZ"},
"test-tube":	{"NN"},
"testa":	{"NN"},
"testacea":	{"NN"},
"testacean":	{"NN"},
"testaceous":	{"JJ"},
"testament":	{"NN"},
"testamentary":	{"JJ"},
"testaments":	{"NNS"},
"testate":	{"JJ","NN"},
"testator":	{"NN"},
"testatrix":	{"NN"},
"testbed":	{"NN"},
"testcross":	{"NN"},
"tested":	{"VBN","VBD"},
"testee":	{"NN"},
"testees":	{"NNS"},
"tester":	{"NN"},
"testers":	{"NNS"},
"testes":	{"NNS"},
"testicle":	{"NN"},
"testicles":	{"NNS"},
"testicular":	{"JJ"},
"testier":	{"JJR"},
"testiere":	{"NN"},
"testiest":	{"JJS"},
"testified":	{"VBD","VBN"},
"testifier":	{"NN"},
"testifies":	{"VBZ","NNS"},
"testify":	{"VB","VBP"},
"testifying":	{"VBG"},
"testily":	{"RB"},
"testimonial":	{"NN"},
"testimonials":	{"NNS"},
"testimonies":	{"NNS"},
"testimony":	{"NN"},
"testiness":	{"NN"},
"testing":	{"VBG","NN","JJ"},
"testis":	{"NN"},
"testosterone":	{"NN"},
"tests":	{"NNS","VBZ"},
"testudinata":	{"NN"},
"testudines":	{"NNS"},
"testudinidae":	{"NN"},
"testudo":	{"NN"},
"testy":	{"JJ"},
"tet":	{"NN"},
"tetanic":	{"JJ"},
"tetanilla":	{"NN"},
"tetanus":	{"NN"},
"tetany":	{"NN"},
"tetartanopia":	{"NN"},
"tetchier":	{"JJR"},
"tetchiest":	{"JJS"},
"tetchily":	{"RB"},
"tetchiness":	{"NN"},
"tetchy":	{"JJ"},
"tete-a-tete":	{"NN","RB"},
"teth":	{"NN"},
"tether":	{"NN","VB","VBP"},
"tetherball":	{"NN"},
"tethered":	{"VBD","VBN"},
"tethering":	{"VBG"},
"tethers":	{"NNS","VBZ"},
"tethyidae":	{"NN"},
"teton":	{"NN"},
"tetra":	{"NN"},
"tetrabromo":	{"NN"},
"tetracaine":	{"NN"},
"tetrachlorethylene":	{"NN"},
"tetrachloride":	{"NN"},
"tetrachloroethylene":	{"NN"},
"tetrachloromethane":	{"NN"},
"tetrachromacy":	{"NN"},
"tetrachromat":	{"NN"},
"tetrachromate":	{"NN"},
"tetrachromates":	{"NNS"},
"tetrachromatic":	{"JJ"},
"tetrachromats":	{"NNS"},
"tetraclinis":	{"NN"},
"tetracycline":	{"NN"},
"tetrad":	{"NN"},
"tetrafluoroethylene":	{"NN"},
"tetragon":	{"NN"},
"tetragonal":	{"JJ"},
"tetragonia":	{"NN"},
"tetragoniaceae":	{"NN"},
"tetragonurus":	{"NN"},
"tetragram":	{"NN"},
"tetragrammaton":	{"NN"},
"tetrahalide":	{"NN"},
"tetrahalides":	{"NNS"},
"tetrahedron":	{"NN"},
"tetrahydrocannabinol":	{"NN"},
"tetrahymena":	{"NN"},
"tetraiodothyronine":	{"NN"},
"tetralogy":	{"NN"},
"tetramerous":	{"JJ"},
"tetrameter":	{"NN"},
"tetramethyldiarsine":	{"NN"},
"tetrametric":	{"JJ"},
"tetraneuris":	{"NN"},
"tetranychid":	{"NN"},
"tetranychidae":	{"NN"},
"tetrao":	{"NN"},
"tetraodontidae":	{"NN"},
"tetraonidae":	{"NN"},
"tetrapod":	{"NN"},
"tetrapturus":	{"NN"},
"tetrasaccharide":	{"NN"},
"tetraskele":	{"NN"},
"tetraskelion":	{"NN"},
"tetrasodium":	{"NN"},
"tetrasporangium":	{"NN"},
"tetraspore":	{"NN"},
"tetravalent":	{"JJ"},
"tetrazzini":	{"NN"},
"tetri":	{"NN"},
"tetris":	{"NNS"},
"tetrode":	{"NN"},
"tetrodotoxin":	{"NN"},
"tetrose":	{"NN"},
"tetroxide":	{"NN"},
"tetryl":	{"NN"},
"tetterwort":	{"NN"},
"tettigoniid":	{"NN"},
"tettigoniidae":	{"NN"},
"teucrium":	{"NN"},
"teutonic":	{"JJ"},
"tevere":	{"NN"},
"tevet":	{"NN"},
"tewkesbury":	{"NN"},
"texarkana":	{"NN"},
"text":	{"NN","VB","VBP"},
"textbook":	{"NN","JJ"},
"textbooks":	{"NNS"},
"texted":	{"VBD","VBN"},
"textile":	{"NN","JJ"},
"textiles":	{"NNS"},
"texting":	{"VBG","NN"},
"texts":	{"NNS","VBZ"},
"textual":	{"JJ"},
"texturally":	{"RB"},
"texture":	{"NN","VB","VBP"},
"textured":	{"JJ","VBD","VBN"},
"textureless":	{"JJ"},
"textures":	{"VBZ","NNS"},
"texturing":	{"VBG"},
"thackeray":	{"NN"},
"thaddaeus":	{"NN"},
"thailand":	{"NN"},
"thalamocortical":	{"JJ"},
"thalamus":	{"NN"},
"thalarctos":	{"NNS"},
"thalassaemia":	{"NN"},
"thalassemia":	{"NN"},
"thalassic":	{"JJ"},
"thalassoma":	{"NN"},
"thalia":	{"NN"},
"thaliacea":	{"NN"},
"thalictrum":	{"NN"},
"thalidomide":	{"NN","JJ"},
"thalidone":	{"NN"},
"thallium":	{"NN"},
"thalloid":	{"JJ"},
"thallophyta":	{"NN"},
"thallophyte":	{"NN"},
"thallophytic":	{"JJ"},
"thallus":	{"NN"},
"thalmencephalon":	{"NN"},
"thalweg":	{"NN"},
"thames":	{"NNS"},
"thammuz":	{"NN"},
"thamnophilus":	{"NN"},
"thamnophis":	{"NN"},
"than":	{"IN","RB","CC"},
"thanatology":	{"NN"},
"thanatophobia":	{"NN"},
"thanatopsis":	{"NN"},
"thane":	{"NN"},
"thaneship":	{"NN"},
"thank":	{"VB","VBP"},
"thank-you":	{"NN"},
"thank-yous":	{"NNS"},
"thanked":	{"VBD","VBN"},
"thankful":	{"JJ"},
"thankfully":	{"RB"},
"thankfulness":	{"NN"},
"thanking":	{"VBG"},
"thankless":	{"JJ"},
"thanklessly":	{"RB"},
"thanklessness":	{"NN"},
"thanks":	{"NNS","VBZ","UH"},
"thanksgiving":	{"NN"},
"thanksgivings":	{"NNS"},
"thar":	{"RB","NN"},
"tharp":	{"NN"},
"thars":	{"NNS"},
"that":	{"CC","WDT","DT","RB","PRP","IN"},
"thataway":	{"RB"},
"thatch":	{"NN","VB","VBP"},
"thatched":	{"VBD","VBN","JJ"},
"thatcher":	{"NN"},
"thatcherian":	{"JJ"},
"thatcherism":	{"NN"},
"thatcherite":	{"NN"},
"thatchers":	{"NNS"},
"thatches":	{"NNS","VBZ"},
"thatching":	{"VBG","NN"},
"thaumatolatry":	{"NN"},
"thaumaturge":	{"NN"},
"thaumaturgist":	{"NN"},
"thaumaturgy":	{"NN"},
"thaw":	{"VB","VBP","NN"},
"thawed":	{"VBD","VBN"},
"thawing":	{"VBG"},
"thaws":	{"NNS","VBZ"},
"the":	{"DT"},
"theaceae":	{"NNS"},
"theaceous":	{"JJ"},
"theales":	{"NN"},
"theanthropism":	{"NN"},
"theare":	{"NN"},
"thease":	{"NN"},
"theat":	{"NN"},
"theater":	{"NN"},
"theatergoer":	{"NN"},
"theatergoers":	{"NNS"},
"theatergoing":	{"JJ"},
"theaters":	{"NNS"},
"theatre":	{"NN"},
"theatre-goer":	{"NN"},
"theatre-goers":	{"NNS"},
"theatregoer":	{"NN"},
"theatregoers":	{"NNS"},
"theatres":	{"NNS"},
"theatrical":	{"JJ","NN"},
"theatricality":	{"NN"},
"theatrically":	{"RB"},
"theatricals":	{"NNS"},
"theca":	{"NN"},
"thecodont":	{"NN"},
"thecodontia":	{"NN"},
"thee":	{"PRP"},
"theelin":	{"NN"},
"theft":	{"NN"},
"thefts":	{"NNS"},
"their":	{"PRP$"},
"theirs":	{"PRP"},
"theism":	{"NN"},
"theist":	{"NN","JJ"},
"theistic":	{"JJ"},
"theistical":	{"JJ"},
"theistically":	{"RB"},
"thelarche":	{"NN"},
"thelephoraceae":	{"NN"},
"thelypteridaceae":	{"NN"},
"thelypteris":	{"NN"},
"them":	{"PRP","DT"},
"thematic":	{"JJ"},
"thematically":	{"RB"},
"theme":	{"NN"},
"themed":	{"JJ"},
"themes":	{"NNS"},
"themselves":	{"PRP"},
"then":	{"RB","IN","JJ"},
"thenal":	{"JJ"},
"thenar":	{"JJ","NN"},
"thence":	{"RB"},
"thenceforth":	{"RB"},
"thenceforward":	{"RB"},
"theobid":	{"NN"},
"theobroma":	{"NN"},
"theocracies":	{"NNS"},
"theocracy":	{"NN"},
"theocratic":	{"JJ"},
"theodicy":	{"NN"},
"theodolite":	{"NN"},
"theodosian":	{"JJ"},
"theodosius":	{"NN"},
"theogony":	{"NN"},
"theologian":	{"NN"},
"theologians":	{"NNS"},
"theological":	{"JJ"},
"theologically":	{"RB"},
"theologies":	{"NNS"},
"theologisation":	{"NN"},
"theologise":	{"VB","VBP"},
"theologised":	{"VBD","VBN"},
"theologiser":	{"NN"},
"theologises":	{"VBZ"},
"theologising":	{"VBG"},
"theologist":	{"NN"},
"theologization":	{"NN"},
"theologize":	{"VB","VBP"},
"theologized":	{"VBD","VBN"},
"theologizer":	{"NN"},
"theologizes":	{"VBZ"},
"theologizing":	{"VBG"},
"theology":	{"NN"},
"theophany":	{"NN"},
"theophrastaceae":	{"NN"},
"theophrastus":	{"NN"},
"theophylline":	{"NN"},
"theopylline":	{"NN"},
"theorem":	{"NN"},
"theorems":	{"NNS"},
"theoretic":	{"JJ"},
"theoretical":	{"JJ"},
"theoretically":	{"RB"},
"theoretician":	{"NN"},
"theoreticians":	{"NNS"},
"theoretics":	{"NN","NNS"},
"theories":	{"NNS"},
"theorisation":	{"NN"},
"theorise":	{"VB","VBP"},
"theorised":	{"VBD","VBN"},
"theoriser":	{"NN"},
"theorises":	{"VBZ"},
"theorising":	{"VBG","NN"},
"theorist":	{"NN"},
"theorists":	{"NNS"},
"theorization":	{"NN"},
"theorize":	{"VB","VBP"},
"theorized":	{"VBD","VBN"},
"theorizer":	{"NN"},
"theorizes":	{"VBZ"},
"theorizing":	{"VBG","NN"},
"theory":	{"NN"},
"theosophical":	{"JJ"},
"theosophism":	{"NN"},
"theosophist":	{"NN"},
"theosophy":	{"NN"},
"therapeutic":	{"JJ"},
"therapeutical":	{"JJ"},
"therapeutically":	{"RB"},
"therapeutics":	{"NN"},
"theraphosidae":	{"NN"},
"therapies":	{"NNS"},
"therapist":	{"NN"},
"therapists":	{"NNS"},
"therapsid":	{"NN"},
"therapsida":	{"NNS"},
"therapy":	{"NN"},
"there":	{"EX","RB","UH"},
"thereabout":	{"RB"},
"thereabouts":	{"RB"},
"thereafter":	{"RB"},
"thereby":	{"RB"},
"therefor":	{"RB"},
"therefore":	{"RB"},
"therefrom":	{"RB"},
"therein":	{"RB"},
"thereinafter":	{"RB"},
"theremin":	{"NN"},
"thereness":	{"NN"},
"thereof":	{"RB"},
"thereon":	{"RB"},
"theresa":	{"NN"},
"thereto":	{"RB"},
"theretofore":	{"RB"},
"thereunder":	{"RB"},
"thereupon":	{"RB"},
"therewith":	{"RB"},
"therewithal":	{"RB"},
"theridiidae":	{"NNS"},
"therm":	{"NN"},
"thermal":	{"JJ","NN"},
"thermalgesia":	{"NN"},
"thermally":	{"RB"},
"thermals":	{"NNS"},
"thermel":	{"NN"},
"thermic":	{"JJ"},
"thermidor":	{"NN"},
"thermion":	{"NN"},
"thermionic":	{"JJ"},
"thermionics":	{"NN"},
"thermistor":	{"NN"},
"thermoacidophile":	{"NN"},
"thermobia":	{"NN"},
"thermocautery":	{"NN"},
"thermochemistry":	{"NN"},
"thermocoagulation":	{"NN"},
"thermocouple":	{"NN"},
"thermocouples":	{"NNS"},
"thermodynamic":	{"JJ"},
"thermodynamical":	{"JJ"},
"thermodynamically":	{"RB"},
"thermodynamics":	{"NN"},
"thermoelectric":	{"JJ"},
"thermoelectrical":	{"JJ"},
"thermoelectricity":	{"NN"},
"thermoform":	{"NN","VB","VBP"},
"thermoformed":	{"VBD","VBN"},
"thermoforming":	{"VBG"},
"thermoforms":	{"VBZ"},
"thermogram":	{"NN"},
"thermograph":	{"NN"},
"thermography":	{"NN"},
"thermogravimeter":	{"NN"},
"thermogravimetric":	{"JJ"},
"thermogravimetry":	{"NN"},
"thermohydrometer":	{"NN"},
"thermohydrometric":	{"JJ"},
"thermojunction":	{"NN"},
"thermolabile":	{"JJ"},
"thermometer":	{"NN"},
"thermometers":	{"NNS"},
"thermometric":	{"JJ"},
"thermometrograph":	{"NN"},
"thermometry":	{"NN"},
"thermonuclear":	{"JJ"},
"thermopile":	{"NN"},
"thermoplastic":	{"JJ","NN"},
"thermoplastics":	{"NNS"},
"thermopsis":	{"NN"},
"thermopylae":	{"NN"},
"thermoreceptor":	{"NN"},
"thermoregulator":	{"NN"},
"thermos":	{"NN"},
"thermoses":	{"NNS"},
"thermoset":	{"JJ"},
"thermosetting":	{"JJ"},
"thermosphere":	{"NN"},
"thermostat":	{"NN"},
"thermostated":	{"VBN"},
"thermostatic":	{"JJ"},
"thermostatically":	{"RB"},
"thermostatics":	{"NN"},
"thermostats":	{"NNS"},
"thermotherapy":	{"NN"},
"thermotropism":	{"NN"},
"therms":	{"NNS"},
"theropod":	{"NN"},
"theropoda":	{"NN"},
"thesauri":	{"NNS"},
"thesaurus":	{"NN"},
"thesauruses":	{"NNS"},
"these":	{"DT","PRP"},
"theses":	{"NNS"},
"thesis":	{"NN"},
"thespesia":	{"NN"},
"thespian":	{"JJ","NN"},
"thespians":	{"NNS"},
"thespis":	{"NN"},
"thessalia":	{"NN"},
"thessalian":	{"NN"},
"thessalonian":	{"NN"},
"thessalonica":	{"NN"},
"thessaloniki":	{"NN"},
"thessaly":	{"NN"},
"theta":	{"NN"},
"theurgy":	{"NN"},
"thevetia":	{"NN"},
"they":	{"PRP"},
"thiabendazole":	{"NN"},
"thiamin":	{"NN"},
"thiamine":	{"NN"},
"thiazide":	{"NN"},
"thiazine":	{"NN"},
"thibet":	{"NN"},
"thick":	{"JJ","RB","NN"},
"thick-headed":	{"JJ"},
"thick-set":	{"JJ"},
"thick-skinned":	{"JJ"},
"thicken":	{"VB","VBP"},
"thickened":	{"VBD","VBN"},
"thickener":	{"NN"},
"thickeners":	{"NNS"},
"thickening":	{"NN","VBG"},
"thickens":	{"VBZ"},
"thicker":	{"JJR"},
"thickest":	{"JJS"},
"thicket":	{"NN"},
"thickets":	{"NNS"},
"thickhead":	{"NN"},
"thickheaded":	{"JJ"},
"thickheadedness":	{"NN"},
"thickly":	{"RB"},
"thickness":	{"NN"},
"thicknesses":	{"NNS"},
"thickset":	{"JJ"},
"thickspread":	{"JJ"},
"thief":	{"NN"},
"thielavia":	{"NNS"},
"thieve":	{"VB","VBP"},
"thieved":	{"VBD","VBN"},
"thievery":	{"NN"},
"thieves":	{"NNS","VBZ"},
"thieving":	{"VBG","NN","JJ"},
"thievish":	{"JJ"},
"thievishly":	{"RB"},
"thievishness":	{"NN"},
"thigh":	{"NN"},
"thigh-bone":	{"NN"},
"thigh-bones":	{"NNS"},
"thighbone":	{"NN"},
"thighbones":	{"NNS"},
"thighs":	{"NNS"},
"thill":	{"NN"},
"thills":	{"NNS"},
"thimble":	{"NN"},
"thimbleberry":	{"NN"},
"thimbleful":	{"NN"},
"thimblefuls":	{"NNS"},
"thimblerig":	{"NN","VB","VBP"},
"thimblerigged":	{"VBD","VBN"},
"thimblerigging":	{"VBG"},
"thimblerigs":	{"NNS","VBZ"},
"thimbles":	{"NNS"},
"thimbleweed":	{"NN"},
"thimerosal":	{"NN"},
"thin":	{"JJ","RB","VB","VBP"},
"thin-skinned":	{"JJ"},
"thine":	{"PRP"},
"thing":	{"NN"},
"thing-in-itself":	{"NN"},
"thingamabob":	{"NN"},
"thingamajig":	{"NN"},
"thingmabob":	{"NN"},
"thingmajig":	{"NN"},
"things":	{"NNS"},
"thingumabob":	{"NN"},
"thingumajig":	{"NN"},
"thingummy":	{"NN"},
"think":	{"VBP","VB","NN"},
"think-alike":	{"JJ"},
"think-tank":	{"NN"},
"think-tanks":	{"NNS"},
"thinkable":	{"JJ"},
"thinker":	{"NN"},
"thinkers":	{"NNS"},
"thinking":	{"VBG","NN","JJ"},
"thinks":	{"VBZ"},
"thinly":	{"RB"},
"thinned":	{"VBD","VBN"},
"thinner":	{"JJR","NN"},
"thinners":	{"NN"},
"thinness":	{"NN"},
"thinnest":	{"JJS"},
"thinning":	{"VBG","JJ"},
"thins":	{"VBZ"},
"thiobacillus":	{"NNS"},
"thiobacteria":	{"NN"},
"thiobacteriaceae":	{"NN"},
"thiocyanate":	{"NN"},
"thiocyanate-perchlorate-fluoro":	{"NN"},
"thiodiphenylamine":	{"NN"},
"thioguanine":	{"NN"},
"thiopental":	{"NN"},
"thioridazine":	{"NN"},
"thiosulfil":	{"NN"},
"thiotepa":	{"NN"},
"thiothixene":	{"NN"},
"thiouracil":	{"NN"},
"third":	{"JJ","NN"},
"third-class":	{"JJ","RB","NN"},
"third-party":	{"JJ"},
"third-rate":	{"JJ"},
"thirdhand":	{"NN"},
"thirdly":	{"RB"},
"thirds":	{"NNS"},
"thirst":	{"NN","VB","VBP"},
"thirsted":	{"VBD","VBN"},
"thirstier":	{"JJR"},
"thirstiest":	{"JJS"},
"thirstily":	{"RB"},
"thirstiness":	{"NN"},
"thirsting":	{"VBG"},
"thirsts":	{"VBZ"},
"thirsty":	{"JJ"},
"thirteen":	{"NN","CD"},
"thirteenth":	{"JJ","NN"},
"thirties":	{"NNS"},
"thirtieth":	{"JJ","NN"},
"thirty":	{"CD","NN"},
"thirtysomething":	{"NN","JJ"},
"thirtysomethings":	{"NNS"},
"this":	{"DT","RB","PRP"},
"thistle":	{"NN"},
"thistledown":	{"NN"},
"thistles":	{"NNS"},
"thither":	{"RB"},
"thlaspi":	{"NN"},
"tho":	{"RB"},
"thole":	{"NN"},
"thole-pin":	{"NN"},
"tholepin":	{"NN"},
"tholins":	{"NN"},
"thomomys":	{"NNS"},
"thompson":	{"NN"},
"thomson":	{"NN"},
"thong":	{"NN"},
"thongs":	{"NNS"},
"thoracentesis":	{"NN"},
"thoraces":	{"NNS"},
"thoracic":	{"JJ"},
"thoracocentesis":	{"NN"},
"thoracoscopy":	{"NN"},
"thoracotomy":	{"NN"},
"thorax":	{"NN"},
"thoraxes":	{"NNS"},
"thorazine":	{"NN"},
"thoreau":	{"NN"},
"thoreauvian":	{"JJ"},
"thoriate":	{"VB","VBP"},
"thoriated":	{"VBD","VBN","JJ"},
"thorite":	{"NN"},
"thorium":	{"NN"},
"thorn":	{"NN"},
"thornbill":	{"NN"},
"thornier":	{"JJR"},
"thorniest":	{"JJS"},
"thorniness":	{"NN"},
"thornless":	{"JJ"},
"thorns":	{"NNS"},
"thorny":	{"JJ"},
"thorough":	{"JJ"},
"thoroughbred":	{"JJ","NN"},
"thoroughbreds":	{"NNS"},
"thoroughfare":	{"NN"},
"thoroughfares":	{"NNS"},
"thoroughgoing":	{"JJ"},
"thoroughly":	{"RB"},
"thoroughness":	{"NN"},
"thoroughwort":	{"NN"},
"thorpe":	{"NN"},
"thorshavn":	{"NN"},
"thortveitite":	{"NN"},
"those":	{"DT","PRP"},
"thou":	{"PRP"},
"though":	{"IN","RB","CC"},
"thought":	{"VBD","VBN","NN"},
"thought-out":	{"JJ"},
"thought-provoking":	{"JJ"},
"thoughtful":	{"JJ"},
"thoughtfully":	{"RB"},
"thoughtfulness":	{"NN"},
"thoughtless":	{"JJ"},
"thoughtlessly":	{"RB"},
"thoughtlessness":	{"NN"},
"thoughts":	{"NNS"},
"thousand":	{"NN","CD","NNS"},
"thousands":	{"NNS"},
"thousandth":	{"NN","JJ"},
"thousandths":	{"NNS"},
"thraldom":	{"NN"},
"thrall":	{"NN"},
"thralldom":	{"NN"},
"thralls":	{"NNS"},
"thrash":	{"VB","VBP","NN"},
"thrashed":	{"VBD","VBN"},
"thrasher":	{"NN"},
"thrashers":	{"NNS"},
"thrashes":	{"VBZ","NNS"},
"thrashing":	{"VBG","NN"},
"thrashings":	{"NNS"},
"thraupidae":	{"NN"},
"thread":	{"NN","VB","VBP"},
"threadbare":	{"JJ"},
"threaded":	{"VBD","VBN"},
"threader":	{"NN"},
"threadfin":	{"NN","NNS"},
"threadfins":	{"NNS"},
"threading":	{"VBG"},
"threadless":	{"JJ"},
"threadlike":	{"JJ"},
"threads":	{"VBZ","NNS"},
"threadworm":	{"NN"},
"thready":	{"JJ"},
"threat":	{"NN"},
"threaten":	{"VB","VBP"},
"threatened":	{"VBN","VBD","JJ"},
"threatening":	{"VBG","JJ"},
"threateningly":	{"RB"},
"threatens":	{"VBZ"},
"threats":	{"NNS"},
"three":	{"CD","LS","NN"},
"three-D":	{"JJ","NN"},
"three-base":	{"JJ"},
"three-card":	{"JJ"},
"three-color":	{"JJ"},
"three-colour":	{"JJ"},
"three-cornered":	{"JJ"},
"three-day":	{"JJ","NN"},
"three-decker":	{"NN"},
"three-deckers":	{"NNS"},
"three-dimensional":	{"JJ"},
"three-door":	{"NN"},
"three-fourths":	{"CD","NN"},
"three-gaited":	{"JJ"},
"three-hour":	{"NN","JJ"},
"three-legged":	{"JJ"},
"three-line":	{"JJ"},
"three-mile":	{"JJ"},
"three-phase":	{"JJ"},
"three-piece":	{"JJ"},
"three-ply":	{"JJ"},
"three-point":	{"JJ"},
"three-pronged":	{"JJ"},
"three-quarter":	{"JJ"},
"three-quarters":	{"NNS","RB"},
"three-ring":	{"JJ"},
"three-sided":	{"JJ"},
"three-square":	{"JJ"},
"three-way":	{"JJ","NN"},
"three-ways":	{"NNS"},
"three-wheeler":	{"NN"},
"three-wheelers":	{"NNS"},
"threefold":	{"JJ","RB"},
"threefoldness":	{"NN"},
"threeness":	{"NN"},
"threenesses":	{"NNS"},
"threepeat":	{"NN","VB","VBP"},
"threepeated":	{"VBD","VBN"},
"threepeating":	{"VBG"},
"threepeats":	{"NNS","VBZ"},
"threepence":	{"NN","NNS"},
"threepences":	{"NNS"},
"threepenceworth":	{"NN"},
"threepennies":	{"NNS"},
"threepenny":	{"JJ","NN"},
"threepennyworth":	{"NN"},
"threes":	{"NNS"},
"threescore":	{"NN","JJ"},
"threescores":	{"NNS"},
"threeside":	{"JJ","NN"},
"threesides":	{"NNS"},
"threesome":	{"NN"},
"threesomes":	{"NNS"},
"threespace":	{"NN"},
"threespaces":	{"NNS"},
"threnodies":	{"NNS"},
"threnody":	{"NN"},
"threonine":	{"NN"},
"thresh":	{"VB","VBP"},
"threshed":	{"VBD","VBN"},
"thresher":	{"NN"},
"threshers":	{"NNS"},
"threshes":	{"VBZ"},
"threshing":	{"NN","VBG"},
"threshold":	{"NN"},
"thresholds":	{"NNS"},
"threskiornis":	{"NN"},
"threskiornithidae":	{"NN"},
"threw":	{"VBD"},
"thrice":	{"RB"},
"thrift":	{"NN"},
"thriftier":	{"JJR"},
"thriftiest":	{"JJS"},
"thriftily":	{"RB"},
"thriftiness":	{"NN"},
"thriftless":	{"JJ"},
"thriftlessly":	{"RB"},
"thriftlessness":	{"NN"},
"thrifts":	{"NNS"},
"thriftshop":	{"NN"},
"thrifty":	{"JJ"},
"thrill":	{"NN","VB","VBP"},
"thrilled":	{"VBN","VBD","JJ"},
"thriller":	{"NN"},
"thrillers":	{"NNS"},
"thrillful":	{"JJ"},
"thrilling":	{"JJ","VBG"},
"thrillingly":	{"RB"},
"thrills":	{"NNS","VBZ"},
"thrinax":	{"NN"},
"thripid":	{"NN"},
"thripidae":	{"NN"},
"thrips":	{"NN","NNS"},
"thrive":	{"VB","VBP"},
"thrived":	{"VBD","VBN"},
"thriven":	{"VBN"},
"thrives":	{"VBZ"},
"thriving":	{"VBG","JJ"},
"throat":	{"NN"},
"throatier":	{"JJR"},
"throatiest":	{"JJS"},
"throatily":	{"RB"},
"throatiness":	{"NN"},
"throats":	{"NNS"},
"throatwort":	{"NN"},
"throaty":	{"JJ"},
"throb":	{"VB","VBP","NN"},
"throbbed":	{"VBD","VBN"},
"throbbing":	{"VBG","JJ"},
"throbbingly":	{"RB"},
"throbs":	{"VBZ","NNS"},
"throe":	{"NN"},
"throes":	{"NNS"},
"thrombasthenia":	{"NN"},
"thrombectomy":	{"NN"},
"thrombi":	{"NNS"},
"thrombin":	{"NN"},
"thrombocyte":	{"NN"},
"thrombocytopenia":	{"NN"},
"thrombocytosis":	{"NN"},
"thromboembolism":	{"NN"},
"thrombokinase":	{"NN"},
"thrombolysis":	{"NN"},
"thrombolytic":	{"JJ","NN"},
"thrombopenia":	{"NN"},
"thrombophlebitis":	{"NN"},
"thromboplastin":	{"NN"},
"thrombose":	{"VB","VBP"},
"thrombosed":	{"VBD","VBN"},
"thromboses":	{"VBZ","NNS"},
"thrombosing":	{"VBG"},
"thrombosis":	{"NN"},
"thrombus":	{"NN"},
"throne":	{"NN","VB","VBP"},
"throned":	{"VBD","VBN"},
"thrones":	{"NNS","VBZ"},
"throng":	{"NN","VB","VBP"},
"thronged":	{"VBD","VBN","JJ"},
"thronging":	{"VBG"},
"throngs":	{"NNS","VBZ"},
"throning":	{"VBG"},
"throstle":	{"NN"},
"throttle":	{"VB","VBP","NN"},
"throttled":	{"VBD","VBN"},
"throttlehold":	{"NN"},
"throttler":	{"NN"},
"throttles":	{"VBZ","NNS"},
"throttling":	{"VBG"},
"through":	{"IN","RB","RP","JJ"},
"throughout":	{"IN","RB"},
"throughput":	{"NN"},
"throughway":	{"NN"},
"throughways":	{"NNS"},
"throve":	{"VBD"},
"throw":	{"VB","NN","VBP"},
"throw-away":	{"JJ"},
"throw-back":	{"NN"},
"throw-in":	{"NN"},
"throw-ins":	{"NNS"},
"throwaway":	{"NN","JJ"},
"throwaways":	{"NNS"},
"throwback":	{"NN"},
"throwbacks":	{"NNS"},
"thrower":	{"NN"},
"throwers":	{"NNS"},
"throwing":	{"VBG","NN"},
"thrown":	{"VBN"},
"thrown-away":	{"JJ"},
"throws":	{"VBZ"},
"throwster":	{"NN"},
"throwsters":	{"NNS"},
"thru":	{"IN","RB","JJ"},
"thrum":	{"VB","VBP","NN"},
"thrummed":	{"VBD","VBN"},
"thrumming":	{"NN","VBG"},
"thrums":	{"VBZ"},
"thrush":	{"NN"},
"thrushes":	{"NNS"},
"thrust":	{"VB","VBP","VBD","VBN","NN"},
"thruster":	{"NN"},
"thrusters":	{"NNS"},
"thrusting":	{"VBG","JJ"},
"thrusts":	{"NNS","VBZ"},
"thruway":	{"NN"},
"thruways":	{"NNS"},
"thryothorus":	{"NN"},
"thucydides":	{"NNS"},
"thud":	{"NN","VB","VBP"},
"thudded":	{"VBD","VBN"},
"thudding":	{"VBG","NN"},
"thuds":	{"NNS","VBZ"},
"thug":	{"NN"},
"thuggee":	{"NN"},
"thuggery":	{"NN"},
"thugs":	{"NNS"},
"thuja":	{"NN"},
"thujopsis":	{"NN"},
"thule":	{"NN"},
"thulium":	{"NN"},
"thumb":	{"NN","VB","VBP"},
"thumb-index":	{"NN"},
"thumb-nail":	{"NN"},
"thumb-nails":	{"NNS"},
"thumb-stall":	{"NN"},
"thumbed":	{"VBD","VBN"},
"thumbhole":	{"NN"},
"thumbing":	{"VBG"},
"thumbnail":	{"JJ","NN"},
"thumbnails":	{"NNS"},
"thumbnut":	{"NN"},
"thumbprint":	{"NN"},
"thumbprints":	{"NNS"},
"thumbs":	{"NNS","VBZ"},
"thumbs-down":	{"NN"},
"thumbscrew":	{"NN"},
"thumbscrews":	{"NNS"},
"thumbstall":	{"NN"},
"thumbtack":	{"NN"},
"thumbtacks":	{"NNS"},
"thump":	{"VB","VBP","NN"},
"thumped":	{"VBD","VBN"},
"thumping":	{"JJ","RB","VBG"},
"thumps":	{"VBZ","NNS"},
"thunbergia":	{"NN"},
"thunder":	{"NN","VB","VBP"},
"thunder-cloud":	{"NN"},
"thunderbird":	{"NN"},
"thunderbolt":	{"NN"},
"thunderbolts":	{"NNS"},
"thunderclap":	{"NN"},
"thunderclaps":	{"NNS"},
"thundercloud":	{"NN"},
"thunderclouds":	{"NNS"},
"thundered":	{"VBD","VBN"},
"thunderhead":	{"NN"},
"thundering":	{"VBG","JJ","RB"},
"thunderous":	{"JJ"},
"thunderously":	{"RB"},
"thunders":	{"NNS","VBZ"},
"thundershower":	{"NN"},
"thunderstorm":	{"NN"},
"thunderstorms":	{"NNS"},
"thunderstruck":	{"JJ"},
"thundery":	{"JJ"},
"thunk":	{"NN","VB","VBP"},
"thunnus":	{"NN"},
"thurber":	{"NN"},
"thurible":	{"NN"},
"thurifer":	{"NN"},
"thurify":	{"VB","VBP"},
"thuringia":	{"NN"},
"thuringiensis":	{"NN"},
"thurow":	{"NN"},
"thus":	{"RB"},
"thusly":	{"RB"},
"thwack":	{"NN","VB","VBP"},
"thwacked":	{"VBD","VBN"},
"thwacking":	{"VBG"},
"thwacks":	{"NNS","VBZ"},
"thwart":	{"VB","VBP","NN"},
"thwarted":	{"VBD","VBN"},
"thwarter":	{"NN"},
"thwarting":	{"VBG"},
"thwarts":	{"VBZ","NNS"},
"thwartwise":	{"JJ"},
"thy":	{"PRP$"},
"thylacine":	{"NN"},
"thylacinus":	{"NN"},
"thylogale":	{"NN"},
"thyme":	{"NN"},
"thymelaeaceae":	{"NN"},
"thymelaeales":	{"NNS"},
"thymidine":	{"NN"},
"thymine":	{"NN"},
"thymol":	{"NN"},
"thymosin":	{"NN"},
"thymus":	{"NN"},
"thyratron":	{"NN"},
"thyreophora":	{"NN"},
"thyreophoran":	{"NN"},
"thyrocalcitonin":	{"NN"},
"thyroglobulin":	{"NN"},
"thyroid":	{"NN"},
"thyroidal":	{"JJ"},
"thyroidectomy":	{"NN"},
"thyroiditis":	{"NN"},
"thyroids":	{"NNS"},
"thyromegaly":	{"NN"},
"thyronine":	{"NN"},
"thyroprotein":	{"NN"},
"thyrotoxic":	{"JJ"},
"thyrotoxicosis":	{"NN"},
"thyrotrophic":	{"JJ"},
"thyrotrophin":	{"NN"},
"thyrotropin":	{"NN"},
"thyroxin":	{"NN"},
"thyroxine":	{"NN"},
"thyrse":	{"NN"},
"thyrsopteris":	{"NN"},
"thyrsus":	{"NN"},
"thysanocarpus":	{"NN"},
"thysanopter":	{"NN"},
"thysanoptera":	{"NN"},
"thysanopteron":	{"NN"},
"thysanura":	{"NN"},
"thysanuron":	{"NN"},
"thyself":	{"PRP"},
"ti":	{"NN"},
"tiara":	{"NN"},
"tiaras":	{"NNS"},
"tiarella":	{"NN"},
"tiber":	{"NN"},
"tibet":	{"NN"},
"tibia":	{"NN"},
"tibiae":	{"NNS"},
"tibial":	{"JJ"},
"tibialis":	{"JJ"},
"tibias":	{"NNS"},
"tibicen":	{"NN"},
"tic":	{"NN"},
"tic-tac-toe":	{"NN"},
"tical":	{"NN"},
"tichodroma":	{"NN"},
"tick":	{"NN","VB","VBP"},
"tick-tack":	{"NN"},
"tick-tack-toe":	{"NN"},
"tick-tock":	{"NN"},
"ticked":	{"VBD","VBN"},
"ticker":	{"NN"},
"ticker-tape":	{"NN"},
"tickers":	{"NNS"},
"ticket":	{"NN","VBP","VB"},
"ticketed":	{"VBD","VBN"},
"ticketing":	{"VBG","NN"},
"tickets":	{"NNS","VBZ"},
"ticking":	{"NN","VBG"},
"ticking-off":	{"NN"},
"tickings-off":	{"NNS"},
"tickle":	{"VB","VBP","NN"},
"tickled":	{"VBD","VBN","JJ"},
"tickler":	{"NN"},
"tickles":	{"VBZ"},
"tickling":	{"VBG"},
"ticklish":	{"JJ"},
"ticklishness":	{"NN"},
"ticks":	{"VBZ","NNS"},
"tickseed":	{"NN"},
"ticktack":	{"NN"},
"ticktock":	{"NN"},
"tictac":	{"NN"},
"tidal":	{"JJ"},
"tidbit":	{"NN"},
"tidbits":	{"NNS"},
"tiddler":	{"NN"},
"tiddlers":	{"NNS"},
"tiddlier":	{"JJR"},
"tiddliest":	{"JJS"},
"tiddly":	{"JJ"},
"tiddlywinks":	{"NN"},
"tide":	{"NN","VB","VBP"},
"tide-mark":	{"NN"},
"tide-marks":	{"NNS"},
"tide-table":	{"NN"},
"tided":	{"VBD","VBN"},
"tideland":	{"NN"},
"tidelands":	{"NNS"},
"tidemark":	{"NN"},
"tides":	{"NNS","VBZ"},
"tidewater":	{"NN"},
"tideway":	{"NN"},
"tidied":	{"VBD","VBN"},
"tidier":	{"JJR"},
"tidies":	{"NNS","VBZ"},
"tidiest":	{"JJS"},
"tidily":	{"RB"},
"tidiness":	{"NN"},
"tiding":	{"VBG"},
"tidings":	{"NNS"},
"tidy":	{"JJ","NN","VB","VBP"},
"tidying":	{"JJ","VBG"},
"tidytips":	{"NN","NNS"},
"tie":	{"NN","VB","VBP"},
"tie-beam":	{"NN"},
"tie-break":	{"NN"},
"tie-breaker":	{"NN"},
"tie-breakers":	{"NNS"},
"tie-breaking":	{"JJ"},
"tie-breaks":	{"NNS"},
"tie-dye":	{"VB","VBP","NN"},
"tie-dyed":	{"VBD","VBN"},
"tie-dyeing":	{"VBG"},
"tie-dyes":	{"VBZ","NNS"},
"tie-in":	{"NN"},
"tie-ins":	{"NNS"},
"tie-on":	{"JJ"},
"tie-pin":	{"NN"},
"tie-pins":	{"NNS"},
"tie-up":	{"NN"},
"tie-ups":	{"NNS"},
"tieback":	{"NN"},
"tiebreaker":	{"NN"},
"tied":	{"VBN","VBD","JJ"},
"tiefes":	{"FW"},
"tiempo":	{"FW"},
"tiene":	{"FW"},
"tiepin":	{"NN"},
"tiepins":	{"NNS"},
"tiepolo":	{"NN"},
"tier":	{"NN","VB","VBP"},
"tierce":	{"NN"},
"tiercel":	{"NN"},
"tiered":	{"VBD","VBN","JJ"},
"tiering":	{"VBG"},
"tiers":	{"NNS","VBZ"},
"ties":	{"NNS","VBZ"},
"tiff":	{"NN","VB","VBP"},
"tiffany":	{"NN"},
"tiffed":	{"VBD","VBN"},
"tiffin":	{"NN"},
"tiffing":	{"VBG"},
"tiffs":	{"NNS","VBZ"},
"tiger":	{"NN"},
"tiger-lily":	{"NN"},
"tiger-moth":	{"NN"},
"tigerish":	{"JJ"},
"tigers":	{"NNS"},
"tight":	{"JJ","RB"},
"tight-fisted":	{"JJ"},
"tight-fistedness":	{"NN"},
"tight-fitting":	{"JJ"},
"tight-knit":	{"JJ"},
"tight-lipped":	{"JJ"},
"tighten":	{"VB","VBP"},
"tightened":	{"VBD","VBN"},
"tightener":	{"NN"},
"tightening":	{"NN","VBG"},
"tightens":	{"VBZ"},
"tighter":	{"JJR"},
"tightest":	{"JJS"},
"tightfisted":	{"JJ"},
"tightfistedness":	{"NN"},
"tightly":	{"RB"},
"tightness":	{"NN"},
"tightrope":	{"NN"},
"tightropes":	{"NNS"},
"tights":	{"NNS"},
"tightwad":	{"NN"},
"tiglon":	{"NN"},
"tigon":	{"NN"},
"tigrean":	{"JJ"},
"tigress":	{"NN"},
"tigresses":	{"NNS"},
"tigris":	{"NN"},
"tijuana":	{"NN"},
"tike":	{"NN"},
"tilapia":	{"NN"},
"tilde":	{"NN"},
"tildes":	{"NNS"},
"tile":	{"NN","VB","VBP"},
"tiled":	{"JJ","VBD","VBN"},
"tilefish":	{"NN","NNS"},
"tilefishes":	{"NNS"},
"tiler":	{"NN"},
"tilers":	{"NNS"},
"tiles":	{"NNS","VBZ"},
"tilia":	{"NN"},
"tiliaceae":	{"NN"},
"tiling":	{"NN","VBG"},
"till":	{"IN","CC","NN","VB","VBP"},
"tillable":	{"JJ"},
"tillage":	{"NN"},
"tillandsia":	{"NN"},
"tilled":	{"VBD","VBN"},
"tiller":	{"NN","VB","VBP"},
"tillered":	{"VBD","VBN"},
"tillering":	{"VBG"},
"tillers":	{"NNS","VBZ"},
"tilletia":	{"NN"},
"tilletiaceae":	{"NN"},
"tillich":	{"NN"},
"tilling":	{"VBG"},
"tills":	{"NNS","VBZ"},
"tilt":	{"VB","VBP","NN"},
"tilted":	{"VBD","VBN"},
"tilter":	{"NN"},
"tilth":	{"NN"},
"tilting":	{"VBG"},
"tilts":	{"VBZ","NNS"},
"tiltyard":	{"NN"},
"timalia":	{"NN"},
"timaliidae":	{"NN"},
"timbale":	{"NN"},
"timber":	{"NN","UH","VB","VBP"},
"timber-wolf":	{"NN"},
"timbered":	{"JJ","VBD","VBN"},
"timbering":	{"VBG","NN"},
"timberland":	{"NN"},
"timberlands":	{"NNS"},
"timberline":	{"NN"},
"timberman":	{"NN"},
"timbermen":	{"NNS"},
"timbers":	{"NNS","VBZ"},
"timbre":	{"NN"},
"timbrel":	{"NN"},
"timbres":	{"NNS"},
"timbuktu":	{"NN"},
"time":	{"NN","VB","VBP"},
"time-card":	{"NN"},
"time-consuming":	{"JJ"},
"time-fuse":	{"NN"},
"time-honored":	{"JJ"},
"time-honoured":	{"JJ"},
"time-keeper":	{"NN"},
"time-keepers":	{"NNS"},
"time-limit":	{"NN"},
"time-limits":	{"NNS"},
"time-out":	{"NN"},
"time-outs":	{"NNS"},
"time-poor":	{"JJ"},
"time-scale":	{"NN"},
"time-scales":	{"NNS"},
"time-server":	{"NN"},
"time-servers":	{"NNS"},
"time-share":	{"NN"},
"time-shares":	{"NNS"},
"time-sharing":	{"NN"},
"time-sheet":	{"NN"},
"time-signal":	{"NN"},
"time-switch":	{"NN"},
"time-switches":	{"NNS"},
"time-table":	{"NN"},
"time-worn":	{"JJ"},
"time-zone":	{"NN"},
"time-zones":	{"NNS"},
"timed":	{"VBD","VBN"},
"timeframe":	{"NN"},
"timeframes":	{"NNS"},
"timekeeper":	{"NN"},
"timekeepers":	{"NNS"},
"timekeeping":	{"NN"},
"timeless":	{"JJ"},
"timelessly":	{"RB"},
"timelessness":	{"NN"},
"timelier":	{"JJR"},
"timeliest":	{"JJS"},
"timeline":	{"NN"},
"timelines":	{"NNS"},
"timeliness":	{"NN"},
"timely":	{"JJ"},
"timeout":	{"NN"},
"timeouts":	{"NNS"},
"timepiece":	{"NN"},
"timepieces":	{"NNS"},
"timer":	{"NN"},
"timers":	{"NNS"},
"times":	{"NNS","VBZ","IN"},
"timeserver":	{"NN"},
"timeservers":	{"NNS"},
"timeserving":	{"JJ","NN"},
"timetable":	{"NN","VB","VBP"},
"timetabled":	{"VBD","VBN"},
"timetables":	{"NNS","VBZ"},
"timetabling":	{"VBG","NN"},
"timework":	{"NN"},
"timeworn":	{"JJ"},
"timid":	{"JJ"},
"timidity":	{"NN"},
"timidly":	{"RB"},
"timidness":	{"NN"},
"timing":	{"NN","VBG"},
"timolol":	{"NN"},
"timor":	{"NN"},
"timorous":	{"JJ"},
"timorously":	{"RB"},
"timorousness":	{"NN"},
"timothy":	{"NN"},
"timpani":	{"NN","NNS"},
"timpanist":	{"NN"},
"tin":	{"NN","VB","VBP","JJ"},
"tin-opener":	{"NN"},
"tin-openers":	{"NNS"},
"tin-tack":	{"NN"},
"tinamidae":	{"NN"},
"tinamiformes":	{"NNS"},
"tinamou":	{"NN"},
"tinbergen":	{"NN"},
"tinca":	{"NN"},
"tinct":	{"NN","VB","VBP","JJ"},
"tincture":	{"NN","VB","VBP"},
"tinctured":	{"VBD","VBN"},
"tinctures":	{"NNS","VBZ"},
"tincturing":	{"VBG"},
"tindal":	{"NN"},
"tindale":	{"NN"},
"tinder":	{"NN"},
"tinder-box":	{"NN"},
"tinder-boxes":	{"NNS"},
"tinderbox":	{"NN"},
"tinderboxes":	{"NNS"},
"tine":	{"NN"},
"tinea":	{"NN"},
"tined":	{"JJ"},
"tineid":	{"NN"},
"tineidae":	{"NN"},
"tineoid":	{"NN"},
"tineoidea":	{"NN"},
"tineola":	{"NN"},
"tines":	{"NNS"},
"tinfoil":	{"NN"},
"ting":	{"NN","VB","VBP"},
"ting-a-ling":	{"NN","RB"},
"tinge":	{"NN","VB","VBP"},
"tinged":	{"JJ","VBN","VBD"},
"tingeing":	{"VBG"},
"tinges":	{"NNS","VBZ"},
"tingidae":	{"NN"},
"tinging":	{"VBG"},
"tingle":	{"VB","VBP","NN"},
"tingled":	{"VBD","VBN"},
"tingles":	{"VBZ","NNS"},
"tingling":	{"VBG","NN"},
"tings":	{"NNS","VBZ"},
"tinier":	{"JJR"},
"tiniest":	{"JJS"},
"tininess":	{"NN"},
"tink":	{"NN"},
"tinker":	{"NN","VB","VBP"},
"tinkered":	{"VBD","VBN"},
"tinkerer":	{"NN"},
"tinkering":	{"NN","VBG"},
"tinkers":	{"VBZ","NNS"},
"tinkle":	{"NN","VB","VBP"},
"tinkled":	{"VBD","VBN"},
"tinkles":	{"NNS","VBZ"},
"tinkling":	{"VBG","JJ"},
"tinkly":	{"RB"},
"tinned":	{"JJ","VBD","VBN"},
"tinner":	{"NN"},
"tinnier":	{"JJR"},
"tinniest":	{"JJS"},
"tinning":	{"NN","VBG"},
"tinnitus":	{"NN"},
"tinny":	{"JJ"},
"tinplate":	{"NN"},
"tinpot":	{"JJ"},
"tins":	{"NNS","VBZ"},
"tinsel":	{"NN","VB","VBP","JJ"},
"tinseled":	{"VBD","VBN"},
"tinseling":	{"VBG"},
"tinselled":	{"VBD","VBN"},
"tinselling":	{"VBG"},
"tinselly":	{"JJ"},
"tinsels":	{"VBZ"},
"tinsmith":	{"NN"},
"tinsnips":	{"NNS"},
"tint":	{"NN","VB","VBP"},
"tintable":	{"JJ"},
"tintack":	{"NN"},
"tinted":	{"VBN","JJ","VBD"},
"tinter":	{"NN"},
"tinting":	{"VBG"},
"tintinnabulate":	{"VB","VBP"},
"tintinnabulation":	{"NN"},
"tintometer":	{"NN"},
"tintoretto":	{"NN"},
"tints":	{"NNS","VBZ"},
"tintype":	{"NN"},
"tinware":	{"NN"},
"tiny":	{"JJ"},
"tip":	{"NN","VB","VBP"},
"tip-off":	{"NN"},
"tip-offs":	{"NNS"},
"tip-top":	{"JJ"},
"tip-up":	{"JJ"},
"tipi":	{"NN"},
"tipis":	{"NNS"},
"tipoff":	{"NN"},
"tipoffs":	{"NNS"},
"tipped":	{"JJ","VBD","VBN"},
"tippee":	{"NN"},
"tipper":	{"NN"},
"tippet":	{"NN"},
"tippier":	{"JJR"},
"tippiest":	{"JJS"},
"tipping":	{"VBG"},
"tipple":	{"NN","VB","VBP"},
"tippled":	{"VBD","VBN"},
"tippler":	{"NN"},
"tipplers":	{"NNS"},
"tipples":	{"NNS","VBZ"},
"tippling":	{"VBG"},
"tippy":	{"JJ"},
"tippy-toe":	{"NN","JJ","VB","VBP"},
"tips":	{"NNS","VBZ"},
"tipsier":	{"JJR"},
"tipsiest":	{"JJS"},
"tipsiness":	{"NN"},
"tipstaff":	{"NN"},
"tipster":	{"NN"},
"tipsters":	{"NNS"},
"tipsy":	{"JJ"},
"tiptoe":	{"NN","VB","VBP"},
"tiptoed":	{"VBD","VBN"},
"tiptoeing":	{"VBG"},
"tiptoes":	{"NNS","VBZ"},
"tiptop":	{"JJ","RB","NN"},
"tiptops":	{"NNS"},
"tipu":	{"NN"},
"tipuana":	{"NN"},
"tipulidae":	{"NN"},
"tirade":	{"NN"},
"tirades":	{"NNS"},
"tiramisu":	{"NN"},
"tire":	{"VB","VBP","NN"},
"tired":	{"VBN","JJ","VBD"},
"tiredly":	{"RB"},
"tiredness":	{"NN"},
"tireless":	{"JJ"},
"tirelessly":	{"RB"},
"tirelessness":	{"NN"},
"tiremaker":	{"NN"},
"tires":	{"VBZ","NNS"},
"tiresome":	{"JJ"},
"tiresomely":	{"RB"},
"tiresomeness":	{"NN"},
"tiring":	{"VBG","JJ"},
"tiro":	{"NN"},
"tirolean":	{"NN"},
"tiros":	{"NNS"},
"tisane":	{"NN"},
"tishri":	{"NN"},
"tisiphone":	{"NN"},
"tissue":	{"NN"},
"tissues":	{"NNS"},
"tit":	{"NN"},
"tit-tat-toe":	{"NN"},
"titan":	{"NN"},
"titanate":	{"NN"},
"titaness":	{"NN"},
"titanic":	{"JJ"},
"titanium":	{"NN"},
"titanosaur":	{"NN"},
"titanosaurian":	{"NN"},
"titanosauridae":	{"NN"},
"titanosaurus":	{"NN"},
"titans":	{"NNS"},
"titbit":	{"NN"},
"titbits":	{"NNS"},
"titer":	{"NN"},
"titers":	{"NNS"},
"titfer":	{"NN"},
"tithe":	{"NN","VB","VBP"},
"tithed":	{"VBD","VBN"},
"tither":	{"NN"},
"tithes":	{"NNS","VBZ"},
"tithing":	{"VBG","NN"},
"tithonia":	{"NN"},
"titi":	{"NN"},
"titian":	{"NN"},
"titillate":	{"VB","VBP"},
"titillated":	{"VBD","VBN"},
"titillates":	{"VBZ"},
"titillating":	{"VBG","JJ"},
"titillation":	{"NN"},
"titivate":	{"VB","VBP"},
"titivated":	{"VBD","VBN"},
"titivates":	{"VBZ"},
"titivating":	{"VBG"},
"titivation":	{"NN"},
"titlark":	{"NN"},
"title":	{"NN","VB","VBP"},
"title-deed":	{"NN"},
"title-holder":	{"NN"},
"title-holders":	{"NNS"},
"title-role":	{"NN"},
"title-roles":	{"NNS"},
"titled":	{"VBN","VBD","JJ"},
"titles":	{"NNS","VBZ"},
"titling":	{"VBG"},
"titmice":	{"NNS"},
"titmouse":	{"NN"},
"tito":	{"NN"},
"titrate":	{"VB","VBP"},
"titration":	{"NN"},
"titrator":	{"NN"},
"titre":	{"NN"},
"tits":	{"NNS"},
"titter":	{"VB","VBP","NN"},
"tittered":	{"VBD","VBN"},
"titterer":	{"NN"},
"tittering":	{"VBG","NN"},
"titters":	{"NNS","VBZ"},
"titties":	{"NNS"},
"tittivate":	{"VB","VBP"},
"tittivation":	{"NN"},
"tittle":	{"NN"},
"tittle-tattle":	{"NN","VB","VBP"},
"tittup":	{"VB","VBP","NN"},
"tittuped":	{"VBD","VBN"},
"tittuping":	{"VBG"},
"tittupped":	{"VBD","VBN"},
"tittupping":	{"VBG"},
"tittups":	{"VBZ","NNS"},
"titty":	{"NN"},
"titular":	{"JJ"},
"titularies":	{"NNS"},
"titularly":	{"RB"},
"titulary":	{"JJ","NN"},
"titus":	{"NN"},
"tivoli":	{"NN"},
"tiyin":	{"NN"},
"tizzy":	{"NN"},
"tk":	{"NN"},
"tko":	{"NN"},
"tl":	{"NN"},
"tlc":	{"NN"},
"tn":	{"NN"},
"to":	{"TO"},
"to-and-fro":	{"JJ"},
"to-do":	{"NN"},
"to-dos":	{"NNS"},
"toad":	{"NN"},
"toad-in-the-hole":	{"NN"},
"toadfish":	{"NN","NNS"},
"toadfishes":	{"NNS"},
"toadflax":	{"NN"},
"toadied":	{"VBD","VBN"},
"toadies":	{"VBZ","NNS"},
"toads":	{"NNS"},
"toadstool":	{"NN"},
"toadstools":	{"NNS"},
"toady":	{"NN","VB","VBP"},
"toadying":	{"VBG"},
"toadyism":	{"NN"},
"toast":	{"NN","VB","VBP"},
"toast-rack":	{"NN"},
"toasted":	{"VBD","VBN"},
"toaster":	{"NN"},
"toasters":	{"NNS"},
"toasting":	{"VBG"},
"toasting-fork":	{"NN"},
"toastmaster":	{"NN"},
"toastmasters":	{"NNS"},
"toasts":	{"NNS","VBZ"},
"tobacco":	{"NN"},
"tobacconist":	{"NN"},
"tobacconists":	{"NNS"},
"tobaccos":	{"NNS"},
"tobies":	{"NNS"},
"tobin":	{"NN"},
"toboggan":	{"NN","VB","VBP"},
"tobogganed":	{"VBD","VBN"},
"tobogganing":	{"NN","VBG"},
"tobogganist":	{"NN"},
"toboggans":	{"NNS","VBZ"},
"tobramycin":	{"NN"},
"toby":	{"NN"},
"tocainide":	{"NN"},
"toccata":	{"NN"},
"toccatas":	{"NNS"},
"tocharian":	{"NN"},
"tocktact":	{"NN"},
"tocology":	{"NN"},
"tocopherol":	{"NN"},
"tocqueville":	{"NN"},
"tocsin":	{"NN"},
"tod":	{"NN"},
"toda":	{"NN"},
"today":	{"RB","NN"},
"toddies":	{"NNS"},
"toddle":	{"VB","VBP"},
"toddled":	{"VBD","VBN"},
"toddler":	{"NN"},
"toddlers":	{"NNS"},
"toddles":	{"VBZ"},
"toddling":	{"VBG"},
"toddy":	{"NN"},
"todea":	{"NN"},
"todidae":	{"NN"},
"todos":	{"NNS"},
"todus":	{"NN"},
"toe":	{"NN","VB","VBP"},
"toe-in":	{"NN"},
"toe-tips":	{"NNS"},
"toe-to-toe":	{"RB"},
"toea":	{"NN"},
"toecap":	{"NN"},
"toed":	{"VBD","VBN"},
"toehold":	{"NN"},
"toeholds":	{"NNS"},
"toeing":	{"VBG"},
"toeless":	{"JJ"},
"toenail":	{"NN"},
"toenails":	{"NNS"},
"toes":	{"NNS","VBZ"},
"toetoe":	{"NN"},
"toff":	{"NN"},
"toffee":	{"NN"},
"toffee-apple":	{"NN"},
"toffee-apples":	{"NNS"},
"toffee-nosed":	{"JJ"},
"toffees":	{"NNS"},
"toffs":	{"NNS"},
"toffy":	{"NN"},
"tofieldia":	{"NN"},
"tofranil":	{"NN"},
"tofu":	{"NN"},
"tog":	{"NN","VB","VBP"},
"toga":	{"NN"},
"togaviridae":	{"NN"},
"together":	{"RB","RP","JJ"},
"togetherness":	{"NN"},
"togged":	{"VBD","VBN"},
"togging":	{"VBG"},
"toggle":	{"NN","VB","VBP"},
"toggled":	{"VBD","VBN"},
"toggles":	{"NNS","VBZ"},
"toggling":	{"VBG"},
"togs":	{"NNS","VBZ"},
"toil":	{"VB","VBP","NN"},
"toiled":	{"VBD","VBN"},
"toiler":	{"NN"},
"toilet":	{"NN"},
"toilet-paper":	{"NN"},
"toilet-roll":	{"NN"},
"toilet-rolls":	{"NNS"},
"toilet-train":	{"VB","VBP"},
"toilet-trained":	{"JJ","VBD","VBN"},
"toilet-training":	{"VBG","NN"},
"toilet-trains":	{"VBZ"},
"toiletries":	{"NNS"},
"toiletry":	{"NN"},
"toilets":	{"NNS"},
"toilette":	{"NN"},
"toilful":	{"JJ"},
"toiling":	{"VBG"},
"toils":	{"VBZ"},
"toilsome":	{"JJ"},
"toilsomeness":	{"NN"},
"toitoes":	{"NNS"},
"toitoi":	{"NN"},
"toitois":	{"NNS"},
"tokamak":	{"NN"},
"tokay":	{"NN"},
"toke":	{"VB","VBP","NN"},
"toked":	{"VBD","VBN"},
"token":	{"NN","JJ","VB","VBP"},
"tokened":	{"VBD","VBN"},
"tokening":	{"VBG"},
"tokenish":	{"JJ"},
"tokens":	{"NNS","VBZ"},
"tokes":	{"VBZ","NNS"},
"toking":	{"VBG"},
"tokio":	{"NN"},
"tokyo":	{"NN"},
"tolazamide":	{"NN"},
"tolazoline":	{"NN"},
"tolbooth":	{"NN"},
"tolbukhin":	{"NN"},
"tolbutamide":	{"NN"},
"told":	{"VBD","VBN"},
"tole":	{"NN"},
"tolectin":	{"NN"},
"toledo":	{"NN"},
"tolerable":	{"JJ"},
"tolerably":	{"RB"},
"tolerance":	{"NN"},
"tolerances":	{"NNS"},
"tolerant":	{"JJ"},
"tolerantly":	{"RB"},
"tolerate":	{"VB","VBP"},
"tolerated":	{"VBD","VBN"},
"tolerates":	{"VBZ"},
"tolerating":	{"VBG"},
"toleration":	{"NN"},
"tolinase":	{"NN"},
"toll":	{"NN","VB","VBP"},
"toll-bridge":	{"NN"},
"toll-free":	{"JJ","RB"},
"toll-gate":	{"NN"},
"toll-house":	{"NN"},
"toll-road":	{"NN"},
"tollbar":	{"NN"},
"tollbooth":	{"NN"},
"tollbooths":	{"NNS"},
"tolled":	{"VBD","VBN"},
"toller":	{"NN"},
"tollgate":	{"NN"},
"tollgatherer":	{"NN"},
"tollhouse":	{"NN"},
"tolling":	{"VBG"},
"tollkeeper":	{"NN"},
"tollman":	{"NN"},
"tollon":	{"NN"},
"tolls":	{"NNS","VBZ"},
"tollway":	{"NN"},
"tollways":	{"NNS"},
"tolmiea":	{"NN"},
"toltec":	{"NN"},
"tolu":	{"NN"},
"toluene":	{"NN"},
"tolylene":	{"NN"},
"tolypeutes":	{"NNS"},
"tom":	{"NN"},
"tom-tom":	{"NN"},
"tom-toms":	{"NNS"},
"tomahawk":	{"NN","VB","VBP"},
"tomahawked":	{"VBD","VBN"},
"tomahawking":	{"VBG"},
"tomahawks":	{"NNS","VBZ"},
"tomalley":	{"NN"},
"tomatillo":	{"NN"},
"tomato":	{"NN"},
"tomatoes":	{"NNS"},
"tomb":	{"NN"},
"tombac":	{"NN"},
"tombak":	{"NN"},
"tombaugh":	{"NN"},
"tombigbee":	{"NN"},
"tomblike":	{"JJ"},
"tombola":	{"NN"},
"tomboy":	{"NN"},
"tomboyish":	{"NN"},
"tomboyishness":	{"NN"},
"tomboys":	{"NNS"},
"tombs":	{"NNS"},
"tombstone":	{"NN"},
"tombstones":	{"NNS"},
"tomcat":	{"NN"},
"tomcats":	{"NNS"},
"tome":	{"NN"},
"tomentose":	{"JJ"},
"tomentous":	{"JJ"},
"tomentum":	{"NN"},
"tomes":	{"NNS"},
"tomfool":	{"JJ"},
"tomfoolery":	{"NN"},
"tomistoma":	{"NN"},
"tommyrot":	{"NN"},
"tomograph":	{"NN"},
"tomography":	{"NN"},
"tomorrow":	{"NN","RB"},
"tompion":	{"NN"},
"toms":	{"NNS"},
"tomtate":	{"NN"},
"tomtit":	{"NN"},
"ton":	{"NN"},
"ton-up":	{"JJ"},
"tonal":	{"JJ"},
"tonalities":	{"NNS"},
"tonality":	{"NN"},
"tonally":	{"RB"},
"tone":	{"NN","VB","VBP"},
"tone-deaf":	{"JJ"},
"tone-poem":	{"NN"},
"toned":	{"JJ","VBD","VBN"},
"toneless":	{"JJ"},
"tonelessly":	{"RB"},
"toner":	{"NN"},
"tones":	{"NNS","VBZ"},
"tong":	{"VB","VBP","NN"},
"tonged":	{"VBD","VBN"},
"tonging":	{"VBG"},
"tongs":	{"NNS","VBZ"},
"tongue":	{"NN","VBP","VB"},
"tongue-in-cheek":	{"JJ","RB"},
"tongue-lashing":	{"NN"},
"tongue-lashings":	{"NNS"},
"tongue-tied":	{"JJ"},
"tongue-twister":	{"NN"},
"tongue-twisters":	{"NNS"},
"tongued":	{"JJ","VBD","VBN"},
"tonguefish":	{"NN"},
"tongueflower":	{"NN"},
"tongueless":	{"JJ"},
"tonguelike":	{"JJ"},
"tongues":	{"NNS","VBZ"},
"tonguing":	{"VBG"},
"toni":	{"NN"},
"tonic":	{"NN","JJ"},
"tonicity":	{"NN"},
"tonics":	{"NNS"},
"tonier":	{"JJR"},
"toniest":	{"JJS"},
"tonight":	{"NN","RB"},
"toning":	{"VBG"},
"tonnage":	{"NN"},
"tonnages":	{"NNS"},
"tonne":	{"NN","NNS"},
"tonnes":	{"NNS"},
"tonocard":	{"NN"},
"tonometer":	{"NN"},
"tonometry":	{"NN"},
"tons":	{"NNS","RB"},
"tonsil":	{"NN"},
"tonsilla":	{"NN"},
"tonsillectomy":	{"NN"},
"tonsillitis":	{"NN"},
"tonsils":	{"NNS"},
"tonsorial":	{"JJ"},
"tonsure":	{"NN","VB","VBP"},
"tonsured":	{"VBD","VBN","JJ"},
"tonsures":	{"NNS","VBZ"},
"tonsuring":	{"VBG"},
"tontine":	{"NN"},
"tonus":	{"NN"},
"tony":	{"JJ"},
"too":	{"RB"},
"took":	{"VBD"},
"tool":	{"NN","VBP","VB"},
"toolbox":	{"NN"},
"toolboxes":	{"NNS"},
"tooled":	{"VBD","VBN"},
"toolhouse":	{"NN"},
"tooling":	{"NN","VBG"},
"toolmaker":	{"NN"},
"tools":	{"NNS","VBZ"},
"toolshed":	{"NN"},
"toon":	{"NN"},
"toona":	{"NN"},
"tooshie":	{"NN"},
"toot":	{"VB","VBP","NN"},
"tooted":	{"VBD","VBN"},
"tooth":	{"NN"},
"tooth-powder":	{"NN"},
"toothache":	{"NN"},
"toothbrush":	{"NN"},
"toothbrushes":	{"NNS"},
"toothed":	{"JJ"},
"toothless":	{"JJ"},
"toothlike":	{"JJ"},
"toothpaste":	{"NN"},
"toothpastes":	{"NNS"},
"toothpick":	{"NN"},
"toothpicks":	{"NNS"},
"toothsome":	{"JJ"},
"toothsomeness":	{"NN"},
"toothwort":	{"NN"},
"toothy":	{"JJ"},
"tooting":	{"VBG"},
"tootle":	{"VB","VBP"},
"tootled":	{"VBD","VBN"},
"tootles":	{"VBZ"},
"tootling":	{"VBG"},
"toots":	{"NNS","VBZ"},
"tootsie":	{"NN"},
"top":	{"JJ","NN","VB","VBP"},
"top-boot":	{"NN"},
"top-down":	{"JJ"},
"top-drawer":	{"JJ"},
"top-dress":	{"VB","VBP"},
"top-dressed":	{"VBD","VBN"},
"top-dresses":	{"VBZ"},
"top-dressing":	{"VBG","NN"},
"top-dressings":	{"NNS"},
"top-flight":	{"JJ"},
"top-heavy":	{"JJ"},
"top-level":	{"JJ"},
"top-notch":	{"JJ"},
"top-priority":	{"JJ"},
"top-ranked":	{"JJ"},
"top-ranking":	{"JJ"},
"top-rated":	{"JJ"},
"top-secret":	{"JJ"},
"top-up":	{"NN","JJ"},
"top-ups":	{"NNS"},
"topaz":	{"NN"},
"topazes":	{"NNS"},
"topcoat":	{"NN"},
"topcoats":	{"NNS"},
"tope":	{"NN","VB","VBP"},
"toped":	{"VBD","VBN"},
"topee":	{"NN"},
"topeka":	{"NN"},
"toper":	{"NN"},
"topes":	{"VBZ"},
"topgallant":	{"NN"},
"topgrade":	{"JJ"},
"tophus":	{"NN"},
"topi":	{"NN"},
"topiary":	{"NN"},
"topic":	{"NN"},
"topical":	{"JJ"},
"topicality":	{"NN"},
"topicalization":	{"NN"},
"topically":	{"RB"},
"topics":	{"NNS"},
"toping":	{"VBG"},
"topknot":	{"NN"},
"topknots":	{"NNS"},
"topless":	{"JJ"},
"topmast":	{"NN"},
"topminnow":	{"NN"},
"topmost":	{"JJ"},
"topnotch":	{"JJ"},
"topognosia":	{"NN"},
"topognosis":	{"NN"},
"topographer":	{"NN"},
"topographers":	{"NNS"},
"topographic":	{"JJ"},
"topographical":	{"JJ"},
"topographically":	{"RB"},
"topographies":	{"NNS"},
"topography":	{"NN"},
"topolatry":	{"NN"},
"topologic":	{"JJ"},
"topological":	{"JJ"},
"topologically":	{"RB"},
"topology":	{"NN"},
"toponomy":	{"NN"},
"toponym":	{"NN"},
"toponymy":	{"NN"},
"topos":	{"NN"},
"topped":	{"VBD","VBN"},
"topper":	{"NN"},
"topping":	{"VBG","JJ","NN"},
"toppingly":	{"RB"},
"toppings":	{"NNS"},
"topple":	{"VB","VBP"},
"toppled":	{"VBD","VBN"},
"topples":	{"VBZ"},
"toppling":	{"VBG"},
"tops":	{"NNS","VBZ","RB"},
"topsail":	{"NN"},
"topside":	{"NN","RB"},
"topsides":	{"NNS"},
"topsoil":	{"NN"},
"topspin":	{"NN"},
"topsy-turvily":	{"RB"},
"topsy-turvy":	{"RB","JJ"},
"topv":	{"NN"},
"toque":	{"NN"},
"tor":	{"NN"},
"toradol":	{"NN"},
"torah":	{"NN"},
"torch":	{"NN","VB","VBP"},
"torchbearer":	{"NN"},
"torched":	{"VBD","VBN"},
"torches":	{"NNS","VBZ"},
"torching":	{"VBG"},
"torchlight":	{"NN"},
"torchon":	{"NN"},
"torchons":	{"NNS"},
"tore":	{"VBD"},
"toreador":	{"NN"},
"toreadors":	{"NNS"},
"torero":	{"NN"},
"tori":	{"NNS"},
"tories":	{"NN"},
"torino":	{"NN"},
"torment":	{"NN","VB","VBP"},
"tormented":	{"VBD","VBN"},
"tormenter":	{"NN"},
"tormenters":	{"NNS"},
"tormenting":	{"VBG"},
"tormentor":	{"NN"},
"tormentors":	{"NNS"},
"torments":	{"VBZ","NNS"},
"torn":	{"VBN","JJ"},
"tornado":	{"NN"},
"tornadoes":	{"NNS"},
"tornados":	{"NNS"},
"tornillo":	{"NN"},
"torodal":	{"NN"},
"toroid":	{"NN"},
"toroidal":	{"JJ"},
"toronto":	{"NN"},
"torpedinidae":	{"NN"},
"torpediniformes":	{"NNS"},
"torpedo":	{"NN","VB","VBP"},
"torpedoed":	{"VBD","VBN"},
"torpedoes":	{"NNS","VBZ"},
"torpedoing":	{"VBG"},
"torpid":	{"JJ"},
"torpidity":	{"NN"},
"torpidly":	{"RB"},
"torpidness":	{"NN"},
"torpor":	{"NN"},
"torque":	{"NN"},
"torquemada":	{"NN"},
"torquer":	{"NN"},
"torquers":	{"NNS"},
"torr":	{"NN"},
"torrent":	{"NN"},
"torrential":	{"JJ"},
"torrents":	{"NNS"},
"torreon":	{"NN"},
"torreya":	{"NN"},
"torricelli":	{"NN"},
"torrid":	{"JJ"},
"torridity":	{"NN"},
"torsion":	{"NN"},
"torsk":	{"NN"},
"torso":	{"NN"},
"torsos":	{"NNS"},
"tort":	{"NN"},
"torte":	{"NN"},
"tortellini":	{"NN"},
"tortfeasor":	{"NN"},
"torticollis":	{"NN"},
"tortilla":	{"NN"},
"tortillas":	{"NNS"},
"tortious":	{"JJ"},
"tortoise":	{"NN"},
"tortoises":	{"NNS"},
"tortoiseshell":	{"NN"},
"tortoiseshells":	{"NNS"},
"tortricid":	{"NN"},
"tortricidae":	{"NN"},
"tortrix":	{"NN"},
"torts":	{"NNS"},
"tortuosity":	{"NN"},
"tortuous":	{"JJ"},
"tortuously":	{"RB"},
"tortuousness":	{"NN"},
"torture":	{"NN","VBP","VB"},
"tortured":	{"VBD","VBN","JJ"},
"torturedly":	{"RB"},
"torturer":	{"NN"},
"torturers":	{"NNS"},
"tortures":	{"NNS","VBZ"},
"torturesome":	{"JJ"},
"torturing":	{"VBG","JJ"},
"torturingly":	{"RB"},
"torturous":	{"JJ"},
"torturously":	{"RB"},
"torulose":	{"JJ"},
"torus":	{"NN"},
"toscana":	{"NN"},
"toscanini":	{"NN"},
"tosh":	{"NN"},
"tosk":	{"NN"},
"toss":	{"VB","VBP","NN"},
"toss-up":	{"NN"},
"toss-ups":	{"NNS"},
"tossed":	{"VBD","VBN"},
"tosser":	{"NN"},
"tossers":	{"NNS"},
"tosses":	{"VBZ","NNS"},
"tossing":	{"VBG"},
"tossup":	{"NN"},
"tostada":	{"NN"},
"tot":	{"NN","VB","VBP"},
"total":	{"JJ","NN","VB","VBP"},
"totaled":	{"VBD","VBN"},
"totaling":	{"VBG"},
"totalisation":	{"NN"},
"totalisator":	{"NN"},
"totalise":	{"VB","VBP"},
"totaliser":	{"NN"},
"totalism":	{"NN"},
"totalistic":	{"JJ"},
"totalitarian":	{"JJ","NN"},
"totalitarianism":	{"NN"},
"totalitarians":	{"NNS"},
"totality":	{"NN"},
"totalization":	{"NN"},
"totalizator":	{"NN"},
"totalize":	{"VB","VBP"},
"totalizer":	{"NN"},
"totalled":	{"VBD","VBN"},
"totalling":	{"VBG"},
"totally":	{"RB"},
"totals":	{"NNS","VBZ"},
"totara":	{"NN"},
"tote":	{"NN","VB","VBP"},
"toted":	{"VBD","VBN"},
"totem":	{"NN"},
"totemic":	{"JJ"},
"totemism":	{"NN"},
"totemist":	{"NN"},
"toter":	{"NN"},
"totes":	{"VBZ"},
"toting":	{"VBG","NN"},
"totipotence":	{"NN"},
"totipotency":	{"NN"},
"totipotent":	{"NN"},
"toto":	{"NN"},
"tots":	{"NNS","VBZ"},
"totted":	{"VBD","VBN"},
"totter":	{"VB","VBP"},
"tottered":	{"VBD","VBN"},
"totterer":	{"NN"},
"tottering":	{"VBG"},
"totters":	{"VBZ"},
"tottery":	{"JJ"},
"totting":	{"VBG"},
"toucan":	{"NN"},
"toucanet":	{"NN"},
"toucans":	{"NNS"},
"touch":	{"NN","VB","VBP"},
"touch-and-go":	{"JJ"},
"touch-judge":	{"NN"},
"touch-line":	{"NN"},
"touch-me-not":	{"NN"},
"touch-screen":	{"JJ"},
"touch-tone":	{"JJ"},
"touch-type":	{"VB","VBP"},
"touch-typed":	{"VBD","VBN"},
"touch-types":	{"VBZ"},
"touch-typing":	{"VBG"},
"touch-typist":	{"NN"},
"touchable":	{"JJ"},
"touchback":	{"NN"},
"touchdown":	{"NN"},
"touchdowns":	{"NNS"},
"touched":	{"VBD","VBN","JJ"},
"toucher":	{"NN"},
"touches":	{"NNS","VBZ"},
"touchier":	{"JJR"},
"touchiest":	{"JJS"},
"touchily":	{"RB"},
"touchiness":	{"NN"},
"touching":	{"VBG","JJ","IN"},
"touchingly":	{"RB"},
"touchline":	{"NN"},
"touchscreen":	{"NN"},
"touchstone":	{"NN"},
"touchstones":	{"NNS"},
"touchwood":	{"NN"},
"touchy":	{"JJ"},
"touchy-feely":	{"JJ"},
"tough":	{"JJ","VB","VBP","RB","NN"},
"toughed":	{"VBD","VBN"},
"toughen":	{"VB","VBP"},
"toughened":	{"VBD","VBN"},
"toughening":	{"VBG"},
"toughens":	{"VBZ"},
"tougher":	{"JJR"},
"toughest":	{"JJS"},
"toughie":	{"NN"},
"toughing":	{"VBG"},
"toughly":	{"RB"},
"toughness":	{"NN"},
"toughs":	{"NNS","VBZ"},
"toulon":	{"NN"},
"toulouse":	{"NN"},
"toulouse-lautrec":	{"NN"},
"toupee":	{"NN"},
"toupeed":	{"JJ"},
"toupees":	{"NNS"},
"tour":	{"NN","VB","VBP"},
"touraco":	{"NN"},
"toured":	{"VBD","VBN"},
"tourer":	{"NN"},
"tourette":	{"NN"},
"touring":	{"VBG","NN"},
"tourism":	{"NN"},
"tourist":	{"NN"},
"touristed":	{"JJ"},
"touristry":	{"NN"},
"tourists":	{"NNS"},
"touristy":	{"JJ"},
"tourmaline":	{"NN"},
"tournament":	{"NN"},
"tournaments":	{"NNS"},
"tournedos":	{"NN","NNS","FW"},
"tourney":	{"NN","VB","VBP"},
"tourneyed":	{"VBD","VBN"},
"tourneyer":	{"NN"},
"tourneying":	{"VBG"},
"tourneys":	{"NNS","VBZ"},
"tourniquet":	{"NN"},
"tourniquets":	{"NNS"},
"tours":	{"NNS","VBZ"},
"tourtiere":	{"NN"},
"tousle":	{"VB","VBP"},
"tousled":	{"JJ","VBD","VBN"},
"tout":	{"VB","VBP","NN"},
"touted":	{"VBD","VBN"},
"touter":	{"NN"},
"touting":	{"VBG"},
"touts":	{"VBZ","NNS"},
"tovarich":	{"NN"},
"tovarisch":	{"NN"},
"tow":	{"VB","VBP","NN"},
"tow-bar":	{"NN"},
"tow-line":	{"NN"},
"tow-path":	{"NN"},
"tow-rope":	{"NN"},
"towage":	{"NN"},
"toward":	{"IN"},
"towards":	{"IN"},
"towboat":	{"NN"},
"towboats":	{"NNS"},
"towed":	{"VBD","VBN"},
"towel":	{"NN","VB","VBP"},
"toweled":	{"VBD","VBN"},
"toweling":	{"NN","VBG"},
"towelled":	{"VBD","VBN"},
"towelling":	{"NN","VBG"},
"towels":	{"NNS","VBZ"},
"tower":	{"NN","VB","VBP"},
"towered":	{"VBD","VBN"},
"towering":	{"JJ","VBG"},
"towers":	{"NNS","VBZ"},
"towhead":	{"NN"},
"towheaded":	{"JJ"},
"towhee":	{"NN"},
"towing":	{"VBG","NN"},
"towline":	{"NN"},
"town":	{"NN"},
"townee":	{"NN"},
"towner":	{"NN"},
"townhouse":	{"NN"},
"townhouses":	{"NNS"},
"townie":	{"NN"},
"townies":	{"NNS"},
"towns":	{"NNS"},
"townsend":	{"NN"},
"townsendia":	{"NN"},
"townsfolk":	{"NNS"},
"township":	{"NN"},
"townships":	{"NNS"},
"townsman":	{"NN"},
"townsmen":	{"NNS"},
"townspeople":	{"NNS"},
"towny":	{"NN"},
"towpath":	{"NN"},
"towpaths":	{"NNS"},
"towrope":	{"NN"},
"towropes":	{"NNS"},
"tows":	{"VBZ"},
"toxaemia":	{"NN"},
"toxemia":	{"NN"},
"toxic":	{"JJ"},
"toxicant":	{"JJ","NN"},
"toxicities":	{"NNS"},
"toxicity":	{"NN"},
"toxicodendron":	{"NN"},
"toxicognath":	{"NN"},
"toxicologic":	{"JJ"},
"toxicological":	{"JJ"},
"toxicologist":	{"NN"},
"toxicologists":	{"NNS"},
"toxicology":	{"NN"},
"toxics":	{"NNS"},
"toxin":	{"NN"},
"toxins":	{"NNS"},
"toxoid":	{"NN"},
"toxoplasmosis":	{"NN"},
"toxostoma":	{"NN"},
"toxotidae":	{"NN"},
"toy":	{"NN","JJ","VB","VBP"},
"toyed":	{"VBD","VBN"},
"toying":	{"VBG"},
"toymaker":	{"NN"},
"toymakers":	{"NNS"},
"toynbee":	{"NN"},
"toyohashi":	{"NN"},
"toyon":	{"NN"},
"toyonaki":	{"NN"},
"toyota":	{"NN"},
"toyotas":	{"NNS"},
"toys":	{"NNS","VBZ"},
"toyshop":	{"NN"},
"trabeate":	{"JJ"},
"trabeated":	{"JJ"},
"trabecula":	{"NN"},
"trabecular":	{"JJ"},
"trabeculate":	{"JJ"},
"trablous":	{"NN"},
"trace":	{"VB","NN","VBP"},
"traceable":	{"JJ"},
"traced":	{"VBN","VBD"},
"tracer":	{"NN"},
"traceries":	{"NNS"},
"tracers":	{"NNS"},
"tracery":	{"NN"},
"traces":	{"NNS","VBZ"},
"trachea":	{"NN"},
"tracheae":	{"NNS"},
"tracheal":	{"JJ"},
"tracheas":	{"NNS"},
"tracheid":	{"NN"},
"tracheitis":	{"NN"},
"trachelospermum":	{"NN"},
"tracheobronchitis":	{"NN"},
"tracheophyta":	{"NN"},
"tracheophyte":	{"NN"},
"tracheostomy":	{"NN"},
"tracheotomies":	{"NNS"},
"tracheotomy":	{"NN"},
"trachinotus":	{"NN"},
"trachipteridae":	{"NN"},
"trachipterus":	{"NN"},
"trachodon":	{"NN"},
"trachodont":	{"NN"},
"trachoma":	{"NN"},
"trachurus":	{"NN"},
"tracing":	{"NN","VBG"},
"tracing-paper":	{"NN"},
"tracings":	{"NNS"},
"track":	{"NN","VB","VBP"},
"trackable":	{"JJ"},
"trackage":	{"NN"},
"trackball":	{"NN"},
"trackballs":	{"NNS"},
"tracked":	{"VBN","VBD","JJ"},
"tracker":	{"NN"},
"trackers":	{"NNS"},
"tracking":	{"VBG","NN"},
"tracklayer":	{"NN"},
"trackless":	{"JJ"},
"tracks":	{"NNS","VBZ"},
"tract":	{"NN"},
"tractability":	{"NN"},
"tractable":	{"JJ"},
"tractableness":	{"NN"},
"tractarians":	{"NNS"},
"tractile":	{"JJ"},
"traction":	{"NN"},
"tractive":	{"JJ"},
"tractor":	{"NN"},
"tractor-trailer":	{"NN"},
"tractor-trailers":	{"NNS"},
"tractors":	{"NNS"},
"tracts":	{"NNS"},
"tracy":	{"NN"},
"trad":	{"NN"},
"trade":	{"NN","VB","VBP"},
"trade-in":	{"NN"},
"trade-ins":	{"NNS"},
"trade-off":	{"NN"},
"trade-offs":	{"NNS"},
"tradeable":	{"JJ"},
"tradecraft":	{"NN"},
"traded":	{"VBN","VBD"},
"tradedistorting":	{"JJ"},
"trademark":	{"NN","VB","VBP"},
"trademarked":	{"VBD","VBN"},
"trademarking":	{"VBG"},
"trademarks":	{"NNS","VBZ"},
"tradeoff":	{"NN"},
"tradeoffs":	{"NNS"},
"trader":	{"NN"},
"traders":	{"NNS"},
"trades":	{"NNS","VBZ"},
"tradescantia":	{"NN"},
"tradesman":	{"NN"},
"tradesmen":	{"NNS"},
"tradespeople":	{"NNS"},
"trading":	{"VBG","NN"},
"tradition":	{"NN"},
"traditional":	{"JJ"},
"traditionalise":	{"VB","VBP"},
"traditionalism":	{"NN"},
"traditionalist":	{"NN","JJ"},
"traditionalistic":	{"JJ"},
"traditionalists":	{"NNS"},
"traditionality":	{"NN"},
"traditionalize":	{"VB","VBP"},
"traditionalized":	{"VBD","VBN"},
"traditionalizes":	{"VBZ"},
"traditionalizing":	{"VBG"},
"traditionally":	{"RB"},
"traditions":	{"NNS"},
"traduce":	{"VB","VBP"},
"traduced":	{"VBD","VBN"},
"traducement":	{"NN"},
"traducer":	{"NN"},
"traduces":	{"VBZ"},
"traducing":	{"VBG"},
"traffic":	{"NN","VBP","VB"},
"traffic-light":	{"NN"},
"traffic-lights":	{"NNS"},
"trafficator":	{"NN"},
"trafficked":	{"VBD","VBN"},
"trafficker":	{"NN"},
"traffickers":	{"NNS"},
"trafficking":	{"NN","VBG"},
"traffics":	{"VBZ"},
"tragacanth":	{"NN"},
"tragedian":	{"NN"},
"tragedians":	{"NNS"},
"tragedienne":	{"NN"},
"tragedies":	{"NNS"},
"tragedy":	{"NN"},
"tragelaphus":	{"NN"},
"tragi-comic":	{"JJ"},
"tragic":	{"JJ"},
"tragical":	{"JJ"},
"tragically":	{"RB"},
"tragicomedies":	{"NNS"},
"tragicomedy":	{"NN"},
"tragicomic":	{"JJ"},
"tragicomical":	{"JJ"},
"tragopan":	{"NN"},
"tragopogon":	{"NN"},
"tragulidae":	{"NN"},
"tragulus":	{"NN"},
"tragus":	{"NN"},
"trail":	{"NN","VB","VBP"},
"trail-blazer":	{"NN"},
"trail-blazing":	{"JJ"},
"trailblazer":	{"NN"},
"trailblazers":	{"NNS"},
"trailblazing":	{"JJ"},
"trailed":	{"VBD","VBN"},
"trailer":	{"NN","VB","VBP"},
"trailered":	{"VBD","VBN"},
"trailering":	{"VBG"},
"trailers":	{"NNS","VBZ"},
"trailhead":	{"NN"},
"trailing":	{"VBG","JJ"},
"trails":	{"NNS","VBZ"},
"train":	{"NN","VB","VBP"},
"train-bearer":	{"NN"},
"train-spotter":	{"NN"},
"trainband":	{"NN"},
"trainbandsman":	{"NN"},
"trainbearer":	{"NN"},
"trained":	{"VBN","VBD"},
"trainee":	{"NN"},
"trainees":	{"NNS"},
"traineeship":	{"NN"},
"traineeships":	{"NNS"},
"trainer":	{"NN"},
"trainers":	{"NNS"},
"training":	{"NN","VBG"},
"training-college":	{"NN"},
"training-colleges":	{"NNS"},
"trainload":	{"NN"},
"trainman":	{"NN"},
"trainmaster":	{"NN"},
"trainmen":	{"NNS"},
"trains":	{"NNS","VBZ"},
"traipse":	{"VB","VBP"},
"traipsed":	{"VBD","VBN"},
"traipses":	{"VBZ"},
"traipsing":	{"VBG"},
"trait":	{"NN"},
"traitor":	{"NN"},
"traitorous":	{"JJ"},
"traitorously":	{"RB"},
"traitorousness":	{"NN"},
"traitors":	{"NNS"},
"traitress":	{"NN"},
"traits":	{"NNS"},
"trajan":	{"NN"},
"trajectories":	{"NNS"},
"trajectory":	{"NN"},
"tralatitious":	{"JJ"},
"tram":	{"NN"},
"tramcar":	{"NN"},
"tramcars":	{"NNS"},
"tramline":	{"NN"},
"tramlines":	{"NNS"},
"trammel":	{"VB","VBP"},
"trammeled":	{"VBD","VBN"},
"trammeling":	{"VBG"},
"trammelled":	{"VBD","VBN"},
"trammelling":	{"VBG"},
"trammels":	{"VBZ","NNS"},
"tramontana":	{"NN"},
"tramontane":	{"JJ","NN"},
"tramontanes":	{"NNS"},
"tramp":	{"VB","VBP","NN"},
"tramped":	{"VBD","VBN"},
"tramper":	{"NN"},
"tramping":	{"VBG"},
"trample":	{"VB","VBP","NN"},
"trampled":	{"VBD","VBN"},
"trampler":	{"NN"},
"tramples":	{"VBZ","NNS"},
"trampling":	{"VBG"},
"trampoline":	{"NN"},
"trampolines":	{"NNS"},
"tramps":	{"NNS","VBZ"},
"trams":	{"NNS"},
"tramway":	{"NN"},
"tramways":	{"NNS"},
"trance":	{"NN"},
"trancelike":	{"JJ"},
"trances":	{"NNS"},
"tranche":	{"NN"},
"tranches":	{"NNS"},
"trandate":	{"NN"},
"trandolapril":	{"NN"},
"tranquil":	{"JJ"},
"tranquilise":	{"VB","VBP"},
"tranquilised":	{"VBD","VBN"},
"tranquiliser":	{"NN"},
"tranquilisers":	{"NNS"},
"tranquilises":	{"VBZ"},
"tranquilising":	{"VBG"},
"tranquility":	{"NN"},
"tranquilize":	{"VB","VBP"},
"tranquilized":	{"VBD","VBN"},
"tranquilizer":	{"NN"},
"tranquilizers":	{"NNS"},
"tranquilizes":	{"VBZ"},
"tranquilizing":	{"VBG"},
"tranquillise":	{"VB","VBP"},
"tranquillised":	{"VBD","VBN"},
"tranquilliser":	{"NN"},
"tranquillisers":	{"NNS"},
"tranquillises":	{"VBZ"},
"tranquillising":	{"VBG"},
"tranquillity":	{"NN"},
"tranquillize":	{"VB","VBP"},
"tranquillized":	{"VBD","VBN"},
"tranquillizer":	{"NN"},
"tranquillizers":	{"NNS"},
"tranquillizes":	{"VBZ"},
"tranquillizing":	{"VBG"},
"tranquilly":	{"RB"},
"trans-woman":	{"NN"},
"trans-women":	{"NNS"},
"transact":	{"VB","VBP"},
"transacted":	{"VBD","VBN"},
"transacting":	{"VBG"},
"transactinide":	{"JJ","NN"},
"transaction":	{"NN"},
"transactions":	{"NNS"},
"transactor":	{"NN"},
"transacts":	{"VBZ"},
"transalpine":	{"JJ","NN"},
"transalpines":	{"NNS"},
"transaminase":	{"NN"},
"transamination":	{"NN"},
"transatlantic":	{"JJ"},
"transbay":	{"JJ"},
"transborder":	{"JJ"},
"transboundary":	{"JJ"},
"transcaucasia":	{"NN"},
"transcaucasian":	{"JJ"},
"transcend":	{"VB","VBP"},
"transcendant":	{"JJ"},
"transcended":	{"VBD","VBN"},
"transcendence":	{"NN"},
"transcendency":	{"NN"},
"transcendent":	{"JJ"},
"transcendental":	{"JJ"},
"transcendentalism":	{"NN"},
"transcendentalist":	{"NN"},
"transcendentally":	{"RB"},
"transcending":	{"VBG"},
"transcends":	{"VBZ"},
"transcontinental":	{"JJ"},
"transcribe":	{"VB","VBP"},
"transcribed":	{"VBD","VBN"},
"transcriber":	{"NN"},
"transcribes":	{"VBZ"},
"transcribing":	{"VBG"},
"transcript":	{"NN"},
"transcriptase":	{"NN"},
"transcription":	{"NN"},
"transcriptions":	{"NNS"},
"transcriptomics":	{"NNS"},
"transcripts":	{"NNS"},
"transcultural":	{"JJ"},
"transcutaneous":	{"JJ"},
"transdermal":	{"JJ"},
"transdermic":	{"JJ"},
"transduce":	{"VB","VBP"},
"transducer":	{"NN"},
"transducers":	{"NNS"},
"transduction":	{"NN"},
"transect":	{"VB","VBP"},
"transept":	{"NN"},
"transepts":	{"NNS"},
"transeunt":	{"JJ"},
"transexual":	{"NN"},
"transfer":	{"NN","VB","VBP"},
"transferability":	{"NN"},
"transferable":	{"JJ"},
"transferal":	{"NN"},
"transferase":	{"NN"},
"transferee":	{"NN"},
"transference":	{"NN"},
"transferer":	{"NN"},
"transferor":	{"NN"},
"transferors":	{"NNS"},
"transferrable":	{"JJ"},
"transferral":	{"NN"},
"transferred":	{"VBN","VBD"},
"transferrer":	{"NN"},
"transferrin":	{"NN"},
"transferring":	{"VBG"},
"transfers":	{"NNS","VBZ"},
"transfiguration":	{"NN"},
"transfigure":	{"VB","VBP"},
"transfigured":	{"VBD","VBN"},
"transfigures":	{"VBZ"},
"transfiguring":	{"VBG"},
"transfix":	{"VB","VBP"},
"transfixed":	{"JJ","VBD","VBN"},
"transfixes":	{"VBZ"},
"transfixing":	{"VBG"},
"transform":	{"VB","VBP"},
"transformable":	{"JJ"},
"transformation":	{"NN"},
"transformations":	{"NNS"},
"transformed":	{"VBN","VBD"},
"transformer":	{"NN"},
"transformers":	{"NNS"},
"transforming":	{"VBG"},
"transforms":	{"VBZ"},
"transfusable":	{"JJ"},
"transfuse":	{"VB","VBP"},
"transfused":	{"VBD","VBN"},
"transfuser":	{"NN"},
"transfuses":	{"VBZ"},
"transfusible":	{"JJ"},
"transfusing":	{"VBG"},
"transfusion":	{"NN"},
"transfusions":	{"NNS"},
"transfusive":	{"JJ"},
"transgender":	{"JJ","NN"},
"transgendered":	{"JJ"},
"transgenderism":	{"NN"},
"transgenders":	{"NNS"},
"transgene":	{"NN"},
"transgenic":	{"JJ"},
"transgress":	{"VB","VBP"},
"transgressed":	{"VBD","VBN"},
"transgresses":	{"VBZ"},
"transgressing":	{"VBG"},
"transgression":	{"NN"},
"transgressions":	{"NNS"},
"transgressor":	{"NN"},
"transgressors":	{"NNS"},
"transience":	{"NN"},
"transiency":	{"NN"},
"transient":	{"JJ","NN"},
"transiently":	{"RB"},
"transients":	{"NNS"},
"transistor":	{"NN"},
"transistorise":	{"VB","VBP"},
"transistorised":	{"JJ","VBD","VBN"},
"transistorises":	{"VBZ"},
"transistorising":	{"VBG"},
"transistorize":	{"VB","VBP"},
"transistorized":	{"JJ","VBD","VBN"},
"transistorizes":	{"VBZ"},
"transistorizing":	{"VBG"},
"transistors":	{"NNS"},
"transit":	{"NN","VB","VBP"},
"transit-association":	{"NN"},
"transited":	{"VBD","VBN"},
"transiting":	{"VBG"},
"transition":	{"NN","VB","VBP"},
"transitional":	{"JJ"},
"transitionally":	{"RB"},
"transitioned":	{"VBD","VBN"},
"transitioning":	{"VBG"},
"transitions":	{"NNS","VBZ"},
"transitive":	{"JJ","NN"},
"transitively":	{"RB"},
"transitiveness":	{"NN"},
"transitivity":	{"NN"},
"transitorily":	{"RB"},
"transitoriness":	{"NN"},
"transitory":	{"JJ"},
"transits":	{"VBZ"},
"translatable":	{"JJ"},
"translate":	{"VB","VBP"},
"translated":	{"VBN","VBD"},
"translates":	{"VBZ"},
"translating":	{"VBG"},
"translation":	{"NN"},
"translational":	{"JJ"},
"translations":	{"NNS"},
"translatology":	{"NN"},
"translator":	{"NN"},
"translators":	{"NNS"},
"transliterate":	{"VB","VBP"},
"transliterated":	{"VBD","VBN"},
"transliterates":	{"VBZ"},
"transliterating":	{"VBG"},
"transliteration":	{"NN"},
"transliterations":	{"NNS"},
"translocate":	{"VB","VBP"},
"translocated":	{"VBD","VBN"},
"translocates":	{"VBZ"},
"translocating":	{"VBG"},
"translocation":	{"NN"},
"translocations":	{"NNS"},
"translucence":	{"NN"},
"translucency":	{"NN"},
"translucent":	{"JJ"},
"transluminal":	{"JJ"},
"translunar":	{"JJ"},
"translunary":	{"JJ"},
"transmasculine":	{"JJ"},
"transmigrate":	{"VB","VBP"},
"transmigrated":	{"VBD","VBN"},
"transmigrates":	{"VBZ"},
"transmigrating":	{"VBG"},
"transmigration":	{"NN"},
"transmissible":	{"JJ"},
"transmission":	{"NN"},
"transmissions":	{"NNS"},
"transmit":	{"VB","VBP"},
"transmits":	{"VBZ"},
"transmittable":	{"JJ"},
"transmittal":	{"NN"},
"transmittance":	{"NN"},
"transmitted":	{"VBN","VBD"},
"transmitter":	{"NN"},
"transmitters":	{"NNS"},
"transmitting":	{"VBG"},
"transmogrification":	{"NN"},
"transmogrified":	{"VBD","VBN"},
"transmogrifies":	{"VBZ"},
"transmogrify":	{"VB","VBP"},
"transmogrifying":	{"VBG"},
"transmontane":	{"JJ"},
"transmundane":	{"JJ"},
"transmutability":	{"NN"},
"transmutable":	{"JJ"},
"transmutation":	{"NN"},
"transmutations":	{"NNS"},
"transmute":	{"VB","VBP"},
"transmuted":	{"VBD","VBN"},
"transmutes":	{"VBZ"},
"transmuting":	{"VBG"},
"transnational":	{"JJ"},
"transoceanic":	{"JJ"},
"transom":	{"NN"},
"transoms":	{"NNS"},
"transonic":	{"JJ"},
"transparence":	{"NN"},
"transparencies":	{"NNS"},
"transparency":	{"NN"},
"transparent":	{"JJ"},
"transparently":	{"RB"},
"transparentness":	{"NN"},
"transphobia":	{"NN"},
"transphobic":	{"JJ"},
"transpiration":	{"NN"},
"transpire":	{"VB","VBP"},
"transpired":	{"VBD","VBN"},
"transpires":	{"VBZ"},
"transpiring":	{"VBG"},
"transplacental":	{"JJ"},
"transplant":	{"VB","VBP","NN"},
"transplantable":	{"JJ"},
"transplantation":	{"NN"},
"transplanted":	{"VBD","VBN"},
"transplanter":	{"NN"},
"transplanting":	{"VBG"},
"transplants":	{"NNS","VBZ"},
"transpolar":	{"JJ"},
"transponder":	{"NN"},
"transponders":	{"NNS"},
"transport":	{"VB","VBP","NN"},
"transportable":	{"JJ"},
"transportation":	{"NN"},
"transported":	{"VBD","VBN"},
"transporter":	{"NN"},
"transporters":	{"NNS"},
"transporting":	{"VBG"},
"transports":	{"NNS","VBZ"},
"transposability":	{"NN"},
"transposable":	{"JJ"},
"transpose":	{"VB","VBP"},
"transposed":	{"VBD","VBN"},
"transposes":	{"VBZ"},
"transposing":	{"VBG"},
"transposition":	{"NN"},
"transpositions":	{"NNS"},
"transposon":	{"NN"},
"transsexual":	{"JJ","NN"},
"transsexualism":	{"NN"},
"transsexuals":	{"NNS"},
"transship":	{"VB","VBP"},
"transshipment":	{"NN"},
"transshipped":	{"VBD","VBN"},
"transshipping":	{"VBG"},
"transships":	{"VBZ"},
"transubstantiate":	{"VB","VBP"},
"transubstantiated":	{"VBD","VBN"},
"transubstantiates":	{"VBZ"},
"transubstantiating":	{"VBG"},
"transubstantiation":	{"NN"},
"transudate":	{"NN"},
"transudation":	{"NN"},
"transude":	{"VB","VBP"},
"transuranic":	{"JJ"},
"transvaal":	{"NN"},
"transversal":	{"JJ","NN"},
"transversally":	{"RB"},
"transverse":	{"JJ","NN"},
"transversely":	{"RB"},
"transverseness":	{"NN"},
"transversus":	{"NN"},
"transvestic":	{"JJ"},
"transvestism":	{"NN"},
"transvestite":	{"NN","JJ"},
"transvestites":	{"NNS"},
"transvestitism":	{"NN"},
"transwoman":	{"NN"},
"transwomen":	{"NNS"},
"transylvania":	{"NN"},
"tranylcypromine":	{"NN"},
"trap":	{"NN","VB","VBP"},
"trap-shooting":	{"NN"},
"trapa":	{"NN"},
"trapaceae":	{"NN"},
"trapan":	{"VB","VBP"},
"trapanned":	{"VBD","VBN"},
"trapanner":	{"NN"},
"trapanning":	{"VBG"},
"trapans":	{"VBZ"},
"trapdoor":	{"NN"},
"trapdoors":	{"NNS"},
"trapeze":	{"NN"},
"trapezes":	{"NNS"},
"trapezium":	{"NN"},
"trapeziums":	{"NNS"},
"trapezius":	{"NN"},
"trapeziuses":	{"NNS"},
"trapezohedra":	{"NNS"},
"trapezohedron":	{"NN"},
"trapezohedrons":	{"NNS"},
"trapezoid":	{"NN"},
"trapezoidal":	{"JJ"},
"trapezoids":	{"NNS"},
"trapped":	{"VBN","VBD","JJ"},
"trapper":	{"NN"},
"trappers":	{"NNS"},
"trapping":	{"VBG"},
"traps":	{"NNS","VBZ"},
"trapshooter":	{"NN"},
"trapshooting":	{"NN"},
"trash":	{"NN","VB","VBP"},
"trashcan":	{"NN"},
"trashed":	{"VBD","VBN","JJ"},
"trashes":	{"VBZ"},
"trashier":	{"JJR"},
"trashiest":	{"JJS"},
"trashiness":	{"NN"},
"trashing":	{"VBG"},
"trashy":	{"JJ"},
"trauma":	{"NN","NNS"},
"traumas":	{"NNS"},
"traumatic":	{"JJ"},
"traumatically":	{"RB"},
"traumatise":	{"VB","VBP"},
"traumatised":	{"VBD","VBN","JJ"},
"traumatises":	{"VBZ"},
"traumatising":	{"VBG"},
"traumatize":	{"VB","VBP"},
"traumatized":	{"VBD","VBN","JJ"},
"traumatizes":	{"VBZ"},
"traumatizing":	{"VBG"},
"traumatology":	{"NN"},
"traumatophobia":	{"NN"},
"trautvetteria":	{"NN"},
"travail":	{"NN","VB","VBP"},
"travailed":	{"VBD","VBN"},
"travailing":	{"VBG"},
"travails":	{"NNS","VBZ"},
"trave":	{"NN"},
"travel":	{"VB","VBP","NN"},
"travel-sick":	{"JJ"},
"travel-sickness":	{"NN"},
"travelable":	{"JJ"},
"traveled":	{"VBN","VBD"},
"traveler":	{"NN"},
"travelers":	{"NNS"},
"traveling":	{"VBG","NN","JJ"},
"travelled":	{"VBD","VBN"},
"traveller":	{"NN"},
"travellers":	{"NNS"},
"travelling":	{"NN","JJ","VBG"},
"travelog":	{"NN"},
"travelogs":	{"NNS"},
"travelogue":	{"NN"},
"travelogues":	{"NNS"},
"travelrestrictions":	{"NNS"},
"travels":	{"VBZ","NNS"},
"traversable":	{"JJ"},
"traversal":	{"NN"},
"traverse":	{"VB","VBP","NN"},
"traversed":	{"VBD","VBN"},
"traverser":	{"NN"},
"traversers":	{"NNS"},
"traverses":	{"VBZ","NNS"},
"traversing":	{"VBG"},
"travestied":	{"VBD","VBN"},
"travesties":	{"NNS","VBZ"},
"travesty":	{"NN","VB","VBP"},
"travestying":	{"VBG"},
"trawl":	{"NN","VB","VBP"},
"trawled":	{"VBD","VBN"},
"trawler":	{"NN"},
"trawlers":	{"NNS"},
"trawling":	{"VBG"},
"trawls":	{"NNS","VBZ"},
"tray":	{"NN"},
"trays":	{"NNS"},
"trazodone":	{"NN"},
"treacheries":	{"NNS"},
"treacherous":	{"JJ"},
"treacherously":	{"RB"},
"treachery":	{"NN"},
"treacle":	{"NN"},
"treacly":	{"JJ"},
"tread":	{"VB","VBP","NN"},
"treading":	{"VBG"},
"treadle":	{"NN","VB","VBP"},
"treadled":	{"VBD","VBN"},
"treadles":	{"NNS","VBZ"},
"treadling":	{"VBG"},
"treadmill":	{"NN"},
"treadmills":	{"NNS"},
"treads":	{"VBZ","NNS"},
"treadwheel":	{"NN"},
"treason":	{"NN"},
"treasonable":	{"JJ"},
"treasonably":	{"RB"},
"treasonous":	{"JJ"},
"treasure":	{"NN","VB","VBP"},
"treasure-house":	{"NN"},
"treasure-hunt":	{"NN"},
"treasured":	{"VBD","VBN","JJ"},
"treasurer":	{"NN"},
"treasurers":	{"NNS"},
"treasurership":	{"NN"},
"treasures":	{"NNS","VBZ"},
"treasuries":	{"NNS"},
"treasuring":	{"VBG"},
"treasury":	{"NN"},
"treat":	{"VB","VBP","NN"},
"treatable":	{"JJ"},
"treated":	{"VBN","VBD"},
"treater":	{"NN"},
"treaties":	{"NNS"},
"treating":	{"VBG"},
"treatise":	{"NN"},
"treatises":	{"NNS"},
"treatment":	{"NN"},
"treatments":	{"NNS"},
"treats":	{"VBZ","NNS"},
"treaty":	{"NN"},
"treble":	{"NN","JJ","VB","VBP"},
"trebled":	{"VBD","VBN"},
"trebles":	{"NNS","VBZ"},
"trebling":	{"VBG","NN"},
"trebuchet":	{"NN"},
"trebucket":	{"NN"},
"tree":	{"NN","VB","VBP"},
"tree-fern":	{"NN"},
"tree-house":	{"NN"},
"tree-line":	{"NN"},
"tree-lined":	{"JJ"},
"tree-top":	{"NN"},
"tree-tops":	{"NNS"},
"treed":	{"JJ","VBD","VBN"},
"treehopper":	{"NN"},
"treehouse":	{"NN"},
"treehouses":	{"NNS"},
"treeing":	{"VBG"},
"treeless":	{"JJ"},
"treelet":	{"NN"},
"treelike":	{"JJ"},
"treenail":	{"NN"},
"trees":	{"NNS","VBZ"},
"treetop":	{"NN"},
"treetops":	{"NNS"},
"tref":	{"NN"},
"trefoil":	{"NN"},
"trefoils":	{"NNS"},
"trehalose":	{"NN"},
"trehaloses":	{"NNS"},
"treillage":	{"NN"},
"treillages":	{"NNS"},
"trek":	{"NN","VB","VBP"},
"trekked":	{"VBD","VBN"},
"trekker":	{"NN"},
"trekking":	{"VBG"},
"treks":	{"VBZ","NNS"},
"trellis":	{"NN"},
"trellises":	{"NNS"},
"trema":	{"NN"},
"trematoda":	{"NN"},
"trematode":	{"NN"},
"tremble":	{"VB","VBP","NN"},
"trembled":	{"VBD","VBN"},
"trembler":	{"NN"},
"trembles":	{"VBZ"},
"trembling":	{"VBG"},
"tremella":	{"NN"},
"tremellaceae":	{"NN"},
"tremellales":	{"NNS"},
"tremendous":	{"JJ"},
"tremendously":	{"RB"},
"tremolite":	{"NN"},
"tremolo":	{"NN"},
"tremolos":	{"NNS"},
"tremor":	{"NN"},
"tremorous":	{"JJ"},
"tremors":	{"NNS"},
"tremulous":	{"JJ"},
"tremulously":	{"RB"},
"trenail":	{"NN"},
"trench":	{"NN","VB","VBP"},
"trenchancy":	{"NN"},
"trenchant":	{"JJ"},
"trenchantly":	{"RB"},
"trenched":	{"VBD","VBN"},
"trencher":	{"NN"},
"trencherman":	{"NN"},
"trenchermen":	{"NNS"},
"trenches":	{"NNS","VBZ"},
"trenching":	{"VBG"},
"trend":	{"NN","VB","VBP"},
"trend-setter":	{"NN"},
"trend-setters":	{"NNS"},
"trend-setting":	{"JJ"},
"trended":	{"VBD","VBN"},
"trendier":	{"JJR"},
"trendies":	{"NNS"},
"trendiest":	{"JJS"},
"trending":	{"NN","VBG"},
"trends":	{"NNS","VBZ"},
"trendsetter":	{"NN"},
"trendsetters":	{"NNS"},
"trendsetting":	{"JJ"},
"trendy":	{"JJ","NN"},
"trent":	{"NN"},
"trenton":	{"NN"},
"trepan":	{"VB","VBP","NN"},
"trepang":	{"NN"},
"trepanned":	{"VBD","VBN"},
"trepanning":	{"VBG"},
"trepans":	{"VBZ","NNS"},
"trephination":	{"NN"},
"trephine":	{"NN","VB","VBP"},
"trephined":	{"VBD","VBN"},
"trephines":	{"NNS","VBZ"},
"trephining":	{"VBG"},
"trephritidae":	{"NN"},
"trepid":	{"JJ"},
"trepidation":	{"NN"},
"trepidly":	{"RB"},
"treponema":	{"NN"},
"treponemataceae":	{"NN"},
"trespass":	{"VB","VBP","NN"},
"trespassed":	{"VBN","VBD"},
"trespasser":	{"NN"},
"trespassers":	{"NNS"},
"trespasses":	{"VBZ","NNS"},
"trespassing":	{"VBG"},
"tress":	{"NN"},
"tresses":	{"NNS"},
"trestle":	{"NN"},
"trestle-table":	{"NN"},
"trestles":	{"NNS"},
"trestlework":	{"NN"},
"trevelyan":	{"NN"},
"trevino":	{"NN"},
"trews":	{"NNS"},
"trey":	{"NN"},
"treys":	{"NNS"},
"triable":	{"JJ"},
"triacetate":	{"NN"},
"triad":	{"NN"},
"triads":	{"NNS"},
"triaenodon":	{"NN"},
"triage":	{"NN","VB","VBP"},
"triaged":	{"VBD","VBN"},
"triages":	{"NNS","VBZ"},
"triaging":	{"VBG"},
"triakidae":	{"NN"},
"trial":	{"NN","JJ","VB","VBP"},
"trialeurodes":	{"NNS"},
"trialled":	{"VBD","VBN"},
"trialling":	{"VBG"},
"trials":	{"NNS","VBZ"},
"triamcinolone":	{"NN"},
"triangle":	{"NN"},
"triangles":	{"NNS"},
"triangular":	{"JJ"},
"triangularity":	{"NN"},
"triangulate":	{"VB","VBP","JJ"},
"triangulated":	{"VBD","VBN"},
"triangulately":	{"RB"},
"triangulates":	{"VBZ"},
"triangulating":	{"VBG"},
"triangulation":	{"NN"},
"triatoma":	{"NN"},
"triavil":	{"NN"},
"triazine":	{"NN"},
"triazolam":	{"NN"},
"tribade":	{"NN"},
"tribadism":	{"NN"},
"tribadistic":	{"JJ"},
"tribal":	{"JJ"},
"tribalisation":	{"NN"},
"tribalism":	{"NN"},
"tribalization":	{"NN"},
"tribe":	{"NN"},
"tribes":	{"NNS"},
"tribesman":	{"NN"},
"tribesmen":	{"NNS"},
"tribolium":	{"NN"},
"tribologist":	{"NN"},
"tribology":	{"NN"},
"tribonema":	{"NN"},
"tribonemaceae":	{"NN"},
"tribromoethanol":	{"NN"},
"tribromomethane":	{"NN"},
"tribulate":	{"VB","VBP"},
"tribulation":	{"NN"},
"tribulations":	{"NNS"},
"tribulus":	{"NN"},
"tribunal":	{"NN"},
"tribunals":	{"NNS"},
"tribune":	{"NN"},
"tribuneship":	{"NN"},
"tributaries":	{"NNS"},
"tributarily":	{"RB"},
"tributary":	{"NN","JJ"},
"tribute":	{"NN"},
"tributes":	{"NNS"},
"tributyrin":	{"NN"},
"trice":	{"NN","VB","VBP"},
"triced":	{"VBD","VBN"},
"tricentenary":	{"JJ"},
"tricentennial":	{"JJ","NN"},
"triceps":	{"NN","NNS"},
"triceratops":	{"NN"},
"triceratopses":	{"NNS"},
"trices":	{"VBZ"},
"trichechidae":	{"NN"},
"trichechus":	{"NN"},
"trichina":	{"NN"},
"trichinella":	{"NN"},
"trichiniasis":	{"NN"},
"trichinosis":	{"NN"},
"trichion":	{"NN"},
"trichiuridae":	{"NN"},
"trichloride":	{"NN"},
"trichlormethiazide":	{"NN"},
"trichloroacetic":	{"JJ"},
"trichloroethane":	{"NN"},
"trichloroethylene":	{"NN"},
"trichloromethane":	{"NN"},
"trichobezoar":	{"NN"},
"trichodesmium":	{"NN"},
"trichodontidae":	{"NN"},
"trichoglossus":	{"NNS"},
"tricholoma":	{"NN"},
"tricholomataceae":	{"NN"},
"trichomanes":	{"NNS"},
"trichomonad":	{"NN"},
"trichomoniasis":	{"NN"},
"trichophaga":	{"NN"},
"trichophyton":	{"NN"},
"trichoptera":	{"NN"},
"trichopteran":	{"NN"},
"trichopteron":	{"NN"},
"trichostema":	{"NN"},
"trichostigma":	{"NN"},
"trichosurus":	{"NN"},
"trichotillomania":	{"NN"},
"trichotomy":	{"NN"},
"trichroism":	{"NN"},
"trichromacy":	{"NN"},
"trichromatic":	{"JJ"},
"trichrome":	{"JJ"},
"trichuriasis":	{"NN"},
"trichys":	{"NNS"},
"tricing":	{"VBG"},
"trick":	{"NN","VB","VBP","JJ"},
"tricked":	{"VBD","VBN"},
"tricker":	{"NN"},
"trickery":	{"NN"},
"trickier":	{"JJR"},
"trickiest":	{"JJS"},
"trickily":	{"RB"},
"trickiness":	{"NN"},
"tricking":	{"VBG"},
"trickle":	{"VB","VBP","NN"},
"trickled":	{"VBD","VBN"},
"trickles":	{"VBZ","NNS"},
"trickling":	{"VBG"},
"tricks":	{"NNS","VBZ"},
"trickster":	{"NN"},
"tricksters":	{"NNS"},
"tricksy":	{"JJ"},
"tricky":	{"JJ"},
"triclinic":	{"JJ"},
"triclinium":	{"NN"},
"tricolor":	{"NN"},
"tricolors":	{"NNS"},
"tricolour":	{"NN"},
"tricolours":	{"NNS"},
"tricorn":	{"JJ"},
"tricorne":	{"NN"},
"tricot":	{"NN"},
"tricuspid":	{"JJ"},
"tricuspidate":	{"JJ"},
"tricycle":	{"NN"},
"tricycles":	{"NNS"},
"tricyclic":	{"JJ","NN"},
"tridacna":	{"NN"},
"tridacnidae":	{"NN"},
"trident":	{"NN"},
"tridymite":	{"NN"},
"tried":	{"VBD","VBN","JJ"},
"triennial":	{"JJ","NN"},
"triennially":	{"RB"},
"trier":	{"NN"},
"triers":	{"NNS"},
"tries":	{"VBZ","NNS"},
"trifid":	{"JJ"},
"trifle":	{"NN","VB","RB"},
"trifled":	{"VBD","VBN"},
"trifler":	{"NN"},
"trifles":	{"NNS","VBZ"},
"trifling":	{"JJ","VBG"},
"trifluoromethane":	{"NN"},
"trifoliata":	{"NN"},
"trifoliate":	{"JJ"},
"trifoliolate":	{"JJ"},
"trifolium":	{"NN"},
"trifurcate":	{"VB","VBP","JJ"},
"trifurcation":	{"NN"},
"trig":	{"JJ","NN","VB","VBP"},
"triga":	{"NN"},
"trigeminal":	{"JJ"},
"trigeminus":	{"NN"},
"trigged":	{"VBD","VBN"},
"trigger":	{"VB","NN","VBP"},
"trigger-happy":	{"JJ"},
"triggered":	{"VBN","VBD"},
"triggerfish":	{"NN"},
"triggering":	{"VBG"},
"triggerman":	{"NN"},
"triggermen":	{"NNS"},
"triggers":	{"NNS","VBZ"},
"trigging":	{"VBG"},
"triglidae":	{"NN"},
"triglinae":	{"NN"},
"triglochin":	{"NN"},
"triglyceride":	{"NN"},
"triglycerides":	{"NNS"},
"trigon":	{"NN"},
"trigonal":	{"JJ"},
"trigonella":	{"NN"},
"trigonometric":	{"JJ"},
"trigonometrical":	{"JJ"},
"trigonometrically":	{"RB"},
"trigonometrician":	{"NN"},
"trigonometry":	{"NN"},
"trigonotarbid":	{"NN"},
"trigonotarbids":	{"NNS"},
"trigons":	{"NNS"},
"trigram":	{"NN"},
"trigrams":	{"NNS"},
"trigs":	{"NNS","VBZ"},
"trihydroxy":	{"JJ"},
"triiodomethane":	{"NN"},
"triiodothyronine":	{"NN"},
"trijet":	{"NN"},
"trijets":	{"NNS"},
"trike":	{"NN"},
"trikes":	{"NNS"},
"trilateral":	{"JJ"},
"trilaterally":	{"RB"},
"trilbies":	{"NNS"},
"trilby":	{"NN"},
"trilingual":	{"JJ"},
"trilisa":	{"NN"},
"trill":	{"NN","VB","VBP"},
"trilled":	{"VBD","VBN"},
"trilliaceae":	{"NN"},
"trilling":	{"VBG"},
"trillion":	{"CD","NN"},
"trillions":	{"NNS"},
"trillionth":	{"JJ","NN"},
"trillium":	{"NN"},
"trills":	{"NNS","VBZ"},
"trilobate":	{"JJ"},
"trilobated":	{"JJ"},
"trilobed":	{"JJ"},
"trilobite":	{"NN"},
"trilogies":	{"NNS"},
"trilogy":	{"NN"},
"trim":	{"VB","VBP","NN","JJ"},
"trimaran":	{"NN"},
"trimarans":	{"NNS"},
"trimble":	{"NN"},
"trimester":	{"NN"},
"trimesters":	{"NNS"},
"trimipramine":	{"NN"},
"trimly":	{"RB"},
"trimmed":	{"VBD","VBN"},
"trimmer":	{"NN","JJR"},
"trimmers":	{"NNS"},
"trimmest":	{"JJS"},
"trimming":	{"NN","VBG"},
"trimmings":	{"NNS"},
"trimness":	{"NN"},
"trimorphodon":	{"NN"},
"trimotored":	{"JJ"},
"trimox":	{"NN"},
"trims":	{"VBZ"},
"trimurti":	{"NN"},
"trinal":	{"JJ"},
"trine":	{"NN","JJ"},
"trinectes":	{"NNS"},
"tringa":	{"NN"},
"trinidad":	{"NN"},
"trinitarian":	{"NN"},
"trinitroglycerin":	{"NN"},
"trinitrotoluene":	{"NN"},
"trinity":	{"NN"},
"trinket":	{"NN"},
"trinketry":	{"NN"},
"trinkets":	{"NNS"},
"trinuclear":	{"JJ"},
"trinucleate":	{"JJ"},
"trinucleated":	{"JJ"},
"trio":	{"NN"},
"triode":	{"NN"},
"triol":	{"NN"},
"triolein":	{"NN"},
"trionychidae":	{"NN"},
"trionyx":	{"NN"},
"triopidae":	{"NN"},
"triops":	{"NN"},
"trios":	{"NNS"},
"triose":	{"NN"},
"triostium":	{"NN"},
"trioxide":	{"NN"},
"trip":	{"VB","VBP","NN"},
"tripalmitin":	{"NN"},
"tripartite":	{"JJ"},
"tripe":	{"NN"},
"triphammer":	{"NN"},
"triphenylarsine":	{"NN"},
"triphenylphosphine":	{"NN"},
"triphenylstibine":	{"NN"},
"triphosphopyridine":	{"NN"},
"triphosphorous":	{"JJ"},
"tripinnate":	{"JJ"},
"tripinnated":	{"JJ"},
"tripinnatifid":	{"JJ"},
"triple":	{"JJ","VB","VBP","NN"},
"triple-digit":	{"JJ"},
"triple-double":	{"NN"},
"triple-doubles":	{"NNS"},
"tripled":	{"VBD","VBN"},
"triples":	{"VBZ","NNS"},
"triplet":	{"NN"},
"tripletail":	{"NN"},
"triplets":	{"NNS"},
"tripleurospermum":	{"NN"},
"triplex":	{"NN","JJ"},
"triplicate":	{"NN","VB","VBP"},
"triplication":	{"NN"},
"triplicity":	{"NN"},
"tripling":	{"VBG"},
"triplochiton":	{"NN"},
"triploid":	{"JJ","NN"},
"tripod":	{"NN"},
"tripods":	{"NNS"},
"tripoli":	{"NN"},
"tripolyphosphate":	{"NN"},
"tripos":	{"NN"},
"tripped":	{"VBD","VBN"},
"tripper":	{"NN"},
"trippers":	{"NNS"},
"tripping":	{"JJ","VBG"},
"trippingly":	{"RB"},
"trips":	{"NNS","VBZ"},
"triptych":	{"NN"},
"triptychs":	{"NNS"},
"triquetral":	{"NN"},
"trireme":	{"NN"},
"trisaccharide":	{"NN"},
"trisect":	{"VB","VBP"},
"triservice":	{"NN"},
"trisexual":	{"JJ","NN"},
"trisexuals":	{"NNS"},
"triskaidekaphobia":	{"NN"},
"triskaidekaphobic":	{"JJ"},
"triskele":	{"NN"},
"triskelion":	{"NN"},
"trismus":	{"NN"},
"trisodium":	{"JJ"},
"trisomy":	{"NN"},
"tristan":	{"NN"},
"tristate":	{"JJ"},
"tristearin":	{"NN"},
"tristram":	{"NN"},
"trisyllable":	{"NN"},
"tritanopia":	{"NN"},
"tritanopic":	{"JJ"},
"trite":	{"JJ"},
"tritely":	{"RB"},
"triteness":	{"NN"},
"tritheism":	{"NN"},
"tritheist":	{"NN"},
"triticum":	{"NN"},
"tritium":	{"NN"},
"tritoma":	{"NN"},
"triton":	{"NN"},
"triturus":	{"NN"},
"triumph":	{"NN","VB","VBP"},
"triumphal":	{"JJ"},
"triumphant":	{"JJ"},
"triumphantly":	{"RB"},
"triumphed":	{"VBD","VBN"},
"triumphing":	{"VBG"},
"triumphs":	{"VBZ","NNS"},
"triumvir":	{"NN"},
"triumvirate":	{"NN"},
"triune":	{"JJ","NN"},
"trivalent":	{"JJ"},
"trivet":	{"NN"},
"trivets":	{"NNS"},
"trivia":	{"NN","NNS"},
"trivial":	{"JJ"},
"trivialisation":	{"NN"},
"trivialise":	{"VB","VBP"},
"trivialised":	{"VBD","VBN"},
"trivialises":	{"VBZ"},
"trivialising":	{"VBG"},
"trivialities":	{"NNS"},
"triviality":	{"NN"},
"trivialization":	{"NN"},
"trivialize":	{"VB","VBP"},
"trivialized":	{"VBD","VBN"},
"trivializes":	{"VBZ"},
"trivializing":	{"VBG"},
"trivially":	{"RB"},
"trivium":	{"NN"},
"tro":	{"NN"},
"troat":	{"VB","VBP"},
"trochaic":	{"JJ"},
"trochanter":	{"NN"},
"troche":	{"NN"},
"trochee":	{"NN"},
"trochees":	{"NNS"},
"troches":	{"NNS"},
"trochilidae":	{"NN"},
"trochlear":	{"JJ"},
"trochlearis":	{"JJ","NN"},
"trod":	{"VBD"},
"trodden":	{"VBN"},
"troglodyte":	{"NN"},
"troglodytes":	{"NNS"},
"troglodytidae":	{"NN"},
"trogon":	{"NN"},
"trogonidae":	{"NN"},
"trogoniformes":	{"NNS"},
"troika":	{"NN"},
"troikas":	{"NNS"},
"troll":	{"NN","VB","VBP"},
"trolled":	{"VBD","VBN"},
"troller":	{"NN"},
"trolley":	{"NN","VB","VBP"},
"trolleybus":	{"NN"},
"trolleybuses":	{"NNS"},
"trolleyed":	{"VBD","VBN"},
"trolleying":	{"VBG"},
"trolleys":	{"NNS","VBZ"},
"trollied":	{"VBD","VBN"},
"trollies":	{"NNS","VBZ"},
"trolling":	{"NN","VBG"},
"trollius":	{"NN"},
"trollop":	{"NN"},
"trollops":	{"NNS"},
"trolls":	{"NNS","VBZ"},
"trolly":	{"NN","VB","VBP"},
"trollying":	{"VBG"},
"trombicula":	{"NN"},
"trombiculiasis":	{"NN"},
"trombiculid":	{"NN"},
"trombiculidae":	{"NN"},
"trombidiid":	{"NN"},
"trombidiidae":	{"NN"},
"trombone":	{"NN"},
"trombones":	{"NNS"},
"trombonist":	{"NN"},
"trombonists":	{"NNS"},
"trompillo":	{"NN"},
"trondheim":	{"NN"},
"troop":	{"NN","VBP","VB"},
"trooped":	{"VBD","VBN"},
"trooper":	{"NN"},
"troopers":	{"NNS"},
"trooping":	{"VBG","NN"},
"troops":	{"NNS","VBZ"},
"troopship":	{"NN"},
"troopships":	{"NNS"},
"trop":	{"RB","FW"},
"tropaeolaceae":	{"NN"},
"tropaeolum":	{"NN"},
"trope":	{"NN"},
"tropes":	{"NNS"},
"trophic":	{"JJ"},
"trophies":	{"NNS"},
"tropho":	{"JJ"},
"trophobiosis":	{"NN"},
"trophoblast":	{"NN"},
"trophoblastic":	{"JJ"},
"trophotropic":	{"JJ"},
"trophotropism":	{"NN"},
"trophozoite":	{"NN"},
"trophy":	{"NN"},
"tropic":	{"NN"},
"tropical":	{"JJ"},
"tropically":	{"RB"},
"tropicbird":	{"NN"},
"tropics":	{"NNS"},
"tropidoclonion":	{"NN"},
"tropism":	{"NN"},
"tropocollagen":	{"NN"},
"troponomy":	{"NN"},
"troponym":	{"NN"},
"troponymy":	{"NN"},
"tropopause":	{"NN"},
"troposphere":	{"NN"},
"trot":	{"VB","VBP","NN"},
"troth":	{"NN","VB","VBP"},
"trothed":	{"VBD","VBN"},
"trothing":	{"VBG"},
"troths":	{"VBZ"},
"trotline":	{"NN"},
"trots":	{"VBZ","NNS"},
"trotsky":	{"NN"},
"trotted":	{"VBD","VBN"},
"trotter":	{"NN"},
"trotters":	{"NNS"},
"trotting":	{"VBG"},
"troubadour":	{"NN"},
"troubadours":	{"NNS"},
"troubie":	{"NN"},
"trouble":	{"NN","VB","VBP"},
"trouble-free":	{"JJ"},
"trouble-maker":	{"NN"},
"trouble-makers":	{"NNS"},
"trouble-shoot":	{"VB","VBP"},
"trouble-shooter":	{"NN"},
"trouble-shooters":	{"NNS"},
"trouble-shooting":	{"VBG","NN","JJ"},
"trouble-shoots":	{"VBZ"},
"trouble-shot":	{"VBD","VBN"},
"trouble-spot":	{"NN"},
"trouble-spots":	{"NNS"},
"troubled":	{"JJ","VBN","VBD"},
"troublemaker":	{"NN"},
"troublemakers":	{"NNS"},
"troubler":	{"NN"},
"troubles":	{"NNS","VBZ"},
"troubleshoot":	{"VB","VBP"},
"troubleshooter":	{"NN"},
"troubleshooters":	{"NNS"},
"troubleshooting":	{"VBG"},
"troubleshoots":	{"VBZ"},
"troubleshot":	{"VBD","VBN"},
"troublesome":	{"JJ"},
"troublesomeness":	{"NN"},
"troubling":	{"JJ","VBG"},
"troublingly":	{"RB"},
"troublous":	{"JJ"},
"trough":	{"NN"},
"troughs":	{"NNS"},
"trounce":	{"VB","VBP"},
"trounced":	{"VBD","VBN"},
"trounces":	{"VBZ"},
"trouncing":	{"VBG"},
"troup":	{"NN"},
"troupe":	{"NN","VB","VBP"},
"trouped":	{"VBD","VBN"},
"trouper":	{"NN"},
"troupers":	{"NNS"},
"troupes":	{"NNS","VBZ"},
"trouping":	{"VBG"},
"trouser":	{"VB","VBP","JJ"},
"trousered":	{"VBD","VBN"},
"trousering":	{"VBG"},
"trousers":	{"NNS","VBZ"},
"trousseau":	{"NN"},
"trousseaus":	{"NNS"},
"trousseaux":	{"NNS"},
"trout":	{"NN","NNS"},
"trove":	{"NN"},
"trowel":	{"NN","VB","VBP"},
"troweled":	{"VBD","VBN"},
"troweler":	{"NN"},
"troweling":	{"VBG"},
"trowelled":	{"VBD","VBN"},
"troweller":	{"NN"},
"trowelling":	{"VBG"},
"trowels":	{"NNS","VBZ"},
"truancy":	{"NN"},
"truant":	{"NN","JJ","VB","VBP"},
"truanted":	{"VBD","VBN"},
"truanting":	{"VBG","NN"},
"truants":	{"NNS","VBZ"},
"truce":	{"NN"},
"truces":	{"NNS"},
"truck":	{"NN","VB","VBP"},
"truckage":	{"NN"},
"truckdriver":	{"NN"},
"truckdrivers":	{"NNS"},
"trucked":	{"VBD","VBN"},
"trucker":	{"NN"},
"truckers":	{"NNS"},
"trucking":	{"NN","VBG"},
"truckle":	{"VB","VBP"},
"truckled":	{"VBD","VBN"},
"truckler":	{"NN"},
"truckles":	{"VBZ"},
"truckling":	{"VBG"},
"truckload":	{"NN"},
"truckloads":	{"NNS"},
"trucks":	{"NNS","VBZ"},
"truculence":	{"NN"},
"truculency":	{"NN"},
"truculent":	{"JJ"},
"truculently":	{"RB"},
"trudge":	{"VB","VBP","NN"},
"trudged":	{"VBD","VBN"},
"trudger":	{"NN"},
"trudges":	{"VBZ"},
"trudging":	{"VBG"},
"true":	{"JJ","NN","RB","VB","VBP"},
"true-blue":	{"JJ","NN"},
"true-born":	{"JJ"},
"true-bred":	{"JJ"},
"true-false":	{"JJ"},
"true-hearted":	{"JJ"},
"true-heartedness":	{"NN"},
"true-life":	{"JJ"},
"true-love":	{"NN"},
"trued":	{"VBD","VBN"},
"trueness":	{"NN"},
"truer":	{"JJR"},
"trues":	{"VBZ"},
"truest":	{"JJS"},
"truffaut":	{"NN"},
"truffle":	{"NN"},
"truffles":	{"NNS"},
"truing":	{"VBG"},
"truism":	{"NN"},
"truley":	{"RB"},
"truly":	{"RB"},
"truman":	{"NN"},
"trumbo":	{"NN"},
"trumbull":	{"NN"},
"trump":	{"NN","VB","VBP"},
"trump-card":	{"NN"},
"trump-watchers":	{"NNS"},
"trumped":	{"VBD","VBN"},
"trumped-up":	{"JJ"},
"trumpery":	{"NN","JJ"},
"trumpet":	{"NN","VB","VBP"},
"trumpeted":	{"VBD","VBN"},
"trumpeter":	{"NN"},
"trumpeters":	{"NNS"},
"trumpetfish":	{"NN"},
"trumpeting":	{"VBG"},
"trumpets":	{"VBZ","NNS"},
"trumpetwood":	{"NN"},
"trumping":	{"VBG"},
"trumps":	{"NNS","VBZ"},
"truncate":	{"VB","VBP"},
"truncated":	{"JJ","VBD","VBN"},
"truncates":	{"VBZ"},
"truncating":	{"VBG"},
"truncation":	{"NN"},
"truncheon":	{"NN"},
"truncheons":	{"NNS"},
"truncocolumella":	{"NN"},
"trundle":	{"VB","VBP"},
"trundle-bed":	{"NN"},
"trundled":	{"VBD","VBN"},
"trundles":	{"VBZ"},
"trundling":	{"VBG"},
"trunk":	{"NN"},
"trunk-call":	{"NN"},
"trunk-road":	{"NN"},
"trunkfish":	{"NN"},
"trunks":	{"NNS"},
"trunnel":	{"NN"},
"truss":	{"VB","VBP","NN"},
"trussed":	{"VBD","VBN"},
"trusses":	{"NNS","VBZ"},
"trussing":	{"VBG"},
"trust":	{"NN","VB","VBP"},
"trustbuster":	{"NN"},
"trusted":	{"VBD","VBN"},
"trustee":	{"NN","VB","VBP"},
"trusteed":	{"VBD","VBN"},
"trusteeing":	{"VBG"},
"trustees":	{"NNS","VBZ"},
"trusteeship":	{"NN"},
"trusteeships":	{"NNS"},
"truster":	{"NN"},
"trusteth":	{"VBP","NN","VB"},
"trustful":	{"JJ"},
"trustfully":	{"RB"},
"trustfulness":	{"NN"},
"trustier":	{"JJR"},
"trusties":	{"NNS"},
"trustiest":	{"JJS"},
"trustiness":	{"NN"},
"trusting":	{"JJ","VBG"},
"trustingly":	{"RB"},
"trustingness":	{"NN"},
"trustor":	{"NN"},
"trusts":	{"VBZ","NNS"},
"trustworthiness":	{"NN"},
"trustworthy":	{"JJ"},
"trusty":	{"JJ","NN"},
"truth":	{"NN"},
"truthful":	{"JJ"},
"truthfully":	{"RB"},
"truthfulness":	{"NN"},
"truths":	{"NNS"},
"try":	{"VB","VBP","NN"},
"try-out":	{"NN"},
"try-outs":	{"NNS"},
"trying":	{"VBG","JJ"},
"tryout":	{"NN"},
"tryouts":	{"NNS"},
"trypetidae":	{"NN"},
"trypsin":	{"NN"},
"trypsinogen":	{"NN"},
"tryptophan":	{"NN"},
"tryptophane":	{"NN"},
"tryst":	{"NN","VB","VBP"},
"trysted":	{"VBD","VBN"},
"trysting":	{"VBG"},
"trysts":	{"NNS","VBZ"},
"tsar":	{"NN"},
"tsarina":	{"NN"},
"tsarinas":	{"NNS"},
"tsarist":	{"NN","JJ"},
"tsaristic":	{"JJ"},
"tsarists":	{"NNS"},
"tsaritsa":	{"NN"},
"tsaritsyn":	{"NN"},
"tsars":	{"NNS"},
"tsatske":	{"NN"},
"tsem":	{"NN"},
"tsetse":	{"NN"},
"tshatshke":	{"NN"},
"tshiluba":	{"NN"},
"tsimshian":	{"NN"},
"tsine":	{"NN"},
"tsk":	{"UH","NN","VB","VBP"},
"tsked":	{"VBD","VBN"},
"tsking":	{"VBG"},
"tsks":	{"NNS","VBZ"},
"tsoris":	{"NN"},
"tsouic":	{"NN"},
"tsuga":	{"NN"},
"tsunami":	{"NN"},
"tsunamis":	{"NNS"},
"tsuris":	{"NN"},
"tsushima":	{"NN"},
"tswana":	{"NN"},
"tt":	{"NN"},
"tuareg":	{"NN"},
"tuatara":	{"NN"},
"tub":	{"NN","VB","VBP"},
"tub-cart":	{"NN"},
"tub-thumper":	{"NN"},
"tub-thumpers":	{"NNS"},
"tub-thumping":	{"NN","JJ"},
"tuba":	{"NN"},
"tubal":	{"JJ"},
"tubas":	{"NNS"},
"tubbed":	{"VBD","VBN"},
"tubbier":	{"JJR"},
"tubbiest":	{"JJS"},
"tubbiness":	{"NN"},
"tubbing":	{"VBG"},
"tubby":	{"JJ"},
"tube":	{"NN","VBP","VB"},
"tubed":	{"VBD","VBN"},
"tubeless":	{"JJ"},
"tubelike":	{"JJ"},
"tuber":	{"NN"},
"tuberaceae":	{"NN"},
"tuberales":	{"NNS"},
"tubercle":	{"NN"},
"tubercular":	{"JJ"},
"tubercularia":	{"NN"},
"tuberculariaceae":	{"NN"},
"tuberculate":	{"JJ"},
"tuberculin":	{"NN"},
"tuberculoid":	{"JJ"},
"tuberculosis":	{"NN"},
"tuberculous":	{"JJ"},
"tuberose":	{"JJ"},
"tuberosity":	{"NN"},
"tuberous":	{"JJ"},
"tubers":	{"NNS"},
"tubes":	{"NNS","VBZ"},
"tubful":	{"NN"},
"tubing":	{"NN","VBG"},
"tubman":	{"NN"},
"tubocurarine":	{"NN"},
"tubs":	{"NNS","VBZ"},
"tubular":	{"JJ"},
"tubule":	{"NN"},
"tubules":	{"NNS"},
"tubulidentata":	{"NN"},
"tucana":	{"NN"},
"tuck":	{"VB","VBP","NN"},
"tuckahoe":	{"NN"},
"tucked":	{"VBD","VBN"},
"tucker":	{"NN","VBP","VB"},
"tuckered":	{"VBD","VBN"},
"tuckering":	{"VBG"},
"tuckers":	{"VBZ"},
"tucket":	{"NN"},
"tucking":	{"VBG"},
"tucks":	{"VBZ","NNS"},
"tucson":	{"NN"},
"tudung":	{"NN"},
"tufa":	{"NN"},
"tuff":	{"NN"},
"tuffaceous":	{"JJ"},
"tuffet":	{"NN"},
"tuft":	{"NN","VB","VBP"},
"tufted":	{"JJ","VBD","VBN"},
"tufting":	{"VBG"},
"tufts":	{"NNS","VBZ"},
"tug":	{"VB","VBP","NN"},
"tug-of-war":	{"NN"},
"tugaru":	{"NN"},
"tugboat":	{"NN"},
"tugela":	{"NN"},
"tugged":	{"VBD","VBN"},
"tugger":	{"NN"},
"tugging":	{"VBG"},
"tughrik":	{"NN"},
"tugrik":	{"NN"},
"tugs":	{"VBZ","NNS"},
"tugs-of-war":	{"NNS"},
"tuille":	{"NN"},
"tuition":	{"NN"},
"tularaemia":	{"NN"},
"tularemia":	{"NN"},
"tulestoma":	{"NN"},
"tulip":	{"NN"},
"tulipa":	{"NN"},
"tulips":	{"NNS"},
"tulipwood":	{"NN"},
"tulle":	{"NN"},
"tulostoma":	{"NN"},
"tulostomaceae":	{"NN"},
"tulostomataceae":	{"NN"},
"tulostomatales":	{"NNS"},
"tulsa":	{"NN"},
"tum":	{"NN"},
"tumble":	{"VB","VBP","NN"},
"tumble-down":	{"JJ"},
"tumble-dryer":	{"NN"},
"tumble-dryers":	{"NNS"},
"tumblebug":	{"NN"},
"tumbled":	{"VBD","VBN"},
"tumbledown":	{"JJ"},
"tumbler":	{"NN"},
"tumblers":	{"NNS"},
"tumbles":	{"VBZ","NNS"},
"tumbleweed":	{"NN"},
"tumbling":	{"NN","VBG"},
"tumbrel":	{"NN"},
"tumbrels":	{"NNS"},
"tumbril":	{"NN"},
"tumefaciens":	{"NNS"},
"tumefaction":	{"NN"},
"tumefied":	{"VBD","VBN"},
"tumefies":	{"VBZ"},
"tumefy":	{"VB","VBP"},
"tumefying":	{"VBG"},
"tumesce":	{"VB","VBP"},
"tumescence":	{"NN"},
"tumescent":	{"JJ"},
"tumid":	{"JJ"},
"tumidity":	{"NN"},
"tumidness":	{"NN"},
"tummies":	{"NNS"},
"tummy":	{"NN"},
"tumor":	{"NN"},
"tumorous":	{"JJ"},
"tumors":	{"NNS"},
"tumour":	{"NN"},
"tumours":	{"NNS"},
"tums":	{"NNS"},
"tumuli":	{"NNS"},
"tumult":	{"NN"},
"tumultuous":	{"JJ"},
"tumultuously":	{"RB"},
"tumultuousness":	{"NN"},
"tumulus":	{"NN"},
"tun":	{"NN","VB","VBP"},
"tuna":	{"NN","NNS"},
"tuna-fish":	{"NN"},
"tunaburger":	{"NN"},
"tunas":	{"NNS"},
"tundra":	{"NN"},
"tundras":	{"NNS"},
"tune":	{"NN","VB","VBP"},
"tune-up":	{"NN"},
"tuned":	{"VBD","VBN"},
"tuneful":	{"JJ"},
"tunefully":	{"RB"},
"tunefulness":	{"NN"},
"tuneless":	{"JJ"},
"tunelessly":	{"RB"},
"tuner":	{"NN"},
"tuners":	{"NNS"},
"tunes":	{"NNS","VBZ"},
"tung":	{"NN"},
"tunga":	{"NN"},
"tungstate":	{"NN"},
"tungsten":	{"NN"},
"tungusic":	{"NN"},
"tunguska":	{"NN"},
"tunguz":	{"NN"},
"tunic":	{"NN"},
"tunica":	{"NN"},
"tunicata":	{"NN"},
"tunicate":	{"NN","JJ"},
"tunics":	{"NNS"},
"tuning":	{"NN","VBG"},
"tunis":	{"NN"},
"tunisia":	{"NN"},
"tunisian":	{"JJ","NN"},
"tunnage":	{"NN"},
"tunned":	{"VBD","VBN"},
"tunnel":	{"NN","VBP","VB"},
"tunneled":	{"VBD","VBN"},
"tunneling":	{"VBG"},
"tunnelled":	{"VBD","VBN"},
"tunnelling":	{"VBG"},
"tunnels":	{"NNS","VBZ"},
"tunning":	{"VBG"},
"tunny":	{"NN","NNS"},
"tuns":	{"NNS","VBZ"},
"tup":	{"NN","VB","VBP"},
"tupaia":	{"NN"},
"tupaiidae":	{"NN"},
"tupek":	{"NN"},
"tupelo":	{"NN"},
"tupi":	{"NN"},
"tupi-guarani":	{"NN"},
"tupik":	{"NN"},
"tupinambis":	{"NN"},
"tupped":	{"VBD","VBN"},
"tuppence":	{"NN"},
"tuppenny":	{"JJ"},
"tuppeny":	{"JJ"},
"tupping":	{"VBG"},
"tups":	{"NNS","VBZ"},
"tupungatito":	{"NN"},
"tupungato":	{"NN"},
"turaco":	{"NN"},
"turacou":	{"NN"},
"turakoo":	{"NN"},
"turban":	{"NN"},
"turbaned":	{"JJ"},
"turbans":	{"NNS"},
"turbatrix":	{"NN"},
"turbellaria":	{"NN"},
"turbid":	{"JJ"},
"turbidity":	{"NN"},
"turbidness":	{"NN"},
"turbinado":	{"NN"},
"turbinal":	{"NN"},
"turbinate":	{"NN","JJ"},
"turbinates":	{"NNS"},
"turbine":	{"NN"},
"turbines":	{"NNS"},
"turbo":	{"NN"},
"turbo-charged":	{"JJ"},
"turbocharge":	{"VB","VBP"},
"turbocharged":	{"JJ","VBD","VBN"},
"turbocharger":	{"NN"},
"turbochargers":	{"NNS"},
"turbocharges":	{"VBZ"},
"turbocharging":	{"VBG","NN"},
"turbofan":	{"NN"},
"turbogenerator":	{"NN"},
"turbogenerators":	{"NNS"},
"turbojet":	{"NN"},
"turbojets":	{"NNS"},
"turboprop":	{"NN"},
"turboprops":	{"NNS"},
"turbos":	{"NNS"},
"turbot":	{"NN","NNS"},
"turbulence":	{"NN"},
"turbulency":	{"NN"},
"turbulent":	{"JJ"},
"turbulently":	{"RB"},
"turd":	{"NN"},
"turdidae":	{"NN"},
"turdinae":	{"NN"},
"turds":	{"NNS"},
"turdus":	{"NN"},
"tureen":	{"NN"},
"tureens":	{"NNS"},
"turf":	{"NN","VB","VBP"},
"turfan":	{"NN"},
"turfed":	{"VBD","VBN"},
"turfing":	{"VBG"},
"turfs":	{"NNS","VBZ"},
"turgid":	{"JJ"},
"turgidity":	{"NN"},
"turgidly":	{"RB"},
"turgidness":	{"NN"},
"turgor":	{"NN"},
"turgot":	{"NN"},
"turin":	{"NN"},
"turk":	{"NN"},
"turkey":	{"NN"},
"turkeys":	{"NNS"},
"turkmenia":	{"NN"},
"turmeric":	{"NN"},
"turmoil":	{"NN"},
"turmoils":	{"NNS"},
"turn":	{"VB","NN","VBP"},
"turn-about":	{"NN"},
"turn-around":	{"NN"},
"turn-of-the-century":	{"JJ"},
"turn-off":	{"NN"},
"turn-offs":	{"NNS"},
"turn-on":	{"NN"},
"turn-ons":	{"NNS"},
"turn-out":	{"NN"},
"turn-round":	{"NN"},
"turn-up":	{"NN"},
"turn-ups":	{"NNS"},
"turnabout":	{"NN"},
"turnaround":	{"NN"},
"turnarounds":	{"NNS"},
"turnbuckle":	{"NN"},
"turnbull":	{"NN"},
"turncoat":	{"NN"},
"turncoats":	{"NNS"},
"turncock":	{"NN"},
"turndown":	{"JJ","NN"},
"turned":	{"VBD","VBN"},
"turner":	{"NN"},
"turners":	{"NNS"},
"turnery":	{"NN"},
"turnicidae":	{"NN"},
"turning":	{"VBG","NN"},
"turning-circle":	{"NN"},
"turning-point":	{"NN"},
"turnings":	{"NNS"},
"turnip":	{"NN"},
"turnips":	{"NNS"},
"turnix":	{"NN"},
"turnkey":	{"NN","JJ"},
"turnoff":	{"NN"},
"turnout":	{"NN"},
"turnouts":	{"NNS"},
"turnover":	{"NN"},
"turnovers":	{"NNS"},
"turnpike":	{"NN"},
"turnpikes":	{"NNS"},
"turnround":	{"NN"},
"turns":	{"VBZ","NNS"},
"turnspit":	{"NN"},
"turnstile":	{"NN"},
"turnstiles":	{"NNS"},
"turnstone":	{"NN"},
"turntable":	{"NN"},
"turntables":	{"NNS"},
"turnup":	{"NN"},
"turnverein":	{"NN"},
"turpentine":	{"NN","VB","VBP"},
"turpentined":	{"VBD","VBN"},
"turpentines":	{"VBZ"},
"turpentining":	{"VBG"},
"turpin":	{"NN"},
"turpitude":	{"NN"},
"turps":	{"NN"},
"turquoise":	{"NN","JJ"},
"turquoises":	{"NNS"},
"turreae":	{"NN"},
"turret":	{"NN"},
"turreted":	{"JJ"},
"turrets":	{"NNS"},
"turritis":	{"NN"},
"tursiops":	{"NN"},
"turtle":	{"NN","VB","VBP"},
"turtle-dove":	{"NN"},
"turtle-doves":	{"NNS"},
"turtle-neck":	{"NN"},
"turtle-necked":	{"JJ"},
"turtleback":	{"NN"},
"turtlebacks":	{"NNS"},
"turtled":	{"VBD","VBN"},
"turtledove":	{"NN"},
"turtledoves":	{"NNS"},
"turtlehead":	{"NN"},
"turtleneck":	{"NN"},
"turtlenecks":	{"NNS"},
"turtler":	{"NN"},
"turtles":	{"NNS","VBZ"},
"turtling":	{"VBG"},
"turves":	{"NNS"},
"tuscaloosa":	{"NN"},
"tuscan":	{"JJ","NN"},
"tuscany":	{"NN"},
"tush":	{"UH","NN"},
"tushery":	{"NN"},
"tusk":	{"NN","VB","VBP"},
"tusked":	{"VBD","VBN"},
"tusker":	{"NN"},
"tusking":	{"VBG"},
"tusks":	{"NNS","VBZ"},
"tussah":	{"NN"},
"tusser":	{"NN"},
"tussilago":	{"NN"},
"tussle":	{"NN","VB","VBP"},
"tussled":	{"VBD","VBN"},
"tussles":	{"NNS","VBZ"},
"tussling":	{"VBG"},
"tussock":	{"NN"},
"tussocks":	{"NNS"},
"tussore":	{"NN"},
"tussur":	{"NN"},
"tut":	{"UH","NN","VB","VBP"},
"tut-tut":	{"UH","NN","VB","VBP"},
"tut-tuts":	{"NNS","VBZ"},
"tut-tutted":	{"VBD","VBN"},
"tut-tutting":	{"VBG"},
"tutee":	{"NN"},
"tutelage":	{"NN"},
"tutelar":	{"JJ","NN"},
"tutelaries":	{"NNS"},
"tutelars":	{"NNS"},
"tutelary":	{"JJ","NNS"},
"tutelo":	{"NN"},
"tutor":	{"NN","VB","VBP"},
"tutored":	{"VBD","VBN"},
"tutorial":	{"NN","JJ"},
"tutorially":	{"RB"},
"tutorials":	{"NNS"},
"tutoring":	{"NN","VBG"},
"tutors":	{"NNS","VBZ"},
"tutorship":	{"NN"},
"tuts":	{"NNS","VBZ"},
"tutsan":	{"NN"},
"tutted":	{"VBD","VBN"},
"tutti-frutti":	{"NN"},
"tutting":	{"VBG"},
"tutu":	{"NN"},
"tutus":	{"NNS"},
"tux":	{"NN"},
"tuxedo":	{"NN"},
"tuxedoed":	{"JJ"},
"tuxedos":	{"NNS"},
"tuxes":	{"NNS"},
"twaddle":	{"NN","VB","VBP"},
"twaddled":	{"VBD","VBN"},
"twaddler":	{"NN"},
"twaddles":	{"VBZ"},
"twaddling":	{"VBG"},
"twain":	{"CD","NN"},
"twang":	{"NN","VB","VBP"},
"twanged":	{"VBD","VBN"},
"twanging":	{"VBG"},
"twangs":	{"NNS","VBZ"},
"twangy":	{"JJ"},
"twat":	{"NN"},
"twats":	{"NNS"},
"twayblade":	{"NN"},
"tweak":	{"VB","VBP","NN"},
"tweaked":	{"VBD","VBN"},
"tweaking":	{"VBG","NN"},
"tweaks":	{"VBZ"},
"twee":	{"JJ"},
"tweed":	{"NN"},
"tweediness":	{"NN"},
"tweedle":	{"VB","VBP","NN"},
"tweedled":	{"VBD","VBN"},
"tweedles":	{"VBZ"},
"tweedling":	{"VBG"},
"tweeds":	{"NNS"},
"tweedy":	{"JJ"},
"tweet":	{"NN","VB","VBP"},
"tweeted":	{"VBD","VBN"},
"tweeter":	{"NN"},
"tweeters":	{"NNS"},
"tweeting":	{"VBG"},
"tweets":	{"NNS","VBZ"},
"tweetstorm":	{"NN"},
"tweeze":	{"VB","VBP"},
"tweezed":	{"VBD","VBN"},
"tweezer":	{"NN"},
"tweezers":	{"NNS"},
"tweezes":	{"VBZ"},
"tweezing":	{"VBG"},
"twelfth":	{"NN","JJ"},
"twelve":	{"CD","NN"},
"twelvefold":	{"JJ","RB"},
"twelvemonth":	{"NN"},
"twenties":	{"NNS"},
"twentieth":	{"JJ","NN"},
"twentieth-century":	{"JJ","NN"},
"twenty":	{"CD","NN","JJ"},
"twenty-first":	{"JJ","NN"},
"twenty-one":	{"CD","NN"},
"twenty-two":	{"CD","NN"},
"twerk":	{"VB","VBP","NN"},
"twerked":	{"VBD","VBN"},
"twerking":	{"VBG"},
"twerks":	{"VBZ","NNS"},
"twerp":	{"NN"},
"twerps":	{"NNS"},
"twice":	{"RB"},
"twiddle":	{"VB","VBP","NN"},
"twiddled":	{"VBD","VBN"},
"twiddler":	{"NN"},
"twiddles":	{"VBZ"},
"twiddling":	{"VBG"},
"twiddly":	{"JJ"},
"twig":	{"NN","VBP","VB"},
"twigged":	{"VBD","VBN"},
"twigging":	{"VBG"},
"twiggy":	{"JJ"},
"twiglike":	{"NN"},
"twigs":	{"NNS","VBZ"},
"twilight":	{"NN"},
"twilit":	{"JJ"},
"twill":	{"NN","JJ","VB","VBP"},
"twilled":	{"JJ","VBD","VBN"},
"twilling":	{"VBG"},
"twills":	{"VBZ"},
"twin":	{"JJ","NN","VB","VBP"},
"twin-bedded":	{"JJ"},
"twin-engined":	{"JJ"},
"twinberry":	{"NN"},
"twindam":	{"NN"},
"twine":	{"NN","VB","VBP"},
"twined":	{"VBD","VBN"},
"twiner":	{"NN"},
"twines":	{"VBZ"},
"twinflower":	{"NN"},
"twinge":	{"NN","VB","VBP"},
"twinged":	{"VBD","VBN"},
"twinges":	{"NNS","VBZ"},
"twinging":	{"VBG"},
"twining":	{"VBG"},
"twinjet":	{"NN","JJ"},
"twinjets":	{"NNS"},
"twinkle":	{"VB","VBP","NN"},
"twinkled":	{"VBD","VBN"},
"twinkler":	{"NN"},
"twinkles":	{"VBZ"},
"twinkling":	{"NN","VBG"},
"twinkly":	{"JJ"},
"twinned":	{"VBD","VBN"},
"twinning":	{"NN","VBG"},
"twinnings":	{"NNS"},
"twins":	{"NNS","VBZ"},
"twirl":	{"VB","VBP","NN"},
"twirled":	{"VBD","VBN"},
"twirler":	{"NN"},
"twirling":	{"VBG"},
"twirls":	{"VBZ","NNS"},
"twirly":	{"JJ"},
"twirp":	{"NN"},
"twist":	{"VB","VBP","NN"},
"twisted":	{"JJ","VBD","VBN"},
"twister":	{"NN"},
"twisters":	{"NNS"},
"twisting":	{"VBG"},
"twists":	{"NNS","VBZ"},
"twisty":	{"JJ"},
"twit":	{"NN","VB","VBP"},
"twitch":	{"NN","VB","VBP"},
"twitched":	{"VBD","VBN"},
"twitcher":	{"NN"},
"twitchers":	{"NNS"},
"twitches":	{"VBZ"},
"twitchier":	{"JJR"},
"twitchiest":	{"JJS"},
"twitchily":	{"RB"},
"twitchiness":	{"NN"},
"twitching":	{"NN","JJ","VBG"},
"twitchings":	{"NNS"},
"twitchy":	{"JJ"},
"twits":	{"NNS","VBZ"},
"twitted":	{"VBD","VBN"},
"twitter":	{"VB","VBP","NN"},
"twittered":	{"VBD","VBN"},
"twitterer":	{"NN"},
"twittering":	{"NN","VBG"},
"twitters":	{"VBZ"},
"twitting":	{"VBG"},
"two":	{"CD","NN"},
"two-a-penny":	{"JJ"},
"two-and-a-half":	{"JJ"},
"two-bagger":	{"NN"},
"two-base":	{"NN"},
"two-bit":	{"JJ"},
"two-by-four":	{"NN"},
"two-by-fours":	{"NNS"},
"two-cycle":	{"JJ"},
"two-cylinder":	{"JJ"},
"two-decker":	{"NN"},
"two-deckers":	{"NNS"},
"two-dimensional":	{"JJ"},
"two-door":	{"JJ"},
"two-edged":	{"JJ"},
"two-faced":	{"JJ"},
"two-facedly":	{"RB"},
"two-facedness":	{"NN"},
"two-fisted":	{"JJ"},
"two-fold":	{"JJ"},
"two-footed":	{"JJ"},
"two-four":	{"NN","JJ"},
"two-fours":	{"NNS"},
"two-handed":	{"JJ"},
"two-hander":	{"NN"},
"two-handers":	{"NNS"},
"two-legged":	{"JJ"},
"two-line":	{"NN"},
"two-man":	{"JJ"},
"two-party":	{"JJ"},
"two-phase":	{"JJ"},
"two-piece":	{"JJ","NN"},
"two-pieces":	{"NNS"},
"two-plies":	{"NNS"},
"two-ply":	{"JJ","NN"},
"two-pointer":	{"NN"},
"two-seater":	{"NN"},
"two-seaters":	{"NNS"},
"two-shot":	{"NN"},
"two-sided":	{"JJ"},
"two-speed":	{"JJ"},
"two-spot":	{"NN"},
"two-star":	{"NN","JJ"},
"two-step":	{"JJ","NN"},
"two-storey":	{"JJ"},
"two-stroke":	{"JJ"},
"two-suiter":	{"NN"},
"two-tailed":	{"JJ"},
"two-thirds":	{"CD","NN"},
"two-tier":	{"JJ"},
"two-time":	{"VB","VBP","JJ"},
"two-timed":	{"VBD","VBN"},
"two-timer":	{"NN"},
"two-timers":	{"NNS"},
"two-times":	{"VBZ"},
"two-timing":	{"VBG"},
"two-tone":	{"JJ"},
"two-tooth":	{"NN"},
"two-tooths":	{"NNS"},
"two-up":	{"NN"},
"two-way":	{"JJ"},
"two-wheeler":	{"NN"},
"twofer":	{"NN"},
"twofold":	{"JJ","RB"},
"twopence":	{"NN"},
"twopenny":	{"JJ"},
"twopenny-halfpenny":	{"JJ"},
"twopoint":	{"NN"},
"twos":	{"NNS"},
"twosome":	{"NN"},
"twosomes":	{"NNS"},
"tyburn":	{"NN"},
"tyche":	{"NN"},
"tyco":	{"NN"},
"tycoon":	{"NN"},
"tycoons":	{"NNS"},
"tying":	{"VBG"},
"tyiyn":	{"NN"},
"tyke":	{"NN"},
"tykes":	{"NNS"},
"tylenchidae":	{"NN"},
"tylenchus":	{"NN"},
"tylenol":	{"NN"},
"tyler":	{"NN"},
"tyme":	{"NN"},
"tympan":	{"NN"},
"tympana":	{"NNS"},
"tympani":	{"NNS"},
"tympanic":	{"JJ"},
"tympanist":	{"NN"},
"tympanites":	{"NN"},
"tympanitic":	{"JJ"},
"tympanitis":	{"NN"},
"tympanoplasty":	{"NN"},
"tympanuchus":	{"NN"},
"tympanum":	{"NN"},
"tympanums":	{"NNS"},
"tyndall":	{"NN"},
"tyne":	{"NN"},
"type":	{"NN","VB","VBP"},
"type-cast":	{"VB","VBP","VBD","VBN"},
"type-casting":	{"VBG"},
"type-casts":	{"VBZ"},
"type-face":	{"NN"},
"typecast":	{"VB","VBP","VBD","VBN"},
"typecasting":	{"VBG","NN"},
"typecasts":	{"VBZ"},
"typed":	{"VBN","VBD"},
"typeface":	{"NN"},
"typefaces":	{"NNS"},
"types":	{"NNS","VBZ"},
"typescript":	{"NN"},
"typescripts":	{"NNS"},
"typeset":	{"VB","VBP","VBD","VBN"},
"typesets":	{"VBZ"},
"typesetter":	{"NN"},
"typesetters":	{"NNS"},
"typesetting":	{"NN","VBG"},
"typewrite":	{"VB","VBP"},
"typewriter":	{"NN"},
"typewriters":	{"NNS"},
"typewrites":	{"VBZ"},
"typewriting":	{"NN","VBG"},
"typewritten":	{"JJ","VBN"},
"typewrote":	{"VBD"},
"typha":	{"NN"},
"typhaceae":	{"NN"},
"typhi":	{"NN"},
"typhlopidae":	{"NN"},
"typhoid":	{"NN","JJ"},
"typhoon":	{"NN"},
"typhoons":	{"NNS"},
"typhus":	{"NN"},
"typic":	{"JJ"},
"typical":	{"JJ"},
"typicality":	{"NN"},
"typically":	{"RB"},
"typification":	{"NN"},
"typified":	{"VBD","VBN"},
"typifies":	{"VBZ"},
"typify":	{"VB","VBP"},
"typifying":	{"VBG"},
"typing":	{"NN","VBG"},
"typist":	{"NN"},
"typists":	{"NNS"},
"typo":	{"NN"},
"typographer":	{"NN"},
"typographers":	{"NNS"},
"typographic":	{"JJ"},
"typographical":	{"JJ"},
"typographically":	{"RB"},
"typography":	{"NN"},
"typological":	{"JJ"},
"typologies":	{"NNS"},
"typology":	{"NN"},
"typophile":	{"NN"},
"typos":	{"NNS"},
"tyramine":	{"NN"},
"tyranni":	{"NN"},
"tyrannic":	{"JJ"},
"tyrannical":	{"JJ"},
"tyrannicide":	{"NN"},
"tyrannid":	{"NN"},
"tyrannidae":	{"NN"},
"tyrannies":	{"NNS"},
"tyrannis":	{"NN"},
"tyrannise":	{"VB","VBP"},
"tyrannised":	{"VBD","VBN"},
"tyrannises":	{"VBZ"},
"tyrannising":	{"VBG"},
"tyrannize":	{"VB","VBP"},
"tyrannized":	{"VBD","VBN"},
"tyrannizes":	{"VBZ"},
"tyrannizing":	{"VBG"},
"tyrannosaur":	{"NN"},
"tyrannosaurus":	{"NN"},
"tyrannous":	{"JJ"},
"tyrannus":	{"NN"},
"tyranny":	{"NN"},
"tyrant":	{"NN"},
"tyrants":	{"NNS"},
"tyre":	{"NN"},
"tyres":	{"NNS"},
"tyro":	{"NN"},
"tyrocidin":	{"NN"},
"tyrocidine":	{"NN"},
"tyrolese":	{"JJ"},
"tyrosine":	{"NN"},
"tyrosinemia":	{"NN"},
"tyrothricin":	{"NN"},
"tyto":	{"NN"},
"tytonidae":	{"NN"},
"tzar":	{"NN"},
"tzara":	{"NN"},
"tzarina":	{"NN"},
"tzarist":	{"JJ"},
"tzetze":	{"NN"},
"u":	{"NN","SYM","LS"},
"u-turn":	{"NN"},
"uakari":	{"NN"},
"ubermensch":	{"NN"},
"ubiety":	{"NN"},
"ubiquinone":	{"NN"},
"ubiquitous":	{"JJ"},
"ubiquitously":	{"RB"},
"ubiquitousness":	{"NN"},
"ubiquity":	{"NN"},
"ubykh":	{"NN"},
"uca":	{"NN"},
"udder":	{"NN"},
"udders":	{"NNS"},
"udmurt":	{"NN"},
"udometer":	{"NN"},
"udon":	{"NN"},
"ufa":	{"NN"},
"ufos":	{"NNS"},
"uganda":	{"NN"},
"ugaritic":	{"NN"},
"ugh":	{"UH"},
"ugli":	{"NN"},
"uglier":	{"JJR"},
"uglies":	{"NNS"},
"ugliest":	{"JJS"},
"uglified":	{"VBD","VBN"},
"uglifies":	{"VBZ"},
"uglify":	{"VB","VBP"},
"uglifying":	{"VBG"},
"ugliness":	{"NN"},
"uglis":	{"NNS"},
"ugly":	{"JJ"},
"ugrian":	{"NN"},
"ugric":	{"NN"},
"uh":	{"UH"},
"uh-huh":	{"UH"},
"uh-uh":	{"UH"},
"uhhu":	{"UH"},
"uhland":	{"NN"},
"uighur":	{"NN"},
"uigur":	{"NN"},
"uintathere":	{"NN"},
"uintatheriidae":	{"NN"},
"uintatherium":	{"NN"},
"ukase":	{"NN"},
"uke":	{"NN"},
"ukelele":	{"NN"},
"ukeleles":	{"NNS"},
"ukulele":	{"NN"},
"ukuleles":	{"NNS"},
"ulalgia":	{"NN"},
"ulama":	{"NN"},
"ulanova":	{"NN"},
"ulatrophia":	{"NN"},
"ulcer":	{"NN"},
"ulcerate":	{"VB","VBP"},
"ulcerated":	{"JJ","VBD","VBN"},
"ulcerates":	{"VBZ"},
"ulcerating":	{"VBG"},
"ulceration":	{"NN"},
"ulcerative":	{"JJ"},
"ulcerous":	{"JJ"},
"ulcers":	{"NNS"},
"ulema":	{"NN"},
"ulemorrhagia":	{"NN"},
"ulex":	{"NN"},
"ulitis":	{"NN"},
"ullage":	{"NN","VB","VBP"},
"ullaged":	{"VBD","VBN","JJ"},
"ullages":	{"VBZ"},
"ullaging":	{"VBG"},
"ulmaceae":	{"NN"},
"ulmus":	{"NN"},
"ulna":	{"NN"},
"ulnae":	{"NNS"},
"ulnar":	{"JJ"},
"ulster":	{"NN"},
"ult":	{"JJ","RB"},
"ulterior":	{"JJ"},
"ulteriority":	{"NN"},
"ulteriorly":	{"RB"},
"ultima":	{"NN","JJ"},
"ultimacy":	{"NN"},
"ultimata":	{"NNS"},
"ultimate":	{"JJ","NN"},
"ultimately":	{"RB"},
"ultimateness":	{"NN"},
"ultimatum":	{"NN"},
"ultimatums":	{"NNS"},
"ultimo":	{"JJ"},
"ultra":	{"JJ","NN"},
"ultra-rightist":	{"NN","JJ"},
"ultra-rightists":	{"NNS"},
"ultracentrifugal":	{"JJ"},
"ultracentrifugally":	{"RB"},
"ultracentrifugation":	{"NN"},
"ultracentrifuge":	{"NN","VB","VBP"},
"ultracentrifuged":	{"VBD","VBN"},
"ultracentrifuges":	{"NNS","VBZ"},
"ultracentrifuging":	{"VBG"},
"ultraconservative":	{"JJ","NN"},
"ultraconservatives":	{"NNS"},
"ultraluxury":	{"JJ"},
"ultramarine":	{"JJ","NN"},
"ultramicroscope":	{"NN"},
"ultramicroscopic":	{"JJ"},
"ultramodern":	{"JJ"},
"ultramontane":	{"JJ","NN"},
"ultramontanism":	{"NN"},
"ultranational":	{"JJ"},
"ultranationalism":	{"NN"},
"ultranationalist":	{"JJ","NN"},
"ultranationalistic":	{"JJ"},
"ultranationalists":	{"NNS"},
"ultrarightist":	{"NN","JJ"},
"ultrarightists":	{"NNS"},
"ultrasimple":	{"JJ"},
"ultrasonic":	{"JJ"},
"ultrasonically":	{"RB"},
"ultrasonics":	{"NN"},
"ultrasonography":	{"NN"},
"ultrasound":	{"NN"},
"ultrasuede":	{"NN"},
"ultravehement":	{"JJ"},
"ultraviolence":	{"NN"},
"ultraviolent":	{"JJ"},
"ultraviolet":	{"JJ","NN"},
"ululate":	{"VB","VBP"},
"ululated":	{"VBD","VBN"},
"ululates":	{"VBZ"},
"ululating":	{"VBG"},
"ululation":	{"NN"},
"ulva":	{"NN"},
"ulvaceae":	{"NN"},
"ulvales":	{"NNS"},
"ulvophyceae":	{"NN"},
"um":	{"UH"},
"umbel":	{"NN"},
"umbellales":	{"NNS"},
"umbellar":	{"JJ"},
"umbellate":	{"JJ"},
"umbellifer":	{"NN"},
"umbelliferae":	{"NN"},
"umbelliferous":	{"JJ"},
"umbelliform":	{"JJ"},
"umbellularia":	{"NN"},
"umber":	{"NN","JJ"},
"umbilical":	{"JJ"},
"umbilicate":	{"JJ"},
"umbilici":	{"NNS"},
"umbilicus":	{"NN"},
"umbo":	{"NN"},
"umboes":	{"NNS"},
"umbonal":	{"JJ"},
"umbonate":	{"JJ"},
"umbonic":	{"JJ"},
"umbos":	{"NNS"},
"umbra":	{"NN"},
"umbrae":	{"NNS"},
"umbrage":	{"NN"},
"umbrageous":	{"JJ"},
"umbras":	{"NNS"},
"umbrella":	{"NN"},
"umbrellalike":	{"JJ"},
"umbrellas":	{"NNS"},
"umbrellawort":	{"NN"},
"umbrina":	{"NN"},
"umlaut":	{"NN"},
"umlauts":	{"NNS"},
"umma":	{"NN"},
"ump":	{"NN","VB","VBP"},
"umped":	{"VBD","VBN"},
"umping":	{"VBG"},
"umpirage":	{"NN"},
"umpire":	{"NN","VB","VBP"},
"umpired":	{"VBD","VBN"},
"umpires":	{"NNS","VBZ"},
"umpiring":	{"VBG"},
"umps":	{"NNS","VBZ"},
"umpteen":	{"NN","JJ"},
"umpteenth":	{"JJ","NN"},
"umteen":	{"JJ"},
"un":	{"NN"},
"un-American":	{"JJ"},
"un-Americanism":	{"NN"},
"un-English":	{"JJ"},
"un-PC":	{"JJ"},
"un-come-at-able":	{"JJ"},
"un-get-at-able":	{"JJ"},
"un-made-up":	{"JJ"},
"unMcGuanean":	{"JJ"},
"unabashed":	{"JJ"},
"unabashedly":	{"RB"},
"unabated":	{"JJ","RB"},
"unabatingly":	{"RB"},
"unable":	{"JJ"},
"unabridged":	{"JJ"},
"unabsorbed":	{"JJ"},
"unabused":	{"JJ"},
"unaccented":	{"JJ"},
"unacceptability":	{"NN"},
"unacceptable":	{"JJ"},
"unacceptableness":	{"NN"},
"unacceptably":	{"RB"},
"unaccepted":	{"JJ"},
"unaccessible":	{"JJ"},
"unaccommodating":	{"JJ"},
"unaccompanied":	{"JJ"},
"unaccountable":	{"JJ"},
"unaccountably":	{"RB"},
"unaccounted":	{"JJ"},
"unaccredited":	{"JJ"},
"unaccustomed":	{"JJ"},
"unachievable":	{"JJ"},
"unachievably":	{"RB"},
"unachieved":	{"JJ"},
"unacknowledged":	{"JJ"},
"unacquainted":	{"JJ"},
"unactable":	{"JJ"},
"unadaptability":	{"NN"},
"unadaptable":	{"JJ"},
"unadapted":	{"JJ"},
"unaddicted":	{"JJ"},
"unaddressed":	{"JJ"},
"unadjustable":	{"JJ"},
"unadjusted":	{"JJ"},
"unadoptable":	{"JJ"},
"unadorned":	{"JJ"},
"unadulterated":	{"JJ"},
"unadventurous":	{"JJ"},
"unadvisable":	{"JJ"},
"unadvised":	{"JJ"},
"unadvisedly":	{"RB"},
"unaerated":	{"JJ"},
"unaesthetic":	{"JJ"},
"unaffected":	{"JJ"},
"unaffectedness":	{"NN"},
"unaffecting":	{"JJ"},
"unaffectionate":	{"JJ"},
"unaffiliated":	{"JJ"},
"unaffixed":	{"JJ"},
"unaffordable":	{"JJ"},
"unafraid":	{"JJ"},
"unaged":	{"JJ"},
"unaggressive":	{"JJ"},
"unagi":	{"NN"},
"unagile":	{"JJ"},
"unai":	{"NN"},
"unaidable":	{"JJ"},
"unaided":	{"JJ"},
"unaired":	{"JJ"},
"unairworthy":	{"JJ"},
"unalarming":	{"JJ"},
"unalert":	{"JJ"},
"unalienable":	{"JJ"},
"unalike":	{"JJ"},
"unallocable":	{"JJ"},
"unalloyed":	{"JJ"},
"unalluring":	{"JJ"},
"unalterability":	{"NN"},
"unalterable":	{"JJ"},
"unalterably":	{"RB"},
"unaltered":	{"JJ"},
"unambiguity":	{"NN"},
"unambiguous":	{"JJ"},
"unambiguously":	{"RB"},
"unambitious":	{"JJ"},
"unambitiously":	{"RB"},
"unamended":	{"JJ"},
"unamortized":	{"JJ"},
"unamused":	{"JJ"},
"unamusing":	{"JJ"},
"unanalyzable":	{"JJ"},
"unanalyzed":	{"JJ"},
"unangry":	{"JJ"},
"unanimated":	{"JJ"},
"unanimity":	{"NN"},
"unanimous":	{"JJ"},
"unanimously":	{"RB"},
"unannealed":	{"JJ"},
"unannounced":	{"JJ"},
"unanswerable":	{"JJ"},
"unanswered":	{"JJ"},
"unanticipated":	{"JJ"},
"unapologetic":	{"JJ"},
"unappareled":	{"JJ"},
"unapparent":	{"JJ"},
"unappealable":	{"JJ"},
"unappealing":	{"JJ"},
"unappealingly":	{"RB"},
"unappeasable":	{"JJ"},
"unappeasably":	{"RB"},
"unappendaged":	{"JJ"},
"unappetising":	{"JJ"},
"unappetisingness":	{"NN"},
"unappetizing":	{"JJ"},
"unappetizingness":	{"NN"},
"unappreciated":	{"JJ"},
"unappreciative":	{"JJ"},
"unappreciatively":	{"RB"},
"unapprehensive":	{"JJ"},
"unapproachability":	{"NN"},
"unapproachable":	{"JJ"},
"unapproved":	{"JJ"},
"unarbitrary":	{"JJ"},
"unarguable":	{"JJ"},
"unarguably":	{"RB"},
"unargumentative":	{"JJ"},
"unarm":	{"VB","VBP"},
"unarmed":	{"VBD","VBN","JJ","RB"},
"unarming":	{"VBG"},
"unarmored":	{"JJ"},
"unarmoured":	{"JJ"},
"unarms":	{"VBZ"},
"unarticulate":	{"JJ"},
"unarticulated":	{"JJ"},
"unartistic":	{"JJ"},
"unary":	{"JJ"},
"unascertainable":	{"JJ"},
"unascribable":	{"JJ"},
"unashamed":	{"JJ"},
"unashamedly":	{"RB"},
"unasked":	{"JJ"},
"unassailable":	{"JJ"},
"unassailably":	{"RB"},
"unassertive":	{"JJ"},
"unassertively":	{"RB"},
"unassertiveness":	{"NN"},
"unassignable":	{"JJ"},
"unassigned":	{"JJ"},
"unassisted":	{"JJ"},
"unassuming":	{"JJ"},
"unassumingly":	{"RB"},
"unassumingness":	{"NN"},
"unassured":	{"JJ"},
"unasterisked":	{"JJ"},
"unattached":	{"JJ"},
"unattackable":	{"JJ"},
"unattainable":	{"JJ"},
"unattainableness":	{"NN"},
"unattainably":	{"RB"},
"unattended":	{"JJ"},
"unattired":	{"JJ"},
"unattractive":	{"JJ"},
"unattractively":	{"RB"},
"unattractiveness":	{"NN"},
"unattributable":	{"JJ"},
"unau":	{"NN"},
"unaudited":	{"JJ"},
"unauthentic":	{"JJ"},
"unauthorised":	{"JJ"},
"unauthorized":	{"JJ"},
"unavailability":	{"NN"},
"unavailable":	{"JJ"},
"unavailing":	{"JJ"},
"unavenged":	{"JJ"},
"unavoidability":	{"NN"},
"unavoidable":	{"JJ"},
"unavoidably":	{"RB"},
"unavowed":	{"JJ"},
"unawakened":	{"JJ"},
"unaware":	{"JJ"},
"unawareness":	{"NN"},
"unawares":	{"RB"},
"unawed":	{"JJ"},
"unbacked":	{"JJ"},
"unbaffled":	{"JJ"},
"unbalance":	{"VB","VBP"},
"unbalanced":	{"JJ","VBD","VBN"},
"unbalances":	{"VBZ"},
"unbalancing":	{"VBG"},
"unbalconied":	{"JJ"},
"unbanded":	{"JJ"},
"unbaptised":	{"JJ"},
"unbaptized":	{"JJ"},
"unbar":	{"VB","VBP"},
"unbarred":	{"VBD","VBN"},
"unbarring":	{"VBG"},
"unbars":	{"VBZ"},
"unbearable":	{"JJ"},
"unbearably":	{"RB"},
"unbeatable":	{"JJ"},
"unbeaten":	{"JJ"},
"unbecoming":	{"JJ"},
"unbecomingly":	{"RB"},
"unbecomingness":	{"NN"},
"unbefitting":	{"JJ"},
"unbeholden":	{"JJ"},
"unbeknown":	{"RB","JJ"},
"unbeknownst":	{"RB","JJ"},
"unbelief":	{"NN"},
"unbelievable":	{"JJ"},
"unbelievably":	{"RB"},
"unbeliever":	{"NN"},
"unbelievers":	{"NNS"},
"unbelieving":	{"JJ"},
"unbelievingly":	{"RB"},
"unbeloved":	{"JJ"},
"unbelt":	{"VB","VBP"},
"unbelted":	{"JJ"},
"unbend":	{"VB","VBP"},
"unbendable":	{"JJ"},
"unbending":	{"JJ","VBG"},
"unbends":	{"VBZ"},
"unbeneficed":	{"JJ"},
"unbent":	{"JJ","VBD","VBN"},
"unbiased":	{"JJ"},
"unbiasedly":	{"RB"},
"unbiasedness":	{"NN"},
"unbiassed":	{"JJ"},
"unbiassedly":	{"RB"},
"unbiassedness":	{"NN"},
"unbidden":	{"JJ","RB"},
"unbigoted":	{"JJ"},
"unbind":	{"VB","VBP"},
"unbinding":	{"VBG"},
"unbinds":	{"VBZ"},
"unbitter":	{"JJ"},
"unbleached":	{"JJ"},
"unblemished":	{"JJ"},
"unblended":	{"JJ"},
"unblessed":	{"JJ"},
"unblinking":	{"JJ"},
"unblinkingly":	{"RB"},
"unblock":	{"VB","VBP"},
"unbloody":	{"JJ"},
"unblushing":	{"JJ"},
"unblushingly":	{"RB"},
"unbodied":	{"JJ"},
"unbolt":	{"VB","VBP"},
"unbolted":	{"JJ","VBD","VBN"},
"unbolting":	{"VBG"},
"unbolts":	{"VBZ"},
"unbooked":	{"JJ"},
"unboring":	{"JJ"},
"unborn":	{"JJ","NNS"},
"unbosom":	{"VB","VBP"},
"unbosomed":	{"VBD","VBN"},
"unbosoming":	{"VBG"},
"unbosoms":	{"VBZ"},
"unbothered":	{"JJ"},
"unbound":	{"VBD","VBN","JJ"},
"unbounded":	{"JJ"},
"unboundedness":	{"NN"},
"unbowed":	{"JJ"},
"unbox":	{"VB","VBP"},
"unbrace":	{"VB","VBP"},
"unbraced":	{"VBD","VBN"},
"unbraces":	{"VBZ"},
"unbracing":	{"VBG"},
"unbraid":	{"VB","VBP"},
"unbrainwashed":	{"JJ"},
"unbranched":	{"JJ"},
"unbranching":	{"JJ"},
"unbranded":	{"JJ"},
"unbreakable":	{"JJ"},
"unbreakableness":	{"NN"},
"unbridgeable":	{"JJ"},
"unbridle":	{"VB","VBP"},
"unbridled":	{"VBD","VBN"},
"unbridles":	{"VBZ"},
"unbridling":	{"VBG"},
"unbroken":	{"JJ"},
"unbrushed":	{"JJ"},
"unbuckle":	{"VB","VBP"},
"unbuckled":	{"VBD","VBN"},
"unbuckles":	{"VBZ"},
"unbuckling":	{"VBG"},
"unbundle":	{"VB","VBP"},
"unbundled":	{"VBD","VBN"},
"unbundles":	{"VBZ"},
"unbundling":	{"VBG"},
"unburden":	{"VB","VBP"},
"unburdened":	{"VBD","VBN"},
"unburdening":	{"VBG"},
"unburdens":	{"VBZ"},
"unburied":	{"JJ"},
"unburned":	{"JJ"},
"unburnished":	{"JJ"},
"unbutton":	{"VB","VBP"},
"unbuttoned":	{"VBD","VBN","JJ"},
"unbuttoning":	{"VBG"},
"unbuttons":	{"VBZ"},
"uncalled":	{"JJ"},
"uncalled-for":	{"JJ"},
"uncamphorated":	{"JJ"},
"uncannier":	{"JJR"},
"uncanniest":	{"JJS"},
"uncannily":	{"RB"},
"uncanny":	{"JJ"},
"uncap":	{"VB","VBP"},
"uncapped":	{"VBD","VBN","JJ"},
"uncapping":	{"VBG"},
"uncaps":	{"VBZ"},
"uncarbonated":	{"JJ"},
"uncared-for":	{"JJ"},
"uncaring":	{"JJ"},
"uncarpeted":	{"JJ"},
"uncarved":	{"JJ"},
"uncase":	{"VB","VBP"},
"uncastrated":	{"JJ"},
"uncataloged":	{"JJ"},
"uncaulked":	{"JJ"},
"uncaused":	{"JJ"},
"unceasing":	{"JJ"},
"unceasingly":	{"RB"},
"uncensored":	{"JJ"},
"unceremonious":	{"JJ"},
"unceremoniously":	{"RB"},
"unceremoniousness":	{"NN"},
"uncertain":	{"JJ"},
"uncertainly":	{"RB"},
"uncertainness":	{"NN"},
"uncertainties":	{"NNS"},
"uncertainty":	{"NN"},
"uncertified":	{"JJ"},
"unchain":	{"VB","VBP"},
"unchained":	{"VBD","VBN"},
"unchallengeable":	{"JJ"},
"unchallenged":	{"JJ"},
"unchangeability":	{"NN"},
"unchangeable":	{"JJ"},
"unchangeableness":	{"NN"},
"unchangeably":	{"RB"},
"unchanged":	{"JJ"},
"unchangedat":	{"JJ"},
"unchanging":	{"JJ"},
"unchangingness":	{"NN"},
"uncharacteristic":	{"JJ"},
"uncharacteristically":	{"RB"},
"uncharged":	{"JJ"},
"uncharitable":	{"JJ"},
"uncharitably":	{"RB"},
"uncharted":	{"JJ"},
"unchartered":	{"JJ"},
"unchaste":	{"JJ"},
"uncheckable":	{"JJ"},
"unchecked":	{"JJ"},
"uncheerful":	{"JJ"},
"uncheerfulness":	{"NN"},
"unchewable":	{"JJ"},
"unchivalrous":	{"JJ"},
"unchivalrously":	{"RB"},
"unchlorinated":	{"JJ"},
"unchristian":	{"JJ"},
"unchristianly":	{"JJ"},
"unchristlike":	{"JJ"},
"unchurch":	{"VB","VBP"},
"unchurched":	{"VBD","VBN","JJ"},
"unci":	{"NNS"},
"uncial":	{"JJ","NN"},
"uncially":	{"RB"},
"uncircumcision":	{"NN"},
"uncivil":	{"JJ"},
"uncivilised":	{"JJ"},
"uncivilized":	{"JJ"},
"uncivilly":	{"RB"},
"unclad":	{"JJ","VBD","VBN"},
"unclaimed":	{"JJ"},
"unclasp":	{"VB","VBP"},
"unclasping":	{"VBG"},
"unclassifiable":	{"JJ"},
"unclassifiably":	{"RB"},
"unclassified":	{"JJ"},
"uncle":	{"NN"},
"unclean":	{"JJ"},
"uncleanliness":	{"NN"},
"uncleanly":	{"JJ","RB"},
"uncleanness":	{"NN"},
"unclear":	{"JJ"},
"uncleared":	{"JJ"},
"unclearly":	{"RB"},
"unclearness":	{"NN"},
"unclench":	{"VB","VBP"},
"unclenched":	{"VBD","VBN"},
"unclenches":	{"VBZ"},
"unclenching":	{"VBG"},
"uncles":	{"NNS"},
"unclimbable":	{"JJ"},
"unclip":	{"VB","VBP"},
"unclipped":	{"VBD","VBN"},
"uncloak":	{"VB","VBP"},
"uncloaked":	{"VBD","VBN"},
"uncloaking":	{"VBG"},
"uncloaks":	{"VBZ"},
"unclocked":	{"VBD","VBN","JJ"},
"unclog":	{"VB","VBP"},
"unclogged":	{"VBD","VBN"},
"unclogging":	{"VBG"},
"unclogs":	{"VBZ"},
"unclothe":	{"VB","VBP"},
"unclothed":	{"VBD","VBN","JJ"},
"unclothes":	{"VBZ"},
"unclothing":	{"VBG"},
"unclouded":	{"JJ"},
"uncloudedness":	{"NN"},
"unclutter":	{"VB","VBP"},
"uncluttered":	{"JJ","VBD","VBN"},
"unco":	{"JJ","RB","NN"},
"uncoached":	{"JJ"},
"uncoated":	{"JJ"},
"uncoer":	{"JJR"},
"uncoerced":	{"JJ"},
"uncoest":	{"JJS"},
"uncoil":	{"VB","VBP"},
"uncoiled":	{"VBD","VBN"},
"uncoiling":	{"VBG"},
"uncoils":	{"VBZ"},
"uncollaborated":	{"JJ"},
"uncollectable":	{"JJ"},
"uncollected":	{"JJ"},
"uncollectible":	{"JJ"},
"uncolored":	{"JJ"},
"uncoloured":	{"JJ"},
"uncolumned":	{"JJ"},
"uncombable":	{"JJ"},
"uncombed":	{"JJ"},
"uncombined":	{"JJ"},
"uncomely":	{"JJ"},
"uncomfortable":	{"JJ"},
"uncomfortableness":	{"NN"},
"uncomfortably":	{"RB"},
"uncomforted":	{"JJ"},
"uncommercial":	{"JJ"},
"uncommercialised":	{"JJ"},
"uncommercialized":	{"JJ"},
"uncommitted":	{"JJ"},
"uncommon":	{"JJ"},
"uncommonly":	{"RB"},
"uncommonness":	{"NN"},
"uncommunicative":	{"JJ"},
"uncommunicativeness":	{"NN"},
"uncomparable":	{"JJ"},
"uncomparably":	{"RB"},
"uncompassionate":	{"JJ"},
"uncompensated":	{"JJ"},
"uncompetitive":	{"JJ"},
"uncomplaining":	{"JJ"},
"uncomplainingly":	{"RB"},
"uncomplete":	{"JJ"},
"uncompleted":	{"JJ"},
"uncomplex":	{"JJ"},
"uncomplicated":	{"JJ"},
"uncomplicatedly":	{"RB"},
"uncomplimentary":	{"JJ"},
"uncompounded":	{"JJ"},
"uncomprehended":	{"JJ"},
"uncomprehending":	{"JJ"},
"uncomprehendingly":	{"RB"},
"uncomprehensible":	{"JJ"},
"uncompress":	{"VB","VBP"},
"uncompromising":	{"JJ"},
"uncompromisingly":	{"RB"},
"unconcealed":	{"JJ"},
"unconcern":	{"NN"},
"unconcerned":	{"JJ"},
"unconcernedly":	{"RB"},
"unconditional":	{"JJ"},
"unconditionally":	{"RB"},
"unconditioned":	{"JJ"},
"unconfessed":	{"JJ"},
"unconfined":	{"JJ"},
"unconfirmed":	{"JJ"},
"unconformable":	{"JJ"},
"unconformist":	{"JJ"},
"unconfused":	{"JJ"},
"uncongenial":	{"JJ"},
"uncongeniality":	{"NN"},
"unconnected":	{"JJ"},
"unconnectedness":	{"NN"},
"unconquerable":	{"JJ"},
"unconquered":	{"JJ"},
"unconscientious":	{"JJ"},
"unconscientiousness":	{"NN"},
"unconscionable":	{"JJ"},
"unconscionably":	{"RB"},
"unconscious":	{"JJ","NN"},
"unconsciously":	{"RB"},
"unconsciousness":	{"NN"},
"unconsecrated":	{"JJ"},
"unconsidered":	{"JJ"},
"unconsolable":	{"JJ"},
"unconsolidated":	{"JJ"},
"unconstipated":	{"JJ"},
"unconstitutional":	{"JJ"},
"unconstitutionally":	{"RB"},
"unconstrained":	{"JJ"},
"unconstraint":	{"NN"},
"unconstricted":	{"JJ"},
"unconstructive":	{"JJ"},
"unconsumed":	{"JJ"},
"unconsummated":	{"JJ"},
"uncontaminated":	{"JJ"},
"uncontaminating":	{"JJ"},
"uncontested":	{"JJ"},
"uncontrived":	{"JJ"},
"uncontrollable":	{"JJ"},
"uncontrollably":	{"RB"},
"uncontrolled":	{"JJ"},
"uncontroversial":	{"JJ"},
"uncontroversially":	{"RB"},
"unconventional":	{"JJ"},
"unconventionality":	{"NN"},
"unconventionally":	{"RB"},
"unconverted":	{"JJ"},
"unconvertible":	{"JJ"},
"unconvinced":	{"JJ"},
"unconvincing":	{"JJ"},
"unconvincingly":	{"RB"},
"uncooked":	{"JJ"},
"uncool":	{"JJ"},
"uncooperative":	{"JJ"},
"uncoordinated":	{"JJ"},
"uncordial":	{"JJ"},
"uncork":	{"VB","VBP"},
"uncorked":	{"VBD","VBN"},
"uncorking":	{"VBG"},
"uncorks":	{"VBZ"},
"uncorrectable":	{"JJ"},
"uncorrected":	{"JJ"},
"uncorrelated":	{"JJ"},
"uncorroborated":	{"JJ"},
"uncorrupted":	{"JJ"},
"uncos":	{"NNS"},
"uncounted":	{"JJ"},
"uncouple":	{"VB","VBP"},
"uncoupled":	{"JJ","VBD","VBN"},
"uncouples":	{"VBZ"},
"uncoupling":	{"VBG"},
"uncourageous":	{"JJ"},
"uncouth":	{"JJ"},
"uncouthly":	{"RB"},
"uncouthness":	{"NN"},
"uncover":	{"VB","VBP"},
"uncovered":	{"VBD","VBN","JJ"},
"uncovering":	{"VBG"},
"uncovers":	{"VBZ"},
"uncrannied":	{"JJ"},
"uncrate":	{"VB","VBP"},
"uncreased":	{"JJ"},
"uncreative":	{"JJ"},
"uncreativeness":	{"NN"},
"uncritical":	{"JJ"},
"uncritically":	{"RB"},
"uncropped":	{"JJ"},
"uncross":	{"VB","VBP"},
"uncrossed":	{"JJ","VBD","VBN"},
"uncrowded":	{"JJ"},
"uncrowned":	{"JJ"},
"uncrystallised":	{"JJ"},
"uncrystallized":	{"JJ"},
"unction":	{"NN"},
"unctuous":	{"JJ"},
"unctuously":	{"RB"},
"unctuousness":	{"NN"},
"uncultivable":	{"JJ"},
"uncultivatable":	{"JJ"},
"uncultivated":	{"JJ"},
"uncultured":	{"JJ"},
"uncurbed":	{"JJ"},
"uncured":	{"JJ"},
"uncurl":	{"VB","VBP"},
"uncurled":	{"VBD","VBN"},
"uncurling":	{"VBG"},
"uncurls":	{"VBZ"},
"uncurtained":	{"JJ"},
"uncurved":	{"JJ"},
"uncus":	{"NN"},
"uncut":	{"JJ"},
"undamaged":	{"JJ"},
"undatable":	{"JJ"},
"undated":	{"JJ"},
"undaunted":	{"JJ"},
"undead":	{"JJ"},
"undecagon":	{"NN"},
"undeceivable":	{"JJ"},
"undeceive":	{"VB","VBP"},
"undeceived":	{"VBD","VBN"},
"undeceiver":	{"NN"},
"undeceives":	{"VBZ"},
"undeceiving":	{"VBG"},
"undecided":	{"JJ"},
"undecidedly":	{"RB"},
"undecidedness":	{"NN"},
"undecipherable":	{"JJ"},
"undecipherably":	{"RB"},
"undeciphered":	{"JJ"},
"undeclared":	{"JJ"},
"undecomposable":	{"JJ"},
"undecomposed":	{"JJ"},
"undecorated":	{"JJ"},
"undedicated":	{"JJ"},
"undefeated":	{"JJ"},
"undefendable":	{"JJ"},
"undefended":	{"JJ"},
"undeferential":	{"JJ"},
"undefiled":	{"JJ"},
"undefinable":	{"JJ"},
"undefined":	{"JJ"},
"undelineated":	{"JJ"},
"undelivered":	{"JJ"},
"undemanding":	{"JJ"},
"undemocratic":	{"JJ"},
"undemocratically":	{"RB"},
"undemonstrative":	{"JJ"},
"undeniable":	{"JJ"},
"undeniably":	{"RB"},
"undenominational":	{"JJ"},
"undependability":	{"NN"},
"undependable":	{"JJ"},
"undependableness":	{"NN"},
"undependably":	{"RB"},
"undepicted":	{"JJ"},
"under":	{"IN","RP","RB","JJ"},
"under-resourced":	{"JJ"},
"under-secretaries":	{"NNS"},
"under-secretary":	{"NN"},
"under-the-counter":	{"JJ"},
"under-the-table":	{"JJ"},
"under-used":	{"JJ"},
"underachieve":	{"VB","VBP"},
"underachieved":	{"VBD","VBN"},
"underachievement":	{"NN"},
"underachiever":	{"NN"},
"underachievers":	{"NNS"},
"underachieves":	{"VBZ"},
"underachieving":	{"VBG"},
"underact":	{"VB","VBP"},
"underacted":	{"VBD","VBN"},
"underacting":	{"VBG"},
"underactive":	{"JJ"},
"underacts":	{"VBZ"},
"underage":	{"JJ"},
"underappreciated":	{"JJ"},
"underarm":	{"JJ","RB","NN"},
"underarms":	{"NNS"},
"underbake":	{"VB","VBP"},
"underbaked":	{"VBD","VBN"},
"underbakes":	{"VBZ"},
"underbaking":	{"VBG"},
"underbanked":	{"JJ"},
"underbedding":	{"NN"},
"underbellies":	{"NNS"},
"underbelly":	{"NN"},
"underbid":	{"VB","VBP","VBD","VBN"},
"underbidding":	{"VBG"},
"underbids":	{"VBZ"},
"underbodice":	{"NN"},
"underbody":	{"NN"},
"underboss":	{"NN"},
"underbosses":	{"NNS"},
"underbracing":	{"NN"},
"underbred":	{"JJ"},
"underbrush":	{"NN"},
"undercapitalise":	{"VB","VBP"},
"undercapitalised":	{"VBD","VBN","JJ"},
"undercapitalises":	{"VBZ"},
"undercapitalising":	{"VBG"},
"undercapitalization":	{"NN"},
"undercapitalize":	{"VB","VBP"},
"undercapitalized":	{"JJ","VBD","VBN"},
"undercapitalizes":	{"VBZ"},
"undercapitalizing":	{"VBG"},
"undercarriage":	{"NN"},
"undercarriages":	{"NNS"},
"undercharge":	{"VB","VBP","NN"},
"undercharged":	{"VBD","VBN"},
"undercharges":	{"VBZ"},
"undercharging":	{"VBG"},
"underclass":	{"NN","JJ"},
"underclasses":	{"NNS"},
"underclassman":	{"NN"},
"underclassmen":	{"NNS"},
"underclothed":	{"JJ"},
"underclothes":	{"NNS"},
"underclothing":	{"NN"},
"undercoat":	{"NN","VB","VBP"},
"undercoated":	{"VBD","VBN"},
"undercoating":	{"VBG"},
"undercoats":	{"NNS","VBZ"},
"undercover":	{"JJ","RB"},
"undercurrent":	{"NN"},
"undercurrents":	{"NNS"},
"undercut":	{"VB","VBP","NN","VBD","VBN"},
"undercuts":	{"VBZ"},
"undercutting":	{"VBG"},
"underdevelop":	{"VB","VBP"},
"underdeveloped":	{"JJ","VBD","VBN"},
"underdeveloping":	{"VBG"},
"underdevelopment":	{"NN"},
"underdevelops":	{"VBZ"},
"underdog":	{"NN"},
"underdogs":	{"NNS"},
"underdone":	{"JJ"},
"underdrawers":	{"NNS"},
"underdress":	{"NN","VB","VBP"},
"underdressed":	{"VBD","VBN","JJ"},
"underdresses":	{"VBZ"},
"underdressing":	{"VBG"},
"undereducated":	{"JJ"},
"underemployed":	{"JJ"},
"underemployment":	{"NN"},
"underestimate":	{"VB","VBP","NN"},
"underestimated":	{"VBD","VBN"},
"underestimates":	{"VBZ","NNS"},
"underestimating":	{"VBG"},
"underestimation":	{"NN"},
"underevaluation":	{"NN"},
"underexpose":	{"VB","VBP"},
"underexposed":	{"VBD","VBN","JJ"},
"underexposes":	{"VBZ"},
"underexposing":	{"VBG"},
"underexposure":	{"NN"},
"underfed":	{"JJ"},
"underfelt":	{"NN"},
"underfoot":	{"RB"},
"underframe":	{"NN"},
"underfund":	{"VB","VBP"},
"underfunded":	{"JJ","VBD","VBN"},
"underfunding":	{"NN","VBG"},
"underfunds":	{"VBZ"},
"underfur":	{"NN"},
"undergarment":	{"NN"},
"undergarments":	{"NNS"},
"undergird":	{"VB","VBP"},
"undergirded":	{"VBD","VBN"},
"undergirding":	{"VBG"},
"undergirds":	{"VBZ"},
"undergo":	{"VB","VBP"},
"undergoes":	{"VBZ"},
"undergoing":	{"VBG"},
"undergone":	{"VBN"},
"undergrad":	{"NN"},
"undergrads":	{"NNS"},
"undergraduate":	{"NN"},
"undergraduates":	{"NNS"},
"underground":	{"JJ","RB","NN"},
"undergrow":	{"VB","VBP"},
"undergrown":	{"JJ","VBN"},
"undergrowth":	{"NN"},
"underhand":	{"JJ","RB"},
"underhanded":	{"JJ"},
"underhandedly":	{"RB"},
"underhandedness":	{"NN"},
"underhill":	{"NN"},
"underhung":	{"JJ"},
"underinvest":	{"VB","VBP"},
"underinvested":	{"VBD","VBN"},
"underinvestigated":	{"JJ"},
"underinvesting":	{"VBG"},
"underinvests":	{"VBZ"},
"underivative":	{"JJ"},
"underived":	{"JJ"},
"underlaid":	{"VBD","VBN","JJ"},
"underlain":	{"VBN"},
"underlay":	{"NN","VBD","VB","VBP"},
"underlaying":	{"VBG"},
"underlayment":	{"NN"},
"underlays":	{"NNS"},
"underlie":	{"VB","VBP"},
"underlies":	{"VBZ"},
"underline":	{"VB","VBP"},
"underlined":	{"VBD","VBN"},
"underlines":	{"VBZ"},
"underling":	{"NN"},
"underlings":	{"NNS"},
"underlining":	{"VBG","NN"},
"underlip":	{"NN"},
"underlying":	{"JJ","VBG"},
"undermanned":	{"JJ"},
"undermentioned":	{"JJ"},
"undermine":	{"VB","VBP"},
"undermined":	{"VBN","VBD"},
"undermines":	{"VBZ"},
"undermining":	{"VBG"},
"underneath":	{"IN","RB","NN"},
"undernourish":	{"VB","VBP"},
"undernourished":	{"JJ","VBD","VBN"},
"undernourishment":	{"NN"},
"underpaid":	{"JJ","VBD","VBN"},
"underpants":	{"NNS"},
"underpart":	{"NN"},
"underpass":	{"NN"},
"underpasses":	{"NNS"},
"underpay":	{"VB","VBP"},
"underpaying":	{"VBG"},
"underpayment":	{"NN"},
"underpays":	{"VBZ"},
"underperform":	{"VB","VBP"},
"underperformance":	{"NN"},
"underperformed":	{"VBD","VBN"},
"underperformer":	{"NN"},
"underperformers":	{"NNS"},
"underperforming":	{"VBG"},
"underperforms":	{"VBZ"},
"underpin":	{"VB","VBP"},
"underpinned":	{"VBD","VBN"},
"underpinning":	{"NN","VBG"},
"underpinnings":	{"NNS"},
"underpins":	{"VBZ"},
"underplay":	{"VB","VBP"},
"underplayed":	{"VBD","VBN"},
"underplaying":	{"VBG"},
"underplays":	{"VBZ"},
"underpopulated":	{"JJ"},
"underprepared":	{"JJ"},
"underprice":	{"VB","VBP"},
"underpriced":	{"VBD","VBN","JJ"},
"underprices":	{"VBZ"},
"underpricing":	{"VBG","NN"},
"underprivileged":	{"JJ","NNS"},
"underproduce":	{"VB","VBP"},
"underproduced":	{"VBD","VBN"},
"underproduces":	{"VBZ"},
"underproducing":	{"VBG"},
"underproduction":	{"NN"},
"underquote":	{"VB","VBP"},
"underquoted":	{"VBD","VBN"},
"underquotes":	{"VBZ"},
"underquoting":	{"VBG"},
"underrate":	{"VB","VBP"},
"underrated":	{"VBN","VBD","JJ"},
"underrates":	{"VBZ"},
"underrating":	{"VBG"},
"underreact":	{"VB","VBP"},
"underreacted":	{"VBD","VBN"},
"underreacting":	{"VBG"},
"underreacts":	{"VBZ"},
"underreport":	{"VB","VBP"},
"underreported":	{"VBD","VBN"},
"underreporting":	{"VBG"},
"underreports":	{"VBZ"},
"underrepresented":	{"JJ"},
"underresourced":	{"JJ"},
"underscore":	{"VB","VBP"},
"underscored":	{"VBD","VBN"},
"underscores":	{"VBZ"},
"underscoring":	{"VBG"},
"undersea":	{"JJ"},
"underseal":	{"NN","VB","VBP"},
"undersealed":	{"VBD","VBN"},
"undersealing":	{"VBG"},
"underseals":	{"VBZ"},
"undersecretaries":	{"NNS"},
"undersecretary":	{"NN"},
"undersell":	{"VB","VBP"},
"underseller":	{"NN"},
"underselling":	{"VBG"},
"undersells":	{"VBZ"},
"underserved":	{"JJ"},
"undersexed":	{"JJ"},
"undershirt":	{"NN"},
"undershirts":	{"NNS"},
"undershoot":	{"VB","VBP"},
"undershooting":	{"VBG"},
"undershoots":	{"VBZ"},
"undershot":	{"JJ","VBD","VBN"},
"undershrub":	{"NN"},
"underside":	{"NN"},
"undersides":	{"NNS"},
"undersign":	{"VB","VBP"},
"undersize":	{"JJ"},
"undersized":	{"JJ"},
"underskirt":	{"NN"},
"underslung":	{"JJ"},
"undersoil":	{"NN"},
"undersold":	{"VBD","VBN"},
"underspend":	{"VB","VBP","NN"},
"underspending":	{"VBG"},
"underspends":	{"VBZ","NNS"},
"underspent":	{"VBD","VBN"},
"understaffed":	{"JJ"},
"understand":	{"VB","VBP"},
"understandability":	{"NN"},
"understandable":	{"JJ"},
"understandably":	{"RB"},
"understanding":	{"NN","VBG","JJ"},
"understandingly":	{"RB"},
"understandings":	{"NNS"},
"understands":	{"VBZ"},
"understate":	{"VB","VBP"},
"understated":	{"VBD","VBN","JJ"},
"understatement":	{"NN"},
"understatements":	{"NNS"},
"understates":	{"VBZ"},
"understating":	{"VBG"},
"understock":	{"VB","VBP"},
"understood":	{"VBD","VBN"},
"understructure":	{"NN"},
"understudied":	{"VBD","VBN"},
"understudies":	{"NNS","VBZ"},
"understudy":	{"NN","VB","VBP"},
"understudying":	{"VBG"},
"undersubscription":	{"NN"},
"undersurface":	{"NN"},
"undertake":	{"VB","VBP"},
"undertaken":	{"VBN"},
"undertaker":	{"NN"},
"undertakers":	{"NNS"},
"undertakes":	{"VBZ","NNS"},
"undertaking":	{"NN","VBG"},
"undertakings":	{"NNS"},
"undertide":	{"NN"},
"undertone":	{"NN"},
"undertones":	{"NNS"},
"undertook":	{"VBD"},
"undertow":	{"NN"},
"undertows":	{"NNS"},
"underuse":	{"VB","VBP","NN"},
"underused":	{"JJ","VBD","VBN"},
"underuses":	{"VBZ"},
"underusing":	{"VBG"},
"underutilization":	{"NN"},
"underutilized":	{"JJ"},
"undervaluation":	{"NN"},
"undervalue":	{"VB","VBP"},
"undervalued":	{"VBD","VBN","JJ"},
"undervalues":	{"VBZ"},
"undervaluing":	{"VBG"},
"underwater":	{"JJ","RB"},
"underway":	{"JJ"},
"underwear":	{"NN"},
"underweight":	{"NN","JJ"},
"underwent":	{"VBD"},
"underwhelm":	{"VB","VBP"},
"underwhelmed":	{"VBD","VBN","JJ"},
"underwhelming":	{"VBG"},
"underwhelms":	{"VBZ"},
"underwing":	{"NN"},
"underwood":	{"NN"},
"underworked":	{"JJ"},
"underworld":	{"NN"},
"underwrite":	{"VB","VBP"},
"underwriter":	{"NN"},
"underwriters":	{"NNS"},
"underwrites":	{"VBZ"},
"underwriting":	{"VBG","NN"},
"underwritings":	{"NNS"},
"underwritten":	{"VBN"},
"underwrote":	{"VBD"},
"undescended":	{"JJ"},
"undescriptive":	{"JJ"},
"undeserved":	{"JJ"},
"undeservedly":	{"RB"},
"undeserving":	{"JJ"},
"undesigned":	{"JJ"},
"undesirability":	{"NN"},
"undesirable":	{"JJ","NN"},
"undesirables":	{"NNS"},
"undesirably":	{"RB"},
"undesired":	{"JJ"},
"undesiring":	{"JJ"},
"undesirous":	{"JJ"},
"undestroyable":	{"JJ"},
"undetectable":	{"JJ"},
"undetected":	{"JJ"},
"undeterminable":	{"JJ"},
"undetermined":	{"JJ"},
"undeterred":	{"JJ"},
"undeveloped":	{"JJ"},
"undeviating":	{"JJ"},
"undiagnosable":	{"JJ"},
"undiagnosed":	{"JJ"},
"undid":	{"VBD"},
"undies":	{"NNS"},
"undifferentiated":	{"JJ"},
"undigested":	{"JJ"},
"undignified":	{"JJ"},
"undiluted":	{"JJ"},
"undiminished":	{"JJ"},
"undimmed":	{"JJ"},
"undine":	{"NN"},
"undiplomatic":	{"JJ"},
"undiplomatically":	{"RB"},
"undirected":	{"JJ"},
"undiscerning":	{"JJ"},
"undischarged":	{"JJ"},
"undiscipline":	{"NN"},
"undisciplined":	{"JJ"},
"undisclosed":	{"JJ"},
"undiscouraged":	{"JJ"},
"undiscoverable":	{"JJ"},
"undiscovered":	{"JJ"},
"undiscriminating":	{"JJ"},
"undisguised":	{"JJ"},
"undismayed":	{"JJ"},
"undisputable":	{"JJ"},
"undisputed":	{"JJ"},
"undisputedly":	{"RB"},
"undisrupted":	{"JJ"},
"undissolved":	{"JJ"},
"undistinguishable":	{"JJ"},
"undistinguished":	{"JJ"},
"undistorted":	{"JJ"},
"undistributed":	{"JJ"},
"undisturbed":	{"JJ"},
"undiversifiable":	{"JJ"},
"undiversified":	{"JJ"},
"undividable":	{"JJ"},
"undivided":	{"JJ"},
"undo":	{"VB","VBP"},
"undoable":	{"JJ"},
"undock":	{"VB","VBP"},
"undocumented":	{"JJ"},
"undoer":	{"NN"},
"undoes":	{"VBZ"},
"undogmatic":	{"JJ"},
"undogmatical":	{"JJ"},
"undogmatically":	{"RB"},
"undoing":	{"NN","VBG"},
"undomestic":	{"JJ"},
"undomesticated":	{"JJ"},
"undone":	{"JJ","VBN"},
"undoubtedly":	{"RB"},
"undrafted":	{"JJ"},
"undrained":	{"JJ"},
"undramatic":	{"JJ"},
"undramatically":	{"RB"},
"undrape":	{"VB","VBP"},
"undraped":	{"VBD","VBN"},
"undrapes":	{"VBZ"},
"undraping":	{"VBG"},
"undraw":	{"VB","VBP"},
"undrawing":	{"VBG"},
"undrawn":	{"VBN"},
"undraws":	{"VBZ"},
"undreamed":	{"JJ"},
"undreamt":	{"NN"},
"undress":	{"VB","VBP","NN"},
"undressed":	{"JJ","VBD","VBN"},
"undresses":	{"VBZ"},
"undressing":	{"VBG"},
"undrew":	{"VBD"},
"undried":	{"JJ"},
"undrinkable":	{"JJ"},
"undue":	{"JJ"},
"undulant":	{"JJ"},
"undulate":	{"VB","VBP"},
"undulated":	{"VBD","VBN"},
"undulates":	{"VBZ"},
"undulating":	{"JJ","VBG"},
"undulation":	{"NN"},
"undulations":	{"NNS"},
"undulatory":	{"JJ"},
"unduly":	{"RB"},
"undutiful":	{"JJ"},
"undutifulness":	{"NN"},
"undyed":	{"JJ"},
"undying":	{"JJ"},
"undynamic":	{"JJ"},
"uneager":	{"JJ"},
"unearned":	{"JJ"},
"unearth":	{"VB","VBP"},
"unearthed":	{"VBD","VBN"},
"unearthing":	{"VBG"},
"unearthliness":	{"NN"},
"unearthly":	{"JJ"},
"unearths":	{"VBZ"},
"unease":	{"NN"},
"uneasier":	{"JJR"},
"uneasiest":	{"JJS"},
"uneasily":	{"RB"},
"uneasiness":	{"NN"},
"uneasy":	{"JJ"},
"uneatable":	{"JJ"},
"uneconomic":	{"JJ"},
"uneconomical":	{"JJ"},
"unedifying":	{"JJ"},
"unedited":	{"JJ"},
"uneducated":	{"JJ","NNS"},
"uneffective":	{"JJ"},
"unelaborate":	{"JJ"},
"unelaborated":	{"JJ"},
"unelected":	{"JJ"},
"unembarrassed":	{"JJ"},
"unembellished":	{"JJ"},
"unembodied":	{"JJ"},
"unemotional":	{"JJ"},
"unemotionality":	{"NN"},
"unemotionally":	{"RB"},
"unemphatic":	{"JJ"},
"unemployable":	{"JJ"},
"unemployed":	{"JJ","NNS"},
"unemployment":	{"NN"},
"unenclosed":	{"JJ"},
"unencouraging":	{"JJ"},
"unencumbered":	{"JJ"},
"unended":	{"JJ"},
"unending":	{"JJ"},
"unendingly":	{"RB"},
"unendowed":	{"JJ"},
"unendurable":	{"JJ"},
"unenergetic":	{"JJ"},
"unenergetically":	{"RB"},
"unenforceable":	{"JJ"},
"unenforced":	{"JJ"},
"unenforcible":	{"JJ"},
"unengaged":	{"JJ"},
"unenlightened":	{"JJ"},
"unenlightening":	{"JJ"},
"unenlightenment":	{"NN"},
"unenlivened":	{"JJ"},
"unenrgetic":	{"JJ"},
"unenterprising":	{"JJ"},
"unenthusiastic":	{"JJ"},
"unenthusiastically":	{"RB"},
"unenticing":	{"JJ"},
"unentitled":	{"JJ"},
"unenunciated":	{"JJ"},
"unenviable":	{"JJ"},
"unenvied":	{"JJ"},
"unequal":	{"JJ"},
"unequaled":	{"JJ"},
"unequalised":	{"JJ"},
"unequalized":	{"JJ"},
"unequalled":	{"JJ"},
"unequally":	{"RB"},
"unequipped":	{"JJ"},
"unequivocal":	{"JJ"},
"unequivocally":	{"RB"},
"unequivocalness":	{"NN"},
"unerasable":	{"JJ"},
"unerect":	{"JJ"},
"unerring":	{"JJ"},
"unerringly":	{"RB"},
"unescorted":	{"JJ"},
"unessential":	{"JJ"},
"unestablished":	{"JJ"},
"unethical":	{"JJ"},
"unethically":	{"RB"},
"uneven":	{"JJ"},
"unevenly":	{"RB"},
"unevenness":	{"NN"},
"uneventful":	{"JJ"},
"uneventfully":	{"RB"},
"uneventfulness":	{"NN"},
"unexacting":	{"JJ"},
"unexamined":	{"JJ"},
"unexampled":	{"JJ"},
"unexceeded":	{"JJ"},
"unexcelled":	{"JJ"},
"unexceptionable":	{"JJ"},
"unexceptional":	{"JJ"},
"unexchangeability":	{"NN"},
"unexchangeable":	{"JJ"},
"unexcitable":	{"JJ"},
"unexcited":	{"JJ"},
"unexciting":	{"JJ"},
"unexcitingly":	{"RB"},
"unexclusive":	{"JJ"},
"unexcused":	{"JJ"},
"unexecuted":	{"JJ"},
"unexercised":	{"JJ"},
"unexhausted":	{"JJ"},
"unexpansive":	{"JJ"},
"unexpectable":	{"JJ"},
"unexpected":	{"JJ"},
"unexpectedly":	{"RB"},
"unexpectedness":	{"NN"},
"unexpendable":	{"JJ"},
"unexpended":	{"JJ"},
"unexpired":	{"JJ"},
"unexplainable":	{"JJ"},
"unexplained":	{"JJ"},
"unexploded":	{"JJ"},
"unexploited":	{"JJ"},
"unexplorative":	{"JJ"},
"unexploratory":	{"JJ"},
"unexplored":	{"JJ"},
"unexportable":	{"JJ"},
"unexpressed":	{"JJ"},
"unexpressible":	{"JJ"},
"unexpressive":	{"JJ"},
"unexpurgated":	{"JJ"},
"unextended":	{"JJ"},
"unfaceted":	{"JJ"},
"unfading":	{"JJ"},
"unfailing":	{"JJ"},
"unfailingly":	{"RB"},
"unfair":	{"JJ"},
"unfairly":	{"RB"},
"unfairness":	{"NN"},
"unfaithful":	{"JJ"},
"unfaithfully":	{"RB"},
"unfaithfulness":	{"NN"},
"unfaltering":	{"JJ"},
"unfalteringly":	{"RB"},
"unfamiliar":	{"JJ"},
"unfamiliarity":	{"NN"},
"unfashionable":	{"JJ"},
"unfashionably":	{"RB"},
"unfasten":	{"VB","VBP"},
"unfastened":	{"VBD","VBN"},
"unfastener":	{"NN"},
"unfastening":	{"VBG"},
"unfastens":	{"VBZ"},
"unfastidious":	{"JJ"},
"unfathomable":	{"JJ"},
"unfathomed":	{"JJ"},
"unfattened":	{"JJ"},
"unfavorable":	{"JJ"},
"unfavorableness":	{"NN"},
"unfavorably":	{"RB"},
"unfavourable":	{"JJ"},
"unfavourableness":	{"NN"},
"unfavourably":	{"RB"},
"unfazed":	{"JJ"},
"unfearing":	{"JJ"},
"unfeasibility":	{"NN"},
"unfeasible":	{"JJ"},
"unfeathered":	{"JJ"},
"unfed":	{"JJ"},
"unfeeling":	{"JJ"},
"unfeelingly":	{"RB"},
"unfeelingness":	{"NN"},
"unfeigned":	{"JJ"},
"unfeignedly":	{"RB"},
"unfelt":	{"JJ"},
"unfeminine":	{"JJ"},
"unfenced":	{"JJ"},
"unfermented":	{"JJ"},
"unfertile":	{"JJ"},
"unfertilised":	{"JJ"},
"unfertilized":	{"JJ"},
"unfetter":	{"VB","VBP"},
"unfettered":	{"JJ","VBD","VBN"},
"unfetters":	{"VBZ"},
"unfilled":	{"JJ"},
"unfilmed":	{"JJ"},
"unfinished":	{"JJ"},
"unfired":	{"JJ"},
"unfirm":	{"JJ"},
"unfit":	{"JJ","VB","VBP"},
"unfitly":	{"RB"},
"unfitness":	{"NN"},
"unfits":	{"VBZ"},
"unfitted":	{"VBD","VBN","JJ"},
"unfittedness":	{"NN"},
"unfitting":	{"JJ","VBG"},
"unfittingly":	{"RB"},
"unfix":	{"VB","VBP"},
"unfixed":	{"VBD","VBN","JJ"},
"unflagging":	{"JJ"},
"unflaggingly":	{"RB"},
"unflaky":	{"JJ"},
"unflappability":	{"NN"},
"unflappable":	{"JJ"},
"unflattering":	{"JJ"},
"unflatteringly":	{"RB"},
"unflavored":	{"JJ"},
"unflavoured":	{"JJ"},
"unflawed":	{"JJ"},
"unfledged":	{"JJ"},
"unflesh":	{"VB","VBP"},
"unfleshed":	{"VBD","VBN","JJ"},
"unflinching":	{"JJ"},
"unflinchingly":	{"RB"},
"unfluctuating":	{"JJ"},
"unfluoridated":	{"JJ"},
"unflurried":	{"JJ"},
"unflush":	{"VB","VBP"},
"unflushed":	{"JJ","VBD","VBN"},
"unflustered":	{"JJ"},
"unfocused":	{"JJ"},
"unfocussed":	{"JJ"},
"unfold":	{"VB","VBP"},
"unfolded":	{"VBD","VBN"},
"unfolding":	{"VBG"},
"unfoldment":	{"NN"},
"unfolds":	{"VBZ"},
"unforbearing":	{"JJ"},
"unforced":	{"JJ"},
"unforceful":	{"JJ"},
"unforeseeable":	{"JJ"},
"unforeseen":	{"JJ"},
"unforesightful":	{"JJ"},
"unforested":	{"JJ"},
"unforethoughtful":	{"JJ"},
"unforfeitable":	{"JJ"},
"unforgettable":	{"JJ"},
"unforgettably":	{"RB"},
"unforgivable":	{"JJ"},
"unforgivably":	{"RB"},
"unforgiving":	{"JJ"},
"unforgivingly":	{"RB"},
"unformed":	{"JJ"},
"unfortunate":	{"JJ","NN"},
"unfortunately":	{"RB"},
"unfortunates":	{"NNS"},
"unfounded":	{"JJ"},
"unframed":	{"JJ"},
"unfree":	{"JJ"},
"unfreeze":	{"VB","VBP"},
"unfreezes":	{"VBZ"},
"unfreezing":	{"VBG"},
"unfrequented":	{"JJ"},
"unfretted":	{"JJ"},
"unfriendlier":	{"JJR"},
"unfriendliest":	{"JJS"},
"unfriendliness":	{"NN"},
"unfriendly":	{"JJ"},
"unfrightened":	{"JJ"},
"unfrock":	{"VB","VBP"},
"unfrocked":	{"VBD","VBN"},
"unfrocking":	{"VBG"},
"unfrocks":	{"VBZ"},
"unfrosted":	{"JJ"},
"unfroze":	{"VBD"},
"unfrozen":	{"VBN"},
"unfruitful":	{"JJ"},
"unfueled":	{"JJ"},
"unfulfilled":	{"JJ"},
"unfunctional":	{"JJ"},
"unfunded":	{"JJ"},
"unfunnily":	{"RB"},
"unfunny":	{"JJ"},
"unfurl":	{"VB","VBP"},
"unfurled":	{"VBD","VBN"},
"unfurling":	{"VBG"},
"unfurls":	{"VBZ"},
"unfurnished":	{"JJ"},
"unfurrowed":	{"JJ"},
"ungainliness":	{"NN"},
"ungainly":	{"JJ"},
"ungallant":	{"JJ"},
"ungarbed":	{"JJ"},
"ungarmented":	{"JJ"},
"ungathered":	{"JJ"},
"ungeared":	{"JJ"},
"ungenerous":	{"JJ"},
"ungentle":	{"JJ"},
"ungentlemanlike":	{"JJ"},
"ungentlemanly":	{"JJ"},
"ungetatable":	{"JJ"},
"unglamorous":	{"JJ"},
"unglazed":	{"JJ"},
"unglued":	{"JJ"},
"ungodliness":	{"NN"},
"ungodly":	{"JJ"},
"ungovernable":	{"JJ"},
"ungoverned":	{"JJ"},
"ungraceful":	{"JJ"},
"ungracefully":	{"RB"},
"ungracefulness":	{"NN"},
"ungracious":	{"JJ"},
"ungraciously":	{"RB"},
"ungraciousness":	{"NN"},
"ungraded":	{"JJ"},
"ungrammatical":	{"JJ"},
"ungrammatically":	{"RB"},
"ungrasped":	{"JJ"},
"ungrateful":	{"JJ"},
"ungratefully":	{"RB"},
"ungratefulness":	{"NN"},
"ungratified":	{"JJ"},
"ungreased":	{"JJ"},
"ungregarious":	{"JJ"},
"ungroomed":	{"JJ"},
"ungrudging":	{"JJ"},
"ungrudgingly":	{"RB"},
"ungual":	{"JJ"},
"unguaranteed":	{"JJ"},
"unguarded":	{"JJ"},
"unguent":	{"NN"},
"ungues":	{"NNS"},
"unguiculata":	{"NN"},
"unguiculate":	{"JJ","NN"},
"unguiculated":	{"JJ"},
"unguided":	{"JJ"},
"unguis":	{"NN"},
"ungulata":	{"NN"},
"ungulate":	{"NN"},
"ungulated":	{"JJ"},
"ungummed":	{"JJ"},
"ungusseted":	{"JJ"},
"unhallow":	{"VB","VBP"},
"unhallowed":	{"JJ"},
"unhampered":	{"JJ"},
"unhand":	{"VB","VBP"},
"unhappier":	{"JJR"},
"unhappiest":	{"JJS"},
"unhappily":	{"RB"},
"unhappiness":	{"NN"},
"unhappy":	{"JJ"},
"unhardened":	{"JJ"},
"unharmed":	{"JJ"},
"unharmonious":	{"JJ"},
"unharmoniously":	{"RB"},
"unharness":	{"VB","VBP"},
"unhatched":	{"JJ"},
"unhazardous":	{"JJ"},
"unheaded":	{"JJ"},
"unhealed":	{"JJ"},
"unhealth":	{"NN"},
"unhealthful":	{"JJ"},
"unhealthfulness":	{"NN"},
"unhealthier":	{"JJR"},
"unhealthiest":	{"JJS"},
"unhealthily":	{"RB"},
"unhealthiness":	{"NN"},
"unhealthy":	{"JJ"},
"unhearable":	{"JJ"},
"unheard":	{"JJ"},
"unheard-of":	{"JJ"},
"unhearing":	{"JJ"},
"unheated":	{"JJ"},
"unhedged":	{"JJ"},
"unheeded":	{"JJ"},
"unheeding":	{"JJ"},
"unhelpful":	{"JJ"},
"unhelpfully":	{"RB"},
"unhelpfulness":	{"NN"},
"unheralded":	{"JJ"},
"unheroic":	{"JJ"},
"unhesitant":	{"JJ"},
"unhesitating":	{"JJ"},
"unhesitatingly":	{"RB"},
"unhewn":	{"JJ"},
"unhindered":	{"JJ"},
"unhinge":	{"VB","VBP"},
"unhinged":	{"VBD","VBN","JJ"},
"unhinges":	{"VBZ"},
"unhinging":	{"VBG"},
"unhip":	{"JJ"},
"unhitch":	{"VB","VBP"},
"unhitched":	{"VBD","VBN"},
"unhitches":	{"VBZ"},
"unhitching":	{"VBG"},
"unholier":	{"JJR"},
"unholiest":	{"JJS"},
"unholiness":	{"NN"},
"unholy":	{"JJ"},
"unhomogenised":	{"JJ"},
"unhomogenized":	{"JJ"},
"unhook":	{"VB","VBP"},
"unhooked":	{"VBD","VBN"},
"unhooking":	{"VBG"},
"unhooks":	{"VBZ"},
"unhoped":	{"JJ"},
"unhoped-for":	{"JJ"},
"unhopeful":	{"JJ"},
"unhorse":	{"VB","VBP"},
"unhorsed":	{"VBD","VBN"},
"unhorses":	{"VBZ"},
"unhorsing":	{"VBG"},
"unhuman":	{"JJ"},
"unhumanly":	{"RB"},
"unhumorous":	{"JJ"},
"unhurried":	{"JJ"},
"unhurriedly":	{"RB"},
"unhurriedness":	{"NN"},
"unhurt":	{"JJ"},
"unhusk":	{"VB","VBP"},
"unhusked":	{"VBD","VBN","JJ"},
"unhusking":	{"VBG"},
"unhusks":	{"VBZ"},
"unhygienic":	{"JJ"},
"unhygienically":	{"RB"},
"unicameral":	{"JJ"},
"unicellular":	{"JJ"},
"unicorn":	{"NN"},
"unicorns":	{"NNS"},
"unicuspid":	{"JJ"},
"unicycle":	{"NN"},
"unicyclist":	{"NN"},
"unidentifiable":	{"JJ"},
"unidentified":	{"JJ"},
"unidimensional":	{"JJ"},
"unidirectional":	{"JJ"},
"unifacial":	{"JJ"},
"unification":	{"NN"},
"unificationist":	{"NN"},
"unificationists":	{"NNS"},
"unifications":	{"NNS"},
"unified":	{"JJ","VBD","VBN"},
"unifier":	{"NN"},
"unifies":	{"VBZ"},
"unifilar":	{"JJ"},
"unifoliate":	{"JJ"},
"uniform":	{"NN","JJ","VB","VBP"},
"uniformed":	{"VBD","VBN","JJ"},
"uniforming":	{"VBG"},
"uniformity":	{"NN"},
"uniformize":	{"VB","VBP"},
"uniformly":	{"RB"},
"uniformness":	{"NN"},
"uniforms":	{"NNS","VBZ"},
"unify":	{"VB","VBP"},
"unifying":	{"VBG","JJ"},
"unilateral":	{"JJ"},
"unilateralism":	{"NN"},
"unilateralist":	{"JJ","NN"},
"unilateralists":	{"NNS"},
"unilaterally":	{"RB"},
"unilluminated":	{"JJ"},
"unilluminating":	{"JJ"},
"unimaginable":	{"JJ"},
"unimaginably":	{"RB"},
"unimaginative":	{"JJ"},
"unimaginatively":	{"RB"},
"unimagined":	{"JJ"},
"unimodal":	{"JJ"},
"unimpaired":	{"JJ"},
"unimpassioned":	{"JJ"},
"unimpeachable":	{"JJ"},
"unimpeachably":	{"RB"},
"unimpeded":	{"JJ"},
"unimportance":	{"NN"},
"unimportant":	{"JJ"},
"unimposing":	{"JJ"},
"unimpregnated":	{"JJ"},
"unimpressed":	{"JJ"},
"unimpressionable":	{"JJ"},
"unimpressive":	{"JJ"},
"unimpressively":	{"RB"},
"unimprisoned":	{"JJ"},
"unimproved":	{"JJ"},
"unincorporated":	{"JJ"},
"unincumbered":	{"JJ"},
"unindicted":	{"JJ"},
"unindustrialised":	{"JJ"},
"unindustrialized":	{"JJ"},
"uninebriated":	{"JJ"},
"uninfected":	{"JJ"},
"uninflected":	{"JJ"},
"uninfluenced":	{"JJ"},
"uninfluential":	{"JJ"},
"uninformative":	{"JJ"},
"uninformatively":	{"RB"},
"uninformed":	{"JJ"},
"uninhabitable":	{"JJ"},
"uninhabited":	{"JJ"},
"uninhibited":	{"JJ"},
"uninhibitedly":	{"RB"},
"uninitiate":	{"JJ"},
"uninitiated":	{"JJ","NNS"},
"uninjectable":	{"JJ"},
"uninjured":	{"JJ"},
"uninominal":	{"JJ"},
"uninquiring":	{"JJ"},
"uninquisitive":	{"JJ"},
"uninspected":	{"JJ"},
"uninspired":	{"JJ"},
"uninspiring":	{"JJ"},
"uninstructed":	{"JJ"},
"uninstructive":	{"JJ"},
"uninstructively":	{"RB"},
"uninsurability":	{"NN"},
"uninsurable":	{"JJ"},
"uninsurance":	{"NN"},
"uninsured":	{"JJ"},
"unintegrated":	{"JJ"},
"unintelligent":	{"JJ"},
"unintelligently":	{"RB"},
"unintelligibility":	{"NN"},
"unintelligible":	{"JJ"},
"unintelligibly":	{"RB"},
"unintended":	{"JJ"},
"unintentional":	{"JJ"},
"unintentionally":	{"RB"},
"uninterested":	{"JJ"},
"uninteresting":	{"JJ"},
"uninterestingly":	{"RB"},
"uninterestingness":	{"NN"},
"uninterruptable":	{"JJ"},
"uninterrupted":	{"JJ"},
"uninterruptedly":	{"RB"},
"uninterruptible":	{"JJ"},
"unintimidated":	{"JJ"},
"unintoxicated":	{"JJ"},
"unintrusive":	{"JJ"},
"uninucleate":	{"JJ"},
"uninventive":	{"JJ"},
"uninvited":	{"JJ"},
"uninvitedly":	{"RB"},
"uninviting":	{"JJ"},
"uninvolved":	{"JJ"},
"unio":	{"NN"},
"unioid":	{"JJ"},
"union":	{"NN"},
"unionidae":	{"NN"},
"unionisation":	{"NN"},
"unionise":	{"VB","VBP"},
"unionised":	{"JJ","VBD","VBN"},
"unionises":	{"VBZ"},
"unionising":	{"VBG"},
"unionism":	{"NN"},
"unionist":	{"NN"},
"unionists":	{"NNS"},
"unionization":	{"NN"},
"unionize":	{"VB","VBP"},
"unionized":	{"JJ","VBD","VBN"},
"unionizes":	{"VBZ"},
"unionizing":	{"VBG"},
"unions":	{"NNS"},
"unios":	{"NNS"},
"uniovular":	{"JJ"},
"uniovulate":	{"JJ"},
"uniparous":	{"JJ"},
"unipolar":	{"JJ"},
"unique":	{"JJ"},
"uniquely":	{"RB"},
"uniqueness":	{"NN"},
"uniramous":	{"JJ"},
"unironed":	{"JJ"},
"unisex":	{"JJ"},
"unisexual":	{"JJ"},
"unison":	{"NN"},
"unissued":	{"JJ"},
"unit":	{"NN"},
"unitard":	{"NN"},
"unitary":	{"JJ"},
"unite":	{"VB","VBP"},
"united":	{"VBN","VBD","JJ"},
"unitedly":	{"RB"},
"unites":	{"VBZ"},
"unitholder":	{"NN"},
"unitholders":	{"NNS"},
"unities":	{"NNS"},
"uniting":	{"NN","VBG"},
"unitisation":	{"NN"},
"unitise":	{"VB","VBP"},
"unitised":	{"VBD","VBN"},
"unitises":	{"VBZ"},
"unitising":	{"VBG"},
"unitization":	{"NN"},
"unitize":	{"VB","VBP"},
"unitized":	{"VBD","VBN"},
"unitizes":	{"VBZ"},
"unitizing":	{"VBG"},
"units":	{"NNS"},
"unity":	{"NN"},
"univalent":	{"JJ"},
"univalve":	{"NN"},
"universal":	{"JJ","NN"},
"universalisation":	{"NN"},
"universalise":	{"VB","VBP"},
"universalised":	{"VBD","VBN"},
"universalises":	{"VBZ"},
"universalising":	{"VBG"},
"universalism":	{"NN"},
"universalist":	{"NN"},
"universalistic":	{"JJ"},
"universality":	{"NN"},
"universalization":	{"NN"},
"universalize":	{"VB","VBP"},
"universalized":	{"VBD","VBN"},
"universalizes":	{"VBZ"},
"universalizing":	{"VBG"},
"universally":	{"RB"},
"universals":	{"NNS"},
"universe":	{"NN"},
"universes":	{"NNS"},
"universities":	{"NNS"},
"university":	{"NN"},
"univocal":	{"JJ","NN"},
"univocally":	{"RB"},
"unjacketed":	{"JJ"},
"unjointed":	{"JJ"},
"unjust":	{"JJ"},
"unjustifiable":	{"JJ"},
"unjustifiably":	{"RB"},
"unjustified":	{"JJ"},
"unjustly":	{"RB"},
"unjustness":	{"NN"},
"unkempt":	{"JJ"},
"unkemptness":	{"NN"},
"unkept":	{"JJ"},
"unkind":	{"JJ"},
"unkinder":	{"JJR"},
"unkindest":	{"JJS"},
"unkindled":	{"JJ"},
"unkindly":	{"RB"},
"unkindness":	{"NN"},
"unknot":	{"VB","VBP"},
"unknots":	{"VBZ"},
"unknotted":	{"VBD","VBN"},
"unknotting":	{"VBG"},
"unknowable":	{"JJ"},
"unknowing":	{"JJ"},
"unknowingly":	{"RB"},
"unknowingness":	{"NN"},
"unknowledgeable":	{"JJ"},
"unknown":	{"JJ","NN"},
"unknowns":	{"NNS"},
"unlabeled":	{"JJ"},
"unlabelled":	{"JJ"},
"unlace":	{"VB","VBP"},
"unlaced":	{"VBD","VBN","JJ"},
"unlaces":	{"NNS"},
"unlacing":	{"VBG"},
"unlade":	{"VB","VBP"},
"unladed":	{"VBD","VBN"},
"unladen":	{"VBN"},
"unlades":	{"VBZ"},
"unlading":	{"VBG"},
"unladylike":	{"JJ"},
"unlamented":	{"JJ"},
"unlash":	{"VB","VBP"},
"unlashed":	{"VBD","VBN"},
"unlatch":	{"VB","VBP"},
"unlatched":	{"VBD","VBN"},
"unlatches":	{"VBZ"},
"unlatching":	{"VBG"},
"unlaundered":	{"JJ"},
"unlaureled":	{"JJ"},
"unlaurelled":	{"JJ"},
"unlawful":	{"JJ"},
"unlawfully":	{"RB"},
"unlawfulness":	{"NN"},
"unlax":	{"VB","VBP"},
"unlaxed":	{"VBD","VBN"},
"unlaxes":	{"VBZ"},
"unlaxing":	{"VBG"},
"unleaded":	{"JJ","NN"},
"unlearn":	{"VB","VBP"},
"unlearned":	{"JJ","VBD","VBN"},
"unlearning":	{"VBG"},
"unlearns":	{"VBZ"},
"unleash":	{"VB","VBP"},
"unleashed":	{"VBD","VBN"},
"unleashes":	{"VBZ"},
"unleashing":	{"VBG"},
"unleavened":	{"JJ"},
"unless":	{"IN"},
"unlettered":	{"JJ"},
"unleveled":	{"JJ"},
"unlicenced":	{"JJ"},
"unlicensed":	{"JJ"},
"unlifelike":	{"JJ"},
"unlighted":	{"JJ"},
"unlikable":	{"JJ"},
"unlike":	{"IN","JJ"},
"unlikeable":	{"JJ"},
"unlikelier":	{"JJR"},
"unlikeliest":	{"JJS"},
"unlikelihood":	{"NN"},
"unlikeliness":	{"NN"},
"unlikely":	{"JJ"},
"unlikeness":	{"NN"},
"unlimited":	{"JJ"},
"unlined":	{"JJ"},
"unlink":	{"VB","VBP"},
"unlinked":	{"VBD","VBN","JJ"},
"unlipped":	{"JJ"},
"unlisted":	{"JJ"},
"unlit":	{"JJ"},
"unliterary":	{"JJ"},
"unlittered":	{"JJ"},
"unlivable":	{"JJ"},
"unlive":	{"VB","VBP"},
"unliveable":	{"JJ"},
"unlived":	{"VBD","VBN"},
"unliveried":	{"JJ"},
"unlives":	{"VBZ"},
"unliving":	{"VBG"},
"unload":	{"VB","VBP"},
"unloaded":	{"JJ","VBD","VBN"},
"unloading":	{"NN","VBG"},
"unloads":	{"VBZ"},
"unlobed":	{"JJ"},
"unlocated":	{"JJ"},
"unlock":	{"VB","VBP"},
"unlockable":	{"JJ"},
"unlocked":	{"VBD","VBN"},
"unlocking":	{"VBG"},
"unlocks":	{"VBZ"},
"unlogical":	{"JJ"},
"unlooked-for":	{"JJ"},
"unloose":	{"VB","VBP"},
"unloosen":	{"VB","VBP"},
"unlovable":	{"JJ"},
"unloved":	{"JJ"},
"unlovely":	{"JJ"},
"unloving":	{"JJ"},
"unlubricated":	{"JJ"},
"unluckier":	{"JJR"},
"unluckiest":	{"JJS"},
"unluckily":	{"RB"},
"unlucky":	{"JJ"},
"unmade":	{"VBD","VBN","JJ"},
"unmagnetic":	{"JJ"},
"unmagnified":	{"JJ"},
"unmake":	{"VB","VBP"},
"unmakes":	{"VBZ"},
"unmaking":	{"VBG"},
"unmalicious":	{"JJ"},
"unmalleability":	{"NN"},
"unmalleable":	{"JJ"},
"unmalted":	{"JJ"},
"unman":	{"VB","VBP"},
"unmanageable":	{"JJ"},
"unmanageableness":	{"NN"},
"unmanageably":	{"RB"},
"unmanaged":	{"JJ"},
"unmanful":	{"JJ"},
"unmanfully":	{"RB"},
"unmanlike":	{"JJ"},
"unmanliness":	{"NN"},
"unmanly":	{"JJ"},
"unmanned":	{"VBD","VBN","JJ"},
"unmannered":	{"JJ"},
"unmannerly":	{"JJ","RB"},
"unmapped":	{"JJ"},
"unmarked":	{"JJ"},
"unmarketable":	{"JJ"},
"unmarred":	{"JJ"},
"unmarried":	{"JJ"},
"unmasculine":	{"JJ"},
"unmask":	{"VB","VBP"},
"unmasked":	{"VBD","VBN"},
"unmasking":	{"VBG"},
"unmasks":	{"VBZ"},
"unmatchable":	{"JJ"},
"unmatched":	{"JJ"},
"unmated":	{"JJ"},
"unmaterialized":	{"JJ"},
"unmeasurable":	{"JJ"},
"unmeasured":	{"JJ"},
"unmechanical":	{"JJ"},
"unmechanised":	{"JJ"},
"unmechanized":	{"JJ"},
"unmediated":	{"JJ"},
"unmedical":	{"JJ"},
"unmedicative":	{"JJ"},
"unmedicinal":	{"JJ"},
"unmelodic":	{"JJ"},
"unmelodious":	{"JJ"},
"unmelodiously":	{"RB"},
"unmelted":	{"JJ"},
"unmemorable":	{"JJ"},
"unmemorably":	{"RB"},
"unmentionable":	{"JJ"},
"unmentionables":	{"NNS"},
"unmentioned":	{"JJ"},
"unmercenary":	{"JJ"},
"unmerchantable":	{"JJ"},
"unmerciful":	{"JJ"},
"unmercifully":	{"RB"},
"unmercifulness":	{"NN"},
"unmerited":	{"JJ"},
"unmeritorious":	{"JJ"},
"unmeshed":	{"JJ"},
"unmet":	{"JJ"},
"unmethodical":	{"JJ"},
"unmilitary":	{"JJ"},
"unmindful":	{"JJ"},
"unmindfully":	{"RB"},
"unmindfulness":	{"NN"},
"unmined":	{"JJ"},
"unmingled":	{"JJ"},
"unmistakable":	{"JJ"},
"unmistakably":	{"RB"},
"unmitigable":	{"JJ"},
"unmitigated":	{"JJ"},
"unmixable":	{"JJ"},
"unmixed":	{"JJ"},
"unmoderated":	{"JJ"},
"unmodernised":	{"JJ"},
"unmodernized":	{"JJ"},
"unmodifiable":	{"JJ"},
"unmodified":	{"JJ"},
"unmodulated":	{"JJ"},
"unmolested":	{"JJ"},
"unmortgaged":	{"JJ"},
"unmotivated":	{"JJ"},
"unmotorised":	{"JJ"},
"unmotorized":	{"JJ"},
"unmourned":	{"JJ"},
"unmovable":	{"JJ"},
"unmoved":	{"JJ"},
"unmoving":	{"JJ"},
"unmown":	{"JJ"},
"unmurmuring":	{"JJ"},
"unmusical":	{"JJ"},
"unmusically":	{"RB"},
"unmutilated":	{"JJ"},
"unmuzzle":	{"VB"},
"unmyelinated":	{"JJ"},
"unnameable":	{"JJ"},
"unnamed":	{"JJ"},
"unnatural":	{"JJ"},
"unnaturalised":	{"JJ"},
"unnaturalized":	{"JJ"},
"unnaturally":	{"RB"},
"unnaturalness":	{"NN"},
"unnavigable":	{"JJ"},
"unnecessarily":	{"RB"},
"unnecessary":	{"JJ"},
"unneeded":	{"JJ"},
"unneighborliness":	{"NN"},
"unneighborly":	{"JJ"},
"unneighbourly":	{"JJ"},
"unnerve":	{"VB","VBP"},
"unnerved":	{"VBD","VBN","JJ"},
"unnerves":	{"VBZ"},
"unnerving":	{"JJ","VBG"},
"unneurotic":	{"JJ"},
"unnilquadium":	{"NN"},
"unnotched":	{"JJ"},
"unnoted":	{"JJ"},
"unnoticeable":	{"JJ"},
"unnoticeableness":	{"NN"},
"unnoticeably":	{"RB"},
"unnoticed":	{"JJ","RB"},
"unnourished":	{"JJ"},
"unnumberable":	{"JJ"},
"unnumbered":	{"JJ"},
"unnumerable":	{"JJ"},
"unobjectionable":	{"JJ"},
"unobjective":	{"JJ"},
"unobligated":	{"JJ"},
"unobliging":	{"JJ"},
"unobservable":	{"JJ"},
"unobservant":	{"JJ"},
"unobserved":	{"JJ","RB"},
"unobstructed":	{"JJ"},
"unobtainable":	{"JJ"},
"unobtrusive":	{"JJ"},
"unobtrusively":	{"RB"},
"unobtrusiveness":	{"NN"},
"unobvious":	{"JJ"},
"unoccupied":	{"JJ"},
"unoffending":	{"JJ"},
"unofficial":	{"JJ"},
"unofficially":	{"RB"},
"unoiled":	{"JJ"},
"unopen":	{"JJ"},
"unopened":	{"JJ"},
"unoperatic":	{"JJ"},
"unopposable":	{"JJ"},
"unopposed":	{"JJ"},
"unordered":	{"JJ"},
"unorganised":	{"JJ"},
"unorganized":	{"JJ"},
"unoriented":	{"JJ"},
"unoriginal":	{"JJ"},
"unoriginality":	{"NN"},
"unoriginally":	{"RB"},
"unornamented":	{"JJ"},
"unorthodox":	{"JJ"},
"unorthodoxy":	{"NN"},
"unostentatious":	{"JJ"},
"unowned":	{"JJ"},
"unoxygenated":	{"JJ"},
"unpack":	{"VB","VBP"},
"unpacked":	{"VBD","VBN"},
"unpacking":	{"NN","VBG"},
"unpacks":	{"VBZ"},
"unpadded":	{"JJ"},
"unpaid":	{"JJ"},
"unpainful":	{"JJ"},
"unpaintable":	{"JJ"},
"unpainted":	{"JJ"},
"unpaired":	{"JJ"},
"unpalatability":	{"NN"},
"unpalatable":	{"JJ"},
"unpalatableness":	{"NN"},
"unpalatably":	{"RB"},
"unparallel":	{"JJ"},
"unparalleled":	{"JJ"},
"unpardonable":	{"JJ"},
"unpardonably":	{"RB"},
"unparented":	{"JJ"},
"unparliamentary":	{"JJ"},
"unpartisan":	{"JJ"},
"unpartisanship":	{"NN"},
"unpartitioned":	{"JJ"},
"unpassable":	{"JJ"},
"unpasteurised":	{"JJ"},
"unpasteurized":	{"JJ"},
"unpatented":	{"JJ"},
"unpatriotic":	{"JJ"},
"unpatriotically":	{"RB"},
"unpatronised":	{"JJ"},
"unpatronized":	{"JJ"},
"unpatterned":	{"JJ"},
"unpaved":	{"JJ"},
"unpeace":	{"NN"},
"unpeaceable":	{"JJ"},
"unpeaceful":	{"JJ"},
"unpeg":	{"VB","VBP"},
"unpegged":	{"VBD","VBN"},
"unpegging":	{"VBG"},
"unpegs":	{"VBZ"},
"unpeopled":	{"JJ"},
"unperceivable":	{"JJ"},
"unperceived":	{"JJ"},
"unperceiving":	{"JJ"},
"unperceptive":	{"JJ"},
"unperceptiveness":	{"NN"},
"unperformed":	{"JJ"},
"unpermissive":	{"JJ"},
"unpermissiveness":	{"NN"},
"unpermitted":	{"JJ"},
"unperplexed":	{"JJ"},
"unperson":	{"NN"},
"unpersuadable":	{"JJ"},
"unpersuaded":	{"JJ"},
"unpersuasive":	{"JJ"},
"unpersuasiveness":	{"NN"},
"unperturbed":	{"JJ"},
"unphysical":	{"JJ"},
"unpick":	{"VB","VBP"},
"unpicked":	{"VBD","VBN"},
"unpicking":	{"VBG"},
"unpicks":	{"VBZ"},
"unpicturesque":	{"JJ"},
"unpierced":	{"JJ"},
"unpigmented":	{"JJ"},
"unpillared":	{"JJ"},
"unpin":	{"VB","VBP"},
"unpinned":	{"VBD","VBN"},
"unpinning":	{"VBG"},
"unpins":	{"VBZ"},
"unpitying":	{"JJ"},
"unplaceable":	{"JJ"},
"unplaced":	{"JJ"},
"unplagued":	{"JJ"},
"unplanned":	{"JJ"},
"unplanted":	{"JJ"},
"unplayable":	{"JJ"},
"unplayful":	{"JJ"},
"unpleasable":	{"JJ"},
"unpleasant":	{"JJ"},
"unpleasantly":	{"RB"},
"unpleasantness":	{"NN"},
"unpleased":	{"JJ"},
"unpleasing":	{"JJ"},
"unpleasingness":	{"NN"},
"unpledged":	{"JJ"},
"unploughed":	{"JJ"},
"unplowed":	{"JJ"},
"unplug":	{"VB","VBP"},
"unplugged":	{"VBD","VBN"},
"unplugging":	{"VBG"},
"unplugs":	{"VBZ"},
"unplumbed":	{"JJ"},
"unpointed":	{"JJ"},
"unpointedness":	{"NN"},
"unpolarizing":	{"NN"},
"unpolished":	{"JJ"},
"unpolitical":	{"JJ"},
"unpolluted":	{"JJ"},
"unpopular":	{"JJ"},
"unpopularity":	{"NN"},
"unpopulated":	{"JJ"},
"unportable":	{"JJ"},
"unposed":	{"JJ"},
"unpotted":	{"JJ"},
"unpowered":	{"JJ"},
"unpracticed":	{"JJ"},
"unpractised":	{"JJ"},
"unprecedented":	{"JJ"},
"unprecedentedly":	{"RB"},
"unpredictability":	{"NN"},
"unpredictable":	{"JJ"},
"unpredictably":	{"RB"},
"unpredicted":	{"JJ"},
"unpredictive":	{"JJ"},
"unprejudiced":	{"JJ"},
"unpremeditated":	{"JJ"},
"unprepared":	{"JJ"},
"unprepossessing":	{"JJ"},
"unpresentable":	{"JJ"},
"unpresidential":	{"JJ"},
"unpressed":	{"JJ"},
"unpretending":	{"JJ"},
"unpretentious":	{"JJ"},
"unpretentiously":	{"RB"},
"unpretentiousness":	{"NN"},
"unpreventable":	{"JJ"},
"unpriestly":	{"JJ"},
"unprincipled":	{"JJ"},
"unprintable":	{"JJ"},
"unproblematic":	{"JJ"},
"unprocessed":	{"JJ"},
"unprocurable":	{"JJ"},
"unproductive":	{"JJ"},
"unproductively":	{"RB"},
"unproductiveness":	{"NN"},
"unprofessional":	{"JJ"},
"unprofitability":	{"NN"},
"unprofitable":	{"JJ"},
"unprofitableness":	{"NN"},
"unprofitably":	{"RB"},
"unprogressive":	{"JJ"},
"unpromised":	{"JJ"},
"unpromising":	{"JJ"},
"unprompted":	{"JJ"},
"unpronounceable":	{"JJ"},
"unprophetic":	{"JJ"},
"unpropitious":	{"JJ"},
"unpropitiously":	{"RB"},
"unpropitiousness":	{"NN"},
"unprotected":	{"JJ"},
"unprotectedness":	{"NN"},
"unprotective":	{"JJ"},
"unprovable":	{"JJ"},
"unproved":	{"JJ"},
"unproven":	{"JJ"},
"unprovocative":	{"JJ"},
"unprovoked":	{"JJ"},
"unprovoking":	{"JJ"},
"unpublicized":	{"JJ"},
"unpublishable":	{"JJ"},
"unpublished":	{"JJ"},
"unpunctual":	{"JJ"},
"unpunctured":	{"JJ"},
"unpunished":	{"JJ"},
"unpurified":	{"JJ"},
"unqualified":	{"JJ"},
"unqualifiedly":	{"RB"},
"unquenchable":	{"JJ"},
"unquenched":	{"JJ"},
"unquestionability":	{"NN"},
"unquestionable":	{"JJ"},
"unquestionableness":	{"NN"},
"unquestionably":	{"RB"},
"unquestioned":	{"JJ"},
"unquestioning":	{"JJ"},
"unquestioningly":	{"RB"},
"unquiet":	{"JJ"},
"unquietly":	{"RB"},
"unquotable":	{"JJ"},
"unraised":	{"JJ"},
"unranked":	{"JJ"},
"unratable":	{"JJ"},
"unratified":	{"JJ"},
"unravel":	{"VB","VBP"},
"unraveled":	{"VBD","VBN"},
"unraveler":	{"NN"},
"unraveling":	{"VBG"},
"unravelled":	{"VBD","VBN"},
"unraveller":	{"NN"},
"unravelling":	{"VBG"},
"unravels":	{"VBZ"},
"unreachable":	{"JJ"},
"unreached":	{"JJ"},
"unreactive":	{"JJ"},
"unread":	{"JJ"},
"unreadable":	{"JJ"},
"unreadably":	{"RB"},
"unready":	{"JJ"},
"unreal":	{"JJ"},
"unrealised":	{"JJ"},
"unrealism":	{"NN"},
"unrealistic":	{"JJ"},
"unrealistically":	{"RB"},
"unreality":	{"NN"},
"unrealizable":	{"JJ"},
"unrealized":	{"JJ"},
"unreason":	{"NN"},
"unreasonable":	{"JJ"},
"unreasonably":	{"RB"},
"unreasoning":	{"JJ"},
"unreasoningly":	{"RB"},
"unreassuring":	{"JJ"},
"unreassuringly":	{"RB"},
"unreceptive":	{"JJ"},
"unreciprocated":	{"JJ"},
"unrecognisable":	{"JJ"},
"unrecognised":	{"JJ"},
"unrecognizable":	{"JJ"},
"unrecognizably":	{"RB"},
"unrecognized":	{"JJ"},
"unreconcilable":	{"JJ"},
"unreconciled":	{"JJ"},
"unreconstructed":	{"JJ"},
"unrecorded":	{"JJ"},
"unrecoverable":	{"JJ"},
"unredacted":	{"JJ"},
"unredeemable":	{"JJ"},
"unredeemed":	{"JJ"},
"unreduced":	{"JJ"},
"unreel":	{"VB","VBP"},
"unreeled":	{"VBD","VBN"},
"unreeling":	{"VBG"},
"unreels":	{"VBZ"},
"unrefined":	{"JJ"},
"unreflected":	{"JJ"},
"unreflective":	{"JJ"},
"unreformable":	{"JJ"},
"unreformed":	{"JJ"},
"unrefreshed":	{"JJ"},
"unrefrigerated":	{"JJ"},
"unregeneracy":	{"NN"},
"unregenerate":	{"JJ","NN"},
"unregenerated":	{"JJ"},
"unregenerately":	{"RB"},
"unregisterd":	{"JJ"},
"unregistered":	{"JJ"},
"unregretful":	{"JJ"},
"unregretting":	{"JJ"},
"unregularity":	{"NN"},
"unregulated":	{"JJ"},
"unrehearsed":	{"JJ"},
"unreinforced":	{"JJ"},
"unrelatable":	{"JJ"},
"unrelated":	{"JJ"},
"unrelatedness":	{"NN"},
"unrelaxed":	{"JJ"},
"unreleasable":	{"JJ"},
"unreleased":	{"JJ"},
"unrelenting":	{"JJ"},
"unrelentingly":	{"RB"},
"unreliability":	{"NN"},
"unreliable":	{"JJ"},
"unreliableness":	{"NN"},
"unreliably":	{"RB"},
"unrelieved":	{"JJ"},
"unremarkable":	{"JJ"},
"unremarkably":	{"RB"},
"unremarked":	{"JJ"},
"unremedied":	{"JJ"},
"unremitting":	{"JJ"},
"unremittingly":	{"RB"},
"unremorseful":	{"JJ"},
"unremunerative":	{"JJ"},
"unrenewable":	{"JJ"},
"unrenewed":	{"JJ"},
"unrentable":	{"JJ"},
"unrepaired":	{"JJ"},
"unrepeatable":	{"JJ"},
"unrepentant":	{"JJ"},
"unrepentantly":	{"RB"},
"unreplaceable":	{"JJ"},
"unreportable":	{"JJ"},
"unreported":	{"JJ"},
"unrepresentative":	{"JJ"},
"unrepressed":	{"JJ"},
"unreproducible":	{"JJ"},
"unreproducibly":	{"RB"},
"unrequested":	{"JJ"},
"unrequited":	{"JJ"},
"unresectable":	{"JJ"},
"unresentful":	{"JJ"},
"unreserved":	{"JJ"},
"unreservedly":	{"RB"},
"unresistant":	{"JJ"},
"unresisting":	{"JJ"},
"unresolvable":	{"JJ"},
"unresolved":	{"JJ"},
"unrespectability":	{"NN"},
"unrespectable":	{"JJ"},
"unresponsive":	{"JJ"},
"unresponsiveness":	{"NN"},
"unrest":	{"NN"},
"unrested":	{"JJ"},
"unrestrained":	{"JJ"},
"unrestrainedly":	{"RB"},
"unrestraint":	{"NN"},
"unrestricted":	{"JJ"},
"unrestrictedly":	{"RB"},
"unrestrictive":	{"JJ"},
"unretentive":	{"JJ"},
"unretouched":	{"JJ"},
"unretrievable":	{"JJ"},
"unrevealed":	{"JJ"},
"unrevealing":	{"JJ"},
"unreverberant":	{"JJ"},
"unrevised":	{"JJ"},
"unrevived":	{"JJ"},
"unrewarded":	{"JJ"},
"unrewarding":	{"JJ"},
"unrhetorical":	{"JJ"},
"unrhymed":	{"JJ"},
"unrhythmic":	{"JJ"},
"unrhythmical":	{"JJ"},
"unrifled":	{"JJ"},
"unrigged":	{"JJ"},
"unrighteous":	{"JJ"},
"unrighteously":	{"RB"},
"unrighteousness":	{"NN"},
"unrimed":	{"JJ"},
"unripe":	{"JJ"},
"unripened":	{"JJ"},
"unrivaled":	{"JJ"},
"unrivalled":	{"JJ"},
"unroll":	{"VB","VBP"},
"unrolled":	{"VBD","VBN"},
"unrolling":	{"VBG"},
"unrolls":	{"VBZ"},
"unromantic":	{"JJ"},
"unromantically":	{"RB"},
"unroofed":	{"JJ"},
"unrouged":	{"JJ"},
"unruffled":	{"JJ"},
"unruliness":	{"NN"},
"unruly":	{"JJ"},
"unsaddle":	{"VB","VBP"},
"unsaddled":	{"VBD","VBN"},
"unsaddles":	{"VBZ"},
"unsaddling":	{"VBG"},
"unsafe":	{"JJ"},
"unsaid":	{"JJ","RB","VBD","VBN"},
"unsalable":	{"JJ"},
"unsalaried":	{"JJ"},
"unsaleable":	{"JJ"},
"unsalted":	{"JJ"},
"unsanctification":	{"NN"},
"unsanctified":	{"VBD","VBN","JJ"},
"unsanctifies":	{"VBZ"},
"unsanctify":	{"VB","VBP"},
"unsanctifying":	{"VBG"},
"unsanctioned":	{"JJ"},
"unsanded":	{"JJ"},
"unsanitariness":	{"NN"},
"unsanitary":	{"JJ"},
"unsaponified":	{"JJ"},
"unsarcastic":	{"JJ"},
"unsated":	{"JJ"},
"unsatiable":	{"JJ"},
"unsatiably":	{"RB"},
"unsatiated":	{"JJ"},
"unsatisfactorily":	{"RB"},
"unsatisfactoriness":	{"NN"},
"unsatisfactory":	{"JJ"},
"unsatisfiable":	{"JJ"},
"unsatisfied":	{"JJ"},
"unsatisfying":	{"JJ"},
"unsatisfyingly":	{"RB"},
"unsaturated":	{"JJ"},
"unsaved":	{"JJ"},
"unsavoriness":	{"NN"},
"unsavory":	{"JJ"},
"unsavoury":	{"JJ"},
"unsay":	{"VB","VBP"},
"unsaying":	{"VBG"},
"unsays":	{"VBZ"},
"unscalable":	{"JJ"},
"unscathed":	{"JJ"},
"unscented":	{"JJ"},
"unscheduled":	{"JJ"},
"unscholarly":	{"JJ"},
"unschooled":	{"JJ"},
"unscientific":	{"JJ"},
"unscientifically":	{"RB"},
"unscramble":	{"VB","VBP"},
"unscrambled":	{"VBD","VBN"},
"unscrambles":	{"VBZ"},
"unscrambling":	{"VBG"},
"unscrew":	{"VB","VBP"},
"unscrewed":	{"VBD","VBN","JJ"},
"unscrewing":	{"VBG"},
"unscrews":	{"VBZ"},
"unscripted":	{"JJ"},
"unscrupulous":	{"JJ"},
"unscrupulously":	{"RB"},
"unscrupulousness":	{"NN"},
"unseal":	{"VB","VBP"},
"unsealed":	{"JJ","VBD","VBN"},
"unsealing":	{"VBG"},
"unseals":	{"VBZ"},
"unseamanlike":	{"JJ"},
"unseamed":	{"JJ"},
"unseasonable":	{"JJ"},
"unseasonableness":	{"NN"},
"unseasonably":	{"RB"},
"unseasonal":	{"JJ"},
"unseasoned":	{"JJ"},
"unseat":	{"VB","VBP"},
"unseated":	{"VBD","VBN"},
"unseating":	{"VBG"},
"unseats":	{"VBZ"},
"unseaworthy":	{"JJ"},
"unsectarian":	{"NN","JJ"},
"unsecured":	{"JJ"},
"unseductive":	{"JJ"},
"unsee":	{"VB","VBP"},
"unseeable":	{"JJ"},
"unseeded":	{"JJ"},
"unseeing":	{"JJ","VBG"},
"unseeingly":	{"RB"},
"unseemliness":	{"NN"},
"unseemly":	{"JJ"},
"unseen":	{"JJ","NN"},
"unseens":	{"NNS"},
"unsegmented":	{"JJ"},
"unsegregated":	{"JJ"},
"unselected":	{"JJ"},
"unselective":	{"JJ"},
"unself-conscious":	{"JJ"},
"unself-consciously":	{"RB"},
"unselfconscious":	{"JJ"},
"unselfconsciously":	{"RB"},
"unselfconsciousness":	{"NN"},
"unselfish":	{"JJ"},
"unselfishly":	{"RB"},
"unselfishness":	{"NN"},
"unsensational":	{"JJ"},
"unsent":	{"JJ"},
"unsentimental":	{"JJ"},
"unsentimentally":	{"RB"},
"unserious":	{"JJ"},
"unserviceable":	{"JJ"},
"unservile":	{"JJ"},
"unsettle":	{"VB","VBP"},
"unsettled":	{"JJ","VBD","VBN"},
"unsettlement":	{"NN"},
"unsettles":	{"VBZ"},
"unsettling":	{"JJ","VBG"},
"unsettlingly":	{"RB"},
"unsex":	{"VB","VBP"},
"unsexed":	{"JJ","VBD","VBN"},
"unsexier":	{"JJR"},
"unsexiest":	{"JJS"},
"unsexy":	{"JJ"},
"unshackle":	{"VB","VBP"},
"unshackled":	{"JJ","VBD","VBN"},
"unshackles":	{"VBZ"},
"unshackling":	{"VBG"},
"unshaded":	{"JJ"},
"unshadowed":	{"JJ"},
"unshakable":	{"JJ"},
"unshakably":	{"RB"},
"unshakeable":	{"JJ"},
"unshaken":	{"JJ"},
"unshaped":	{"JJ"},
"unshapely":	{"JJ"},
"unshapen":	{"JJ"},
"unshared":	{"JJ"},
"unsharpened":	{"JJ"},
"unshaved":	{"JJ"},
"unshaven":	{"JJ"},
"unsheared":	{"JJ"},
"unsheathe":	{"VB","VBP"},
"unsheathed":	{"VBD","VBN"},
"unsheathes":	{"VBZ"},
"unsheathing":	{"VBG"},
"unshed":	{"JJ"},
"unshelled":	{"JJ"},
"unsheltered":	{"JJ"},
"unshielded":	{"JJ"},
"unshirted":	{"JJ"},
"unshockable":	{"JJ"},
"unshod":	{"JJ"},
"unshoed":	{"JJ"},
"unshorn":	{"JJ"},
"unshrinkable":	{"JJ"},
"unshrinking":	{"JJ"},
"unshuttered":	{"JJ"},
"unsighted":	{"JJ"},
"unsightliness":	{"NN"},
"unsightly":	{"JJ"},
"unsigned":	{"JJ"},
"unsilenced":	{"JJ"},
"unsimilarity":	{"NN"},
"unsinkable":	{"JJ"},
"unsized":	{"JJ"},
"unskilled":	{"JJ"},
"unskillful":	{"JJ"},
"unskillfulness":	{"NN"},
"unsleeping":	{"JJ"},
"unsloped":	{"JJ"},
"unsmiling":	{"JJ"},
"unsmilingly":	{"RB"},
"unsmooth":	{"JJ"},
"unsmoothed":	{"JJ"},
"unsnarl":	{"VB","VBP"},
"unsnarled":	{"JJ","VBD","VBN"},
"unsnarling":	{"NN","VBG"},
"unsnarls":	{"VBZ"},
"unsociability":	{"NN"},
"unsociable":	{"JJ"},
"unsociableness":	{"NN"},
"unsociably":	{"RB"},
"unsocial":	{"JJ"},
"unsoiled":	{"JJ"},
"unsold":	{"JJ"},
"unsolder":	{"VB","VBP"},
"unsoldierly":	{"JJ"},
"unsolicited":	{"JJ"},
"unsoluble":	{"JJ"},
"unsolvability":	{"NN"},
"unsolvable":	{"JJ"},
"unsolved":	{"JJ"},
"unsophisticated":	{"JJ"},
"unsorted":	{"JJ"},
"unsought":	{"JJ"},
"unsound":	{"JJ"},
"unsoundable":	{"JJ"},
"unsounded":	{"JJ"},
"unsoundness":	{"NN"},
"unsoured":	{"JJ"},
"unsown":	{"JJ"},
"unspaced":	{"JJ"},
"unsparing":	{"JJ"},
"unsparingly":	{"RB"},
"unspeakable":	{"JJ"},
"unspeakably":	{"RB"},
"unspecialised":	{"JJ"},
"unspecialized":	{"JJ"},
"unspecific":	{"JJ"},
"unspecified":	{"JJ"},
"unspectacular":	{"JJ"},
"unspell":	{"VB","VBP"},
"unspent":	{"JJ"},
"unspoiled":	{"JJ"},
"unspoilt":	{"JJ"},
"unspoken":	{"JJ"},
"unspool":	{"VB","VBP"},
"unspooled":	{"VBD","VBN"},
"unspooling":	{"VBG"},
"unspools":	{"VBZ"},
"unsporting":	{"JJ"},
"unsportingly":	{"RB"},
"unsportsmanlike":	{"JJ"},
"unspotted":	{"JJ"},
"unsprayed":	{"JJ"},
"unstable":	{"JJ"},
"unstableness":	{"NN"},
"unstaged":	{"JJ"},
"unstained":	{"JJ"},
"unstanched":	{"JJ"},
"unstarred":	{"JJ"},
"unstated":	{"JJ"},
"unstatesmanlike":	{"JJ"},
"unsteadied":	{"VBD","VBN"},
"unsteadies":	{"VBZ"},
"unsteadily":	{"RB"},
"unsteadiness":	{"NN"},
"unsteady":	{"JJ","VB","VBP"},
"unsteadying":	{"VBG"},
"unsterilised":	{"JJ"},
"unsterilized":	{"JJ"},
"unstick":	{"VB","VBP"},
"unsticking":	{"VBG"},
"unsticks":	{"VBZ"},
"unstilted":	{"JJ"},
"unstimulated":	{"JJ"},
"unstimulating":	{"JJ"},
"unstinted":	{"JJ"},
"unstinting":	{"JJ"},
"unstintingly":	{"RB"},
"unstirred":	{"JJ"},
"unstoppable":	{"JJ"},
"unstoppered":	{"JJ"},
"unstrain":	{"VB","VBP"},
"unstrained":	{"JJ","VBD","VBN"},
"unstrap":	{"VB","VBP"},
"unstrapped":	{"VBD","VBN"},
"unstrapping":	{"VBG"},
"unstraps":	{"VBZ"},
"unstratified":	{"JJ"},
"unstressed":	{"JJ"},
"unstring":	{"VB","VBP"},
"unstringing":	{"VBG"},
"unstrings":	{"VBZ"},
"unstructured":	{"JJ"},
"unstrung":	{"VBD","VBN","JJ"},
"unstuck":	{"JJ","VBD","VBN"},
"unstudied":	{"JJ"},
"unstudious":	{"JJ"},
"unstuff":	{"VB","VBP"},
"unstuffed":	{"JJ","VBD","VBN"},
"unstuffier":	{"JJR"},
"unstuffiest":	{"JJS"},
"unstuffy":	{"JJ"},
"unstylish":	{"JJ"},
"unsuasible":	{"JJ"},
"unsubdivided":	{"JJ"},
"unsubduable":	{"JJ"},
"unsubdued":	{"JJ"},
"unsubmissive":	{"JJ"},
"unsubmitted":	{"JJ"},
"unsubordinated":	{"JJ"},
"unsubsidized":	{"JJ"},
"unsubstantial":	{"JJ"},
"unsubstantiated":	{"JJ"},
"unsubtle":	{"JJ"},
"unsuccessful":	{"JJ"},
"unsuccessfully":	{"RB"},
"unsufferable":	{"JJ"},
"unsugared":	{"JJ"},
"unsuitability":	{"NN"},
"unsuitable":	{"JJ"},
"unsuitableness":	{"NN"},
"unsuitably":	{"RB"},
"unsuited":	{"JJ"},
"unsullied":	{"JJ"},
"unsung":	{"JJ"},
"unsupervised":	{"JJ"},
"unsupportable":	{"JJ"},
"unsupported":	{"JJ"},
"unsupportive":	{"JJ"},
"unsuppressed":	{"JJ"},
"unsure":	{"JJ"},
"unsurmountable":	{"JJ"},
"unsurpassable":	{"JJ"},
"unsurpassed":	{"JJ"},
"unsurprised":	{"JJ"},
"unsurprising":	{"JJ"},
"unsurprisingly":	{"RB"},
"unsusceptibility":	{"NN"},
"unsusceptible":	{"JJ"},
"unsuspected":	{"JJ"},
"unsuspecting":	{"JJ"},
"unsuspectingly":	{"RB"},
"unsuspicious":	{"JJ"},
"unsustainable":	{"JJ"},
"unswagged":	{"JJ"},
"unswaggering":	{"JJ"},
"unswayed":	{"JJ"},
"unsweet":	{"JJ"},
"unsweetened":	{"JJ"},
"unswept":	{"JJ"},
"unswerving":	{"JJ"},
"unswervingly":	{"RB"},
"unsworn":	{"JJ"},
"unsyllabic":	{"JJ"},
"unsyllabled":	{"JJ"},
"unsymbolic":	{"JJ"},
"unsymmetric":	{"JJ"},
"unsymmetrical":	{"JJ"},
"unsymmetrically":	{"RB"},
"unsympathetic":	{"JJ"},
"unsympathetically":	{"RB"},
"unsympathising":	{"JJ"},
"unsympathizing":	{"JJ"},
"unsynchronised":	{"JJ"},
"unsynchronized":	{"JJ"},
"unsynchronous":	{"JJ"},
"unsystematic":	{"JJ"},
"unsystematically":	{"RB"},
"untactful":	{"JJ"},
"untagged":	{"JJ"},
"untainted":	{"JJ"},
"untalented":	{"JJ"},
"untalkative":	{"JJ"},
"untamed":	{"JJ"},
"untangle":	{"VB","VBP"},
"untangled":	{"VBD","VBN"},
"untangles":	{"VBZ"},
"untangling":	{"VBG"},
"untanned":	{"JJ"},
"untaped":	{"JJ"},
"untapped":	{"JJ"},
"untarnished":	{"JJ"},
"untasted":	{"JJ"},
"untaught":	{"JJ","VBD","VBN"},
"untaxed":	{"JJ"},
"unteach":	{"VB","VBP"},
"unteaches":	{"VBZ"},
"unteaching":	{"VBG"},
"untechnical":	{"JJ"},
"untellable":	{"JJ"},
"untempered":	{"JJ"},
"untempting":	{"JJ"},
"untenable":	{"JJ"},
"untenanted":	{"JJ"},
"untended":	{"JJ"},
"untenured":	{"JJ"},
"untested":	{"JJ"},
"untethered":	{"JJ"},
"unthankful":	{"JJ"},
"unthaw":	{"VB","VBP"},
"unthawed":	{"VBD","VBN","JJ"},
"unthawing":	{"VBG"},
"unthaws":	{"VBZ"},
"untheatrical":	{"JJ"},
"unthematic":	{"JJ"},
"unthink":	{"VB","VBP"},
"unthinkable":	{"JJ"},
"unthinkably":	{"RB"},
"unthinking":	{"JJ","VBG"},
"unthinkingly":	{"RB"},
"unthinks":	{"VBZ"},
"unthought":	{"JJ","VBD","VBN"},
"unthought-of":	{"JJ"},
"unthoughtful":	{"JJ"},
"unthoughtfulness":	{"NN"},
"unthreatened":	{"JJ"},
"unthreatening":	{"JJ"},
"unthreateningly":	{"RB"},
"untidier":	{"JJR"},
"untidiest":	{"JJS"},
"untidily":	{"RB"},
"untidiness":	{"NN"},
"untidy":	{"JJ"},
"untie":	{"VB","VBP"},
"untied":	{"VBD","VBN"},
"untier":	{"NN"},
"unties":	{"VBZ"},
"until":	{"IN","CC"},
"untilled":	{"JJ"},
"untimbered":	{"JJ"},
"untimeliness":	{"NN"},
"untimely":	{"JJ"},
"untipped":	{"JJ"},
"untired":	{"JJ"},
"untiring":	{"JJ"},
"untitled":	{"JJ"},
"unto":	{"IN"},
"untoasted":	{"JJ"},
"untold":	{"JJ"},
"untoothed":	{"JJ"},
"untouchable":	{"JJ","NN"},
"untouchables":	{"NNS"},
"untouched":	{"JJ"},
"untoughened":	{"JJ"},
"untoward":	{"JJ"},
"untraceable":	{"JJ"},
"untracked":	{"JJ"},
"untradeable":	{"JJ"},
"untraditional":	{"JJ"},
"untrained":	{"JJ"},
"untrammeled":	{"JJ"},
"untrammelled":	{"JJ"},
"untransferable":	{"JJ"},
"untranslatable":	{"JJ"},
"untransmutable":	{"JJ"},
"untraveled":	{"JJ"},
"untravelled":	{"JJ"},
"untraversable":	{"JJ"},
"untraversed":	{"JJ"},
"untreated":	{"JJ"},
"untried":	{"JJ"},
"untrimmed":	{"JJ"},
"untrod":	{"JJ"},
"untrodden":	{"JJ"},
"untroubled":	{"JJ"},
"untrue":	{"JJ"},
"untruly":	{"RB"},
"untrustiness":	{"NN"},
"untrusting":	{"JJ"},
"untrustworthiness":	{"NN"},
"untrustworthy":	{"JJ"},
"untrusty":	{"JJ"},
"untruth":	{"NN"},
"untruthful":	{"JJ"},
"untruthfully":	{"RB"},
"untruthfulness":	{"NN"},
"untruths":	{"NNS"},
"untucked":	{"JJ"},
"untufted":	{"JJ"},
"untune":	{"VB","VBP"},
"untuneful":	{"JJ"},
"unturned":	{"JJ"},
"untutored":	{"JJ"},
"untwine":	{"VB","VBP"},
"untwist":	{"VB","VBP"},
"untwisted":	{"VBD","VBN"},
"untwisting":	{"VBG"},
"untwists":	{"VBZ"},
"untying":	{"VBG"},
"untypical":	{"JJ"},
"untypicality":	{"NN"},
"untypically":	{"RB"},
"ununbium":	{"NN"},
"ununderstandably":	{"RB"},
"ununderstood":	{"JJ"},
"ununhexium":	{"NN"},
"ununpentium":	{"NN"},
"ununquadium":	{"NN"},
"ununtrium":	{"NN"},
"unusable":	{"JJ"},
"unusally":	{"RB"},
"unuseable":	{"JJ"},
"unused":	{"JJ"},
"unusefulness":	{"NN"},
"unusual":	{"JJ"},
"unusually":	{"RB"},
"unusualness":	{"NN"},
"unutterable":	{"JJ"},
"unutterably":	{"RB"},
"unuttered":	{"JJ"},
"unvaccinated":	{"JJ"},
"unvalued":	{"JJ"},
"unvaned":	{"JJ"},
"unvanquishable":	{"JJ"},
"unvanquished":	{"JJ"},
"unvaried":	{"JJ"},
"unvariedness":	{"NN"},
"unvarnished":	{"JJ"},
"unvarying":	{"JJ"},
"unvaryingly":	{"RB"},
"unveil":	{"VB","VBP"},
"unveiled":	{"VBD","VBN"},
"unveiling":	{"NN","VBG"},
"unveils":	{"VBZ"},
"unvendible":	{"JJ"},
"unvented":	{"JJ"},
"unventilated":	{"JJ"},
"unverbalised":	{"JJ"},
"unverbalized":	{"JJ"},
"unverifiable":	{"JJ"},
"unverified":	{"JJ"},
"unversed":	{"JJ"},
"unviable":	{"JJ"},
"unvigilant":	{"JJ"},
"unvindictive":	{"JJ"},
"unvisited":	{"JJ"},
"unvitrified":	{"JJ"},
"unvoiced":	{"JJ"},
"unvoluntary":	{"JJ"},
"unvulcanised":	{"JJ"},
"unvulcanized":	{"JJ"},
"unwanted":	{"JJ"},
"unwantedly":	{"RB"},
"unwarily":	{"RB"},
"unwariness":	{"NN"},
"unwarmed":	{"JJ"},
"unwarrantable":	{"JJ"},
"unwarrantably":	{"RB"},
"unwarranted":	{"JJ"},
"unwary":	{"JJ"},
"unwashed":	{"JJ"},
"unwatchful":	{"JJ"},
"unwatered":	{"JJ"},
"unwavering":	{"JJ"},
"unwaveringly":	{"RB"},
"unwaxed":	{"JJ"},
"unweaned":	{"JJ"},
"unwearable":	{"JJ"},
"unwearied":	{"JJ"},
"unweary":	{"JJ"},
"unwearying":	{"JJ"},
"unweathered":	{"JJ"},
"unweave":	{"VB","VBP"},
"unweaves":	{"VBZ"},
"unweaving":	{"VBG"},
"unwebbed":	{"JJ"},
"unwed":	{"JJ"},
"unwedded":	{"JJ"},
"unwelcome":	{"JJ"},
"unwell":	{"JJ"},
"unwellness":	{"NN"},
"unwholesome":	{"JJ"},
"unwholesomeness":	{"NN"},
"unwieldiness":	{"NN"},
"unwieldy":	{"JJ"},
"unwilled":	{"JJ"},
"unwilling":	{"JJ"},
"unwillingly":	{"RB"},
"unwillingness":	{"NN"},
"unwind":	{"VB","VBP"},
"unwinding":	{"VBG"},
"unwinds":	{"VBZ"},
"unwire":	{"VB","VBP"},
"unwired":	{"VBD","VBN"},
"unwise":	{"JJ"},
"unwisely":	{"RB"},
"unwiseness":	{"NN"},
"unwished":	{"JJ"},
"unwished-for":	{"JJ"},
"unwitting":	{"JJ"},
"unwittingly":	{"RB"},
"unwomanly":	{"JJ"},
"unwonted":	{"JJ"},
"unwontedly":	{"RB"},
"unwooded":	{"JJ"},
"unworkable":	{"JJ"},
"unworkmanlike":	{"JJ"},
"unworldliness":	{"NN"},
"unworldly":	{"JJ"},
"unworn":	{"JJ"},
"unworried":	{"JJ"},
"unworthily":	{"RB"},
"unworthiness":	{"NN"},
"unworthy":	{"JJ"},
"unwound":	{"VBD","VBN"},
"unwounded":	{"JJ"},
"unwove":	{"VBD"},
"unwoven":	{"VBN"},
"unwrap":	{"VB","VBP"},
"unwrapped":	{"VBD","VBN"},
"unwrapping":	{"VBG"},
"unwraps":	{"VBZ"},
"unwrinkle":	{"VB","VBP"},
"unwrinkled":	{"VBD","VBN","JJ"},
"unwritten":	{"JJ"},
"unyielding":	{"JJ"},
"unyieldingness":	{"NN"},
"unyoke":	{"VB","VBP"},
"unyoked":	{"VBD","VBN"},
"unyokes":	{"VBZ"},
"unyoking":	{"VBG"},
"unzip":	{"VB","VBP"},
"unzipped":	{"VBD","VBN"},
"unzipping":	{"VBG"},
"unzips":	{"VBZ"},
"up":	{"RP","RB","IN","JJ","VB","VBP","NN"},
"up-and-coming":	{"JJ"},
"up-country":	{"JJ","RB"},
"up-front":	{"RB","JJ"},
"up-market":	{"JJ"},
"up-tempo":	{"JJ"},
"up-to-date":	{"JJ"},
"up-to-the-minute":	{"JJ"},
"upbeat":	{"JJ","NN"},
"upbeats":	{"NNS"},
"upbound":	{"JJ"},
"upbraid":	{"VB","VBP"},
"upbraided":	{"VBD","VBN"},
"upbraider":	{"NN"},
"upbraiding":	{"NN","VBG"},
"upbraids":	{"VBZ"},
"upbringing":	{"NN"},
"upcast":	{"NN","JJ","VB","VBP","VBD","VBN"},
"upcasting":	{"VBG"},
"upcasts":	{"NNS","VBZ"},
"upchuck":	{"VB","VBP"},
"upchucked":	{"VBD","VBN"},
"upchucking":	{"VBG"},
"upchucks":	{"VBZ"},
"upcoming":	{"JJ"},
"upcountry":	{"JJ","RB","NN"},
"upcurved":	{"JJ"},
"update":	{"VB","VBP","NN"},
"updated":	{"VBN","VBD"},
"updates":	{"NNS","VBZ"},
"updating":	{"VBG"},
"updraft":	{"NN"},
"upend":	{"VB","VBP"},
"upended":	{"VBD","VBN"},
"upending":	{"VBG"},
"upends":	{"VBZ"},
"upfield":	{"JJ","RB"},
"upfront":	{"JJ","RB"},
"upgrade":	{"VB","VBP","NN","RB","JJ"},
"upgraded":	{"VBN","VBD"},
"upgrades":	{"VBZ","NNS"},
"upgrading":	{"VBG"},
"upheaval":	{"NN"},
"upheavals":	{"NNS"},
"upheave":	{"VB"},
"upheld":	{"VBD","VBN"},
"uphill":	{"JJ","RB"},
"uphold":	{"VB","VBP"},
"upholder":	{"NN"},
"upholders":	{"NNS"},
"upholding":	{"VBG"},
"upholds":	{"VBZ"},
"upholster":	{"VB","VBP"},
"upholstered":	{"VBN","VBD","JJ"},
"upholsterer":	{"NN"},
"upholsterers":	{"NNS"},
"upholstering":	{"VBG"},
"upholsters":	{"VBZ"},
"upholstery":	{"NN"},
"upkeep":	{"NN"},
"upland":	{"NN","JJ"},
"uplands":	{"NNS"},
"uplift":	{"VB","VBP","NN"},
"uplifted":	{"VBD","VBN","JJ"},
"uplifting":	{"JJ","VBG"},
"uplifts":	{"VBZ"},
"uplink":	{"NN","VB","VBP"},
"upload":	{"VB","VBP","NN"},
"uploaded":	{"VBD","VBN"},
"uploading":	{"VBG"},
"uploads":	{"VBZ","NNS"},
"upmarket":	{"JJ","RB"},
"upmost":	{"JJ"},
"upon":	{"IN","RP"},
"upped":	{"VBD","VBN","JJ"},
"upper":	{"JJ","NN"},
"upper-class":	{"JJ"},
"upper-crust":	{"JJ","NN"},
"uppercase":	{"JJ"},
"upperclassman":	{"NN"},
"upperclassmen":	{"NNS"},
"uppercut":	{"NN"},
"uppercuts":	{"NNS"},
"uppermost":	{"JJ","RB"},
"uppers":	{"NNS"},
"upping":	{"VBG"},
"uppish":	{"JJ"},
"uppishly":	{"RB"},
"uppishness":	{"NN"},
"uppity":	{"JJ"},
"uppityness":	{"NN"},
"upraise":	{"VB","VBP"},
"upraised":	{"JJ","VBD","VBN"},
"upregulation":	{"NN"},
"upright":	{"JJ","RB","NN"},
"uprightly":	{"RB"},
"uprightness":	{"NN"},
"uprights":	{"NNS"},
"uprise":	{"VB","VBP","NN"},
"uprisen":	{"VBN"},
"upriser":	{"NN"},
"uprises":	{"VBZ"},
"uprising":	{"VBG","NN"},
"uprisings":	{"NNS"},
"upriver":	{"RB"},
"uproar":	{"NN"},
"uproarious":	{"JJ"},
"uproariously":	{"RB"},
"uproot":	{"VB","VBP"},
"uprooted":	{"VBD","VBN"},
"uprooter":	{"NN"},
"uprooting":	{"VBG"},
"uproots":	{"VBZ"},
"uprose":	{"VBD"},
"ups":	{"NNS","VBZ"},
"upscale":	{"JJ","RB","VB","VBP"},
"upscaled":	{"VBD","VBN"},
"upscales":	{"VBZ"},
"upscaling":	{"VBG"},
"upset":	{"JJ","VBN","VB","NN","VBD","VBP"},
"upsets":	{"NNS","VBZ"},
"upsetter":	{"NN"},
"upsetting":	{"JJ","VBG"},
"upshot":	{"NN"},
"upside":	{"NN","IN"},
"upside-down":	{"JJ","RB"},
"upsilon":	{"NN"},
"upstage":	{"VB","VBP","JJ","RB"},
"upstaged":	{"VBD","VBN"},
"upstager":	{"NN"},
"upstages":	{"VBZ"},
"upstaging":	{"VBG"},
"upstairs":	{"RB","JJ","NN"},
"upstanding":	{"JJ"},
"upstart":	{"NN","JJ","VB","VBP"},
"upstarted":	{"VBD","VBN"},
"upstarting":	{"VBG"},
"upstarts":	{"NNS","VBZ"},
"upstate":	{"JJ","RB"},
"upstream":	{"RB","JJ"},
"upstroke":	{"NN"},
"upsurge":	{"NN","VB","VBP"},
"upsurged":	{"VBD","VBN"},
"upsurges":	{"VBZ","NNS"},
"upsurging":	{"VBG"},
"upswing":	{"NN"},
"upswings":	{"NNS"},
"uptake":	{"NN"},
"upthrew":	{"VBD"},
"upthrow":	{"NN","VB","VBP"},
"upthrowing":	{"VBG"},
"upthrown":	{"VBN"},
"upthrows":	{"NNS","VBZ"},
"upthrust":	{"VB","VBP","NN"},
"uptick":	{"NN"},
"uptight":	{"JJ"},
"uptime":	{"NN"},
"uptown":	{"JJ","RB","NN"},
"uptrend":	{"NN"},
"upturn":	{"NN","VB","VBP"},
"upturned":	{"JJ","VBD","VBN"},
"upturning":	{"VBG"},
"upturns":	{"NNS","VBZ"},
"upupa":	{"NN"},
"upupidae":	{"NN"},
"upvote":	{"VB","VBP","NN"},
"upvoted":	{"VBD","VBN"},
"upvotes":	{"VBZ","NNS"},
"upvoting":	{"VBG"},
"upward":	{"RB","JJ"},
"upwardly":	{"RB"},
"upwards":	{"RB"},
"upwind":	{"JJ","RB"},
"uracil":	{"NN"},
"uraemia":	{"NN"},
"uraemic":	{"JJ"},
"urals":	{"NNS"},
"uranalyses":	{"NNS"},
"uranalysis":	{"NN"},
"urania":	{"NN"},
"uraninite":	{"NN"},
"uranium":	{"NN"},
"uranologist":	{"NN"},
"uranology":	{"NN"},
"uranoplasty":	{"NN"},
"uranoscopidae":	{"NN"},
"uranyl":	{"NN"},
"uranylic":	{"JJ"},
"urarthritis":	{"NN"},
"urate":	{"NN"},
"uratemia":	{"NN"},
"uraturia":	{"NN"},
"urban":	{"JJ"},
"urbana":	{"NN"},
"urbane":	{"JJ"},
"urbanely":	{"RB"},
"urbanisation":	{"NN"},
"urbanise":	{"VB","VBP"},
"urbanised":	{"JJ","VBD","VBN"},
"urbanism":	{"NN"},
"urbanity":	{"NN"},
"urbanization":	{"NN"},
"urbanize":	{"VB","VBP"},
"urbanized":	{"VBD","VBN","JJ"},
"urceolate":	{"JJ"},
"urceole":	{"NN"},
"urceoles":	{"NNS"},
"urchin":	{"NN"},
"urchins":	{"NNS"},
"urd":	{"NN"},
"urea":	{"NN"},
"urease":	{"NN"},
"uredinales":	{"NNS"},
"uremia":	{"NN"},
"uremic":	{"JJ"},
"ureter":	{"NN"},
"ureteritis":	{"NN"},
"ureterocele":	{"NN"},
"ureterostenosis":	{"NN"},
"urethane":	{"NN"},
"urethanes":	{"NNS"},
"urethra":	{"NN"},
"urethrae":	{"NNS"},
"urethral":	{"JJ"},
"urethras":	{"NNS"},
"urethritis":	{"NN"},
"urethrocele":	{"NN"},
"urex":	{"NN"},
"urge":	{"VB","NN","VBP"},
"urged":	{"VBD","VBN"},
"urgencies":	{"NNS"},
"urgency":	{"NN"},
"urgent":	{"JJ"},
"urgently":	{"RB"},
"urges":	{"VBZ","NNS"},
"urginea":	{"NN"},
"urging":	{"VBG"},
"urial":	{"NN"},
"uric":	{"JJ"},
"uricaciduria":	{"NN"},
"uricosuric":	{"JJ"},
"urinal":	{"NN"},
"urinals":	{"NNS"},
"urinalysis":	{"NN"},
"urinary":	{"JJ"},
"urinate":	{"VB","VBP"},
"urinated":	{"VBD","VBN"},
"urinates":	{"VBZ"},
"urinating":	{"VBG"},
"urination":	{"NN"},
"urinator":	{"NN"},
"urine":	{"NN"},
"urmia":	{"NN"},
"urn":	{"NN"},
"urns":	{"NNS"},
"urobilin":	{"NN"},
"urobilinogen":	{"NN"},
"urocele":	{"NN"},
"urochesia":	{"NN"},
"urochezia":	{"NN"},
"urochord":	{"NN"},
"urochorda":	{"NN"},
"urochordata":	{"NN"},
"urochordate":	{"NN"},
"urocyon":	{"NN"},
"urocystis":	{"NN"},
"urodele":	{"NN"},
"urodella":	{"NN"},
"urodynia":	{"NN"},
"urogenital":	{"JJ"},
"urokinase":	{"NN"},
"urolith":	{"NN"},
"urological":	{"JJ"},
"urologist":	{"NN"},
"urology":	{"NN"},
"uropathy":	{"NN"},
"urophycis":	{"NN"},
"uropsilus":	{"NN"},
"uropygi":	{"NN"},
"uropygium":	{"NN"},
"urosaurus":	{"NN"},
"urothelial":	{"JJ"},
"ursidae":	{"NN"},
"ursine":	{"JJ"},
"ursinia":	{"NN"},
"ursus":	{"NN"},
"urtica":	{"NN"},
"urticaceae":	{"NN"},
"urticales":	{"NNS"},
"urticaria":	{"NN"},
"urticate":	{"JJ","VB","VBP"},
"urtication":	{"NN"},
"urubupunga":	{"NN"},
"urus":	{"NN"},
"uruses":	{"NNS"},
"us":	{"PRP"},
"usability":	{"NN"},
"usable":	{"JJ"},
"usableness":	{"NN"},
"usage":	{"NN"},
"usages":	{"NNS"},
"usance":	{"NN"},
"use":	{"VB","NN","VBP"},
"useability":	{"NN"},
"useable":	{"JJ"},
"useably":	{"RB"},
"used":	{"VBN","VBD","JJ"},
"useful":	{"JJ"},
"usefully":	{"RB"},
"usefulness":	{"NN"},
"useless":	{"JJ"},
"uselessly":	{"RB"},
"uselessness":	{"NN"},
"user":	{"NN"},
"user-friendly":	{"JJ"},
"username":	{"NN"},
"users":	{"NNS"},
"usership":	{"NN"},
"userships":	{"NNS"},
"uses":	{"VBZ","NNS"},
"usher":	{"NN","VB","VBP"},
"ushered":	{"VBD","VBN"},
"usherette":	{"NN"},
"ushering":	{"VBG"},
"ushers":	{"VBZ","NNS"},
"using":	{"VBG"},
"usnea":	{"NN"},
"usneaceae":	{"NN"},
"ustilaginaceae":	{"NN"},
"ustilaginales":	{"NNS"},
"ustilaginoidea":	{"NN"},
"ustilago":	{"NN"},
"ustinov":	{"NN"},
"usual":	{"JJ"},
"usually":	{"RB"},
"usualness":	{"NN"},
"usufruct":	{"NN"},
"usufructuary":	{"NN"},
"usurer":	{"NN"},
"usurious":	{"JJ"},
"usuriously":	{"RB"},
"usurp":	{"VB","VBP"},
"usurpation":	{"NN"},
"usurped":	{"VBD","VBN"},
"usurper":	{"NN"},
"usurpers":	{"NNS"},
"usurping":	{"VBG"},
"usurps":	{"VBZ"},
"usury":	{"NN"},
"ut":	{"NN"},
"utahraptor":	{"NN"},
"ute":	{"NN"},
"utensil":	{"NN"},
"utensils":	{"NNS"},
"uterine":	{"JJ"},
"utero":	{"NN","JJ"},
"uterus":	{"NN"},
"uteruses":	{"NNS"},
"utes":	{"NNS"},
"utile":	{"JJ"},
"utilisation":	{"NN"},
"utilise":	{"VB","VBP"},
"utilised":	{"VBD","VBN"},
"utiliser":	{"NN"},
"utilises":	{"VBZ"},
"utilising":	{"VBG"},
"utilitarian":	{"JJ","NN"},
"utilitarianism":	{"NN"},
"utilitarians":	{"NNS"},
"utilities":	{"NNS"},
"utility":	{"NN"},
"utilizable":	{"JJ"},
"utilization":	{"NN"},
"utilize":	{"VB","VBP"},
"utilized":	{"VBD","VBN"},
"utilizer":	{"NN"},
"utilizes":	{"VBZ"},
"utilizing":	{"VBG"},
"utmost":	{"JJ","NN"},
"utopia":	{"NN"},
"utopian":	{"JJ","NN"},
"utopianism":	{"NN"},
"utopians":	{"NNS"},
"utopias":	{"NNS"},
"utricle":	{"NN"},
"utricularia":	{"NN"},
"utriculus":	{"NN"},
"utrillo":	{"NN"},
"utter":	{"JJ","VB","VBP"},
"utterable":	{"JJ"},
"utterance":	{"NN"},
"utterances":	{"NNS"},
"uttered":	{"VBD","VBN"},
"utterer":	{"NN"},
"uttering":	{"VBG"},
"utterly":	{"RB"},
"uttermost":	{"NN","JJ"},
"utterness":	{"NN"},
"utters":	{"VBZ"},
"utu":	{"NN"},
"utus":	{"NNS"},
"uvea":	{"NN"},
"uveal":	{"JJ"},
"uveitis":	{"NN"},
"uveous":	{"JJ"},
"uvula":	{"NN"},
"uvulae":	{"NNS"},
"uvular":	{"JJ","NN"},
"uvularia":	{"NN"},
"uvulariaceae":	{"NN"},
"uvularly":	{"RB"},
"uvulitis":	{"NN"},
"uvulopalatopharyngoplasty":	{"NN"},
"uxorial":	{"JJ"},
"uxoricide":	{"NN"},
"uxorious":	{"JJ"},
"uxoriously":	{"RB"},
"uxoriousness":	{"NN"},
"uzbekistan":	{"NN"},
"v":	{"NN","RB","IN","SYM","LS"},
"v.":	{"NN","RB","IN"},
"vac":	{"NN"},
"vacancies":	{"NNS"},
"vacancy":	{"NN"},
"vacant":	{"JJ"},
"vacantly":	{"RB"},
"vacate":	{"VB","VBP"},
"vacated":	{"VBD","VBN"},
"vacates":	{"VBZ"},
"vacating":	{"VBG"},
"vacation":	{"NN","VBP","VB"},
"vacationed":	{"VBD","VBN"},
"vacationer":	{"NN"},
"vacationers":	{"NNS"},
"vacationing":	{"VBG"},
"vacationist":	{"NN"},
"vacationland":	{"NN"},
"vacations":	{"NNS","VBZ"},
"vaccaria":	{"NN"},
"vaccina":	{"NN"},
"vaccinate":	{"VB","VBP"},
"vaccinated":	{"VBD","VBN"},
"vaccinates":	{"VBZ"},
"vaccinating":	{"VBG"},
"vaccination":	{"NN"},
"vaccinations":	{"NNS"},
"vaccinator":	{"NN"},
"vaccine":	{"NN"},
"vaccinee":	{"NN"},
"vaccinees":	{"NNS"},
"vaccines":	{"NNS"},
"vaccinia":	{"NN"},
"vaccinium":	{"NN"},
"vacciniums":	{"NNS"},
"vacillant":	{"JJ"},
"vacillate":	{"VB","VBP"},
"vacillated":	{"VBD","VBN"},
"vacillates":	{"VBZ"},
"vacillating":	{"VBG"},
"vacillation":	{"NN"},
"vacillations":	{"NNS"},
"vacillator":	{"NN"},
"vacs":	{"NNS"},
"vacua":	{"NNS"},
"vacuity":	{"NN"},
"vacuolate":	{"JJ"},
"vacuolated":	{"JJ"},
"vacuolation":	{"NN"},
"vacuole":	{"NN"},
"vacuoles":	{"NNS"},
"vacuolisation":	{"NN"},
"vacuolization":	{"NN"},
"vacuous":	{"JJ"},
"vacuously":	{"RB"},
"vacuousness":	{"NN"},
"vacuum":	{"NN","VB","VBP"},
"vacuum-packed":	{"JJ"},
"vacuumed":	{"VBD","VBN"},
"vacuuming":	{"VBG"},
"vacuums":	{"NNS","VBZ"},
"vade":	{"NN"},
"vagabond":	{"NN","JJ","VB","VBP"},
"vagabondage":	{"NN"},
"vagabonded":	{"VBD","VBN"},
"vagabonding":	{"VBG"},
"vagabondish":	{"JJ"},
"vagabondism":	{"NN"},
"vagabonds":	{"NNS","VBZ"},
"vagal":	{"JJ"},
"vagaries":	{"NNS"},
"vagary":	{"NN"},
"vagile":	{"JJ"},
"vagina":	{"NN"},
"vaginae":	{"NNS"},
"vaginal":	{"JJ"},
"vaginas":	{"NNS"},
"vaginismus":	{"NN"},
"vaginitis":	{"NN"},
"vaginocele":	{"NN"},
"vagrancy":	{"NN"},
"vagrant":	{"NN","JJ"},
"vagrants":	{"NNS"},
"vague":	{"JJ"},
"vaguely":	{"RB"},
"vagueness":	{"NN"},
"vaguer":	{"JJR"},
"vaguest":	{"JJS"},
"vagus":	{"NN"},
"vail":	{"VB","VBP"},
"vailed":	{"VBD","VBN"},
"vailes":	{"VBZ"},
"vailing":	{"VBG"},
"vain":	{"JJ","NN"},
"vainer":	{"JJR"},
"vainest":	{"JJS"},
"vainglorious":	{"JJ"},
"vainglory":	{"NN"},
"vainly":	{"RB"},
"valance":	{"NN"},
"valances":	{"NNS"},
"valdecoxib":	{"NN"},
"vale":	{"NN"},
"valediction":	{"NN"},
"valedictions":	{"NNS"},
"valedictorian":	{"NN"},
"valedictorians":	{"NNS"},
"valedictories":	{"NNS"},
"valedictory":	{"NN","JJ"},
"valence":	{"NN"},
"valences":	{"NNS"},
"valencies":	{"NNS"},
"valency":	{"NN"},
"valent":	{"JJ"},
"valentine":	{"NN"},
"valentines":	{"NNS"},
"valerian":	{"NN"},
"valeriana":	{"NN"},
"valerianaceae":	{"NN"},
"valerianella":	{"NN"},
"vales":	{"NNS"},
"valet":	{"NN","VB","VBP"},
"valeted":	{"VBD","VBN"},
"valeting":	{"VBG"},
"valets":	{"NNS","VBZ"},
"valetudinarian":	{"JJ","NN"},
"valetudinarianism":	{"NN"},
"valetudinarians":	{"NNS"},
"valetudinary":	{"JJ"},
"valeur":	{"NN"},
"valgus":	{"JJ","NN"},
"valiance":	{"NN"},
"valiancy":	{"NN"},
"valiant":	{"JJ"},
"valiantly":	{"RB"},
"valid":	{"JJ"},
"validate":	{"VB","VBP"},
"validated":	{"VBD","VBN"},
"validates":	{"VBZ"},
"validating":	{"VBG"},
"validation":	{"NN"},
"validations":	{"NNS"},
"validatory":	{"JJ"},
"validity":	{"NN"},
"validly":	{"RB"},
"validness":	{"NN"},
"valine":	{"NN"},
"valise":	{"NN"},
"valium":	{"NN"},
"vallecula":	{"NN"},
"valleculae":	{"NNS"},
"valley":	{"NN"},
"valleys":	{"NNS"},
"vallisneria":	{"NN"},
"valor":	{"NN"},
"valorous":	{"JJ"},
"valorously":	{"RB"},
"valorousness":	{"NN"},
"valour":	{"NN"},
"valsartan":	{"NN"},
"valse":	{"NN","FW"},
"valuable":	{"JJ"},
"valuableness":	{"NN"},
"valuables":	{"NNS"},
"valuate":	{"VB","VBP"},
"valuated":	{"VBD","VBN"},
"valuates":	{"VBZ"},
"valuating":	{"VBG"},
"valuation":	{"NN"},
"valuations":	{"NNS"},
"valuator":	{"NN"},
"value":	{"NN","VB","VBP"},
"valued":	{"VBN","VBD","JJ"},
"valueless":	{"JJ"},
"valuelessness":	{"NN"},
"valuer":	{"NN"},
"valuers":	{"NNS"},
"values":	{"NNS","VBZ"},
"valuing":	{"VBG"},
"valve":	{"NN","VB","VBP"},
"valved":	{"VBD","VBN"},
"valvelet":	{"NN"},
"valves":	{"NNS","VBZ"},
"valving":	{"VBG"},
"valvotomy":	{"NN"},
"valvula":	{"NN"},
"valvular":	{"JJ"},
"valvule":	{"NN"},
"valvulitis":	{"NN"},
"valvulotomy":	{"NN"},
"vambrace":	{"NN"},
"vamoose":	{"VB","VBP"},
"vamp":	{"NN","VB","VBP"},
"vamped":	{"VBD","VBN"},
"vamper":	{"NN"},
"vamping":	{"VBG"},
"vampire":	{"NN"},
"vampires":	{"NNS"},
"vampirism":	{"NN"},
"vamps":	{"NNS","VBZ"},
"van":	{"NN","VB","VBP"},
"vanadate":	{"NN"},
"vanadinite":	{"NN"},
"vanadium":	{"NN"},
"vancocin":	{"NN"},
"vancomycin":	{"NN"},
"vanda":	{"NN"},
"vandal":	{"NN"},
"vandalise":	{"VB","VBP"},
"vandalised":	{"VBD","VBN"},
"vandalises":	{"VBZ"},
"vandalising":	{"VBG"},
"vandalism":	{"NN"},
"vandalize":	{"VB","VBP"},
"vandalized":	{"VBD","VBN"},
"vandalizes":	{"VBZ"},
"vandalizing":	{"VBG"},
"vandals":	{"NNS"},
"vanderbilt":	{"NN"},
"vane":	{"NN"},
"vaned":	{"JJ"},
"vaneless":	{"JJ"},
"vanellus":	{"NN"},
"vanes":	{"NNS"},
"vanguard":	{"NN"},
"vangueria":	{"NN"},
"vanilla":	{"NN","JJ"},
"vanillas":	{"NNS"},
"vanillin":	{"NN"},
"vanish":	{"VB","VBP"},
"vanished":	{"VBD","VBN","JJ"},
"vanisher":	{"NN"},
"vanishes":	{"VBZ"},
"vanishing":	{"VBG","JJ"},
"vanishingly":	{"RB"},
"vanities":	{"NNS"},
"vanity":	{"NN"},
"vanned":	{"VBD","VBN"},
"vanner":	{"NN"},
"vanning":	{"VBG"},
"vanquish":	{"VB","VBP"},
"vanquishable":	{"JJ"},
"vanquished":	{"VBD","VBN"},
"vanquisher":	{"NN"},
"vanquishes":	{"VBZ"},
"vanquishing":	{"VBG"},
"vans":	{"NNS","VBZ"},
"vantage":	{"NN"},
"vantage-point":	{"NN"},
"vantage-points":	{"NNS"},
"vantages":	{"NNS"},
"vape":	{"VB","VBP","NN"},
"vaped":	{"VBD","VBN"},
"vaper":	{"NN"},
"vapers":	{"NNS"},
"vapes":	{"VBZ","NNS"},
"vapid":	{"JJ"},
"vapidities":	{"NNS"},
"vapidity":	{"NN"},
"vapidly":	{"RB"},
"vapidness":	{"NN"},
"vaping":	{"VBG","NN"},
"vapor":	{"NN","VB","VBP"},
"vapor-like":	{"JJ"},
"vaporability":	{"NN"},
"vaporable":	{"JJ"},
"vapored":	{"VBD","VBN"},
"vaporer":	{"NN"},
"vaporific":	{"JJ"},
"vaporing":	{"VBG","JJ","NN"},
"vaporings":	{"NNS"},
"vaporisation":	{"NN"},
"vaporise":	{"VB","VBP"},
"vaporised":	{"VBD","VBN"},
"vaporiser":	{"NN"},
"vaporisers":	{"NNS"},
"vaporises":	{"VBZ"},
"vaporish":	{"JJ"},
"vaporising":	{"VBG"},
"vaporizable":	{"JJ"},
"vaporization":	{"NN"},
"vaporize":	{"VB","VBP"},
"vaporized":	{"VBD","VBN"},
"vaporizer":	{"NN"},
"vaporizers":	{"NNS"},
"vaporizes":	{"VBZ"},
"vaporizing":	{"VBG"},
"vaporless":	{"JJ"},
"vaporous":	{"JJ"},
"vaporousness":	{"NN"},
"vapors":	{"NNS","VBZ"},
"vapory":	{"JJ"},
"vapour":	{"NN","VB","VBP"},
"vapour-like":	{"JJ"},
"vapourability":	{"NN"},
"vapourable":	{"JJ"},
"vapoured":	{"VBD","VBN"},
"vapourer":	{"NN"},
"vapourific":	{"JJ"},
"vapouring":	{"VBG"},
"vapourisable":	{"JJ"},
"vapourised":	{"JJ"},
"vapourish":	{"JJ"},
"vapourless":	{"JJ"},
"vapourous":	{"JJ"},
"vapourousness":	{"NN"},
"vapours":	{"NNS","VBZ"},
"vapoury":	{"JJ"},
"vaquero":	{"NN"},
"vaqueros":	{"NNS"},
"vaquita":	{"NN"},
"var":	{"NN"},
"vara":	{"NN"},
"varanidae":	{"NN"},
"varanus":	{"NN"},
"vardenafil":	{"NN"},
"variability":	{"NN"},
"variable":	{"JJ","NN"},
"variableness":	{"NN"},
"variables":	{"NNS"},
"variably":	{"RB"},
"variance":	{"NN"},
"variances":	{"NNS"},
"variant":	{"NN","JJ"},
"variants":	{"NNS"},
"variate":	{"NN"},
"variation":	{"NN"},
"variations":	{"NNS"},
"varicella":	{"NN"},
"varicelliform":	{"JJ"},
"varicocele":	{"NN"},
"varicolored":	{"JJ"},
"varicoloured":	{"JJ"},
"varicose":	{"JJ"},
"varicosis":	{"NN"},
"varicosity":	{"NN"},
"varied":	{"JJ","VBD","VBN"},
"variedness":	{"NN"},
"variegate":	{"VB","VBP"},
"variegated":	{"JJ","VBD","VBN"},
"variegation":	{"NN"},
"varies":	{"VBZ"},
"varietal":	{"JJ"},
"varieties":	{"NNS"},
"variety":	{"NN"},
"variform":	{"JJ"},
"variola":	{"NN"},
"variolar":	{"JJ"},
"variolation":	{"NN"},
"variolic":	{"JJ"},
"variolization":	{"NN"},
"variolous":	{"JJ"},
"variometer":	{"NN"},
"variorum":	{"NN","JJ"},
"various":	{"JJ"},
"variously":	{"RB"},
"varitype":	{"NN","VB","VBP"},
"varityped":	{"VBD","VBN"},
"varitypes":	{"NNS","VBZ"},
"varityping":	{"VBG"},
"varitypist":	{"NN"},
"varix":	{"NN"},
"varlet":	{"NN"},
"varment":	{"NN"},
"varments":	{"NNS"},
"varmint":	{"NN"},
"varnish":	{"NN","VB","VBP"},
"varnished":	{"VBD","VBN"},
"varnisher":	{"NN"},
"varnishes":	{"NNS","VBZ"},
"varnishing":	{"VBG","NN"},
"varnishy":	{"JJ"},
"varsities":	{"NNS"},
"varsity":	{"JJ","NN"},
"varus":	{"JJ","NN"},
"vary":	{"VB","VBP"},
"varying":	{"VBG","JJ"},
"varyingly":	{"RB"},
"vas":	{"NN"},
"vasa":	{"NNS"},
"vascular":	{"JJ"},
"vascularisation":	{"NN"},
"vascularise":	{"VB","VBP"},
"vascularity":	{"NN"},
"vascularization":	{"NN"},
"vascularize":	{"VB","VBP"},
"vasculitis":	{"NN"},
"vase":	{"NN"},
"vasectomies":	{"NNS"},
"vasectomise":	{"VB","VBP"},
"vasectomize":	{"VB","VBP"},
"vasectomy":	{"NN"},
"vaseline":	{"NN"},
"vases":	{"NNS"},
"vasiform":	{"JJ"},
"vasoconstriction":	{"NN"},
"vasoconstrictive":	{"NN"},
"vasoconstrictor":	{"NN","JJ"},
"vasoconstrictors":	{"NNS"},
"vasodilatation":	{"NN"},
"vasodilation":	{"NN"},
"vasodilative":	{"NN"},
"vasodilator":	{"NN","JJ"},
"vasomotor":	{"JJ"},
"vasopressin":	{"NN"},
"vasopressor":	{"NN"},
"vasorum":	{"NN"},
"vasosection":	{"NN"},
"vasotec":	{"NN"},
"vasotomy":	{"NN"},
"vasovasostomy":	{"NN"},
"vasovesiculitis":	{"NN"},
"vassal":	{"NN"},
"vassalage":	{"NN"},
"vassals":	{"NNS"},
"vast":	{"JJ"},
"vaster":	{"JJR"},
"vastest":	{"JJS"},
"vastly":	{"RB"},
"vastness":	{"NN"},
"vat":	{"NN","VB","VBP"},
"vatic":	{"JJ"},
"vatical":	{"JJ"},
"vaticinate":	{"VB"},
"vaticination":	{"NN"},
"vaticinator":	{"NN"},
"vats":	{"NNS","VBZ"},
"vatted":	{"VBD","VBN"},
"vatting":	{"VBG"},
"vaudeville":	{"NN"},
"vaudevillian":	{"NN"},
"vault":	{"NN","VB","VBP"},
"vaulted":	{"JJ","VBD","VBN"},
"vaulter":	{"NN"},
"vaulting":	{"JJ","NN","VBG"},
"vaults":	{"NNS","VBZ"},
"vaunt":	{"VB","VBP","NN"},
"vaunted":	{"JJ","VBN","VBD"},
"vaunter":	{"NN"},
"vauntery":	{"NN"},
"vaunting":	{"VBG"},
"vauntingly":	{"RB"},
"vaunts":	{"VBZ"},
"vcrs":	{"NNS"},
"veal":	{"NN"},
"veau":	{"NN"},
"vector":	{"NN","VB","VBP"},
"vectored":	{"VBD","VBN"},
"vectorial":	{"JJ"},
"vectorially":	{"RB"},
"vectoring":	{"VBG"},
"vectors":	{"NNS","VBZ"},
"vedalia":	{"NN"},
"veer":	{"VB","VBP"},
"veered":	{"VBD","VBN"},
"veeries":	{"NNS"},
"veering":	{"VBG"},
"veers":	{"VBZ"},
"veery":	{"NN"},
"veg":	{"NN","NNS","VB","VBP"},
"vegan":	{"NN","JJ"},
"vegans":	{"NNS"},
"vegetable":	{"NN","JJ"},
"vegetables":	{"NNS"},
"vegetal":	{"JJ"},
"vegetarian":	{"NN","JJ"},
"vegetarianism":	{"NN"},
"vegetarians":	{"NNS"},
"vegetate":	{"VB","VBP"},
"vegetated":	{"VBD","VBN"},
"vegetates":	{"VBZ"},
"vegetating":	{"VBG"},
"vegetation":	{"NN"},
"vegetational":	{"JJ"},
"vegetative":	{"JJ"},
"vegetive":	{"JJ"},
"vegged":	{"VBD","VBN"},
"vegges":	{"VBZ"},
"veggie":	{"NN","JJ"},
"veggies":	{"NNS"},
"vegging":	{"VBG"},
"vehemence":	{"NN"},
"vehement":	{"JJ"},
"vehemently":	{"RB"},
"vehicle":	{"NN"},
"vehicle-borne":	{"JJ"},
"vehicles":	{"NNS"},
"vehicular":	{"JJ"},
"veil":	{"NN","VB","VBP"},
"veiled":	{"JJ","VBD","VBN"},
"veiling":	{"VBG"},
"veils":	{"NNS","VBZ"},
"vein":	{"NN","VB","VBP"},
"veinal":	{"JJ"},
"veined":	{"JJ","VBD","VBN"},
"veining":	{"NN","VBG"},
"veinless":	{"JJ"},
"veinlike":	{"JJ"},
"veins":	{"NNS","VBZ"},
"veiny":	{"JJ"},
"vela":	{"NNS"},
"velar":	{"JJ"},
"velban":	{"NN"},
"veld":	{"NN"},
"veldt":	{"NN"},
"velleity":	{"NN"},
"vellicate":	{"VB","VBP"},
"vellicated":	{"VBD","VBN"},
"vellicates":	{"VBZ"},
"vellicating":	{"VBG"},
"vellication":	{"NN"},
"vellicative":	{"NN"},
"vellum":	{"NN"},
"velocipede":	{"NN"},
"velociraptor":	{"NN"},
"velocities":	{"NNS"},
"velocity":	{"NN"},
"velodrome":	{"NN"},
"velour":	{"NN"},
"velours":	{"NNS"},
"veloute":	{"NN"},
"velum":	{"NN"},
"velvet":	{"NN","JJ"},
"velvet-like":	{"JJ"},
"velveteen":	{"NN"},
"velvetleaf":	{"NN"},
"velvetweed":	{"NN"},
"velvety":	{"JJ"},
"vena":	{"NN"},
"venal":	{"JJ"},
"venality":	{"NN"},
"venally":	{"RB"},
"venation":	{"NN"},
"vend":	{"VB","VBP"},
"vendable":	{"JJ"},
"vended":	{"VBD","VBN"},
"vendee":	{"NN"},
"vendemiaire":	{"NN"},
"vender":	{"NN"},
"vendetta":	{"NN"},
"vendettas":	{"NNS"},
"vendible":	{"JJ"},
"vending":	{"NN","VBG"},
"vendition":	{"NN"},
"vendor":	{"NN"},
"vendors":	{"NNS"},
"vends":	{"VBZ"},
"vendue":	{"NN"},
"veneer":	{"NN","VB","VBP"},
"veneered":	{"VBD","VBN"},
"veneering":	{"VBG"},
"veneers":	{"NNS","VBZ"},
"venerability":	{"NN"},
"venerable":	{"JJ"},
"venerableness":	{"NN"},
"venerate":	{"VB","VBP"},
"venerated":	{"VBD","VBN","JJ"},
"venerates":	{"VBZ"},
"venerating":	{"VBG"},
"veneration":	{"NN"},
"venerator":	{"NN"},
"venereal":	{"JJ"},
"venereally":	{"RB"},
"veneridae":	{"NN"},
"venesect":	{"VB","VBP"},
"venesection":	{"NN"},
"venezia":	{"NN"},
"vengeance":	{"NN"},
"vengeful":	{"JJ"},
"vengefully":	{"RB"},
"vengefulness":	{"NN"},
"venial":	{"JJ"},
"venipuncture":	{"NN"},
"venire":	{"NN"},
"venison":	{"NN"},
"venogram":	{"NN"},
"venography":	{"NN"},
"venom":	{"NN","VB","VBP"},
"venomed":	{"VBD","VBN"},
"venomless":	{"JJ"},
"venomous":	{"JJ"},
"venomously":	{"RB"},
"venomousness":	{"NN"},
"venoms":	{"NNS","VBZ"},
"venose":	{"JJ"},
"venous":	{"JJ"},
"vent":	{"NN","VB","VBP"},
"ventail":	{"NN"},
"vented":	{"VBD","VBN"},
"venter":	{"NN"},
"venthole":	{"NN"},
"ventilate":	{"VB","VBP"},
"ventilated":	{"VBD","VBN"},
"ventilates":	{"VBZ"},
"ventilating":	{"VBG"},
"ventilation":	{"NN"},
"ventilator":	{"NN"},
"ventilators":	{"NNS"},
"ventilatory":	{"JJ"},
"venting":	{"VBG"},
"ventolin":	{"NN"},
"ventose":	{"JJ"},
"ventral":	{"JJ"},
"ventrally":	{"RB"},
"ventricle":	{"NN"},
"ventricles":	{"NNS"},
"ventricose":	{"JJ"},
"ventricous":	{"JJ"},
"ventricular":	{"JJ"},
"ventriculi":	{"NNS"},
"ventriculus":	{"NN"},
"ventriloquism":	{"NN"},
"ventriloquist":	{"NN"},
"ventriloquists":	{"NNS"},
"ventriloquy":	{"NN"},
"vents":	{"NNS","VBZ"},
"venture":	{"NN","VBP","VB"},
"ventured":	{"VBD","VBN"},
"venturer":	{"NN"},
"venturers":	{"NNS"},
"ventures":	{"NNS","VBZ"},
"venturesome":	{"JJ"},
"venturesomeness":	{"NN"},
"venturing":	{"VBG"},
"venturous":	{"JJ"},
"venue":	{"NN"},
"venues":	{"NNS"},
"venula":	{"NN"},
"venular":	{"JJ"},
"venule":	{"NN"},
"venulose":	{"JJ"},
"vera":	{"NN"},
"veracious":	{"JJ"},
"veraciously":	{"RB"},
"veracity":	{"NN"},
"veranda":	{"NN"},
"verandah":	{"NN"},
"verandas":	{"NNS"},
"verapamil":	{"NN"},
"veratrum":	{"NN"},
"verb":	{"NN"},
"verbal":	{"JJ","NN"},
"verbalisation":	{"NN"},
"verbalisations":	{"NNS"},
"verbalise":	{"VB","VBP"},
"verbalised":	{"VBD","VBN"},
"verbaliser":	{"NN"},
"verbalises":	{"VBZ"},
"verbalising":	{"VBG"},
"verbalism":	{"NN"},
"verbalization":	{"NN"},
"verbalizations":	{"NNS"},
"verbalize":	{"VB","VBP"},
"verbalized":	{"VBD","VBN"},
"verbalizer":	{"NN"},
"verbalizes":	{"VBZ"},
"verbalizing":	{"VBG"},
"verbally":	{"RB"},
"verbascum":	{"NN"},
"verbatim":	{"JJ","RB"},
"verbena":	{"NN"},
"verbenaceae":	{"NN"},
"verbenas":	{"NNS"},
"verbesina":	{"NN"},
"verbiage":	{"NN"},
"verbified":	{"VBD","VBN"},
"verbifies":	{"VBZ"},
"verbify":	{"VB","VBP"},
"verbifying":	{"VBG"},
"verbose":	{"JJ"},
"verbosely":	{"RB"},
"verboseness":	{"NN"},
"verbosity":	{"NN"},
"verboten":	{"JJ"},
"verbs":	{"NNS"},
"verdancy":	{"NN"},
"verdant":	{"JJ"},
"verdantly":	{"RB"},
"verdict":	{"NN"},
"verdicts":	{"NNS"},
"verdigris":	{"NN"},
"verdin":	{"NN"},
"verdins":	{"NNS"},
"verdolaga":	{"NN"},
"verdolagas":	{"NNS"},
"verdure":	{"NN"},
"verge":	{"NN","VBP","VB"},
"verged":	{"VBD","VBN"},
"verger":	{"NN"},
"vergers":	{"NNS"},
"verges":	{"NNS","VBZ"},
"verging":	{"VBG"},
"veridical":	{"JJ"},
"verifiable":	{"JJ"},
"verifiably":	{"RB"},
"verification":	{"NN"},
"verificational":	{"JJ"},
"verificatory":	{"JJ"},
"verified":	{"JJ","VBD","VBN"},
"verifier":	{"NN"},
"verifiers":	{"NNS"},
"verifies":	{"VBZ"},
"verify":	{"VB","VBP"},
"verifying":	{"VBG"},
"verily":	{"RB"},
"verisimilar":	{"JJ"},
"verisimilarly":	{"RB"},
"verisimilitude":	{"NN"},
"veritable":	{"JJ"},
"verities":	{"NNS"},
"verity":	{"NN"},
"vermeil":	{"NN","JJ"},
"vermicelli":	{"NN"},
"vermicide":	{"NN"},
"vermicular":	{"JJ"},
"vermiculate":	{"VB","VBP","JJ"},
"vermiculated":	{"VBD","VBN"},
"vermiculates":	{"VBZ"},
"vermiculating":	{"VBG"},
"vermiculation":	{"NN"},
"vermiculite":	{"NN"},
"vermiform":	{"JJ"},
"vermifuge":	{"NN"},
"vermilion":	{"NN","JJ"},
"vermillion":	{"NN"},
"vermin":	{"NNS"},
"verminous":	{"JJ"},
"vermis":	{"NN"},
"vermouth":	{"NN"},
"vermouths":	{"NNS"},
"vernacular":	{"NN","JJ"},
"vernaculars":	{"NNS"},
"vernal":	{"JJ"},
"vernation":	{"NN"},
"vernier":	{"NN"},
"vernix":	{"NN"},
"vernonia":	{"NN"},
"veronica":	{"NN"},
"verpa":	{"NN"},
"verruca":	{"NN"},
"verrucae":	{"NNS"},
"verrucas":	{"NNS"},
"verrucose":	{"JJ"},
"versa":	{"RB","JJ"},
"versant":	{"NN","JJ"},
"versatile":	{"JJ"},
"versatility":	{"NN"},
"verse":	{"NN","VB","VBP"},
"versed":	{"VBD","VBN","JJ"},
"verses":	{"VBZ","NNS"},
"versicle":	{"NN"},
"versification":	{"NN"},
"versified":	{"VBD","VBN"},
"versifier":	{"NN"},
"versifiers":	{"NNS"},
"versifies":	{"VBZ"},
"versify":	{"VB","VBP"},
"versifying":	{"VBG"},
"versing":	{"VBG"},
"version":	{"NN"},
"versions":	{"NNS"},
"verso":	{"NN"},
"versos":	{"NNS"},
"verst":	{"NN"},
"versus":	{"IN"},
"vertebra":	{"NN"},
"vertebrae":	{"NNS"},
"vertebral":	{"JJ"},
"vertebrata":	{"NN"},
"vertebrate":	{"NN","JJ"},
"vertebrates":	{"NNS"},
"vertebrospinal":	{"NN"},
"vertex":	{"NN"},
"vertexes":	{"NNS"},
"vertical":	{"JJ","NN"},
"verticality":	{"NN"},
"vertically":	{"RB"},
"verticalness":	{"NN"},
"verticals":	{"NNS"},
"vertices":	{"NNS"},
"verticil":	{"NN"},
"verticillate":	{"JJ"},
"verticillated":	{"JJ"},
"verticilliosis":	{"NN"},
"verticillium":	{"NN"},
"vertiginous":	{"JJ"},
"vertigo":	{"NN"},
"vertu":	{"NN"},
"vervain":	{"NN"},
"verve":	{"NN"},
"vervet":	{"NN"},
"very":	{"RB","JJ"},
"vesica":	{"NN"},
"vesical":	{"JJ"},
"vesicant":	{"JJ","NN"},
"vesicants":	{"NNS"},
"vesicaria":	{"NN"},
"vesicate":	{"VB","VBP"},
"vesication":	{"NN"},
"vesicatories":	{"NNS"},
"vesicatory":	{"JJ","NN"},
"vesicle":	{"NN"},
"vesicopapule":	{"NN"},
"vesicular":	{"JJ"},
"vesiculate":	{"JJ","VB","VBP"},
"vesiculated":	{"VBD","VBN"},
"vesiculates":	{"VBZ"},
"vesiculating":	{"VBG"},
"vesiculation":	{"NN"},
"vesiculitis":	{"NN"},
"vesiculovirus":	{"NN"},
"vespa":	{"NN"},
"vesper":	{"NN"},
"vespers":	{"NNS","NN"},
"vespertilio":	{"NN"},
"vespertilionid":	{"NN"},
"vespertilionidae":	{"NN"},
"vespid":	{"NN","JJ"},
"vespidae":	{"NN"},
"vespula":	{"NN"},
"vessel":	{"NN"},
"vessels":	{"NNS"},
"vest":	{"NN","VB","VBP"},
"vesta":	{"NN"},
"vestal":	{"JJ","NN"},
"vestals":	{"NNS"},
"vested":	{"JJ","VBD","VBN"},
"vestiary":	{"NN"},
"vestibular":	{"JJ"},
"vestibule":	{"NN"},
"vestibules":	{"NNS"},
"vestige":	{"NN"},
"vestiges":	{"NNS"},
"vestigial":	{"JJ"},
"vesting":	{"VBG"},
"vestiture":	{"NN"},
"vestment":	{"NN"},
"vestmental":	{"JJ"},
"vestmented":	{"JJ"},
"vestments":	{"NNS"},
"vestries":	{"NNS"},
"vestry":	{"NN"},
"vestryman":	{"NN"},
"vestrywoman":	{"NN"},
"vests":	{"VBZ","NNS"},
"vesture":	{"NN","VB","VBP"},
"vestured":	{"VBD","VBN"},
"vestures":	{"VBZ","NNS"},
"vesturing":	{"VBG"},
"vesuvian":	{"NN"},
"vesuvianite":	{"NN"},
"vet":	{"NN","VB","VBP"},
"vetch":	{"NN"},
"vetches":	{"NNS"},
"vetchling":	{"NN"},
"vetchworm":	{"NN"},
"veteran":	{"NN","JJ"},
"veterans":	{"NNS"},
"veterinarian":	{"NN"},
"veterinarians":	{"NNS"},
"veterinaries":	{"NNS"},
"veterinary":	{"JJ","NN"},
"veto":	{"VB","VBP","NN"},
"veto-proof":	{"JJ"},
"vetoed":	{"VBD","VBN"},
"vetoes":	{"NNS","VBZ"},
"vetoing":	{"VBG"},
"vets":	{"NNS","VBZ"},
"vetted":	{"VBD","VBN"},
"vetting":	{"VBG"},
"vex":	{"VB","VBP"},
"vexation":	{"NN"},
"vexatious":	{"JJ"},
"vexatiously":	{"RB"},
"vexed":	{"JJ","VBN","VBD"},
"vexer":	{"NN"},
"vexes":	{"VBZ","NNS"},
"vexing":	{"JJ","VBG"},
"vexingly":	{"RB"},
"vi":	{"NN"},
"via":	{"IN"},
"viability":	{"NN"},
"viable":	{"JJ"},
"viaduct":	{"NN"},
"viaducts":	{"NNS"},
"vial":	{"NN","VB","VBP"},
"vialed":	{"VBD","VBN"},
"vialing":	{"VBG"},
"vialled":	{"VBD","VBN"},
"vialling":	{"VBG"},
"vials":	{"NNS","VBZ"},
"viand":	{"NN"},
"viands":	{"NNS"},
"viatical":	{"JJ"},
"viatication":	{"NN"},
"vibe":	{"NN"},
"vibes":	{"NNS"},
"vibist":	{"NN"},
"vibraharp":	{"NN"},
"vibramycin":	{"NN"},
"vibrancy":	{"NN"},
"vibrant":	{"JJ"},
"vibrantly":	{"RB"},
"vibraphone":	{"NN"},
"vibraphones":	{"NNS"},
"vibraphonist":	{"NN"},
"vibrate":	{"VB","VBP"},
"vibrated":	{"VBD","VBN"},
"vibrates":	{"VBZ"},
"vibrating":	{"VBG"},
"vibration":	{"NN"},
"vibrational":	{"JJ"},
"vibrations":	{"NNS"},
"vibrato":	{"NN"},
"vibrator":	{"NN"},
"vibrators":	{"NNS"},
"vibratory":	{"JJ"},
"vibratos":	{"NNS"},
"vibrio":	{"NN"},
"vibrion":	{"NN"},
"vibrionic":	{"JJ"},
"vibrissa":	{"NN"},
"vibrometer":	{"NN"},
"viburnum":	{"NN"},
"vic":	{"NN"},
"vicar":	{"NN"},
"vicarage":	{"NN"},
"vicarages":	{"NNS"},
"vicarial":	{"JJ"},
"vicariate":	{"NN"},
"vicarious":	{"JJ"},
"vicariously":	{"RB"},
"vicars":	{"NNS"},
"vicarship":	{"NN"},
"vice":	{"NN","VB","VBP","IN"},
"vice-chancellor":	{"NN"},
"vice-chancellors":	{"NNS"},
"vice-presidency":	{"NN"},
"vice-president":	{"NN"},
"vice-presidential":	{"JJ"},
"vice-presidents":	{"NNS"},
"vice-regent":	{"NN"},
"viced":	{"VBD","VBN"},
"vicegerent":	{"NN"},
"vicelike":	{"JJ"},
"vicenary":	{"JJ"},
"vicennial":	{"JJ"},
"viceregal":	{"JJ"},
"vicereine":	{"NN"},
"viceroy":	{"NN"},
"viceroyalty":	{"NN"},
"viceroys":	{"NNS"},
"viceroyship":	{"NN"},
"vices":	{"NNS","VBZ"},
"vichyssoise":	{"NN"},
"vicia":	{"NN"},
"vicinal":	{"JJ"},
"vicing":	{"VBG"},
"vicinity":	{"NN"},
"vicious":	{"JJ"},
"viciously":	{"RB"},
"viciousness":	{"NN"},
"vicissitude":	{"NN"},
"vicissitudes":	{"NNS"},
"victim":	{"NN"},
"victimisation":	{"NN"},
"victimise":	{"VB","VBP"},
"victimised":	{"VBD","VBN"},
"victimiser":	{"NN"},
"victimises":	{"VBZ"},
"victimising":	{"VBG"},
"victimization":	{"NN"},
"victimize":	{"VB","VBP"},
"victimized":	{"VBD","VBN"},
"victimizer":	{"NN"},
"victimizes":	{"VBZ"},
"victimizing":	{"VBG"},
"victimless":	{"JJ"},
"victims":	{"NNS"},
"victor":	{"NN"},
"victories":	{"NNS"},
"victorious":	{"JJ"},
"victoriously":	{"RB"},
"victors":	{"NNS"},
"victory":	{"NN"},
"victrola":	{"NN"},
"victual":	{"VB","VBP","NN"},
"victualed":	{"VBD","VBN"},
"victualer":	{"NN"},
"victualing":	{"VBG"},
"victualled":	{"VBD","VBN"},
"victualler":	{"NN"},
"victualling":	{"VBG"},
"victuals":	{"NNS","VBZ"},
"vicugna":	{"NN"},
"vicuna":	{"NN"},
"vide":	{"VB","VBP"},
"vided":	{"VBD","VBN"},
"videlicet":	{"RB"},
"video":	{"NN","VB","VBP","JJ"},
"video-conferencing":	{"NN"},
"videocam":	{"NN"},
"videocams":	{"NNS"},
"videocassette":	{"NN"},
"videocassettes":	{"NNS"},
"videoconference":	{"NN","VB","VBP"},
"videoconferenced":	{"VBD","VBN"},
"videoconferences":	{"NNS","VBZ"},
"videoconferencing":	{"NN","VBG"},
"videodisc":	{"NN"},
"videodiscs":	{"NNS"},
"videodisk":	{"NN"},
"videodisks":	{"NNS"},
"videoed":	{"VBD","VBN"},
"videogame":	{"NN"},
"videogames":	{"NNS"},
"videoing":	{"VBG"},
"videomaker":	{"NN"},
"videomakers":	{"NNS"},
"videos":	{"NNS","VBZ"},
"videotape":	{"NN","VB","VBP"},
"videotaped":	{"VBD","VBN"},
"videotapes":	{"NNS","VBZ"},
"videotaping":	{"VBG"},
"videotex":	{"NN"},
"videotext":	{"NN"},
"vides":	{"VBZ"},
"viding":	{"VBG"},
"vidua":	{"NN"},
"vie":	{"VB","VBP"},
"vied":	{"VBD","VBN"},
"vielleicht":	{"FW"},
"vies":	{"VBZ","NNS"},
"view":	{"NN","VB","VBP"},
"viewable":	{"JJ"},
"viewed":	{"VBN","VBD"},
"viewer":	{"NN"},
"viewers":	{"NNS"},
"viewership":	{"NN"},
"viewfinder":	{"NN"},
"viewfinders":	{"NNS"},
"viewgraph":	{"NN"},
"viewing":	{"VBG","NN"},
"viewings":	{"NNS"},
"viewless":	{"JJ"},
"viewpoint":	{"NN"},
"viewpoints":	{"NNS"},
"views":	{"NNS","VBZ"},
"vigesimal":	{"JJ"},
"vigil":	{"NN"},
"vigilance":	{"NN"},
"vigilant":	{"JJ"},
"vigilante":	{"NN"},
"vigilantes":	{"NNS"},
"vigilantism":	{"NN"},
"vigilantly":	{"RB"},
"vigils":	{"NNS"},
"vigna":	{"NN"},
"vignette":	{"NN"},
"vignettes":	{"NNS"},
"vigor":	{"NN"},
"vigorish":	{"NN"},
"vigorous":	{"JJ"},
"vigorously":	{"RB"},
"vigour":	{"NN"},
"vii":	{"SYM"},
"viii":	{"CD","NN"},
"vile":	{"JJ"},
"vilely":	{"RB"},
"vileness":	{"NN"},
"viler":	{"JJR"},
"vilest":	{"JJS"},
"vilification":	{"NN"},
"vilified":	{"VBD","VBN"},
"vilifier":	{"NN"},
"vilifies":	{"VBZ"},
"vilify":	{"VB","VBP"},
"vilifying":	{"VBG"},
"vilipend":	{"VB","VBP"},
"vilipender":	{"NN"},
"villa":	{"NN"},
"village":	{"NN"},
"villager":	{"NN"},
"villagers":	{"NNS"},
"villages":	{"NNS"},
"villain":	{"NN"},
"villainage":	{"NN"},
"villainess":	{"NN"},
"villainous":	{"JJ"},
"villainously":	{"RB"},
"villainousness":	{"NN"},
"villains":	{"NNS"},
"villainy":	{"NN"},
"villas":	{"NNS"},
"villein":	{"NN"},
"villeinage":	{"NN"},
"villi":	{"NNS"},
"villoma":	{"NN"},
"villus":	{"NN"},
"vim":	{"NN"},
"viminaria":	{"NN"},
"vinaceous":	{"JJ"},
"vinaigrette":	{"NN"},
"vinaigrettes":	{"NNS"},
"vinblastine":	{"NN"},
"vinca":	{"NN"},
"vincetoxicum":	{"NN"},
"vincible":	{"JJ"},
"vincristine":	{"NN"},
"vindicate":	{"VB","VBP"},
"vindicated":	{"VBD","VBN"},
"vindicates":	{"VBZ"},
"vindicating":	{"VBG"},
"vindication":	{"NN"},
"vindicator":	{"NN"},
"vindicatory":	{"JJ"},
"vindictive":	{"JJ"},
"vindictively":	{"RB"},
"vindictiveness":	{"NN"},
"vine":	{"NN"},
"vined":	{"JJ"},
"vinegar":	{"NN"},
"vinegariness":	{"NN"},
"vinegarish":	{"JJ"},
"vinegarishness":	{"NN"},
"vinegarroon":	{"NN"},
"vinegars":	{"NNS"},
"vinegary":	{"JJ"},
"vineless":	{"JJ"},
"vinelike":	{"JJ"},
"vineries":	{"NNS"},
"vinery":	{"NN"},
"vines":	{"NNS"},
"vineyard":	{"NN"},
"vineyards":	{"NNS"},
"vingt-et-un":	{"FW"},
"vinicultural":	{"JJ"},
"viniculture":	{"NN"},
"viniculturist":	{"NN"},
"vinifera":	{"NN"},
"vinification":	{"NN"},
"vinified":	{"VBD","VBN"},
"vinifies":	{"VBZ"},
"vinify":	{"VB","VBP"},
"vinifying":	{"VBG"},
"vino":	{"NN"},
"vinous":	{"JJ"},
"vintager":	{"NN"},
"vintages":	{"NNS"},
"vintner":	{"NN"},
"vintners":	{"NNS"},
"viny":	{"JJ"},
"vinyl":	{"NN"},
"vinylbenzene":	{"NN"},
"vinylite":	{"NN"},
"vinyls":	{"NNS"},
"viocin":	{"NN"},
"viol":	{"NN"},
"viola":	{"NN"},
"violable":	{"JJ"},
"violaceae":	{"NN"},
"violas":	{"NNS"},
"violate":	{"VB","VBP"},
"violated":	{"VBD","VBN"},
"violates":	{"VBZ"},
"violating":	{"VBG"},
"violation":	{"NN"},
"violations":	{"NNS"},
"violative":	{"JJ"},
"violator":	{"NN"},
"violators":	{"NNS"},
"violence":	{"NN"},
"violent":	{"JJ"},
"violently":	{"RB"},
"violet":	{"NN","JJ"},
"violets":	{"NNS"},
"violin":	{"NN"},
"violinist":	{"NN"},
"violinists":	{"NNS"},
"violins":	{"NNS"},
"violist":	{"NN"},
"violoncellist":	{"NN"},
"violoncello":	{"NN"},
"violoncellos":	{"NNS"},
"viols":	{"NNS"},
"viomycin":	{"NN"},
"viosterol":	{"NN"},
"viper":	{"NN"},
"vipera":	{"NN"},
"viperidae":	{"NN"},
"viperish":	{"JJ"},
"vipers":	{"NNS"},
"viraemia":	{"NN"},
"virago":	{"NN"},
"viragos":	{"NNS"},
"viral":	{"JJ"},
"virality":	{"NN"},
"virally":	{"RB"},
"virazole":	{"NN"},
"viremia":	{"NN"},
"vireo":	{"NN"},
"vireonidae":	{"NN"},
"virga":	{"NN"},
"virgin":	{"JJ","NN"},
"virginal":	{"JJ"},
"virginity":	{"NN"},
"virgins":	{"NNS"},
"virgule":	{"NN"},
"viricidal":	{"JJ"},
"viricide":	{"NN"},
"viridity":	{"NN"},
"virile":	{"JJ"},
"virilisation":	{"NN"},
"virilise":	{"VB","VBP"},
"virilism":	{"NN"},
"virility":	{"NN"},
"virilization":	{"NN"},
"virilize":	{"VB","VBP"},
"virino":	{"NN"},
"virion":	{"NN"},
"viroid":	{"NN"},
"virological":	{"JJ"},
"virologist":	{"NN"},
"virologists":	{"NNS"},
"virology":	{"NN"},
"virtu":	{"NN"},
"virtual":	{"JJ"},
"virtually":	{"RB"},
"virtue":	{"NN"},
"virtues":	{"NNS"},
"virtuosi":	{"NNS"},
"virtuosity":	{"NN"},
"virtuoso":	{"NN","JJ"},
"virtuosos":	{"NNS"},
"virtuous":	{"JJ"},
"virtuously":	{"RB"},
"virtuousness":	{"NN"},
"virucidal":	{"JJ"},
"virucide":	{"NN"},
"virulence":	{"NN"},
"virulency":	{"NN"},
"virulent":	{"JJ"},
"virulently":	{"RB"},
"virus":	{"NN"},
"viruses":	{"NNS"},
"virusoid":	{"NN"},
"vis":	{"NN","FW"},
"vis-a-vis":	{"IN","FW"},
"visa":	{"NN","VB","VBP"},
"visaed":	{"VBD","VBN"},
"visage":	{"NN"},
"visages":	{"NNS"},
"visaing":	{"VBG"},
"visas":	{"VBZ","NNS"},
"viscaceae":	{"NN"},
"viscacha":	{"NN"},
"viscera":	{"NNS"},
"visceral":	{"JJ"},
"viscerally":	{"RB"},
"viscid":	{"JJ"},
"viscidity":	{"NN"},
"viscidly":	{"RB"},
"viscidness":	{"NN"},
"viscoelastic":	{"JJ"},
"viscoelasticity":	{"NN"},
"viscometer":	{"NN"},
"viscometric":	{"JJ"},
"viscometry":	{"NN"},
"viscose":	{"NN","JJ"},
"viscosimeter":	{"NN"},
"viscosimetric":	{"JJ"},
"viscosimetry":	{"NN"},
"viscosity":	{"NN"},
"viscount":	{"NN"},
"viscountcy":	{"NN"},
"viscountess":	{"NN"},
"viscounty":	{"NN"},
"viscous":	{"JJ"},
"viscousness":	{"NN"},
"viscum":	{"NN"},
"viscus":	{"NN"},
"vise":	{"NN","VB","VBP","IN"},
"vised":	{"VBD","VBN"},
"viselike":	{"JJ"},
"vises":	{"NNS","VBZ"},
"visibility":	{"NN"},
"visible":	{"JJ"},
"visibleness":	{"NN"},
"visibly":	{"RB"},
"vising":	{"VBG"},
"vision":	{"NN","VB","VBP"},
"visionaries":	{"NNS"},
"visionary":	{"JJ","NN"},
"visioned":	{"VBD","VBN"},
"visioning":	{"VBG"},
"visions":	{"NNS","VBZ"},
"visit":	{"NN","VB","VBP"},
"visitant":	{"NN"},
"visitation":	{"NN"},
"visitations":	{"NNS"},
"visited":	{"VBD","VBN"},
"visiting":	{"VBG","JJ"},
"visitor":	{"NN"},
"visitors":	{"NNS"},
"visits":	{"NNS","VBZ"},
"visor":	{"NN","VB","VBP"},
"visored":	{"VBD","VBN"},
"visoring":	{"VBG"},
"visors":	{"NNS","VBZ"},
"vista":	{"NN"},
"vistas":	{"NNS"},
"visual":	{"JJ","NN"},
"visualisation":	{"NN"},
"visualise":	{"VB","VBP"},
"visualised":	{"VBD","VBN"},
"visualiser":	{"NN"},
"visualises":	{"VBZ"},
"visualising":	{"VBG"},
"visualization":	{"NN"},
"visualizations":	{"NNS"},
"visualize":	{"VB","VBP"},
"visualized":	{"VBD","VBN"},
"visualizer":	{"NN"},
"visualizes":	{"VBZ"},
"visualizing":	{"VBG"},
"visually":	{"RB"},
"visuals":	{"NNS"},
"visuospatial":	{"JJ"},
"vita":	{"NN"},
"vitaceae":	{"NN"},
"vitae":	{"NNS"},
"vital":	{"JJ"},
"vitalisation":	{"NN"},
"vitalise":	{"VB","VBP"},
"vitalised":	{"VBD","VBN"},
"vitaliser":	{"NN"},
"vitalises":	{"VBZ"},
"vitalising":	{"VBG"},
"vitalism":	{"NN"},
"vitalist":	{"NN"},
"vitality":	{"NN"},
"vitalization":	{"NN"},
"vitalize":	{"VB","VBP"},
"vitalized":	{"VBD","VBN"},
"vitalizer":	{"NN"},
"vitalizes":	{"VBZ"},
"vitalizing":	{"VBG"},
"vitally":	{"RB"},
"vitalness":	{"NN"},
"vitals":	{"NNS"},
"vitamin":	{"NN"},
"vitamin-enriched":	{"JJ"},
"vitamin-rich":	{"JJ"},
"vitaminise":	{"VB","VBP"},
"vitaminised":	{"VBD","VBN"},
"vitaminises":	{"VBZ"},
"vitaminising":	{"VBG"},
"vitaminize":	{"VB","VBP"},
"vitaminized":	{"VBD","VBN"},
"vitaminizes":	{"VBZ"},
"vitaminizing":	{"VBG"},
"vitamins":	{"NNS"},
"vitelli":	{"NNS"},
"vitellus":	{"NN"},
"vitelluses":	{"NNS"},
"vitiate":	{"VB","VBP"},
"vitiated":	{"VBD","VBN"},
"vitiates":	{"VBZ"},
"vitiating":	{"VBG"},
"vitiation":	{"NN"},
"viticulture":	{"NN"},
"viticulturist":	{"NN"},
"vitidaceae":	{"NN"},
"vitiliginous":	{"JJ"},
"vitiligo":	{"NN"},
"vitis":	{"NN"},
"vitrectomy":	{"NN"},
"vitreous":	{"JJ"},
"vitrifaction":	{"NN"},
"vitrification":	{"NN"},
"vitrified":	{"VBD","VBN"},
"vitrifies":	{"VBZ"},
"vitrify":	{"VB","VBP"},
"vitrifying":	{"VBG"},
"vitrine":	{"NN"},
"vitriol":	{"NN","VB","VBP"},
"vitrioled":	{"VBD","VBN"},
"vitriolic":	{"JJ"},
"vitriolically":	{"RB"},
"vitrioling":	{"VBG"},
"vitriolled":	{"VBD","VBN"},
"vitriolling":	{"VBG"},
"vitriols":	{"VBZ"},
"vitro":	{"NN","JJ","FW"},
"vittaria":	{"NN"},
"vittariaceae":	{"NN"},
"vituperate":	{"VB","VBP"},
"vituperated":	{"VBD","VBN"},
"vituperates":	{"VBZ"},
"vituperating":	{"VBG"},
"vituperation":	{"NN"},
"vituperative":	{"JJ"},
"viva":	{"NN","UH"},
"viva-voce":	{"JJ"},
"vivace":	{"JJ","RB"},
"vivacious":	{"JJ"},
"vivaciously":	{"RB"},
"vivaciousness":	{"NN"},
"vivacity":	{"NN"},
"vivaria":	{"NNS"},
"vivarium":	{"NN"},
"vivariums":	{"NNS"},
"vivas":	{"NNS"},
"viverra":	{"NN"},
"viverricula":	{"NN"},
"viverridae":	{"NN"},
"viverrinae":	{"NN"},
"viverrine":	{"JJ","NN"},
"vivid":	{"JJ"},
"vividly":	{"RB"},
"vividness":	{"NN"},
"vivification":	{"NN"},
"vivified":	{"VBD","VBN"},
"vivifies":	{"VBZ"},
"vivify":	{"VB","VBP"},
"vivifying":	{"VBG"},
"viviparous":	{"JJ"},
"vivisect":	{"VB","VBP"},
"vivisection":	{"NN"},
"vivisectionist":	{"NN"},
"vivisectionists":	{"NNS"},
"vivisector":	{"NN"},
"vivo":	{"NN","JJ"},
"vivre":	{"NN","FW"},
"vixen":	{"NN"},
"vixenish":	{"JJ"},
"vixens":	{"NNS"},
"viz.":	{"RB"},
"vizier":	{"NN"},
"viziership":	{"NN"},
"vizor":	{"NN","VB","VBP"},
"vizored":	{"VBD","VBN"},
"vizoring":	{"VBG"},
"vizors":	{"NNS","VBZ"},
"vizsla":	{"NN"},
"vlogger":	{"NN"},
"vloggers":	{"NNS"},
"vocable":	{"NN"},
"vocabularies":	{"NNS"},
"vocabulary":	{"NN"},
"vocal":	{"JJ","NN"},
"vocalic":	{"JJ"},
"vocalisation":	{"NN"},
"vocalise":	{"VB","VBP"},
"vocaliser":	{"NN"},
"vocalism":	{"NN"},
"vocalist":	{"NN"},
"vocalists":	{"NNS"},
"vocalization":	{"NN"},
"vocalize":	{"VB","VBP"},
"vocalized":	{"VBD","VBN"},
"vocalizer":	{"NN"},
"vocalizes":	{"VBZ"},
"vocalizing":	{"VBG","NN"},
"vocally":	{"RB"},
"vocals":	{"NNS"},
"vocation":	{"NN"},
"vocational":	{"JJ"},
"vocationally":	{"RB"},
"vocations":	{"NNS"},
"vocative":	{"NN","JJ"},
"vocatives":	{"NNS"},
"voce":	{"NN"},
"vociferate":	{"VB","VBP"},
"vociferation":	{"NN"},
"vociferator":	{"NN"},
"vociferous":	{"JJ"},
"vociferously":	{"RB"},
"vociferousness":	{"NN"},
"vodka":	{"NN"},
"vodkas":	{"NNS"},
"vodoun":	{"NN","VB","VBP","JJ"},
"vogue":	{"NN"},
"voguish":	{"JJ"},
"voice":	{"NN","VB","VBP"},
"voice-over":	{"NN"},
"voice-overs":	{"NNS"},
"voiced":	{"JJ","VBD","VBN"},
"voiceless":	{"JJ"},
"voicelessness":	{"NN"},
"voicemail":	{"NN"},
"voicemails":	{"NNS"},
"voiceover":	{"NN"},
"voiceovers":	{"NNS"},
"voiceprint":	{"NN"},
"voicer":	{"NN"},
"voices":	{"NNS","VBZ"},
"voicing":	{"VBG","NN"},
"void":	{"NN","JJ","VB","VBP"},
"voidable":	{"JJ"},
"voidance":	{"NN"},
"voided":	{"VBD","VBN","JJ"},
"voider":	{"NN"},
"voiding":	{"VBG","NN"},
"voids":	{"NNS","VBZ"},
"voile":	{"NN"},
"voir":	{"NN","FW"},
"vol-au-vent":	{"NN"},
"volaille":	{"NN"},
"volant":	{"JJ"},
"volar":	{"JJ"},
"volaries":	{"NNS"},
"volary":	{"NN"},
"volatile":	{"JJ"},
"volatilisable":	{"JJ"},
"volatilisation":	{"NN"},
"volatilise":	{"VB","VBP"},
"volatilised":	{"VBD","VBN"},
"volatility":	{"NN"},
"volatilizable":	{"JJ"},
"volatilization":	{"NN"},
"volatilize":	{"VB","VBP"},
"volatilized":	{"VBD","VBN"},
"volcanic":	{"JJ"},
"volcanically":	{"RB"},
"volcanism":	{"NN"},
"volcano":	{"NN"},
"volcanoes":	{"NNS"},
"volcanology":	{"NN"},
"volcanos":	{"NNS"},
"vole":	{"NN"},
"volens":	{"RB","FW"},
"voles":	{"NNS"},
"voleur":	{"FW"},
"volition":	{"NN"},
"volitional":	{"JJ"},
"volitionally":	{"RB"},
"volksgeist":	{"NN"},
"volley":	{"NN","VB","VBP"},
"volleyball":	{"NN"},
"volleyed":	{"VBD","VBN"},
"volleying":	{"VBG"},
"volleys":	{"NNS","VBZ"},
"volt":	{"NN"},
"volt-ampere":	{"NN"},
"volta":	{"NN"},
"voltage":	{"NN"},
"voltages":	{"NNS"},
"voltaic":	{"JJ"},
"volte-face":	{"NN"},
"voltmeter":	{"NN"},
"voltmeters":	{"NNS"},
"volts":	{"NNS"},
"volubility":	{"NN"},
"voluble":	{"JJ"},
"volubly":	{"RB"},
"volume":	{"NN"},
"volumed":	{"JJ"},
"volumes":	{"NNS"},
"volumeter":	{"NN"},
"volumetric":	{"JJ"},
"volumetrical":	{"JJ"},
"volumetrically":	{"RB"},
"voluminosity":	{"NN"},
"voluminous":	{"JJ"},
"voluminously":	{"RB"},
"voluminousness":	{"NN"},
"volumise":	{"VB","VBP"},
"volumised":	{"VBD","VBN"},
"volumises":	{"VBZ"},
"volumising":	{"VBG"},
"volumize":	{"VB","VBP"},
"volumized":	{"VBD","VBN"},
"volumizer":	{"NN"},
"volumizes":	{"VBZ"},
"volumizing":	{"VBG"},
"voluntaries":	{"NNS"},
"voluntarily":	{"RB"},
"voluntarism":	{"NN"},
"voluntary":	{"JJ","NN"},
"volunteer":	{"NN","VB","VBP"},
"volunteered":	{"VBD","VBN"},
"volunteering":	{"VBG"},
"volunteerism":	{"NN"},
"volunteers":	{"NNS","VBZ"},
"voluptuaries":	{"NNS"},
"voluptuary":	{"NN"},
"voluptuous":	{"JJ"},
"voluptuously":	{"RB"},
"voluptuousness":	{"NN"},
"volute":	{"NN"},
"voluted":	{"JJ"},
"volution":	{"NN"},
"volva":	{"NN"},
"volvaria":	{"NN"},
"volvariaceae":	{"NN"},
"volvariella":	{"NN"},
"volvocaceae":	{"NN"},
"volvocales":	{"NNS"},
"volvox":	{"NN"},
"volvulus":	{"NN"},
"vombatidae":	{"NN"},
"vomer":	{"NN"},
"vomica":	{"NN"},
"vomit":	{"VB","VBP","NN"},
"vomited":	{"VBD","VBN"},
"vomiter":	{"NN"},
"vomiting":	{"NN","JJ","VBG"},
"vomitive":	{"NN","JJ"},
"vomitories":	{"NNS"},
"vomitory":	{"NN","JJ"},
"vomits":	{"VBZ"},
"vomitus":	{"NN"},
"von":	{"IN"},
"voodoo":	{"NN","VB","VBP"},
"voodooed":	{"VBD","VBN"},
"voodooing":	{"VBG"},
"voodooism":	{"NN"},
"voodoos":	{"VBZ"},
"voracious":	{"JJ"},
"voraciously":	{"RB"},
"voraciousness":	{"NN"},
"voracity":	{"NN"},
"vortex":	{"NN"},
"vortexes":	{"NNS"},
"vortical":	{"JJ"},
"vortically":	{"RB"},
"vorticella":	{"NN"},
"vortices":	{"NNS"},
"vos":	{"NN","FW"},
"votaries":	{"NNS"},
"votary":	{"NN"},
"vote":	{"NN","VB","VBP"},
"vote-getter":	{"NN"},
"vote-getters":	{"NNS"},
"voted":	{"VBD","VBN"},
"voteless":	{"JJ"},
"voter":	{"NN"},
"voters":	{"NNS"},
"votes":	{"NNS","VBZ"},
"voting":	{"NN","VBG"},
"votive":	{"JJ"},
"votyak":	{"NN"},
"vouch":	{"VB","VBP"},
"vouched":	{"VBD","VBN"},
"vouchee":	{"NN"},
"voucher":	{"NN"},
"voucherise":	{"VB","VBP"},
"voucherised":	{"VBD","VBN"},
"voucherises":	{"VBZ"},
"voucherising":	{"VBG"},
"voucherize":	{"VB","VBP"},
"voucherized":	{"VBD","VBN"},
"voucherizes":	{"VBZ"},
"voucherizing":	{"VBG"},
"vouchers":	{"NNS"},
"vouches":	{"VBZ"},
"vouching":	{"NN","VBG"},
"vouchsafe":	{"VB","VBP"},
"vouchsafed":	{"VBD","VBN"},
"vouchsafes":	{"VBZ"},
"vouchsafing":	{"VBG"},
"vouge":	{"NN"},
"vous":	{"PRP","FW"},
"voussoir":	{"NN"},
"vow":	{"NN","VB","VBP"},
"vowed":	{"VBD","VBN"},
"vowel":	{"NN"},
"vowelisation":	{"NN"},
"vowelise":	{"VB","VBP"},
"vowelization":	{"NN"},
"vowelize":	{"VB","VBP"},
"vowellike":	{"JJ"},
"vowels":	{"NNS"},
"vower":	{"NN"},
"vowing":	{"VBG"},
"vows":	{"VBZ","NNS"},
"vox":	{"NN","FW"},
"voyage":	{"NN","VB","VBP"},
"voyaged":	{"VBD","VBN"},
"voyager":	{"NN"},
"voyagers":	{"NNS"},
"voyages":	{"NNS","VBZ"},
"voyageur":	{"NN","FW"},
"voyageurs":	{"NNS","FW"},
"voyaging":	{"VBG","NN"},
"voyeur":	{"NN"},
"voyeurism":	{"NN"},
"voyeuristic":	{"JJ"},
"voyeuristical":	{"JJ"},
"voyeuristically":	{"RB"},
"voyeurs":	{"NNS"},
"vroom":	{"NN","VB","VBP","UH"},
"vs":	{"IN"},
"vs.":	{"IN"},
"vu":	{"NN","FW"},
"vulcanisation":	{"NN"},
"vulcanise":	{"VB","VBP"},
"vulcanised":	{"VBD","VBN"},
"vulcaniser":	{"NN"},
"vulcanite":	{"NN"},
"vulcanization":	{"NN"},
"vulcanize":	{"VB","VBP"},
"vulcanized":	{"VBD","VBN"},
"vulcanizer":	{"NN"},
"vulcanology":	{"NN"},
"vulgar":	{"NN"},
"vulgarian":	{"NN"},
"vulgarisation":	{"NN"},
"vulgarise":	{"VB","VBP"},
"vulgariser":	{"NN"},
"vulgarism":	{"NN"},
"vulgarities":	{"NNS"},
"vulgarity":	{"NN"},
"vulgarization":	{"NN"},
"vulgarize":	{"VB","VBP"},
"vulgarizer":	{"NN"},
"vulgarly":	{"RB"},
"vulnerabilities":	{"NN"},
"vulnerability":	{"NN"},
"vulnerable":	{"JJ"},
"vulnerably":	{"RB"},
"vulpecular":	{"JJ"},
"vulpes":	{"NNS"},
"vulpine":	{"JJ"},
"vulture":	{"NN"},
"vulture-like":	{"JJ"},
"vultures":	{"NNS"},
"vulturidae":	{"NNS"},
"vulturine":	{"JJ"},
"vulturous":	{"JJ"},
"vulva":	{"NN"},
"vulvae":	{"NNS"},
"vulval":	{"JJ"},
"vulvar":	{"JJ"},
"vulvas":	{"NNS"},
"vulvate":	{"JJ"},
"vulvectomy":	{"NN"},
"vulviform":	{"JJ"},
"vulvitis":	{"NN"},
"vulvovaginitis":	{"NN"},
"vying":	{"VBG"},
"w":	{"NN","SYM","LS"},
"w.c.":	{"NN"},
"wackier":	{"JJR"},
"wackiest":	{"JJS"},
"wackily":	{"RB"},
"wackiness":	{"NN"},
"wacko":	{"NN","JJ"},
"wackos":	{"NNS"},
"wacky":	{"JJ"},
"wad":	{"NN","VB","VBP"},
"wadable":	{"JJ"},
"wadded":	{"VBD","VBN"},
"wadding":	{"NN","VBG"},
"waddle":	{"VB","VBP","NN"},
"waddled":	{"VBD","VBN"},
"waddler":	{"NN"},
"waddlers":	{"NNS"},
"waddles":	{"VBZ","NNS"},
"waddling":	{"VBG","JJ"},
"waddly":	{"JJ"},
"wade":	{"VB","VBP","NN"},
"wadeable":	{"JJ"},
"waded":	{"VBD","VBN"},
"wader":	{"NN"},
"waders":	{"NNS"},
"wades":	{"VBZ"},
"wadi":	{"NN"},
"wading":	{"NN","VBG"},
"wadis":	{"NNS"},
"wads":	{"NNS","VBZ"},
"wafer":	{"NN","VB","VBP"},
"wafer-like":	{"JJ"},
"wafer-thin":	{"JJ"},
"wafered":	{"VBD","VBN"},
"wafering":	{"VBG"},
"wafers":	{"NNS","VBZ"},
"wafery":	{"JJ"},
"waffle":	{"NN","VB","VBP"},
"waffle-iron":	{"NN"},
"waffled":	{"VBD","VBN"},
"waffler":	{"NN"},
"waffles":	{"NNS","VBZ"},
"waffling":	{"VBG","NN","JJ"},
"waffly":	{"JJ"},
"waft":	{"VB","VBP","NN"},
"wafted":	{"VBD","VBN"},
"wafting":	{"VBG"},
"wafts":	{"VBZ","NNS"},
"wafture":	{"NN"},
"wag":	{"VB","VBP","NN"},
"wage":	{"NN","VB","VBP"},
"waged":	{"VBN","VBD","JJ"},
"wager":	{"VB","VBP","NN"},
"wagered":	{"VBD","VBN"},
"wagerer":	{"NN"},
"wagering":	{"VBG"},
"wagers":	{"VBZ","NNS"},
"wages":	{"NNS","VBZ"},
"wagged":	{"VBD","VBN"},
"waggery":	{"NN"},
"wagging":	{"VBG"},
"waggish":	{"JJ"},
"waggishly":	{"RB"},
"waggishness":	{"NN"},
"waggle":	{"VB","VBP","NN"},
"waggled":	{"VBD","VBN"},
"waggles":	{"VBZ"},
"waggling":	{"VBG"},
"waggon":	{"NN"},
"waggoner":	{"NN"},
"waggons":	{"NNS"},
"waggonwright":	{"NN"},
"waging":	{"VBG"},
"wagon":	{"NN"},
"wagon-lit":	{"NN"},
"wagon-lits":	{"NNS"},
"wagoner":	{"NN"},
"wagons":	{"NNS"},
"wagonwright":	{"NN"},
"wags":	{"NNS","VBZ"},
"wagtail":	{"NN"},
"wagtails":	{"NNS"},
"wahoo":	{"NN"},
"waif":	{"NN"},
"waifs":	{"NNS"},
"wail":	{"VB","VBP","NN"},
"wailed":	{"VBD","VBN"},
"wailer":	{"NN"},
"wailful":	{"JJ"},
"wailfully":	{"RB"},
"wailing":	{"VBG","NN"},
"wails":	{"VBZ","NNS"},
"wain":	{"NN"},
"wainscot":	{"NN","VB","VBP"},
"wainscoted":	{"VBD","VBN","JJ"},
"wainscoting":	{"VBG","NN"},
"wainscots":	{"NNS","VBZ"},
"wainscotting":	{"VBG","NN"},
"wainwright":	{"NN"},
"waist":	{"NN"},
"waist-deep":	{"JJ","RB"},
"waist-high":	{"JJ","RB"},
"waistband":	{"NN"},
"waistbands":	{"NNS"},
"waistcloth":	{"NN"},
"waistcoat":	{"NN"},
"waistcoats":	{"NNS"},
"waistline":	{"NN"},
"waistlines":	{"NNS"},
"waists":	{"NNS"},
"wait":	{"VB","VBP","NN"},
"wait-and-see":	{"JJ"},
"wait-list":	{"VB","VBP"},
"wait-listed":	{"VBD","VBN","JJ"},
"wait-listing":	{"VBG"},
"wait-lists":	{"VBZ"},
"waited":	{"VBD","VBN"},
"waiter":	{"NN"},
"waiters":	{"NNS"},
"waiting":	{"VBG","NN"},
"waitlist":	{"VB","VBP","NN"},
"waitlisted":	{"VBD","VBN","JJ"},
"waitlisting":	{"VBG"},
"waitlists":	{"VBZ","NNS"},
"waitress":	{"NN","VB","VBP"},
"waitressed":	{"VBD","VBN"},
"waitresses":	{"NNS","VBZ"},
"waitressing":	{"VBG","NN"},
"waits":	{"VBZ","NNS"},
"waive":	{"VB","VBP"},
"waived":	{"VBD","VBN"},
"waiver":	{"NN"},
"waivers":	{"NNS"},
"waives":	{"VBZ"},
"waiving":	{"VBG"},
"wake":	{"VB","VBP","NN"},
"wake-robin":	{"NN"},
"wake-up":	{"NN","JJ"},
"wake-ups":	{"NNS"},
"wakeboard":	{"NN","VB","VBP"},
"wakeboarded":	{"VBD","VBN"},
"wakeboarder":	{"NN"},
"wakeboarders":	{"NNS"},
"wakeboarding":	{"VBG","NN"},
"wakeboards":	{"NNS","VBZ"},
"wakeful":	{"JJ"},
"wakefulness":	{"NN"},
"wakeless":	{"JJ"},
"waken":	{"VB","VBP"},
"wakened":	{"VBD","VBN"},
"wakening":	{"VBG"},
"wakens":	{"VBZ"},
"waker":	{"NN"},
"wakes":	{"NNS","VBZ"},
"waking":	{"VBG","JJ"},
"waldmeister":	{"NN"},
"wale":	{"NN","VB","VBP"},
"waled":	{"VBD","VBN"},
"wales":	{"NNS","VBZ"},
"waling":	{"VBG"},
"walk":	{"VB","NN","VBP"},
"walk-in":	{"JJ"},
"walk-on":	{"JJ","NN"},
"walk-ons":	{"NNS"},
"walk-out":	{"NN"},
"walk-outs":	{"NNS"},
"walk-over":	{"NN"},
"walk-overs":	{"NNS"},
"walk-up":	{"JJ","NN"},
"walk-ups":	{"NNS"},
"walkability":	{"NN"},
"walkabout":	{"NN"},
"walkabouts":	{"NNS"},
"walkaway":	{"NN"},
"walkaways":	{"NNS"},
"walked":	{"VBD","VBN"},
"walker":	{"NN"},
"walkers":	{"NNS"},
"walkie-talkie":	{"NN"},
"walkie-talkies":	{"NNS"},
"walking":	{"VBG","NN","JJ"},
"walking-stick":	{"NN"},
"walking-tour":	{"NN"},
"walkingstick":	{"NN"},
"walkout":	{"NN"},
"walkouts":	{"NNS"},
"walkover":	{"NN"},
"walkovers":	{"NNS"},
"walks":	{"VBZ","NNS"},
"walkway":	{"NN"},
"walkways":	{"NNS"},
"walky-talkies":	{"NNS"},
"walky-talky":	{"NN"},
"wall":	{"NN","VBP","VB"},
"wall-painting":	{"NN"},
"wall-to-wall":	{"JJ","RB"},
"walla":	{"NN"},
"wallabies":	{"NNS"},
"wallaby":	{"NN"},
"wallah":	{"NN"},
"wallahs":	{"NNS"},
"wallboard":	{"NN"},
"wallcovering":	{"NN"},
"wallcoverings":	{"NNS"},
"walled":	{"VBN","VBD","JJ"},
"wallet":	{"NN"},
"wallets":	{"NNS"},
"walleye":	{"NN","NNS"},
"walleyed":	{"JJ"},
"walleyes":	{"NNS"},
"wallflower":	{"NN"},
"wallflowers":	{"NNS"},
"wallies":	{"NNS"},
"walling":	{"VBG"},
"wallop":	{"VB","VBP","NN"},
"walloped":	{"VBD","VBN"},
"walloper":	{"NN"},
"walloping":	{"NN","JJ","VBG"},
"wallops":	{"NNS","VBZ"},
"wallow":	{"VB","VBP","NN"},
"wallowed":	{"VBD","VBN"},
"wallower":	{"NN"},
"wallowing":	{"VBG"},
"wallows":	{"VBZ","NNS"},
"wallpaper":	{"NN","VB","VBP"},
"wallpapered":	{"VBD","VBN"},
"wallpaperer":	{"NN"},
"wallpapering":	{"VBG"},
"wallpapers":	{"NNS","VBZ"},
"walls":	{"NNS","VBZ"},
"wally":	{"NN"},
"walnut":	{"NN"},
"walnuts":	{"NNS"},
"walrus":	{"NN","NNS","JJ"},
"walruses":	{"NNS"},
"waltz":	{"NN","VB","VBP"},
"waltzed":	{"VBD","VBN"},
"waltzer":	{"NN"},
"waltzes":	{"NNS","VBZ"},
"waltzing":	{"VBG"},
"wamble":	{"VB","VBP","NN"},
"wambled":	{"VBD","VBN"},
"wambles":	{"VBZ","NNS"},
"wambliness":	{"NN"},
"wambling":	{"VBG"},
"wambly":	{"JJ"},
"wampee":	{"NN"},
"wampum":	{"NN"},
"wampumpeag":	{"NN"},
"wan":	{"JJ","VB","VBP"},
"wand":	{"NN"},
"wander":	{"VB","NN","VBP"},
"wandered":	{"VBD","VBN"},
"wanderer":	{"NN"},
"wanderers":	{"NNS"},
"wandering":	{"VBG","JJ","NN"},
"wanderings":	{"NNS"},
"wanderlust":	{"NN"},
"wanders":	{"VBZ","NNS"},
"wandflower":	{"NN"},
"wands":	{"NNS"},
"wane":	{"VB","VBP","NN"},
"waned":	{"VBD","VBN"},
"wanes":	{"VBZ"},
"wangle":	{"VB","VBP","NN"},
"wangled":	{"VBD","VBN"},
"wangler":	{"NN"},
"wangles":	{"VBZ"},
"wangling":	{"VBG"},
"waning":	{"JJ","NN","VBG"},
"wank":	{"VB","VBP","NN"},
"wanker":	{"NN"},
"wankers":	{"NNS"},
"wanly":	{"RB"},
"wanna":	{"VB","VBP"},
"wannabe":	{"NN"},
"wannabee":	{"NN"},
"wannabes":	{"NNS"},
"wanned":	{"VBD","VBN"},
"wanner":	{"JJR"},
"wanness":	{"NN"},
"wannest":	{"JJS"},
"wanning":	{"VBG"},
"wans":	{"VBZ"},
"want":	{"VBP","VB","NN"},
"wanted":	{"VBD","VBN","JJ"},
"wanter":	{"NN"},
"wanting":	{"JJ","VBG"},
"wanton":	{"JJ","NN","VB","VBP"},
"wantoned":	{"VBD","VBN"},
"wantoning":	{"VBG"},
"wantonly":	{"RB"},
"wantonness":	{"NN"},
"wantons":	{"VBZ","NNS"},
"wants":	{"VBZ","NNS"},
"wapiti":	{"NN","NNS"},
"wapitis":	{"NNS"},
"war":	{"NN","VB","VBP"},
"war-cry":	{"NN"},
"war-dance":	{"NN"},
"war-game":	{"NN"},
"war-horse":	{"NN"},
"war-lord":	{"NN"},
"war-paint":	{"NN"},
"war-path":	{"NN"},
"war-torn":	{"JJ"},
"warble":	{"VB","VBP","NN"},
"warbled":	{"VBD","VBN"},
"warbler":	{"NN"},
"warblers":	{"NNS"},
"warbles":	{"VBZ","NNS"},
"warbling":	{"VBG"},
"ward":	{"NN","VB","VBP"},
"warded":	{"VBN","VBD","JJ"},
"warden":	{"NN"},
"wardens":	{"NNS"},
"wardenship":	{"NN"},
"warder":	{"NN"},
"warders":	{"NNS"},
"wardership":	{"NN"},
"warding":	{"VBG"},
"wardress":	{"NN"},
"wardrobe":	{"NN"},
"wardrobes":	{"NNS"},
"wardroom":	{"NN"},
"wards":	{"VBZ","NNS"},
"ware":	{"NN","VB","VBP"},
"wared":	{"VBD","VBN"},
"warehouse":	{"NN","VB","VBP"},
"warehoused":	{"VBD","VBN"},
"warehouseman":	{"NN"},
"warehouser":	{"NN"},
"warehouses":	{"VBZ","NNS"},
"warehousing":	{"VBG","NN"},
"wares":	{"NNS","VBZ"},
"warfare":	{"NN"},
"warfarin":	{"NN"},
"warfighting":	{"NN"},
"warfront":	{"NN"},
"warhead":	{"NN"},
"warheads":	{"NNS"},
"warhorse":	{"NN"},
"warhorses":	{"NNS"},
"warier":	{"JJR"},
"wariest":	{"JJS"},
"warily":	{"RB"},
"wariness":	{"NN"},
"waring":	{"VBG"},
"warless":	{"JJ"},
"warlike":	{"JJ"},
"warlock":	{"NN"},
"warlord":	{"NN"},
"warlords":	{"NNS"},
"warm":	{"JJ","VB","VBP","NN","RB"},
"warm-blooded":	{"JJ"},
"warm-hearted":	{"JJ"},
"warm-heartedness":	{"NN"},
"warm-up":	{"NN","JJ"},
"warm-ups":	{"NNS"},
"warmed":	{"VBD","VBN"},
"warmed-over":	{"JJ"},
"warmer":	{"NN","JJR"},
"warmers":	{"NNS"},
"warmest":	{"JJS"},
"warmhearted":	{"JJ"},
"warmheartedness":	{"NN"},
"warming":	{"NN","VBG","JJ"},
"warmish":	{"JJ"},
"warmly":	{"RB"},
"warmness":	{"NN"},
"warmonger":	{"NN"},
"warmongering":	{"NN","JJ"},
"warmongers":	{"NNS"},
"warms":	{"VBZ"},
"warmth":	{"NN"},
"warn":	{"VB","VBP"},
"warned":	{"VBD","VBN"},
"warner":	{"NN"},
"warners":	{"NNS"},
"warning":	{"NN","VBG","JJ"},
"warningly":	{"RB"},
"warnings":	{"NNS"},
"warns":	{"VBZ"},
"warp":	{"VB","VBP","NN"},
"warpath":	{"NN"},
"warped":	{"JJ","VBD","VBN"},
"warping":	{"NN","VBG"},
"warplane":	{"NN"},
"warplanes":	{"NNS","VBZ"},
"warps":	{"VBZ","NNS"},
"warragal":	{"NN"},
"warrant":	{"NN","VBP","VB"},
"warranted":	{"VBN","JJ","VBD"},
"warrantee":	{"NN"},
"warranter":	{"NN"},
"warranties":	{"NNS"},
"warranting":	{"VBG"},
"warrantless":	{"JJ"},
"warrantor":	{"NN"},
"warrants":	{"NNS","VBZ"},
"warranty":	{"NN"},
"warred":	{"VBD","VBN"},
"warren":	{"NN"},
"warrener":	{"NN"},
"warrens":	{"NNS"},
"warrigal":	{"NN"},
"warrigals":	{"NNS"},
"warring":	{"VBG","JJ"},
"warrior":	{"NN"},
"warriors":	{"NNS"},
"wars":	{"NNS","VBZ"},
"warship":	{"NN"},
"warships":	{"NNS"},
"wart":	{"NN"},
"wart-hog":	{"NN"},
"warthog":	{"NN"},
"warthogs":	{"NNS"},
"wartime":	{"NN","JJ"},
"wartlike":	{"JJ"},
"warts":	{"NNS"},
"wartweed":	{"NN"},
"wartwort":	{"NN"},
"warty":	{"JJ"},
"warwick":	{"NN"},
"wary":	{"JJ"},
"was":	{"VBD"},
"wasabi":	{"NN"},
"wash":	{"VB","NN","VBP"},
"wash-basin":	{"NN"},
"wash-bowl":	{"NN"},
"wash-day":	{"NN"},
"wash-drawing":	{"NN"},
"wash-hand-basin":	{"NN"},
"wash-leather":	{"NN"},
"wash-out":	{"NN"},
"wash-outs":	{"NNS"},
"wash-stand":	{"NN"},
"wash-tub":	{"NN"},
"washable":	{"JJ"},
"washbasin":	{"NN"},
"washbasins":	{"NNS"},
"washboard":	{"NN"},
"washboards":	{"NNS"},
"washbowl":	{"NN"},
"washcloth":	{"NN"},
"washcloths":	{"NNS"},
"washday":	{"NN"},
"washed":	{"JJ","VBD","VBN"},
"washed-out":	{"JJ"},
"washed-up":	{"JJ"},
"washer":	{"NN"},
"washerman":	{"NN"},
"washers":	{"NNS"},
"washerwoman":	{"NN"},
"washerwomen":	{"NNS"},
"washes":	{"VBZ","NNS"},
"washhouse":	{"NN"},
"washing":	{"NN","VBG"},
"washing-machine":	{"NN"},
"washing-powder":	{"NN"},
"washing-soda":	{"NN"},
"washing-up":	{"NN"},
"washings":	{"NNS"},
"washout":	{"NN"},
"washouts":	{"NNS"},
"washrag":	{"NN"},
"washroom":	{"NN"},
"washrooms":	{"NNS"},
"washstand":	{"NN"},
"washstands":	{"NNS"},
"washtub":	{"NN"},
"washup":	{"NN"},
"washwoman":	{"NN"},
"washwomen":	{"NNS"},
"washy":	{"JJ"},
"wasp":	{"NN"},
"wasp-waisted":	{"JJ"},
"waspish":	{"JJ"},
"waspishly":	{"RB"},
"wasps":	{"NNS"},
"wassail":	{"NN","VB","VBP"},
"wassailed":	{"VBD","VBN"},
"wassailer":	{"NN"},
"wassailing":	{"VBG"},
"wassails":	{"VBZ"},
"wastage":	{"NN"},
"waste":	{"NN","VB","JJ","VBP"},
"waste-basket":	{"NN"},
"waste-bin":	{"NN"},
"waste-paper":	{"NN"},
"waste-pipe":	{"NN"},
"wastebasket":	{"NN"},
"wastebaskets":	{"NNS"},
"wastebin":	{"NN"},
"wasted":	{"JJ","VBD","VBN"},
"wasteful":	{"JJ"},
"wastefully":	{"RB"},
"wastefulness":	{"NN"},
"wasteland":	{"NN"},
"wastelands":	{"NNS"},
"wastepaper":	{"NN"},
"waster":	{"NN"},
"wasters":	{"NNS"},
"wastes":	{"NNS","VBZ"},
"wastewater":	{"NN","JJ"},
"wasteweir":	{"NN"},
"wasteyard":	{"NN"},
"wasting":	{"JJ","VBG"},
"wastrel":	{"NN"},
"wastrels":	{"NNS"},
"watch":	{"VB","NN","VBP"},
"watchband":	{"NN"},
"watchdog":	{"NN"},
"watchdogs":	{"NNS"},
"watched":	{"VBD","VBN"},
"watcher":	{"NN"},
"watchers":	{"NNS"},
"watches":	{"VBZ","NNS"},
"watchful":	{"JJ"},
"watchfully":	{"RB"},
"watchfulness":	{"NN"},
"watching":	{"VBG"},
"watchmaker":	{"NN"},
"watchman":	{"NN"},
"watchmen":	{"NNS"},
"watchstrap":	{"NN"},
"watchtower":	{"NN"},
"watchtowers":	{"NNS"},
"watchword":	{"NN"},
"watchwords":	{"NNS"},
"water":	{"NN","VB","VBP"},
"water-bed":	{"NN"},
"water-bird":	{"NN"},
"water-biscuit":	{"NN"},
"water-borne":	{"JJ"},
"water-bottle":	{"NN"},
"water-buffalo":	{"NN","NNS"},
"water-buffaloes":	{"NNS"},
"water-butt":	{"NN"},
"water-cannon":	{"NN"},
"water-closet":	{"NN"},
"water-color":	{"NN"},
"water-colour":	{"NN"},
"water-colours":	{"NNS"},
"water-cooled":	{"JJ"},
"water-diviner":	{"NN"},
"water-fowl":	{"NN","NNS"},
"water-hammer":	{"NN"},
"water-hole":	{"NN"},
"water-ice":	{"NN"},
"water-jump":	{"NN"},
"water-level":	{"NN"},
"water-like":	{"JJ"},
"water-lily":	{"NN"},
"water-main":	{"NN"},
"water-meadow":	{"NN"},
"water-melon":	{"NN"},
"water-mill":	{"NN"},
"water-pistol":	{"NN"},
"water-power":	{"NN"},
"water-proof":	{"JJ"},
"water-rat":	{"NN"},
"water-rate":	{"NN"},
"water-repellent":	{"JJ","NN"},
"water-resistant":	{"JJ"},
"water-ski":	{"VB","VBP"},
"water-skied":	{"VBD","VBN"},
"water-skiing":	{"NN","VBG"},
"water-skis":	{"VBZ"},
"water-soluble":	{"JJ"},
"water-supply":	{"NN"},
"water-table":	{"NN"},
"water-tower":	{"NN"},
"water-wheel":	{"NN"},
"water-wings":	{"NNS"},
"waterbird":	{"NN"},
"waterborne":	{"JJ"},
"waterbuck":	{"NN","NNS"},
"waterbucks":	{"NNS"},
"watercannon":	{"NN"},
"watercolor":	{"NN","JJ"},
"watercolorist":	{"NN"},
"watercolorists":	{"NNS"},
"watercolors":	{"NNS"},
"watercolour":	{"NN","JJ"},
"watercolourist":	{"NN"},
"watercolours":	{"NNS"},
"watercourse":	{"NN"},
"watercourses":	{"NNS"},
"watercraft":	{"NN"},
"watercress":	{"NN"},
"waterdog":	{"NN"},
"watered":	{"JJ","VBD","VBN"},
"watered-down":	{"JJ"},
"watered-silk":	{"NN"},
"waterer":	{"NN"},
"waterfall":	{"NN"},
"waterfalls":	{"NNS"},
"waterfinder":	{"NN"},
"waterfowl":	{"NN","NNS"},
"waterfront":	{"NN"},
"waterfronts":	{"NNS"},
"watergate":	{"NN"},
"wateriness":	{"NN"},
"watering":	{"NN","VBG"},
"waterish":	{"JJ"},
"waterishness":	{"NN"},
"waterleaf":	{"NN","JJ"},
"waterleafs":	{"NNS"},
"waterless":	{"JJ"},
"waterlessness":	{"NN"},
"waterline":	{"NN"},
"waterlines":	{"NNS"},
"waterlog":	{"VB","VBP"},
"waterlogged":	{"JJ","VBD","VBN"},
"waterlogging":	{"VBG","NN"},
"waterlogs":	{"VBZ"},
"waterman":	{"NN"},
"watermark":	{"NN","VB","VBP"},
"watermarked":	{"VBD","VBN"},
"watermarking":	{"VBG"},
"watermarks":	{"VBZ","NNS"},
"watermeal":	{"NN"},
"watermelon":	{"NN"},
"watermelons":	{"NNS"},
"watermen":	{"NNS"},
"waterpower":	{"NN"},
"waterproof":	{"JJ","NN","VB","VBP"},
"waterproofed":	{"VBD","VBN","JJ"},
"waterproofing":	{"NN","VBG"},
"waterproofs":	{"NNS","VBZ"},
"waters":	{"NNS","VBZ"},
"waterscape":	{"NN"},
"watershed":	{"NN"},
"watersheds":	{"NNS"},
"waterside":	{"NN","JJ"},
"waterskiing":	{"NN"},
"waterskin":	{"NN"},
"waterspout":	{"NN"},
"waterspouts":	{"NNS"},
"watertight":	{"JJ"},
"waterway":	{"NN"},
"waterways":	{"NNS"},
"waterweed":	{"NN"},
"waterwheel":	{"NN"},
"waterwheels":	{"NNS"},
"waterworks":	{"NN","NNS"},
"waterworn":	{"JJ"},
"watery":	{"JJ"},
"watt":	{"NN"},
"wattage":	{"NN"},
"wattle":	{"NN"},
"wattles":	{"NNS"},
"wattmeter":	{"NN"},
"watts":	{"NNS"},
"waul":	{"VB","VBP"},
"wauled":	{"VBD","VBN"},
"wauling":	{"VBG"},
"wauls":	{"VBZ"},
"wave":	{"NN","VB","VBP"},
"waveband":	{"NN"},
"wavebands":	{"NNS"},
"waved":	{"VBD","VBN"},
"waveform":	{"NN"},
"wavefront":	{"NN"},
"waveguide":	{"NN"},
"wavelength":	{"NN"},
"wavelengths":	{"NNS"},
"wavelet":	{"NN"},
"wavelike":	{"JJ"},
"waver":	{"VB","VBP"},
"wavered":	{"VBD","VBN"},
"waverer":	{"NN"},
"waverers":	{"NNS"},
"wavering":	{"VBG"},
"wavers":	{"VBZ"},
"waves":	{"NNS","VBZ"},
"wavier":	{"JJR"},
"waviest":	{"JJS"},
"waviness":	{"NN"},
"waving":	{"VBG"},
"wavy":	{"JJ"},
"waw":	{"NN"},
"wawl":	{"VB","VBP"},
"wax":	{"NN","VB","VBP"},
"waxberries":	{"NNS"},
"waxberry":	{"NN"},
"waxed":	{"VBD","VBN"},
"waxen":	{"JJ"},
"waxer":	{"NN"},
"waxes":	{"VBZ"},
"waxflower":	{"NN"},
"waxiness":	{"NN"},
"waxing":	{"NN","VBG"},
"waxlike":	{"JJ"},
"waxmallow":	{"NN"},
"waxwing":	{"NN"},
"waxwork":	{"NN"},
"waxworks":	{"NNS"},
"waxy":	{"JJ"},
"way":	{"NN","RB"},
"way-out":	{"JJ"},
"waybill":	{"NN"},
"wayfarer":	{"NN"},
"wayfaring":	{"JJ","NN"},
"waylaid":	{"VBD","VBN"},
"waylay":	{"VB","VBP"},
"waylaying":	{"VBG"},
"waylays":	{"VBZ"},
"waypoint":	{"NN"},
"ways":	{"NNS"},
"wayside":	{"NN","JJ"},
"waysides":	{"NNS"},
"wayward":	{"JJ"},
"waywardness":	{"NN"},
"we":	{"PRP"},
"weak":	{"JJ"},
"weak-kneed":	{"JJ"},
"weak-minded":	{"JJ"},
"weak-mindedly":	{"RB"},
"weak-mindedness":	{"NN"},
"weaken":	{"VB","VBP"},
"weakened":	{"VBN","VBD"},
"weakener":	{"NN"},
"weakening":	{"VBG","NN","JJ"},
"weakens":	{"VBZ"},
"weaker":	{"JJR"},
"weakest":	{"JJS"},
"weakfish":	{"NN"},
"weaklier":	{"JJR"},
"weakliest":	{"JJS"},
"weakliness":	{"NN"},
"weakling":	{"NN"},
"weaklings":	{"NNS"},
"weakly":	{"JJ","RB"},
"weakness":	{"NN"},
"weaknesses":	{"NNS"},
"weakwilled":	{"JJ"},
"weal":	{"NN"},
"weald":	{"NN"},
"weals":	{"NNS"},
"wealth":	{"NN"},
"wealthier":	{"JJR"},
"wealthiest":	{"JJS"},
"wealthily":	{"RB"},
"wealthiness":	{"NN"},
"wealthy":	{"JJ","NNS"},
"wean":	{"VB","VBP"},
"weaned":	{"VBD","VBN"},
"weaning":	{"NN","VBG"},
"weans":	{"VBZ"},
"weapon":	{"NN"},
"weaponed":	{"JJ"},
"weaponisation":	{"NN"},
"weaponise":	{"VB","VBP"},
"weaponize":	{"VB","VBP"},
"weaponized":	{"VBD","VBN"},
"weaponizes":	{"VBZ"},
"weaponizing":	{"VBG"},
"weaponless":	{"JJ"},
"weaponry":	{"NN"},
"weapons":	{"NNS"},
"weapons-grade":	{"JJ"},
"wear":	{"VB","VBP","NN"},
"wearable":	{"JJ"},
"wearer":	{"NN"},
"wearers":	{"NNS"},
"wearied":	{"VBD","VBN"},
"wearier":	{"JJR"},
"wearies":	{"VBZ"},
"weariest":	{"JJS"},
"wearily":	{"RB"},
"weariness":	{"NN"},
"wearing":	{"JJ","VBG"},
"wearisome":	{"JJ"},
"wears":	{"VBZ"},
"weary":	{"JJ","VB","VBP"},
"wearying":	{"VBG","JJ"},
"weasel":	{"NN","VBP","VB"},
"weaseled":	{"VBD","VBN"},
"weaseling":	{"VBG"},
"weaselled":	{"VBD","VBN"},
"weaselling":	{"VBG"},
"weasels":	{"NNS","VBZ"},
"weather":	{"NN","VB","VBP","JJ"},
"weather-beaten":	{"JJ"},
"weather-board":	{"NN"},
"weather-boarding":	{"NN"},
"weather-bound":	{"JJ"},
"weather-chart":	{"NN"},
"weather-map":	{"NN"},
"weather-vane":	{"NN"},
"weatherboard":	{"NN","VB","VBP"},
"weatherboarded":	{"VBD","VBN"},
"weatherboarding":	{"NN","VBG"},
"weatherboards":	{"NNS","VBZ"},
"weathercock":	{"NN"},
"weathercocks":	{"NNS"},
"weathered":	{"JJ","VBD","VBN"},
"weatherglass":	{"NN"},
"weathering":	{"VBG"},
"weatherliness":	{"NN"},
"weatherly":	{"JJ"},
"weatherman":	{"NN"},
"weatherproof":	{"JJ","VB","VBP"},
"weatherproofness":	{"NN"},
"weathers":	{"VBZ"},
"weatherstrip":	{"NN","VB","VBP"},
"weatherstripped":	{"VBD","VBN"},
"weatherstripping":	{"NN","VBG"},
"weatherstrips":	{"NNS","VBZ"},
"weatherworn":	{"JJ"},
"weave":	{"VB","VBP","NN"},
"weaver":	{"NN"},
"weaverbird":	{"NN"},
"weavers":	{"NNS"},
"weaves":	{"NNS","VBZ"},
"weaving":	{"NN","VBG"},
"web":	{"NN","VB","VBP"},
"web-footed":	{"JJ"},
"webb":	{"NN"},
"webbed":	{"JJ","VBD","VBN"},
"webbing":	{"NN","VBG"},
"webby":	{"NN"},
"webcam":	{"NN"},
"weber":	{"NN"},
"weber-controlled":	{"JJ"},
"webfoot":	{"NN"},
"webless":	{"JJ"},
"weblike":	{"NN"},
"webmaster":	{"NN"},
"webmasters":	{"NNS"},
"webpage":	{"NN"},
"webpages":	{"NNS"},
"webs":	{"NNS","VBZ"},
"website":	{"NN"},
"websites":	{"NNS"},
"webster":	{"NN"},
"webworm":	{"NN"},
"wed":	{"VBD","VBN","VB","VBP"},
"wedded":	{"JJ","VBD","VBN"},
"wedding":	{"NN","VBG"},
"weddings":	{"NNS"},
"wedel":	{"VB","VBP"},
"wedeln":	{"NN"},
"wedge":	{"NN","VB","VBP"},
"wedge-shaped":	{"JJ"},
"wedged":	{"VBD","VBN"},
"wedges":	{"NNS","VBZ"},
"wedgie":	{"NN"},
"wedging":	{"VBG"},
"wedlock":	{"NN"},
"weds":	{"VBZ"},
"wee":	{"JJ","NN","VB","VBP"},
"wee-wee":	{"VB","VBP","NN"},
"wee-weed":	{"VBD","VBN"},
"wee-weeing":	{"VBG"},
"wee-wees":	{"VBZ"},
"weed":	{"NN","VBP","VB","VBD","VBN"},
"weed-killer":	{"NN"},
"weeded":	{"VBN","VBD"},
"weeder":	{"NN"},
"weedier":	{"JJR"},
"weediest":	{"JJS"},
"weeding":	{"VBG","NN"},
"weedkiller":	{"NN"},
"weedkillers":	{"NNS"},
"weedless":	{"JJ"},
"weeds":	{"NNS","VBZ"},
"weedy":	{"JJ"},
"weeing":	{"VBG"},
"week":	{"NN"},
"weekday":	{"NN"},
"weekdays":	{"NNS","RB"},
"weekend":	{"NN","VBP","VB"},
"weekended":	{"VBD","VBN"},
"weekender":	{"NN"},
"weekenders":	{"NNS"},
"weekending":	{"VBG"},
"weekends":	{"NNS","VBZ"},
"weeklies":	{"NNS"},
"weeklong":	{"JJ"},
"weekly":	{"JJ","RB","NN"},
"weeknight":	{"NN"},
"weeknights":	{"NNS"},
"weeks":	{"NNS"},
"weeks-long":	{"JJ"},
"ween":	{"VB","VBP"},
"weened":	{"VBD","VBN"},
"weenie":	{"NN"},
"weenier":	{"JJR"},
"weenies":	{"NNS"},
"weeniest":	{"JJS"},
"weening":	{"VBG"},
"weens":	{"VBZ"},
"weensier":	{"JJR"},
"weensiest":	{"JJS"},
"weensy":	{"JJ"},
"weeny":	{"JJ"},
"weep":	{"VB","VBP","NN"},
"weeper":	{"NN"},
"weepers":	{"NNS"},
"weepie":	{"NN"},
"weepies":	{"NNS"},
"weepiness":	{"NN"},
"weeping":	{"JJ","VBG"},
"weeps":	{"VBZ"},
"weepy":	{"NN","JJ"},
"wees":	{"VBZ"},
"weevil":	{"NN"},
"weevils":	{"NNS"},
"weft":	{"NN"},
"weigela":	{"NN"},
"weigh":	{"VB","VBP"},
"weighbridge":	{"NN"},
"weighed":	{"VBD","VBN"},
"weigher":	{"NN"},
"weighing":	{"VBG"},
"weighs":	{"VBZ"},
"weight":	{"NN","VB","VBP"},
"weight-lifter":	{"NN"},
"weight-lifting":	{"NN"},
"weighted":	{"VBN","JJ","VBD"},
"weightier":	{"JJR"},
"weightiest":	{"JJS"},
"weightily":	{"RB"},
"weightiness":	{"NN"},
"weighting":	{"NN","VBG"},
"weightings":	{"NNS"},
"weightless":	{"JJ"},
"weightlessness":	{"NN"},
"weightlifter":	{"NN"},
"weightlifters":	{"NNS"},
"weightlifting":	{"NN"},
"weights":	{"NNS","VBZ"},
"weighty":	{"JJ"},
"weir":	{"NN"},
"weird":	{"JJ","VB","VBP"},
"weirded":	{"VBD","VBN"},
"weirder":	{"JJR"},
"weirdest":	{"JJS"},
"weirdie":	{"NN"},
"weirding":	{"VBG"},
"weirdly":	{"RB"},
"weirdness":	{"NN"},
"weirdo":	{"NN"},
"weirdos":	{"NNS"},
"weirds":	{"VBZ"},
"weirdy":	{"NN"},
"weirs":	{"NNS"},
"weisenheimer":	{"NN"},
"weissbier":	{"NN","FW"},
"weizenbier":	{"NN","FW"},
"weizenbock":	{"NN","FW"},
"weka":	{"NN"},
"welch":	{"VB","VBP"},
"welched":	{"VBD","VBN"},
"welcher":	{"NN"},
"welches":	{"VBZ"},
"welching":	{"VBG"},
"welcome":	{"JJ","VB","VBP","NN","UH"},
"welcomed":	{"VBD","VBN"},
"welcomely":	{"RB"},
"welcomeness":	{"NN"},
"welcomer":	{"NN"},
"welcomers":	{"NNS"},
"welcomes":	{"VBZ","NNS"},
"welcoming":	{"VBG","JJ"},
"weld":	{"VB","VBP","NN"},
"welded":	{"VBN","VBD"},
"welder":	{"NN"},
"welders":	{"NNS"},
"welding":	{"NN","VBG"},
"weldment":	{"NN"},
"welds":	{"VBZ","NNS"},
"welfare":	{"NN"},
"welfarism":	{"NN"},
"welfarist":	{"NN"},
"welkin":	{"NN"},
"well":	{"RB","NN","UH","JJ","VBP","VB"},
"well-adjusted":	{"JJ"},
"well-advised":	{"JJ"},
"well-appointed":	{"JJ"},
"well-baby":	{"JJ"},
"well-balanced":	{"JJ"},
"well-behaved":	{"JJ"},
"well-being":	{"NN"},
"well-born":	{"JJ"},
"well-bred":	{"JJ"},
"well-built":	{"JJ"},
"well-chosen":	{"JJ"},
"well-connected":	{"JJ"},
"well-defined":	{"JJ"},
"well-deserved":	{"JJ"},
"well-designed":	{"JJ"},
"well-developed":	{"JJ"},
"well-disposed":	{"JJ"},
"well-documented":	{"JJ"},
"well-done":	{"JJ"},
"well-dressed":	{"JJ"},
"well-earned":	{"JJ"},
"well-educated":	{"JJ"},
"well-endowed":	{"JJ"},
"well-equipped":	{"JJ"},
"well-established":	{"JJ"},
"well-favored":	{"JJ"},
"well-favoured":	{"JJ"},
"well-fed":	{"JJ"},
"well-financed":	{"JJ"},
"well-fitted":	{"JJ"},
"well-fixed":	{"JJ"},
"well-formed":	{"JJ"},
"well-fortified":	{"JJ"},
"well-found":	{"JJ"},
"well-founded":	{"JJ"},
"well-groomed":	{"JJ"},
"well-grounded":	{"JJ"},
"well-guarded":	{"JJ"},
"well-handled":	{"JJ"},
"well-heeled":	{"JJ"},
"well-illustrated":	{"JJ"},
"well-informed":	{"JJ"},
"well-intentioned":	{"JJ"},
"well-kept":	{"JJ"},
"well-knit":	{"JJ"},
"well-known":	{"JJ"},
"well-lined":	{"JJ"},
"well-made":	{"JJ"},
"well-managed":	{"JJ"},
"well-mannered":	{"JJ"},
"well-marked":	{"JJ"},
"well-meaning":	{"JJ"},
"well-meant":	{"JJ"},
"well-nigh":	{"RB"},
"well-nourished":	{"JJ"},
"well-off":	{"JJ","NNS"},
"well-oiled":	{"JJ"},
"well-paid":	{"JJ"},
"well-placed":	{"JJ"},
"well-planned":	{"JJ"},
"well-played":	{"JJ"},
"well-prepared":	{"JJ"},
"well-preserved":	{"JJ"},
"well-proportioned":	{"JJ"},
"well-qualified":	{"JJ"},
"well-read":	{"JJ"},
"well-received":	{"JJ"},
"well-regarded":	{"JJ"},
"well-regulated":	{"JJ"},
"well-rehearsed":	{"JJ"},
"well-respected":	{"JJ"},
"well-rounded":	{"JJ"},
"well-run":	{"JJ"},
"well-seasoned":	{"JJ"},
"well-set":	{"JJ"},
"well-situated":	{"JJ"},
"well-spoken":	{"JJ"},
"well-stocked":	{"JJ"},
"well-tempered":	{"JJ"},
"well-thought-of":	{"JJ"},
"well-thought-out":	{"JJ"},
"well-thumbed":	{"JJ"},
"well-timed":	{"JJ"},
"well-to-do":	{"JJ","NNS"},
"well-trained":	{"JJ"},
"well-traveled":	{"JJ"},
"well-travelled":	{"JJ"},
"well-tried":	{"JJ"},
"well-turned":	{"JJ"},
"well-turned-out":	{"JJ"},
"well-understood":	{"JJ"},
"well-versed":	{"JJ"},
"well-wisher":	{"NN"},
"well-wishers":	{"NNS"},
"well-wishing":	{"JJ","NN"},
"well-worn":	{"JJ"},
"well-written":	{"JJ"},
"wellbeing":	{"NN"},
"wellborn":	{"JJ"},
"welled":	{"VBD","VBN"},
"wellhead":	{"NN"},
"welling":	{"RB","NN","VBG"},
"wellington":	{"NN"},
"wellingtons":	{"NNS"},
"wellness":	{"NN"},
"wellpoint":	{"NN"},
"wells":	{"NNS","VBZ"},
"wellspring":	{"NN"},
"welsh":	{"VBP","VB"},
"welshed":	{"VBD","VBN"},
"welsher":	{"NN"},
"welshes":	{"VBZ"},
"welshing":	{"VBG"},
"welt":	{"NN","VB","VBP"},
"weltanschauung":	{"NN"},
"welted":	{"VBD","VBN"},
"welter":	{"NN","VB","VBP"},
"weltered":	{"VBD","VBN"},
"weltering":	{"VBG"},
"welters":	{"VBZ"},
"welterweight":	{"NN"},
"welterweights":	{"NNS"},
"welting":	{"VBG"},
"welts":	{"NNS","VBZ"},
"weltschmerz":	{"NN","FW"},
"welwitschia":	{"NN"},
"welwitschiaceae":	{"NN"},
"wen":	{"NN"},
"wench":	{"NN","VB","VBP"},
"wenched":	{"VBD","VBN"},
"wencher":	{"NN"},
"wenches":	{"NNS","VBZ"},
"wenching":	{"VBG"},
"wend":	{"VB","VBP"},
"wended":	{"VBD","VBN"},
"wending":	{"VBG"},
"wends":	{"VBZ"},
"went":	{"VBD"},
"wept":	{"VBD","VBN"},
"were":	{"VBD"},
"werewolf":	{"NN"},
"werewolves":	{"NNS"},
"west":	{"NN","RB","JJ"},
"west-northwest":	{"NN","JJ","RB"},
"west-southwest":	{"NN","JJ","RB"},
"westbound":	{"JJ"},
"wester":	{"VB","VBP","NN"},
"westerlies":	{"NNS"},
"westerly":	{"JJ","NN"},
"western":	{"JJ","NN"},
"westerner":	{"NN"},
"westerners":	{"NNS"},
"westernisation":	{"NN"},
"westernise":	{"VB","VBP"},
"westernised":	{"VBD","VBN","JJ"},
"westernises":	{"VBZ"},
"westernising":	{"VBG"},
"westernization":	{"NN"},
"westernize":	{"VB","VBP"},
"westernized":	{"VBD","VBN","JJ"},
"westernizes":	{"VBZ"},
"westernizing":	{"VBG"},
"westernmost":	{"JJ"},
"westerns":	{"NNS"},
"westmost":	{"JJ"},
"westward":	{"RB","NN","JJ"},
"westwards":	{"RB"},
"wet":	{"JJ","VB","VBP","NN","VBD","VBN"},
"wet-nurse":	{"NN","VB","VBP"},
"wetback":	{"NN"},
"wetbacks":	{"NNS"},
"wether":	{"NN"},
"wetland":	{"NN"},
"wetlands":	{"NNS"},
"wetly":	{"RB"},
"wetness":	{"NN"},
"wets":	{"NNS","VBZ"},
"wetted":	{"VBD","VBN"},
"wetter":	{"JJR","NN"},
"wettest":	{"JJS"},
"wetting":	{"NN","VBG"},
"whack":	{"VB","VBP","NN"},
"whacked":	{"JJ","VBD","VBN"},
"whacker":	{"NN"},
"whacking":	{"JJ","NN","RB","VBG"},
"whacko":	{"JJ","NN"},
"whackos":	{"NNS"},
"whacks":	{"VBZ"},
"whacky":	{"JJ"},
"whaddya":	{"WP"},
"whale":	{"NN","VB","VBP"},
"whaleboat":	{"NN"},
"whalebone":	{"NN"},
"whaled":	{"VBD","VBN"},
"whaler":	{"NN"},
"whalers":	{"NNS"},
"whales":	{"VBZ","NNS"},
"whaling":	{"NN","VBG"},
"wham":	{"UH","NN","VB","VBP"},
"whammed":	{"VBD","VBN"},
"whamming":	{"VBG"},
"whammo":	{"UH"},
"whammy":	{"NN"},
"whams":	{"NNS","VBZ"},
"whang":	{"NN","VB","VBP"},
"whanged":	{"VBD","VBN"},
"whanging":	{"VBG"},
"whangs":	{"NNS","VBZ"},
"whap":	{"VB","VBP","NN"},
"whapped":	{"VBD","VBN"},
"whapping":	{"VBG"},
"whaps":	{"VBZ","NNS"},
"wharf":	{"NN","VB","VBP"},
"wharfage":	{"NN"},
"wharfed":	{"VBD","VBN"},
"wharfing":	{"VBG"},
"wharfs":	{"NNS","VBZ"},
"wharves":	{"NNS"},
"what":	{"WP","WDT","UH"},
"whatchamacallit":	{"NN"},
"whatchamacallum":	{"NN"},
"whatever":	{"WDT","RB","WP"},
"whatnot":	{"NN"},
"whatnots":	{"NNS"},
"whatsis":	{"NN"},
"whatsoever":	{"JJ","RB","NN"},
"wheal":	{"NN"},
"wheat":	{"NN"},
"wheat-grass":	{"NN"},
"wheatear":	{"NN"},
"wheaten":	{"JJ"},
"wheatfield":	{"NN"},
"wheatgerm":	{"NN"},
"wheatgrass":	{"NN"},
"wheatworm":	{"NN"},
"wheedle":	{"VB","VBP"},
"wheedled":	{"VBD","VBN"},
"wheedler":	{"NN"},
"wheedles":	{"VBZ"},
"wheedling":	{"VBG"},
"wheel":	{"NN","VBP","VB"},
"wheelbarrow":	{"NN"},
"wheelbarrows":	{"NNS"},
"wheelbase":	{"NN"},
"wheelbases":	{"NNS"},
"wheelchair":	{"NN"},
"wheelchairs":	{"NNS"},
"wheeled":	{"JJ","VBD","VBN"},
"wheeler":	{"NN"},
"wheeler-dealer":	{"NN"},
"wheeler-dealers":	{"NNS"},
"wheelhouse":	{"NN"},
"wheelhouses":	{"NNS"},
"wheelie":	{"NN"},
"wheeling":	{"VBG","NN"},
"wheelless":	{"JJ"},
"wheels":	{"NNS","VBZ"},
"wheelwork":	{"NN"},
"wheelwright":	{"NN"},
"wheelwrights":	{"NNS"},
"wheeze":	{"VB","VBP","NN"},
"wheezed":	{"VBD","VBN"},
"wheezes":	{"VBZ","NNS"},
"wheezily":	{"RB"},
"wheeziness":	{"NN"},
"wheezing":	{"VBG"},
"wheezingly":	{"RB"},
"wheezy":	{"JJ"},
"whelk":	{"NN"},
"whelks":	{"NNS"},
"whelm":	{"VB","VBP"},
"whelmed":	{"VBD","VBN"},
"whelming":	{"VBG"},
"whelms":	{"VBZ"},
"whelp":	{"NN","VB","VBP"},
"whelped":	{"VBD","VBN"},
"whelping":	{"VBG"},
"whelps":	{"NNS","VBZ"},
"when":	{"WRB"},
"whence":	{"RB","IN","CC"},
"whenever":	{"WRB"},
"where":	{"WRB"},
"whereabouts":	{"RB","NNS"},
"whereas":	{"IN","CC"},
"whereby":	{"WRB"},
"wherefore":	{"RB","IN","NN"},
"wherefores":	{"NNS"},
"wherein":	{"WRB","IN"},
"whereof":	{"RB","IN"},
"whereon":	{"RB","IN"},
"wheresoever":	{"RB","IN"},
"whereupon":	{"IN","CC"},
"wherever":	{"WRB"},
"wherewith":	{"RB"},
"wherewithal":	{"NN"},
"wherry":	{"NN","VB","VBP"},
"whet":	{"VB","VBP","NN"},
"whether":	{"IN","CC"},
"whets":	{"VBZ","NNS"},
"whetstone":	{"NN"},
"whetstones":	{"NNS"},
"whetted":	{"VBD","VBN"},
"whetter":	{"NN"},
"whetting":	{"VBG"},
"whey":	{"NN"},
"which":	{"WDT","WP"},
"whichever":	{"WDT"},
"whicker":	{"VB","VBP"},
"whickered":	{"VBD","VBN"},
"whickering":	{"VBG"},
"whickers":	{"VBZ"},
"whidah":	{"NN"},
"whiff":	{"NN","VB","VBP"},
"whiffed":	{"VBD","VBN"},
"whiffer":	{"NN"},
"whiffing":	{"VBG"},
"whiffle":	{"VB","VBP"},
"whiffled":	{"VBD","VBN"},
"whiffles":	{"VBZ"},
"whiffletree":	{"NN"},
"whiffling":	{"VBG"},
"whiffs":	{"NNS","VBZ"},
"while":	{"IN","CC","NN","VBP","VB"},
"whiled":	{"VBD","VBN"},
"whiles":	{"VBZ"},
"whiling":	{"VBG"},
"whim":	{"NN"},
"whimper":	{"VB","VBP","NN"},
"whimpered":	{"VBD","VBN"},
"whimpering":	{"VBG"},
"whimpers":	{"NNS","VBZ"},
"whims":	{"NNS"},
"whimsey":	{"NN","JJ"},
"whimseys":	{"NNS"},
"whimsical":	{"JJ"},
"whimsicality":	{"NN"},
"whimsically":	{"RB"},
"whimsy":	{"NN"},
"whin":	{"NN"},
"whinberry":	{"NN"},
"whinchat":	{"NN"},
"whine":	{"VB","VBP","NN"},
"whined":	{"VBD","VBN"},
"whiner":	{"NN"},
"whiners":	{"NNS"},
"whines":	{"VBZ"},
"whiney":	{"JJ"},
"whinier":	{"JJR"},
"whiniest":	{"JJS"},
"whining":	{"VBG"},
"whinnied":	{"VBD","VBN"},
"whinnies":	{"VBZ"},
"whinny":	{"VB","VBP","NN"},
"whinnying":	{"VBG"},
"whinstone":	{"NN"},
"whiny":	{"JJ"},
"whip":	{"NN","VB","VBP"},
"whip-round":	{"NN"},
"whipcord":	{"NN"},
"whiplash":	{"NN","VB","VBP"},
"whiplashed":	{"VBD","VBN"},
"whiplashing":	{"VBG"},
"whiplike":	{"JJ"},
"whipped":	{"VBD","VBN"},
"whipper":	{"NN"},
"whipper-in":	{"NN"},
"whippers-in":	{"NNS"},
"whippersnapper":	{"NN"},
"whippersnappers":	{"NNS"},
"whippet":	{"NN"},
"whippets":	{"NNS"},
"whipping":	{"NN","VBG"},
"whipping-boy":	{"NN"},
"whipping-boys":	{"NNS"},
"whippings":	{"NNS"},
"whippletree":	{"NN"},
"whippoorwill":	{"NN"},
"whippoorwills":	{"NNS"},
"whippy":	{"JJ"},
"whips":	{"NNS","VBZ"},
"whipsaw":	{"VB","VBP","NN"},
"whipsawed":	{"VBD","VBN"},
"whipsawing":	{"VBG"},
"whipsaws":	{"VBZ","NNS"},
"whipsnake":	{"NN"},
"whipstitch":	{"NN","VB","VBP"},
"whipstitching":	{"VBG"},
"whiptail":	{"NN"},
"whir":	{"VB","VBP","NN"},
"whirl":	{"VB","VBP","NN"},
"whirled":	{"VBD","VBN"},
"whirler":	{"NN"},
"whirligig":	{"NN"},
"whirling":	{"VBG","JJ"},
"whirlingly":	{"RB"},
"whirlpool":	{"NN"},
"whirlpools":	{"NNS"},
"whirls":	{"VBZ","NNS"},
"whirlwind":	{"NN","JJ"},
"whirlwinds":	{"NNS"},
"whirlybird":	{"NN"},
"whirr":	{"VB","VBP","NN"},
"whirred":	{"VBD","VBN"},
"whirring":	{"VBG","NN"},
"whirrs":	{"VBZ","NNS"},
"whirs":	{"NNS","VBZ"},
"whish":	{"NN","VB","VBP"},
"whisk":	{"VB","VBP","NN"},
"whisked":	{"VBD","VBN"},
"whisker":	{"NN"},
"whiskered":	{"JJ"},
"whiskers":	{"NNS"},
"whiskery":	{"JJ"},
"whiskey":	{"NN"},
"whiskeys":	{"NNS"},
"whiskies":	{"NNS"},
"whisking":	{"VBG"},
"whisks":	{"NNS","VBZ"},
"whisky":	{"NN"},
"whisper":	{"VB","VBP","NN"},
"whispered":	{"VBD","VBN"},
"whisperer":	{"NN"},
"whispering":	{"VBG","NN","JJ"},
"whisperings":	{"NNS"},
"whispers":	{"VBZ","NNS"},
"whist":	{"UH","JJ","NN"},
"whistle":	{"NN","VB","VBP"},
"whistle-blower":	{"NN"},
"whistle-blowers":	{"NNS"},
"whistle-blowing":	{"NN"},
"whistle-stop":	{"JJ","VB","VBP"},
"whistle-stopped":	{"VBD","VBN"},
"whistle-stopping":	{"VBG"},
"whistle-stops":	{"VBZ"},
"whistleblower":	{"NN"},
"whistleblowers":	{"NNS"},
"whistled":	{"VBD","VBN"},
"whistler":	{"NN"},
"whistles":	{"NNS","VBZ"},
"whistling":	{"NN","VBG"},
"whit":	{"NN"},
"white":	{"JJ","NN","VB","VBP"},
"white-bread":	{"JJ"},
"white-collar":	{"JJ"},
"white-haired":	{"JJ"},
"white-hot":	{"JJ"},
"white-knight":	{"NN"},
"white-knuckle":	{"JJ"},
"white-shoe":	{"JJ"},
"white-tie":	{"JJ"},
"whitebait":	{"NN"},
"whitecap":	{"NN"},
"whitecup":	{"NN"},
"whited":	{"VBD","VBN"},
"whiteface":	{"NN","JJ"},
"whitefish":	{"NN"},
"whiteflies":	{"NNS"},
"whitefly":	{"NN"},
"whitehead":	{"NN"},
"whitely":	{"RB"},
"whiten":	{"VB","VBP"},
"whitened":	{"VBD","VBN"},
"whitener":	{"NN"},
"whiteness":	{"NN"},
"whitening":	{"NN","VBG"},
"whitens":	{"VBZ"},
"whiteout":	{"NN"},
"whiter":	{"JJR"},
"whites":	{"NNS","VBZ"},
"whitest":	{"JJS"},
"whitetail":	{"NN"},
"whitethorn":	{"NN"},
"whitethroat":	{"NN"},
"whitewall":	{"NN","JJ"},
"whitewash":	{"NN","VB","VBP"},
"whitewashed":	{"VBD","VBN"},
"whitewashes":	{"NNS","VBZ"},
"whitewashing":	{"VBG"},
"whitewater":	{"NN"},
"whitewood":	{"NN"},
"whitey":	{"NN"},
"whiting":	{"NN","VBG","NNS"},
"whitings":	{"NNS"},
"whitish":	{"JJ"},
"whitlow":	{"NN"},
"whitlowwort":	{"NN"},
"whittle":	{"VB","VBP"},
"whittled":	{"VBD","VBN"},
"whittler":	{"NN"},
"whittles":	{"VBZ"},
"whittling":	{"VBG"},
"whiz":	{"VB","VBP","NN"},
"whiz-kid":	{"NN"},
"whizbang":	{"NN","JJ"},
"whizz":	{"VB","VBP","NN"},
"whizz-kid":	{"NN"},
"whizz-kids":	{"NNS"},
"whizzbang":	{"NN"},
"whizzed":	{"VBD","VBN"},
"whizzes":	{"NNS","VBZ"},
"whizzing":	{"VBG"},
"who":	{"WP"},
"whoa":	{"UH"},
"whodunit":	{"NN"},
"whodunits":	{"NNS"},
"whodunnit":	{"NN"},
"whodunnits":	{"NNS"},
"whoe'er":	{"WP"},
"whoever":	{"WP"},
"whole":	{"JJ","NN"},
"whole-hearted":	{"JJ"},
"whole-heartedly":	{"RB"},
"wholefood":	{"NN"},
"wholefoods":	{"NNS"},
"wholehearted":	{"JJ"},
"wholeheartedly":	{"RB"},
"wholeheartedness":	{"NN"},
"wholemeal":	{"JJ","NN"},
"wholeness":	{"NN"},
"wholes":	{"NNS"},
"wholesale":	{"JJ","NN","RB","VB","VBP"},
"wholesale-price":	{"JJ"},
"wholesaled":	{"VBD","VBN"},
"wholesaler":	{"NN"},
"wholesalers":	{"NNS"},
"wholesales":	{"VBZ"},
"wholesaling":	{"VBG","NN"},
"wholesome":	{"JJ"},
"wholesomely":	{"RB"},
"wholesomeness":	{"NN"},
"wholewheat":	{"JJ","NN"},
"wholly":	{"RB"},
"whom":	{"WP"},
"whomp":	{"VB","VBP","NN"},
"whomped":	{"VBD","VBN"},
"whomping":	{"VBG"},
"whomps":	{"VBZ"},
"whoop":	{"VB","VBP","NN"},
"whooped":	{"VBD","VBN"},
"whoopee":	{"NN","UH"},
"whooper":	{"NN"},
"whoopie":	{"JJ","NN","UH"},
"whooping":	{"JJ","VBG"},
"whoops":	{"UH","VBZ"},
"whoosh":	{"NN","VB","VBP"},
"whooshed":	{"VBD","VBN"},
"whooshes":	{"VBZ"},
"whooshing":	{"VBG"},
"whop":	{"VBP","VB"},
"whopped":	{"VBD","VBN"},
"whopper":	{"NN"},
"whoppers":	{"NNS"},
"whopping":	{"JJ","RB","VBG"},
"whops":	{"VBZ"},
"whore":	{"NN","VB","VBP"},
"whored":	{"VBD","VBN"},
"whoredom":	{"NN"},
"whorehouse":	{"NN"},
"whorehouses":	{"NNS"},
"whoremaster":	{"NN"},
"whoremonger":	{"NN"},
"whores":	{"VBZ","NNS"},
"whoreson":	{"NN","JJ"},
"whoring":	{"VBG","NN"},
"whorl":	{"NN"},
"whorled":	{"JJ"},
"whorls":	{"NNS"},
"whorlywort":	{"NN"},
"whortleberries":	{"NNS"},
"whortleberry":	{"NN"},
"whose":	{"WP$"},
"whosoever":	{"WP"},
"whup":	{"VB","VBP"},
"whupped":	{"VBD","VBN"},
"whupping":	{"VBG"},
"whups":	{"VBZ"},
"why":	{"WRB","UH","NN"},
"whydah":	{"NN"},
"whys":	{"NNS"},
"wick":	{"NN","VB","VBP"},
"wicked":	{"JJ","VBD","VBN","NNS"},
"wickeder":	{"JJR"},
"wickedest":	{"JJS"},
"wickedly":	{"RB"},
"wickedness":	{"NN"},
"wicker":	{"NN"},
"wickerwork":	{"NN"},
"wicket":	{"NN"},
"wicket-keeper":	{"NN"},
"wicket-keepers":	{"NNS"},
"wickets":	{"NNS"},
"wicking":	{"VBG"},
"wickiup":	{"NN"},
"wickliffe":	{"NN"},
"wicks":	{"NNS","VBZ"},
"wickup":	{"NN"},
"wickups":	{"NNS"},
"wicopies":	{"NNS"},
"wicopy":	{"NN"},
"wide":	{"JJ","RB","NN"},
"wide-angle":	{"JJ"},
"wide-eyed":	{"JJ","RB"},
"wide-ranging":	{"JJ"},
"wideband":	{"JJ","NN"},
"widely":	{"RB"},
"widen":	{"VB","VBP"},
"widened":	{"VBD","VBN"},
"wideness":	{"NN"},
"widening":	{"VBG","NN"},
"widens":	{"VBZ"},
"wider":	{"JJR"},
"widespread":	{"JJ"},
"widest":	{"JJS"},
"widgeon":	{"NN","NNS"},
"widgeons":	{"NNS"},
"widget":	{"NN"},
"widgets":	{"NNS"},
"widow":	{"NN","VB","VBP"},
"widowed":	{"JJ","VBD","VBN"},
"widower":	{"NN"},
"widowers":	{"NNS"},
"widowhood":	{"NN"},
"widowing":	{"VBG"},
"widowman":	{"NN"},
"widowmen":	{"NNS"},
"widows":	{"VBZ","NNS"},
"width":	{"NN"},
"widths":	{"NNS"},
"widthwise":	{"RB"},
"wield":	{"VB","VBP"},
"wieldable":	{"JJ"},
"wielded":	{"VBD","VBN"},
"wielder":	{"NN"},
"wieldier":	{"JJR"},
"wieldiest":	{"JJS"},
"wielding":	{"VBG"},
"wields":	{"VBZ"},
"wieldy":	{"JJ"},
"wiener":	{"NN"},
"wieners":	{"NNS"},
"wienerwurst":	{"NN"},
"wife":	{"NN"},
"wifehood":	{"NN"},
"wifeless":	{"JJ"},
"wifelike":	{"JJ"},
"wifeliness":	{"NN"},
"wifely":	{"JJ"},
"wifi":	{"NN"},
"wig":	{"NN","VB","VBP"},
"wigeon":	{"NN"},
"wigged":	{"JJ","VBD","VBN"},
"wiggier":	{"JJR"},
"wiggiest":	{"JJS"},
"wigging":	{"NN","VBG"},
"wiggle":	{"VB","VBP","NN"},
"wiggled":	{"VBD","VBN"},
"wiggler":	{"NN"},
"wiggles":	{"VBZ","NNS"},
"wiggling":	{"VBG"},
"wiggly":	{"JJ"},
"wiggy":	{"JJ"},
"wight":	{"NN"},
"wigless":	{"JJ"},
"wiglike":	{"JJ"},
"wigmaker":	{"NN"},
"wigmakers":	{"NNS"},
"wignapping":	{"NN"},
"wigs":	{"VBZ","NNS"},
"wigwag":	{"VB","VBP","NN"},
"wigwagged":	{"VBD","VBN"},
"wigwagger":	{"NN"},
"wigwagging":	{"VBG"},
"wigwags":	{"VBZ","NNS"},
"wigwam":	{"NN"},
"wigwams":	{"NNS"},
"wikiup":	{"NN"},
"wild":	{"JJ","RB","NN"},
"wild-carded":	{"JJ"},
"wild-carding":	{"JJ"},
"wild-cards":	{"NNS"},
"wild-eyed":	{"JJ"},
"wildcard":	{"NN"},
"wildcards":	{"NNS"},
"wildcat":	{"JJ","NN","VB","VBP"},
"wildcats":	{"VBZ","NNS"},
"wildcatted":	{"VBD","VBN"},
"wildcatter":	{"NN"},
"wildcatters":	{"NNS"},
"wildcatting":	{"VBG"},
"wildebeest":	{"NN","NNS"},
"wildebeests":	{"NNS"},
"wilder":	{"JJR","VB","VBP"},
"wildered":	{"VBD","VBN"},
"wildering":	{"VBG"},
"wilderness":	{"NN"},
"wildernesses":	{"NNS"},
"wilders":	{"VBZ"},
"wildest":	{"JJS"},
"wildfire":	{"NN"},
"wildfires":	{"NNS"},
"wildflower":	{"NN"},
"wildflowers":	{"NNS"},
"wildfowl":	{"NNS"},
"wildfowler":	{"NN"},
"wildfowling":	{"JJ","NN"},
"wilding":	{"NN","JJ"},
"wildland":	{"NN"},
"wildlands":	{"NNS"},
"wildlife":	{"NN"},
"wildly":	{"RB"},
"wildness":	{"NN"},
"wile":	{"NN","VB","VBP"},
"wiled":	{"VBD","VBN"},
"wiles":	{"NNS","VBZ"},
"wilful":	{"JJ"},
"wilfully":	{"RB"},
"wilfulness":	{"NN"},
"wilier":	{"JJR"},
"wiliest":	{"JJS"},
"wiliness":	{"NN"},
"wiling":	{"VBG"},
"will":	{"MD","NN","VB","VBP"},
"will-o'-the-wisp":	{"NN"},
"will-o'-the-wisps":	{"NNS"},
"willed":	{"VBD","VBN","JJ"},
"willet":	{"NN","NNS"},
"willets":	{"NNS"},
"willful":	{"JJ"},
"willfully":	{"RB"},
"willfulness":	{"NN"},
"willies":	{"NNS"},
"willing":	{"JJ","VBG"},
"willingly":	{"RB"},
"willingness":	{"NN"},
"willling":	{"VBG"},
"willow":	{"NN","VB","VBP"},
"willow-pattern":	{"NN"},
"willowed":	{"VBD","VBN"},
"willowherb":	{"NN"},
"willowing":	{"VBG"},
"willows":	{"NNS","VBZ"},
"willowware":	{"NN"},
"willowy":	{"JJ"},
"willpower":	{"NN"},
"wills":	{"NNS","VBZ"},
"willy":	{"NN"},
"willy-nilly":	{"RB"},
"wilt":	{"VB","VBP","NN"},
"wilted":	{"JJ","VBD","VBN"},
"wilting":	{"VBG"},
"wilts":	{"VBZ","NNS"},
"wily":	{"JJ"},
"wimble":	{"NN"},
"wimp":	{"NN","VB","VBP"},
"wimped":	{"VBD","VBN"},
"wimping":	{"VBG"},
"wimpish":	{"JJ"},
"wimple":	{"VB","VBP","NN"},
"wimpled":	{"VBD","VBN"},
"wimples":	{"NNS","VBZ"},
"wimpling":	{"VBG"},
"wimps":	{"NNS","VBZ"},
"wimpy":	{"JJ"},
"win":	{"VB","VBP","NN"},
"win-win":	{"NN","JJ"},
"wince":	{"VB","VBP","NN"},
"winced":	{"VBD","VBN"},
"winces":	{"VBZ"},
"wincey":	{"NN"},
"winceyette":	{"NN"},
"winch":	{"NN","VB","VBP"},
"winched":	{"VBD","VBN"},
"winches":	{"NNS","VBZ"},
"winching":	{"VBG"},
"wincing":	{"VBG"},
"wind":	{"NN","VB","VBP"},
"wind-blown":	{"JJ"},
"windage":	{"NN"},
"windbag":	{"NN"},
"windbags":	{"NNS"},
"windblown":	{"JJ"},
"windbreak":	{"NN"},
"windbreaker":	{"NN"},
"windbreakers":	{"NNS"},
"windbreaks":	{"NNS"},
"windburn":	{"NN"},
"windburned":	{"JJ"},
"windburnt":	{"JJ"},
"windcheater":	{"NN"},
"winded":	{"JJ","VBD","VBN"},
"winder":	{"NN"},
"winders":	{"NNS"},
"windfall":	{"NN"},
"windfalls":	{"NNS"},
"windflower":	{"NN"},
"windier":	{"JJR"},
"windiest":	{"JJS"},
"windily":	{"RB"},
"windiness":	{"NN"},
"winding":	{"NN","VBG","JJ"},
"winding-sheet":	{"NN"},
"windjammer":	{"NN"},
"windjammers":	{"NNS"},
"windlass":	{"NN","VB","VBP"},
"windlassed":	{"VBD","VBN"},
"windlasses":	{"NNS","VBZ"},
"windlassing":	{"VBG"},
"windless":	{"JJ"},
"windlessness":	{"NN"},
"windmill":	{"NN","VB","VBP"},
"windmilled":	{"VBD","VBN"},
"windmilling":	{"VBG"},
"windmills":	{"NNS","VBZ"},
"window":	{"NN"},
"window-box":	{"NN"},
"window-boxes":	{"NNS"},
"window-dress":	{"VB","VBP"},
"window-dressing":	{"NN","VBG"},
"window-ledge":	{"NN"},
"window-pane":	{"NN"},
"window-shop":	{"VB","VBP"},
"window-shopped":	{"VBD","VBN"},
"window-shopper":	{"NN"},
"window-shoppers":	{"NNS"},
"window-shopping":	{"NN","VBG"},
"window-shops":	{"VBZ"},
"window-sill":	{"NN"},
"window-washing":	{"NN"},
"windowless":	{"JJ"},
"windowpane":	{"NN"},
"windowpanes":	{"NNS"},
"windows":	{"NNS"},
"windowsill":	{"NN"},
"windowsills":	{"NNS"},
"windpipe":	{"NN"},
"windpipes":	{"NNS"},
"winds":	{"NNS","VBZ"},
"windscreen":	{"NN"},
"windscreens":	{"NNS"},
"windshield":	{"NN"},
"windshields":	{"NNS"},
"windsock":	{"NN"},
"windsocks":	{"NNS"},
"windstorm":	{"NN"},
"windstorms":	{"NNS"},
"windsurf":	{"VB","VBP"},
"windsurfed":	{"VBD","VBN"},
"windsurfer":	{"NN"},
"windsurfers":	{"NNS"},
"windsurfing":	{"VBG","NN"},
"windsurfs":	{"VBZ"},
"windswept":	{"JJ"},
"windup":	{"NN"},
"windward":	{"NN","JJ","RB"},
"windwards":	{"RB"},
"windy":	{"JJ"},
"wine":	{"NN","VBP","VB"},
"wine-bottling":	{"NN"},
"wine-cellar":	{"NN"},
"wine-colored":	{"JJ"},
"wine-coloured":	{"JJ"},
"wine-producing":	{"JJ"},
"wineberries":	{"NNS"},
"wineberry":	{"NN"},
"wined":	{"VBD","VBN","JJ"},
"wineglass":	{"NN"},
"winemaker":	{"NN"},
"winemakers":	{"NNS"},
"winemaking":	{"JJ","NN"},
"winepress":	{"NN"},
"wineries":	{"NNS"},
"winery":	{"NN"},
"wines":	{"NNS","VBZ"},
"winesap":	{"NN"},
"wineskin":	{"NN"},
"winey":	{"NN"},
"wing":	{"NN","VBP","VB"},
"wing-chair":	{"NN"},
"wing-nut":	{"NN"},
"wingback":	{"NN","JJ"},
"wingbacks":	{"NNS"},
"wingbeat":	{"NN"},
"winged":	{"JJ","VBD","VBN"},
"winger":	{"NN"},
"wingers":	{"NNS"},
"winging":	{"VBG"},
"wingless":	{"JJ"},
"winglike":	{"JJ"},
"wingman":	{"NN"},
"wingmen":	{"NNS"},
"wings":	{"NNS","VBZ"},
"wingspan":	{"NN"},
"wingspans":	{"NNS"},
"wingspread":	{"NN"},
"wingstem":	{"NN"},
"wingtip":	{"NN"},
"wingtips":	{"NNS"},
"winier":	{"JJR"},
"winiest":	{"JJS"},
"wining":	{"VBG"},
"wink":	{"VB","VBP","NN"},
"winked":	{"VBD","VBN"},
"winker":	{"NN"},
"winking":	{"VBG"},
"winkle":	{"NN","VB","VBP"},
"winkled":	{"VBD","VBN"},
"winkler":	{"NN"},
"winkles":	{"NNS","VBZ"},
"winkling":	{"VBG"},
"winks":	{"VBZ","NNS"},
"winless":	{"JJ"},
"winner":	{"NN"},
"winners":	{"NNS"},
"winning":	{"VBG","JJ"},
"winning-post":	{"NN"},
"winnings":	{"NNS"},
"winnow":	{"VB","VBP","NN"},
"winnowed":	{"VBD","VBN"},
"winnower":	{"NN"},
"winnowing":	{"VBG"},
"winnows":	{"VBZ","NNS"},
"wino":	{"NN"},
"winos":	{"NNS"},
"wins":	{"VBZ","NNS"},
"winsome":	{"JJ"},
"winsomely":	{"RB"},
"winsomeness":	{"NN"},
"winter":	{"NN","VBP","VB"},
"winter/summer":	{"NN"},
"winteraceae":	{"NN"},
"winterberry":	{"NN"},
"wintered":	{"VBD","VBN"},
"wintergreen":	{"NN"},
"winteriness":	{"NN"},
"wintering":	{"VBG"},
"winterise":	{"VB","VBP"},
"winterize":	{"VB","VBP"},
"winters":	{"NNS","VBZ"},
"wintertime":	{"NN"},
"wintery":	{"JJ"},
"wintrier":	{"JJR"},
"wintriest":	{"JJS"},
"wintrily":	{"RB"},
"wintriness":	{"NN"},
"wintry":	{"JJ"},
"winy":	{"JJ"},
"wipe":	{"VB","VBP","NN"},
"wiped":	{"VBD","VBN"},
"wiped-out":	{"JJ"},
"wipeout":	{"NN"},
"wiper":	{"NN"},
"wipers":	{"NNS"},
"wipes":	{"VBZ","NNS"},
"wiping":	{"VBG"},
"wire":	{"NN","VB","VBP"},
"wire-cutter":	{"NN"},
"wire-cutters":	{"NNS"},
"wire-haired":	{"JJ"},
"wire-puller":	{"NN"},
"wire-tapping":	{"NN"},
"wire-worm":	{"NN"},
"wired":	{"JJ","VBD","VBN"},
"wirehair":	{"NN"},
"wireless":	{"JJ","NN","VBP","VB"},
"wirelessed":	{"VBD","VBN"},
"wirelesses":	{"NNS","VBZ"},
"wirelessing":	{"VBG"},
"wireline":	{"NN"},
"wirelines":	{"NNS"},
"wireman":	{"NN"},
"wiremen":	{"NNS"},
"wirer":	{"NN"},
"wires":	{"NNS","VBZ"},
"wiretap":	{"VB","NN","VBP"},
"wiretapped":	{"VBD","VBN"},
"wiretapper":	{"NN"},
"wiretapping":	{"NN","VBG"},
"wiretaps":	{"NNS","VBZ"},
"wirework":	{"NN"},
"wireworker":	{"NN"},
"wireworking":	{"NN"},
"wireworks":	{"NN","NNS"},
"wireworm":	{"NN"},
"wiriness":	{"NN"},
"wiring":	{"NN","VBG"},
"wiry":	{"JJ"},
"wisdom":	{"NN"},
"wisdoms":	{"NNS"},
"wise":	{"JJ","VBP","VB"},
"wiseacre":	{"NN"},
"wisecrack":	{"NN","VB","VBP"},
"wisecracked":	{"VBD","VBN"},
"wisecracker":	{"NN"},
"wisecracking":	{"VBG","JJ"},
"wisecracks":	{"VBZ","NNS"},
"wised":	{"VBD","VBN"},
"wisely":	{"RB"},
"wiseness":	{"NN"},
"wisenheimer":	{"NN"},
"wisent":	{"NN"},
"wiser":	{"JJR"},
"wises":	{"VBZ"},
"wisest":	{"JJS"},
"wish":	{"VBP","NN","VB"},
"wish-list":	{"NN"},
"wish-lists":	{"NNS"},
"wish-wash":	{"NN"},
"wishbone":	{"NN"},
"wishbones":	{"NNS"},
"wished":	{"VBD","VBN"},
"wisher":	{"NN"},
"wishes":	{"NNS","VBZ"},
"wishful":	{"JJ"},
"wishfully":	{"RB"},
"wishfulness":	{"NN"},
"wishing":	{"VBG"},
"wishless":	{"JJ"},
"wishy-washy":	{"JJ"},
"wishywashily":	{"RB"},
"wishywashiness":	{"NN"},
"wising":	{"VBG"},
"wisp":	{"NN","VB","VBP"},
"wisped":	{"VBD","VBN"},
"wisping":	{"VBG"},
"wisplike":	{"JJ"},
"wisps":	{"NNS","VBZ"},
"wispy":	{"JJ"},
"wist":	{"VBD","VBN"},
"wistaria":	{"NN"},
"wisteria":	{"NN"},
"wistful":	{"JJ"},
"wistfully":	{"RB"},
"wistfulness":	{"NN"},
"wit":	{"NN","RB","VB","VBP"},
"witch":	{"NN","VB","VBP"},
"witch-hunt":	{"NN"},
"witch-hunter":	{"NN"},
"witch-hunts":	{"NNS"},
"witchcraft":	{"NN"},
"witched":	{"VBD","VBN"},
"witchery":	{"NN"},
"witches":	{"VBZ","NNS"},
"witchgrass":	{"NN"},
"witching":	{"JJ","NN","VBG"},
"witchlike":	{"JJ"},
"witchy":	{"JJ"},
"with":	{"IN"},
"with-it":	{"JJ"},
"withal":	{"RB","IN"},
"withdraw":	{"VB","VBP"},
"withdrawable":	{"JJ"},
"withdrawal":	{"NN"},
"withdrawals":	{"NNS"},
"withdrawer":	{"NN"},
"withdrawing":	{"VBG"},
"withdrawn":	{"JJ","VBN"},
"withdrawnness":	{"NN"},
"withdraws":	{"VBZ"},
"withdrew":	{"VBD"},
"withe":	{"NN","VB","VBP"},
"withed":	{"VBD","VBN"},
"wither":	{"VB","VBP"},
"withered":	{"JJ","VBD","VBN"},
"withering":	{"JJ","VBG"},
"witheringly":	{"RB"},
"withers":	{"VBZ"},
"withes":	{"NNS","VBZ"},
"withheld":	{"VBD","VBN"},
"withhold":	{"VB","VBP"},
"withholder":	{"NN"},
"withholding":	{"NN","VBG"},
"withholds":	{"VBZ"},
"withies":	{"NNS"},
"within":	{"IN","RB"},
"withing":	{"VBG"},
"without":	{"IN","RB"},
"withstand":	{"VB","VBP"},
"withstander":	{"NN"},
"withstanding":	{"VBG"},
"withstands":	{"VBZ"},
"withstood":	{"VBD","VBN"},
"withy":	{"NN","JJ"},
"witless":	{"JJ"},
"witlessly":	{"RB"},
"witlessness":	{"NN"},
"witloof":	{"NN"},
"witness":	{"NN","VB","VBP"},
"witnessable":	{"JJ"},
"witnessed":	{"VBD","VBN"},
"witnesser":	{"NN"},
"witnesses":	{"NNS","VBZ"},
"witnessing":	{"VBG"},
"wits":	{"NNS","VBZ"},
"witticism":	{"NN"},
"witticisms":	{"NNS"},
"wittier":	{"JJR"},
"wittiest":	{"JJS"},
"wittily":	{"RB"},
"wittiness":	{"NN"},
"witting":	{"JJ","VBG","NN"},
"wittingly":	{"RB"},
"wittol":	{"NN"},
"witty":	{"JJ"},
"wive":	{"VB","VBP"},
"wived":	{"VBD","VBN"},
"wivern":	{"NN"},
"wives":	{"NNS","VBZ"},
"wiving":	{"VBG"},
"wiz":	{"NN"},
"wizard":	{"NN","JJ"},
"wizarding":	{"JJ"},
"wizardly":	{"JJ"},
"wizardry":	{"NN"},
"wizards":	{"NNS"},
"wizen":	{"JJ"},
"wizened":	{"JJ"},
"wo":	{"MD"},
"woad":	{"NN"},
"woadwax":	{"NN"},
"woadwaxen":	{"NN"},
"woadwaxens":	{"NNS"},
"woadwaxes":	{"NNS"},
"wobble":	{"VB","VBP","NN"},
"wobbled":	{"VBD","VBN"},
"wobbler":	{"NN"},
"wobbles":	{"VBZ","NNS"},
"wobbling":	{"VBG","JJ"},
"wobblingly":	{"RB"},
"wobbly":	{"JJ","NN"},
"woe":	{"NN"},
"woebegone":	{"JJ"},
"woeful":	{"JJ"},
"woefully":	{"RB"},
"woefulness":	{"NN"},
"woes":	{"NNS"},
"wog":	{"NN"},
"wogs":	{"NNS"},
"wok":	{"NN"},
"woke":	{"VBD"},
"woken":	{"VBN"},
"woks":	{"NNS"},
"wold":	{"NN"},
"wolf":	{"NN","VB","VBP"},
"wolf-cub":	{"NN"},
"wolf-sized":	{"JJ"},
"wolf-whistle":	{"VB","VBP","NN"},
"wolf-whistled":	{"VBD","VBN"},
"wolf-whistles":	{"VBZ"},
"wolf-whistling":	{"VBG"},
"wolfed":	{"VBD","VBN"},
"wolffia":	{"NN"},
"wolffiella":	{"NN"},
"wolffish":	{"NN","NNS"},
"wolffishes":	{"NNS"},
"wolfhound":	{"NN"},
"wolfhounds":	{"NNS"},
"wolfing":	{"VBG"},
"wolfish":	{"JJ"},
"wolfishly":	{"RB"},
"wolflike":	{"JJ"},
"wolfram":	{"NN"},
"wolframite":	{"NN"},
"wolfs":	{"VBZ"},
"wolfsbane":	{"NN"},
"wollastonite":	{"NN"},
"wolverine":	{"NN"},
"wolves":	{"NNS"},
"woman":	{"NN"},
"womanhood":	{"NN"},
"womanise":	{"VB","VBP"},
"womanised":	{"VBD","VBN"},
"womaniser":	{"NN"},
"womanisers":	{"NNS"},
"womanises":	{"VBZ"},
"womanish":	{"JJ"},
"womanishness":	{"NN"},
"womanising":	{"VBG","NN","JJ"},
"womanize":	{"VB","VBP"},
"womanized":	{"VBD","VBN"},
"womanizer":	{"NN"},
"womanizers":	{"NNS"},
"womanizes":	{"VBZ"},
"womanizing":	{"VBG","NN","JJ"},
"womankind":	{"NN"},
"womanlike":	{"JJ"},
"womanliness":	{"NN"},
"womanly":	{"JJ"},
"womb":	{"NN"},
"womb-leasing":	{"NN"},
"wombat":	{"NN"},
"wombats":	{"NNS"},
"wombed":	{"JJ"},
"womblike":	{"JJ"},
"wombs":	{"NNS"},
"women":	{"NNS"},
"won":	{"VBD","VBN","NN","NNS"},
"wonder":	{"NN","VB","VBP"},
"wonderberry":	{"NN"},
"wondered":	{"VBD","VBN"},
"wonderer":	{"NN"},
"wonderful":	{"JJ"},
"wonderfully":	{"RB"},
"wonderfulness":	{"NN"},
"wondering":	{"VBG","JJ"},
"wonderingly":	{"RB"},
"wonderland":	{"NN"},
"wonderlands":	{"NNS"},
"wonderless":	{"JJ"},
"wonderment":	{"NN"},
"wonders":	{"NNS","VBZ"},
"wonderwork":	{"NN"},
"wonderworker":	{"NN"},
"wonderworking":	{"NN","JJ"},
"wondrous":	{"JJ"},
"wondrously":	{"RB"},
"wong":	{"NN"},
"wongs":	{"NNS"},
"wonk":	{"NN"},
"wonkery":	{"NN"},
"wonkier":	{"JJR"},
"wonkiest":	{"JJS"},
"wonkish":	{"JJ"},
"wonkishness":	{"NN"},
"wonks":	{"NNS"},
"wonky":	{"JJ"},
"wont":	{"NN","JJ","VB","VBP"},
"wonted":	{"JJ","VBD","VBN"},
"wonting":	{"VBG"},
"wonton":	{"NN"},
"wonts":	{"VBZ","NNS"},
"woo":	{"VB","VBP"},
"wood":	{"NN","JJ","VB","VBP"},
"wood-block":	{"NN"},
"wood-lice":	{"NNS"},
"wood-louse":	{"NN"},
"wood-pigeon":	{"NN"},
"wood-pulp":	{"NN"},
"wood-shed":	{"NN"},
"woodbine":	{"NN"},
"woodborer":	{"NN"},
"woodcarver":	{"NN"},
"woodcarving":	{"NN"},
"woodchuck":	{"NN"},
"woodchucks":	{"NNS"},
"woodcock":	{"NN","NNS"},
"woodcocks":	{"NNS"},
"woodcraft":	{"NN"},
"woodcreeper":	{"NN"},
"woodcut":	{"NN"},
"woodcuts":	{"NNS"},
"woodcutter":	{"NN"},
"woodcutters":	{"NNS"},
"wooded":	{"JJ","VBD","VBN"},
"wooden":	{"JJ"},
"woodenly":	{"RB"},
"woodenness":	{"NN"},
"woodenware":	{"NN"},
"woodgrain":	{"NN"},
"woodgraining":	{"NN"},
"woodhewer":	{"NN"},
"woodiness":	{"NN"},
"wooding":	{"VBG"},
"woodland":	{"NN"},
"woodlands":	{"NNS"},
"woodlet":	{"NN"},
"woodlice":	{"NNS"},
"woodlot":	{"NN"},
"woodlots":	{"NNS"},
"woodlouse":	{"NN"},
"woodman":	{"NN"},
"woodpecker":	{"NN"},
"woodpeckers":	{"NNS"},
"woodpile":	{"NN"},
"woodpiles":	{"NNS"},
"woodruff":	{"NN"},
"woods":	{"NNS","VBZ"},
"woodscrew":	{"NN"},
"woodshed":	{"NN"},
"woodsheds":	{"NNS"},
"woodsia":	{"NN"},
"woodsiness":	{"NN"},
"woodsman":	{"NN"},
"woodsmen":	{"NNS"},
"woodsmoke":	{"NN"},
"woodsy":	{"JJ"},
"woodwardia":	{"NN"},
"woodwaxen":	{"NN"},
"woodwind":	{"NN"},
"woodwinds":	{"NNS"},
"woodwork":	{"NN"},
"woodworker":	{"NN"},
"woodworking":	{"NN","JJ"},
"woodworm":	{"NN","NNS"},
"woodworms":	{"NNS"},
"woody":	{"JJ"},
"wooed":	{"VBD","VBN"},
"wooer":	{"NN"},
"woof":	{"UH","NN","VBP","VB"},
"woofed":	{"VBD","VBN"},
"woofer":	{"NN"},
"woofing":	{"VBG"},
"woofs":	{"NNS","VBZ"},
"wooing":	{"VBG","NN"},
"wool":	{"NN"},
"woolen":	{"JJ","NN"},
"woolens":	{"NNS"},
"woolgather":	{"VB","VBP"},
"woolgathered":	{"VBD","VBN"},
"woolgatherer":	{"NN"},
"woolgathering":	{"NN","VBG"},
"woolgatherings":	{"NNS"},
"woolgathers":	{"VBZ"},
"woolier":	{"JJR"},
"woolies":	{"NNS"},
"wooliest":	{"JJS"},
"wooliness":	{"NN"},
"woollen":	{"JJ","NN"},
"woollens":	{"NNS"},
"woollies":	{"NNS"},
"woolliness":	{"NN"},
"woolly":	{"JJ","NN"},
"woolsorter":	{"NN"},
"wooly":	{"JJ","NN"},
"woomera":	{"NN"},
"woos":	{"VBZ"},
"woosh":	{"VB","VBP","NN","UH"},
"wooshed":	{"VBD","VBN"},
"wooshes":	{"VBZ","NNS"},
"wooshing":	{"VBG"},
"woozier":	{"JJR"},
"wooziest":	{"JJS"},
"woozy":	{"JJ"},
"wop":	{"NN"},
"wops":	{"NNS"},
"word":	{"NN","VBP","VB"},
"word-blind":	{"JJ"},
"word-perfect":	{"JJ"},
"word-processing":	{"NN"},
"wordage":	{"NN"},
"wordbook":	{"NN"},
"worded":	{"JJ","VBD","VBN"},
"wordily":	{"RB"},
"wordiness":	{"NN"},
"wording":	{"NN","VBG"},
"wordless":	{"JJ"},
"wordlessly":	{"RB"},
"wordmonger":	{"NN"},
"wordnet":	{"NN"},
"wordplay":	{"NN"},
"words":	{"NNS","VBZ"},
"wordsmith":	{"NN"},
"wordsmiths":	{"NNS"},
"wordy":	{"JJ"},
"wore":	{"VBD"},
"work":	{"NN","VB","VBP"},
"work-basket":	{"NN"},
"work-bench":	{"NN"},
"work-force":	{"NN"},
"work-harden":	{"VB","VBP"},
"work-hardened":	{"VBD","VBN"},
"work-hardening":	{"VBG","NN"},
"work-hardens":	{"VBZ"},
"work-horse":	{"NN"},
"work-in":	{"NN"},
"work-in-progress":	{"NN"},
"work-load":	{"NN"},
"work-out":	{"JJ","NN"},
"work-outs":	{"NNS"},
"work-release":	{"JJ"},
"work-room":	{"NN"},
"work-rule":	{"NN"},
"work-sharer":	{"NN"},
"work-sharing":	{"NN"},
"work-shy":	{"JJ"},
"work-study":	{"JJ","NN"},
"work-table":	{"NN"},
"work-to-rule":	{"NN"},
"work-to-rules":	{"NNS"},
"work-worn":	{"JJ"},
"workability":	{"NN"},
"workable":	{"JJ"},
"workaday":	{"JJ"},
"workaholic":	{"NN"},
"workaholics":	{"NNS"},
"workaholism":	{"NN"},
"workaround":	{"NN"},
"workarounds":	{"NNS"},
"workbag":	{"NN"},
"workbasket":	{"NN"},
"workbench":	{"NN"},
"workbenches":	{"NNS"},
"workboard":	{"NN"},
"workbook":	{"NN"},
"workbooks":	{"NNS"},
"workbox":	{"NN"},
"workday":	{"NN"},
"workdays":	{"NNS"},
"worked":	{"VBD","VBN"},
"worker":	{"NN"},
"workers":	{"NNS"},
"workfare":	{"NN"},
"workfellow":	{"NN"},
"workflow":	{"NN"},
"workforce":	{"NN"},
"workforces":	{"NNS"},
"workgroup":	{"NN"},
"workgroups":	{"NNS"},
"workhorse":	{"NN"},
"workhorses":	{"NNS"},
"workhouse":	{"NN"},
"workhouses":	{"NNS"},
"working":	{"VBG","NN","JJ"},
"working-capital":	{"JJ","NN"},
"working-class":	{"JJ"},
"workingman":	{"NN"},
"workingmen":	{"NNS"},
"workings":	{"NNS"},
"workless":	{"JJ"},
"worklike":	{"JJ"},
"workload":	{"NN"},
"workloads":	{"NNS"},
"workman":	{"NN"},
"workmanlike":	{"JJ"},
"workmanship":	{"NN"},
"workmate":	{"NN"},
"workmates":	{"NNS"},
"workmen":	{"NNS"},
"workout":	{"NN"},
"workouts":	{"NNS"},
"workpiece":	{"NN"},
"workpieces":	{"NNS"},
"workplace":	{"NN"},
"workplaces":	{"NNS"},
"workroom":	{"NN"},
"workrooms":	{"NNS"},
"works":	{"VBZ","NNS"},
"worksheet":	{"NN"},
"worksheets":	{"NNS"},
"workshop":	{"NN"},
"workshops":	{"NNS"},
"worksite":	{"NN"},
"worksites":	{"NNS"},
"workspace":	{"NN"},
"workstation":	{"NN"},
"workstations":	{"NNS"},
"worktable":	{"NN"},
"workwear":	{"NN"},
"workweek":	{"NN"},
"workweeks":	{"NNS"},
"world":	{"NN","JJ"},
"world-beater":	{"NN"},
"world-beaters":	{"NNS"},
"world-beating":	{"JJ"},
"world-class":	{"JJ"},
"world-famous":	{"JJ"},
"world-view":	{"NN"},
"world-weariness":	{"NN"},
"world-weary":	{"JJ"},
"world-wide":	{"JJ","RB"},
"worldlier":	{"JJR"},
"worldliest":	{"JJS"},
"worldliness":	{"NN"},
"worldling":	{"NN"},
"worldly":	{"JJ"},
"worldly-minded":	{"JJ"},
"worldly-wise":	{"JJ"},
"worlds":	{"NNS"},
"worldview":	{"NN"},
"worldviews":	{"NNS"},
"worldwide":	{"JJ","RB"},
"worm":	{"NN","VB","VBP"},
"worm-eaten":	{"JJ"},
"worm-shaped":	{"JJ"},
"wormcast":	{"NN"},
"wormed":	{"VBD","VBN"},
"wormhole":	{"NN"},
"worming":	{"VBG"},
"wormlike":	{"JJ"},
"worms":	{"NNS","VBZ"},
"wormseed":	{"NN"},
"wormwood":	{"NN"},
"wormy":	{"JJ"},
"worn":	{"VBN","JJ"},
"worn-out":	{"JJ"},
"worried":	{"VBN","VBD","JJ"},
"worriedly":	{"RB"},
"worrier":	{"NN"},
"worriers":	{"NNS"},
"worries":	{"NNS","VBZ"},
"worriless":	{"JJ"},
"worriment":	{"NN"},
"worrisome":	{"JJ"},
"worry":	{"VB","VBP","NN"},
"worrying":	{"VBG","JJ"},
"worryingly":	{"RB"},
"worrywart":	{"NN"},
"worse":	{"JJR","RBR","NN"},
"worsen":	{"VB","VBP"},
"worsened":	{"VBD","VBN"},
"worsening":	{"NN","VBG","JJ"},
"worsens":	{"VBZ"},
"worship":	{"NN","VB","VBP"},
"worshiped":	{"VBD","VBN"},
"worshiper":	{"NN"},
"worshipers":	{"NNS"},
"worshipful":	{"JJ"},
"worshiping":	{"VBG"},
"worshipped":	{"VBD","VBN"},
"worshipper":	{"NN"},
"worshippers":	{"NNS"},
"worshipping":	{"VBG"},
"worships":	{"VBZ"},
"worst":	{"JJS","NN","RBS","VB","VBP"},
"worsted":	{"VBD","VBN","NN"},
"worsteds":	{"NNS"},
"worsting":	{"VBG"},
"worsts":	{"VBZ"},
"wort":	{"NN"},
"worth":	{"JJ","NN","IN"},
"worthful":	{"JJ"},
"worthier":	{"JJR"},
"worthiest":	{"JJS"},
"worthily":	{"RB"},
"worthiness":	{"NN"},
"worthless":	{"JJ"},
"worthlessly":	{"RB"},
"worthlessness":	{"NN"},
"worthwhile":	{"JJ"},
"worthwhileness":	{"NN"},
"worthy":	{"JJ","NN"},
"wot":	{"WP","WDT"},
"would":	{"MD"},
"would-be":	{"JJ","NN"},
"wound":	{"VBD","VBN","NN","VB","VBP"},
"woundable":	{"JJ"},
"wounded":	{"VBN","VBD","JJ","NNS"},
"wounder":	{"NN"},
"wounding":	{"JJ","VBG"},
"woundingly":	{"RB"},
"woundless":	{"JJ"},
"wounds":	{"NNS","VBZ"},
"wove":	{"VBD"},
"woven":	{"VBN","JJ"},
"wow":	{"UH","VB","VBP","NN"},
"wowed":	{"VBD","VBN"},
"wowing":	{"VBG"},
"wows":	{"VBZ"},
"wpm":	{"NN"},
"wrack":	{"NN","VB","VBP"},
"wracked":	{"VBD","VBN"},
"wracking":	{"VBG"},
"wracks":	{"VBZ"},
"wraith":	{"NN"},
"wraith-like":	{"JJ"},
"wraithlike":	{"JJ"},
"wraiths":	{"NNS"},
"wrangle":	{"NN","VB","VBP"},
"wrangled":	{"VBD","VBN"},
"wrangler":	{"NN"},
"wranglers":	{"NNS"},
"wrangles":	{"NNS","VBZ"},
"wrangling":	{"VBG","NN"},
"wranglings":	{"NNS"},
"wrap":	{"VB","NN","VBP"},
"wrap-around":	{"JJ"},
"wrap-up":	{"NN"},
"wraparound":	{"NN"},
"wrapped":	{"VBN","VBD","JJ"},
"wrapper":	{"NN"},
"wrappers":	{"NNS"},
"wrapping":	{"NN","VBG"},
"wrappings":	{"NNS"},
"wraps":	{"VBZ","NNS"},
"wrasse":	{"NN","NNS"},
"wrasses":	{"NNS"},
"wrath":	{"NN"},
"wrathful":	{"JJ"},
"wrathfully":	{"RB"},
"wrawl":	{"VB","VBP"},
"wreak":	{"VB","VBP"},
"wreaked":	{"VBD","VBN"},
"wreaking":	{"VBG"},
"wreaks":	{"VBZ"},
"wreath":	{"NN"},
"wreathe":	{"VB","VBP"},
"wreathed":	{"VBD","VBN"},
"wreathes":	{"VBZ"},
"wreathing":	{"VBG"},
"wreaths":	{"NNS"},
"wreck":	{"NN","VB","VBP"},
"wreckage":	{"NN"},
"wrecked":	{"JJ","VBD","VBN"},
"wrecker":	{"NN"},
"wreckers":	{"NNS"},
"wreckfish":	{"NN","NNS"},
"wreckfishes":	{"NNS"},
"wrecking":	{"NN","VBG"},
"wrecks":	{"NNS","VBZ"},
"wren":	{"NN"},
"wrench":	{"VB","VBP","NN"},
"wrenched":	{"VBD","VBN"},
"wrenches":	{"NNS","VBZ"},
"wrenching":	{"JJ","VBG"},
"wrenchingly":	{"RB"},
"wrens":	{"NNS"},
"wrest":	{"VB","VBP","NN"},
"wrested":	{"VBD","VBN"},
"wrester":	{"NN"},
"wresting":	{"VBG"},
"wrestle":	{"VB","VBP","NN"},
"wrestled":	{"VBD","VBN","JJ"},
"wrestler":	{"NN"},
"wrestlers":	{"NNS"},
"wrestles":	{"VBZ","NNS"},
"wrestling":	{"NN","VBG"},
"wrests":	{"VBZ"},
"wretch":	{"NN"},
"wretched":	{"JJ"},
"wretchedly":	{"RB"},
"wretchedness":	{"NN"},
"wretches":	{"NNS"},
"wrick":	{"NN","VB","VBP"},
"wricked":	{"VBD","VBN"},
"wricking":	{"VBG"},
"wricks":	{"VBZ"},
"wriggle":	{"VB","VBP","NN"},
"wriggled":	{"VBD","VBN"},
"wriggler":	{"NN"},
"wriggles":	{"VBZ","NNS"},
"wriggling":	{"VBG"},
"wriggly":	{"JJ"},
"wright":	{"NN"},
"wring":	{"VBP","NN","VB"},
"wringer":	{"NN"},
"wringing":	{"VBG"},
"wrings":	{"VBZ","NNS"},
"wrinkle":	{"NN","VB","VBP"},
"wrinkle-fighting":	{"JJ"},
"wrinkle-resistant":	{"JJ"},
"wrinkled":	{"VBD","VBN","JJ"},
"wrinkleless":	{"JJ"},
"wrinkles":	{"VBZ","NNS"},
"wrinklies":	{"NNS"},
"wrinkling":	{"VBG"},
"wrinkly":	{"JJ","NN"},
"wrist":	{"NN"},
"wristband":	{"NN"},
"wristlet":	{"NN"},
"wrists":	{"NNS"},
"wristwatch":	{"NN"},
"wristwatches":	{"NNS"},
"writ":	{"NN","JJ"},
"write":	{"VB","VBP"},
"write-down":	{"NN"},
"write-downs":	{"NNS"},
"write-in":	{"NN"},
"write-ins":	{"NNS"},
"write-off":	{"NN"},
"write-offs":	{"NNS"},
"writer":	{"NN"},
"writers":	{"NNS"},
"writes":	{"VBZ"},
"writhe":	{"VB","VBP","NN"},
"writhed":	{"VBD","VBN"},
"writhen":	{"JJ"},
"writher":	{"NN"},
"writhes":	{"VBZ"},
"writhing":	{"VBG","NN"},
"writhings":	{"NNS"},
"writing":	{"VBG","NN"},
"writing-desk":	{"NN"},
"writing-paper":	{"NN"},
"writings":	{"NNS"},
"writs":	{"NNS"},
"written":	{"VBN","JJ"},
"wrong":	{"JJ","NN","RB","VBP","VB"},
"wrong-foot":	{"VB","VBP"},
"wrong-footed":	{"VBD","VBN"},
"wrong-footing":	{"VBG"},
"wrong-foots":	{"VBZ"},
"wrong-headed":	{"JJ"},
"wrong-side-out":	{"JJ"},
"wrongdoer":	{"NN"},
"wrongdoers":	{"NNS"},
"wrongdoing":	{"NN"},
"wrongdoings":	{"NNS"},
"wronged":	{"VBD","VBN"},
"wrongful":	{"JJ"},
"wrongfully":	{"RB"},
"wrongfulness":	{"NN"},
"wrongheaded":	{"JJ"},
"wrongheadedly":	{"RB"},
"wrongheadedness":	{"NN"},
"wronging":	{"VBG"},
"wrongly":	{"RB"},
"wrongness":	{"NN"},
"wrongs":	{"VBZ","NNS"},
"wrote":	{"VBD"},
"wroth":	{"JJ"},
"wrought":	{"JJ","VBD","VBN"},
"wrought-iron":	{"JJ"},
"wrung":	{"VBD","VBN"},
"wry":	{"JJ"},
"wryer":	{"JJR"},
"wryest":	{"JJS"},
"wryly":	{"RB"},
"wrymouth":	{"NN"},
"wryneck":	{"NN"},
"wryness":	{"NN"},
"wt":	{"NN"},
"wulfenite":	{"NN"},
"wurtzite":	{"NN"},
"wus":	{"NN"},
"wuss":	{"NN"},
"wusses":	{"NNS"},
"wussier":	{"JJR"},
"wussies":	{"NNS"},
"wussiest":	{"JJS"},
"wussy":	{"NN","JJ"},
"wyomingite":	{"NN"},
"wysiwyg":	{"NN"},
"wyvern":	{"NN"},
"x":	{"NN","LS","SYM"},
"x-axis":	{"NN"},
"x-radiation":	{"NN"},
"xanthate":	{"NN"},
"xanthation":	{"NN"},
"xanthelasma":	{"NN"},
"xanthemia":	{"NN"},
"xanthine":	{"NN"},
"xanthium":	{"NN"},
"xanthoma":	{"NN"},
"xanthomatosis":	{"NN"},
"xanthomonad":	{"NN"},
"xanthophyceae":	{"NN"},
"xanthophyl":	{"NN"},
"xanthophyll":	{"NN"},
"xanthophyllous":	{"JJ"},
"xanthopsia":	{"NN"},
"xanthorrhoeaceae":	{"NN"},
"xanthorroea":	{"NN"},
"xanthosis":	{"NN"},
"xanthosoma":	{"NN"},
"xanthous":	{"JJ"},
"xantusiidae":	{"NN"},
"xenarthra":	{"NN"},
"xenicidae":	{"NN"},
"xenicus":	{"NNS"},
"xenogeneic":	{"JJ"},
"xenogenesis":	{"NN"},
"xenograft":	{"NN"},
"xenolith":	{"NN"},
"xenon":	{"NN"},
"xenophobia":	{"NN"},
"xenophobic":	{"JJ"},
"xenopodidae":	{"NN"},
"xenopus":	{"NN"},
"xenorhyncus":	{"NNS"},
"xenosauridae":	{"NN"},
"xenosaurus":	{"NN"},
"xenotime":	{"NN"},
"xenotransplant":	{"NN"},
"xenotransplantation":	{"NN"},
"xeranthemum":	{"NN"},
"xeric":	{"JJ"},
"xerobates":	{"NNS"},
"xeroderma":	{"NN"},
"xerodermia":	{"NN"},
"xerographic":	{"JJ"},
"xerography":	{"NN"},
"xeroma":	{"NN"},
"xerophile":	{"NN"},
"xerophthalmia":	{"NN"},
"xerophthalmus":	{"NN"},
"xerophyllum":	{"NN"},
"xerophyte":	{"NN"},
"xerophytic":	{"JJ"},
"xeroradiography":	{"NN"},
"xerostomia":	{"NN"},
"xerotes":	{"NN"},
"xi":	{"NN"},
"xii":	{"JJ","NN"},
"xiii":	{"JJ","NN"},
"xiphias":	{"NN","NNS"},
"xiphiidae":	{"NN"},
"xiphosura":	{"NN"},
"xiv":	{"JJ","NN"},
"xix":	{"JJ","NN"},
"xl":	{"JJ","NN"},
"xli":	{"JJ"},
"xlii":	{"JJ"},
"xliii":	{"JJ"},
"xliv":	{"JJ"},
"xlv":	{"JJ"},
"xlvi":	{"JJ"},
"xlvii":	{"JJ"},
"xlviii":	{"JJ"},
"xv":	{"JJ","NN"},
"xvi":	{"JJ","NN"},
"xvii":	{"JJ","NN"},
"xviii":	{"JJ","NN"},
"xx":	{"JJ","NN"},
"xxi":	{"JJ","NN"},
"xxii":	{"JJ","NN"},
"xxiii":	{"JJ","NN"},
"xxiv":	{"JJ","NN"},
"xxix":	{"JJ","NN"},
"xxv":	{"JJ","NN"},
"xxvi":	{"JJ","NN"},
"xxvii":	{"JJ","NN"},
"xxviii":	{"JJ","NN"},
"xxx":	{"JJ","NN"},
"xxxi":	{"JJ","NN"},
"xxxii":	{"JJ","NN"},
"xxxiii":	{"JJ","NN"},
"xxxiv":	{"JJ","NN"},
"xxxv":	{"JJ","NN"},
"xxxvi":	{"JJ","NN"},
"xxxvii":	{"JJ","NN"},
"xxxviii":	{"JJ","NN"},
"xylaria":	{"NN"},
"xylariaceae":	{"NN"},
"xylem":	{"NN"},
"xylene":	{"NN"},
"xylocaine":	{"NN"},
"xylocopa":	{"NN"},
"xylol":	{"NN"},
"xylomelum":	{"NN"},
"xylophone":	{"NN"},
"xylophones":	{"NNS"},
"xylophonist":	{"NN"},
"xylopia":	{"NN"},
"xylose":	{"NN"},
"xylosma":	{"NN"},
"xyphophorus":	{"NN"},
"xyridaceae":	{"NN"},
"xyridales":	{"NNS"},
"xyris":	{"NN"},
"y":	{"NN","SYM","LS"},
"y-axis":	{"NN"},
"ya":	{"PRP"},
"yacca":	{"NN"},
"yacht":	{"NN","VB","VBP"},
"yachted":	{"VBD","VBN"},
"yachtel":	{"NN"},
"yachtels":	{"NNS"},
"yachter":	{"NN"},
"yachters":	{"NNS"},
"yachting":	{"NN","VBG"},
"yachts":	{"NNS","VBZ"},
"yachtsman":	{"NN"},
"yachtsmen":	{"NNS"},
"yachtswoman":	{"NN"},
"yachtswomen":	{"NNS"},
"yack":	{"VB","VBP","NN"},
"yacka":	{"NN"},
"yagi":	{"NN"},
"yahoo":	{"UH","NN"},
"yahoos":	{"NNS"},
"yak":	{"NN","NNS","VB","VBP"},
"yakety-yak":	{"NN"},
"yakked":	{"VBD","VBN"},
"yakking":	{"VBG"},
"yaks":	{"NNS","VBZ"},
"yakuza":	{"NN","NNS"},
"yam":	{"NN"},
"yammer":	{"VB","VBP","NN"},
"yammered":	{"VBD","VBN"},
"yammerer":	{"NN"},
"yammering":	{"VBG","NN"},
"yammers":	{"VBZ"},
"yams":	{"NNS"},
"yang":	{"NN"},
"yank":	{"VB","VBP","NN"},
"yanked":	{"VBD","VBN"},
"yanker":	{"NN"},
"yanking":	{"VBG"},
"yanks":	{"VBZ","NNS"},
"yap":	{"VB","VBP","NN"},
"yapped":	{"VBD","VBN"},
"yapping":	{"VBG","JJ","NN"},
"yaps":	{"VBZ","NNS"},
"yard":	{"NN","VB","VBP"},
"yardage":	{"NN"},
"yardarm":	{"NN"},
"yardbird":	{"NN"},
"yarded":	{"VBD","VBN"},
"yarder":	{"NN"},
"yarding":	{"VBG"},
"yardman":	{"NN"},
"yardmaster":	{"NN"},
"yards":	{"NNS","VBZ"},
"yardstick":	{"NN"},
"yardsticks":	{"NNS"},
"yardwork":	{"NN"},
"yarmelke":	{"NN"},
"yarmulka":	{"NN"},
"yarmulke":	{"NN"},
"yarn":	{"NN","VB","VBP"},
"yarn-dye":	{"VB","VBP"},
"yarn-dyed":	{"JJ"},
"yarned":	{"VBD","VBN"},
"yarning":	{"VBG"},
"yarns":	{"NNS","VBZ"},
"yarrow":	{"NN"},
"yashmac":	{"NN"},
"yashmak":	{"NN"},
"yataghan":	{"NN"},
"yatobyo":	{"NN"},
"yaup":	{"VB","VBP","NN"},
"yautia":	{"NN"},
"yaw":	{"VB","VBP","NN"},
"yawed":	{"VBD","VBN"},
"yawing":	{"VBG"},
"yawl":	{"NN"},
"yawn":	{"VB","VBP","NN"},
"yawned":	{"VBD","VBN"},
"yawner":	{"NN"},
"yawning":	{"JJ","VBG"},
"yawningly":	{"RB"},
"yawns":	{"NNS","VBZ"},
"yawp":	{"NN"},
"yaws":	{"NNS","VBZ","NN"},
"yay":	{"UH","NN","RB"},
"yd":	{"NN","NNS"},
"yd.":	{"NN","NNS"},
"yds":	{"NNS"},
"yds.":	{"NNS"},
"ye":	{"PRP","DT"},
"yea":	{"NN","RB"},
"yeah":	{"UH","RB"},
"year":	{"NN"},
"year-book":	{"NN"},
"year-end":	{"NN","JJ"},
"year-long":	{"JJ"},
"year-old":	{"JJ"},
"year-round":	{"JJ","RB"},
"yearbook":	{"NN"},
"yearbooks":	{"NNS"},
"yeard":	{"VB","VBP","NN"},
"yearend":	{"NN","JJ"},
"yearling":	{"NN","JJ"},
"yearlings":	{"NNS"},
"yearlong":	{"JJ"},
"yearly":	{"JJ","RB"},
"yearn":	{"VB","VBP"},
"yearned":	{"VBD","VBN"},
"yearner":	{"NN"},
"yearning":	{"NN","VBG"},
"yearningly":	{"RB"},
"yearnings":	{"NNS"},
"yearns":	{"VBZ"},
"years":	{"NNS"},
"yeast":	{"NN","VB","VBP"},
"yeasted":	{"VBD","VBN"},
"yeasting":	{"VBG"},
"yeastless":	{"JJ"},
"yeastlike":	{"JJ"},
"yeasts":	{"NNS","VBZ"},
"yeasty":	{"JJ"},
"yeh":	{"UH","RB"},
"yell":	{"VB","VBP","NN"},
"yelled":	{"VBD","VBN"},
"yeller":	{"NN"},
"yelling":	{"VBG","NN","JJ"},
"yellow":	{"JJ","NN","VB","VBP"},
"yellow-bellied":	{"JJ"},
"yellowbird":	{"NN"},
"yellowcake":	{"NN"},
"yellowed":	{"VBD","VBN"},
"yellowfin":	{"NN"},
"yellowhammer":	{"NN"},
"yellowing":	{"VBG"},
"yellowish":	{"JJ"},
"yellowlegs":	{"NN","NNS"},
"yellowness":	{"NN"},
"yellows":	{"NNS","VBZ"},
"yellowtail":	{"NN","NNS"},
"yellowtails":	{"NNS"},
"yellowthroat":	{"NN"},
"yellowwood":	{"NN"},
"yells":	{"VBZ","NNS"},
"yelp":	{"NN","VB","VBP"},
"yelped":	{"VBD","VBN"},
"yelping":	{"VBG"},
"yelps":	{"VBZ","NNS"},
"yen":	{"NN","NNS","VB","VBP"},
"yenned":	{"VBD","VBN"},
"yenning":	{"VBG"},
"yens":	{"VBZ"},
"yenta":	{"NN"},
"yeoman":	{"NN"},
"yeomanry":	{"NN"},
"yeomen":	{"NNS"},
"yes":	{"RB","UH","NN","VB","VBP","JJ"},
"yes-man":	{"NN"},
"yes-men":	{"NNS"},
"yeses":	{"NNS","VBZ"},
"yeshiva":	{"NN"},
"yeshivah":	{"NN"},
"yessed":	{"VBD","VBN"},
"yessing":	{"VBG"},
"yesterday":	{"NN","RB"},
"yesterdays":	{"NNS"},
"yesteryear":	{"NN"},
"yet":	{"RB","CC","RP"},
"yeti":	{"NN"},
"yew":	{"NN"},
"yews":	{"NNS"},
"yid":	{"NN"},
"yield":	{"VB","VBP","NN"},
"yielded":	{"VBD","VBN"},
"yielder":	{"NN"},
"yielding":	{"JJ","VBG"},
"yieldingly":	{"RB"},
"yields":	{"NNS","VBZ"},
"yin":	{"NN"},
"yip":	{"VB","VBP","NN"},
"yipped":	{"VBD","VBN"},
"yipping":	{"VBG"},
"yips":	{"NNS","VBZ"},
"ylang-ylang":	{"NN"},
"ylem":	{"NN"},
"yo":	{"UH"},
"yo-yo":	{"NN","JJ","VB","VBP"},
"yo-yoed":	{"VBD","VBN"},
"yo-yoing":	{"VBG"},
"yo-yos":	{"NNS","VBZ"},
"yob":	{"NN"},
"yobbo":	{"NN"},
"yobbos":	{"NNS"},
"yobibyte":	{"NN"},
"yobs":	{"NNS"},
"yodel":	{"VB","VBP","NN"},
"yodeled":	{"VBD","VBN"},
"yodeling":	{"NN","VBG"},
"yodelled":	{"VBD","VBN"},
"yodeller":	{"NN"},
"yodelling":	{"VBG","NN"},
"yodels":	{"VBZ","NNS"},
"yodh":	{"NN"},
"yoga":	{"NN"},
"yogacara":	{"NN"},
"yoghourt":	{"NN"},
"yoghurt":	{"NN"},
"yogi":	{"NN"},
"yogic":	{"JJ"},
"yogis":	{"NNS"},
"yogurt":	{"NN"},
"yogurts":	{"NNS"},
"yoke":	{"NN","VB","VBP"},
"yoked":	{"VBD","VBN"},
"yokel":	{"NN"},
"yokelish":	{"JJ"},
"yokels":	{"NNS"},
"yokes":	{"NNS","VBZ"},
"yoking":	{"VBG"},
"yolk":	{"NN"},
"yolks":	{"NNS"},
"yon":	{"JJ","RB","PRP"},
"yonder":	{"JJ","RB","DT"},
"yore":	{"NN"},
"yottabit":	{"NN"},
"yottabyte":	{"NN"},
"you":	{"PRP"},
"young":	{"JJ","NNS"},
"youngblood":	{"NN"},
"younger":	{"JJR"},
"youngest":	{"JJS"},
"youngish":	{"JJ"},
"youngness":	{"NN"},
"youngster":	{"NN"},
"youngsters":	{"NNS"},
"younker":	{"NN"},
"your":	{"PRP$"},
"yours":	{"PRP"},
"yourself":	{"PRP"},
"yourselves":	{"PRP"},
"youth":	{"NN"},
"youthful":	{"JJ"},
"youthfully":	{"RB"},
"youthfulness":	{"NN"},
"youths":	{"NNS"},
"yow":	{"UH"},
"yowl":	{"VB","VBP","NN"},
"yowled":	{"VBD","VBN"},
"yowling":	{"VBG","NN"},
"yowls":	{"VBZ","NNS"},
"yr":	{"NN"},
"yr.":	{"NN"},
"yrs":	{"NNS"},
"yrs.":	{"NNS"},
"ytterbite":	{"NN"},
"ytterbium":	{"NN"},
"yttrium":	{"NN"},
"yuan":	{"NN","NNS"},
"yucca":	{"NN"},
"yuccas":	{"NNS"},
"yucky":	{"JJ"},
"yuk":	{"UH","NN","VB","VBP"},
"yukked":	{"VBD","VBN"},
"yukking":	{"VBG"},
"yuks":	{"NNS","VBZ"},
"yule":	{"NN"},
"yummy":	{"JJ"},
"yuppie":	{"NN"},
"yuppies":	{"NNS"},
"yurt":	{"NN"},
"z":	{"NN","SYM","LS"},
"z-axis":	{"NN"},
"zabaglione":	{"NN"},
"zaftig":	{"JJ"},
"zag":	{"NN","VB","VBP","RB"},
"zagged":	{"VBD","VBN"},
"zagging":	{"VBG"},
"zaglossus":	{"NNS"},
"zags":	{"NNS","VBZ"},
"zakat":	{"NN"},
"zalcitabine":	{"NN"},
"zalophus":	{"NNS"},
"zamia":	{"NN"},
"zamiaceae":	{"NN"},
"zanier":	{"JJR"},
"zanies":	{"NNS"},
"zaniest":	{"JJS"},
"zannichellia":	{"NN"},
"zannichelliaceae":	{"NN"},
"zantac":	{"NN"},
"zantedeschia":	{"NN"},
"zanthoxylum":	{"NN"},
"zany":	{"JJ","NN"},
"zap":	{"VB","VBP","NN"},
"zapodidae":	{"NN"},
"zapped":	{"VBD","VBN"},
"zapper":	{"NN"},
"zappers":	{"NNS"},
"zapping":	{"VBG"},
"zaps":	{"VBZ"},
"zapus":	{"NNS"},
"zarf":	{"NN"},
"zarfs":	{"NNS"},
"zarontin":	{"NN"},
"zarpanit":	{"NN"},
"zayin":	{"NN"},
"zbit":	{"NN"},
"zea":	{"NN"},
"zeal":	{"NN"},
"zealot":	{"NN"},
"zealotry":	{"NN"},
"zealots":	{"NNS"},
"zealous":	{"JJ"},
"zealously":	{"RB"},
"zeaxanthin":	{"NN"},
"zebibit":	{"NN"},
"zebibyte":	{"NN"},
"zebra":	{"NN","NNS"},
"zebras":	{"NNS"},
"zebrawood":	{"NN"},
"zebu":	{"NN"},
"zed":	{"NN"},
"zee":	{"NN"},
"zegapain":	{"FW"},
"zeidae":	{"NN"},
"zeitgeist":	{"NN"},
"zenith":	{"NN"},
"zenithal":	{"JJ"},
"zeolite":	{"NN"},
"zep":	{"NN"},
"zephyr":	{"NN"},
"zephyrs":	{"NNS"},
"zeppelin":	{"NN"},
"zero":	{"CD","NN","VB","VBP"},
"zero-hour":	{"NN"},
"zero-rated":	{"JJ"},
"zeroed":	{"VBD","VBN"},
"zeroes":	{"NNS","VBZ"},
"zeroing":	{"VBG"},
"zeros":	{"NNS","VBZ"},
"zeroth":	{"JJ"},
"zest":	{"NN","VB","VBP"},
"zested":	{"VBD","VBN"},
"zestful":	{"JJ"},
"zestfully":	{"RB"},
"zestfulness":	{"NN"},
"zestily":	{"RB"},
"zesting":	{"VBG"},
"zestril":	{"NN"},
"zests":	{"VBZ"},
"zesty":	{"JJ"},
"zeta":	{"NN"},
"zettabit":	{"NN"},
"zettabyte":	{"NN"},
"zeugma":	{"NN"},
"zeugmatic":	{"JJ"},
"zeugmatically":	{"RB"},
"zidovudine":	{"NN"},
"zig":	{"NN","VB","VBP"},
"zig-zag":	{"NN","JJ","RB","VB","VBP"},
"zigadene":	{"NN"},
"zigadenus":	{"NN"},
"zigged":	{"VBD","VBN"},
"zigging":	{"VBG"},
"ziggurat":	{"NN"},
"zigs":	{"NNS","VBZ"},
"zigzag":	{"NN","JJ","RB","VB","VBP"},
"zigzagged":	{"VBD","VBN"},
"zigzagging":	{"VBG"},
"zigzags":	{"VBZ","NNS"},
"zikkurat":	{"NN"},
"zikurat":	{"NN"},
"zilch":	{"NN"},
"zill":	{"NN"},
"zillion":	{"CD","NN"},
"zillions":	{"NNS"},
"zinacef":	{"NN"},
"zinc":	{"NN","VB","VBP"},
"zinced":	{"VBD","VBN"},
"zincic":	{"JJ"},
"zincing":	{"VBG"},
"zincked":	{"VBD","VBN"},
"zincking":	{"VBG"},
"zincks":	{"VBZ"},
"zincky":	{"JJ"},
"zincoid":	{"JJ"},
"zincous":	{"JJ"},
"zincs":	{"VBZ"},
"zincy":	{"JJ"},
"zing":	{"NN","VB","VBP"},
"zinged":	{"VBD","VBN"},
"zinger":	{"NN"},
"zingers":	{"NNS"},
"zingiber":	{"NN"},
"zingiberaceae":	{"NN"},
"zinging":	{"VBG"},
"zings":	{"VBZ"},
"zinkenite":	{"NN"},
"zinky":	{"JJ"},
"zinnia":	{"NN"},
"zinnwaldite":	{"NN"},
"zip":	{"NN","VB","VBP"},
"ziphiidae":	{"NN"},
"zipped":	{"VBD","VBN","JJ"},
"zipper":	{"NN","VB","VBP"},
"zippered":	{"VBD","VBN"},
"zippering":	{"VBG"},
"zippers":	{"NNS","VBZ"},
"zippier":	{"JJR"},
"zippiest":	{"JJS"},
"zipping":	{"VBG"},
"zippo":	{"NN"},
"zippy":	{"JJ"},
"zips":	{"NNS","VBZ"},
"zirbanit":	{"NN"},
"zircon":	{"NN"},
"zirconate":	{"NN"},
"zirconia":	{"NN"},
"zirconium":	{"NN"},
"zit":	{"NN"},
"zither":	{"NN"},
"zithern":	{"NN"},
"zithers":	{"NNS"},
"zithromax":	{"NN"},
"ziti":	{"NN"},
"zits":	{"NNS"},
"zizania":	{"NN"},
"ziziphus":	{"NN"},
"zizz":	{"NN","VB","VBP"},
"zizzed":	{"VBD","VBN"},
"zizzes":	{"NNS","VBZ"},
"zizzing":	{"VBG"},
"zloties":	{"NNS"},
"zloty":	{"NN"},
"zlotys":	{"NNS"},
"zoanthropy":	{"NN"},
"zoarces":	{"NN"},
"zoarcidae":	{"NN"},
"zocor":	{"NN"},
"zodiac":	{"NN"},
"zodiacal":	{"JJ"},
"zoftig":	{"JJ"},
"zoic":	{"JJ"},
"zolaesque":	{"JJ"},
"zoloft":	{"NN"},
"zombi":	{"NN"},
"zombie":	{"NN"},
"zombies":	{"NNS"},
"zombified":	{"VBD","VBN"},
"zombifies":	{"VBZ"},
"zombify":	{"VB","VBP"},
"zombifying":	{"VBG"},
"zona":	{"NN"},
"zonal":	{"JJ"},
"zonary":	{"JJ"},
"zone":	{"NN","VB","VBP"},
"zoned":	{"VBN","JJ","VBD"},
"zones":	{"NNS","VBZ"},
"zoning":	{"NN","VBG"},
"zonotrichia":	{"NN"},
"zonula":	{"NN"},
"zonule":	{"NN"},
"zoo":	{"NN"},
"zooerastia":	{"NN"},
"zooerasty":	{"NN"},
"zooflagellate":	{"NN"},
"zooid":	{"NN","JJ"},
"zookeeper":	{"NN"},
"zoolatry":	{"NN"},
"zoological":	{"JJ"},
"zoologically":	{"RB"},
"zoologist":	{"NN"},
"zoologists":	{"NNS"},
"zoology":	{"NN"},
"zoom":	{"VB","VBP","NN"},
"zoomastigina":	{"NN"},
"zoomastigote":	{"NN"},
"zoomed":	{"VBD","VBN"},
"zooming":	{"VBG"},
"zoomorphism":	{"NN"},
"zooms":	{"VBZ","NNS"},
"zoonosis":	{"NN"},
"zoonotic":	{"JJ"},
"zoophagous":	{"JJ"},
"zoophilia":	{"NN"},
"zoophilism":	{"NN"},
"zoophobia":	{"NN"},
"zoophyte":	{"NN"},
"zooplankton":	{"NN"},
"zoopsia":	{"NN"},
"zoos":	{"NNS"},
"zoospore":	{"NN"},
"zoot":	{"NN"},
"zootoxin":	{"NN"},
"zori":	{"NN","NNS"},
"zoril":	{"NN"},
"zorille":	{"NN"},
"zoris":	{"NNS"},
"zoster":	{"NN"},
"zostera":	{"NN"},
"zosteraceae":	{"NN"},
"zounds":	{"UH"},
"zovirax":	{"NN"},
"zoysia":	{"NN"},
"zubird":	{"NN"},
"zucchini":	{"NN","NNS"},
"zucchinis":	{"NNS"},
"zwieback":	{"NN"},
"zydeco":	{"NN"},
"zygnema":	{"NN"},
"zygnemataceae":	{"NN"},
"zygnematales":	{"NNS"},
"zygocactus":	{"NNS"},
"zygodactyl":	{"JJ"},
"zygoma":	{"NN"},
"zygomatic":	{"JJ"},
"zygomorphic":	{"JJ"},
"zygomorphous":	{"JJ"},
"zygomycetes":	{"NNS"},
"zygomycota":	{"NN"},
"zygomycotina":	{"NN"},
"zygophyllaceae":	{"NN"},
"zygophyllum":	{"NN"},
"zygoptera":	{"NN"},
"zygospore":	{"NN"},
"zygote":	{"NN"},
"zygotene":	{"NN"},
"zygotic":	{"JJ"},
"zyloprim":	{"NN"},
"zymase":	{"NN"},
"zymogen":	{"NN"},
"zymoid":	{"JJ"},
"zymology":	{"NN"},
"zymolysis":	{"NN"},
"zymolytic":	{"JJ"},
"zymosis":	{"NN"},
"zymotic":	{"JJ"},
"zymurgy":	{"NN"},
}