
#vi_typical = {'look','wait','cry','smile','laugh','go','come','rain','snow','appear','happen','fall','feel','remain'} #stop
#collective_noun = {"clothing","furniture","baggage","luggage","jewelry","traffic","information","machinery","merchandise","produce","scenery","people","police","cattle","poultry","vermin","clergy","militia","crew","family","class","team","government","crowd","committee","jury","party","firm","couple","board","group","gang","enemy","union","audience","public","mankind","humanity","youth"} #集体名词
#nns_only = {"trousers","pants","shorts","glasses","compasses","scales","pliers","clips","traffic lights","sports"} 
#nn_eq_nns = {'antelope','bison','buffalo','crab','deer','fish','reindeer','sheep','Burmese','Cantonese','Chinese','counsel','kin','Japanese','Swiss','aircraft','craft','spacecraft','brance','score','series','species','means'} 
#vlink_lemma = {'be','seem','appear'}
#vbd_eq_vbn = {'said','ignored','paid'}

# _vlink , lexc is the key,not lemma
word_bits = {
"it":{"_n"}, 
"'d":{"_past"},
"'ll":{"_probabl"},
"a":{"_art"},
"a-bomb":{"_prprn"},
"a-horizon":{"_prprn"},
"a-Includes":{"_art"},
"a-ok":{"_prprn"},
"a-reflects":{"_art"},
"a-team":{"_prprn"},
"a.m.":{"_ampm","_tme"},
"aa":{"_prprn"},
"aaa":{"_prprn"},
"aachen":{"_cty","_geo","_prprn"},
"aah":{"_loc_sr"},
"aalborg":{"_geo","_prprn"},
"aalst":{"_cty","_geo","_prprn"},
"aalto":{"_anim","_nme","_prprn","_sb"},
"aardvark":{"_anim"},
"aardwolf":{"_anim"},
"aare":{"_geo","_prprn"},
"aarhus":{"_geo","_prprn"},
"aaron":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"aas":{"_prprn"},
"abadan":{"_cty","_geo","_prprn"},
"abandoned":{"_past"},
"abase":{"_loc_sr"},
"abash":{"_psych"},
"abate":{"_loc_sr"},
"abated":{"_loc_sr","_past"},
"abates":{"_loc_sr"},
"abating":{"_loc_sr"},
"abator":{"_anim","_sb"},
"Abba":{"_prprn"},
"Abbas":{"_prprn"},
"abbess":{"_anim","_fem","_sb"},
"abbot":{"_anim","_masc","_sb"},
"Abbott":{"_anim","_nme","_prprn","_sb"},
"abbreviated":{"_past"},
"abbreviator":{"_anim","_sb"},
"abc":{"_prprn"},
"abc's":{"_prprn"},
"abcs":{"_prprn"},
"abdias":{"_anim","_nme","_prprn","_sb"},
"abdicator":{"_anim","_sb"},
"abducted":{"_past"},
"Abdullah":{"_prprn"},
"Abe":{"_prprn"},
"abecedarian":{"_anim","_sb"},
"abel":{"_anim","_nme","_prprn","_sb"},
"abelard":{"_anim","_nme","_prprn","_sb"},
"Abelson":{"_prprn"},
"abenaki":{"_prprn","_sb"},
"aber":{"_anim","_sb"},
"Aberdeen":{"_cty","_geo","_prprn"},
"Abernathy":{"_anim","_nme","_prprn","_sb"},
"abetted":{"_past"},
"abetter":{"_anim","_sb"},
"abettor":{"_anim","_sb"},
"abhorrer":{"_anim","_sb"},
"abidjan":{"_cty","_geo","_prprn"},
"Abigail":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"abilene":{"_cty","_geo","_prprn"},
"Abingdon":{"_prprn"},
"abjurer":{"_anim","_sb"},
"ablated":{"_past"},
"abm":{"_prprn"},
"abnaki":{"_prprn"},
"abnegator":{"_anim","_sb"},
"Abner":{"_prprn"},
"abo":{"_anim","_sb"},
"abode":{"_loc_sr"},
"abolished":{"_past"},
"abominator":{"_anim","_sb"},
"aboriginal":{"_anim","_sb"},
"aborigine":{"_anim","_sb"},
"aborigines":{"_anim","_sb"},
"abound":{"_loc_sr"},
"abounded":{"_loc_sr","_past"},
"abounding":{"_loc_sr"},
"abounds":{"_loc_sr"},
"about-faced":{"_past"},
"above":{"_loc"},
"above-average":{"_loc"},
"above-ceiling":{"_loc"},
"above-ground":{"_loc"},
"above-market":{"_loc"},
"above-named":{"_loc"},
"above-normal":{"_loc"},
"above-noted":{"_loc"},
"above-target":{"_loc"},
"abrader":{"_anim","_sb"},
"abraham":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"abranchiate":{"_anim"},
"abridged":{"_past"},
"abridger":{"_anim","_sb"},
"abrogated":{"_past"},
"abrogator":{"_anim","_sb"},
"abruzzi":{"_anim","_geo","_nme","_prprn","_sb","_stte"},
"abscessed":{"_past"},
"absconder":{"_anim","_sb"},
"absentee-ballot":{"_anim","_sb"},
"absentees":{"_anim","_sb"},
"absolved":{"_past"},
"absolver":{"_anim","_sb"},
"absorb":{"_loc_sr","_psych"},
"absorbed":{"_loc_sr","_past","_psych"},
"absorbing":{"_loc_sr","_psych"},
"absorbs":{"_loc_sr","_psych"},
"absquatulate":{"_loc_sr"},
"abstained":{"_past"},
"abstainer":{"_anim","_sb"},
"abstracted":{"_past"},
"abstracter":{"_anim","_sb"},
"abstractionist":{"_anim","_sb"},
"abstractionists":{"_anim","_sb"},
"abstractor":{"_anim","_sb"},
"abstractors":{"_anim","_sb"},
"absurdist":{"_anim","_sb"},
"abuja":{"_cty","_geo","_prprn"},
"abukir":{"_geo","_prprn"},
"abused":{"_past"},
"abuser":{"_anim","_sb"},
"abusers":{"_anim","_sb"},
"abutter":{"_anim","_sb"},
"abydos":{"_cty","_geo","_prprn"},
"abyssinia":{"_geo","_prprn"},
"academic":{"_anim","_sb"},
"Acadia":{"_geo","_prprn"},
"acadian":{"_prprn"},
"acapulco":{"_cty","_geo","_prprn"},
"Accademia":{"_prprn"},
"Accardo":{"_prprn"},
"acceded":{"_past"},
"accelerate":{"_loc_sr"},
"accelerated":{"_loc_sr","_past"},
"accelerates":{"_loc_sr"},
"accelerating":{"_loc_sr"},
"accented":{"_past"},
"accentor":{"_anim","_sb"},
"accentuated":{"_past"},
"accepted":{"_past"},
"accessed":{"_past"},
"acclaimed":{"_past"},
"acclimatized":{"_past"},
"accommodation":{"_loc_sr"},
"accommodations":{"_loc_sr"},
"accommodator":{"_anim","_sb"},
"accompanied":{"_loc_sr","_past"},
"accompanies":{"_loc_sr"},
"accompanists":{"_anim","_sb"},
"accompany":{"_loc_sr"},
"accomplices":{"_anim","_sb"},
"accomplish":{"_loc_sr"},
"accomplished":{"_loc_sr","_past"},
"accomplishes":{"_loc_sr"},
"accomplishing":{"_loc_sr"},
"accorded":{"_loc_sr","_past"},
"according":{"_loc_sr"},
"accordionist":{"_anim","_sb"},
"accosted":{"_loc_sr","_past"},
"accosting":{"_loc_sr"},
"accountants":{"_anim","_sb"},
"accounted":{"_past"},
"accoutered":{"_past"},
"accoutred":{"_past"},
"accra":{"_cty","_geo","_prprn"},
"accredit":{"_loc_sr"},
"accreted":{"_past"},
"accrued":{"_past"},
"acculturated":{"_past"},
"accumulate":{"_loc_sr"},
"accumulated":{"_loc_sr","_past"},
"accumulates":{"_loc_sr"},
"accumulating":{"_loc_sr"},
"accuser":{"_anim","_sb"},
"accusers":{"_anim","_sb"},
"accustomed":{"_past"},
"acer":{"_anim","_sb"},
"achaea":{"_geo","_prprn"},
"achaean":{"_anim","_prprn","_sb"},
"achaian":{"_prprn"},
"ached":{"_past"},
"acheron":{"_prprn"},
"acheson":{"_anim","_nme","_prprn","_sb"},
"achilles":{"_prprn"},
"achomawi":{"_anim","_prprn","_sb"},
"acidified":{"_past"},
"acolyte":{"_anim","_sb"},
"aconcagua":{"_geo","_prprn"},
"acores":{"_geo","_prprn"},
"acoustician":{"_anim","_sb"},
"acquainted":{"_past"},
"acquiesced":{"_past"},
"acquired":{"_past"},
"acquirer":{"_anim","_sb"},
"acquirers":{"_anim","_sb"},
"acquit":{"_loc_sr"},
"acquitted":{"_loc_sr","_past"},
"acre":{"_loc_sr"},
"acre-feet":{"_loc_sr"},
"acre-foot":{"_loc_sr"},
"acres":{"_loc_sr"},
"acrobat":{"_anim","_sb"},
"acrobats":{"_anim","_sb"},
"across":{"_loc"},
"across-the-board-cuts":{"_loc"},
"acted":{"_past"},
"acth":{"_prprn"},
"actinia":{"_anim"},
"actium":{"_geo","_prprn"},
"activate":{"_loc_sr"},
"activated":{"_loc_sr","_past"},
"activist":{"_anim","_sb"},
"activists":{"_anim","_sb"},
"Acton":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"actor":{"_anim","_sb"},
"actors":{"_anim","_sb"},
"actress":{"_anim","_fem","_sb"},
"actresses":{"_anim","_fem","_sb"},
"actualise":{"_loc_sr"},
"actuaries":{"_anim","_sb"},
"actuate":{"_loc_sr"},
"actuated":{"_loc_sr","_past"},
"actuating":{"_loc_sr"},
"acupuncturist":{"_anim","_sb"},
"Ada":{"_cty","_geo","_prprn"},
"adam":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"adam-and-eve":{"_prprn"},
"Adams":{"_anim","_geo","_nme","_prprn","_sb"},
"adana":{"_cty","_geo","_prprn"},
"adapted":{"_past"},
"adapters":{"_sb"},
"adar":{"_prprn"},
"addax":{"_anim"},
"added":{"_past"},
"added-value":{"_past"},
"adder":{"_anim"},
"addicts":{"_anim","_sb"},
"Addington":{"_prprn"},
"Addison":{"_anim","_geo","_nme","_prprn","_sb"},
"addle":{"_loc_sr","_psych"},
"addle-brained":{"_loc_sr","_psych"},
"addle-head":{"_loc_sr","_psych"},
"addled":{"_loc_sr","_past","_psych"},
"addressed":{"_loc_sr","_past"},
"addressees":{"_anim","_sb"},
"addressing":{"_loc_sr"},
"adducent":{"_anim","_sb"},
"adducer":{"_anim","_sb"},
"Ade":{"_anim","_nme","_prprn","_sb"},
"Adelaide":{"_cty","_geo","_prprn"},
"aden":{"_cty","_geo","_prprn"},
"Adenauer":{"_anim","_nme","_prprn","_sb"},
"adepts":{"_anim","_sb"},
"adh":{"_prprn"},
"adhered":{"_past"},
"adherent":{"_anim","_sb"},
"adige":{"_geo","_prprn"},
"Adirondacks":{"_geo","_prprn"},
"adjoined":{"_past"},
"adjourned":{"_past"},
"adjudged":{"_past"},
"adjudicators":{"_anim","_sb"},
"adjusted":{"_past"},
"adjuster":{"_anim","_sb"},
"adjusters":{"_anim","_sb"},
"adjustor":{"_anim","_sb"},
"Adler":{"_anim","_nme","_prprn","_sb"},
"Adm":{"_prprn"},
"Adm.":{"_anim","_prprn","_sb"},
"admen":{"_anim","_sb"},
"administered":{"_past"},
"administrator":{"_anim","_sb"},
"administrator-general":{"_anim","_sb"},
"administrators":{"_anim","_sb"},
"admiral":{"_anim","_sb"},
"admirals":{"_anim","_sb"},
"Admiralty":{"_prprn","_sb"},
"admired":{"_past"},
"admirers":{"_anim","_sb"},
"admitted":{"_past"},
"admixed":{"_past"},
"admonisher":{"_anim","_sb"},
"adolescent":{"_anim","_sb"},
"adolescents":{"_anim","_sb"},
"Adolph":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Adonis":{"_prprn"},
"adopt":{"_loc_sr"},
"adopter":{"_anim","_sb"},
"adopters":{"_anim","_sb"},
"adopting":{"_loc_sr"},
"adopts":{"_loc_sr"},
"adored":{"_past"},
"adorer":{"_anim","_sb"},
"adorned":{"_past"},
"adp":{"_prprn"},
"adrian":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"adrianople":{"_geo","_prprn"},
"adriatic":{"_geo","_prprn"},
"Adrienne":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"adsorbed":{"_past"},
"adult-literacy":{"_anim","_sb"},
"adult-training":{"_anim","_sb"},
"adulterated":{"_past"},
"adulterator":{"_anim","_sb"},
"adulterer":{"_anim","_sb"},
"adulterers":{"_anim","_sb"},
"adulteress":{"_anim","_fem","_sb"},
"adulthood":{"_tme"},
"adults":{"_anim","_sb"},
"advance":{"_loc_sr"},
"advanced-ceramics":{"_loc_sr","_past"},
"advanced-materials":{"_loc_sr","_past"},
"advanced-technology":{"_loc_sr","_past"},
"advancers":{"_anim","_sb"},
"advancing":{"_loc_sr"},
"Advent":{"_prprn"},
"adventism":{"_prprn"},
"adventist":{"_anim","_prprn","_sb"},
"adventurers":{"_anim","_sb"},
"adventuress":{"_anim","_fem","_sb"},
"adventurist":{"_anim","_sb"},
"adversaries":{"_anim","_sb"},
"adversary":{"_anim","_sb"},
"advertised":{"_past"},
"advertiser":{"_anim","_sb"},
"advertiser-bankrolled":{"_anim","_sb"},
"advertiser-programming":{"_anim","_sb"},
"advertiser-sponsored":{"_anim","_sb"},
"advertisers":{"_anim","_sb"},
"advertizer":{"_anim","_sb"},
"Advil":{"_prprn"},
"advised":{"_past"},
"advisee":{"_anim","_sb"},
"adviser":{"_anim","_sb"},
"advisers":{"_anim","_sb"},
"advisor":{"_anim","_sb"},
"advisors":{"_anim","_sb"},
"advocated":{"_past"},
"advocates":{"_anim","_sb"},
"adzhar":{"_prprn"},
"adzharia":{"_geo","_prprn"},
"aegates":{"_prprn"},
"Aegean":{"_geo","_prprn"},
"aegina":{"_geo","_prprn"},
"aegir":{"_anim","_masc","_nme","_prprn","_sb"},
"aegisthus":{"_anim","_prprn","_sb"},
"aegospotami":{"_geo","_prprn"},
"aegospotamos":{"_prprn"},
"aeneas":{"_prprn"},
"Aeneid":{"_prprn"},
"aeolia":{"_geo","_prprn"},
"aeolic":{"_prprn"},
"aeolis":{"_geo","_prprn"},
"aeolus":{"_anim","_masc","_nme","_prprn","_sb"},
"aerate":{"_loc_sr"},
"aerates":{"_loc_sr"},
"aeronaut":{"_anim","_sb"},
"Aerosmith":{"_prprn"},
"aerosol":{"_loc_sr"},
"aerosolised":{"_past"},
"aerosolized":{"_past"},
"aerosols":{"_loc_sr"},
"aeschylus":{"_anim","_nme","_prprn","_sb"},
"aesculapius":{"_anim","_masc","_nme","_prprn","_sb"},
"aesir":{"_prprn"},
"aesop":{"_anim","_nme","_prprn","_sb"},
"aesthete":{"_anim","_sb"},
"aesthetes":{"_anim","_sb"},
"aesthetician":{"_anim","_sb"},
"aetiologist":{"_anim","_sb"},
"Aetna":{"_geo","_prprn"},
"affect":{"_loc_sr","_psych"},
"affenpinscher":{"_anim"},
"affiance":{"_loc_sr"},
"affiant":{"_anim","_sb"},
"affiliated":{"_past"},
"affiliates":{"_sb"},
"affirmed":{"_past"},
"affirmer":{"_anim","_sb"},
"affixed":{"_past"},
"afflict":{"_psych"},
"afflicted":{"_past","_psych"},
"afflicting":{"_psych"},
"afflicts":{"_psych"},
"afforded":{"_past"},
"afforest":{"_loc_sr"},
"affront":{"_loc_sr","_psych"},
"affronted":{"_loc_sr","_past","_psych"},
"affronting":{"_loc_sr","_psych"},
"Afghan":{"_anim","_prprn","_sb"},
"Afghanistan":{"_cntry","_geo","_prprn"},
"afghanistani":{"_anim","_prprn","_sb"},
"Afghans":{"_anim","_prprn","_sb"},
"aficionado":{"_anim","_sb"},
"aficionados":{"_anim","_sb"},
"afield":{"_loc"},
"afl":{"_prprn"},
"afl-cio":{"_prprn"},
"afp":{"_prprn"},
"africa":{"_geo","_prprn"},
"African":{"_anim","_prprn","_sb"},
"African-American":{"_prprn"},
"African-Americans":{"_anim","_prprn","_sb"},
"Africanist":{"_prprn"},
"Africans":{"_anim","_prprn","_sb"},
"afrikaans":{"_prprn"},
"afrikaner":{"_prprn"},
"Afrikaners":{"_prprn"},
"afro-american":{"_anim","_prprn","_sb"},
"afro-asiatic":{"_prprn"},
"after":{"_tme"},
"after-dinner":{"_tme"},
"after-school":{"_anim","_loc_sr"},
"afterglow":{"_anim","_sb"},
"aftermath":{"_tme"},
"aftermaths":{"_tme"},
"afternoon":{"_tme"},
"afternoons":{"_tme"},
"afterward":{"_tme"},
"afterwards":{"_tme"},
"ag":{"_prprn"},
"Agamemnon":{"_prprn"},
"Agassi":{"_prprn"},
"agassiz":{"_anim","_geo","_nme","_prprn","_sb"},
"Agatha":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"age":{"_tme"},
"age-and-sex":{"_tme"},
"age-bias":{"_tme"},
"age-related":{"_tme"},
"age-specific":{"_tme"},
"aged":{"_sb"},
"aged-care":{"_sb"},
"Agee":{"_anim","_nme","_prprn","_sb"},
"agent":{"_anim","_sb"},
"agent-in-place":{"_anim","_sb"},
"agents":{"_anim","_sb"},
"agents-in-training":{"_anim","_sb"},
"ages":{"_tme"},
"agglomerate":{"_loc_sr"},
"agglomerator":{"_anim","_sb"},
"aggravate":{"_psych"},
"aggravated":{"_past","_psych"},
"aggravates":{"_psych"},
"aggravating":{"_psych"},
"aggravator":{"_anim","_sb"},
"aggregate":{"_loc_sr"},
"aggregated":{"_loc_sr","_past"},
"aggregator":{"_anim","_sb"},
"aggrieved":{"_past"},
"agincourt":{"_geo","_prprn"},
"agitate":{"_loc_sr","_psych"},
"agitated":{"_loc_sr","_past","_psych"},
"agitating":{"_loc_sr","_psych"},
"agitator":{"_anim","_sb"},
"agitators":{"_anim","_sb"},
"aglaia":{"_prprn"},
"Agnes":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Agnew":{"_anim","_nme","_prprn","_sb"},
"agni":{"_anim","_masc","_nme","_prprn","_sb"},
"agnostic":{"_anim","_sb"},
"agnostics":{"_anim","_sb"},
"ago":{"_tme"},
"agonised":{"_past"},
"agonize":{"_psych"},
"agonized":{"_past","_psych"},
"agonizes":{"_psych"},
"agonizing":{"_psych"},
"agora":{"_loc_sr"},
"agoraphobia":{"_loc_sr"},
"agoraphobic":{"_anim","_sb"},
"agouti":{"_anim"},
"agra":{"_cty","_geo","_prprn"},
"agrarian":{"_anim","_sb"},
"agrarian-reform":{"_anim","_sb"},
"agreed":{"_past"},
"agreed-upon":{"_past"},
"Agricola":{"_anim","_nme","_prprn","_sb"},
"agricolas":{"_anim","_nme","_prprn","_sb"},
"agrigento":{"_cty","_geo","_prprn"},
"agrippa":{"_anim","_nme","_prprn","_sb"},
"agrippina":{"_anim","_nme","_prprn","_sb"},
"ahead":{"_loc"},
"Ahern":{"_prprn"},
"ahriman":{"_prprn"},
"ahvenanmaa":{"_geo","_prprn"},
"AIChE":{"_prprn"},
"aide":{"_anim","_sb"},
"AIDS-related":{"_prprn"},
"aiken":{"_anim","_nme","_prprn","_sb"},
"Ailey":{"_anim","_nme","_prprn","_sb"},
"aimed":{"_past"},
"Ainsley":{"_prprn"},
"Ainu":{"_anim","_prprn","_sb"},
"Ainus":{"_anim","_prprn","_sb"},
"air-conditioned":{"_past"},
"air-conditioner":{"_anim","_sb"},
"air-conditioners":{"_anim","_sb"},
"air-cooled":{"_past"},
"air-dried":{"_past"},
"aircraftman":{"_anim","_sb"},
"aircrew":{"_anim"},
"aired":{"_past"},
"airedale":{"_anim","_prprn"},
"Airedales":{"_anim","_prprn"},
"airfields":{"_loc_sr"},
"airforce":{"_anim"},
"airhead":{"_sb"},
"airheads":{"_sb"},
"airlifted":{"_past"},
"airmailed":{"_loc_sr","_past"},
"airmailer":{"_anim","_sb"},
"airmen":{"_anim","_sb"},
"airport":{"_loc_sr"},
"airports":{"_loc_sr"},
"airstrips":{"_loc_sr"},
"airwoman":{"_anim","_fem","_sb"},
"aix-la-chapelle":{"_geo","_prprn"},
"Ajax":{"_cty","_geo","_prprn"},
"ak":{"_prprn","_stte"},
"akan":{"_anim","_prprn","_sb"},
"akhenaten":{"_prprn"},
"akhenaton":{"_anim","_nme","_prprn","_sb"},
"Akita":{"_cty","_geo","_prprn"},
"akkadian":{"_anim","_prprn","_sb"},
"akko":{"_geo","_prprn"},
"Akron":{"_cty","_geo","_prprn"},
"alabama":{"_geo","_prprn","_stte"},
"aladdin":{"_prprn"},
"Alagoas":{"_prprn"},
"Alai":{"_geo","_prprn"},
"Alameda":{"_cty","_geo","_prprn"},
"Alamein":{"_prprn"},
"Alamo":{"_geo","_prprn"},
"Alamogordo":{"_cty","_geo","_prprn"},
"Alan":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Alaouite":{"_prprn"},
"alaric":{"_anim","_nme","_prprn","_sb"},
"alarmed":{"_past","_psych"},
"alarmist":{"_anim","_sb"},
"alaska":{"_geo","_prprn","_stte"},
"Alaskan":{"_anim","_prprn","_sb"},
"Alba":{"_anim","_nme","_prprn","_sb"},
"albacore":{"_anim"},
"Albania":{"_cntry","_geo","_prprn"},
"albanian":{"_anim","_prprn","_sb"},
"albany":{"_cty","_geo","_prprn"},
"albatross":{"_anim"},
"albee":{"_anim","_nme","_prprn","_sb"},
"Albers":{"_anim","_nme","_prprn","_sb"},
"Albert":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Alberta":{"_geo","_prprn","_stte"},
"albigenses":{"_prprn","_sb"},
"albino":{"_anim","_sb"},
"Albion":{"_geo","_prprn"},
"alborg":{"_cty","_geo","_prprn"},
"albuquerque":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"alcaeus":{"_anim","_nme","_prprn","_sb"},
"alcaic":{"_prprn"},
"Alcatraz":{"_geo","_prprn"},
"alchemist":{"_anim","_sb"},
"alchemists":{"_anim","_sb"},
"Alcibiades":{"_anim","_nme","_prprn","_sb"},
"alcoholic":{"_anim","_sb"},
"alcoholic-beverage":{"_anim","_sb"},
"Alcott":{"_anim","_nme","_prprn","_sb"},
"alcove":{"_loc_sr"},
"alcoves":{"_loc_sr"},
"aldebaran":{"_prprn"},
"Alden":{"_anim","_nme","_prprn","_sb"},
"alder":{"_anim"},
"alderman":{"_anim","_sb"},
"aldermen":{"_anim","_sb"},
"Aldrich":{"_anim","_nme","_prprn","_sb"},
"Aldrin":{"_anim","_prprn","_sb"},
"alecto":{"_prprn"},
"alee":{"_loc"},
"alehouse":{"_loc_sr"},
"alep":{"_geo","_prprn"},
"aleppo":{"_cty","_geo","_prprn"},
"alert":{"_loc_sr"},
"alerted":{"_loc_sr","_past"},
"alerting":{"_loc_sr"},
"aleutian":{"_anim","_geo","_prprn","_sb"},
"aleutians":{"_anim","_geo","_prprn","_sb"},
"alewife":{"_anim","_sb"},
"Alexander":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Alexandra":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Alexandria":{"_cty","_geo","_prprn"},
"Alexandrine":{"_prprn"},
"Alexis":{"_anim","_fem","_fnme","_masc","_nme","_prprn","_sb"},
"Alfa":{"_prprn"},
"Alfieri":{"_anim","_nme","_prprn","_sb"},
"Alfonse":{"_prprn"},
"Alfred":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Alfredo":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"algebraist":{"_anim","_sb"},
"Alger":{"_anim","_fnme","_nme","_prprn","_sb"},
"algeria":{"_cntry","_geo","_prprn"},
"Algerian":{"_anim","_prprn","_sb"},
"Algiers":{"_cty","_geo","_prprn"},
"Algol":{"_prprn"},
"algonkian":{"_prprn"},
"algonkin":{"_prprn"},
"algonquian":{"_anim","_prprn","_sb"},
"algonquin":{"_prprn","_sb"},
"algren":{"_anim","_nme","_prprn","_sb"},
"alhambra":{"_cty","_geo","_prprn"},
"ali":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Alice":{"_anim","_cty","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"Alicia":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"alien":{"_anim","_sb"},
"alienate":{"_psych"},
"alienating":{"_psych"},
"alienator":{"_anim","_sb"},
"alienor":{"_anim","_sb"},
"aliens":{"_anim","_sb"},
"align":{"_loc_sr"},
"aligned":{"_loc_sr","_past"},
"aligning":{"_loc_sr"},
"Alistair":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Alito":{"_prprn"},
"alkaliser":{"_anim","_sb"},
"alkalizer":{"_anim","_sb"},
"alkane":{"_sb"},
"all":{"_quant","_univ"},
"all-America":{"_quant"},
"all-American-boy":{"_quant"},
"all-automatic":{"_quant"},
"all-black":{"_quant"},
"all-cargo":{"_quant"},
"all-cash":{"_quant"},
"all-college":{"_quant"},
"all-consuming":{"_quant"},
"all-Copland":{"_quant"},
"all-county":{"_quant"},
"all-day":{"_tme"},
"all-devouring":{"_quant"},
"all-embracing":{"_quant"},
"all-employee":{"_quant"},
"all-encompassing":{"_quant"},
"all-exclusive":{"_quant"},
"all-expenses-paid":{"_quant"},
"all-federal":{"_quant"},
"all-female":{"_quant"},
"all-in-all":{"_quant"},
"all-lesbian":{"_quant"},
"all-male":{"_quant"},
"all-married":{"_quant"},
"all-metal":{"_quant"},
"all-natural":{"_quant"},
"all-Negro":{"_quant"},
"all-news":{"_quant"},
"all-night":{"_tme"},
"all-options":{"_quant"},
"all-something-or-the-other":{"_quant"},
"all-student":{"_quant"},
"all-too-brief":{"_quant"},
"all-too-familiar":{"_quant"},
"all-too-sincere":{"_quant"},
"all-weather":{"_quant"},
"all-woman":{"_quant"},
"allah":{"_prprn"},
"Allan":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"allayed":{"_past"},
"allayer":{"_anim","_sb"},
"alleged":{"_past"},
"alleghenies":{"_prprn"},
"Allegheny":{"_prprn"},
"allegoriser":{"_anim","_sb"},
"allegorizer":{"_anim","_sb"},
"allele":{"_sb"},
"allen":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Allende":{"_prprn"},
"allentown":{"_cty","_geo","_prprn"},
"alleviated":{"_past"},
"allhallows":{"_prprn"},
"Allied":{"_loc_sr","_past"},
"allies":{"_anim","_sb"},
"alligator":{"_anim"},
"alligators":{"_anim"},
"Allingham":{"_prprn"},
"alliterate":{"_loc_sr"},
"alliterator":{"_anim","_sb"},
"allotted":{"_past"},
"allowed":{"_past"},
"alloyed":{"_past"},
"allure":{"_psych"},
"alluring":{"_psych"},
"alluvion":{"_loc_sr"},
"ally":{"_loc_sr"},
"allying":{"_loc_sr"},
"Alma":{"_anim","_cty","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"alma-ata":{"_cty","_geo","_prprn"},
"Almagest":{"_prprn"},
"Almighty":{"_prprn"},
"along":{"_loc"},
"alongside":{"_loc"},
"alonso":{"_anim","_fnme","_nme","_prprn","_sb"},
"alpaca":{"_anim"},
"alphabetised":{"_past"},
"alphabetiser":{"_anim","_sb"},
"alphabetized":{"_past"},
"alphabetizer":{"_anim","_sb"},
"Alphonsus":{"_prprn"},
"Alps":{"_geo","_prprn"},
"already":{"_tme"},
"already-developed":{"_tme"},
"already-expensive":{"_tme"},
"already-identified":{"_tme"},
"already-known":{"_tme"},
"already-nervous":{"_tme"},
"already-reluctant":{"_tme"},
"already-shaky":{"_tme"},
"already-sizable":{"_tme"},
"already-strained":{"_tme"},
"already-tense":{"_tme"},
"als":{"_prprn"},
"alsace":{"_geo","_prprn","_stte"},
"Alsatian":{"_anim","_prprn","_sb"},
"Alsatians":{"_anim","_prprn","_sb"},
"also-ran":{"_anim","_sb"},
"Alta":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"altaic":{"_prprn"},
"Altair":{"_prprn"},
"altar":{"_loc_sr"},
"altered":{"_past"},
"Altman":{"_prprn"},
"altoist":{"_anim","_sb"},
"altoona":{"_cty","_geo","_prprn"},
"altruist":{"_anim","_sb"},
"altruists":{"_anim","_sb"},
"alumna":{"_anim","_fem","_sb"},
"alumni":{"_anim","_masc","_sb"},
"Alva":{"_anim","_fnme","_nme","_prprn","_sb"},
"Alvarez":{"_anim","_nme","_prprn","_sb"},
"always":{"_tme"},
"always-present":{"_tme"},
"Amado":{"_anim","_nme","_prprn","_sb"},
"amalgamated":{"_past"},
"Amanda":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Amarillo":{"_cty","_geo","_prprn"},
"amass":{"_loc_sr"},
"amassed":{"_loc_sr","_past"},
"amasses":{"_loc_sr"},
"amassing":{"_loc_sr"},
"amateurs":{"_anim","_sb"},
"amaze":{"_psych"},
"amazed":{"_past","_psych"},
"amazing":{"_psych"},
"amazon":{"_anim","_fem","_sb"},
"Amazonia":{"_geo","_prprn"},
"amazons":{"_anim","_fem","_sb"},
"ambassador":{"_anim","_sb"},
"ambassadors":{"_anim","_sb"},
"ambassadress":{"_anim","_fem","_sb"},
"ambience":{"_loc_sr"},
"amble":{"_loc_sr"},
"ambling":{"_loc_sr"},
"Ambridge":{"_prprn"},
"Ambrose":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"ambulatory":{"_loc_sr"},
"ambushed":{"_loc_sr","_past"},
"ambusher":{"_anim","_sb"},
"Amelia":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"amended":{"_past"},
"Amer":{"_prprn"},
"America":{"_cntry","_geo","_prprn"},
"American":{"_anim","_prprn","_sb"},
"americana":{"_cty","_geo","_prprn"},
"Americans":{"_anim","_prprn","_sb"},
"Americas":{"_cntry","_geo","_prprn"},
"Amex":{"_prprn"},
"Amherst":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Amiga":{"_prprn"},
"Amin":{"_prprn"},
"Amir":{"_anim","_sb"},
"Amis":{"_anim","_nme","_prprn","_sb"},
"Amish":{"_anim","_prprn","_sb"},
"Amman":{"_cty","_geo","_prprn"},
"ammoniated":{"_past"},
"amoeba":{"_anim"},
"Amon":{"_prprn"},
"amortized":{"_past"},
"amos":{"_anim","_fnme","_nme","_prprn","_sb"},
"amounted":{"_loc_sr","_past"},
"amounting":{"_loc_sr"},
"amphibian":{"_anim"},
"amphitheatre":{"_loc_sr"},
"amplified":{"_loc_sr","_past"},
"amplifies":{"_loc_sr"},
"amplify":{"_loc_sr"},
"amplifying":{"_loc_sr"},
"amplitude":{"_loc_sr"},
"ampoule":{"_loc_sr"},
"amputated":{"_past"},
"amputee":{"_anim","_sb"},
"Amsterdam":{"_cty","_geo","_prprn"},
"Amtrak":{"_prprn"},
"Amundsen":{"_anim","_nme","_prprn","_sb"},
"amuse":{"_psych"},
"amused":{"_past","_psych"},
"amusing":{"_psych"},
"Amway":{"_prprn"},
"Amy":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"an":{"_art"},
"Ana":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Anabaptist":{"_prprn","_sb"},
"Anabaptists":{"_prprn","_sb"},
"anaconda":{"_anim"},
"anacondas":{"_anim"},
"anaesthetist":{"_anim","_sb"},
"anaheim":{"_cty","_geo","_prprn"},
"analysand":{"_anim","_sb"},
"analyst":{"_anim","_sb"},
"analysts":{"_anim","_sb"},
"analyze":{"_loc_sr"},
"analyzed":{"_loc_sr","_past"},
"analyzes":{"_loc_sr"},
"analyzing":{"_loc_sr"},
"anarchist":{"_anim","_sb"},
"anarchist-adventurers":{"_anim","_sb"},
"Anastasia":{"_prprn"},
"Anastasio":{"_prprn"},
"anatomist":{"_anim","_sb"},
"ancestors":{"_anim","_sb"},
"Anchorage":{"_cty","_geo","_loc_sr","_prprn"},
"anchorages":{"_loc_sr"},
"anchormen":{"_anim","_masc","_sb"},
"anchorwoman":{"_anim","_fem","_sb"},
"anchovy":{"_anim"},
"ancient":{"_anim","_sb"},
"ancillary":{"_anim","_sb"},
"Andean":{"_anim","_prprn","_sb"},
"Andersen":{"_anim","_nme","_prprn","_sb"},
"Anderson":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Andes":{"_geo","_prprn"},
"Andre":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Andretti":{"_prprn"},
"Andrew":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"andrews":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"android":{"_anim"},
"Andromache":{"_anim","_fem","_nme","_prprn","_sb"},
"Andy":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"anesthetist":{"_anim","_sb"},
"anesthetized":{"_past"},
"angel":{"_anim","_sb"},
"Angela":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Angeles":{"_prprn"},
"Angelico":{"_anim","_nme","_prprn","_sb"},
"Angelina":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Angell":{"_anim","_nme","_prprn","_sb"},
"Angelou":{"_prprn"},
"angels":{"_anim","_sb"},
"angered":{"_past","_psych"},
"Angkor":{"_geo","_prprn"},
"angle":{"_loc_sr"},
"angled":{"_loc_sr","_past"},
"angler":{"_anim","_sb"},
"anglerfish":{"_anim"},
"anglers":{"_anim","_sb"},
"angles":{"_loc_sr"},
"Anglia":{"_geo","_prprn"},
"Anglian":{"_prprn"},
"Anglican":{"_prprn","_sb"},
"Anglicanism":{"_prprn"},
"Anglicans":{"_prprn","_sb"},
"angling":{"_loc_sr"},
"Anglo":{"_prprn"},
"Anglo-American":{"_anim","_prprn","_sb"},
"Anglo-Americans":{"_anim","_prprn","_sb"},
"Anglo-French":{"_prprn"},
"Anglo-Irish":{"_anim","_prprn","_sb"},
"Anglo-Saxon":{"_anim","_prprn","_sb"},
"anglophile":{"_anim","_sb"},
"Anglophilia":{"_prprn"},
"Anglophobia":{"_prprn"},
"Angola":{"_cntry","_geo","_prprn"},
"Angolan":{"_anim","_prprn","_sb"},
"angora":{"_anim"},
"angus":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"anhinga":{"_anim"},
"Anhwei":{"_prprn"},
"animal":{"_anim"},
"animal-based":{"_anim"},
"animal-health":{"_anim"},
"animal-human":{"_anim"},
"animal-like":{"_anim"},
"animal-protection":{"_anim"},
"animal-rights":{"_anim"},
"animals":{"_anim"},
"animated":{"_past"},
"animator":{"_anim","_sb"},
"animators":{"_anim","_sb"},
"Anita":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Ann":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Anna":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"annalist":{"_anim","_sb"},
"Annandale":{"_cty","_geo","_prprn"},
"Annapolis":{"_cty","_geo","_prprn"},
"anne":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Annette":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"annexed":{"_past"},
"Annie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"annihilated":{"_past"},
"annihilator":{"_anim","_sb"},
"annotated":{"_past"},
"annotator":{"_anim","_sb"},
"announced":{"_past"},
"announcer":{"_anim","_sb"},
"announcers":{"_anim","_sb"},
"annoy":{"_psych"},
"annoyed":{"_past","_psych"},
"annoyer":{"_anim","_sb"},
"annoying":{"_psych"},
"annoys":{"_psych"},
"annualized":{"_past"},
"annually":{"_tme"},
"annulled":{"_past"},
"annunciated":{"_past"},
"annunciator":{"_anim","_sb"},
"anomic":{"_sb"},
"anopheles":{"_anim"},
"anorectic":{"_anim","_sb"},
"Anouilh":{"_anim","_nme","_prprn","_sb"},
"answered":{"_past"},
"answerer":{"_anim","_sb"},
"ant":{"_anim"},
"antagonised":{"_past","_psych"},
"antagonist":{"_anim","_sb"},
"antagonists":{"_anim","_sb"},
"antagonize":{"_psych"},
"Antarctic":{"_prprn"},
"Antarctica":{"_geo","_prprn"},
"Antares":{"_prprn"},
"ante":{"_loc_sr"},
"anteaters":{"_anim"},
"antecedents":{"_anim"},
"antechamber":{"_loc_sr"},
"antelope":{"_anim"},
"anteroom":{"_loc_sr"},
"anthill":{"_loc_sr"},
"Anthony":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"anthropoid":{"_anim"},
"anthropologist":{"_anim","_sb"},
"anthropologists":{"_anim","_sb"},
"anti":{"_anim","_sb"},
"anti-A":{"_anim","_sb"},
"anti-abortionist":{"_anim","_sb"},
"anti-abortionists":{"_anim","_sb"},
"anti-airline-takeover":{"_anim","_sb"},
"anti-army":{"_anim","_sb"},
"anti-authoritarian":{"_anim","_sb"},
"anti-ballistic-missile":{"_anim","_sb"},
"anti-Bork":{"_anim","_sb"},
"anti-Catholic":{"_sb"},
"anti-Christian":{"_anim","_masc","_sb"},
"anti-cigarette":{"_loc_sr"},
"anti-clotting":{"_anim","_sb"},
"anti-Colmer":{"_anim","_sb"},
"anti-communist":{"_anim","_sb"},
"anti-Communists":{"_anim","_sb"},
"anti-deer":{"_anim"},
"anti-diarrheal":{"_anim","_sb"},
"anti-dilutive":{"_anim","_sb"},
"anti-drug-law":{"_anim","_sb"},
"anti-epileptic":{"_anim","_sb"},
"anti-European":{"_anim","_sb"},
"anti-Fascist":{"_sb"},
"anti-flag-burning":{"_anim","_sb"},
"anti-foreigner":{"_anim","_sb"},
"anti-French":{"_anim","_sb"},
"anti-Galileo":{"_anim","_sb"},
"anti-gay":{"_sb"},
"anti-heroes":{"_anim","_sb"},
"anti-homosexual":{"_anim","_sb"},
"anti-Honecker":{"_anim","_sb"},
"anti-hooligan":{"_anim","_sb"},
"anti-human":{"_anim","_sb"},
"anti-idiotypes":{"_anim","_sb"},
"anti-immigrant":{"_anim","_sb"},
"anti-Japanese":{"_anim","_sb"},
"anti-Kennedy":{"_anim","_sb"},
"anti-LDP":{"_anim","_sb"},
"anti-lobbying":{"_anim","_sb"},
"anti-lobbyist":{"_anim","_sb"},
"anti-men":{"_anim","_masc","_sb"},
"anti-morning-sickness":{"_anim","_sb"},
"anti-Nazi":{"_sb"},
"anti-Nazis":{"_sb"},
"anti-Negro":{"_anim","_sb"},
"anti-Noriega":{"_anim","_sb"},
"anti-outsider":{"_anim","_sb"},
"anti-Phnom":{"_anim","_sb"},
"anti-profiteering":{"_anim","_sb"},
"anti-program-trading":{"_anim","_sb"},
"anti-programmers":{"_anim","_sb"},
"anti-psychotic":{"_anim","_sb"},
"anti-recession":{"_tme"},
"anti-rightist":{"_anim","_sb"},
"anti-Sandinista":{"_anim","_sb"},
"anti-semite":{"_anim","_prprn","_sb"},
"anti-smokers":{"_anim","_sb"},
"anti-socialist":{"_anim","_sb"},
"anti-Somoza":{"_anim","_sb"},
"anti-Soviet":{"_anim","_sb"},
"anti-state":{"_loc_sr"},
"anti-statist":{"_anim","_sb"},
"anti-Taliban":{"_anim","_sb"},
"anti-tax-shelter":{"_anim","_sb"},
"anti-virus":{"_anim"},
"anti-vivisectionists":{"_anim","_sb"},
"anti-war-related":{"_anim","_sb"},
"anti-wrinkling":{"_anim","_sb"},
"anti-Yankee":{"_anim","_sb"},
"antiauthoritarian":{"_anim","_sb"},
"antiblack":{"_anim","_sb"},
"antiCommunist":{"_anim","_sb"},
"anticult":{"_sb"},
"antidiabetic":{"_anim","_sb"},
"antiepileptic":{"_anim","_sb"},
"Antietam":{"_geo","_prprn"},
"antifundamentalist":{"_anim","_sb"},
"Antigone":{"_prprn"},
"antigua":{"_geo","_prprn"},
"antihero":{"_anim","_sb"},
"antipodes":{"_loc_sr"},
"antipope":{"_anim","_sb"},
"antiquarians":{"_anim","_sb"},
"antiquary":{"_anim","_sb"},
"antiquated":{"_past"},
"Antoinette":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Antonia":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Antony":{"_cty","_geo","_prprn"},
"ants":{"_anim"},
"Antwerp":{"_cty","_geo","_prprn"},
"any":{"_quant"},
"anybody":{"_anim","_sb","_univ"},
"anyone":{"_anim","_sb","_univ"},
"anyplace":{"_loc","_univ"},
"anythin":{"_univ"},
"anything":{"_univ"},
"anytime":{"_tme"},
"anywhere":{"_loc","_univ"},
"apache":{"_sb"},
"Apalachicola":{"_geo","_prprn"},
"apartment":{"_loc_sr"},
"apartment-building":{"_loc_sr"},
"apartments":{"_loc_sr","_sb"},
"ape":{"_anim"},
"ape-man":{"_anim","_sb"},
"apes":{"_anim"},
"aphid":{"_anim"},
"apiarist":{"_anim","_sb"},
"apiary":{"_loc_sr"},
"apiece":{"_quant"},
"apis":{"_prprn"},
"Apollinaire":{"_anim","_nme","_prprn","_sb"},
"Apollo":{"_anim","_masc","_prprn","_sb"},
"apologists":{"_anim","_sb"},
"apologized":{"_past"},
"apostate":{"_anim","_sb"},
"apostates":{"_anim","_sb"},
"apostle":{"_anim","_sb"},
"apostles":{"_anim","_sb"},
"apostrophe":{"_sb"},
"apothecary":{"_anim","_sb"},
"appal":{"_psych"},
"Appalachia":{"_geo","_prprn"},
"Appalachians":{"_geo","_prprn"},
"appall":{"_psych"},
"appalled":{"_past","_psych"},
"appaloosa":{"_anim"},
"Appaloosas":{"_anim"},
"appals":{"_psych"},
"apparatchik":{"_sb"},
"appareled":{"_loc_sr","_past"},
"apparition":{"_anim","_sb"},
"apparitions":{"_anim","_sb"},
"appeal":{"_psych"},
"appealed":{"_past","_psych"},
"appealing":{"_psych"},
"appear":{"_loc_sr","_vlink"},
"appeared":{"_loc_sr","_past"},
"appearing":{"_loc_sr"},
"appears":{"_loc_sr"},
"appeaser":{"_anim","_sb"},
"appeasing":{"_psych"},
"appellant":{"_anim","_sb"},
"appended":{"_past"},
"appestat":{"_loc_sr"},
"applauder":{"_anim","_sb"},
"Appleby":{"_prprn"},
"Appleseed":{"_anim","_nme","_prprn","_sb"},
"Appleton":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"applicant":{"_anim","_sb"},
"applicants":{"_anim","_sb"},
"applied":{"_loc_sr","_past"},
"applier":{"_anim","_sb"},
"applies":{"_loc_sr"},
"apply":{"_loc_sr"},
"applying":{"_loc_sr"},
"appoint":{"_loc_sr"},
"appointed":{"_loc_sr","_past"},
"appointee":{"_anim","_sb"},
"appointees":{"_anim","_sb"},
"appointing":{"_loc_sr"},
"appoints":{"_loc_sr"},
"apportioned":{"_past"},
"appose":{"_loc_sr"},
"appraisers":{"_anim","_sb"},
"appraising":{"_loc_sr"},
"appreciated":{"_past"},
"apprehend":{"_loc_sr"},
"apprehended":{"_loc_sr","_past"},
"apprehender":{"_anim","_sb"},
"apprehending":{"_loc_sr"},
"apprentice":{"_anim","_sb"},
"apprenticed":{"_loc_sr","_past"},
"apprentices":{"_anim","_sb"},
"apprised":{"_past"},
"approached":{"_past"},
"appropriator":{"_anim","_sb"},
"appropriators":{"_anim","_sb"},
"approved":{"_past"},
"approver":{"_anim","_sb"},
"approximated":{"_past"},
"apr":{"_prprn"},
"april":{"_anim","_fem","_fnme","_nme","_prprn","_sb","_tme"},
"apse":{"_loc_sr"},
"apses":{"_loc_sr"},
"apt":{"_probabl"},
"apulia":{"_geo","_prprn"},
"apus":{"_prprn"},
"aqua":{"_loc_sr"},
"aquaplane":{"_loc_sr"},
"aquarium":{"_loc_sr"},
"aquarius":{"_prprn"},
"aquifer":{"_loc_sr"},
"aquifers":{"_loc_sr"},
"aquila":{"_geo","_prprn"},
"aquinas":{"_anim","_nme","_sb"},
"Aquino":{"_anim","_nme","_prprn","_sb"},
"Aquitaine":{"_geo","_prprn","_stte"},
"aquitania":{"_geo","_prprn"},
"ara":{"_prprn"},
"arab-berbers":{"_anim","_prprn","_sb"},
"arabia":{"_geo","_prprn"},
"Arabian":{"_anim","_prprn","_sb"},
"Arabic":{"_prprn"},
"arabist":{"_anim","_prprn","_sb"},
"arable":{"_loc_sr"},
"Arabs":{"_anim","_prprn","_sb"},
"arachnid":{"_anim"},
"arafat":{"_anim","_nme","_prprn","_sb"},
"aragon":{"_anim","_cntry","_geo","_nme","_prprn","_sb","_stte"},
"araguaia":{"_geo","_prprn"},
"araguaya":{"_prprn"},
"aram":{"_cntry","_geo","_prprn"},
"aramaean":{"_prprn"},
"aramaic":{"_prprn"},
"aramean":{"_prprn","_sb"},
"arapaho":{"_anim","_prprn","_sb"},
"arapahoe":{"_anim","_prprn","_sb"},
"aras":{"_geo","_prprn"},
"arauca":{"_geo","_prprn"},
"arawak":{"_anim","_prprn","_sb"},
"arawakan":{"_prprn","_sb"},
"araxes":{"_geo","_prprn"},
"arbitragers":{"_anim","_sb"},
"arbitrageurs":{"_anim","_sb"},
"arbitrated":{"_past"},
"arbitrator":{"_anim","_sb"},
"arbitrators":{"_anim","_sb"},
"arbor":{"_loc_sr"},
"arboretum":{"_loc_sr"},
"arboriculturist":{"_anim","_sb"},
"arbour":{"_loc_sr"},
"arcade":{"_loc_sr"},
"arcades":{"_loc_sr"},
"Arcadia":{"_cty","_geo","_loc_sr","_prprn"},
"Arcadian":{"_anim","_prprn","_sb"},
"arced":{"_past"},
"arch":{"_loc_sr"},
"archaeozoic":{"_prprn"},
"archangel":{"_anim","_sb"},
"archangels":{"_anim","_sb"},
"archdeacon":{"_anim","_sb"},
"archduchess":{"_anim","_fem","_sb"},
"archduke":{"_anim","_sb"},
"arched":{"_loc_sr","_past"},
"archeologist":{"_anim","_sb"},
"archeologists":{"_anim","_sb"},
"archeozoic":{"_prprn"},
"archer":{"_anim","_sb"},
"archerfish":{"_anim"},
"Archibald":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Archie":{"_prprn"},
"archimandrite":{"_anim","_sb"},
"Archimedes":{"_anim","_nme","_prprn","_sb"},
"arching":{"_loc_sr"},
"architect-developer":{"_anim","_sb"},
"architects":{"_anim","_sb"},
"architecture":{"_loc_sr"},
"architectures":{"_loc_sr"},
"Arctic":{"_geo","_prprn"},
"arcturus":{"_prprn"},
"Arden":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"ardennes":{"_geo","_prprn"},
"area":{"_loc_sr"},
"area-sales":{"_loc_sr"},
"area-wide":{"_loc_sr"},
"areas":{"_loc_sr"},
"areaway":{"_loc_sr"},
"arena":{"_loc_sr"},
"arenas":{"_loc_sr"},
"arendt":{"_anim","_nme","_prprn","_sb"},
"areola":{"_loc_sr"},
"areopagite":{"_prprn","_sb"},
"areopagus":{"_prprn"},
"arequipa":{"_cty","_geo","_prprn"},
"argali":{"_anim"},
"Argentina":{"_cntry","_geo","_prprn"},
"Argentinian":{"_anim","_prprn","_sb"},
"argive":{"_prprn"},
"argo":{"_prprn"},
"Argonne":{"_geo","_prprn"},
"argos":{"_cty","_geo","_prprn"},
"argued":{"_past"},
"arguer":{"_anim","_sb"},
"argus":{"_prprn"},
"argyrol":{"_prprn"},
"arhat":{"_anim","_sb"},
"arhus":{"_cty","_geo","_prprn"},
"ariadne":{"_prprn"},
"arianism":{"_prprn"},
"Ariel":{"_prprn"},
"aries":{"_prprn"},
"arikara":{"_anim","_prprn","_sb"},
"Arimathea":{"_prprn"},
"arise":{"_loc_sr"},
"arisen":{"_loc_sr"},
"arises":{"_loc_sr"},
"arising":{"_loc_sr"},
"aristarchus":{"_anim","_nme","_prprn","_sb"},
"aristocracy":{"_anim","_sb"},
"aristocrat":{"_anim","_sb"},
"aristocrats":{"_anim","_sb"},
"Aristophanes":{"_anim","_nme","_prprn","_sb"},
"Aristotelian":{"_anim","_prprn","_sb"},
"Aristotle":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"arithmetician":{"_anim","_sb"},
"arius":{"_anim","_nme","_prprn","_sb"},
"Ariz":{"_prprn","_stte"},
"Ariz.":{"_prprn","_stte"},
"Arizona":{"_geo","_prprn","_stte"},
"arjuna":{"_prprn"},
"Ark":{"_prprn","_stte"},
"Arkansas":{"_geo","_prprn","_stte"},
"Arkhangelsk":{"_cty","_geo","_prprn"},
"Arlene":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Arles":{"_cntry","_cty","_geo","_prprn"},
"Arlington":{"_cty","_geo","_prprn"},
"arm-twisting":{"_loc_sr"},
"armadillos":{"_anim"},
"armageddon":{"_prprn"},
"armagnac":{"_geo","_prprn"},
"Armani":{"_prprn"},
"Armco":{"_prprn"},
"armed":{"_past"},
"armenia":{"_cntry","_cty","_geo","_prprn"},
"Armenian":{"_anim","_prprn","_sb"},
"armies":{"_anim","_sb"},
"armiger":{"_anim","_sb"},
"armin":{"_anim","_nme","_prprn","_sb"},
"arminian":{"_prprn"},
"arminius":{"_anim","_nme","_prprn","_sb"},
"Armitage":{"_prprn"},
"armored":{"_past"},
"armored-vehicle":{"_past"},
"armorer":{"_anim","_sb"},
"armoured":{"_past"},
"armourer":{"_anim","_sb"},
"armoury":{"_loc_sr"},
"armpit":{"_loc_sr"},
"armpits":{"_loc_sr"},
"armstrong":{"_anim","_nme","_prprn","_sb"},
"army":{"_anim","_sb"},
"Arne":{"_anim","_nme","_prprn","_sb"},
"Arnhem":{"_cty","_geo","_prprn"},
"arno":{"_anim","_geo","_nme","_prprn","_sb"},
"arnold":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Aroostook":{"_geo","_prprn"},
"arose":{"_loc_sr","_past"},
"around-the-world":{"_loc"},
"arousing":{"_psych"},
"arp":{"_anim","_nme","_prprn","_sb"},
"Arpanet":{"_prprn"},
"arraigned":{"_past"},
"arrange":{"_loc_sr"},
"arranged":{"_loc_sr","_past"},
"arranger":{"_anim","_sb"},
"arrangers":{"_anim","_sb"},
"arranges":{"_loc_sr"},
"arranging":{"_loc_sr"},
"arrayed":{"_loc_sr","_past"},
"arrester":{"_anim","_sb"},
"arresting":{"_loc_sr"},
"arrhenius":{"_anim","_nme","_prprn","_sb"},
"arrived":{"_past"},
"arriver":{"_anim","_sb"},
"arriviste":{"_anim","_sb"},
"arrogator":{"_anim","_sb"},
"Artemis":{"_anim","_fem","_nme","_prprn","_sb"},
"arterialize":{"_loc_sr"},
"arthur":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"articled":{"_past"},
"articulated":{"_past"},
"articulator":{"_anim","_sb"},
"artificer":{"_anim","_sb"},
"artisan":{"_anim","_sb"},
"artisans":{"_anim","_sb"},
"artist":{"_anim","_sb"},
"artist-author":{"_anim","_sb"},
"artist-nature":{"_anim","_sb"},
"artiste":{"_anim","_sb"},
"artists":{"_anim","_sb"},
"artois":{"_geo","_prprn","_stte"},
"Artur":{"_prprn"},
"Arturo":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"aruba":{"_geo","_prprn"},
"Arundel":{"_prprn"},
"aryan":{"_anim","_prprn","_sb"},
"asahikawa":{"_cty","_geo","_prprn"},
"asat":{"_prprn"},
"Asbury":{"_anim","_nme","_prprn","_sb"},
"ascend":{"_loc_sr"},
"ascended":{"_loc_sr","_past"},
"ascending":{"_loc_sr"},
"ascertain":{"_loc_sr"},
"ascetic":{"_anim","_sb"},
"ascetics":{"_anim","_sb"},
"asch":{"_anim","_nme","_prprn","_sb"},
"ASCII":{"_prprn"},
"asclepius":{"_anim","_masc","_nme","_prprn","_sb"},
"ascomycete":{"_sb"},
"ascomycetes":{"_sb"},
"ascribed":{"_past"},
"ASEAN":{"_prprn"},
"asgard":{"_prprn"},
"ashamed":{"_psych"},
"Ashcroft":{"_anim","_nme","_prprn","_sb"},
"Ashe":{"_anim","_nme","_prprn","_sb"},
"Asher":{"_anim","_nme","_prprn","_sb"},
"Asheville":{"_cty","_geo","_prprn"},
"ashkenazi":{"_prprn","_sb"},
"ashkhabad":{"_cty","_geo","_prprn"},
"ashlar":{"_loc_sr"},
"Ashley":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"ashore":{"_loc"},
"Ashton":{"_anim","_nme","_prprn","_sb"},
"ashtoreth":{"_anim","_fem","_nme","_prprn","_sb"},
"ashur":{"_prprn"},
"ashurbanipal":{"_anim","_nme","_prprn","_sb"},
"Asia":{"_geo","_prprn"},
"asian":{"_anim","_prprn","_sb"},
"Asian-American":{"_anim","_prprn","_sb"},
"Asian-Americans":{"_anim","_prprn","_sb"},
"Asians":{"_anim","_prprn","_sb"},
"asiatic":{"_prprn"},
"asimov":{"_anim","_nme","_prprn","_sb"},
"ask":{"_loc_sr"},
"asked":{"_loc_sr","_past"},
"asker":{"_anim","_sb"},
"asking":{"_loc_sr"},
"asks":{"_loc_sr"},
"asl":{"_prprn"},
"asmara":{"_cty","_geo","_prprn"},
"asp":{"_anim"},
"asper":{"_anim","_sb"},
"asphyxiated":{"_past"},
"asphyxiator":{"_anim","_sb"},
"aspirant":{"_anim","_sb"},
"aspirants":{"_anim","_sb"},
"aspired":{"_past"},
"Asquith":{"_anim","_nme","_prprn","_sb"},
"ass":{"_anim"},
"ass-kisser":{"_anim"},
"Assad":{"_anim","_nme","_prprn","_sb"},
"assailants":{"_anim","_sb"},
"assailed":{"_past"},
"assam":{"_cntry","_geo","_prprn"},
"assamese":{"_anim","_prprn","_sb"},
"assassin":{"_anim","_sb"},
"assassinated":{"_past"},
"assassinator":{"_anim","_sb"},
"assassins":{"_anim","_sb"},
"assaulter":{"_anim","_sb"},
"assayed":{"_past"},
"assemblage":{"_anim","_sb"},
"assemblages":{"_anim","_sb"},
"assembled":{"_past"},
"assembler":{"_anim","_sb"},
"assemblies":{"_anim","_sb"},
"assembly":{"_anim","_sb"},
"assembly-line":{"_anim","_sb"},
"assemblyman":{"_anim","_masc","_sb"},
"assemblywoman":{"_anim","_fem","_sb"},
"assented":{"_past"},
"assenter":{"_anim","_sb"},
"asserted":{"_past"},
"asserter":{"_anim","_sb"},
"asses":{"_anim"},
"assessed":{"_past"},
"assessee":{"_anim","_sb"},
"assessors":{"_anim","_sb"},
"asset":{"_sb"},
"asset-backed":{"_sb"},
"asset-based":{"_sb"},
"asset-forfeiture":{"_sb"},
"asset-growth":{"_sb"},
"asset-liability":{"_sb"},
"asset-management":{"_sb"},
"asset-quality":{"_sb"},
"asset-rich":{"_sb"},
"asset-sale":{"_sb"},
"asset-trading":{"_sb"},
"asset-valuation":{"_sb"},
"assets":{"_sb"},
"asseverator":{"_anim","_sb"},
"assigned":{"_past"},
"assigned-risk":{"_past"},
"assignor":{"_anim","_sb"},
"assimilate":{"_loc_sr"},
"assimilating":{"_loc_sr"},
"Assiniboine":{"_anim","_geo","_prprn","_sb"},
"assisted":{"_past"},
"assisted-living":{"_past"},
"associate-label":{"_anim","_sb"},
"assort":{"_loc_sr"},
"assorted":{"_loc_sr","_past"},
"assuage":{"_psych"},
"assuaged":{"_past","_psych"},
"assuaging":{"_psych"},
"assumed":{"_past"},
"assur":{"_prprn"},
"assurbanipal":{"_anim","_nme","_prprn","_sb"},
"assured":{"_anim","_sb"},
"Assyrian":{"_anim","_prprn","_sb"},
"assyriology":{"_prprn"},
"Astaire":{"_anim","_nme","_prprn","_sb"},
"astarte":{"_anim","_fem","_nme","_prprn","_sb"},
"asterope":{"_prprn"},
"asthenic":{"_anim","_sb"},
"Asti":{"_cty","_geo","_prprn"},
"Aston":{"_anim","_nme","_prprn","_sb"},
"astonish":{"_psych"},
"astonished":{"_past","_psych"},
"astonishes":{"_psych"},
"astonishing":{"_psych"},
"astor":{"_anim","_nme","_prprn","_sb"},
"Astoria":{"_cty","_geo","_prprn"},
"astound":{"_psych"},
"astounded":{"_past","_psych"},
"astounding":{"_psych"},
"astounds":{"_psych"},
"astrogator":{"_anim","_sb"},
"astrologer":{"_anim","_sb"},
"astrologist":{"_anim","_sb"},
"astronaut":{"_anim","_sb"},
"astronauts":{"_anim","_sb"},
"astronomer":{"_anim","_sb"},
"astronomers":{"_anim","_sb"},
"asuncion":{"_cty","_geo","_prprn"},
"aswan":{"_cty","_geo","_prprn"},
"asylum":{"_loc_sr"},
"atabrine":{"_prprn"},
"ataturk":{"_anim","_nme","_prprn","_sb"},
"ate":{"_loc_sr","_past"},
"atelier":{"_loc_sr"},
"aten":{"_prprn"},
"athabascan":{"_prprn"},
"athabaskan":{"_prprn"},
"athanasius":{"_anim","_nme","_prprn","_sb"},
"athapascan":{"_prprn"},
"atheist":{"_anim","_sb"},
"atheists":{"_anim","_sb"},
"athelstan":{"_anim","_nme","_prprn","_sb"},
"athena":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"athene":{"_prprn"},
"Athenian":{"_prprn","_sb"},
"Athenians":{"_prprn","_sb"},
"athens":{"_cty","_geo","_prprn"},
"Atherton":{"_anim","_nme","_prprn","_sb"},
"athlete":{"_anim","_sb"},
"athlete-payoff":{"_anim","_sb"},
"athlete-student":{"_anim","_sb"},
"athletes":{"_anim","_sb"},
"Atkins":{"_anim","_nme","_prprn","_sb"},
"Atkinson":{"_anim","_nme","_prprn","_sb"},
"atlanta":{"_cty","_geo","_prprn"},
"Atlantic":{"_geo","_prprn"},
"atlantis":{"_prprn"},
"Atlas":{"_prprn"},
"atomiser":{"_anim","_sb"},
"atomize":{"_loc_sr"},
"atp":{"_prprn"},
"atreus":{"_anim","_prprn","_sb"},
"atrophied":{"_past"},
"atropos":{"_prprn"},
"attache":{"_anim","_sb"},
"attached":{"_past"},
"attaches":{"_anim","_sb"},
"attacked":{"_loc_sr","_past"},
"attacker":{"_anim","_sb"},
"attackers":{"_anim","_sb"},
"attacking":{"_loc_sr"},
"attain":{"_loc_sr"},
"attained":{"_loc_sr","_past"},
"attaining":{"_loc_sr"},
"attains":{"_loc_sr"},
"attempter":{"_anim","_sb"},
"attendant":{"_anim","_sb"},
"attendants":{"_anim","_sb"},
"attendees":{"_anim","_sb"},
"attender":{"_anim","_sb"},
"attenuated":{"_past"},
"attested":{"_past"},
"attester":{"_anim","_sb"},
"attestor":{"_anim","_sb"},
"Attica":{"_geo","_prprn"},
"attics":{"_loc_sr"},
"atticus":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"attila":{"_anim","_nme","_prprn","_sb"},
"attired":{"_loc_sr","_past"},
"attitudinize":{"_loc_sr"},
"attitudinizing":{"_loc_sr"},
"Attlee":{"_anim","_nme","_prprn","_sb"},
"attorney":{"_anim","_sb"},
"attorney-client":{"_anim","_sb"},
"attorney-consultant":{"_anim","_sb"},
"attorney-disciplinary":{"_anim","_sb"},
"attorneys":{"_anim","_sb"},
"attracted":{"_past"},
"attracter":{"_anim","_sb"},
"attractor":{"_anim","_sb"},
"attributed":{"_past"},
"attrited":{"_past"},
"Attu":{"_geo","_prprn"},
"Au":{"_prprn"},
"Auckland":{"_cty","_geo","_prprn"},
"auctioned":{"_past"},
"auden":{"_anim","_nme","_prprn","_sb"},
"audience":{"_anim","_sb"},
"audience-friendly":{"_anim","_sb"},
"audiences":{"_anim","_sb"},
"audile":{"_sb"},
"audiophiles":{"_anim","_sb"},
"audited":{"_past"},
"audition":{"_loc_sr"},
"auditioning":{"_loc_sr"},
"auditor":{"_anim","_sb"},
"auditor-general":{"_anim","_sb"},
"auditorium":{"_loc_sr"},
"auditors":{"_anim","_sb"},
"audubon":{"_anim","_nme","_prprn","_sb"},
"Auerbach":{"_anim","_nme","_prprn","_sb"},
"aug":{"_prprn","_tme"},
"Aug.":{"_prprn","_tme"},
"augmented":{"_past"},
"augur":{"_loc_sr"},
"augurs":{"_loc_sr"},
"August":{"_prprn","_tme"},
"augusta":{"_anim","_cty","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"augustan":{"_prprn"},
"augustine":{"_anim","_nme","_prprn","_sb"},
"Augustines":{"_anim","_nme","_prprn","_sb"},
"augustinian":{"_prprn"},
"Augustus":{"_anim","_nme","_prprn","_sb"},
"auk":{"_anim"},
"aum":{"_prprn"},
"aunt":{"_anim","_fem","_sb"},
"Auntie":{"_anim","_sb"},
"aunts":{"_anim","_fem","_sb"},
"aunty":{"_anim","_sb"},
"Aurelius":{"_prprn"},
"aureomycin":{"_prprn"},
"auriga":{"_prprn"},
"aurochs":{"_anim"},
"Aurora":{"_anim","_cty","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"auschwitz":{"_geo","_prprn"},
"auspex":{"_anim","_sb"},
"auspices":{"_anim","_sb"},
"Aussie":{"_anim","_prprn","_sb"},
"Austen":{"_anim","_nme","_prprn","_sb"},
"austerlitz":{"_cty","_geo","_prprn"},
"Austin":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"Australasian":{"_prprn","_sb"},
"Australia":{"_cntry","_geo","_prprn"},
"Australian":{"_anim","_prprn","_sb"},
"Australians":{"_anim","_prprn","_sb"},
"austria":{"_cntry","_geo","_prprn"},
"austria-hungary":{"_cntry","_geo","_prprn"},
"austrian":{"_anim","_prprn","_sb"},
"Austrians":{"_anim","_prprn","_sb"},
"austro-asiatic":{"_prprn"},
"Austro-Hungarian":{"_prprn"},
"austronesia":{"_geo","_prprn"},
"austronesian":{"_prprn"},
"authenticated":{"_past"},
"author":{"_anim","_sb"},
"authored":{"_past"},
"authoress":{"_anim","_fem","_sb"},
"authorised":{"_past"},
"authoriser":{"_anim","_sb"},
"authoritarian":{"_anim","_sb"},
"authorities":{"_anim","_sb"},
"authority":{"_anim"},
"authorized":{"_past"},
"authorizer":{"_anim","_sb"},
"authors":{"_anim","_sb"},
"auto-dealer":{"_anim","_sb"},
"auto-loaders":{"_anim","_sb"},
"auto-maker":{"_anim","_sb"},
"auto-parts":{"_loc_sr"},
"auto-strop":{"_loc_sr"},
"autobiographer":{"_anim","_sb"},
"autochthon":{"_loc_sr"},
"autoclave":{"_loc_sr"},
"autocollimator":{"_anim","_sb"},
"autocrat":{"_anim","_sb"},
"autocrats":{"_anim","_sb"},
"autodidact":{"_sb"},
"autofluorescent":{"_anim","_sb"},
"autofocus":{"_loc_sr"},
"autograft":{"_loc_sr"},
"autographed":{"_past"},
"autographer":{"_anim","_sb"},
"autoinjector":{"_anim","_sb"},
"automated":{"_past"},
"automated-pit-trading":{"_past"},
"automated-quotation":{"_past"},
"automated-teller":{"_past"},
"automated-teller-machine":{"_past"},
"automobilist":{"_anim","_sb"},
"autonavigator":{"_anim","_sb"},
"autumn":{"_tme"},
"autumn-blooming":{"_tme"},
"autumn-flowering":{"_tme"},
"autumn-touched":{"_tme"},
"autumns":{"_tme"},
"auvergne":{"_geo","_prprn","_stte"},
"auxiliaries":{"_anim","_sb"},
"AV":{"_prprn"},
"availed":{"_past"},
"Avalon":{"_prprn"},
"Ave":{"_prprn"},
"Ave.":{"_prprn"},
"avenged":{"_past"},
"Aventine":{"_geo","_loc_sr","_prprn"},
"averaged":{"_past"},
"averred":{"_past"},
"averroes":{"_anim","_nme","_prprn","_sb"},
"averted":{"_past"},
"Avery":{"_anim","_fnme","_nme","_prprn","_sb"},
"avesta":{"_prprn"},
"avestan":{"_prprn"},
"aviators":{"_anim","_sb"},
"aviatress":{"_anim","_fem","_sb"},
"aviatrix":{"_anim","_fem","_sb"},
"avicenna":{"_anim","_nme","_prprn","_sb"},
"avifauna":{"_anim"},
"avignon":{"_cty","_geo","_prprn"},
"avocet":{"_anim"},
"avogadro":{"_anim","_nme","_prprn","_sb"},
"avoided":{"_past"},
"Avon":{"_geo","_prprn"},
"avower":{"_anim","_sb"},
"awaited":{"_past"},
"awake":{"_loc_sr"},
"awakened":{"_past"},
"awarded":{"_past"},
"awed":{"_past","_psych"},
"awhile":{"_tme"},
"awless":{"_anim","_fem","_sb"},
"awoke":{"_loc_sr","_past"},
"awol":{"_anim","_prprn","_sb"},
"Axelrod":{"_anim","_nme","_prprn","_sb"},
"axle":{"_sb"},
"axle-breaking":{"_sb"},
"axolotl":{"_anim"},
"ayah":{"_anim","_sb"},
"aye-aye":{"_anim"},
"Ayer":{"_anim","_sb"},
"Aylesbury":{"_prprn"},
"ayr":{"_geo","_prprn"},
"ayrshire":{"_prprn"},
"az":{"_prprn","_stte"},
"Azerbaijan":{"_cntry","_geo","_prprn"},
"azerbaijani":{"_anim","_prprn","_sb"},
"azeri":{"_anim","_prprn","_sb"},
"azores":{"_geo","_prprn"},
"azt":{"_prprn"},
"Aztec":{"_anim","_prprn","_sb"},
"B-cell":{"_prprn"},
"B-cells":{"_prprn"},
"b-girl":{"_anim","_fem","_prprn","_sb"},
"b-horizon":{"_prprn"},
"B-movie":{"_prprn"},
"babar":{"_anim","_nme","_prprn","_sb"},
"babbitt":{"_anim","_nme","_prprn","_sb"},
"babbled":{"_past"},
"babbler":{"_anim","_sb"},
"Babel":{"_cty","_geo","_prprn"},
"babes":{"_anim","_sb"},
"babies":{"_anim","_sb"},
"babies'-breath":{"_anim","_sb"},
"babirusa":{"_anim"},
"baboons":{"_anim"},
"babu":{"_anim","_sb"},
"baby-boom":{"_anim","_sb"},
"baby-boomers":{"_anim","_sb"},
"baby-faced":{"_anim","_sb"},
"baby-food":{"_anim","_sb"},
"baby-like":{"_anim","_sb"},
"baby-walker":{"_anim","_sb"},
"babylon":{"_cty","_geo","_prprn"},
"babylonia":{"_geo","_prprn"},
"babysitter":{"_anim","_sb"},
"Bacall":{"_prprn"},
"Bacardi":{"_prprn"},
"bacchus":{"_prprn"},
"Bacharach":{"_prprn"},
"bachelor":{"_anim","_masc","_sb"},
"bachelor-at-arms":{"_anim","_masc","_sb"},
"bachelor-type":{"_anim","_masc","_sb"},
"bachelors":{"_anim","_masc","_sb"},
"backbench":{"_anim","_sb"},
"backbencher":{"_anim","_sb"},
"backbiter":{"_anim","_sb"},
"backdated":{"_past"},
"backed":{"_loc_sr","_past"},
"backer":{"_anim","_sb"},
"backers":{"_anim","_sb"},
"backfired":{"_past"},
"backhanded":{"_past"},
"backing":{"_loc_sr"},
"backpacker":{"_anim","_sb"},
"backpackers":{"_anim","_sb"},
"backpedal":{"_loc_sr"},
"backpedaling":{"_loc_sr"},
"backrooms":{"_loc_sr"},
"backslapper":{"_anim","_sb"},
"backslide":{"_loc_sr"},
"backslider":{"_anim","_sb"},
"backsliding":{"_loc_sr"},
"backspace":{"_loc_sr"},
"backspacer":{"_anim","_sb"},
"backstroker":{"_anim","_sb"},
"backtrack":{"_loc_sr"},
"backtracking":{"_loc_sr"},
"backup":{"_sb"},
"backups":{"_sb"},
"backwater":{"_loc_sr"},
"backwoods":{"_loc_sr"},
"backwoods-and-sand-hill":{"_loc_sr"},
"backwoodsman":{"_anim","_sb"},
"bacteria":{"_anim","_loc_sr"},
"bacteria-based":{"_anim","_loc_sr"},
"bacteria-contaminated":{"_anim","_loc_sr"},
"bacteria-free":{"_anim","_loc_sr"},
"Baden-Baden":{"_cty","_geo","_prprn"},
"Bader":{"_anim","_sb"},
"badger":{"_anim"},
"badgered":{"_past"},
"badgerer":{"_anim","_sb"},
"Badlands":{"_geo","_loc_sr","_prprn"},
"baeda":{"_anim","_nme","_prprn","_sb"},
"Baez":{"_anim","_nme","_prprn","_sb"},
"Baffin":{"_anim","_geo","_nme","_prprn","_sb"},
"baffle":{"_psych"},
"baffled":{"_past","_psych"},
"baffling":{"_psych"},
"bag":{"_loc_sr"},
"bag-shaped":{"_loc_sr"},
"bagdad":{"_geo","_prprn"},
"baggage":{"_loc_sr"},
"bagged":{"_loc_sr","_past"},
"bagging":{"_loc_sr"},
"Baghdad":{"_cty","_geo","_prprn"},
"bagman":{"_anim","_sb"},
"bagpiper":{"_anim","_sb"},
"bahaism":{"_prprn"},
"Bahamas":{"_cntry","_geo","_prprn"},
"bahamian":{"_anim","_prprn","_sb"},
"Bahia":{"_geo","_prprn"},
"bahrain":{"_cntry","_geo","_prprn"},
"bahraini":{"_anim","_prprn","_sb"},
"bahrein":{"_prprn"},
"bailed":{"_past"},
"bailee":{"_anim","_sb"},
"bailiwick":{"_loc_sr"},
"bailor":{"_anim","_sb"},
"Bainbridge":{"_anim","_nme","_prprn","_sb"},
"Baird":{"_anim","_nme","_prprn","_sb"},
"bairiki":{"_geo","_prprn"},
"bairn":{"_anim","_sb"},
"baited":{"_past"},
"baked":{"_past"},
"bakeries":{"_loc_sr"},
"bakers":{"_anim","_sb"},
"bakersfield":{"_cty","_geo","_prprn"},
"bakery":{"_loc_sr"},
"bakery-mix":{"_loc_sr"},
"baku":{"_cty","_geo","_prprn"},
"bakunin":{"_anim","_nme","_prprn","_sb"},
"Bala":{"_prprn"},
"Balaguer":{"_prprn"},
"Balance":{"_prprn"},
"balanced":{"_past"},
"balanced-budget":{"_past"},
"Balanchine":{"_anim","_nme","_prprn","_sb"},
"balconies":{"_loc_sr"},
"baldhead":{"_anim","_sb"},
"baldwin":{"_anim","_geo","_nme","_prprn","_sb"},
"balenciaga":{"_anim","_nme","_prprn","_sb"},
"Balfour":{"_anim","_nme","_prprn","_sb"},
"Bali":{"_geo","_prprn"},
"balinese":{"_anim","_prprn","_sb"},
"balkanized":{"_loc_sr","_past"},
"Balkanizing":{"_loc_sr"},
"balkans":{"_prprn"},
"balked":{"_loc_sr","_past"},
"balker":{"_anim","_sb"},
"balking":{"_loc_sr"},
"Ballard":{"_anim","_nme","_prprn","_sb"},
"ballards":{"_anim","_nme","_prprn","_sb"},
"balled":{"_loc_sr","_past"},
"balling":{"_loc_sr"},
"ballooning":{"_loc_sr"},
"balloonist":{"_anim","_sb"},
"balloonists":{"_anim","_sb"},
"ballplayers":{"_anim","_sb"},
"ballroom":{"_loc_sr"},
"ballyhooed":{"_past"},
"Balmer":{"_anim","_sb"},
"balthasar":{"_prprn"},
"balthazar":{"_anim","_nme","_prprn","_sb"},
"Baltic":{"_prprn"},
"baltic-finnic":{"_prprn"},
"Baltimore":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"balto-slavic":{"_prprn"},
"baluchi":{"_anim","_prprn","_sb"},
"balzac":{"_anim","_nme","_prprn","_sb"},
"bamako":{"_cty","_geo","_prprn"},
"Bambi":{"_prprn"},
"bamboozled":{"_past"},
"Banbury":{"_prprn"},
"Bancroft":{"_anim","_nme","_prprn","_sb"},
"Band-Aid":{"_prprn"},
"Banda":{"_prprn"},
"bandaged":{"_past"},
"banded":{"_loc_sr","_past"},
"banderillero":{"_anim","_sb"},
"bandicoot":{"_anim"},
"bandied":{"_past"},
"banding":{"_loc_sr"},
"bandits":{"_anim","_sb"},
"bandleader":{"_anim","_sb"},
"bandmaster":{"_anim","_sb"},
"bandsman":{"_anim","_sb"},
"bandung":{"_cty","_geo","_prprn"},
"banff":{"_cty","_geo","_prprn"},
"Bangalore":{"_cty","_geo","_prprn"},
"banged":{"_past"},
"Bangladesh":{"_cntry","_geo","_prprn"},
"bangor":{"_cty","_geo","_prprn"},
"banish":{"_loc_sr"},
"banjul":{"_cty","_geo","_prprn"},
"bank-affiliated":{"_loc_sr"},
"bank-backed":{"_loc_sr"},
"bank-baiting":{"_loc_sr"},
"bank-branch":{"_loc_sr"},
"bank-credit":{"_loc_sr"},
"bank-debt":{"_loc_sr"},
"bank-director":{"_loc_sr"},
"bank-embezzlement":{"_loc_sr"},
"bank-fraud":{"_loc_sr"},
"bank-looting":{"_loc_sr"},
"bank-owned":{"_loc_sr"},
"bank-sponsored":{"_loc_sr"},
"bank-teller":{"_loc_sr"},
"banked":{"_loc_sr","_past"},
"banker":{"_anim","_sb"},
"banker-editor":{"_anim","_sb"},
"bankers":{"_anim","_sb"},
"Bankhead":{"_anim","_nme","_prprn","_sb"},
"banking":{"_loc_sr"},
"bankrupts":{"_anim","_sb"},
"banks":{"_loc_sr"},
"banned":{"_past"},
"Bannister":{"_anim","_prprn","_sb"},
"bannockburn":{"_cty","_geo","_prprn"},
"banqueting":{"_loc_sr"},
"banshee":{"_anim","_fem","_sb"},
"banshees":{"_anim","_fem","_sb"},
"bantam":{"_anim"},
"bantamweight":{"_anim","_sb"},
"banting":{"_anim","_nme","_prprn","_sb"},
"bantu":{"_anim","_prprn","_sb"},
"bantu-speaking":{"_anim","_prprn","_sb"},
"baptised":{"_past"},
"baptize":{"_loc_sr"},
"baptized":{"_loc_sr","_past"},
"Barak":{"_prprn"},
"baraka":{"_anim","_nme","_prprn","_sb"},
"barany":{"_anim","_nme","_prprn","_sb"},
"barbadian":{"_anim","_prprn","_sb"},
"Barbados":{"_cntry","_geo","_prprn"},
"Barbara":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"barbarian":{"_anim","_sb"},
"barbarians":{"_anim","_sb"},
"barbarossa":{"_anim","_nme","_prprn","_sb"},
"barbary":{"_geo","_prprn"},
"barbecued":{"_loc_sr","_past"},
"barbed":{"_past"},
"barbed-wire":{"_past"},
"barbel":{"_anim"},
"Barbera":{"_prprn"},
"barbers":{"_anim","_sb"},
"barbershop":{"_loc_sr"},
"barbette":{"_loc_sr"},
"Barbour":{"_anim","_nme","_prprn","_sb"},
"barbuda":{"_geo","_prprn"},
"Barcalounger":{"_prprn"},
"barcelona":{"_cty","_geo","_prprn"},
"Barclay":{"_anim","_nme","_prprn","_sb"},
"bardeen":{"_anim","_nme","_prprn","_sb"},
"bards":{"_anim","_sb"},
"bared":{"_past"},
"barflies":{"_anim","_sb"},
"bargained":{"_past"},
"bargainer":{"_anim","_sb"},
"bargee":{"_anim","_sb"},
"bargeman":{"_sb"},
"bari":{"_cty","_geo","_prprn"},
"baritone":{"_anim","_masc","_sb"},
"barked":{"_past"},
"barkeeper":{"_anim","_sb"},
"barker":{"_anim","_sb"},
"barkley":{"_anim","_nme","_prprn","_sb"},
"Barletta":{"_cty","_geo","_prprn"},
"barmaid":{"_anim","_fem","_sb"},
"barman":{"_anim","_masc","_sb"},
"barn":{"_loc_sr"},
"barn-burner":{"_loc_sr"},
"Barnabas":{"_anim","_nme","_prprn","_sb"},
"barnacle":{"_anim","_sb"},
"Barnard":{"_anim","_nme","_prprn","_sb"},
"barns":{"_loc_sr"},
"barnstorm":{"_loc_sr"},
"barnum":{"_anim","_nme","_prprn","_sb"},
"barnyards":{"_loc_sr"},
"baron":{"_anim","_masc","_sb"},
"baronet":{"_anim","_masc","_sb"},
"barranquilla":{"_cty","_geo","_prprn"},
"barrator":{"_anim","_sb"},
"barred":{"_past"},
"barrel":{"_loc_sr"},
"barrel-a-day":{"_loc_sr"},
"barrel-chested":{"_loc_sr"},
"barrel-per-day":{"_loc_sr"},
"barrel-shaped":{"_loc_sr"},
"barrel-vaulted":{"_loc_sr"},
"barrel-wide":{"_loc_sr"},
"barreled":{"_loc_sr","_past"},
"barreling":{"_loc_sr"},
"barrelled":{"_loc_sr","_past"},
"barrels":{"_loc_sr"},
"barren":{"_loc_sr"},
"Barrett":{"_anim","_fnme","_nme","_prprn","_sb"},
"barretter":{"_anim","_sb"},
"barricaded":{"_past"},
"barricades":{"_loc_sr"},
"barrie":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Barrington":{"_cty","_geo","_prprn"},
"barristers":{"_anim","_sb"},
"Barros":{"_anim","_nme","_prprn","_sb"},
"Barry":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Barrymore":{"_anim","_nme","_prprn","_sb"},
"barstow":{"_cty","_geo","_prprn"},
"Bart":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"bartender":{"_anim","_sb"},
"bartenders":{"_anim","_sb"},
"bartered":{"_past"},
"barterer":{"_anim","_sb"},
"barth":{"_anim","_nme","_prprn","_sb"},
"barthelme":{"_anim","_nme","_prprn","_sb"},
"bartholdi":{"_anim","_nme","_prprn","_sb"},
"Bartholomew":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"bartlesville":{"_cty","_geo","_prprn"},
"Bartlett":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Bartok":{"_anim","_nme","_prprn","_sb"},
"Bartoli":{"_prprn"},
"Barton":{"_anim","_nme","_prprn","_sb"},
"baruch":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"baryshnikov":{"_anim","_nme","_prprn","_sb"},
"based":{"_past"},
"Basel":{"_cty","_geo","_prprn"},
"basement":{"_loc_sr"},
"basements":{"_loc_sr"},
"basenji":{"_anim"},
"bashed":{"_past"},
"Bashir":{"_prprn"},
"Basho":{"_anim","_nme","_prprn","_sb"},
"basidiomycete":{"_sb"},
"basidiomycetes":{"_sb"},
"Basie":{"_anim","_nme","_prprn","_sb"},
"basify":{"_loc_sr"},
"basilica":{"_loc_sr"},
"basilicata":{"_geo","_prprn","_stte"},
"basilisk":{"_anim"},
"basin":{"_loc_sr"},
"basins":{"_loc_sr"},
"basked":{"_loc_sr","_past"},
"Baskerville":{"_anim","_nme","_prprn","_sb"},
"basket":{"_loc_sr"},
"basket-shaped":{"_loc_sr"},
"baskets":{"_loc_sr"},
"basking":{"_loc_sr"},
"basle":{"_geo","_prprn"},
"Basque":{"_anim","_prprn","_sb"},
"Basra":{"_cty","_geo","_prprn"},
"basses":{"_anim"},
"basset":{"_anim"},
"basseterre":{"_cty","_geo","_prprn"},
"bassist":{"_anim","_sb"},
"bassoonist":{"_anim","_sb"},
"bastard":{"_anim","_sb"},
"bastardised":{"_past"},
"bastardize":{"_loc_sr"},
"bastardized":{"_loc_sr","_past"},
"bastards":{"_anim","_sb"},
"baste":{"_loc_sr"},
"baster":{"_anim","_sb"},
"basting":{"_loc_sr"},
"basutoland":{"_geo","_prprn"},
"bataan":{"_geo","_prprn"},
"Batangas":{"_prprn"},
"Batavia":{"_cty","_geo","_prprn"},
"bated":{"_past"},
"batfish":{"_anim"},
"bathe":{"_loc_sr"},
"bathed":{"_past"},
"bather":{"_anim","_sb"},
"bathers":{"_anim","_sb"},
"bathhouse":{"_loc_sr"},
"bathing":{"_loc_sr"},
"bathroom":{"_loc_sr"},
"bathrooms":{"_loc_sr"},
"baths":{"_loc_sr"},
"bathsheba":{"_anim","_fem","_nme","_prprn","_sb"},
"Bathurst":{"_cty","_geo","_prprn"},
"bathyscaph":{"_loc_sr"},
"bathysphere":{"_loc_sr"},
"Batista":{"_prprn"},
"batman":{"_anim","_sb"},
"batswana":{"_anim","_prprn","_sb"},
"battalion":{"_anim","_sb"},
"battalions":{"_anim","_sb"},
"batter-fried":{"_anim","_loc_sr","_sb"},
"battered":{"_past"},
"batters":{"_anim","_loc_sr","_sb"},
"battled":{"_past"},
"battlefield":{"_loc_sr"},
"battlefields":{"_loc_sr"},
"battler":{"_anim","_sb"},
"baudelaire":{"_anim","_nme","_prprn","_sb"},
"baulker":{"_anim","_sb"},
"Baum":{"_anim","_nme","_prprn","_sb"},
"bavaria":{"_geo","_prprn","_stte"},
"bavarian":{"_anim","_prprn","_sb"},
"bawled":{"_loc_sr","_past"},
"bawler":{"_anim","_sb"},
"bawling":{"_loc_sr"},
"Baxter":{"_anim","_nme","_prprn","_sb"},
"bay":{"_loc_sr"},
"bayard":{"_anim","_nme","_prprn","_sb"},
"bayed":{"_past"},
"bayer":{"_anim","_sb"},
"baykal":{"_prprn"},
"bayonne":{"_cty","_geo","_prprn"},
"bayou":{"_loc_sr"},
"Bayreuth":{"_cty","_geo","_prprn"},
"bc":{"_prprn","_stte","_tme"},
#"be":{"_vlink"},  # is a boy | seem weakness
#"being":{"_vlink"},
#"been":{"_vlink"},
"beach-drift":{"_loc_sr"},
"beach-head":{"_loc_sr"},
"beach-house":{"_loc_sr"},
"beach-party":{"_loc_sr"},
"beachcomber":{"_anim","_sb"},
"beached":{"_past"},
"beaches":{"_loc_sr"},
"beaded":{"_loc_sr","_past"},
"beading":{"_loc_sr"},
"beagle":{"_anim"},
"beakers":{"_loc_sr"},
"Beale":{"_prprn"},
"beam":{"_loc_sr"},
"beamed":{"_loc_sr","_past"},
"beaming":{"_loc_sr"},
"beaner":{"_anim","_sb"},
"Beantown":{"_prprn"},
"bear":{"_loc_sr"},
"bear-like":{"_anim"},
"bear-market":{"_anim"},
"bear-sized":{"_anim"},
"bearcat":{"_anim"},
"bearded":{"_past"},
"Beardsley":{"_anim","_nme","_prprn","_sb"},
"bears":{"_anim"},
"beast":{"_anim"},
"beasts":{"_anim"},
"beat":{"_past"},
"beatified":{"_past"},
"Beatitudes":{"_prprn"},
"Beatles":{"_anim","_nme","_prprn","_sb"},
"beatnik":{"_anim","_sb"},
"beatniks":{"_anim","_sb"},
"Beatrice":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"beau":{"_anim","_sb"},
"Beaufort":{"_anim","_nme","_prprn","_sb"},
"Beaujolais":{"_geo","_prprn"},
"Beaumont":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Beauregard":{"_anim","_nme","_prprn","_sb"},
"beautician":{"_anim","_sb"},
"beauticians":{"_anim","_sb"},
"beauvoir":{"_anim","_nme","_prprn","_sb"},
"beaver":{"_anim","_loc_sr","_sb"},
"beavered":{"_past"},
"beavers":{"_anim","_loc_sr","_sb"},
"becalmed":{"_past"},
"became":{"_past"},
"Beccaria":{"_prprn"},
"bechuana":{"_prprn"},
"Becker":{"_anim","_nme","_prprn","_sb"},
"Becket":{"_anim","_prprn","_sb"},
"Beckett":{"_anim","_nme","_prprn","_sb"},
"beckley":{"_cty","_geo","_prprn"},
"beckoned":{"_past"},
"becquerel":{"_anim","_nme","_prprn","_sb"},
"beda":{"_anim","_nme","_prprn","_sb"},
"bedaubed":{"_past"},
"bedazzled":{"_past"},
"bedbug":{"_anim"},
"bedder":{"_anim","_sb"},
"Bede":{"_anim","_nme","_prprn","_sb"},
"bedeck":{"_loc_sr"},
"bedevil":{"_psych"},
"bedeviled":{"_past","_psych"},
"bedewed":{"_past"},
"bedfellow":{"_anim","_sb"},
"bedfellows":{"_anim","_sb"},
"Bedford":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"bedimmed":{"_past"},
"bedlam":{"_loc_sr"},
"bedlamite":{"_sb"},
"bedouin":{"_anim","_sb"},
"Bedouins":{"_anim","_prprn","_sb"},
"bedpan":{"_loc_sr"},
"bedraggled":{"_past"},
"bedroom":{"_loc_sr"},
"bedrooms":{"_loc_sr"},
"bedside":{"_loc_sr"},
"bedsore":{"_loc_sr"},
"bedtime":{"_tme"},
"beduin":{"_prprn"},
"bee":{"_anim"},
"Beebe":{"_anim","_nme","_prprn","_sb"},
"Beecham":{"_anim","_nme","_prprn","_sb"},
"Beecher":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"beefalo":{"_anim"},
"beefcake":{"_sb"},
"Beefeater":{"_prprn"},
"beefed":{"_past"},
"beelzebub":{"_prprn"},
"beeped":{"_past"},
"beerbohm":{"_anim","_nme","_prprn","_sb"},
"bees":{"_anim"},
"Beethoven":{"_anim","_nme","_prprn","_sb"},
"beetle":{"_loc_sr"},
"beetle-browed":{"_anim"},
"beetles":{"_anim"},
"beetling":{"_loc_sr"},
"befell":{"_past"},
"befogged":{"_past"},
"before":{"_loc","_tme"},
"before-and-after":{"_loc","_tme"},
"before-tax":{"_loc","_tme"},
"beforehand":{"_tme"},
"befouled":{"_past"},
"befriended":{"_past"},
"befuddle":{"_psych"},
"befuddling":{"_psych"},
"began":{"_loc_sr","_past"},
"begetter":{"_anim","_sb"},
"beggar":{"_anim","_sb"},
"beggar's-ticks":{"_anim","_sb"},
"beggar-my-neighbor":{"_anim","_sb"},
"beggar-my-neighbour":{"_anim","_sb"},
"beggar-thy-neighbor":{"_anim","_sb"},
"beggar-ticks":{"_anim","_sb"},
"beggars":{"_anim","_sb"},
"begged":{"_past"},
"begin":{"_loc_sr"},
"beginner":{"_anim","_sb"},
"beginners":{"_anim","_sb"},
"beginning":{"_loc_sr"},
"begins":{"_loc_sr"},
"begot":{"_past"},
"begrimed":{"_past"},
"beguile":{"_psych"},
"beguiler":{"_anim","_sb"},
"beguiling":{"_psych"},
"begum":{"_anim","_fem","_sb"},
"begun":{"_loc_sr"},
"Behan":{"_anim","_nme","_prprn","_sb"},
"behaved":{"_past"},
"beheaded":{"_past"},
"beheld":{"_loc_sr","_past"},
"behold":{"_loc_sr"},
"beholds":{"_loc_sr"},
"behring":{"_anim","_nme","_prprn","_sb"},
"Beiderbecke":{"_anim","_nme","_prprn","_sb"},
"Beijing":{"_cty","_geo","_prprn"},
"beings":{"_anim","_sb"},
"Beira":{"_cty","_geo","_prprn"},
"Beirut":{"_cty","_geo","_prprn"},
"Bekaa":{"_prprn"},
"Belarus":{"_cntry","_geo","_prprn"},
"Belasco":{"_anim","_nme","_prprn","_sb"},
"belau":{"_cntry","_geo","_prprn"},
"belch":{"_loc_sr"},
"belched":{"_loc_sr","_past"},
"beldam":{"_anim","_fem","_sb"},
"beleaguer":{"_psych"},
"beleaguered":{"_past","_psych"},
"beleaguering":{"_psych"},
"belem":{"_cty","_geo","_prprn"},
"Belfast":{"_cty","_geo","_prprn"},
"Belgian":{"_anim","_prprn","_sb"},
"Belgium":{"_cntry","_geo","_prprn"},
"Belgrade":{"_cty","_geo","_prprn"},
"belied":{"_past"},
"belief":{"_loc_sr"},
"beliefs":{"_loc_sr"},
"believed":{"_past"},
"believers":{"_anim","_sb"},
"belisarius":{"_anim","_nme","_prprn","_sb"},
"belittled":{"_past"},
"Belize":{"_cntry","_cty","_geo","_prprn"},
"bell":{"_loc_sr"},
"bell-ringer":{"_loc_sr"},
"bell-ringers":{"_loc_sr"},
"bell-ringing":{"_loc_sr"},
"bell-shaped":{"_loc_sr"},
"Bella":{"_prprn"},
"Bellamy":{"_anim","_nme","_prprn","_sb"},
"Bellas":{"_prprn"},
"bellboys":{"_anim","_sb"},
"belle":{"_anim","_fem","_sb"},
"belled":{"_loc_sr","_past"},
"bellerophon":{"_prprn"},
"belles":{"_anim","_fem","_sb"},
"bellhop":{"_anim","_sb"},
"bellhops":{"_anim","_sb"},
"bellied":{"_past"},
"belling":{"_loc_sr"},
"Bellingham":{"_cty","_geo","_prprn"},
"Bellini":{"_anim","_nme","_prprn","_sb"},
"belloc":{"_anim","_nme","_prprn","_sb"},
"bellowed":{"_past"},
"bellower":{"_anim","_sb"},
"bells":{"_loc_sr"},
"belly-land":{"_loc_sr"},
"bellyacher":{"_anim","_sb"},
"belmont":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"belonged":{"_past"},
"belorussia":{"_cntry","_geo","_prprn"},
"Belorussian":{"_anim","_prprn","_sb"},
"beloved":{"_anim","_sb"},
"below":{"_loc"},
"below-average":{"_loc"},
"below-investment":{"_loc"},
"below-market":{"_loc"},
"belsen":{"_geo","_prprn"},
"Belshazzar":{"_anim","_nme","_prprn","_sb"},
"belted":{"_past"},
"bemidji":{"_cty","_geo","_prprn"},
"bemoaned":{"_past"},
"bemused":{"_past"},
"ben":{"_loc_sr"},
"Ben-Gurion":{"_anim","_fnme","_loc_sr","_masc","_nme","_prprn","_sb"},
"benched":{"_past"},
"Benchley":{"_anim","_nme","_prprn","_sb"},
"Benda":{"_prprn"},
"beneath":{"_loc"},
"benedict":{"_sb"},
"Benedictine":{"_anim","_masc","_prprn","_sb"},
"benefactors":{"_anim","_sb"},
"benefactress":{"_anim","_fem","_sb"},
"beneficed":{"_past"},
"beneficiaries":{"_anim","_sb"},
"beneficiary":{"_anim","_sb"},
"benefited":{"_past"},
"Benelux":{"_geo","_prprn"},
"benet":{"_anim","_nme","_prprn","_sb"},
"BEng":{"_prprn"},
"bengal":{"_geo","_prprn"},
"Bengali":{"_anim","_prprn","_sb"},
"Bengalis":{"_prprn"},
"benghazi":{"_cty","_geo","_prprn"},
"benin":{"_cntry","_cty","_geo","_prprn"},
"Benjamin":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Bennett":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Bennington":{"_cty","_geo","_prprn"},
"benniseed":{"_past"},
"Benny":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Benson":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"bent":{"_past"},
"Bentham":{"_anim","_nme","_prprn","_sb"},
"Bentley":{"_anim","_nme","_prprn","_sb"},
"Benton":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"benumbed":{"_past"},
"Benz":{"_anim","_nme","_prprn","_sb"},
"Benzedrine":{"_prprn"},
"beograd":{"_geo","_prprn"},
"Beowulf":{"_prprn"},
"bequeath":{"_loc_sr"},
"berated":{"_past"},
"Berber":{"_anim","_prprn","_sb"},
"Berbera":{"_prprn"},
"bereft":{"_past"},
"Berenson":{"_anim","_nme","_prprn","_sb"},
"Beresford":{"_prprn"},
"Bergen":{"_cty","_geo","_prprn"},
"Bergman":{"_anim","_nme","_prprn","_sb"},
"Bergson":{"_anim","_nme","_prprn","_sb"},
"beria":{"_anim","_nme","_prprn","_sb"},
"Bering":{"_anim","_nme","_prprn","_sb"},
"berk":{"_anim","_sb"},
"Berkeley":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Berkshire":{"_anim","_geo","_prprn"},
"berkshires":{"_prprn"},
"Berlin":{"_cty","_geo","_prprn","_stte"},
"Berliner":{"_anim","_nme","_prprn","_sb"},
"Berliners":{"_anim","_nme","_prprn","_sb"},
"berlioz":{"_anim","_nme","_prprn","_sb"},
"Berlusconi":{"_prprn"},
"bermuda":{"_geo","_prprn"},
"bermudan":{"_anim","_sb"},
"bermudas":{"_prprn"},
"Bern":{"_cty","_geo","_prprn"},
"Bernadette":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Bernard":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Bernardine":{"_prprn"},
"berne":{"_geo","_prprn"},
"bernhardt":{"_anim","_nme","_prprn","_sb"},
"Bernice":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"bernini":{"_anim","_nme","_prprn","_sb"},
"bernoulli":{"_anim","_nme","_prprn","_sb"},
"bernstein":{"_anim","_nme","_prprn","_sb"},
"Berra":{"_anim","_nme","_prprn","_sb"},
"berried":{"_past"},
"berserk":{"_anim","_sb"},
"berserker":{"_anim","_sb"},
"berth":{"_loc_sr"},
"berths":{"_loc_sr"},
"bertillon":{"_anim","_nme","_prprn","_sb"},
"Bertram":{"_prprn"},
"berzelius":{"_anim","_nme","_prprn","_sb"},
"beset":{"_loc_sr","_past"},
"besets":{"_loc_sr"},
"besieged":{"_past"},
"besieger":{"_anim","_sb"},
"besiegers":{"_anim","_sb"},
"besmirch":{"_loc_sr"},
"besmirching":{"_loc_sr"},
"besotted":{"_past"},
"Bess":{"_prprn"},
"Bessarabia":{"_geo","_prprn"},
"bessel":{"_anim","_nme","_prprn","_sb"},
"bessemer":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"bested":{"_past"},
"bestir":{"_loc_sr"},
"bestirred":{"_loc_sr","_past"},
"bestowed":{"_past"},
"bestower":{"_anim","_sb"},
"bet":{"_loc_sr","_past"},
"betelgeuse":{"_prprn"},
"beth":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"bethel":{"_loc_sr"},
"Bethesda":{"_cty","_geo","_prprn"},
"bethlehem":{"_cty","_geo","_prprn"},
"bethlehem-judah":{"_cty","_geo","_prprn"},
"bethought":{"_past"},
"Bethune":{"_anim","_nme","_prprn","_sb"},
"betrayed":{"_past"},
"betrothed":{"_anim","_sb"},
"bettered":{"_past"},
"betters":{"_anim","_sb"},
"betties":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"betting":{"_loc_sr"},
"bettor":{"_anim","_sb"},
"Betty":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"betwixt":{"_loc"},
"beveled":{"_past"},
"beveridge":{"_anim","_nme","_prprn","_sb"},
"Beverly":{"_anim","_cty","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"bevin":{"_anim","_nme","_prprn","_sb"},
"bewilder":{"_psych"},
"bewildered":{"_past","_psych"},
"bewildering":{"_psych"},
"bewilders":{"_psych"},
"bewitch":{"_psych"},
"bewitched":{"_past","_psych"},
"bewitching":{"_psych"},
"bey":{"_anim","_masc","_sb"},
"Bezos":{"_prprn"},
"bh":{"_prprn"},
"bhagavad-gita":{"_prprn"},
"Bharat":{"_prprn"},
"bhutan":{"_cntry","_geo","_prprn"},
"bhutanese":{"_anim","_prprn","_sb"},
"bhutani":{"_anim","_prprn","_sb"},
"Bhutto":{"_anim","_nme","_prprn","_sb"},
"bi-modal":{"_anim","_sb"},
"bi-monthly":{"_anim","_sb"},
"bi-polar":{"_anim","_sb"},
"bi-regional":{"_anim","_sb"},
"Biafra":{"_geo","_prprn"},
"biased":{"_loc_sr","_past"},
"bib":{"_loc_sr"},
"bibbed":{"_loc_sr","_past"},
"Bible":{"_prprn"},
"Bibles":{"_prprn"},
"bibliographer":{"_anim","_sb"},
"bibliophile":{"_anim","_sb"},
"bibliophiles":{"_anim","_sb"},
"Bic":{"_prprn"},
"bickering":{"_loc_sr"},
"bicycle":{"_loc_sr"},
"bicycler":{"_anim","_sb"},
"bicycling":{"_loc_sr"},
"bid":{"_past"},
"bidder":{"_anim","_sb"},
"bidders":{"_anim","_sb"},
"biddies":{"_anim"},
"Biddle":{"_anim","_nme","_prprn","_sb"},
"biddy":{"_anim"},
"bided":{"_past"},
"Biden":{"_anim","_fnme","_nme","_prprn","_sb"},
"biennium":{"_tme"},
"Bienville":{"_anim","_nme","_prprn","_sb"},
"bierce":{"_anim","_nme","_prprn","_sb"},
"bifurcate":{"_loc_sr"},
"bifurcated":{"_loc_sr","_past"},
"bigamist":{"_anim","_sb"},
"bigfoot":{"_prprn"},
"biggie":{"_sb"},
"bighead":{"_anim","_sb"},
"bigot":{"_anim","_sb"},
"bigots":{"_anim","_sb"},
"bigwig":{"_anim","_sb"},
"bihar":{"_geo","_prprn"},
"bihari":{"_anim","_prprn","_sb"},
"biker":{"_anim","_sb"},
"Bilbao":{"_cty","_geo","_prprn"},
"bilingual":{"_anim","_sb"},
"bilingualist":{"_anim","_sb"},
"bilked":{"_past"},
"billed":{"_loc_sr","_past"},
"Billie":{"_anim","_fem","_fnme","_masc","_nme","_prprn","_sb"},
"billing":{"_loc_sr"},
"billion":{"_num","_quant"},
"billion-a":{"_num","_quant"},
"billion-asset":{"_num","_quant"},
"billion-dollar":{"_num","_quant"},
"billion-pound":{"_num","_quant"},
"billion-share":{"_num","_quant"},
"billion-yen":{"_num","_quant"},
"billionaire":{"_anim","_sb"},
"billionaires":{"_anim","_sb"},
"billions":{"_num","_quant"},
"billow":{"_loc_sr"},
"billowed":{"_loc_sr","_past"},
"billowing":{"_loc_sr"},
"billows":{"_loc_sr"},
"billy":{"_loc_sr"},
"billy-ho":{"_loc_sr"},
"biloxi":{"_anim","_cty","_geo","_prprn","_sb"},
"bimbo":{"_anim","_fem","_sb"},
"bimbos":{"_anim","_fem","_sb"},
"bin":{"_loc_sr"},
"binders":{"_anim","_sb"},
"bindery":{"_loc_sr"},
"Bing":{"_anim","_nme","_prprn","_sb"},
"binger":{"_anim","_sb"},
"Bingham":{"_anim","_nme","_prprn","_sb"},
"Binghamton":{"_cty","_geo","_prprn"},
"Bini":{"_prprn"},
"binturong":{"_anim"},
"biochemist":{"_anim","_sb"},
"biochemists":{"_anim","_sb"},
"bioengineer":{"_anim","_sb"},
"bioengineers":{"_anim","_sb"},
"biographer":{"_anim","_sb"},
"bioko":{"_geo","_prprn"},
"biophysicist":{"_anim","_sb"},
"biosphere":{"_loc_sr"},
"biped":{"_anim"},
"bird":{"_anim"},
"bird-brain":{"_anim"},
"bird-nest":{"_anim"},
"bird-on-the-wing":{"_anim"},
"bird-scarer":{"_anim"},
"birdbrain":{"_anim","_sb"},
"birdied":{"_loc_sr","_past"},
"birds":{"_anim"},
"Birmingham":{"_cty","_geo","_prprn"},
"birthday":{"_tme"},
"birthdays":{"_tme"},
"birthed":{"_past"},
"bisect":{"_loc_sr"},
"bisexual":{"_anim","_sb"},
"bishop":{"_anim","_sb"},
"bishops":{"_anim","_sb"},
"bismarck":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"bison":{"_anim"},
"bissau":{"_cty","_geo","_prprn"},
"bit":{"_past"},
"bitches":{"_anim","_fem"},
"bitee":{"_anim","_sb"},
"bithynia":{"_cntry","_geo","_prprn"},
"bittern":{"_anim"},
"bivalve":{"_anim"},
"bivouac":{"_loc_sr"},
"bivouacking":{"_loc_sr"},
"biwa":{"_geo","_prprn"},
"Bix":{"_prprn"},
"Bizerte":{"_cty","_geo","_prprn"},
"bizet":{"_anim","_nme","_prprn","_sb"},
"bk":{"_prprn"},
"blab":{"_loc_sr"},
"blabbed":{"_loc_sr","_past"},
"blabbermouth":{"_anim","_sb"},
"black":{"_anim","_sb"},
"black-and-orange":{"_anim","_sb"},
"black-and-yellow":{"_anim","_sb"},
"black-balled":{"_anim","_sb"},
"black-barred":{"_anim","_sb"},
"black-bearded":{"_anim","_sb"},
"black-body":{"_anim","_sb"},
"black-clad":{"_anim","_sb"},
"black-coated":{"_anim","_sb"},
"black-consumer":{"_anim","_sb"},
"black-crowned":{"_anim","_sb"},
"black-draped":{"_anim","_sb"},
"black-figured":{"_anim","_sb"},
"black-gray":{"_anim","_sb"},
"black-grey":{"_anim","_sb"},
"black-majority":{"_anim","_sb"},
"black-marked":{"_anim","_sb"},
"black-market":{"_loc_sr"},
"black-on-black":{"_anim","_sb"},
"black-owned":{"_anim","_sb"},
"black-robed":{"_anim","_sb"},
"black-seeded":{"_anim","_sb"},
"black-tipped":{"_anim","_sb"},
"black-white":{"_anim","_sb"},
"blackamoor":{"_anim","_sb"},
"blackballed":{"_past"},
"blackbeard":{"_anim","_nme","_prprn","_sb"},
"blackbird":{"_anim"},
"blackbirds":{"_anim"},
"blackbuck":{"_anim"},
"Blackburn":{"_geo","_prprn"},
"blackcap":{"_sb"},
"blacked":{"_past"},
"blacked-in":{"_past"},
"blacked-out":{"_past"},
"Blackfeet":{"_prprn"},
"blackfoot":{"_prprn"},
"blackguard":{"_anim","_sb"},
"blacklist":{"_loc_sr"},
"blacklisting":{"_loc_sr"},
"blackmailed":{"_past"},
"blackmailer":{"_anim","_sb"},
"blackmailers":{"_anim","_sb"},
"Blackmun":{"_anim","_nme","_prprn","_sb"},
"blackpoll":{"_sb"},
"Blackpool":{"_geo","_prprn"},
"blacks":{"_anim","_sb"},
"blacksburg":{"_cty","_geo","_prprn"},
"blackshirt":{"_prprn","_sb"},
"Blackstone":{"_anim","_nme","_prprn","_sb"},
"blackwash":{"_loc_sr"},
"Blackwell":{"_anim","_nme","_prprn","_sb"},
"blackwood":{"_anim","_nme","_prprn","_sb"},
"bladdernose":{"_anim"},
"blaeberry":{"_anim"},
"Blaine":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Blair":{"_anim","_nme","_prprn","_sb"},
"blake":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Blakey":{"_prprn"},
"blamed":{"_past"},
"blanc":{"_anim","_nme","_prprn","_sb"},
"Blanche":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"blanched":{"_past"},
"Blanchett":{"_prprn"},
"Blanco":{"_prprn"},
"blank-faced":{"_loc_sr"},
"blanketed":{"_past"},
"blanks":{"_loc_sr"},
"blantyre":{"_cty","_geo","_prprn"},
"blared":{"_past"},
"blasphemed":{"_past"},
"blasphemer":{"_anim","_sb"},
"blasphemers":{"_anim","_sb"},
"blasted":{"_past"},
"blatherskite":{"_sb"},
"Blaydon":{"_prprn"},
"blazed":{"_past"},
"bleached":{"_past"},
"bled":{"_past"},
"bleeder":{"_anim","_sb"},
"bleeders":{"_anim","_sb"},
"bleep":{"_loc_sr"},
"blemished":{"_past"},
"blench":{"_loc_sr"},
"blended":{"_past"},
"blender":{"_sb"},
"blenders":{"_sb"},
"Blenheim":{"_prprn"},
"bleriot":{"_anim","_nme","_prprn","_sb"},
"blessed":{"_past"},
"blest":{"_past"},
"blew":{"_loc_sr","_past","_wthr"},
"blida":{"_cty","_geo","_prprn"},
"bligh":{"_anim","_nme","_prprn","_sb"},
"blighted":{"_past"},
"blighter":{"_anim","_sb"},
"blind-sided":{"_past"},
"blinded":{"_past"},
"blindfolded":{"_past"},
"blindsided":{"_past"},
"blinked":{"_past"},
"blistered":{"_past"},
"blixen":{"_anim","_nme","_prprn","_sb"},
"bloated":{"_past"},
"bloater":{"_anim"},
"bloc":{"_anim","_sb"},
"bloch":{"_anim","_nme","_prprn","_sb"},
"block":{"_loc_sr"},
"blockade-runner":{"_anim","_sb"},
"blockhead":{"_anim","_sb"},
"blocking":{"_loc_sr"},
"blocs":{"_anim","_sb"},
"bloemfontein":{"_cty","_geo","_prprn"},
"Blois":{"_cty","_geo","_prprn"},
"blok":{"_anim","_nme","_prprn","_sb"},
"blokes":{"_anim","_masc","_sb"},
"blond":{"_anim","_sb"},
"blonde":{"_anim","_sb"},
"blondes":{"_anim","_sb"},
"blooded":{"_past"},
"bloodhound":{"_anim"},
"bloodhounds":{"_anim"},
"bloodied":{"_past"},
"bloodstock":{"_anim"},
"bloodsucker":{"_anim","_sb"},
"bloom":{"_loc_sr"},
"bloomed":{"_loc_sr","_past"},
"Bloomfield":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"blooming":{"_loc_sr"},
"Bloomington":{"_cty","_geo","_prprn"},
"blossomed":{"_loc_sr","_past"},
"blossoming":{"_loc_sr"},
"blotched":{"_past"},
"blotted":{"_past"},
"blow":{"_loc_sr","_wthr"},
"blower":{"_anim","_sb"},
"blowfly":{"_anim"},
"blowhard":{"_anim","_sb"},
"blowing":{"_loc_sr","_wthr"},
"blown":{"_loc_sr","_wthr"},
"blown-up":{"_loc_sr","_wthr"},
"blt":{"_prprn"},
"blubberer":{"_anim","_sb"},
"bludgeoned":{"_past"},
"bludgeoner":{"_anim","_sb"},
"blue-pencil":{"_loc_sr"},
"bluebeard":{"_anim","_masc","_sb"},
"bluebottle":{"_anim"},
"bluecoat":{"_anim","_sb"},
"bluefish":{"_anim","_loc_sr"},
"bluejacket":{"_anim","_sb"},
"bluenose":{"_sb"},
"Blum":{"_anim","_nme","_prprn","_sb"},
"Blumberg":{"_anim","_nme","_prprn","_sb"},
"blunder":{"_loc_sr"},
"blundered":{"_loc_sr","_past"},
"blunderer":{"_anim","_sb"},
"blunted":{"_past"},
"blurred":{"_past"},
"blurted":{"_past"},
"blushed":{"_past"},
"bluster":{"_loc_sr"},
"blustered":{"_loc_sr","_past"},
"blusterer":{"_anim","_sb"},
"blustering":{"_loc_sr"},
"Blyth":{"_geo","_prprn"},
"bm":{"_prprn"},
"bmr":{"_prprn"},
"Boadicea":{"_anim","_nme","_prprn","_sb"},
"boar":{"_anim","_masc"},
"boarded":{"_past"},
"boardroom":{"_loc_sr"},
"boardrooms":{"_loc_sr"},
"boarfish":{"_anim"},
"boarhound":{"_anim"},
"boasted":{"_past"},
"boaster":{"_anim","_sb"},
"boat":{"_fem","_loc_sr"},
"boat-building":{"_fem","_loc_sr"},
"boat-race":{"_fem","_loc_sr"},
"boat-shaped":{"_fem","_loc_sr"},
"boat-yard":{"_fem","_loc_sr"},
"boatbuilder":{"_anim","_sb"},
"boater":{"_anim","_sb"},
"boaters":{"_anim","_sb"},
"boathouse":{"_loc_sr"},
"boathouses":{"_loc_sr"},
"boats":{"_fem","_loc_sr"},
"Boaz":{"_anim","_nme","_prprn","_sb"},
"bob":{"_loc_sr"},
"bobbed":{"_loc_sr","_past"},
"bobber":{"_anim","_sb"},
"bobbing":{"_loc_sr"},
"bobby":{"_anim","_sb"},
"bobby-socker":{"_anim","_sb"},
"bobby-sox":{"_anim","_sb"},
"bobby-soxer":{"_anim","_sb"},
"bobbysoxer":{"_sb"},
"bobcat":{"_anim"},
"bobolink":{"_anim","_sb"},
"bobtail":{"_anim"},
"boccaccio":{"_anim","_nme","_prprn","_sb"},
"bod":{"_anim","_sb"},
"bode":{"_past"},
"boded":{"_past"},
"bodensee":{"_geo","_prprn"},
"bodhisattva":{"_anim","_sb"},
"Bodleian":{"_prprn"},
"bodoni":{"_anim","_nme","_prprn","_sb"},
"bods":{"_anim","_sb"},
"bodybuilders":{"_anim","_sb"},
"bodyguard":{"_anim","_sb"},
"bodyguards":{"_anim","_sb"},
"bodyworkers":{"_anim","_sb"},
"boehm":{"_prprn"},
"boehme":{"_anim","_nme","_prprn","_sb"},
"Boeings":{"_prprn"},
"boeotia":{"_geo","_prprn"},
"boer":{"_prprn"},
"boethius":{"_anim","_nme","_prprn","_sb"},
"boffin":{"_anim","_sb"},
"bog":{"_loc_sr"},
"Bogart":{"_anim","_nme","_prprn","_sb"},
"bogged":{"_past"},
"boggle":{"_loc_sr","_psych"},
"bogs":{"_loc_sr"},
"Boheme":{"_prprn"},
"Bohemia":{"_geo","_prprn","_stte"},
"bohemian":{"_anim","_sb"},
"Bohemians":{"_anim","_sb"},
"bohme":{"_anim","_nme","_prprn","_sb"},
"bohr":{"_anim","_nme","_prprn","_sb"},
"boiled":{"_past"},
"boiler":{"_loc_sr"},
"boiler-burner":{"_loc_sr"},
"boilers":{"_loc_sr"},
"Boise":{"_cty","_geo","_prprn"},
"bokmal":{"_prprn"},
"Bol":{"_prprn"},
"Boland":{"_prprn"},
"boleyn":{"_anim","_fem","_nme","_prprn","_sb"},
"Bolger":{"_anim","_nme","_prprn","_sb"},
"bolingbroke":{"_anim","_nme","_prprn","_sb"},
"Bolivar":{"_anim","_prprn","_sb"},
"bolivia":{"_cntry","_geo","_prprn"},
"Bolivian":{"_anim","_prprn","_sb"},
"bollix":{"_loc_sr"},
"Bologna":{"_cty","_geo","_prprn"},
"Bolsheviks":{"_prprn","_sb"},
"Bolshevism":{"_prprn"},
"bolted":{"_past"},
"Bolton":{"_geo","_prprn"},
"boltzmann":{"_anim","_nme","_prprn","_sb"},
"bolzano":{"_cty","_geo","_prprn"},
"bomb":{"_loc_sr"},
"bomb-detection":{"_loc_sr"},
"bomb-plant":{"_loc_sr"},
"bomb-proof":{"_loc_sr"},
"bombarded":{"_past"},
"bombardier":{"_anim","_sb"},
"Bombay":{"_cty","_geo","_prprn"},
"bombs":{"_loc_sr"},
"Bon":{"_prprn"},
"bonaire":{"_geo","_prprn"},
"Bonaparte":{"_anim","_nme","_prprn","_sb"},
"Bonaventure":{"_anim","_nme","_prprn","_sb"},
"bondholder":{"_anim","_sb"},
"bondholders":{"_anim","_sb"},
"Bondi":{"_prprn"},
"bonding":{"_loc_sr"},
"bondmaid":{"_anim","_fem","_sb"},
"bondman":{"_anim","_masc","_sb"},
"bondwoman":{"_anim","_fem","_sb"},
"boned":{"_past"},
"bonefish":{"_anim","_loc_sr"},
"bonehead":{"_anim","_sb"},
"bonesetter":{"_anim","_sb"},
"bongo":{"_anim"},
"bonheur":{"_anim","_nme","_prprn","_sb"},
"Bonhoeffer":{"_prprn"},
"Boniface":{"_anim","_prprn","_sb"},
"bonito":{"_anim"},
"Bonn":{"_cty","_geo","_prprn"},
"bontemps":{"_anim","_nme","_prprn","_sb"},
"booboisie":{"_anim","_sb"},
"bookbinder":{"_anim","_sb"},
"booked":{"_past"},
"bookers":{"_anim","_sb"},
"bookkeeper":{"_anim","_sb"},
"booklouse":{"_anim"},
"bookmaker":{"_anim","_sb"},
"booksellers":{"_anim","_sb"},
"bookworm":{"_anim","_sb"},
"Boole":{"_anim","_nme","_prprn","_sb"},
"boomed":{"_past"},
"boomer":{"_anim","_sb"},
"boomerang":{"_loc_sr"},
"boomers":{"_anim","_sb"},
"boondoggle":{"_loc_sr"},
"boondoggler":{"_anim","_sb"},
"boone":{"_anim","_nme","_prprn","_sb"},
"boor":{"_anim","_sb"},
"boors":{"_anim","_sb"},
"boosted":{"_past"},
"booster":{"_anim","_sb"},
"boosters":{"_anim","_sb"},
"boot":{"_loc_sr"},
"bootblack":{"_anim","_sb"},
"booted":{"_loc_sr","_past"},
"booting":{"_loc_sr"},
"Bootle":{"_geo","_prprn"},
"bootleggers":{"_anim","_sb"},
"bootlicker":{"_anim","_sb"},
"boots":{"_anim","_masc","_sb"},
"boozed-out":{"_past"},
"boozer":{"_anim","_sb"},
"Bordeaux":{"_cty","_geo","_loc_sr","_prprn"},
"Borden":{"_anim","_nme","_prprn","_sb"},
"bordered":{"_loc_sr","_past"},
"borderer":{"_anim","_sb"},
"borderland":{"_loc_sr"},
"borderlands":{"_loc_sr"},
"bore":{"_loc_sr","_past","_psych"},
"bored":{"_past","_psych"},
"borers":{"_sb"},
"Borg":{"_anim","_nme","_prprn","_sb"},
"Borges":{"_anim","_nme","_prprn","_sb"},
"Borghese":{"_prprn"},
"Borglum":{"_anim","_nme","_prprn","_sb"},
"boring":{"_psych"},
"Boris":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Borneo":{"_geo","_prprn"},
"Bornholm":{"_geo","_prprn"},
"borodin":{"_anim","_nme","_prprn","_sb"},
"borodino":{"_geo","_prprn"},
"Borromini":{"_anim","_nme","_prprn","_sb"},
"borrow":{"_loc_sr"},
"borrowed":{"_loc_sr","_past"},
"borrower":{"_anim","_sb"},
"borrowers":{"_anim","_sb"},
"borrowing":{"_loc_sr"},
"borrows":{"_loc_sr"},
"borzoi":{"_anim"},
"bos'n":{"_anim","_sb"},
"bosc":{"_prprn"},
"bosch":{"_anim","_nme","_prprn","_sb"},
"bosk":{"_loc_sr"},
"bosnia":{"_cntry","_geo","_prprn"},
"bosnia-herzegovina":{"_cntry","_geo","_prprn"},
"Bosphorus":{"_prprn"},
"bosporus":{"_geo","_prprn"},
"boss":{"_anim","_sb"},
"bosses":{"_anim","_sb"},
"bossy":{"_anim"},
"boston":{"_cty","_geo","_prprn"},
"bosun":{"_anim","_sb"},
"Boswell":{"_anim","_nme","_prprn","_sb"},
"bot":{"_anim"},
"botanist":{"_anim","_sb"},
"botanists":{"_anim","_sb"},
"botch":{"_loc_sr"},
"botched":{"_loc_sr","_past"},
"botcher":{"_anim","_sb"},
"both":{"_quant"},
"Botha":{"_anim","_nme","_prprn","_sb"},
"bothered":{"_past","_psych"},
"bothering":{"_psych"},
"botswana":{"_cntry","_geo","_prprn"},
"botticelli":{"_anim","_nme","_prprn","_sb"},
"bottle":{"_loc_sr"},
"bottle-grass":{"_loc_sr"},
"bottle-green":{"_loc_sr"},
"bottle-shaped":{"_loc_sr"},
"bottle-tree":{"_loc_sr"},
"bottled":{"_loc_sr","_past"},
"bottleneck":{"_loc_sr"},
"bottlenecks":{"_loc_sr"},
"bottler":{"_anim","_sb"},
"bottlers":{"_anim","_sb"},
"bottles":{"_loc_sr"},
"bottling":{"_loc_sr"},
"Boucher":{"_anim","_nme","_prprn","_sb"},
"boudoir":{"_loc_sr"},
"bougainville":{"_anim","_geo","_nme","_prprn","_sb"},
"bought":{"_past"},
"boulevardier":{"_anim","_masc","_sb"},
"boulez":{"_anim","_nme","_prprn","_sb"},
"bounce":{"_loc_sr"},
"bounced":{"_loc_sr","_past"},
"bouncer":{"_anim","_sb"},
"bouncing":{"_loc_sr"},
"bound":{"_past"},
"bounded":{"_past"},
"bounder":{"_anim","_sb"},
"bourgeois":{"_anim","_sb"},
"bourgeois-bashing":{"_anim","_sb"},
"bourgogne":{"_geo","_prprn","_stte"},
"Bourguiba":{"_prprn"},
"Boursin":{"_prprn"},
"bovid":{"_anim","_sb"},
"bovine":{"_anim"},
"bovines":{"_anim"},
"bovril":{"_prprn"},
"bowditch":{"_anim","_nme","_prprn","_sb"},
"bowdleriser":{"_anim","_sb"},
"bowdlerize":{"_loc_sr"},
"bowdlerizer":{"_anim","_sb"},
"bowed":{"_past"},
"Bowen":{"_anim","_nme","_prprn","_sb"},
"bower":{"_loc_sr"},
"bowerbird":{"_anim"},
"bowhead":{"_anim"},
"Bowie":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"bowl":{"_loc_sr"},
"bowled":{"_loc_sr","_past"},
"bowler":{"_anim","_sb"},
"Bowles":{"_anim","_nme","_prprn","_sb"},
"bowling":{"_loc_sr"},
"bowls":{"_loc_sr"},
"bowman":{"_anim","_sb"},
"box":{"_loc_sr"},
"box-shaped":{"_loc_sr"},
"box-sized":{"_loc_sr"},
"boxed":{"_loc_sr","_past"},
"boxer":{"_anim","_sb"},
"boxes":{"_loc_sr"},
"boxing":{"_loc_sr"},
"boy":{"_anim","_masc","_sb"},
"boy-furiendo":{"_anim","_masc","_sb"},
"boy-manager":{"_anim","_masc","_sb"},
"boy-meets-girl":{"_anim","_masc","_sb"},
"boy-name":{"_anim","_masc","_sb"},
"boyars":{"_sb"},
"Boyce":{"_prprn"},
"boycott":{"_loc_sr"},
"boycotted":{"_loc_sr","_past"},
"boycotting":{"_loc_sr"},
"Boyd":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Boyer":{"_anim","_sb"},
"boyfriend":{"_anim","_masc","_sb"},
"boyfriends":{"_anim","_masc","_sb"},
"boyhood":{"_sb","_tme"},
"Boyle":{"_anim","_nme","_prprn","_sb"},
"boyne":{"_geo","_prprn"},
"boys":{"_anim","_masc","_sb"},
"boys-and-girls":{"_anim","_masc","_sb"},
"bozeman":{"_cty","_geo","_prprn"},
"braced":{"_past"},
"brachiate":{"_loc_sr"},
"brachyuran":{"_sb"},
"Bracknell":{"_cty","_geo","_prprn"},
"bradbury":{"_anim","_nme","_prprn","_sb"},
"Braddock":{"_anim","_nme","_prprn","_sb"},
"Bradford":{"_anim","_geo","_nme","_prprn","_sb"},
"Bradley":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Bradshaw":{"_prprn"},
"bradstreet":{"_anim","_nme","_prprn","_sb"},
"Brady":{"_anim","_nme","_prprn","_sb"},
"braga":{"_cty","_geo","_prprn"},
"bragg":{"_anim","_nme","_prprn","_sb"},
"bragger":{"_anim","_sb"},
"bragging":{"_loc_sr"},
"brahe":{"_anim","_nme","_prprn","_sb"},
"brahman":{"_anim","_prprn","_sb"},
"brahmanism":{"_prprn"},
"brahmaputra":{"_geo","_prprn"},
"brahmin":{"_anim","_prprn","_sb"},
"brahminism":{"_prprn"},
"brahms":{"_anim","_nme","_prprn","_sb"},
"braided":{"_loc_sr","_past"},
"braiding":{"_loc_sr"},
"Braille":{"_prprn"},
"brain-damaged":{"_loc_sr"},
"brain-fag":{"_loc_sr"},
"brain-stem":{"_loc_sr"},
"brain-teaser":{"_loc_sr"},
"brain-wave":{"_loc_sr"},
"brain-worker":{"_loc_sr"},
"brain-wracking":{"_loc_sr"},
"brains":{"_loc_sr"},
"brainwashed":{"_past"},
"brainworker":{"_anim","_sb"},
"braise":{"_loc_sr"},
"braised":{"_loc_sr","_past"},
"braising":{"_loc_sr"},
"brakeman":{"_anim","_sb"},
"bramante":{"_anim","_nme","_prprn","_sb"},
"Branagh":{"_prprn"},
"branched":{"_loc_sr","_past"},
"branching":{"_loc_sr"},
"brancusi":{"_anim","_nme","_prprn","_sb"},
"branded":{"_past"},
"Brandeis":{"_anim","_nme","_prprn","_sb"},
"brandished":{"_past"},
"Brando":{"_anim","_nme","_prprn","_sb"},
"Brandon":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"Brandt":{"_anim","_nme","_prprn","_sb"},
"Brandywine":{"_geo","_prprn"},
"Branson":{"_prprn"},
"Brantford":{"_cty","_geo","_prprn"},
"braque":{"_anim","_nme","_prprn","_sb"},
"brasilia":{"_cty","_geo","_prprn"},
"brasov":{"_cty","_geo","_prprn"},
"brat":{"_anim","_sb"},
"Bratislava":{"_cty","_geo","_prprn"},
"brats":{"_anim","_sb"},
"brattleboro":{"_cty","_geo","_prprn"},
"braun":{"_anim","_nme","_prprn","_sb"},
"braved":{"_past"},
"brawler":{"_anim","_sb"},
"brawling":{"_loc_sr"},
"brazier":{"_anim","_loc_sr","_sb"},
"Brazil":{"_cntry","_geo","_prprn"},
"Brazilian":{"_anim","_prprn","_sb"},
"brazos":{"_geo","_prprn"},
"brazzaville":{"_cty","_geo","_prprn"},
"breached":{"_past"},
"breadbasket":{"_loc_sr"},
"breaded":{"_past"},
"breadline":{"_anim","_sb"},
"breadwinner":{"_anim","_sb"},
"breakfast":{"_tme"},
"breakfast-table":{"_tme"},
"breakfasted":{"_past"},
"breakfasts":{"_tme"},
"bream":{"_anim"},
"breast-fed":{"_past"},
"breasted":{"_past"},
"breaststroker":{"_anim","_sb"},
"breathe":{"_loc_sr"},
"breathing":{"_loc_sr"},
"brecht":{"_anim","_nme","_prprn","_sb"},
"bred":{"_past"},
"Breda":{"_cty","_geo","_prprn"},
"breeched":{"_past"},
"breeder":{"_anim","_sb"},
"breeders":{"_anim","_sb"},
"breeds":{"_anim"},
"bremen":{"_cty","_geo","_prprn","_stte"},
"bremerhaven":{"_cty","_geo","_prprn"},
"bren":{"_anim","_fem","_fnme","_masc","_nme","_prprn","_sb"},
"Brenda":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Brendel":{"_prprn"},
"Brennan":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Brent":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Brentwood":{"_geo","_prprn"},
"brescia":{"_cty","_geo","_prprn"},
"breslau":{"_geo","_prprn"},
"Brest":{"_cty","_geo","_prprn"},
"bretagne":{"_geo","_prprn","_stte"},
"brethren":{"_anim","_masc","_sb"},
"breton":{"_anim","_nme","_prprn","_sb"},
"breuer":{"_anim","_nme","_prprn","_sb"},
"breughel":{"_anim","_nme","_prprn","_sb"},
"brew":{"_loc_sr"},
"brewed":{"_loc_sr","_past"},
"brewer":{"_anim","_sb"},
"breweries":{"_loc_sr"},
"brewers":{"_anim","_sb"},
"brewery-scion-turned-banker":{"_loc_sr"},
"brewing":{"_loc_sr"},
"brewing-assets":{"_loc_sr"},
"Brewster":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Breyer":{"_prprn"},
"brezhnev":{"_anim","_nme","_prprn","_sb"},
"Brian":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"briard":{"_anim"},
"bribed":{"_past"},
"Brice":{"_anim","_nme","_prprn","_sb"},
"brickfield":{"_loc_sr"},
"bricklayer":{"_anim","_sb"},
"bricklayers":{"_anim","_sb"},
"brickyard":{"_loc_sr"},
"bride":{"_anim","_fem","_sb"},
"bride-to-be":{"_anim","_fem","_sb"},
"brides":{"_anim","_fem","_sb"},
"bridesmaid":{"_anim","_fem","_sb"},
"bridesmaids":{"_anim","_fem","_sb"},
"bridged-T":{"_past"},
"Bridgeport":{"_cty","_geo","_prprn"},
"Bridget":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Bridgetown":{"_cty","_geo","_prprn"},
"bridle":{"_loc_sr"},
"bridled":{"_loc_sr","_past"},
"briefed":{"_past"},
"briefly":{"_tme"},
"briefly-illumed":{"_tme"},
"brigade":{"_anim","_sb"},
"brigades":{"_anim","_sb"},
"brigand":{"_anim","_sb"},
"brigands":{"_anim","_sb"},
"Briggs":{"_anim","_nme","_prprn","_sb"},
"brightened":{"_past"},
"brightener":{"_anim","_sb"},
"Brighton":{"_geo","_prprn"},
"brill":{"_anim","_loc_sr"},
"Brillo":{"_prprn"},
"brimmed":{"_past"},
"brindisi":{"_cty","_geo","_prprn"},
"brine":{"_loc_sr"},
"brine-cured":{"_loc_sr"},
"brinton":{"_anim","_nme","_prprn","_sb"},
"brisbane":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"bristle":{"_loc_sr"},
"bristled":{"_loc_sr","_past"},
"bristling":{"_loc_sr"},
"Bristol":{"_cty","_geo","_prprn"},
"brit":{"_anim"},
"Britain":{"_cntry","_geo","_prprn"},
"Britannia":{"_anim","_fem","_prprn","_sb"},
"briticism":{"_prprn"},
"British":{"_anim","_prprn","_sb"},
"Britisher":{"_anim","_prprn","_sb"},
"britishism":{"_prprn"},
"briton":{"_anim","_prprn","_sb"},
"Britons":{"_anim","_prprn","_sb"},
"brits":{"_anim"},
"Brittany":{"_anim","_fem","_fnme","_geo","_nme","_prprn","_sb","_stte"},
"Britten":{"_anim","_nme","_prprn","_sb"},
"brno":{"_cty","_geo","_prprn"},
"broached":{"_past"},
"broad":{"_anim","_fem","_sb"},
"broad-appeal":{"_anim","_fem","_sb"},
"broad-based":{"_anim","_fem","_sb"},
"broad-bean":{"_anim","_fem","_sb"},
"broad-headed":{"_anim","_fem","_sb"},
"broad-nibbed":{"_anim","_fem","_sb"},
"broad-scale":{"_anim","_fem","_sb"},
"broad-scaled":{"_anim","_fem","_sb"},
"broad-shouldered":{"_anim","_fem","_sb"},
"broadcast":{"_past"},
"broadcaster":{"_anim","_sb"},
"broadcasters":{"_anim","_sb"},
"broadened":{"_past"},
"Broadway":{"_prprn"},
"brocaded":{"_past"},
"brocket":{"_anim"},
"Brodsky":{"_anim","_nme","_prprn","_sb"},
"broglie":{"_anim","_nme","_prprn","_sb"},
"broiled":{"_past"},
"broke":{"_past"},
"broker":{"_anim","_sb"},
"broker-dealer":{"_anim","_sb"},
"broker-dealers":{"_anim","_sb"},
"broker-sold":{"_anim","_sb"},
"brokered":{"_past"},
"brokers":{"_anim","_sb"},
"Bromley":{"_prprn"},
"bronco":{"_anim"},
"broncobuster":{"_anim","_sb"},
"Bronislaw":{"_prprn"},
"bronte":{"_anim","_nme","_prprn","_sb"},
"brontosaurus":{"_anim"},
"bronx":{"_geo","_prprn"},
"bronzed":{"_past"},
"brood":{"_anim"},
"brooded":{"_loc_sr","_past"},
"brooding":{"_loc_sr"},
"broods":{"_anim"},
"Brooke":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"brooked":{"_past"},
"Brookline":{"_cty","_geo","_prprn"},
"Brooklyn":{"_geo","_prprn"},
"Bros":{"_prprn"},
"broth":{"_loc_sr"},
"brother":{"_anim","_masc","_sb"},
"brothers":{"_anim","_masc","_sb"},
"brought":{"_past"},
"browbeat":{"_past"},
"brown":{"_loc_sr"},
"brown-coal":{"_loc_sr"},
"brown-edged":{"_loc_sr"},
"brown-gray":{"_loc_sr"},
"brown-green":{"_loc_sr"},
"brown-grey":{"_loc_sr"},
"brown-paper":{"_loc_sr"},
"brown-purple":{"_loc_sr"},
"brown-speckled":{"_loc_sr"},
"brown-striped":{"_loc_sr"},
"brown-tobacco":{"_loc_sr"},
"browne":{"_anim","_nme","_prprn","_sb"},
"browned":{"_past"},
"browns":{"_loc_sr"},
"Brownsville":{"_cty","_geo","_prprn"},
"browsing":{"_loc_sr"},
"Bruce":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"brucella":{"_anim"},
"Bruch":{"_anim","_nme","_prprn","_sb"},
"bruckner":{"_anim","_nme","_prprn","_sb"},
"Bruegel":{"_prprn"},
"brueghel":{"_anim","_nme","_prprn","_sb"},
"bruges":{"_cty","_geo","_prprn"},
"bruin":{"_anim"},
"bruised":{"_past"},
"bruiser":{"_anim","_sb"},
"bruises":{"_loc_sr"},
"bruited":{"_past"},
"brule":{"_anim","_prprn","_sb"},
"brummell":{"_anim","_nme","_prprn","_sb"},
"brunch":{"_tme"},
"brunches":{"_tme"},
"brunei":{"_cntry","_geo","_prprn"},
"bruneian":{"_anim","_prprn","_sb"},
"brunelleschi":{"_anim","_nme","_prprn","_sb"},
"brunet":{"_anim","_sb"},
"brunette":{"_anim","_sb"},
"brunettes":{"_anim","_sb"},
"brunhild":{"_prprn"},
"bruno":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"brunswick":{"_cty","_geo","_prprn"},
"brushed":{"_past"},
"brussels":{"_anim"},
"brutalized":{"_past"},
"brute":{"_anim","_sb"},
"brutes":{"_anim","_sb"},
"Bruton":{"_prprn"},
"brutus":{"_anim","_nme","_prprn","_sb"},
"Bruxelles":{"_prprn"},
"bryan":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"Bryant":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Bryce":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"brynhild":{"_prprn"},
"brythonic":{"_prprn"},
"bs":{"_prprn"},
"btu":{"_prprn"},
"Bubba":{"_prprn"},
"bubbled":{"_past"},
"Buber":{"_anim","_nme","_prprn","_sb"},
"Bucaramanga":{"_cty","_geo","_prprn"},
"buccaneers":{"_anim","_sb"},
"Buchanan":{"_anim","_nme","_prprn","_sb"},
"Bucharest":{"_cty","_geo","_prprn"},
"Buchenwald":{"_geo","_prprn"},
"Buchner":{"_anim","_nme","_prprn","_sb"},
"buck-and-wing":{"_anim"},
"buck-toothed":{"_anim"},
"bucked":{"_past"},
"bucket":{"_loc_sr"},
"bucket-shop":{"_loc_sr"},
"buckets":{"_loc_sr"},
"Buckingham":{"_anim","_nme","_prprn","_sb"},
"buckled":{"_past"},
"Bud":{"_anim","_fnme","_loc_sr","_masc","_nme","_prprn","_sb"},
"Budapest":{"_cty","_geo","_prprn"},
"budded":{"_past"},
"Buddha":{"_anim","_nme","_prprn","_sb"},
"Buddhism":{"_prprn"},
"Buddhist":{"_prprn"},
"Buddhists":{"_prprn"},
"buddies":{"_anim","_sb"},
"budge":{"_loc_sr"},
"budged":{"_loc_sr","_past"},
"budgerigar":{"_anim"},
"budgeted":{"_past"},
"buds":{"_anim","_loc_sr"},
"Budweisers":{"_prprn"},
"buffalo":{"_anim"},
"buffaloes":{"_anim"},
"buffeted":{"_past"},
"Buffett":{"_prprn"},
"bufflehead":{"_anim"},
"buffoons":{"_anim","_sb"},
"bug":{"_psych"},
"bug-free":{"_anim"},
"bug-hunter":{"_anim"},
"buganda":{"_cntry","_geo","_prprn"},
"Bugatti":{"_prprn"},
"bugged":{"_past","_psych"},
"buggers":{"_anim","_sb"},
"bugging":{"_psych"},
"bugs":{"_anim"},
"Buick":{"_prprn"},
"builder":{"_anim","_sb"},
"builder-dealer":{"_anim","_sb"},
"builders":{"_anim","_sb"},
"buildup":{"_loc_sr"},
"built":{"_past"},
"built-detergent":{"_past"},
"built-from-kit":{"_past"},
"built-soap":{"_past"},
"bujumbura":{"_cty","_geo","_prprn"},
"bukharin":{"_anim","_nme","_prprn","_sb"},
"bulawayo":{"_cty","_geo","_prprn"},
"bulbul":{"_anim"},
"Bulgaria":{"_cntry","_geo","_prprn"},
"Bulgarian":{"_anim","_prprn","_sb"},
"bulged":{"_past"},
"bulked":{"_past"},
"bulked-up":{"_past"},
"bull":{"_anim"},
"bull-headed":{"_anim"},
"bull-like":{"_anim"},
"bull-market":{"_anim"},
"bull-necked":{"_anim"},
"bull-roaring":{"_anim"},
"bull-sessions":{"_anim"},
"bull-snake":{"_anim"},
"bulldog":{"_anim"},
"bulldoze":{"_loc_sr"},
"bulldozed":{"_loc_sr","_past"},
"bullfinch":{"_anim"},
"bullfrog":{"_anim"},
"bullied":{"_loc_sr","_past"},
"bullies":{"_anim","_sb"},
"bullring":{"_loc_sr"},
"bulls":{"_anim"},
"bully":{"_anim","_sb"},
"bullyboy":{"_anim","_masc","_sb"},
"bullyboys":{"_anim","_masc","_sb"},
"bullying":{"_loc_sr"},
"Bultmann":{"_prprn"},
"bulwer-lytton":{"_anim","_nme","_prprn","_sb"},
"bumblebee":{"_anim"},
"bumblebees":{"_anim"},
"bumbler":{"_anim","_sb"},
"Bumbry":{"_prprn"},
"bummed":{"_past"},
"bumped":{"_past"},
"bumpkin":{"_anim","_sb"},
"bums":{"_anim","_sb"},
"bunche":{"_anim","_nme","_prprn","_sb"},
"bunched":{"_loc_sr","_past"},
"bunches":{"_loc_sr"},
"bunching":{"_loc_sr"},
"Bundesbank":{"_prprn"},
"bundle":{"_loc_sr","_sb"},
"bundled":{"_loc_sr","_past","_sb"},
"bundled-up":{"_loc_sr","_past","_sb"},
"bundling":{"_loc_sr","_sb"},
"bungled":{"_past"},
"bunk":{"_loc_sr"},
"bunked":{"_loc_sr","_past"},
"bunker":{"_loc_sr"},
"bunkered":{"_loc_sr","_past"},
"bunkers":{"_loc_sr"},
"bunkmates":{"_anim","_sb"},
"bunnies":{"_anim"},
"bunny":{"_anim"},
"bunsen":{"_anim","_nme","_prprn","_sb"},
"bunters":{"_anim","_sb"},
"bunuel":{"_anim","_nme","_prprn","_sb"},
"bunyan":{"_anim","_nme","_prprn","_sb"},
"buoyed":{"_past"},
"burbage":{"_anim","_nme","_prprn","_sb"},
"Burbank":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"burberry":{"_prprn"},
"Burckhardt":{"_anim","_nme","_prprn","_sb"},
"burdened":{"_past"},
"bureaucracies":{"_anim","_sb"},
"bureaucracy":{"_anim","_sb"},
"bureaucrat":{"_anim","_sb"},
"bureaucraticized":{"_past"},
"bureaucrats":{"_anim","_sb"},
"burgeoned":{"_past"},
"burgess":{"_anim","_sb"},
"burgher":{"_anim","_sb"},
"Burghley":{"_anim","_nme","_prprn","_sb"},
"burglaries":{"_loc_sr"},
"burglarized":{"_past"},
"burglars":{"_anim","_sb"},
"burglary":{"_loc_sr"},
"burgle":{"_loc_sr"},
"burgoyne":{"_anim","_nme","_prprn","_sb"},
"Burgundian":{"_anim","_sb"},
"Burgundies":{"_prprn"},
"Burgundy":{"_anim","_geo","_prprn","_sb","_stte"},
"buried":{"_loc_sr","_past"},
"burk":{"_anim","_nme","_prprn","_sb"},
"Burke":{"_anim","_fnme","_nme","_prprn","_sb"},
"burked":{"_past"},
"Burkina":{"_prprn"},
"burled":{"_past"},
"Burlington":{"_cty","_geo","_prprn"},
"Burma":{"_cntry","_geo","_prprn"},
"Burman":{"_anim","_prprn","_sb"},
"Burmese":{"_anim","_prprn","_sb"},
"burmese-yi":{"_anim","_prprn","_sb"},
"burned-over":{"_past"},
"burners":{"_sb"},
"Burnet":{"_anim","_prprn","_sb"},
"burnett":{"_anim","_nme","_prprn","_sb"},
"burnham":{"_anim","_nme","_prprn","_sb"},
"burnished":{"_past"},
"Burnside":{"_anim","_nme","_prprn","_sb"},
"burnt":{"_past"},
"burnt-orange":{"_past"},
"burnt-red":{"_past"},
"Burr":{"_anim","_prprn","_sb"},
"burred":{"_past"},
"burro":{"_anim"},
"Burroughs":{"_anim","_nme","_prprn","_sb"},
"burrowed":{"_past"},
"bursar":{"_anim","_sb"},
"burst":{"_past"},
"burt":{"_anim","_nme","_prprn","_sb"},
"Burundi":{"_cntry","_geo","_prprn"},
"burundian":{"_anim","_prprn","_sb"},
"bury":{"_loc_sr"},
"burying":{"_loc_sr"},
"Bush":{"_anim","_prprn","_sb"},
"bushbaby":{"_anim"},
"bushbuck":{"_anim"},
"bushed":{"_past"},
"bushnell":{"_anim","_nme","_prprn","_sb"},
"bushwhacked":{"_loc_sr","_past"},
"bushwhacker":{"_anim","_sb"},
"bushwhacking":{"_loc_sr"},
"businessman":{"_anim","_masc","_sb"},
"businessmen":{"_anim","_masc","_sb"},
"businessmen-authors":{"_anim","_masc","_sb"},
"businesspeople":{"_anim","_sb"},
"businessperson":{"_anim","_sb"},
"businesswoman":{"_anim","_fem","_sb"},
"busk":{"_loc_sr"},
"busker":{"_anim","_sb"},
"busman":{"_anim","_sb"},
"bustard":{"_anim"},
"busted":{"_past"},
"busters":{"_anim","_sb"},
"bustle":{"_loc_sr"},
"busybodies":{"_anim","_sb"},
"busybody":{"_anim","_sb"},
"butazolidin":{"_prprn"},
"butch":{"_anim","_fem","_sb"},
"butchered":{"_past"},
"butchers":{"_anim","_sb"},
"butler":{"_anim","_masc","_sb"},
"butlers":{"_anim","_masc","_sb"},
"butte":{"_loc_sr"},
"butted":{"_past"},
"butter":{"_loc_sr"},
"butter-flower":{"_loc_sr"},
"butter-print":{"_loc_sr"},
"butterball":{"_anim","_sb"},
"Butterfield":{"_prprn"},
"butterfingers":{"_anim","_sb"},
"butterfish":{"_anim"},
"butterflies":{"_anim"},
"butterfly":{"_anim"},
"butterfly-shaped":{"_anim"},
"Butterworth":{"_prprn"},
"buttery":{"_loc_sr"},
"buttinsky":{"_anim","_sb"},
"buttoned":{"_past"},
"buttoned-up":{"_past"},
"buttressed":{"_past"},
"butts":{"_anim","_sb"},
"Buxtehude":{"_anim","_nme","_prprn","_sb"},
"Buxton":{"_prprn"},
"buyer":{"_anim","_sb"},
"buyers":{"_anim","_sb"},
"buzzard":{"_anim"},
"buzzed":{"_past"},
"bw":{"_prprn"},
"by":{"_loc"},
"by-bid":{"_loc"},
"by-catch":{"_loc"},
"by-laws":{"_loc"},
"by-passes":{"_loc"},
"by-passing":{"_loc"},
"by-roads":{"_loc"},
"by-ways":{"_loc"},
"by-wheelchair":{"_loc"},
"byblos":{"_cty","_geo","_prprn"},
"bydgoszcz":{"_cty","_geo","_prprn"},
"Byelorussia":{"_cntry","_geo","_prprn"},
"Byrd":{"_anim","_nme","_prprn","_sb"},
"byre":{"_loc_sr"},
"byron":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"bystander":{"_anim","_sb"},
"bystanders":{"_anim","_sb"},
"Byzantine":{"_anim","_prprn","_sb"},
"Byzantium":{"_cty","_geo","_prprn"},
"c-horizon":{"_prprn"},
"c-section":{"_prprn"},
"Ca":{"_prprn"},
"cabal":{"_anim","_sb"},
"cabby":{"_anim","_sb"},
"cabell":{"_anim","_nme","_prprn","_sb"},
"cabg":{"_prprn"},
"cabin-crew":{"_loc_sr"},
"cabins":{"_loc_sr"},
"cabled":{"_loc_sr","_past"},
"cabman":{"_anim","_masc","_sb"},
"cabot":{"_anim","_nme","_prprn","_sb"},
"Cabrini":{"_anim","_nme","_prprn","_sb"},
"cabstand":{"_loc_sr"},
"cache":{"_loc_sr"},
"cad":{"_anim","_sb"},
"cadaver":{"_anim","_sb"},
"Cadbury":{"_prprn"},
"caddoan":{"_prprn"},
"Cade":{"_anim","_prprn","_sb"},
"cadets":{"_anim","_sb"},
"Cadillacs":{"_anim","_nme","_prprn","_sb"},
"cadiz":{"_cty","_geo","_prprn"},
"cadmus":{"_anim","_nme","_prprn","_sb"},
"cadres":{"_anim","_sb"},
"Cadwalader":{"_prprn"},
"caelum":{"_prprn"},
"Caesar":{"_anim","_prprn","_sb"},
"caesarea":{"_geo","_prprn"},
"caesarism":{"_prprn"},
"cage":{"_loc_sr"},
"caged":{"_loc_sr","_past"},
"cager":{"_anim","_sb"},
"cages":{"_loc_sr"},
"Cagliari":{"_cty","_geo","_prprn"},
"cagliostro":{"_anim","_nme","_prprn","_sb"},
"cagney":{"_anim","_nme","_prprn","_sb"},
"caiman":{"_anim"},
"Cain":{"_anim","_nme","_prprn","_sb"},
"Caine":{"_prprn"},
"Cairns":{"_cty","_prprn"},
"cairo":{"_cty","_geo","_prprn"},
"Caius":{"_anim","_nme","_prprn","_sb"},
"Cajun":{"_anim","_prprn","_sb"},
"caked":{"_past"},
"Calabria":{"_geo","_prprn","_stte"},
"Calais":{"_cty","_geo","_prprn"},
"calcified":{"_past"},
"calculated":{"_past"},
"calculator":{"_anim","_sb"},
"calculator-toting":{"_anim","_sb"},
"calculators":{"_anim","_sb"},
"Calcutta":{"_cty","_geo","_prprn"},
"Calder":{"_anim","_nme","_prprn","_sb"},
"caldron":{"_loc_sr"},
"Caldwell":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Caleb":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"calender":{"_loc_sr"},
"calendered":{"_loc_sr","_past"},
"calf":{"_anim"},
"Calgary":{"_cty","_geo","_prprn"},
"Calgon":{"_prprn"},
"Calhoun":{"_anim","_nme","_prprn","_sb"},
"Cali":{"_cty","_geo","_prprn"},
"calibrated":{"_past"},
"Calif":{"_prprn","_stte"},
"Calif.":{"_prprn","_stte"},
"California":{"_geo","_prprn","_stte"},
"caligula":{"_anim","_nme","_prprn","_sb"},
"caliph":{"_anim","_masc","_sb"},
"caliphs":{"_anim","_masc","_sb"},
"call":{"_loc_sr"},
"Callas":{"_anim","_prprn","_sb"},
"called":{"_loc_sr","_past"},
"caller":{"_anim","_sb"},
"caller-out":{"_anim","_sb"},
"caller-up":{"_anim","_sb"},
"callers":{"_anim","_sb"},
"calligrapher":{"_anim","_sb"},
"calligraphers":{"_anim","_sb"},
"callin":{"_loc_sr"},
"callisto":{"_prprn"},
"calluses":{"_loc_sr"},
"calm":{"_psych"},
"calmed":{"_past","_psych"},
"calming":{"_psych"},
"caloocan":{"_cty","_geo","_prprn"},
"calpe":{"_geo","_prprn"},
"Caltech":{"_prprn"},
"calumniated":{"_past"},
"Calvary":{"_geo","_loc_sr","_prprn"},
"Calvert":{"_anim","_nme","_prprn","_sb"},
"calves":{"_anim"},
"Calvinist":{"_prprn"},
"calvino":{"_anim","_nme","_prprn","_sb"},
"calyx":{"_anim"},
"cambodia":{"_cntry","_geo","_prprn"},
"Cambodian":{"_anim","_prprn","_sb"},
"Cambodians":{"_anim","_prprn","_sb"},
"cambria":{"_geo","_prprn"},
"Cambrian":{"_prprn"},
"Cambridge":{"_cty","_geo","_prprn"},
"camden":{"_cty","_geo","_prprn"},
"came":{"_loc_sr","_past"},
"camel":{"_anim"},
"camelot":{"_prprn"},
"camels":{"_anim"},
"cameraman":{"_anim","_masc","_sb"},
"cameramen":{"_anim","_masc","_sb"},
"cameroon":{"_cntry","_geo","_prprn"},
"cameroonian":{"_anim","_prprn","_sb"},
"cameroun":{"_cntry","_geo","_prprn"},
"Camille":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"camlan":{"_prprn"},
"camouflaged":{"_past"},
"camp":{"_anim","_loc_sr"},
"campaigned":{"_loc_sr","_past"},
"campaigner":{"_anim","_sb"},
"campaigners":{"_anim","_sb"},
"campaigning":{"_loc_sr"},
"Campania":{"_geo","_prprn","_stte"},
"campbell":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"camped":{"_loc_sr","_past"},
"campers":{"_anim","_sb"},
"campgrounds":{"_loc_sr"},
"camphorated":{"_past"},
"camping":{"_loc_sr"},
"camping-out":{"_loc_sr"},
"Campion":{"_anim","_prprn","_sb"},
"Campobello":{"_prprn"},
"Campos":{"_cty","_geo","_prprn"},
"camps":{"_anim","_loc_sr"},
"campsite":{"_loc_sr"},
"campsites":{"_loc_sr"},
"camus":{"_anim","_nme","_prprn","_sb"},
"canaan":{"_geo","_prprn"},
"canada":{"_cntry","_geo","_prprn"},
"Canadian":{"_anim","_prprn","_sb"},
"Canadians":{"_anim","_prprn","_sb"},
"canalize":{"_loc_sr"},
"canaries":{"_anim"},
"canary-colored":{"_anim"},
"Canaveral":{"_prprn"},
"canberra":{"_cty","_geo","_prprn"},
"canceled":{"_past"},
"cancelled":{"_past"},
"cancun":{"_geo","_prprn"},
"candidate":{"_anim","_sb"},
"candidate-picking":{"_anim","_sb"},
"candidates":{"_anim","_sb"},
"Candide":{"_prprn"},
"candlemas":{"_prprn","_tme"},
"canetti":{"_anim","_nme","_prprn","_sb"},
"canid":{"_anim"},
"canine":{"_anim"},
"canister":{"_loc_sr"},
"canisters":{"_loc_sr"},
"cannae":{"_geo","_prprn"},
"canned-food":{"_past"},
"canned-mushroom":{"_past"},
"Cannes":{"_cty","_geo","_prprn"},
"cannibal":{"_anim","_sb"},
"cannibals":{"_anim","_sb"},
"cannonball":{"_loc_sr"},
"canonised":{"_past"},
"canonist":{"_anim","_sb"},
"canonized":{"_past"},
"canoodle":{"_loc_sr"},
"canopied":{"_past"},
"canopus":{"_cty","_geo","_prprn"},
"cans":{"_loc_sr"},
"cantabrigian":{"_prprn"},
"canted":{"_past"},
"Canteloube":{"_prprn"},
"canter":{"_loc_sr"},
"canterbury":{"_cty","_geo","_prprn"},
"cantered":{"_loc_sr","_past"},
"cantering":{"_loc_sr"},
"cantillate":{"_loc_sr"},
"Canton":{"_cty","_geo","_prprn"},
"Cantonese":{"_prprn"},
"cantor":{"_anim","_sb"},
"canuck":{"_prprn"},
"Canute":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"canvass":{"_loc_sr"},
"canvassed":{"_loc_sr","_past"},
"canvasser":{"_anim","_sb"},
"canvassers":{"_anim","_sb"},
"caparisoned":{"_past"},
"cape":{"_geo"},
"capek":{"_anim","_nme","_prprn","_sb"},
"capelin":{"_loc_sr"},
"capella":{"_prprn"},
"Capello":{"_prprn"},
"caper":{"_loc_sr"},
"capering":{"_loc_sr"},
"capes":{"_geo"},
"Capet":{"_anim","_nme","_prprn","_sb"},
"capetian":{"_prprn","_sb"},
"capitalist":{"_anim","_sb"},
"capitalist-democratic":{"_anim","_sb"},
"capitalist-exploiters-greedy-American-consumers-gl":{"_anim","_sb"},
"capitalists":{"_anim","_sb"},
"capitalize":{"_loc_sr"},
"capitalized":{"_loc_sr","_past"},
"capitalizes":{"_loc_sr"},
"capitalizing":{"_loc_sr"},
"capitol":{"_loc_sr"},
"Capitoline":{"_geo","_prprn"},
"capitulary":{"_sb"},
"capon":{"_anim","_masc"},
"capone":{"_anim","_nme","_prprn","_sb"},
"Capote":{"_anim","_prprn","_sb"},
"cappadocia":{"_geo","_prprn"},
"capped":{"_past"},
"Capra":{"_anim","_nme","_prprn","_sb"},
"capri":{"_geo","_prprn"},
"Capricorn":{"_prprn"},
"capricornus":{"_prprn"},
"capsule":{"_loc_sr"},
"capsules":{"_loc_sr"},
"Capt":{"_prprn"},
"Capt.":{"_anim","_prprn","_sb"},
"captain":{"_anim","_sb"},
"captioned":{"_past"},
"captivate":{"_psych"},
"captivated":{"_past","_psych"},
"captivating":{"_psych"},
"captive":{"_anim","_sb"},
"captives":{"_anim","_sb"},
"captor":{"_anim","_sb"},
"capturer":{"_anim","_sb"},
"car":{"_fem"},
"car-assembly":{"_fem"},
"car-buff":{"_fem"},
"car-care":{"_fem"},
"car-crash":{"_fem"},
"car-dealers":{"_fem"},
"car-development":{"_fem"},
"car-ferry":{"_fem"},
"car-happy":{"_fem"},
"car-industry":{"_fem"},
"car-leasing":{"_fem"},
"car-maker":{"_fem"},
"car-market":{"_fem"},
"car-mechanic":{"_fem"},
"car-owners":{"_fem"},
"car-parking":{"_fem"},
"car-rental":{"_fem"},
"car-safety":{"_fem"},
"car-sales":{"_fem"},
"caracal":{"_anim"},
"caracas":{"_cty","_geo","_prprn"},
"caracul":{"_anim"},
"caramelize":{"_loc_sr"},
"Caravaggio":{"_anim","_nme","_prprn","_sb"},
"caravan":{"_anim","_sb"},
"caravans":{"_anim","_sb"},
"carbonated":{"_past"},
"carbondale":{"_cty","_geo","_prprn"},
"cardholders":{"_anim","_sb"},
"cardiac":{"_anim","_sb"},
"cardiac-drug":{"_anim","_sb"},
"Cardiff":{"_cty","_geo","_prprn"},
"cardinal":{"_anim","_sb"},
"cardinals":{"_anim","_sb"},
"cardiologists":{"_anim","_sb"},
"Cardoso":{"_prprn"},
"cardsharp":{"_anim","_sb"},
"cardsharper":{"_anim","_sb"},
"carducci":{"_anim","_nme","_prprn","_sb"},
"cared":{"_past","_psych"},
"cared-for":{"_past","_psych"},
"careened":{"_loc_sr","_past"},
"careening":{"_loc_sr"},
"careerists":{"_anim","_sb"},
"caregiver":{"_anim","_sb"},
"caregivers":{"_anim","_sb"},
"cares":{"_psych"},
"caressed":{"_past"},
"Carew":{"_anim","_nme","_prprn","_sb"},
"Carey":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"carhop":{"_anim","_sb"},
"Caribbean":{"_geo","_prprn"},
"caribou":{"_anim"},
"caricatured":{"_loc_sr","_past"},
"carillonneur":{"_anim","_sb"},
"caring":{"_psych"},
"carissa":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Carl":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Carla":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Carlisle":{"_geo","_prprn"},
"Carlos":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"carlovingian":{"_prprn"},
"Carlsbad":{"_cty","_geo","_prprn"},
"Carlson":{"_anim","_nme","_prprn","_sb"},
"Carlton":{"_cty","_geo","_prprn"},
"carlyle":{"_anim","_nme","_prprn","_sb"},
"Carmel":{"_cty","_geo","_prprn"},
"Carmelite":{"_prprn","_sb"},
"Carmen":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"carmichael":{"_anim","_geo","_nme","_prprn","_sb"},
"Carnarvon":{"_prprn"},
"Carnegie":{"_anim","_nme","_prprn","_sb"},
"carnivore":{"_anim"},
"carnivores":{"_anim"},
"carnot":{"_anim","_nme","_prprn","_sb"},
"Caro":{"_prprn"},
"caroler":{"_anim","_sb"},
"Carolina":{"_cty","_geo","_prprn"},
"Carolinas":{"_geo","_prprn"},
"caroline":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Carolingian":{"_prprn","_sb"},
"Carolinian":{"_anim","_prprn","_sb"},
"caroller":{"_anim","_sb"},
"Carothers":{"_anim","_nme","_prprn","_sb"},
"carouse":{"_loc_sr"},
"carouser":{"_anim","_sb"},
"carousing":{"_loc_sr"},
"carpenters":{"_anim","_sb"},
"Carpentier":{"_prprn"},
"carper":{"_anim","_sb"},
"carpetbagger":{"_anim","_sb"},
"carpetbaggers":{"_anim","_sb"},
"carpeted":{"_past"},
"carps":{"_anim"},
"Carrara":{"_cty","_geo","_prprn"},
"Carrey":{"_prprn"},
"Carrie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"carried":{"_past"},
"carrier":{"_anim","_sb"},
"carrier-based":{"_anim","_sb"},
"carrier-current":{"_anim","_sb"},
"carriers":{"_anim","_sb"},
"Carrington":{"_prprn"},
"Carroll":{"_anim","_nme","_prprn","_sb"},
"Carrollton":{"_cty","_geo","_prprn"},
"carrycot":{"_loc_sr"},
"cars":{"_fem"},
"carson":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"cart":{"_loc_sr"},
"Cartagena":{"_cty","_geo","_prprn"},
"carted":{"_loc_sr","_past"},
"carter":{"_anim","_sb"},
"carthage":{"_cty","_geo","_prprn"},
"carthorse":{"_anim"},
"carthusian":{"_prprn","_sb"},
"Cartier":{"_anim","_nme","_prprn","_sb"},
"carting":{"_loc_sr"},
"cartographer":{"_anim","_sb"},
"carton":{"_loc_sr"},
"cartons":{"_loc_sr"},
"cartwheel":{"_loc_sr"},
"cartwright":{"_anim","_nme","_prprn","_sb"},
"caruso":{"_anim","_nme","_prprn","_sb"},
"carve":{"_loc_sr"},
"carved":{"_loc_sr","_past"},
"carved-out-of-solid":{"_loc_sr","_past"},
"carvers":{"_anim","_sb"},
"carves":{"_loc_sr"},
"carving":{"_loc_sr"},
"Cary":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"casablanca":{"_cty","_geo","_prprn"},
"Casals":{"_anim","_nme","_prprn","_sb"},
"Casanova":{"_anim","_masc","_prprn","_sb"},
"Casanovas":{"_prprn"},
"cascaded":{"_past"},
"cased":{"_past"},
"caseworker":{"_anim","_sb"},
"caseworkers":{"_anim","_sb"},
"cashed":{"_loc_sr","_past"},
"cashier":{"_anim","_sb"},
"cashiers":{"_anim","_sb"},
"cashing":{"_loc_sr"},
"casino":{"_loc_sr"},
"casino-company":{"_loc_sr"},
"casino-hotel":{"_loc_sr"},
"casinos":{"_loc_sr"},
"cask":{"_loc_sr"},
"casks":{"_loc_sr"},
"Caspar":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"casper":{"_cty","_geo","_prprn"},
"Caspian":{"_prprn"},
"Cass":{"_anim","_nme","_prprn","_sb"},
"Cassandra":{"_anim","_prprn","_sb"},
"Cassatt":{"_anim","_nme","_prprn","_sb"},
"cassette":{"_loc_sr"},
"cassettes":{"_loc_sr"},
"cassie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"cassiopeia":{"_prprn"},
"cassirer":{"_anim","_nme","_prprn","_sb"},
"Casson":{"_prprn"},
"cassowary":{"_anim"},
"cast":{"_past"},
"castaway":{"_anim","_sb"},
"castigate":{"_loc_sr"},
"castigated":{"_loc_sr","_past"},
"castigates":{"_loc_sr"},
"castigating":{"_loc_sr"},
"castile":{"_cntry","_geo","_prprn"},
"castilian":{"_anim","_prprn","_sb"},
"castle":{"_loc_sr"},
"castle-like":{"_loc_sr"},
"castle-themed":{"_loc_sr"},
"castled":{"_loc_sr","_past"},
"castles":{"_loc_sr"},
"castling":{"_loc_sr"},
"castrato":{"_anim","_masc","_sb"},
"castries":{"_cty","_geo","_prprn"},
"Castro":{"_anim","_nme","_prprn","_sb"},
"castroism":{"_prprn"},
"casual":{"_anim","_sb"},
"casuals":{"_anim","_sb"},
"casualties":{"_anim","_sb"},
"casualty":{"_anim","_sb"},
"casualty-insurance":{"_anim","_sb"},
"casualty-loss":{"_anim","_sb"},
"casuist":{"_anim","_sb"},
"cat":{"_anim"},
"cat's-claw":{"_anim"},
"cat's-ear":{"_anim"},
"cat's-paw":{"_anim","_sb"},
"cat's-tail":{"_anim"},
"cat-like":{"_anim"},
"catacomb":{"_loc_sr"},
"catalan":{"_anim","_prprn","_sb"},
"cataloger":{"_anim","_sb"},
"catalogued":{"_past"},
"cataloguer":{"_anim","_sb"},
"catalonia":{"_geo","_prprn","_stte"},
"catalyzed":{"_past"},
"catamite":{"_sb"},
"catamount":{"_anim"},
"catamountain":{"_anim"},
"Catania":{"_cty","_geo","_prprn"},
"catapulted":{"_past"},
"catatonic":{"_anim","_sb"},
"catawba":{"_anim","_prprn","_sb"},
"catchall":{"_loc_sr"},
"catcher":{"_anim","_sb"},
"catchers":{"_anim","_sb"},
"catechist":{"_anim","_sb"},
"catechumen":{"_anim","_sb"},
"categorised":{"_past"},
"categorize":{"_loc_sr"},
"categorized":{"_loc_sr","_past"},
"categorizing":{"_loc_sr"},
"catenate":{"_loc_sr"},
"catered":{"_past"},
"caterpillar-tracked":{"_anim"},
"catfish":{"_anim"},
"cathari":{"_prprn","_sb"},
"catharism":{"_prprn"},
"cathars":{"_prprn","_sb"},
"Cathay":{"_geo","_prprn"},
"cathedral":{"_loc_sr"},
"cathedrals":{"_loc_sr"},
"cather":{"_anim","_nme","_prprn","_sb"},
"catherine":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Catholic":{"_prprn","_sb"},
"Catholicism":{"_prprn"},
"Cathy":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"catnip":{"_anim"},
"Cato":{"_anim","_nme","_prprn","_sb"},
"cats":{"_anim"},
"Catt":{"_anim","_nme","_prprn","_sb"},
"cattle":{"_anim"},
"cattle-car":{"_anim"},
"cattle-lifter":{"_anim"},
"cattleman":{"_anim","_masc","_sb"},
"cattlemen":{"_anim","_masc","_sb"},
"catullus":{"_anim","_nme","_prprn","_sb"},
"caucasia":{"_geo","_prprn"},
"Caucasian":{"_anim","_prprn","_sb"},
"caucasoid":{"_prprn","_sb"},
"Caucasus":{"_geo","_prprn"},
"caucus":{"_sb"},
"caucuses":{"_sb"},
"Caulfield":{"_prprn"},
"caulk":{"_loc_sr"},
"caulked":{"_loc_sr","_past"},
"caulking":{"_loc_sr"},
"cause-and-effect":{"_sb"},
"caused":{"_past"},
"causes":{"_sb"},
"causeway":{"_loc_sr"},
"causeways":{"_loc_sr"},
"cautioned":{"_past"},
"cavalier":{"_anim","_sb"},
"cavalry":{"_anim","_sb"},
"cavalryman":{"_anim","_sb"},
"cavalrymen":{"_anim","_sb"},
"cave-like":{"_loc_sr"},
"cave-men":{"_loc_sr"},
"caved":{"_past"},
"cavell":{"_anim","_nme","_prprn","_sb"},
"caveman":{"_anim","_sb"},
"cavemen":{"_anim","_sb"},
"caves":{"_loc_sr"},
"caviller":{"_anim","_sb"},
"cavities":{"_loc_sr"},
"cavity":{"_loc_sr"},
"cavity-fighting":{"_loc_sr"},
"cavorted":{"_past"},
"Cavour":{"_anim","_nme","_prprn","_sb"},
"cavy":{"_anim"},
"Cawley":{"_prprn"},
"caxton":{"_anim","_nme","_prprn","_sb"},
"cayman":{"_anim"},
"cayuga":{"_anim","_prprn","_sb"},
"cayuse":{"_anim"},
"cbc":{"_prprn"},
"ccc":{"_prprn"},
"cd-rom":{"_prprn"},
"CD-ROMs":{"_prprn"},
"cdc":{"_prprn"},
"ce":{"_prprn"},
"ceased":{"_past"},
"cebu":{"_geo","_prprn"},
"Cecil":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Cecilia":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"ceded":{"_past"},
"Cedric":{"_prprn"},
"ceilings":{"_loc_sr"},
"Cela":{"_prprn"},
"celebes":{"_geo","_prprn"},
"celebrant":{"_anim","_sb"},
"celebrants":{"_anim","_sb"},
"celebrater":{"_anim","_sb"},
"celebrities":{"_anim","_sb"},
"celebrity":{"_anim","_sb"},
"celebrity-driven":{"_anim","_sb"},
"celebrity-oriented":{"_anim","_sb"},
"celestial":{"_anim"},
"Celia":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"celibate":{"_anim","_sb"},
"cell":{"_loc_sr"},
"cell-like":{"_loc_sr"},
"cellar":{"_loc_sr"},
"cellarage":{"_loc_sr"},
"cellars":{"_loc_sr"},
"cellini":{"_anim","_nme","_prprn","_sb"},
"cellists":{"_anim","_sb"},
"cells":{"_loc_sr"},
"Celsius":{"_anim","_nme","_prprn","_sb"},
"cemented":{"_past"},
"cemeteries":{"_loc_sr"},
"cemetery":{"_loc_sr"},
"cenobite":{"_sb"},
"cenotaph":{"_sb"},
"cenozoic":{"_prprn"},
"censer":{"_loc_sr"},
"censored":{"_past"},
"censors":{"_anim","_sb"},
"censured":{"_past"},
"centaurus":{"_prprn"},
"centenarian":{"_anim","_sb"},
"centenarians":{"_anim","_sb"},
"center":{"_loc_sr"},
"center-aisle":{"_loc_sr"},
"center-field":{"_loc_sr"},
"center-fire":{"_loc_sr"},
"center-left":{"_loc_sr"},
"center-right":{"_loc_sr"},
"center-stage":{"_loc_sr"},
"center-vented":{"_loc_sr"},
"centers":{"_loc_sr"},
"Centigrade":{"_prprn"},
"centipede":{"_anim"},
"central":{"_sb"},
"central-bank":{"_sb"},
"central-city":{"_sb"},
"central-district":{"_sb"},
"central-planning":{"_sb"},
"centralised":{"_past"},
"Centrex":{"_prprn"},
"centrifuged":{"_loc_sr","_past"},
"centrifuging":{"_loc_sr"},
"centrist":{"_anim","_sb"},
"centuries":{"_tme"},
"centuries-old":{"_tme"},
"centurion":{"_anim","_sb"},
"centurions":{"_anim","_sb"},
"century":{"_tme"},
"century-old":{"_tme"},
"ceo":{"_anim","_prprn","_sb"},
"cepheus":{"_prprn"},
"ceramicist":{"_anim","_sb"},
"ceramist":{"_anim","_sb"},
"cerberus":{"_prprn"},
"cerebrated":{"_past"},
"Cernuda":{"_prprn"},
"certificated":{"_past"},
"certified":{"_past"},
"Cervantes":{"_prprn"},
"cesspit":{"_loc_sr"},
"cetacean":{"_anim"},
"Cetus":{"_prprn"},
"ceylon":{"_cntry","_geo","_prprn"},
"cezanne":{"_anim","_nme","_prprn","_sb"},
"CFC":{"_prprn"},
"CFO":{"_anim","_prprn","_sb"},
"ch'in":{"_anim","_nme","_prprn","_sb"},
"ch'ing":{"_anim","_nme","_prprn","_sb"},
"chablis":{"_prprn"},
"Chabrier":{"_prprn"},
"Chad":{"_cntry","_geo","_prprn"},
"chadian":{"_anim","_prprn","_sb"},
"chadic":{"_prprn"},
"Chadwick":{"_anim","_nme","_prprn","_sb"},
"chaeronea":{"_cty","_geo","_prprn"},
"chafed":{"_past"},
"chaffinch":{"_anim","_sb"},
"chagall":{"_anim","_nme","_prprn","_sb"},
"chagatai":{"_anim","_nme","_prprn","_sb"},
"chain-smoker":{"_anim","_sb"},
"chained":{"_past"},
"chaired":{"_loc_sr","_past"},
"chairing":{"_loc_sr"},
"chairman":{"_anim","_sb"},
"chairman-designate":{"_anim","_sb"},
"chairman-elect":{"_anim","_sb"},
"chairmen":{"_anim","_sb"},
"chairperson":{"_anim","_sb"},
"chairwoman":{"_anim","_fem","_sb"},
"chalcedon":{"_cty","_geo","_prprn"},
"chalcis":{"_cty","_geo","_prprn"},
"chaldaea":{"_prprn"},
"chaldea":{"_geo","_prprn"},
"chaldean":{"_anim","_prprn","_sb"},
"chalked":{"_past"},
"challenged":{"_past"},
"challenger":{"_anim","_sb"},
"challengers":{"_anim","_sb"},
"chalons-sur-marne":{"_cty","_geo","_prprn"},
"chalybeate":{"_loc_sr"},
"chamaeleon":{"_prprn"},
"chamber":{"_loc_sr"},
"chamber-music":{"_loc_sr"},
"chambered":{"_past"},
"chamberlain":{"_anim","_sb"},
"chambermaids":{"_anim","_fem","_sb"},
"chameleons":{"_anim"},
"Chamorro":{"_prprn"},
"champaign":{"_loc_sr"},
"champion":{"_anim","_sb"},
"championed":{"_past"},
"champions":{"_anim","_sb"},
"champlain":{"_anim","_nme","_prprn","_sb"},
"champollion":{"_anim","_nme","_prprn","_sb"},
"champs":{"_anim","_sb"},
"chanced":{"_past"},
"Chancellor":{"_anim","_sb"},
"Chancellorsville":{"_geo","_prprn"},
"chandelier":{"_loc_sr"},
"chandeliers":{"_loc_sr"},
"chandler":{"_anim","_sb"},
"Chanel":{"_anim","_nme","_prprn","_sb"},
"changed":{"_past"},
"changeling":{"_anim","_sb"},
"channelled":{"_past"},
"Channing":{"_anim","_nme","_prprn","_sb"},
"chanted":{"_past"},
"chanter":{"_sb"},
"Chantilly":{"_geo","_prprn"},
"chanukah":{"_prprn","_tme"},
"chaos":{"_loc_sr"},
"chapel":{"_loc_sr"},
"chapel-like":{"_loc_sr"},
"chapelgoer":{"_anim","_sb"},
"chapels":{"_loc_sr"},
"chaperoned":{"_past"},
"chaplain":{"_anim","_sb"},
"chaplaincy":{"_loc_sr"},
"chaplains":{"_anim","_sb"},
"Chaplin":{"_anim","_nme","_prprn","_sb"},
"Chapman":{"_anim","_prprn","_sb"},
"chapped":{"_past"},
"Chappell":{"_prprn"},
"chaps":{"_anim","_sb"},
"chapultepec":{"_geo","_loc_sr","_prprn"},
"char-broiled":{"_anim","_sb"},
"char-grilled":{"_anim","_sb"},
"characterized":{"_past"},
"charcot":{"_anim","_nme","_prprn","_sb"},
"charged":{"_loc_sr","_past"},
"charger":{"_anim"},
"charging":{"_loc_sr"},
"chari":{"_geo","_prprn"},
"chari-nile":{"_geo","_prprn"},
"charioteer":{"_anim","_sb"},
"charismatic":{"_sb"},
"charlatan":{"_anim","_sb"},
"charlatans":{"_anim","_sb"},
"Charlemagne":{"_anim","_nme","_prprn","_sb"},
"charleroi":{"_cty","_geo","_prprn"},
"Charles":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Charleston":{"_cty","_geo","_prprn"},
"charlestown":{"_cty","_geo","_prprn"},
"Charley":{"_prprn"},
"Charlie":{"_anim","_fem","_fnme","_masc","_nme","_prprn","_sb"},
"Charlotte":{"_anim","_cty","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"Charlottesville":{"_cty","_geo","_prprn"},
"charlottetown":{"_cty","_geo","_prprn"},
"Charlton":{"_prprn"},
"charmed":{"_past","_psych"},
"charmer":{"_anim","_sb"},
"charmers":{"_anim","_sb"},
"charming":{"_psych"},
"charon":{"_prprn"},
"charr":{"_anim","_sb"},
"charred":{"_past"},
"chart":{"_loc_sr"},
"chart-room":{"_loc_sr"},
"charted":{"_loc_sr","_past"},
"chartered":{"_past"},
"charting":{"_loc_sr"},
"chartism":{"_prprn"},
"Chartres":{"_cty","_geo","_prprn"},
"charts":{"_loc_sr"},
"Chartwell":{"_prprn"},
"charwoman":{"_anim","_fem","_sb"},
"charybdis":{"_prprn"},
"chased":{"_past"},
"chaser":{"_anim","_sb"},
"chasers":{"_anim","_sb"},
"chassid":{"_prprn"},
"chassidim":{"_prprn","_sb"},
"chastened":{"_past"},
"chastised":{"_past"},
"chat":{"_loc_sr"},
"chateau-thierry":{"_cty","_geo","_prprn"},
"Chateaubriand":{"_prprn"},
"chatelaine":{"_anim","_fem","_sb"},
"Chatham":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"chattahoochee":{"_geo","_prprn"},
"chattanooga":{"_cty","_geo","_prprn"},
"chatted":{"_loc_sr","_past"},
"chatterbox":{"_anim","_sb"},
"chattered":{"_past"},
"Chatterton":{"_anim","_nme","_prprn","_sb"},
"chatting":{"_loc_sr"},
"chaucer":{"_anim","_nme","_prprn","_sb"},
"chauffeur-driven":{"_anim","_sb"},
"chauffeurs":{"_anim","_sb"},
"Chauncey":{"_prprn"},
"Chautauqua":{"_prprn"},
"chauvinist":{"_anim","_sb"},
"chauvinists":{"_anim","_sb"},
"chavez":{"_anim","_nme","_prprn","_sb"},
"cheapskate":{"_anim","_sb"},
"Chechen":{"_prprn"},
"Chechens":{"_prprn"},
"chechnya":{"_cntry","_geo","_prprn"},
"checked":{"_past"},
"checker":{"_anim","_sb"},
"checkers":{"_anim","_sb"},
"checkout":{"_loc_sr"},
"checkout-stand":{"_loc_sr"},
"checkpoint":{"_loc_sr"},
"checkpoints":{"_loc_sr"},
"checkroom":{"_loc_sr"},
"cheer":{"_loc_sr","_psych"},
"cheered":{"_loc_sr","_past","_psych"},
"cheerer":{"_anim","_sb"},
"cheering":{"_loc_sr","_psych"},
"Cheerios":{"_prprn"},
"cheetah":{"_anim"},
"cheever":{"_anim","_nme","_prprn","_sb"},
"chef":{"_anim","_sb"},
"chefs":{"_anim","_sb"},
"Chekhov":{"_anim","_nme","_prprn","_sb"},
"chekov":{"_anim","_nme","_prprn","_sb"},
"chelated":{"_past"},
"Chelmsford":{"_cty","_geo","_prprn"},
"Chelsea":{"_anim","_cty","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"chelyabinsk":{"_cty","_geo","_prprn"},
"chemist's":{"_anim","_sb"},
"chemist-turned-entrepreneur":{"_anim","_sb"},
"chemists":{"_anim","_sb"},
"chemnitz":{"_geo","_prprn"},
"chen":{"_anim","_nme","_prprn","_sb"},
"Cheney":{"_prprn"},
"Chengdu":{"_cty","_geo","_prprn"},
"cheops":{"_anim","_nme","_prprn","_sb"},
"chequered":{"_past"},
"Cher":{"_geo","_prprn"},
"cherbourg":{"_cty","_geo","_prprn"},
"cherepovets":{"_cty","_geo","_prprn"},
"cherished":{"_past"},
"chernobyl":{"_cty","_geo","_prprn"},
"cherokee":{"_anim","_prprn","_sb"},
"Cherokees":{"_anim","_prprn","_sb"},
"cherub":{"_anim","_sb"},
"cherubim":{"_anim","_sb"},
"cherubini":{"_anim","_nme","_prprn","_sb"},
"cherubs":{"_anim","_sb"},
"Cherwell":{"_prprn"},
"Cheryl":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Ches":{"_prprn"},
"Chesapeake":{"_cty","_geo","_prprn"},
"Cheshire":{"_cty","_geo","_prprn"},
"chest":{"_loc_sr"},
"chest-back-lat-shoulder":{"_loc_sr"},
"chest-back-shoulder":{"_loc_sr"},
"chest-high":{"_loc_sr"},
"chest-swelling":{"_loc_sr"},
"chester":{"_cty","_geo","_prprn"},
"chesterton":{"_anim","_nme","_prprn","_sb"},
"chests":{"_loc_sr"},
"chetah":{"_anim"},
"chevalier":{"_anim","_masc","_sb"},
"Chevrolet":{"_prprn"},
"Chevrolets":{"_prprn"},
"chevrotain":{"_anim"},
"chewa":{"_prprn"},
"chewed":{"_past"},
"chewer":{"_anim","_sb"},
"Chex":{"_prprn"},
"cheyenne":{"_cty","_geo","_prprn","_sb"},
"Cheyennes":{"_cty","_geo","_prprn","_sb"},
"chianti":{"_prprn"},
"Chiapas":{"_cty","_geo","_prprn","_stte"},
"Chiba":{"_cty","_geo","_prprn"},
"Chicago":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"chicano":{"_prprn"},
"chick":{"_anim"},
"chickamauga":{"_cty","_geo","_prprn"},
"chickasaw":{"_anim","_prprn","_sb"},
"Chickasaws":{"_anim","_prprn","_sb"},
"chicken":{"_anim"},
"chicken-and-egg":{"_anim"},
"chicken-breasted":{"_anim"},
"chicken-fight":{"_anim"},
"chicken-mutilating":{"_anim"},
"chicken-wire":{"_anim"},
"chickens":{"_anim"},
"chicks":{"_anim"},
"chico":{"_cty","_geo","_prprn"},
"Chicopee":{"_cty","_geo","_prprn"},
"chided":{"_past"},
"chief":{"_anim","_sb"},
"chiefs":{"_anim","_sb"},
"chieftain":{"_anim","_sb"},
"chieftains":{"_anim","_sb"},
"chigger":{"_anim"},
"chihuahua":{"_anim"},
"child":{"_anim","_sb"},
"child-abuse":{"_anim","_sb"},
"child-as-required-yuppie-possession":{"_anim","_sb"},
"child-bearing":{"_anim","_sb"},
"child-centered":{"_anim","_sb"},
"child-cloud":{"_anim","_sb"},
"child-development":{"_anim","_sb"},
"child-face":{"_anim","_sb"},
"child-oriented":{"_anim","_sb"},
"child-parent":{"_anim","_sb"},
"child-protection":{"_anim","_sb"},
"child-rearing":{"_anim","_sb"},
"child-safety":{"_anim","_sb"},
"childbearing":{"_anim","_sb"},
"childbed":{"_sb"},
"childhood":{"_sb","_tme"},
"children":{"_anim","_sb"},
"Chile":{"_cntry","_geo","_prprn"},
"Chilean":{"_anim","_prprn","_sb"},
"chiliad":{"_tme"},
"chill":{"_psych"},
"chilling":{"_psych"},
"chiloe":{"_geo","_prprn"},
"chimborazo":{"_geo","_prprn"},
"chimed":{"_past"},
"chimera":{"_anim"},
"chimera-chasing":{"_anim"},
"chimneysweep":{"_anim","_sb"},
"chimneysweeper":{"_anim","_sb"},
"chimp":{"_anim"},
"chimpanzee":{"_anim"},
"chimpanzees":{"_anim"},
"chimps":{"_anim"},
"China":{"_cntry","_geo","_prprn"},
"Chinaman":{"_prprn"},
"Chinatown":{"_geo","_loc_sr","_prprn"},
"chinchilla":{"_anim"},
"Chinese":{"_anim","_prprn","_sb"},
"chinese-red":{"_anim","_prprn","_sb"},
"Ching":{"_prprn"},
"chinked":{"_past"},
"Chinook":{"_anim","_prprn","_sb"},
"chinookan":{"_prprn"},
"Chinooks":{"_anim","_prprn","_sb"},
"chios":{"_geo","_prprn"},
"chipewyan":{"_anim","_prprn","_sb"},
"chipmunk":{"_anim"},
"chippewa":{"_prprn"},
"Chirac":{"_prprn"},
"chirico":{"_anim","_nme","_prprn","_sb"},
"Chiron":{"_prprn"},
"chiropteran":{"_anim","_sb"},
"chiseled":{"_past"},
"chiseller":{"_anim","_sb"},
"Chisholm":{"_anim","_nme","_prprn","_sb"},
"chit":{"_anim","_sb"},
"chittagong":{"_cty","_geo","_prprn"},
"Chloe":{"_prprn"},
"chloromycetin":{"_prprn"},
"Choate":{"_anim","_nme","_prprn","_sb"},
"Choctaw":{"_anim","_prprn","_sb"},
"Choctaws":{"_anim","_prprn","_sb"},
"choir":{"_anim","_sb"},
"choirboy":{"_anim","_masc","_sb"},
"choirmaster":{"_anim","_sb"},
"choked":{"_past"},
"chomped":{"_past"},
"chomsky":{"_anim","_nme","_prprn","_sb"},
"chongqing":{"_cty","_geo","_prprn"},
"choose":{"_loc_sr"},
"chooser":{"_anim","_sb"},
"chooses":{"_loc_sr"},
"choosing":{"_loc_sr"},
"Chopin":{"_anim","_nme","_prprn","_sb"},
"chopped":{"_past"},
"choragus":{"_anim","_sb"},
"choreographed":{"_past"},
"choreographer":{"_anim","_sb"},
"choreographers":{"_anim","_sb"},
"chorine":{"_anim","_fem","_sb"},
"chorines":{"_anim","_fem","_sb"},
"chorister":{"_anim","_sb"},
"chortled":{"_past"},
"chorus":{"_anim","_sb"},
"chorused":{"_past"},
"choruses":{"_anim","_sb"},
"chosen":{"_loc_sr"},
"chou":{"_anim","_nme","_prprn","_sb"},
"chow":{"_anim"},
"Chrissake":{"_prprn"},
"christ's-thorn":{"_anim","_masc","_nme","_prprn","_sb"},
"christchurch":{"_cty","_geo","_prprn"},
"christen":{"_loc_sr"},
"Christendom":{"_prprn","_sb"},
"christened":{"_loc_sr","_past"},
"christening":{"_loc_sr"},
"Christer":{"_prprn"},
"Christian":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Christiania":{"_geo","_prprn"},
"christianity":{"_prprn"},
"Christians":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Christie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Christina":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Christine":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"christmas":{"_prprn","_tme"},
"christmastide":{"_prprn","_tme"},
"Christmastime":{"_prprn","_tme"},
"christology":{"_prprn"},
"Christopher":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Christos":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Christy":{"_anim","_fem","_fnme","_masc","_nme","_prprn","_sb"},
"chromed":{"_past"},
"chronicled":{"_loc_sr","_past"},
"chroniclers":{"_anim","_sb"},
"Chronicles":{"_prprn"},
"chronicling":{"_loc_sr"},
"Chrysler":{"_anim","_nme","_prprn","_sb"},
"chub":{"_anim"},
"Chubb":{"_prprn"},
"chucked":{"_past"},
"chuckled":{"_past"},
"chuff":{"_sb"},
"chuffed":{"_loc_sr","_past"},
"chuffing":{"_loc_sr"},
"chug":{"_loc_sr"},
"chugging":{"_loc_sr"},
"Chukchi":{"_anim","_prprn","_sb"},
"chukka":{"_tme"},
"chukker":{"_tme"},
"chukker-brown":{"_tme"},
"chums":{"_anim","_sb"},
"chungking":{"_geo","_prprn"},
"chunking":{"_loc_sr"},
"church":{"_loc_sr"},
"church-goers":{"_loc_sr"},
"church-going":{"_loc_sr"},
"church-owned":{"_loc_sr"},
"church-state":{"_loc_sr"},
"church-supported":{"_loc_sr"},
"churches":{"_loc_sr"},
"churchgoer":{"_anim","_sb"},
"churchgoers":{"_anim","_sb"},
"churchill":{"_anim","_nme","_prprn","_sb"},
"churchman":{"_anim","_masc","_sb"},
"churchwarden":{"_anim","_sb"},
"churl":{"_anim","_sb"},
"churned":{"_past"},
"churned-up":{"_past"},
"chuvash":{"_anim","_geo","_prprn","_sb"},
"cia":{"_prprn"},
"ciardi":{"_anim","_nme","_prprn","_sb"},
"cicada":{"_anim"},
"cicero":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"cicerone":{"_anim","_sb"},
"CID":{"_anim","_prprn","_sb"},
"Cie":{"_prprn"},
"cigarette":{"_loc_sr"},
"cigarette-tax":{"_loc_sr"},
"cigarette-vending":{"_loc_sr"},
"cigarettes":{"_loc_sr"},
"Cimabue":{"_anim","_nme","_prprn","_sb"},
"cimarron":{"_geo","_prprn"},
"cimmerian":{"_prprn","_sb"},
"cinch":{"_loc_sr"},
"cincinnati":{"_cty","_geo","_prprn"},
"cincinnatus":{"_anim","_nme","_prprn","_sb"},
"Cinderella":{"_anim","_prprn","_sb"},
"cinematographer":{"_anim","_sb"},
"Cineplex":{"_prprn"},
"Cinerama":{"_prprn"},
"cineraria":{"_loc_sr"},
"cinerarium":{"_loc_sr"},
"Cinzano":{"_prprn"},
"cio":{"_prprn"},
"Cipro":{"_prprn"},
"circassian":{"_anim","_prprn","_sb"},
"circe":{"_anim","_fem","_nme","_prprn","_sb"},
"circinus":{"_prprn"},
"circled":{"_past"},
"circularize":{"_loc_sr"},
"circulate":{"_loc_sr"},
"circulated":{"_loc_sr","_past"},
"circulates":{"_loc_sr"},
"circulating":{"_loc_sr"},
"circumambulate":{"_loc_sr"},
"cissy":{"_anim","_sb"},
"cistercian":{"_prprn","_sb"},
"cistern":{"_loc_sr"},
"cited":{"_past"},
"cities":{"_loc_sr"},
"citizen":{"_anim","_sb"},
"citizen-plaintiffs":{"_anim","_sb"},
"citizen-sparked":{"_anim","_sb"},
"citizenry":{"_anim","_sb"},
"citizens":{"_anim","_sb"},
"citlaltepetl":{"_geo","_prprn"},
"city":{"_loc_sr"},
"city-born":{"_loc_sr"},
"city-charter":{"_loc_sr"},
"city-dweller":{"_loc_sr"},
"city-owned":{"_loc_sr"},
"city-trading":{"_loc_sr"},
"city-wide":{"_loc_sr"},
"civet":{"_anim"},
"civilian":{"_anim","_sb"},
"civilian-aircraft":{"_anim","_sb"},
"civilians":{"_anim","_sb"},
"civilize":{"_loc_sr"},
"civilized":{"_loc_sr","_past"},
"civilizing":{"_loc_sr"},
"clad":{"_loc_sr","_past"},
"Claiborne":{"_prprn"},
"claimant":{"_anim","_sb"},
"claimants":{"_anim","_sb"},
"claimed":{"_past"},
"Clair":{"_anim","_nme","_prprn","_sb"},
"Claire":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"clairvoyant":{"_anim","_sb"},
"clambered":{"_past"},
"clamored":{"_past"},
"clamped":{"_past"},
"clams":{"_anim"},
"clan":{"_anim","_sb"},
"clanged":{"_past"},
"clans":{"_anim","_sb"},
"clansman":{"_anim","_masc","_sb"},
"clanswoman":{"_anim","_fem","_sb"},
"clapped":{"_past"},
"clapper":{"_anim","_sb"},
"clappers":{"_anim","_sb"},
"Clapton":{"_prprn"},
"claque":{"_anim","_sb"},
"Clara":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Clare":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Clarendon":{"_anim","_nme","_prprn","_sb"},
"Clarice":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"clarified":{"_past"},
"clarinettist":{"_anim","_sb"},
"Clark":{"_anim","_geo","_nme","_prprn","_sb"},
"Clarke":{"_anim","_nme","_prprn","_sb"},
"clarksburg":{"_cty","_geo","_prprn"},
"Clarkson":{"_prprn"},
"clash":{"_loc_sr"},
"clashed":{"_loc_sr","_past"},
"clashing":{"_loc_sr"},
"clasped":{"_past"},
"classicist":{"_anim","_sb"},
"classification-angle":{"_loc_sr"},
"classifications":{"_loc_sr"},
"classified":{"_loc_sr","_past"},
"classified-ad":{"_loc_sr","_past"},
"classifies":{"_loc_sr"},
"classify":{"_loc_sr"},
"classifying":{"_loc_sr"},
"classmate":{"_anim","_sb"},
"classmates":{"_anim","_sb"},
"classroom":{"_loc_sr"},
"classrooms":{"_loc_sr"},
"clatter":{"_loc_sr"},
"clattered":{"_loc_sr","_past"},
"clattering":{"_loc_sr"},
"Claude":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Claudia":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"claudius":{"_anim","_nme","_prprn","_sb"},
"Claus":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"clausewitz":{"_anim","_nme","_prprn","_sb"},
"claustrophobe":{"_anim","_sb"},
"clay":{"_loc_sr"},
"clay-like":{"_loc_sr"},
"clay-mining":{"_loc_sr"},
"clays":{"_loc_sr"},
"cleaned-up":{"_past"},
"cleaner-burning":{"_anim","_sb"},
"cleanse":{"_loc_sr"},
"cleansed":{"_loc_sr","_past"},
"cleansing":{"_loc_sr"},
"cleanthes":{"_anim","_nme","_prprn","_sb"},
"clear":{"_wthr"},
"clear-channel":{"_loc_sr"},
"clear-cut":{"_past"},
"clear-it-out":{"_loc_sr"},
"clear-thinking":{"_loc_sr"},
"cleared":{"_past","_wthr"},
"clearing":{"_wthr"},
"clearing-firm":{"_loc_sr"},
"clears":{"_wthr"},
"Clearwater":{"_cty","_geo","_prprn"},
"cleaved":{"_past"},
"cleft":{"_loc_sr"},
"clefts":{"_loc_sr"},
"Cleland":{"_prprn"},
"clemenceau":{"_anim","_nme","_prprn","_sb"},
"clemens":{"_anim","_nme","_prprn","_sb"},
"clenched":{"_past"},
"cleopatra":{"_anim","_nme","_prprn","_sb"},
"clergy":{"_anim","_sb"},
"clergyman":{"_anim","_masc","_sb"},
"clergymen":{"_anim","_masc","_sb"},
"cleric":{"_sb"},
"clerical":{"_sb"},
"clerical-lay":{"_sb"},
"clericalist":{"_anim","_sb"},
"clerics":{"_sb"},
"clerisy":{"_sb"},
"clerk":{"_anim","_sb"},
"clerk-turned":{"_anim","_sb"},
"clerks":{"_anim","_sb"},
"cleveland":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"clichy":{"_cty","_geo","_prprn"},
"clichy-la-garenne":{"_cty","_geo","_prprn"},
"clicked":{"_past"},
"client":{"_anim","_sb"},
"client-server":{"_anim","_sb"},
"client-service":{"_anim","_sb"},
"clientele":{"_anim","_sb"},
"clients":{"_anim","_sb"},
"cliff":{"_loc_sr"},
"cliff-brake":{"_loc_sr"},
"cliff-hanging":{"_loc_sr"},
"Clifford":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"cliffs":{"_loc_sr"},
"Clifton":{"_cty","_geo","_prprn"},
"climatologist":{"_anim","_sb"},
"climaxed":{"_past"},
"climb":{"_loc_sr"},
"climbed":{"_loc_sr","_past"},
"climber":{"_anim","_sb"},
"climbers":{"_anim","_sb"},
"climbing":{"_loc_sr"},
"clinched":{"_loc_sr","_past"},
"clinches":{"_loc_sr"},
"clinching":{"_loc_sr"},
"clingfish":{"_anim"},
"clinic":{"_loc_sr"},
"clinician":{"_anim","_sb"},
"clinics":{"_loc_sr"},
"clinked":{"_past"},
"Clinton":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"clio":{"_prprn"},
"cliques":{"_anim","_sb"},
"Clive":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"cloaked":{"_past"},
"cloakroom":{"_loc_sr"},
"cloakrooms":{"_loc_sr"},
"clobbered":{"_past"},
"clocked":{"_past"},
"clod":{"_loc_sr"},
"clodhopper":{"_anim","_sb"},
"clodhoppers":{"_anim","_sb"},
"clods":{"_loc_sr"},
"cloistered":{"_past"},
"clomp":{"_loc_sr"},
"clomped":{"_loc_sr","_past"},
"cloned":{"_past"},
"clones":{"_anim"},
"Clooney":{"_prprn"},
"clop":{"_loc_sr"},
"clopping":{"_loc_sr"},
"Clorox":{"_prprn"},
"close":{"_loc_sr"},
"closed":{"_loc_sr","_past"},
"closed-chain":{"_loc_sr","_past"},
"closed-end":{"_loc_sr","_past"},
"closed-ring":{"_loc_sr","_past"},
"closes":{"_loc_sr"},
"closeted":{"_loc_sr","_past"},
"closing":{"_loc_sr"},
"clot":{"_loc_sr"},
"clothe":{"_loc_sr"},
"clothed":{"_loc_sr","_past"},
"clothier":{"_anim","_sb"},
"clothiers":{"_anim","_sb"},
"clothing":{"_loc_sr"},
"clotho":{"_prprn"},
"clotted":{"_loc_sr","_past"},
"clotting":{"_loc_sr"},
"cloud":{"_loc_sr"},
"cloud-covered":{"_loc_sr"},
"cloud-cuckoo-land":{"_loc_sr"},
"cloud-flecked":{"_loc_sr"},
"clouded":{"_past","_wthr"},
"clouds":{"_loc_sr"},
"Clough":{"_anim","_nme","_prprn","_sb"},
"clovis":{"_cty","_geo","_prprn"},
"clowns":{"_anim","_sb"},
"club":{"_anim","_sb"},
"club-head":{"_anim","_sb"},
"club-shaped":{"_anim","_sb"},
"clubbed":{"_past"},
"clubhouse":{"_loc_sr"},
"clubhouses":{"_loc_sr"},
"clubroom":{"_loc_sr"},
"clubrooms":{"_loc_sr"},
"clubs":{"_anim","_sb"},
"clucked":{"_past"},
"clump":{"_loc_sr"},
"clumping":{"_loc_sr"},
"clung":{"_past"},
"clunk":{"_loc_sr"},
"clunking":{"_loc_sr"},
"cluster":{"_loc_sr"},
"clustered":{"_loc_sr","_past"},
"clustering":{"_loc_sr"},
"clutched":{"_past"},
"cluttered":{"_past"},
"clyde":{"_geo","_prprn"},
"clydesdale":{"_anim","_prprn"},
"clytemnestra":{"_anim","_fem","_nme","_prprn","_sb"},
"Cmdr":{"_prprn"},
"cmv":{"_prprn"},
"cnossos":{"_geo","_prprn"},
"cnossus":{"_prprn"},
"cns":{"_prprn"},
"cnut":{"_anim","_nme","_prprn","_sb"},
"Co":{"_prprn"},
"co-anchor":{"_co"},
"co-anchored":{"_co","_past"},
"co-author":{"_co"},
"co-authors":{"_co"},
"co-beneficiary":{"_anim","_co","_sb"},
"co-chair":{"_co","_loc_sr"},
"co-chaired":{"_co","_loc_sr","_past"},
"co-chairman":{"_co"},
"co-chairmen":{"_anim","_co","_sb"},
"co-chairperson":{"_anim","_co","_sb"},
"co-chief":{"_anim","_co","_sb"},
"co-conspirators":{"_anim","_co","_sb"},
"co-defendant":{"_anim","_co","_sb"},
"co-defendants":{"_anim","_co","_sb"},
"co-develop":{"_co","_loc_sr"},
"co-developers":{"_anim","_co","_sb"},
"co-discoverer":{"_anim","_co","_sb"},
"co-edited":{"_co","_past"},
"co-editor":{"_anim","_co","_sb"},
"co-edits":{"_co"},
"co-educate":{"_co"},
"co-exist":{"_co"},
"co-existence":{"_co"},
"co-extinction":{"_co"},
"co-founder":{"_co"},
"co-founders":{"_anim","_co","_sb"},
"co-head":{"_co"},
"co-heads":{"_co"},
"co-hero":{"_anim","_co","_sb"},
"co-insurance":{"_co"},
"co-inventors":{"_anim","_co","_sb"},
"co-lead":{"_co"},
"co-major":{"_co","_loc_sr"},
"co-managed":{"_co","_past"},
"co-manager":{"_anim","_co","_sb"},
"co-managers":{"_anim","_co","_sb"},
"co-marketing":{"_co"},
"co-obligation":{"_co"},
"co-occur":{"_co"},
"co-occurrence":{"_co"},
"co-occurring":{"_co"},
"co-operate":{"_co"},
"co-operated":{"_co","_past"},
"co-operates":{"_co"},
"co-operating":{"_co"},
"co-operation":{"_co"},
"co-operative":{"_co"},
"co-opt":{"_co"},
"co-opted":{"_co","_past"},
"co-opting":{"_co"},
"co-option":{"_co"},
"co-ordinates":{"_co"},
"co-ordination":{"_co"},
"co-owner":{"_anim","_co","_sb"},
"co-payment":{"_co"},
"co-payments":{"_co"},
"co-pilot":{"_co"},
"co-pilots":{"_anim","_co","_sb"},
"co-plaintiff":{"_anim","_co","_sb"},
"co-presidents":{"_anim","_co","_sb"},
"co-produce":{"_co"},
"co-produced":{"_co","_past"},
"co-producer":{"_anim","_co","_sb"},
"co-production":{"_co"},
"co-publisher":{"_anim","_co","_sb"},
"co-referent":{"_co"},
"co-respondent":{"_anim","_co","_sb"},
"co-star":{"_co"},
"co-stars":{"_anim","_co","_sb"},
"co-vary":{"_co","_loc_sr"},
"co-venture":{"_co"},
"co-worker":{"_anim","_co","_sb"},
"co-workers":{"_anim","_co","_sb"},
"co-written":{"_co","_loc_sr"},
"co-wrote":{"_co","_loc_sr","_past"},
"Co.":{"_geo","_prprn"},
"coach":{"_anim","_loc_sr","_sb"},
"coach-and-four":{"_anim","_loc_sr","_sb"},
"coachbuilder":{"_anim","_sb"},
"coached":{"_past"},
"coaches":{"_anim","_loc_sr","_sb"},
"coachmen":{"_anim","_masc","_sb"},
"coact":{"_co"},
"coaction":{"_co"},
"coadjutor":{"_anim","_sb"},
"coagulate":{"_loc_sr"},
"coagulated":{"_loc_sr","_past"},
"coagulating":{"_loc_sr"},
"coagulator":{"_anim","_sb"},
"coalesced":{"_past"},
"coalfield":{"_loc_sr"},
"coalfields":{"_loc_sr"},
"coalhole":{"_loc_sr"},
"coalition":{"_sb"},
"coalitions":{"_sb"},
"coalminers":{"_anim","_sb"},
"coarsened":{"_past"},
"coast":{"_loc_sr"},
"coasted":{"_past"},
"coaster":{"_co"},
"coasters":{"_co"},
"coastguard":{"_anim","_sb"},
"coastguardsman":{"_anim","_sb"},
"coastland":{"_loc_sr"},
"coasts":{"_loc_sr"},
"coated":{"_past"},
"coated-magnetic":{"_past"},
"coatee":{"_anim","_sb"},
"Coates":{"_anim","_co","_fem","_prprn","_sb"},
"coati":{"_anim"},
"coati-mondi":{"_anim"},
"coati-mundi":{"_anim"},
"coauthor":{"_co"},
"coaxed":{"_co","_past"},
"coaxer":{"_anim","_sb"},
"coaxing":{"_co"},
"cobber":{"_anim","_sb"},
"cobblers":{"_anim","_sb"},
"cobol":{"_prprn"},
"Coburg":{"_cty","_geo","_prprn"},
"Coca-Cola":{"_prprn"},
"cocaine":{"_sb"},
"cocaine-processing":{"_sb"},
"cocarboxylase":{"_co"},
"cochannel":{"_co"},
"cochin":{"_geo","_prprn","_stte"},
"cochineal":{"_anim"},
"cochise":{"_anim","_nme","_prprn","_sb"},
"cochran":{"_anim","_nme","_prprn","_sb"},
"cock":{"_anim"},
"cockaigne":{"_loc_sr","_prprn"},
"cockatoos":{"_anim"},
"cockchafer":{"_anim"},
"cockcroft":{"_anim","_nme","_prprn","_sb"},
"cocked":{"_loc_sr","_past"},
"cocker":{"_anim"},
"cockerel":{"_anim"},
"cockle":{"_anim"},
"cockle-bur":{"_anim"},
"cockle-burr":{"_anim"},
"cockles":{"_anim"},
"cockpit":{"_loc_sr"},
"cockpits":{"_loc_sr"},
"cockroach":{"_anim"},
"cockroaches":{"_anim"},
"cocksucker":{"_anim","_sb"},
"coconspirator":{"_co"},
"coconspire":{"_co","_loc_sr"},
"cocooning":{"_loc_sr"},
"cocteau":{"_anim","_nme","_prprn","_sb"},
"cocytus":{"_prprn"},
"cod":{"_anim","_loc_sr"},
"cod-liver":{"_anim","_loc_sr"},
"coddled":{"_loc_sr","_past"},
"coddler":{"_anim","_sb"},
"coddling":{"_loc_sr"},
"code-named":{"_past"},
"coded":{"_loc_sr","_past"},
"codefendant":{"_co"},
"coder":{"_anim","_sb"},
"codetermines":{"_co"},
"codified":{"_loc_sr","_past"},
"codifies":{"_loc_sr"},
"codify":{"_loc_sr"},
"codifying":{"_loc_sr"},
"coding":{"_loc_sr"},
"codling":{"_anim"},
"Cody":{"_anim","_fnme","_nme","_prprn","_sb"},
"Coe":{"_prprn"},
"coed":{"_anim","_fem","_sb"},
"coeds":{"_anim","_fem","_sb"},
"coeducate":{"_co"},
"coeducation":{"_co"},
"coeducational":{"_co"},
"coelacanth":{"_anim"},
"coenzyme":{"_co"},
"coequal":{"_co","_sb"},
"Coeur":{"_prprn"},
"coeval":{"_anim","_sb"},
"coevals":{"_anim","_sb"},
"coexist":{"_co"},
"coexistence":{"_co"},
"coexistent":{"_co"},
"coexisting":{"_co"},
"coextension":{"_co"},
"coextensive":{"_co"},
"coextrude":{"_co"},
"cofactor":{"_co"},
"cofactors":{"_co"},
"cofounder":{"_co"},
"cogeneration":{"_co"},
"cogeneration-plant":{"_co"},
"cogged":{"_past"},
"cognate":{"_sb"},
"cognoscente":{"_anim","_sb"},
"cohabit":{"_co"},
"cohabitation":{"_co"},
"cohan":{"_anim","_nme","_prprn","_sb"},
"Cohen":{"_anim","_nme","_prprn","_sb"},
"cohere":{"_loc_sr"},
"cohn":{"_anim","_nme","_prprn","_sb"},
"cohoe":{"_co"},
"cohort":{"_anim","_sb"},
"cohorts":{"_anim","_sb"},
"coiffeur":{"_anim","_masc","_sb"},
"coiffeuse":{"_anim","_fem","_sb"},
"coil":{"_loc_sr"},
"coiled":{"_loc_sr","_past"},
"coiling":{"_loc_sr"},
"coincide":{"_loc_sr"},
"coincided":{"_loc_sr","_past"},
"coincidence":{"_co"},
"coinciding":{"_loc_sr"},
"coined":{"_loc_sr","_past"},
"coinsurance":{"_co"},
"coinsure":{"_co"},
"coitus":{"_anim","_fem"},
"col":{"_loc_sr"},
"Col.":{"_anim","_cntry","_loc_sr","_prprn","_sb","_stte"},
"colbert":{"_anim","_nme","_prprn","_sb"},
"Colby":{"_prprn"},
"colchis":{"_geo","_prprn"},
"Cole":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Coleman":{"_anim","_nme","_prprn","_sb"},
"Coleridge":{"_anim","_nme","_prprn","_sb"},
"Colgate":{"_anim","_nme","_prprn","_sb"},
"Colin":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"collaborate":{"_loc_sr"},
"collaborated":{"_loc_sr","_past"},
"collaborates":{"_loc_sr"},
"collaborating":{"_loc_sr"},
"collapsed":{"_past"},
"collared":{"_past"},
"collate":{"_loc_sr"},
"collateralize":{"_loc_sr"},
"collateralized":{"_loc_sr","_past"},
"colleague":{"_anim","_sb"},
"colleagues":{"_anim","_sb"},
"collect":{"_loc_sr","_psych"},
"collected":{"_loc_sr","_past","_psych"},
"collecting":{"_loc_sr","_psych"},
"collective":{"_anim","_sb"},
"collective-bargaining":{"_anim","_sb"},
"collectives":{"_anim","_sb"},
"collectivised":{"_past"},
"collectivize":{"_loc_sr"},
"collectivized":{"_loc_sr","_past"},
"collectivizers":{"_anim","_sb"},
"collector":{"_anim","_sb"},
"collectors":{"_anim","_sb"},
"collects":{"_loc_sr","_psych"},
"colleen":{"_anim","_fem","_sb"},
"collider":{"_anim","_sb"},
"collie":{"_anim"},
"collier":{"_anim","_sb"},
"colliery":{"_loc_sr"},
"collimated":{"_past"},
"Collins":{"_anim","_prprn","_sb"},
"collocate":{"_loc_sr"},
"collude":{"_loc_sr"},
"colluded":{"_loc_sr","_past"},
"Colo":{"_prprn"},
"Colo.":{"_prprn","_stte"},
"Cologne":{"_cty","_geo","_prprn"},
"Colombia":{"_cntry","_geo","_prprn"},
"Colombians":{"_anim","_prprn","_sb"},
"Colombo":{"_cty","_geo","_prprn"},
"colonel":{"_anim","_sb"},
"colonels":{"_anim","_sb"},
"colonial":{"_anim","_sb"},
"colonialist":{"_anim","_sb"},
"colonialists":{"_anim","_sb"},
"colonials":{"_anim","_sb"},
"colonies":{"_loc_sr"},
"colonised":{"_past"},
"coloniser":{"_anim","_sb"},
"colonist":{"_anim","_sb"},
"colonize":{"_loc_sr"},
"colony":{"_loc_sr"},
"color-coded":{"_past"},
"colorado":{"_geo","_prprn","_stte"},
"coloreds":{"_anim","_sb"},
"colossae":{"_cty","_geo","_prprn"},
"colossians":{"_prprn"},
"colossus":{"_sb"},
"coloured":{"_sb"},
"colt":{"_anim"},
"Coltrane":{"_anim","_nme","_prprn","_sb"},
"colts":{"_anim"},
"coluber":{"_anim","_co","_sb"},
"columba":{"_anim","_nme","_prprn","_sb"},
"Columbia":{"_cty","_geo","_prprn"},
"Columbus":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"columnist":{"_anim","_sb"},
"columnists":{"_anim","_sb"},
"Comanche":{"_anim","_prprn","_sb"},
"Comanches":{"_anim","_prprn","_sb"},
"comate":{"_co"},
"combat":{"_loc_sr"},
"combatant":{"_anim","_sb"},
"combatants":{"_anim","_sb"},
"combatted":{"_loc_sr","_past"},
"combed":{"_past"},
"comber":{"_sb"},
"combine":{"_loc_sr"},
"combined":{"_loc_sr","_past"},
"combines":{"_anim","_sb"},
"combo":{"_anim","_sb"},
"combos":{"_anim","_sb"},
"Comdex":{"_prprn"},
"come":{"_loc_sr"},
"Comecon":{"_prprn"},
"comedians":{"_anim","_sb"},
"comedienne":{"_anim","_fem","_sb"},
"comenius":{"_anim","_nme","_prprn","_sb"},
"comer":{"_anim","_sb"},
"comers":{"_anim","_sb"},
"comes":{"_loc_sr"},
"comest":{"_loc_sr"},
"cometh":{"_co"},
"comforted":{"_past","_psych"},
"comforter":{"_anim","_sb"},
"comforting":{"_psych"},
"comic":{"_anim","_sb"},
"comics":{"_anim","_sb"},
"Cominform":{"_prprn"},
"coming":{"_loc_sr"},
"comint":{"_co","_loc_sr"},
"commandant":{"_anim","_sb"},
"commanded":{"_past"},
"commandeered":{"_loc_sr","_past"},
"commandeering":{"_loc_sr"},
"commander":{"_anim","_sb"},
"commander-in-chief":{"_anim","_sb"},
"commando-trained":{"_anim","_sb"},
"commandos":{"_anim","_sb"},
"commemorated":{"_past"},
"commenced":{"_past"},
"commended":{"_past"},
"commentator":{"_anim","_sb"},
"commentators":{"_anim","_sb"},
"commented":{"_past"},
"commercialised":{"_past"},
"commercialized":{"_past"},
"commingled":{"_past"},
"commissionaire":{"_anim","_sb"},
"Commissioner":{"_anim","_sb"},
"commissioners":{"_anim","_sb"},
"commissure":{"_loc_sr"},
"committed":{"_past"},
"committee":{"_anim","_sb"},
"committeeman":{"_anim","_masc","_sb"},
"committeemen":{"_anim","_masc","_sb"},
"committees":{"_anim","_sb"},
"commodore":{"_anim","_sb"},
"common":{"_loc_sr"},
"common-law-marriage":{"_loc_sr"},
"common-position":{"_loc_sr"},
"common-sense":{"_loc_sr"},
"common-sensical":{"_loc_sr"},
"common-share":{"_loc_sr"},
"common-stock":{"_loc_sr"},
"commonalty":{"_sb"},
"commoner":{"_anim","_sb"},
"commoners":{"_anim","_sb"},
"commonly":{"_tme"},
"commons":{"_loc_sr","_sb"},
"Commonwealth":{"_anim","_prprn","_sb"},
"commonwealths":{"_anim","_sb"},
"communalize":{"_loc_sr"},
"commune":{"_anim","_sb"},
"communes":{"_anim","_sb"},
"communicant":{"_anim","_sb"},
"communicated":{"_past"},
"communications":{"_sb"},
"communications-equipment":{"_sb"},
"communications-network":{"_sb"},
"communications-technology":{"_sb"},
"communicators":{"_anim","_sb"},
"communion":{"_anim","_sb"},
"Communism":{"_prprn"},
"communist":{"_anim","_sb"},
"communist-led":{"_anim","_sb"},
"communists":{"_anim","_sb"},
"communitarians":{"_sb"},
"communities":{"_anim","_sb"},
"community":{"_anim","_sb"},
"community-based":{"_anim","_sb"},
"community-development":{"_anim","_sb"},
"community-oriented":{"_anim","_sb"},
"commute":{"_loc_sr"},
"commuter-airline":{"_anim","_sb"},
"commuters":{"_anim","_sb"},
"commuting":{"_loc_sr"},
"comoros":{"_cntry","_geo","_prprn"},
"compact-car":{"_loc_sr"},
"compact-disk":{"_loc_sr"},
"compacted":{"_past"},
"compacts":{"_loc_sr"},
"companies":{"_anim","_sb"},
"companion":{"_anim","_sb"},
"companions":{"_anim","_sb"},
"company":{"_anim","_sb"},
"company-arranged":{"_anim","_sb"},
"company-managed":{"_anim","_sb"},
"company-operated":{"_anim","_sb"},
"company-owned":{"_anim","_sb"},
"company-paid":{"_anim","_sb"},
"company-run":{"_anim","_sb"},
"company-sponsored":{"_anim","_sb"},
"company-wide":{"_anim","_sb"},
"compared":{"_past"},
"compart":{"_loc_sr"},
"compartment":{"_loc_sr"},
"compartmentalised":{"_past"},
"compartmentalize":{"_loc_sr"},
"compartments":{"_loc_sr"},
"compatiblizers":{"_anim","_sb"},
"compatriots":{"_anim","_sb"},
"compeer":{"_anim","_sb"},
"compelled":{"_past"},
"compensated":{"_past"},
"competed":{"_past"},
"competitor":{"_anim","_sb"},
"competitors":{"_anim","_sb"},
"compile":{"_loc_sr"},
"compiled":{"_loc_sr","_past"},
"compiling":{"_loc_sr"},
"complainant":{"_anim","_sb"},
"complained":{"_past"},
"complainer":{"_anim","_sb"},
"complemented":{"_past"},
"completed":{"_past"},
"completed-contract":{"_past"},
"complexifier":{"_anim","_sb"},
"complicated":{"_past"},
"complimented":{"_past"},
"comported":{"_past"},
"compose":{"_psych"},
"composed":{"_past","_psych"},
"composer":{"_anim","_sb"},
"composer-in-residence":{"_anim","_sb"},
"composer-pianist-conductor":{"_anim","_sb"},
"composers":{"_anim","_sb"},
"composes":{"_psych"},
"composing":{"_psych"},
"compositor":{"_anim","_sb"},
"compounded":{"_past"},
"comprehend":{"_loc_sr"},
"comprehended":{"_loc_sr","_past"},
"comprehending":{"_loc_sr"},
"compressed":{"_past"},
"comprised":{"_past"},
"compromised":{"_past"},
"compton":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"comptroller":{"_anim","_sb"},
"compulsive":{"_anim","_sb"},
"compulsives":{"_anim","_sb"},
"computed":{"_past"},
"computerize":{"_loc_sr"},
"computerized":{"_loc_sr","_past"},
"computerizing":{"_loc_sr"},
"comrade":{"_anim","_sb"},
"comrades":{"_anim","_sb"},
"comstock":{"_anim","_nme","_prprn","_sb"},
"comstockery":{"_prprn"},
"comte":{"_anim","_nme","_prprn","_sb"},
"comtism":{"_prprn"},
"Comus":{"_co"},
"Con":{"_loc_sr"},
"conakry":{"_cty","_geo","_prprn"},
"Conant":{"_anim","_nme","_prprn","_sb"},
"concatenate":{"_loc_sr"},
"concealed":{"_past"},
"conceded":{"_past"},
"conceited":{"_past"},
"conceived":{"_past"},
"concentrated":{"_past"},
"concepcion":{"_anim","_cty","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"concerned":{"_past","_psych"},
"concerning":{"_psych"},
"concertize":{"_loc_sr"},
"concertmaster":{"_anim","_sb"},
"concessioner":{"_anim","_sb"},
"conch":{"_anim"},
"conchologist":{"_anim","_sb"},
"concierge":{"_anim","_sb"},
"concluded":{"_past"},
"concocted":{"_past"},
"Concord":{"_cty","_geo","_prprn"},
"Concorde":{"_prprn"},
"concourse":{"_loc_sr"},
"concubine":{"_anim","_fem","_sb"},
"concurrently":{"_tme"},
"condemn":{"_psych"},
"condemned":{"_past","_psych"},
"condemning":{"_psych"},
"condemns":{"_psych"},
"condensed":{"_past"},
"conditioned":{"_loc_sr","_past"},
"conditioning":{"_loc_sr"},
"Condon":{"_anim","_nme","_prprn","_sb"},
"condoned":{"_past"},
"condor":{"_anim"},
"condorcet":{"_anim","_nme","_prprn","_sb"},
"conductor":{"_anim","_sb"},
"conductors":{"_anim","_sb"},
"conductress":{"_anim","_fem","_sb"},
"conestoga":{"_prprn"},
"coney":{"_anim"},
"confab":{"_loc_sr"},
"confabulated":{"_past"},
"confect":{"_loc_sr"},
"confederates":{"_anim","_sb"},
"conferred":{"_past"},
"conferrer":{"_anim","_sb"},
"confessed":{"_past"},
"confessional":{"_loc_sr"},
"confessionals":{"_loc_sr"},
"confidant":{"_anim","_sb"},
"confidants":{"_anim","_sb"},
"confided":{"_loc_sr","_past"},
"confides":{"_loc_sr"},
"confiding":{"_loc_sr"},
"confinement":{"_sb"},
"confinements":{"_sb"},
"confirmed":{"_past"},
"conflicted":{"_loc_sr","_past","_psych"},
"conflicting":{"_loc_sr","_psych"},
"conform":{"_loc_sr"},
"conformed":{"_loc_sr","_past"},
"conformists":{"_anim","_sb"},
"confounded":{"_past","_psych"},
"confounding":{"_psych"},
"confrere":{"_sb"},
"confronted":{"_past"},
"Confucian":{"_prprn"},
"confucianism":{"_prprn"},
"confucianist":{"_prprn"},
"Confucius":{"_anim","_masc","_nme","_prprn","_sb"},
"confuse":{"_psych"},
"confused":{"_past","_psych"},
"confuses":{"_psych"},
"confusing":{"_psych"},
"confuter":{"_anim","_sb"},
"congealed":{"_past"},
"congener":{"_sb"},
"congested":{"_past"},
"conglobate":{"_loc_sr"},
"Congo":{"_cntry","_geo","_prprn"},
"Congolese":{"_anim","_prprn","_sb"},
"congratulated":{"_past"},
"congregant":{"_anim","_sb"},
"congregated":{"_past"},
"congregation":{"_anim","_sb"},
"Congregationalism":{"_prprn"},
"congregationalist":{"_anim","_sb"},
"Congregationalists":{"_anim","_sb"},
"congregations":{"_anim","_sb"},
"congressman":{"_anim","_masc","_sb"},
"congressmen":{"_anim","_masc","_sb"},
"congresswoman":{"_anim","_fem","_sb"},
"congreve":{"_anim","_nme","_prprn","_sb"},
"conjugated":{"_past"},
"conjured":{"_past"},
"conjurer":{"_anim","_sb"},
"conk":{"_loc_sr"},
"Conn":{"_prprn","_stte"},
"Connaught":{"_geo","_prprn"},
"connected":{"_past"},
"connecter":{"_anim","_sb"},
"Connecticut":{"_geo","_prprn","_stte"},
"connector":{"_anim","_sb"},
"connectors":{"_anim","_sb"},
"conned":{"_past"},
"Connell":{"_prprn"},
"connive":{"_loc_sr"},
"conniving":{"_loc_sr"},
"connoisseurs":{"_anim","_sb"},
"Connolly":{"_anim","_nme","_prprn","_sb"},
"connors":{"_anim","_nme","_prprn","_sb"},
"conquistador":{"_anim","_sb"},
"Conrad":{"_anim","_fnme","_nme","_prprn","_sb"},
"Conrail":{"_prprn"},
"conscripted":{"_loc_sr","_past"},
"conscripts":{"_anim","_sb"},
"consecrate":{"_loc_sr"},
"consecrated":{"_loc_sr","_past"},
"consented":{"_past"},
"conservationist":{"_anim","_sb"},
"conservationists":{"_anim","_sb"},
"conservative":{"_anim","_sb"},
"conservative-communist":{"_anim","_sb"},
"conservative-led":{"_anim","_sb"},
"conservative-liberal":{"_anim","_sb"},
"conservatives":{"_anim","_sb"},
"conservativist":{"_anim","_sb"},
"conservatories":{"_loc_sr"},
"conservators":{"_anim","_sb"},
"conservatory":{"_loc_sr"},
"conserve":{"_loc_sr"},
"conserved":{"_loc_sr","_past"},
"considered":{"_past"},
"consigned":{"_loc_sr","_past"},
"consignee":{"_anim","_sb"},
"consignor":{"_anim","_sb"},
"consigns":{"_loc_sr"},
"consisted":{"_past"},
"consociate":{"_loc_sr"},
"consoled":{"_past","_psych"},
"consolidate":{"_loc_sr"},
"consolidated":{"_loc_sr","_past"},
"consolidated-pretax":{"_loc_sr","_past"},
"consolidates":{"_loc_sr"},
"consolidating":{"_loc_sr"},
"consoling":{"_psych"},
"consorted":{"_past"},
"conspirators":{"_anim","_sb"},
"conspire":{"_loc_sr"},
"conspired":{"_loc_sr","_past"},
"conspires":{"_loc_sr"},
"conspiring":{"_loc_sr"},
"constable":{"_anim","_sb"},
"constabulary":{"_loc_sr"},
"constance":{"_anim","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"Constantin":{"_prprn"},
"constantine":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"Constantinople":{"_geo","_prprn"},
"constantly":{"_tme"},
"constipated":{"_past"},
"constituent":{"_anim","_sb"},
"constituents":{"_anim","_sb"},
"constituted":{"_past"},
"constrained":{"_past"},
"constricted":{"_past"},
"constructed":{"_past"},
"constructivist":{"_anim","_sb"},
"consubstantiate":{"_loc_sr"},
"consul":{"_anim","_sb"},
"consulate":{"_loc_sr"},
"consult":{"_loc_sr"},
"consultants":{"_anim","_sb"},
"consulted":{"_loc_sr","_past"},
"consulting":{"_loc_sr"},
"consulting-firm":{"_loc_sr"},
"consumed":{"_past"},
"consumer":{"_anim","_sb"},
"consumer-advocacy":{"_anim","_sb"},
"consumer-analgesic":{"_anim","_sb"},
"consumer-credit":{"_anim","_sb"},
"consumer-driven":{"_anim","_sb"},
"consumer-electronics":{"_anim","_sb"},
"consumer-finance":{"_anim","_sb"},
"consumer-goods":{"_anim","_sb"},
"consumer-led":{"_anim","_sb"},
"consumer-minded":{"_anim","_sb"},
"consumer-oriented":{"_anim","_sb"},
"consumer-paint":{"_anim","_sb"},
"consumer-price":{"_anim","_sb"},
"consumer-price-index":{"_anim","_sb"},
"consumer-product":{"_anim","_sb"},
"consumer-products":{"_anim","_sb"},
"consumer-protection":{"_anim","_sb"},
"consumer-telephone":{"_anim","_sb"},
"consumer-warning":{"_anim","_sb"},
"consumers":{"_anim","_sb"},
"consummated":{"_past"},
"consumptive":{"_anim","_sb"},
"contact":{"_anim","_sb"},
"contact-lens":{"_anim","_sb"},
"contacted":{"_loc_sr","_past"},
"contacting":{"_loc_sr"},
"contacts":{"_anim","_sb"},
"contained":{"_past"},
"containerize":{"_loc_sr"},
"containerized-cargo":{"_loc_sr","_past"},
"contaminated":{"_past"},
"contemplative":{"_anim","_sb"},
"contemporaries":{"_anim","_sb"},
"contemporary":{"_anim","_sb"},
"contended":{"_past"},
"contender":{"_anim","_sb"},
"contented":{"_past","_psych"},
"contenting":{"_psych"},
"contestant":{"_anim","_sb"},
"contestants":{"_anim","_sb"},
"contested":{"_past"},
"contestee":{"_anim","_sb"},
"contester":{"_anim","_sb"},
"continent":{"_loc_sr"},
"continental":{"_anim","_sb"},
"continents":{"_loc_sr"},
"contingent":{"_anim","_sb"},
"contingent-fee":{"_anim","_sb"},
"contingents":{"_anim","_sb"},
"continually":{"_tme"},
"continue":{"_loc_sr"},
"continued":{"_loc_sr","_past"},
"continues":{"_loc_sr"},
"continuing-education":{"_loc_sr"},
"continuously":{"_tme"},
"contorted":{"_past"},
"contortionist":{"_anim","_sb"},
"contortionists":{"_anim","_sb"},
"contour":{"_loc_sr"},
"contouring":{"_loc_sr"},
"contrabandist":{"_anim","_sb"},
"contrabass":{"_anim","_sb"},
"contracted":{"_past"},
"contracted-for":{"_past"},
"contractor":{"_anim","_sb"},
"contractors":{"_anim","_sb"},
"contradicted":{"_past"},
"contralto":{"_anim","_sb"},
"contrarians":{"_anim","_sb"},
"contrasting":{"_loc_sr"},
"contravened":{"_past"},
"contributed":{"_past"},
"contributors":{"_anim","_sb"},
"contrived":{"_past"},
"contriver":{"_anim","_sb"},
"controlled-circulation":{"_past"},
"controller":{"_anim","_sb"},
"controllers":{"_anim","_sb"},
"controversialist":{"_anim","_sb"},
"controversialists":{"_anim","_sb"},
"conurbation":{"_loc_sr"},
"convalescent":{"_sb"},
"convened":{"_past"},
"convener":{"_anim","_sb"},
"conventicle":{"_loc_sr"},
"conventionalised":{"_past"},
"conventioneer":{"_anim","_sb"},
"conventioneers":{"_anim","_sb"},
"conventioners":{"_anim","_sb"},
"conventual":{"_sb"},
"converged":{"_past"},
"conversationalist":{"_anim","_sb"},
"conversing":{"_loc_sr"},
"converted":{"_past"},
"convertible":{"_fem"},
"convertible-bond":{"_fem"},
"convertibles":{"_fem"},
"convey":{"_loc_sr"},
"conveyancer":{"_anim","_sb"},
"conveyed":{"_loc_sr","_past"},
"conveyer":{"_anim","_sb"},
"conveying":{"_loc_sr"},
"conveys":{"_loc_sr"},
"convicts":{"_anim","_sb"},
"convinced":{"_past"},
"convoluted":{"_past"},
"Conway":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"cony":{"_anim"},
"cooccur":{"_co"},
"cooccurring":{"_co"},
"cooke":{"_anim","_nme","_prprn","_sb"},
"cooked":{"_past"},
"cooked-over":{"_past"},
"cooks":{"_anim","_sb"},
"cool-white":{"_loc_sr"},
"cooled":{"_past"},
"cooler":{"_loc_sr"},
"coolers":{"_loc_sr"},
"Coolidge":{"_anim","_nme","_prprn","_sb"},
"coolie":{"_anim","_sb"},
"cools":{"_loc_sr"},
"coon":{"_anim","_sb"},
"coonhound":{"_anim"},
"cooped":{"_past"},
"Cooper":{"_anim","_fnme","_nme","_prprn","_sb"},
"cooperate":{"_co"},
"cooperated":{"_co","_past"},
"cooperates":{"_co"},
"cooperating":{"_co"},
"cooperation":{"_co"},
"cooperative":{"_co","_loc_sr"},
"cooperative-care":{"_co","_loc_sr"},
"cooperatives":{"_co","_loc_sr"},
"cooperator":{"_co"},
"cooperstown":{"_geo","_prprn"},
"coordinate":{"_loc_sr"},
"coordinated":{"_loc_sr","_past"},
"coordinates":{"_co","_sb"},
"coordinating":{"_loc_sr"},
"coordination":{"_co"},
"coosa":{"_geo","_prprn"},
"coot":{"_anim"},
"cop-killer":{"_anim","_sb"},
"copartner":{"_co"},
"copartnership":{"_co"},
"copeck":{"_co"},
"copenhagen":{"_cty","_geo","_prprn"},
"Copernicus":{"_anim","_nme","_prprn","_sb"},
"copied":{"_past"},
"copier":{"_sb"},
"copiers":{"_sb"},
"copilot":{"_anim","_co","_sb"},
"copland":{"_anim","_nme","_prprn","_sb"},
"Copley":{"_anim","_nme","_prprn","_sb"},
"copolymer":{"_co"},
"copolymerise":{"_co"},
"copolymerize":{"_co"},
"copolymers":{"_co"},
"copperhead":{"_anim"},
"coppersmith":{"_anim","_sb"},
"coppola":{"_anim","_nme","_prprn","_sb"},
"coproducer":{"_anim","_co","_sb"},
"coproductions":{"_co"},
"cops":{"_anim","_sb"},
"copt":{"_prprn"},
"coptic":{"_prprn"},
"copulate":{"_loc_sr"},
"copycats":{"_anim","_sb"},
"copyist":{"_anim","_sb"},
"copyreader":{"_anim","_sb"},
"copyrighted":{"_past"},
"coquet":{"_loc_sr"},
"coquette":{"_anim","_fem","_sb"},
"cora":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"corbelled":{"_past"},
"Corbett":{"_anim","_nme","_prprn","_sb"},
"Corby":{"_geo","_prprn"},
"corday":{"_anim","_nme","_prprn","_sb"},
"Cordova":{"_prprn"},
"coreference":{"_co"},
"coreferent":{"_co"},
"coreligionist":{"_anim","_co","_sb"},
"Corelli":{"_anim","_nme","_prprn","_sb"},
"corespondent":{"_anim","_co","_sb"},
"corgi":{"_anim"},
"Corinne":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Corinth":{"_cty","_geo","_prprn"},
"Corinthian":{"_anim","_prprn","_sb"},
"Corinthians":{"_anim","_prprn","_sb"},
"Coriolanus":{"_prprn"},
"Cork":{"_cty","_geo","_prprn"},
"corked":{"_past"},
"corker":{"_anim","_sb"},
"corkers":{"_anim","_sb"},
"corkscrew":{"_loc_sr"},
"Cormack":{"_anim","_nme","_prprn","_sb"},
"cormorant":{"_anim"},
"corn":{"_anim"},
"corn-based":{"_anim"},
"corn-belt":{"_anim"},
"corn-buying":{"_anim"},
"corn-farmers":{"_anim"},
"corn-producing":{"_anim"},
"corn-seed":{"_anim"},
"cornball":{"_anim","_sb"},
"corncrake":{"_anim"},
"corned":{"_past"},
"corneille":{"_anim","_nme","_prprn","_sb"},
"Cornelius":{"_anim","_nme","_prprn","_sb"},
"Cornell":{"_anim","_nme","_prprn","_sb"},
"cornerback":{"_anim","_sb"},
"cornerbacks":{"_anim","_sb"},
"cornered":{"_loc_sr","_past"},
"cornering":{"_loc_sr"},
"cornetist":{"_anim","_sb"},
"cornflower":{"_anim"},
"cornhusker":{"_anim","_sb"},
"Cornish":{"_anim","_prprn","_sb"},
"cornishman":{"_anim","_masc","_prprn","_sb"},
"cornishwoman":{"_anim","_fem","_prprn","_sb"},
"corns":{"_anim"},
"Cornwall":{"_cty","_geo","_prprn"},
"Cornwallis":{"_anim","_nme","_prprn","_sb"},
"Cornwell":{"_prprn"},
"Coronado":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"coroner":{"_anim","_sb"},
"Corot":{"_anim","_nme","_prprn","_sb"},
"Corp.":{"_anim","_prprn","_sb"},
"corporal":{"_anim","_sb"},
"corporation":{"_anim","_sb"},
"corporation-socialist":{"_anim","_sb"},
"corporations":{"_anim","_sb"},
"corporatist":{"_anim","_sb"},
"corporativists":{"_anim","_sb"},
"corpse":{"_sb"},
"corpses":{"_sb"},
"corral":{"_loc_sr"},
"corralled":{"_loc_sr","_past"},
"corralling":{"_loc_sr"},
"corrals":{"_loc_sr"},
"corrected":{"_past"},
"Correggio":{"_anim","_nme","_prprn","_sb"},
"corregidor":{"_geo","_prprn"},
"correlate":{"_loc_sr"},
"correlated":{"_loc_sr","_past"},
"correlating":{"_loc_sr"},
"corresponded":{"_past"},
"correspondent":{"_anim","_sb"},
"correspondents":{"_anim","_sb"},
"corridor":{"_loc_sr"},
"corridors":{"_loc_sr"},
"corrie":{"_fnme","_prprn"},
"corroborated":{"_past"},
"corrugate":{"_loc_sr"},
"corrugated":{"_loc_sr","_past"},
"corrupted":{"_past"},
"corsair":{"_anim","_sb"},
"corsica":{"_geo","_prprn"},
"Cortes":{"_anim","_nme","_prprn","_sb"},
"Cortez":{"_anim","_nme","_prprn","_sb"},
"Cortland":{"_cty","_geo","_prprn"},
"corvette":{"_loc_sr"},
"corvettes":{"_loc_sr"},
"corvus":{"_prprn"},
"cosecant":{"_co"},
"cosher":{"_anim","_sb"},
"cosign":{"_co"},
"cosignatory":{"_anim","_co","_sb"},
"cosigner":{"_anim","_co","_sb"},
"cosine":{"_co"},
"cosmetician":{"_anim","_sb"},
"cosmetologist":{"_anim","_sb"},
"Cosmo":{"_prprn"},
"cosmographer":{"_anim","_sb"},
"cosmographist":{"_anim","_sb"},
"cosmologist":{"_anim","_sb"},
"cosmologists":{"_anim","_sb"},
"cosmonaut":{"_anim","_sb"},
"cosmopolitan":{"_anim","_sb"},
"cosmopolitans":{"_anim","_sb"},
"cosmopolite":{"_sb"},
"cosponsored":{"_co","_loc_sr","_past"},
"cossack":{"_anim","_prprn","_sb"},
"Cossacks":{"_anim","_prprn","_sb"},
"Costello":{"_anim","_nme","_prprn","_sb"},
"costermonger":{"_anim","_sb"},
"costumed":{"_loc_sr","_past"},
"costumer":{"_anim","_sb"},
"costumier":{"_anim","_sb"},
"costuming":{"_loc_sr"},
"cotan":{"_co","_loc_sr"},
"cotangent":{"_co"},
"cote":{"_loc_sr"},
"cotenant":{"_co"},
"cothromboplastin":{"_co"},
"Cotman":{"_prprn"},
"cotonou":{"_cty","_geo","_prprn"},
"cotopaxi":{"_geo","_prprn"},
"cotswold":{"_anim","_prprn"},
"cottager":{"_anim","_sb"},
"cottar":{"_anim","_sb"},
"cottontail":{"_anim"},
"couched":{"_past"},
"coue":{"_anim","_nme","_prprn","_sb"},
"cougar":{"_anim"},
"cough":{"_loc_sr"},
"coughed":{"_loc_sr","_past"},
"coughing":{"_loc_sr"},
"could":{"_past"},
"coulda":{"_past"},
"Coulomb":{"_anim","_prprn","_sb"},
"councillor":{"_anim","_sb"},
"councilor":{"_sb"},
"councilors":{"_sb"},
"councils":{"_anim","_sb"},
"counsel":{"_anim","_sb"},
"counseled":{"_past"},
"counselor":{"_anim","_sb"},
"counselors":{"_anim","_sb"},
"counter-attack":{"_loc_sr"},
"counter-attacked":{"_loc_sr","_past"},
"counter-balanced":{"_past"},
"counter-revolutionist":{"_anim","_sb"},
"counter-tenor":{"_anim","_sb"},
"counter-trade":{"_loc_sr"},
"counter-trend":{"_loc_sr"},
"counteracted":{"_past"},
"counterattacked":{"_past"},
"counterbalanced":{"_past"},
"counterbidder":{"_anim","_sb"},
"counterbidders":{"_anim","_sb"},
"countercharged":{"_past"},
"counterdemonstrator":{"_anim","_sb"},
"countered":{"_loc_sr","_past"},
"counterfeiter":{"_anim","_sb"},
"counterflow":{"_loc_sr"},
"countering":{"_loc_sr"},
"countermove":{"_loc_sr"},
"counterpart":{"_anim","_sb"},
"counterparts":{"_anim","_sb"},
"counterperson":{"_anim","_sb"},
"counterpointing":{"_loc_sr"},
"counterpoised":{"_past"},
"counterrevolutionaries":{"_anim","_sb"},
"counterrevolutionist":{"_anim","_sb"},
"countersuing":{"_loc_sr"},
"counterterrorist":{"_anim","_sb"},
"counterwoman":{"_anim","_fem","_sb"},
"counties":{"_loc_sr"},
"countinghouse":{"_loc_sr"},
"countless":{"_quant"},
"countries":{"_loc_sr"},
"country":{"_loc_sr"},
"country-bred":{"_loc_sr"},
"country-club":{"_loc_sr"},
"country-development":{"_loc_sr"},
"country-life":{"_loc_sr"},
"country-squirehood":{"_loc_sr"},
"country-style":{"_loc_sr"},
"countryman":{"_anim","_sb"},
"countrymen":{"_anim","_sb"},
"countryside":{"_loc_sr"},
"countrywoman":{"_anim","_fem","_sb"},
"county":{"_loc_sr"},
"couperin":{"_anim","_nme","_prprn","_sb"},
"couple":{"_anim","_sb"},
"coupled":{"_past"},
"couples":{"_anim","_sb"},
"courbet":{"_anim","_nme","_prprn","_sb"},
"courier":{"_anim","_sb"},
"couriers":{"_anim","_sb"},
"coursed":{"_loc_sr","_past"},
"courser":{"_anim"},
"court":{"_loc_sr"},
"court-appointed":{"_loc_sr"},
"court-approved":{"_loc_sr"},
"court-length":{"_loc_sr"},
"court-ordered":{"_loc_sr"},
"court-reporting":{"_loc_sr"},
"court-supervised":{"_loc_sr"},
"courted":{"_past"},
"courthouse":{"_loc_sr"},
"courthouses":{"_loc_sr"},
"courtiers":{"_anim","_sb"},
"Courtney":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Courtrai":{"_geo","_prprn"},
"courtroom":{"_loc_sr"},
"courtrooms":{"_loc_sr"},
"courts":{"_loc_sr"},
"courtside":{"_loc_sr"},
"courtyard":{"_loc_sr"},
"courtyards":{"_loc_sr"},
"cousin":{"_anim","_sb"},
"cousin-wife":{"_anim","_sb"},
"cousins":{"_anim","_sb"},
"cousteau":{"_anim","_nme","_prprn","_sb"},
"couturier":{"_anim","_sb"},
"covalence":{"_co"},
"covariance":{"_co"},
"covariation":{"_co"},
"Coventry":{"_cty","_geo","_prprn"},
"coveted":{"_past"},
"cow":{"_anim"},
"cow-blood":{"_anim"},
"cow-man":{"_anim"},
"cow-people":{"_anim"},
"cowage":{"_co","_loc_sr"},
"coward":{"_anim","_sb"},
"cowards":{"_anim","_sb"},
"cowboy":{"_anim","_sb"},
"cowboys":{"_anim","_sb"},
"cowed":{"_past","_psych"},
"cower":{"_loc_sr"},
"cowering":{"_loc_sr"},
"cowfish":{"_anim"},
"cowhands":{"_anim","_sb"},
"cowherd":{"_anim","_sb"},
"cowled":{"_past"},
"Cowley":{"_anim","_nme","_prprn","_sb"},
"coworkers":{"_anim","_co","_sb"},
"cowper":{"_anim","_nme","_prprn","_sb"},
"cowrie":{"_anim"},
"cowry":{"_anim"},
"cows":{"_anim"},
"cowshed":{"_loc_sr"},
"cowslip":{"_sb"},
"cox":{"_anim","_sb"},
"cox-1":{"_anim","_sb"},
"cox-2":{"_anim","_sb"},
"coxcomb":{"_sb"},
"coxcombs":{"_sb"},
"coydog":{"_anim"},
"coyote":{"_anim"},
"coyotes":{"_anim"},
"coypu":{"_anim"},
"cpa":{"_prprn"},
"CPAs":{"_prprn"},
"cpi":{"_prprn"},
"cpr":{"_prprn"},
"crab":{"_anim"},
"crabbed":{"_past"},
"crabs":{"_anim"},
"cracked":{"_past"},
"crackled":{"_past"},
"crackpot":{"_sb"},
"crackpots":{"_sb"},
"cracksman":{"_anim","_sb"},
"cracow":{"_cty","_geo","_prprn"},
"cradle":{"_loc_sr"},
"cradled":{"_loc_sr","_past"},
"craftsman-in-residence":{"_anim","_masc","_sb"},
"craftsmen":{"_anim","_masc","_sb"},
"Craig":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"craigie":{"_anim","_nme","_prprn","_sb"},
"crake":{"_anim"},
"cram":{"_loc_sr"},
"crammer":{"_anim","_sb"},
"cramming":{"_loc_sr"},
"craniate":{"_sb"},
"craning":{"_loc_sr"},
"craniologist":{"_anim","_sb"},
"cranked":{"_past"},
"Cranston":{"_cty","_geo","_prprn"},
"crap":{"_loc_sr"},
"crapshooter":{"_anim","_sb"},
"crashed":{"_past"},
"crate":{"_loc_sr"},
"cratered":{"_past"},
"crates":{"_loc_sr"},
"craved":{"_past"},
"craven":{"_anim","_sb"},
"crawford":{"_anim","_nme","_prprn","_sb"},
"crawl":{"_loc_sr"},
"crawled":{"_loc_sr","_past"},
"crawler":{"_anim","_sb"},
"crawling":{"_loc_sr"},
"crayfish":{"_anim"},
"crazee":{"_anim","_sb"},
"crazies":{"_anim","_sb"},
"crazy":{"_anim","_sb"},
"crazy-wonderful":{"_anim","_sb"},
"creaked":{"_past"},
"creamed":{"_past"},
"creamery":{"_loc_sr"},
"creased":{"_past"},
"create":{"_loc_sr"},
"created":{"_loc_sr","_past"},
"creates":{"_loc_sr"},
"creating":{"_loc_sr"},
"Creation":{"_prprn"},
"creationist":{"_anim","_sb"},
"creative":{"_anim","_sb"},
"creator":{"_anim","_sb"},
"creators":{"_anim","_sb"},
"creature":{"_anim"},
"creatures":{"_anim"},
"crecy":{"_cty","_geo","_prprn"},
"credentialized":{"_past"},
"credited":{"_past"},
"creditor":{"_sb"},
"creditors":{"_sb"},
"Cree":{"_anim","_prprn","_sb"},
"creek":{"_loc_sr"},
"creek-filled":{"_loc_sr"},
"creeks":{"_loc_sr"},
"creep":{"_loc_sr"},
"creeping":{"_loc_sr"},
"creeps":{"_anim","_sb"},
"creepy-crawlies":{"_anim"},
"creepy-crawly":{"_anim"},
"cremated":{"_past"},
"crematorium":{"_loc_sr"},
"crematoriums":{"_loc_sr"},
"cremona":{"_cty","_geo","_prprn"},
"Creole":{"_anim","_prprn","_sb"},
"creon":{"_anim","_masc","_prprn","_sb"},
"crept":{"_loc_sr","_past"},
"Cressida":{"_prprn","_sb"},
"crested":{"_past"},
"Cretaceous":{"_prprn"},
"Crete":{"_geo","_prprn"},
"cretin":{"_anim","_sb"},
"crew":{"_anim","_sb"},
"crew-rest":{"_anim","_sb"},
"crewman":{"_anim","_sb"},
"crews":{"_anim","_sb"},
"crichton":{"_anim","_nme","_prprn","_sb"},
"cricketer":{"_anim","_sb"},
"crickets":{"_anim"},
"cried":{"_loc_sr","_past"},
"crier":{"_anim","_sb"},
"Crimea":{"_geo","_prprn"},
"criminal":{"_anim","_sb"},
"criminal-abortion":{"_anim","_sb"},
"criminal-defense":{"_anim","_sb"},
"criminals":{"_anim","_sb"},
"crimped":{"_loc_sr","_past"},
"crimper":{"_anim","_sb"},
"cringed":{"_loc_sr","_past"},
"cringing":{"_loc_sr"},
"crinkled":{"_past"},
"crinoid":{"_anim"},
"cripple-maker":{"_anim","_sb"},
"crippled":{"_past"},
"cripples":{"_anim","_sb"},
"Crisco":{"_prprn"},
"Crispin":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"crisscrossed":{"_past"},
"cristal":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"critic":{"_anim","_sb"},
"criticized":{"_past"},
"critics":{"_anim","_sb"},
"cro-magnon":{"_prprn","_sb"},
"croak":{"_loc_sr"},
"croaked":{"_loc_sr","_past"},
"croaking":{"_loc_sr"},
"croat":{"_anim","_prprn","_sb"},
"Croatia":{"_cntry","_geo","_prprn"},
"croatian":{"_anim","_prprn","_sb"},
"crocked":{"_past"},
"Crockett":{"_anim","_nme","_prprn","_sb"},
"crocodile":{"_anim"},
"croesus":{"_anim","_nme","_prprn","_sb"},
"crofter":{"_anim","_sb"},
"crofters":{"_anim","_sb"},
"cromwell":{"_anim","_nme","_prprn","_sb"},
"cronies":{"_anim","_sb"},
"Cronin":{"_anim","_nme","_prprn","_sb"},
"cronus":{"_prprn"},
"crooked":{"_past"},
"crooks":{"_anim","_sb"},
"crooned":{"_past"},
"crooner":{"_anim","_sb"},
"cropped":{"_past"},
"cropper":{"_anim","_sb"},
"crore":{"_num","_quant"},
"crosby":{"_anim","_geo","_nme","_prprn","_sb"},
"cross":{"_loc_sr"},
"cross-banded":{"_anim"},
"cross-bay":{"_anim"},
"cross-blending":{"_anim"},
"cross-border":{"_anim"},
"cross-buying":{"_anim"},
"cross-classification":{"_anim"},
"cross-connect":{"_anim"},
"cross-currency":{"_anim"},
"cross-currents":{"_anim"},
"cross-division":{"_anim"},
"cross-dress":{"_loc_sr"},
"cross-dresser":{"_anim","_sb"},
"cross-dressing":{"_loc_sr"},
"cross-examiner":{"_anim","_sb"},
"cross-fertilized":{"_past"},
"cross-functional":{"_anim"},
"cross-investing":{"_anim"},
"cross-licensing":{"_anim"},
"cross-linguistic":{"_anim"},
"cross-linguistically":{"_anim"},
"cross-linkage":{"_anim"},
"cross-margining":{"_anim"},
"cross-market":{"_anim"},
"cross-marketing":{"_anim"},
"cross-modal":{"_anim"},
"cross-ownership":{"_anim"},
"cross-party":{"_anim"},
"cross-ply":{"_anim"},
"cross-pollinated":{"_past"},
"cross-promotion":{"_anim"},
"cross-purchase":{"_anim"},
"cross-questioner":{"_anim","_sb"},
"cross-selling":{"_anim"},
"cross-sentential":{"_anim"},
"cross-shaped":{"_anim"},
"cross-shareholdings":{"_anim"},
"cross-state":{"_anim"},
"cross-striations":{"_anim"},
"cross-subsidies":{"_anim"},
"cross-top":{"_anim"},
"cross-writing":{"_anim"},
"crossbeam":{"_sb"},
"crossbred":{"_anim"},
"crosscut":{"_past"},
"crossed":{"_loc_sr","_past"},
"crosses":{"_anim"},
"crosshatched":{"_past"},
"crossing":{"_loc_sr"},
"Crossman":{"_prprn"},
"crossopterygian":{"_sb"},
"crossover":{"_loc_sr"},
"crosspatch":{"_anim","_sb"},
"crosswise":{"_loc"},
"crotch":{"_loc_sr"},
"crouched":{"_past"},
"croup":{"_sb"},
"crouse":{"_anim","_nme","_prprn","_sb"},
"crow":{"_anim"},
"crow-bait":{"_anim"},
"crow-sized":{"_anim"},
"crowd":{"_anim","_sb"},
"crowded":{"_loc_sr","_past"},
"crowds":{"_anim","_sb"},
"Crowe":{"_prprn"},
"crowed":{"_past"},
"crowned":{"_loc_sr","_past"},
"crowning":{"_loc_sr"},
"crows":{"_anim"},
"Croydon":{"_prprn"},
"crp":{"_prprn"},
"crt":{"_prprn"},
"crucible":{"_loc_sr"},
"crucifer":{"_anim","_sb"},
"cruised":{"_loc_sr","_past"},
"cruisers":{"_fem"},
"cruising":{"_loc_sr"},
"crumb":{"_loc_sr"},
"crumble":{"_loc_sr"},
"crumbled":{"_loc_sr","_past"},
"crumbles":{"_loc_sr"},
"crumple":{"_loc_sr"},
"crumpled":{"_loc_sr","_past"},
"crunched":{"_past"},
"crusaded":{"_loc_sr","_past"},
"crusading":{"_loc_sr"},
"cruse":{"_loc_sr"},
"crush":{"_psych"},
"crushers":{"_anim","_sb"},
"crushing":{"_psych"},
"crust":{"_loc_sr"},
"Crustacea":{"_prprn"},
"crustacean":{"_anim"},
"crusted":{"_past"},
"crusts":{"_loc_sr"},
"cry":{"_loc_sr"},
"crybaby":{"_anim","_sb"},
"crying":{"_loc_sr"},
"crypt":{"_loc_sr"},
"cryptogam":{"_sb"},
"cryptographer":{"_anim","_sb"},
"cryptographers":{"_anim","_sb"},
"cryptologist":{"_anim","_sb"},
"crystalised":{"_past"},
"crystalized":{"_past"},
"crystallised":{"_past"},
"crystallized":{"_past"},
"crystallographer":{"_anim","_sb"},
"crystallographers":{"_anim","_sb"},
"cst":{"_prprn"},
"cub":{"_anim"},
"Cuba":{"_cntry","_geo","_prprn"},
"Cuban":{"_anim","_prprn","_sb"},
"cubby":{"_loc_sr"},
"cubbyhole":{"_loc_sr"},
"cubbyholes":{"_loc_sr"},
"cubed":{"_past"},
"cubicle":{"_loc_sr"},
"cubs":{"_anim"},
"cuckoo":{"_anim"},
"cuckoos":{"_anim"},
"cuddle":{"_loc_sr"},
"cuddled":{"_loc_sr","_past"},
"cuddling":{"_loc_sr"},
"cued":{"_past"},
"Cuisinart":{"_prprn"},
"Cuisinarts":{"_prprn"},
"Culbertson":{"_anim","_nme","_prprn","_sb"},
"culiacan":{"_cty","_geo","_prprn"},
"culled":{"_past"},
"Cullen":{"_anim","_nme","_prprn","_sb"},
"culminated":{"_past"},
"culotte":{"_anim"},
"culprits":{"_anim","_sb"},
"cult":{"_sb"},
"cultivated":{"_past"},
"cultivator":{"_anim","_sb"},
"cults":{"_sb"},
"cultured":{"_past"},
"cumana":{"_cty","_geo","_prprn"},
"cumberland":{"_cty","_geo","_prprn"},
"cumbria":{"_cntry","_geo","_prprn"},
"Cummings":{"_anim","_nme","_prprn","_sb"},
"cumulate":{"_loc_sr"},
"Cunard":{"_prprn"},
"cunaxa":{"_geo","_prprn"},
"Cuneo":{"_cty","_geo","_prprn"},
"cunner":{"_loc_sr"},
"Cunningham":{"_anim","_nme","_prprn","_sb"},
"cup":{"_loc_sr"},
"cupbearer":{"_anim","_sb"},
"cupboard":{"_loc_sr"},
"cupboards":{"_loc_sr"},
"cupid":{"_anim","_masc","_sb"},
"cupids":{"_anim","_masc","_sb"},
"cupped":{"_loc_sr","_past"},
"cupper":{"_anim","_sb"},
"cupping":{"_loc_sr"},
"cups":{"_loc_sr"},
"cur":{"_anim"},
"curate":{"_anim","_sb"},
"curator":{"_anim","_sb"},
"curators":{"_anim","_sb"},
"curdle":{"_loc_sr"},
"curdled":{"_loc_sr","_past"},
"curdling":{"_loc_sr"},
"cured":{"_past"},
"Curie":{"_anim","_fnme","_nme","_prprn","_sb"},
"curitiba":{"_cty","_geo","_prprn"},
"curling":{"_loc_sr"},
"currently":{"_tme"},
"curst":{"_past"},
"curtailed":{"_past"},
"curtained":{"_past"},
"curtal":{"_anim"},
"curtilage":{"_loc_sr"},
"Curtin":{"_anim","_nme","_prprn","_sb"},
"Curtis":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"curtiss":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"curtseyed":{"_past"},
"curve":{"_loc_sr"},
"curved":{"_loc_sr","_past"},
"curvet":{"_loc_sr"},
"Curzon":{"_anim","_nme","_prprn","_sb"},
"Cusack":{"_prprn"},
"cusco":{"_geo","_prprn"},
"cuscus":{"_anim"},
"cush-cush":{"_anim","_cntry","_geo","_nme","_prprn","_sb"},
"cushing":{"_anim","_nme","_prprn","_sb"},
"cushioned":{"_past"},
"cushitic":{"_prprn"},
"cusk":{"_loc_sr"},
"cusk-eel":{"_loc_sr"},
"cussed":{"_past"},
"custer":{"_anim","_nme","_prprn","_sb"},
"custodian":{"_anim","_sb"},
"customer":{"_anim","_sb"},
"customer-account":{"_anim","_sb"},
"customer-cost":{"_anim","_sb"},
"customer-driven":{"_anim","_sb"},
"customer-inventory":{"_anim","_sb"},
"customer-oriented":{"_anim","_sb"},
"customer-service":{"_anim","_sb"},
"customers":{"_anim","_sb"},
"customhouse":{"_loc_sr"},
"customized":{"_past"},
"cut":{"_past"},
"cutler":{"_anim","_sb"},
"cutpurse":{"_anim","_sb"},
"cutthroat":{"_anim","_sb"},
"cuttlefish":{"_anim"},
"cuvier":{"_anim","_nme","_prprn","_sb"},
"cuzco":{"_cty","_geo","_prprn"},
"cv":{"_prprn"},
"cva":{"_prprn"},
"cwm":{"_loc_sr"},
"cyanobacteria":{"_anim"},
"cybele":{"_anim","_fem","_nme","_prprn","_sb"},
"Cyclades":{"_geo","_prprn"},
"cyclamen":{"_anim"},
"cycle":{"_tme"},
"cycled":{"_loc_sr","_past"},
"cycles":{"_tme"},
"cycling":{"_loc_sr"},
"cyclist":{"_anim","_sb"},
"cyclists":{"_anim","_sb"},
"Cyclopes":{"_prprn"},
"Cyclops":{"_anim","_prprn","_sb"},
"cygnet":{"_anim"},
"cygnus":{"_prprn"},
"cymric":{"_prprn"},
"cymry":{"_prprn"},
"Cynewulf":{"_anim","_nme","_prprn","_sb"},
"cynic":{"_anim","_sb"},
"cynics":{"_anim","_sb"},
"cynoscephalae":{"_geo","_loc_sr","_prprn"},
"Cynthia":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"cynwulf":{"_anim","_nme","_prprn","_sb"},
"Cyprian":{"_anim","_prprn","_sb"},
"cypriote":{"_prprn"},
"Cyprus":{"_cntry","_geo","_prprn"},
"cyril":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"cyrillic":{"_prprn"},
"cyrus":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"cytherea":{"_prprn"},
"cytogeneticist":{"_anim","_sb"},
"czarina":{"_anim","_fem","_sb"},
"czarist":{"_anim","_sb"},
"czars":{"_anim","_masc","_sb"},
"Czech":{"_anim","_prprn","_sb"},
"Czechoslovak":{"_anim","_prprn","_sb"},
"Czechoslovakia":{"_cntry","_geo","_prprn"},
"czechoslovakian":{"_anim","_prprn","_sb"},
"Czechoslovaks":{"_anim","_prprn","_sb"},
"Czechs":{"_anim","_prprn","_sb"},
"czerny":{"_anim","_nme","_prprn","_sb"},
"czestochowa":{"_cty","_geo","_prprn"},
"d-day":{"_prprn","_tme"},
"DA":{"_prprn"},
"dabbled":{"_past"},
"dabchick":{"_anim"},
"dacca":{"_cty","_geo","_prprn"},
"dace":{"_anim"},
"dachau":{"_cty","_geo","_prprn"},
"dachshund":{"_anim"},
"dacoit":{"_sb"},
"dacron":{"_prprn"},
"dad":{"_anim","_masc","_sb"},
"Dada":{"_prprn"},
"Dadaism":{"_prprn"},
"daddy":{"_anim","_masc","_sb"},
"dads":{"_anim","_masc","_sb"},
"daedalus":{"_prprn"},
"dagan":{"_anim","_loc_sr","_masc","_nme","_prprn","_sb"},
"Dagestan":{"_geo","_prprn"},
"dago":{"_anim","_sb"},
"dagon":{"_anim","_masc","_nme","_prprn","_sb"},
"daguerre":{"_anim","_nme","_prprn","_sb"},
"dahomey":{"_cntry","_geo","_prprn"},
"dail":{"_prprn"},
"Daimler":{"_anim","_nme","_prprn","_sb"},
"dairen":{"_geo","_prprn"},
"dairies":{"_loc_sr"},
"dairy":{"_loc_sr"},
"dairy-oh":{"_loc_sr"},
"dairymaid":{"_anim","_fem","_sb"},
"dairyman":{"_anim","_masc","_sb"},
"dairymen":{"_anim","_masc","_sb"},
"dais":{"_loc_sr"},
"daises":{"_loc_sr"},
"Dak.":{"_prprn"},
"dakar":{"_cty","_geo","_prprn"},
"Dakota":{"_prprn","_sb"},
"Dalglish":{"_prprn"},
"dali":{"_anim","_nme","_prprn","_sb"},
"Dalian":{"_cty","_geo","_prprn"},
"dallas":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"dallier":{"_anim","_sb"},
"dalmane":{"_prprn"},
"dalmatia":{"_geo","_prprn"},
"dalmatian":{"_anim"},
"Dalton":{"_cty","_geo","_prprn"},
"Daly":{"_anim","_nme","_prprn","_sb"},
"dam":{"_anim"},
"damaged":{"_past"},
"damascus":{"_cty","_geo","_prprn"},
"dame":{"_anim","_fem","_sb"},
"dammed":{"_past"},
"dammed-up":{"_past"},
"damn":{"_loc_sr"},
"damning":{"_loc_sr"},
"damocles":{"_anim","_nme","_prprn","_sb"},
"Damon":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"damped":{"_past"},
"dampened":{"_past"},
"dampener":{"_anim","_sb"},
"dams":{"_anim"},
"damselfish":{"_anim"},
"Dan":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"dana":{"_anim","_fem","_fnme","_masc","_nme","_prprn","_sb"},
"danaus":{"_prprn"},
"Danbury":{"_cty","_geo","_prprn"},
"dance":{"_loc_sr"},
"danced":{"_loc_sr","_past"},
"dancer":{"_anim","_sb"},
"dancers":{"_anim","_sb"},
"dancing":{"_loc_sr"},
"dancing-master":{"_loc_sr"},
"dandified":{"_past"},
"dandle":{"_loc_sr"},
"dandy":{"_anim","_masc","_sb"},
"dane":{"_anim","_prprn","_sb"},
"Danes":{"_anim","_prprn","_sb"},
"dangled":{"_past"},
"daniel":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Danielle":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Daniels":{"_anim","_nme","_prprn","_sb"},
"Danish":{"_anim","_prprn","_sb"},
"Danny":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"dano-norwegian":{"_prprn"},
"danseur":{"_anim","_masc","_sb"},
"danseuse":{"_anim","_fem","_sb"},
"danton":{"_anim","_nme","_prprn","_sb"},
"danu":{"_anim","_fem","_nme","_prprn","_sb"},
"Danube":{"_geo","_prprn"},
"Danubian":{"_prprn"},
"Danville":{"_cty","_geo","_prprn"},
"danzig":{"_geo","_prprn"},
"DAO":{"_prprn"},
"Daphne":{"_prprn"},
"dapple":{"_anim"},
"dapple-grey":{"_anim"},
"dappled":{"_past"},
"dappled-gray":{"_past"},
"dappled-grey":{"_past"},
"Darby":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Darcy":{"_anim","_fem","_fnme","_masc","_nme","_prprn","_sb"},
"dardanelles":{"_geo","_prprn"},
"dardanian":{"_prprn"},
"dardanus":{"_prprn"},
"dardic":{"_prprn"},
"dared":{"_past"},
"daredevil":{"_anim","_sb"},
"darfur":{"_geo","_prprn"},
"Darien":{"_cty","_geo","_prprn"},
"Dario":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Darius":{"_prprn"},
"darjeeling":{"_cty","_geo","_prprn"},
"darkened":{"_past"},
"darky":{"_anim","_sb"},
"darling":{"_anim","_sb"},
"darlings":{"_anim","_sb"},
"Darlington":{"_geo","_prprn"},
"darned":{"_past"},
"darner":{"_anim","_sb"},
"Darrow":{"_anim","_nme","_prprn","_sb"},
"dart":{"_loc_sr"},
"darted":{"_loc_sr","_past"},
"darting":{"_loc_sr"},
"Dartmouth":{"_cty","_geo","_prprn"},
"Darvon":{"_prprn"},
"Darwin":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Darwinian":{"_prprn"},
"darwinism":{"_prprn"},
"dashed":{"_past"},
"dasht-e-kavir":{"_geo","_prprn"},
"dasht-e-lut":{"_geo","_prprn"},
"dasyure":{"_anim"},
"date-mark":{"_tme"},
"dated":{"_past"},
"datelined":{"_past"},
"dates":{"_tme"},
"Datuk":{"_prprn"},
"daubed":{"_past"},
"daugavpils":{"_cty","_geo","_prprn"},
"daughter":{"_anim","_fem","_sb"},
"daughters":{"_anim","_fem","_sb"},
"daumier":{"_anim","_nme","_prprn","_sb"},
"daunted":{"_past","_psych"},
"daunting":{"_psych"},
"Dauphin":{"_anim","_sb"},
"Davao":{"_cty","_geo","_prprn"},
"Dave":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"David":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Davidson":{"_anim","_nme","_prprn","_sb"},
"Davies":{"_anim","_nme","_prprn","_sb"},
"Davis":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Davos":{"_prprn"},
"Davy":{"_anim","_fnme","_nme","_prprn","_sb"},
"davys":{"_anim","_nme","_prprn","_sb"},
"dawdle":{"_loc_sr"},
"dawdled":{"_loc_sr","_past"},
"dawdling":{"_loc_sr"},
"dawes":{"_anim","_nme","_prprn","_sb"},
"Dawkins":{"_prprn"},
"dawn":{"_tme"},
"dawned":{"_past"},
"dawns":{"_tme"},
"Dawson":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"day":{"_tme"},
"day-and-night":{"_tme"},
"day-by-day":{"_tme"},
"day-even":{"_tme"},
"day-long":{"_tme"},
"day-today":{"_tme"},
"day-watch":{"_tme"},
"dayan":{"_anim","_nme","_prprn","_sb"},
"dayboy":{"_anim","_sb"},
"daybreak":{"_tme"},
"daydreamed":{"_past"},
"daydreamer":{"_anim","_sb"},
"daytime":{"_tme"},
"dayton":{"_cty","_geo","_prprn"},
"dazed":{"_past","_psych"},
"dazzle":{"_psych"},
"dazzled":{"_past","_psych"},
"dazzler":{"_anim","_sb"},
"dazzling":{"_psych"},
"dds":{"_prprn"},
"de-aerate":{"_loc_sr"},
"de-emphasized":{"_past"},
"deaccession":{"_loc_sr"},
"deaconess":{"_anim","_fem","_sb"},
"deactivated":{"_past"},
"dead":{"_anim","_sb"},
"dead-eyed":{"_anim","_sb"},
"dead-man's-fingers":{"_anim","_sb"},
"dead-weight":{"_anim","_sb"},
"deadbeat":{"_anim","_sb"},
"deadbeats":{"_anim","_sb"},
"deadheads":{"_anim","_sb"},
"deadlocked":{"_past"},
"deaerate":{"_loc_sr"},
"deaf":{"_anim","_sb"},
"deaf-and-dumb":{"_anim","_sb"},
"deaf-mute":{"_anim","_sb"},
"deafened":{"_past"},
"Deak":{"_prprn"},
"dealer":{"_anim","_sb"},
"dealer-community":{"_anim","_sb"},
"dealer-led":{"_anim","_sb"},
"dealer-manager":{"_anim","_sb"},
"dealer-managers":{"_anim","_sb"},
"dealer-related":{"_anim","_sb"},
"dealer-to-dealer":{"_anim","_sb"},
"dealers":{"_anim","_sb"},
"dealfish":{"_anim"},
"dealmaker":{"_anim","_sb"},
"dealmakers":{"_anim","_sb"},
"dealt":{"_past"},
"dean":{"_anim","_sb"},
"Deane":{"_anim","_nme","_prprn","_sb"},
"deanery":{"_loc_sr"},
"deans":{"_anim","_sb"},
"dear":{"_anim","_sb"},
"Dearborn":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"dearest":{"_anim","_sb"},
"deary":{"_anim","_sb"},
"deathtrap":{"_loc_sr"},
"Deauville":{"_cty","_geo","_prprn"},
"deb":{"_anim","_fem","_sb"},
"debase":{"_loc_sr"},
"debased":{"_loc_sr","_past"},
"debaser":{"_anim","_sb"},
"debasing":{"_loc_sr"},
"debated":{"_loc_sr","_past"},
"debater":{"_anim","_sb"},
"debating":{"_loc_sr"},
"debauched":{"_past"},
"debauchee":{"_anim","_sb"},
"debaucher":{"_anim","_sb"},
"Debbie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"debilitated":{"_past"},
"debitor":{"_anim","_sb"},
"debouch":{"_loc_sr"},
"debs":{"_anim","_fem","_sb"},
"debtor":{"_anim","_sb"},
"debtor-in-possession":{"_anim","_sb"},
"debtor-nation":{"_anim","_sb"},
"debtors":{"_anim","_sb"},
"debugged":{"_past"},
"debugger":{"_anim","_sb"},
"debunked":{"_past"},
"Debussy":{"_anim","_nme","_prprn","_sb"},
"debutante":{"_anim","_fem","_sb"},
"debuted":{"_loc_sr","_past"},
"Dec":{"_prprn"},
"Dec.":{"_prprn"},
"decade-long":{"_tme"},
"decade-old":{"_tme"},
"decadent":{"_anim","_sb"},
"decades":{"_tme"},
"decades-old":{"_tme"},
"decaffeinated":{"_past"},
"decalogue":{"_prprn"},
"decamped":{"_past"},
"decant":{"_loc_sr"},
"decanted":{"_loc_sr","_past"},
"decanter":{"_loc_sr"},
"decanting":{"_loc_sr"},
"decapitalize":{"_loc_sr"},
"decapitalized":{"_loc_sr","_past"},
"decatur":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"decay":{"_loc_sr"},
"decayed":{"_loc_sr","_past"},
"decaying":{"_loc_sr"},
"deceased":{"_anim","_sb"},
"deceive":{"_psych"},
"deceived":{"_past","_psych"},
"deceiver":{"_anim","_sb"},
"deceives":{"_psych"},
"deceiving":{"_psych"},
"decelerate":{"_loc_sr"},
"decelerated":{"_loc_sr","_past"},
"decelerating":{"_loc_sr"},
"december":{"_prprn","_tme"},
"decentralised":{"_past"},
"decentralize":{"_loc_sr"},
"decentralized":{"_loc_sr","_past"},
"decentralizing":{"_loc_sr"},
"decertified":{"_past"},
"decimated":{"_past"},
"deciphered":{"_past"},
"decipherer":{"_anim","_sb"},
"decision-maker":{"_anim","_sb"},
"decision-makers":{"_anim","_sb"},
"decius":{"_anim","_nme","_prprn","_sb"},
"deckhand":{"_anim","_sb"},
"declaimed":{"_past"},
"declared":{"_past"},
"declarer":{"_anim","_sb"},
"declassified":{"_past"},
"decline":{"_loc_sr"},
"declined":{"_loc_sr","_past"},
"decliners":{"_anim","_sb"},
"decode":{"_loc_sr"},
"decoder":{"_anim","_sb"},
"decoke":{"_loc_sr"},
"decolonize":{"_loc_sr"},
"decommissioned":{"_loc_sr","_past"},
"decompose":{"_loc_sr"},
"decomposed":{"_loc_sr","_past"},
"decomposes":{"_loc_sr"},
"decomposing":{"_loc_sr"},
"deconsecrated":{"_past"},
"deconstructed":{"_past"},
"decontaminated":{"_past"},
"decorated":{"_past"},
"decorators":{"_anim","_sb"},
"decorticated":{"_past"},
"decreased":{"_past"},
"decreed":{"_loc_sr","_past"},
"decreeing":{"_loc_sr"},
"decried":{"_past"},
"decriminalized":{"_past"},
"decurved":{"_loc_sr","_past"},
"dedicated":{"_past"},
"deduce":{"_loc_sr"},
"deduces":{"_loc_sr"},
"deducing":{"_loc_sr"},
"deduct":{"_loc_sr"},
"deducting":{"_loc_sr"},
"Dee":{"_anim","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"deemed":{"_past"},
"deep":{"_loc_sr"},
"deep-chested":{"_loc_sr"},
"deep-discount":{"_loc_sr"},
"deep-dye":{"_loc_sr"},
"deep-fat-fry":{"_loc_sr"},
"deep-fried":{"_past"},
"deep-lobed":{"_loc_sr"},
"deep-mined":{"_loc_sr"},
"deep-pink":{"_loc_sr"},
"deep-pocket":{"_loc_sr"},
"deep-pocketed":{"_loc_sr"},
"deep-sounding":{"_loc_sr"},
"deep-space":{"_loc_sr"},
"deep-tendon":{"_loc_sr"},
"deep-yellow":{"_loc_sr"},
"deer":{"_anim"},
"deer's-ear":{"_anim"},
"deer's-ears":{"_anim"},
"deer-are-long-legged-rats-with-big-ears":{"_anim"},
"deer-handling":{"_anim"},
"deer-killing":{"_anim"},
"deere":{"_anim","_nme","_prprn","_sb"},
"deerhound":{"_anim"},
"Def":{"_prprn"},
"defalcator":{"_anim","_sb"},
"defamed":{"_past"},
"defamer":{"_anim","_sb"},
"defaulted":{"_past"},
"defaulter":{"_anim","_sb"},
"defaulters":{"_anim","_sb"},
"defeated":{"_loc_sr","_past"},
"defecate":{"_loc_sr"},
"defecated":{"_loc_sr","_past"},
"defecator":{"_anim","_sb"},
"defected":{"_past"},
"defendant":{"_anim","_sb"},
"defendants":{"_anim","_sb"},
"defended":{"_past"},
"defender":{"_anim","_sb"},
"defenders":{"_anim","_sb"},
"defenseman":{"_sb"},
"defensemen":{"_sb"},
"deferred":{"_past"},
"deferred-maintenance":{"_past"},
"defied":{"_past"},
"defiler":{"_anim","_sb"},
"defined":{"_past"},
"defined-benefit":{"_past"},
"defined-contribution":{"_past"},
"deflated":{"_past"},
"deflationist":{"_anim","_sb"},
"deflator":{"_anim","_sb"},
"deflators":{"_anim","_sb"},
"deflected":{"_past"},
"deflector":{"_anim","_sb"},
"defoe":{"_anim","_nme","_prprn","_sb"},
"defoliated":{"_past"},
"defoliator":{"_anim","_sb"},
"deformed":{"_past"},
"defrauded":{"_past"},
"defrauder":{"_anim","_sb"},
"defused":{"_past"},
"degassed":{"_past"},
"degenerate":{"_loc_sr"},
"deglycerolized":{"_past"},
"degrade":{"_loc_sr"},
"degraded":{"_loc_sr","_past"},
"degrader":{"_anim","_sb"},
"degrading":{"_loc_sr"},
"dehorn":{"_loc_sr"},
"dehumanised":{"_past"},
"dehumanized":{"_past"},
"dehumidified":{"_past"},
"dehydrated":{"_past"},
"deigned":{"_past"},
"deimos":{"_prprn"},
"deities":{"_anim","_sb"},
"deity":{"_anim","_sb"},
"deject":{"_psych"},
"dejected":{"_past","_psych"},
"dekker":{"_anim","_nme","_prprn","_sb"},
"del":{"_prprn","_stte"},
"Del.":{"_prprn","_stte"},
"delacroix":{"_anim","_nme","_prprn","_sb"},
"Delaunay":{"_anim","_nme","_prprn","_sb"},
"delaware":{"_cty","_geo","_prprn","_sb","_stte"},
"delayed":{"_past"},
"delayer":{"_loc_sr"},
"delbruck":{"_anim","_nme","_prprn","_sb"},
"delegate":{"_loc_sr"},
"delegated":{"_loc_sr","_past"},
"delegates":{"_anim","_sb"},
"delegating":{"_loc_sr"},
"delegation":{"_anim"},
"delegations":{"_anim"},
"deleted":{"_past"},
"Delgado":{"_anim","_nme","_prprn","_sb"},
"Delhi":{"_cty","_geo","_prprn"},
"Delia":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"deliberate":{"_loc_sr"},
"deliberated":{"_loc_sr","_past"},
"deliberating":{"_loc_sr"},
"delibes":{"_anim","_nme","_prprn","_sb"},
"delight":{"_psych"},
"delightful":{"_psych"},
"delighting":{"_psych"},
"delilah":{"_anim","_nme","_prprn","_sb"},
"delimited":{"_past"},
"delineated":{"_past"},
"delinquent":{"_anim","_sb"},
"delinquents":{"_anim","_sb"},
"delist":{"_loc_sr"},
"delisting":{"_loc_sr"},
"delius":{"_anim","_nme","_prprn","_sb"},
"delivered":{"_past"},
"deliverer":{"_anim","_sb"},
"deliverers":{"_anim","_sb"},
"deliveryman":{"_anim","_sb"},
"Deller":{"_anim","_sb"},
"delocalize":{"_loc_sr"},
"delorme":{"_anim","_nme","_prprn","_sb"},
"Delors":{"_prprn"},
"deloused":{"_past"},
"Delphi":{"_geo","_prprn"},
"delphinus":{"_prprn"},
"delude":{"_psych"},
"deluding":{"_psych"},
"delved":{"_past"},
"delver":{"_anim","_sb"},
"demagogue":{"_anim","_sb"},
"demagogues":{"_anim","_sb"},
"demanded":{"_past"},
"demarcated":{"_past"},
"demavend":{"_geo","_prprn"},
"demean":{"_loc_sr","_psych"},
"demeaned":{"_loc_sr","_past","_psych"},
"demeaning":{"_loc_sr","_psych"},
"demeans":{"_loc_sr","_psych"},
"demerol":{"_prprn"},
"demesne":{"_loc_sr"},
"demeter":{"_anim","_fem","_nme","_prprn","_sb"},
"demigod":{"_anim","_masc","_sb"},
"demijohn":{"_loc_sr"},
"demilitarize":{"_loc_sr"},
"demimondaine":{"_anim","_fem","_sb"},
"demimonde":{"_sb"},
"demobilized":{"_loc_sr","_past"},
"demobilizing":{"_loc_sr"},
"democrat":{"_anim","_sb"},
"democratise":{"_tme","_wh"},
"democratized":{"_past"},
"democritus":{"_anim","_nme","_prprn","_sb"},
"demodulate":{"_loc_sr"},
"demodulator":{"_anim","_sb"},
"demogorgon":{"_prprn"},
"demographer":{"_anim","_sb"},
"demographist":{"_anim","_sb"},
"demoiselle":{"_anim","_sb"},
"demolishing":{"_psych"},
"demon":{"_anim","_sb"},
"demon-ridden":{"_anim","_sb"},
"demonetized":{"_past"},
"demonized":{"_past"},
"demonologist":{"_anim","_sb"},
"demons":{"_anim","_sb"},
"demonstrated":{"_past"},
"demonstrator":{"_anim","_sb"},
"demonstrators":{"_anim","_sb"},
"demoralised":{"_past"},
"demoralize":{"_psych"},
"demoralized":{"_past","_psych"},
"demoralizes":{"_psych"},
"demoralizing":{"_psych"},
"demosthenes":{"_anim","_nme","_prprn","_sb"},
"demote":{"_loc_sr"},
"demoted":{"_loc_sr","_past"},
"dempsey":{"_anim","_nme","_prprn","_sb"},
"demurred":{"_past"},
"demythologised":{"_past"},
"den":{"_loc_sr"},
"Denali":{"_geo","_prprn"},
"denationalize":{"_loc_sr"},
"denationalized":{"_loc_sr","_past"},
"denatured":{"_past"},
"Dench":{"_prprn"},
"deneb":{"_prprn"},
"denebola":{"_prprn"},
"denied":{"_past"},
"denier":{"_anim","_sb"},
"Denis":{"_anim","_fnme","_nme","_prprn","_sb"},
"Denise":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"denizen":{"_anim","_sb"},
"denizens":{"_anim","_sb"},
"denmark":{"_cntry","_geo","_prprn"},
"Dennis":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"denominated":{"_past"},
"denounced":{"_past"},
"dented":{"_past"},
"dentist":{"_anim","_sb"},
"dentists":{"_anim","_sb"},
"Denton":{"_cty","_geo","_prprn"},
"dents":{"_loc_sr"},
"denuclearized":{"_past"},
"denuded":{"_past"},
"Denver":{"_cty","_geo","_prprn"},
"depart":{"_loc_sr"},
"departer":{"_anim","_sb"},
"departing":{"_loc_sr"},
"departmentalizing":{"_loc_sr"},
"departs":{"_loc_sr"},
"dependant":{"_anim","_sb"},
"depended":{"_past"},
"depersonalized":{"_past"},
"depict":{"_loc_sr"},
"depicted":{"_loc_sr","_past"},
"depicting":{"_loc_sr"},
"depicts":{"_loc_sr"},
"deplane":{"_loc_sr"},
"deplete":{"_loc_sr"},
"depleted":{"_loc_sr","_past"},
"depletes":{"_loc_sr"},
"deplored":{"_past"},
"deploy":{"_loc_sr"},
"deployed":{"_loc_sr","_past"},
"deploying":{"_loc_sr"},
"deponent":{"_anim","_sb"},
"deport":{"_loc_sr"},
"deported":{"_loc_sr","_past"},
"deportee":{"_anim","_sb"},
"deportees":{"_anim","_sb"},
"depose":{"_loc_sr"},
"deposer":{"_anim","_sb"},
"deposited":{"_loc_sr","_past"},
"depositing":{"_loc_sr"},
"Depp":{"_prprn"},
"depraved":{"_past"},
"depreciated":{"_past"},
"depress":{"_loc_sr","_psych"},
"depressed":{"_loc_sr","_past","_psych"},
"depresses":{"_loc_sr","_psych"},
"deprived":{"_past"},
"Dept":{"_prprn"},
"deputation":{"_anim","_sb"},
"deputies":{"_anim","_sb"},
"deputy":{"_anim","_sb"},
"derain":{"_anim","_nme","_prprn","_sb"},
"deregulate":{"_loc_sr"},
"deregulated":{"_loc_sr","_past"},
"deregulating":{"_loc_sr"},
"derided":{"_past"},
"derive":{"_loc_sr"},
"derived":{"_loc_sr","_past"},
"derives":{"_loc_sr"},
"deriving":{"_loc_sr"},
"dermatome":{"_loc_sr"},
"dervish":{"_anim","_sb"},
"dervish-like":{"_anim","_sb"},
"dervishes":{"_anim","_sb"},
"DES":{"_prprn"},
"Desai":{"_prprn"},
"descale":{"_loc_sr"},
"Descartes":{"_anim","_nme","_prprn","_sb"},
"descend":{"_loc_sr"},
"descendant":{"_anim","_sb"},
"descendants":{"_anim","_sb"},
"descended":{"_loc_sr","_past"},
"descending":{"_loc_sr"},
"descends":{"_loc_sr"},
"describe":{"_loc_sr"},
"described":{"_loc_sr","_past"},
"describes":{"_loc_sr"},
"describing":{"_loc_sr"},
"desecrated":{"_past"},
"desegregated":{"_past"},
"desensitized":{"_past"},
"desert":{"_loc_sr"},
"desert-battle":{"_loc_sr"},
"desert-bound":{"_loc_sr"},
"deserter":{"_anim","_sb"},
"deserts":{"_loc_sr"},
"deserved":{"_past"},
"desiccated":{"_past"},
"designed":{"_loc_sr","_past"},
"designees":{"_anim","_sb"},
"designer":{"_anim","_sb"},
"designers":{"_anim","_sb"},
"desirable":{"_sb"},
"desired":{"_past"},
"desisted":{"_past"},
"deskman":{"_anim","_masc","_sb"},
"Desmond":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"despaired":{"_past"},
"despatched":{"_past"},
"desperadoes":{"_anim","_sb"},
"despised":{"_past"},
"despoiled":{"_past"},
"despoiler":{"_anim","_sb"},
"despoilers":{"_anim","_sb"},
"despots":{"_anim","_sb"},
"Desprez":{"_prprn"},
"destination":{"_loc_sr"},
"destinations":{"_loc_sr"},
"destined":{"_past"},
"destroyers":{"_anim","_sb"},
"detached":{"_past"},
"detailed":{"_past"},
"detain":{"_loc_sr"},
"detained":{"_loc_sr","_past"},
"detainee":{"_anim","_sb"},
"detainees":{"_anim","_sb"},
"detected":{"_past"},
"detective":{"_anim","_sb"},
"detective-story":{"_anim","_sb"},
"detectives":{"_anim","_sb"},
"deter":{"_loc_sr"},
"deteriorate":{"_loc_sr"},
"determined":{"_past"},
"deterred":{"_loc_sr","_past"},
"deterring":{"_loc_sr"},
"detested":{"_past"},
"dethaw":{"_loc_sr","_wthr"},
"dethrone":{"_loc_sr"},
"detour":{"_loc_sr"},
"detoured":{"_loc_sr","_past"},
"detracted":{"_past"},
"detractor":{"_anim","_sb"},
"detractors":{"_anim","_sb"},
"detroit":{"_cty","_geo","_prprn"},
"deuced":{"_past"},
"Deus":{"_prprn"},
"deuterated":{"_past"},
"deuteronomy":{"_prprn"},
"Deutsch":{"_prprn"},
"devalued":{"_past"},
"devanagari":{"_prprn"},
"devastate":{"_psych"},
"devastated":{"_past","_psych"},
"devastating":{"_psych"},
"developed":{"_loc_sr","_past"},
"developer":{"_anim","_sb"},
"developers":{"_anim","_sb"},
"developing":{"_loc_sr"},
"developing-country":{"_loc_sr"},
"developing-nation":{"_loc_sr"},
"develops":{"_loc_sr"},
"Devereux":{"_anim","_nme","_prprn","_sb"},
"devi":{"_anim","_fem","_nme","_prprn","_sb"},
"deviant":{"_anim","_sb"},
"deviants":{"_anim","_sb"},
"deviate":{"_loc_sr"},
"deviated":{"_loc_sr","_past"},
"deviating":{"_loc_sr"},
"devil":{"_anim","_sb"},
"devil-worship":{"_anim","_sb"},
"devilfish":{"_anim"},
"devils":{"_anim","_sb"},
"devise":{"_loc_sr"},
"deviser":{"_anim","_sb"},
"devising":{"_loc_sr"},
"devolve":{"_loc_sr"},
"devon":{"_geo","_prprn"},
"devonian":{"_prprn"},
"Devonshire":{"_geo","_prprn"},
"devotees":{"_anim","_sb"},
"devoting":{"_psych"},
"devoured":{"_past"},
"devourer":{"_anim","_sb"},
"dew":{"_loc_sr"},
"dew-sodden":{"_loc_sr"},
"Dewar":{"_anim","_nme","_prprn","_sb"},
"dewars":{"_anim","_nme","_prprn","_sb"},
"dewey":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Dexedrine":{"_prprn"},
"dhaka":{"_geo","_prprn"},
"dhaulagiri":{"_geo","_prprn"},
"dhegiha":{"_prprn"},
"dhole":{"_anim"},
"Di":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"diabetic":{"_anim","_sb"},
"diabetics":{"_anim","_sb"},
"diabolist":{"_anim","_sb"},
"Diaghilev":{"_anim","_nme","_prprn","_sb"},
"diagnostician":{"_anim","_sb"},
"diagnosticians":{"_anim","_sb"},
"diagrammed":{"_past"},
"dial":{"_loc_sr"},
"dialectician":{"_anim","_sb"},
"dialed":{"_loc_sr","_past"},
"dialing":{"_loc_sr"},
"dialyzed":{"_past"},
"Dian":{"_prprn"},
"diana":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Diane":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"diarist":{"_anim","_sb"},
"Dias":{"_anim","_nme","_prprn","_sb"},
"diaz":{"_anim","_nme","_prprn","_sb"},
"dibranchiate":{"_sb"},
"DiCaprio":{"_prprn"},
"dice":{"_anim"},
"diced":{"_past"},
"dichotomize":{"_loc_sr"},
"Dickens":{"_anim","_prprn","_sb"},
"dickered":{"_past"},
"dickinson":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"dickybird":{"_anim"},
"dictaphone":{"_prprn"},
"dictated":{"_past"},
"dictator":{"_anim","_sb"},
"dictators":{"_anim","_sb"},
"did":{"_past"},
"diderot":{"_anim","_nme","_prprn","_sb"},
"didrikson":{"_anim","_nme","_prprn","_sb"},
"die-hards":{"_anim","_sb"},
"died":{"_past"},
"diehard":{"_anim","_sb"},
"diehards":{"_anim","_sb"},
"diem":{"_anim","_nme","_prprn","_sb"},
"Dieppe":{"_cty","_geo","_prprn"},
"dieter":{"_anim","_sb"},
"dieters":{"_anim","_sb"},
"dietician":{"_anim","_sb"},
"dietitian":{"_anim","_sb"},
"Dietrich":{"_anim","_nme","_prprn","_sb"},
"differentiator":{"_anim","_sb"},
"diffused":{"_past"},
"dig":{"_loc_sr"},
"digest":{"_loc_sr"},
"digested":{"_loc_sr","_past"},
"digesting":{"_loc_sr"},
"digging":{"_loc_sr"},
"dighted":{"_past"},
"digitalize":{"_loc_sr"},
"digitalized":{"_loc_sr","_past"},
"digitiser":{"_anim","_sb"},
"digitized":{"_past"},
"digitizer":{"_anim","_sb"},
"dignified":{"_past"},
"dignitaries":{"_anim","_sb"},
"dignitary":{"_anim","_sb"},
"Dijon":{"_cty","_geo","_prprn"},
"dik-dik":{"_anim"},
"Dilantin":{"_prprn"},
"dilapidate":{"_loc_sr"},
"dilater":{"_anim","_sb"},
"dilettante":{"_anim","_sb"},
"Dili":{"_prprn"},
"Dillinger":{"_anim","_nme","_prprn","_sb"},
"dilly-dallier":{"_anim","_sb"},
"dilly-dally":{"_loc_sr"},
"dillydallier":{"_anim","_sb"},
"Dilthey":{"_prprn"},
"diluted":{"_past"},
"DiMaggio":{"_anim","_nme","_prprn","_sb"},
"diminished":{"_past"},
"dimmed":{"_past"},
"dimwit":{"_anim","_sb"},
"dimwits":{"_anim","_sb"},
"dined":{"_past"},
"diner":{"_anim","_sb"},
"diners":{"_anim","_sb"},
"Dinesen":{"_anim","_nme","_prprn","_sb"},
"dingbat":{"_anim","_sb"},
"dinner":{"_tme"},
"dinner-hour":{"_tme"},
"dinners":{"_tme"},
"dinosaur":{"_anim"},
"diocese":{"_loc_sr"},
"dioceses":{"_loc_sr"},
"diocletian":{"_anim","_nme","_prprn","_sb"},
"Dion":{"_prprn"},
"dionysia":{"_prprn"},
"dionysius":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Dionysus":{"_anim","_masc","_nme","_prprn","_sb"},
"dior":{"_anim","_nme","_prprn","_sb"},
"dip":{"_loc_sr"},
"diplomat":{"_anim","_sb"},
"diplomate":{"_anim","_sb"},
"diplomatist":{"_anim","_sb"},
"diplomats":{"_anim","_sb"},
"dipped":{"_loc_sr","_past"},
"dippers":{"_loc_sr"},
"dipsomaniac":{"_anim","_sb"},
"dirac":{"_anim","_nme","_prprn","_sb"},
"directed":{"_past"},
"director":{"_anim","_sb"},
"director-general":{"_anim","_sb"},
"directors":{"_anim","_sb"},
"disabled":{"_anim","_sb"},
"disabled-workers":{"_anim","_sb"},
"disabused":{"_loc_sr","_past"},
"disadvantaged":{"_anim","_sb"},
"disaffect":{"_psych"},
"disaffected":{"_past","_psych"},
"disaffiliate":{"_loc_sr"},
"disaffiliated":{"_loc_sr","_past"},
"disagreed":{"_past"},
"disallowed":{"_past"},
"disambiguator":{"_anim","_sb"},
"disappear":{"_loc_sr"},
"disappeared":{"_loc_sr","_past"},
"disappearing":{"_loc_sr"},
"disappears":{"_loc_sr"},
"disappoint":{"_psych"},
"disappointed":{"_past","_psych"},
"disappointing":{"_psych"},
"disappoints":{"_psych"},
"disapproved":{"_past"},
"disarm":{"_psych"},
"disarmed":{"_past","_psych"},
"disarmer":{"_anim","_sb"},
"disarming":{"_psych"},
"disarrayed":{"_loc_sr","_past"},
"disassembled":{"_past"},
"disassociate":{"_loc_sr"},
"disassociated":{"_loc_sr","_past"},
"disavowed":{"_past"},
"disbanded":{"_past"},
"disbar":{"_loc_sr"},
"disbelieved":{"_past"},
"disbeliever":{"_anim","_sb"},
"disburse":{"_loc_sr"},
"disbursed":{"_loc_sr","_past"},
"disburser":{"_anim","_sb"},
"disburses":{"_loc_sr"},
"discarded":{"_past"},
"discerned":{"_past"},
"discharge":{"_loc_sr"},
"discharged":{"_loc_sr","_past"},
"discharging":{"_loc_sr"},
"disciple":{"_anim","_sb"},
"disciples":{"_anim","_sb"},
"disciplinarian":{"_anim","_sb"},
"disclaimed":{"_past"},
"disclosed":{"_past"},
"discolored":{"_past"},
"discombobulate":{"_loc_sr","_psych"},
"discombobulated":{"_loc_sr","_past","_psych"},
"discompose":{"_psych"},
"discomposed":{"_past","_psych"},
"disconcert":{"_psych"},
"disconcerted":{"_past","_psych"},
"disconcerting":{"_psych"},
"disconnected":{"_past"},
"discontented":{"_past"},
"discontinued":{"_past"},
"discounters":{"_anim","_sb"},
"discounting":{"_loc_sr"},
"discouraged":{"_past","_psych"},
"discourages":{"_psych"},
"discovered":{"_loc_sr","_past"},
"discovering":{"_loc_sr"},
"discovers":{"_loc_sr"},
"discredit":{"_loc_sr"},
"discrediting":{"_loc_sr"},
"discriminated":{"_past"},
"discuss":{"_loc_sr"},
"discussed":{"_loc_sr","_past"},
"discusses":{"_loc_sr"},
"discussing":{"_loc_sr"},
"disdained":{"_past"},
"disembark":{"_loc_sr"},
"disembarked":{"_loc_sr","_past"},
"disembarking":{"_loc_sr"},
"disembodied":{"_loc_sr","_past"},
"disembody":{"_loc_sr"},
"disembroil":{"_loc_sr"},
"disenchant":{"_loc_sr"},
"disenchanted":{"_loc_sr","_past"},
"disenchanting":{"_loc_sr"},
"disenfranchised":{"_past"},
"disengaged":{"_past"},
"disentangle":{"_loc_sr"},
"disentangled":{"_loc_sr","_past"},
"disentangler":{"_anim","_sb"},
"disentangling":{"_loc_sr"},
"disesteem":{"_loc_sr"},
"disfavored":{"_past"},
"disfigured":{"_past"},
"disfranchised":{"_past"},
"disgraced":{"_past","_psych"},
"disguised":{"_past"},
"disgusted":{"_past","_psych"},
"disgusting":{"_psych"},
"dish-shaped":{"_loc_sr"},
"dishearten":{"_psych"},
"disheartened":{"_past","_psych"},
"disheartening":{"_psych"},
"dished":{"_past"},
"dishes":{"_loc_sr"},
"disheveled":{"_past"},
"dishonored":{"_past"},
"dishonour":{"_sb"},
"dishwasher":{"_anim","_sb"},
"dishwashers":{"_anim","_sb"},
"dishwater":{"_loc_sr"},
"disillusion":{"_loc_sr","_psych"},
"disillusioned":{"_loc_sr","_past","_psych"},
"disillusioning":{"_loc_sr","_psych"},
"disincarnate":{"_loc_sr"},
"disinclined":{"_past"},
"disinfected":{"_past"},
"disinfest":{"_loc_sr"},
"disinherit":{"_loc_sr"},
"disinherited":{"_loc_sr","_past"},
"disintegrated":{"_past"},
"disinter":{"_loc_sr"},
"disinterested":{"_past","_psych"},
"disinterred":{"_loc_sr","_past"},
"disinvolve":{"_psych"},
"disjoined":{"_past"},
"disjointed":{"_past"},
"disliked":{"_past"},
"dislocated":{"_past"},
"dislodged":{"_past"},
"dismantled":{"_past"},
"dismayed":{"_past","_psych"},
"dismaying":{"_psych"},
"dismember":{"_loc_sr"},
"dismembered":{"_loc_sr","_past"},
"dismembering":{"_loc_sr"},
"dismiss":{"_loc_sr"},
"dismissed":{"_loc_sr","_past"},
"dismisses":{"_loc_sr"},
"dismissing":{"_loc_sr"},
"dismounted":{"_past"},
"disney":{"_anim","_nme","_prprn","_sb"},
"disneyland":{"_geo","_prprn"},
"disoblige":{"_loc_sr"},
"disobliging":{"_loc_sr"},
"disorganised":{"_past"},
"disorganize":{"_loc_sr"},
"disorganized":{"_loc_sr","_past"},
"disoriented":{"_past"},
"disowned":{"_past"},
"disparaged":{"_past"},
"disparager":{"_anim","_sb"},
"dispatched":{"_loc_sr","_past"},
"dispatcher":{"_anim","_sb"},
"dispatchers":{"_anim","_sb"},
"dispatching":{"_loc_sr"},
"dispensary":{"_loc_sr"},
"dispensed":{"_past"},
"dispensers":{"_anim","_sb"},
"disperse":{"_loc_sr"},
"dispersing":{"_loc_sr"},
"dispirit":{"_loc_sr","_psych"},
"dispirited":{"_loc_sr","_past","_psych"},
"dispiriting":{"_loc_sr","_psych"},
"displacing":{"_loc_sr"},
"displayed":{"_past"},
"displease":{"_psych"},
"displeasing":{"_psych"},
"dispose":{"_loc_sr"},
"disposing":{"_loc_sr"},
"disprover":{"_anim","_sb"},
"disputant":{"_anim","_sb"},
"disqualified":{"_past"},
"disquiet":{"_psych"},
"disquieted":{"_past","_psych"},
"disquieting":{"_psych"},
"Disraeli":{"_anim","_nme","_prprn","_sb"},
"disrupt":{"_loc_sr"},
"disrupted":{"_loc_sr","_past"},
"disrupting":{"_loc_sr"},
"disrupts":{"_loc_sr"},
"dissatisfied":{"_past","_psych"},
"dissatisfy":{"_psych"},
"dissect":{"_loc_sr"},
"dissecting":{"_loc_sr"},
"disseminated":{"_past"},
"disseminator":{"_anim","_sb"},
"dissenters":{"_anim","_sb"},
"dissenting":{"_loc_sr"},
"dissident":{"_anim","_sb"},
"dissident-shareholder":{"_anim","_sb"},
"dissidents":{"_anim","_sb"},
"dissimulator":{"_anim","_sb"},
"dissipated":{"_past"},
"dissociated":{"_loc_sr","_past"},
"dissociates":{"_loc_sr"},
"dissociating":{"_loc_sr"},
"dissolve":{"_loc_sr"},
"dissolver":{"_anim","_sb"},
"dissolves":{"_loc_sr"},
"dissuade":{"_loc_sr"},
"dissuaded":{"_loc_sr","_past"},
"distance":{"_loc_sr"},
"distilled":{"_past"},
"distiller":{"_anim","_sb"},
"distillers":{"_anim","_sb"},
"distinguished":{"_past"},
"distortionist":{"_anim","_sb"},
"distract":{"_psych"},
"distracted":{"_past","_psych"},
"distracting":{"_psych"},
"distressed":{"_past","_psych"},
"distressing":{"_psych"},
"distribute":{"_loc_sr"},
"distributes":{"_loc_sr"},
"distributing":{"_loc_sr"},
"distributor":{"_sb"},
"distributors":{"_sb"},
"district":{"_loc_sr"},
"district-by-district":{"_loc_sr"},
"district-court":{"_loc_sr"},
"districts":{"_loc_sr"},
"distrusted":{"_past"},
"disturbing":{"_psych"},
"disturbs":{"_psych"},
"disunited":{"_past"},
"ditcher":{"_anim","_sb"},
"Ditmars":{"_anim","_nme","_prprn","_sb"},
"divagate":{"_loc_sr"},
"dive":{"_loc_sr"},
"dive-bomb":{"_loc_sr"},
"dive-bombing":{"_loc_sr"},
"dived":{"_loc_sr","_past"},
"diverge":{"_loc_sr"},
"diverging":{"_loc_sr"},
"divers":{"_anim","_sb"},
"diversified":{"_past"},
"divested":{"_past"},
"divide":{"_loc_sr"},
"divided":{"_loc_sr","_past"},
"divides":{"_loc_sr"},
"dividing":{"_loc_sr"},
"diviner":{"_anim","_sb"},
"diving":{"_loc_sr"},
"divorced":{"_past"},
"divvied":{"_past"},
"dix":{"_anim","_nme","_prprn","_sb"},
"Dixie":{"_geo","_prprn"},
"Dixiecrat":{"_prprn","_sb"},
"Dixieland":{"_prprn"},
"Dixon":{"_cty","_geo","_prprn"},
"Djakarta":{"_geo","_prprn"},
"Django":{"_prprn"},
"djibouti":{"_cntry","_cty","_geo","_prprn"},
"dmz":{"_prprn"},
"dna":{"_prprn"},
"dneprodzerzhinsk":{"_cty","_geo","_prprn"},
"Dnieper":{"_geo","_prprn"},
"do-gooder":{"_anim","_sb"},
"do-gooders":{"_anim","_sb"},
"do-nothing":{"_sb"},
"dobbin":{"_anim"},
"Doberman":{"_prprn"},
"docent":{"_anim","_sb"},
"docetism":{"_prprn"},
"Docherty":{"_prprn"},
"dock-siders":{"_loc_sr"},
"dock-walloper":{"_loc_sr"},
"docked":{"_past"},
"docker":{"_anim","_sb"},
"docketed":{"_past"},
"dockside":{"_loc_sr"},
"dockyard":{"_loc_sr"},
"dockyards":{"_loc_sr"},
"doctor":{"_anim","_sb"},
"doctor-fish":{"_anim","_sb"},
"doctor-oriented":{"_anim","_sb"},
"doctor-originated":{"_anim","_sb"},
"doctor-patient":{"_anim","_sb"},
"doctored":{"_past"},
"doctorow":{"_anim","_nme","_prprn","_sb"},
"doctors":{"_anim","_sb"},
"doctrinaire":{"_anim","_sb"},
"documented":{"_past"},
"DOD":{"_prprn"},
"Dodd":{"_prprn"},
"dodecanese":{"_geo","_prprn"},
"dodge":{"_loc_sr"},
"dodged":{"_loc_sr","_past"},
"dodger":{"_anim","_sb"},
"dodging":{"_loc_sr"},
"dodgson":{"_anim","_nme","_prprn","_sb"},
"dodo":{"_anim"},
"Dodoma":{"_cty","_geo","_prprn"},
"doe":{"_anim"},
"doer":{"_anim","_sb"},
"doers":{"_anim","_sb"},
"dog":{"_anim"},
"dog-and-pony":{"_anim"},
"dog-iron":{"_anim"},
"dog-meat":{"_anim"},
"dog-pin":{"_anim"},
"dog-powered":{"_anim"},
"dog-rose":{"_anim"},
"dog-sized":{"_anim"},
"dogcatcher":{"_anim","_sb"},
"doge":{"_anim","_sb"},
"dogfighter":{"_anim","_sb"},
"doggy":{"_anim"},
"dogie":{"_anim"},
"dogmatist":{"_anim","_sb"},
"dogs":{"_anim"},
"dogsbody":{"_anim","_sb"},
"Doha":{"_cty","_geo","_prprn"},
"DOJ":{"_prprn"},
"Dolby":{"_prprn"},
"doldrums":{"_loc_sr"},
"doled":{"_past"},
"dollies":{"_sb"},
"dolly":{"_sb"},
"Dolores":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"dolphin":{"_anim"},
"Dom":{"_prprn"},
"domain":{"_loc_sr"},
"domains":{"_loc_sr"},
"domestic":{"_anim","_sb"},
"domestic-airline":{"_anim","_sb"},
"domestic-credit":{"_anim","_sb"},
"domestic-demand":{"_anim","_sb"},
"domestic-inflation":{"_anim","_sb"},
"domestic-made":{"_anim","_sb"},
"domestic-policy":{"_anim","_sb"},
"domestic-production":{"_anim","_sb"},
"domicile":{"_loc_sr"},
"dominated":{"_past"},
"dominatrix":{"_anim","_fem","_sb"},
"dominee":{"_anim","_sb"},
"Domingo":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"dominic":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Dominica":{"_cntry","_geo","_prprn"},
"Dominican":{"_anim","_prprn","_sb"},
"dominick":{"_prprn"},
"dominique":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Domino":{"_anim","_prprn","_sb"},
"Dominus":{"_prprn"},
"Domitian":{"_anim","_nme","_prprn","_sb"},
"don":{"_loc_sr"},
"Dona":{"_prprn"},
"Donald":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Donatello":{"_anim","_nme","_prprn","_sb"},
"donatism":{"_prprn"},
"donatist":{"_prprn","_sb"},
"Donbas":{"_geo","_prprn"},
"donetsk":{"_cty","_geo","_prprn"},
"donizetti":{"_anim","_nme","_prprn","_sb"},
"donkey":{"_anim"},
"donkeys":{"_anim"},
"donna":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Donne":{"_anim","_nme","_prprn","_sb"},
"donned":{"_loc_sr","_past"},
"Donnelly":{"_anim","_nme","_prprn","_sb"},
"donning":{"_loc_sr"},
"donor":{"_anim","_sb"},
"donors":{"_anim","_sb"},
"dons":{"_anim","_sb"},
"Doolittle":{"_anim","_nme","_prprn","_sb"},
"doomed":{"_past"},
"doomsayer":{"_anim","_sb"},
"doomsayers":{"_anim","_sb"},
"Doonesbury":{"_prprn"},
"doormen":{"_anim","_masc","_sb"},
"Doppler":{"_anim","_nme","_prprn","_sb"},
"Dora":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Dorado":{"_prprn"},
"dorbeetle":{"_anim"},
"Dorcas":{"_prprn"},
"Dorchester":{"_geo","_prprn"},
"Dorian":{"_prprn","_sb"},
"Doric":{"_prprn"},
"Doris":{"_anim","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"dormitories":{"_loc_sr"},
"dormouse":{"_anim"},
"Dorothy":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Dorset":{"_anim","_geo","_nme","_prprn","_sb"},
"Dort":{"_geo","_prprn"},
"Dortmund":{"_cty","_geo","_prprn"},
"dosed":{"_past"},
"doss":{"_loc_sr"},
"dosser":{"_anim","_sb"},
"dostoevski":{"_prprn"},
"Dostoevsky":{"_prprn"},
"Dostoyevsky":{"_anim","_nme","_prprn","_sb"},
"dotard":{"_anim","_sb"},
"doted":{"_past"},
"douala":{"_cty","_geo","_prprn"},
"double-crossed":{"_past"},
"double-crosser":{"_anim","_sb"},
"double-dealer":{"_anim","_sb"},
"double-glazed":{"_past"},
"double-spaced":{"_past"},
"double-tongued":{"_loc_sr","_past"},
"doubled":{"_past"},
"doubled-edged":{"_past"},
"doubted":{"_past"},
"doubters":{"_anim","_sb"},
"doubtless":{"_probabl"},
"Douglas":{"_anim","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"Douglass":{"_anim","_nme","_prprn","_sb"},
"douse":{"_loc_sr"},
"doused":{"_loc_sr","_past"},
"dousing":{"_loc_sr"},
"dove":{"_anim"},
"Dover":{"_cty","_geo","_prprn"},
"doves":{"_anim"},
"Dow":{"_anim","_nme","_prprn","_sb"},
"dowager":{"_anim","_fem","_sb"},
"dowdy":{"_sb"},
"dowdy-looking":{"_sb"},
"dowered":{"_past"},
"down-and-out":{"_anim","_sb"},
"down-and-outs":{"_anim","_sb"},
"downed":{"_past"},
"Downey":{"_cty","_geo","_prprn"},
"downgraded":{"_loc_sr","_past"},
"downgrading":{"_loc_sr"},
"downloaded":{"_past"},
"downs":{"_loc_sr"},
"downscale":{"_loc_sr"},
"downshift":{"_loc_sr"},
"downsized":{"_loc_sr","_past"},
"downsizing":{"_loc_sr"},
"downwards":{"_loc"},
"downwind":{"_loc"},
"dowser":{"_anim","_sb"},
"dowsing":{"_loc_sr"},
"doxy":{"_sb"},
"doyen":{"_anim","_masc","_sb"},
"doyenne":{"_anim","_fem","_sb"},
"Doyle":{"_anim","_nme","_prprn","_sb"},
"dozed":{"_past"},
"dozen":{"_num","_quant"},
"dozens":{"_num"},
"dp":{"_prprn"},
"Dr":{"_anim","_prprn","_sb"},
"Dr.":{"_anim","_prprn","_sb"},
"drab-haired":{"_anim","_fem","_sb"},
"Draco":{"_anim","_nme","_prprn","_sb"},
"Dracula":{"_prprn"},
"drafted":{"_loc_sr","_past"},
"draftees":{"_anim","_sb"},
"drafter":{"_anim","_sb"},
"drafters":{"_anim","_sb"},
"drafting":{"_loc_sr"},
"draftsman":{"_anim","_masc","_sb"},
"draftsmen":{"_anim","_masc","_sb"},
"draggled":{"_past"},
"dragoman":{"_anim","_sb"},
"dragon":{"_anim"},
"dragonfly":{"_anim"},
"dragons":{"_anim"},
"dragooned":{"_past"},
"drain":{"_psych"},
"drake":{"_anim","_masc"},
"dramamine":{"_prprn"},
"dramatist":{"_anim","_sb"},
"dramatists":{"_anim","_sb"},
"dramatized":{"_past"},
"Drambuie":{"_prprn"},
"drank":{"_loc_sr","_past"},
"draped":{"_past"},
"drapers":{"_anim","_sb"},
"draughtsman":{"_anim","_sb"},
"dravidian":{"_prprn"},
"draw":{"_loc_sr"},
"drawer":{"_anim","_sb"},
"drawers":{"_anim","_sb"},
"drawled":{"_past"},
"drawler":{"_anim","_sb"},
"drawn":{"_loc_sr"},
"drawn-back":{"_loc_sr"},
"dreaded":{"_past"},
"dreamed":{"_loc_sr","_past"},
"dreamer":{"_anim","_sb"},
"dreamers":{"_anim","_sb"},
"dreamin":{"_loc_sr"},
"dreamland":{"_loc_sr"},
"dreamt":{"_loc_sr","_past"},
"Dreiser":{"_anim","_nme","_prprn","_sb"},
"Dresden":{"_cty","_geo","_prprn"},
"dressed":{"_loc_sr","_past"},
"dressed-up":{"_loc_sr","_past"},
"dressing":{"_loc_sr"},
"dressings":{"_sb"},
"dressmaker":{"_anim","_sb"},
"drew":{"_loc_sr","_past"},
"dreyfus":{"_anim","_nme","_prprn","_sb"},
"dribble":{"_loc_sr"},
"dribbled":{"_loc_sr","_past"},
"dribbler":{"_anim","_sb"},
"dribbling":{"_loc_sr"},
"dried":{"_past"},
"dried-out":{"_past"},
"drifted":{"_past"},
"drifter":{"_anim","_sb"},
"drilled":{"_past"},
"drillers":{"_anim","_sb"},
"drink":{"_loc_sr"},
"drinkers":{"_anim","_sb"},
"drinking":{"_loc_sr"},
"drinking-water":{"_loc_sr"},
"drip":{"_loc_sr"},
"dripped":{"_loc_sr","_past"},
"dripping":{"_loc_sr"},
"driver":{"_anim","_sb"},
"drivers":{"_anim","_sb"},
"driveway":{"_loc_sr"},
"driveways":{"_loc_sr"},
"drizzle":{"_loc_sr","_wthr"},
"drizzling":{"_loc_sr","_wthr"},
"Drobny":{"_prprn"},
"drogheda":{"_geo","_prprn"},
"dromedary":{"_anim"},
"drones":{"_anim","_masc"},
"drooling":{"_loc_sr"},
"drooped":{"_past"},
"drop":{"_loc_sr"},
"drop-in":{"_anim","_sb"},
"dropkicker":{"_anim","_sb"},
"dropout":{"_anim","_sb"},
"dropouts":{"_anim","_sb"},
"dropped":{"_loc_sr","_past"},
"droppers":{"_anim","_sb"},
"dropping":{"_loc_sr"},
"drove":{"_past"},
"drovers":{"_anim","_sb"},
"drowned":{"_past"},
"drowse":{"_loc_sr"},
"drowsed":{"_loc_sr","_past"},
"drowsing":{"_loc_sr"},
"drugged":{"_past"},
"druggers":{"_anim","_sb"},
"druggies":{"_anim","_sb"},
"druggists":{"_anim","_sb"},
"druid":{"_anim","_sb"},
"drumbeater":{"_anim","_sb"},
"drummed":{"_past"},
"drummer":{"_anim","_sb"},
"drummers":{"_anim","_sb"},
"drunk-and-disorderlies":{"_anim","_sb"},
"drunk-and-disorderly":{"_anim","_sb"},
"drunk-driving":{"_anim","_sb"},
"drunkard":{"_anim","_sb"},
"drunkards":{"_anim","_sb"},
"drunken":{"_loc_sr"},
"drunks":{"_anim","_sb"},
"Druze":{"_anim","_prprn","_sb"},
"dry-cleaned":{"_past"},
"dryad":{"_anim","_sb"},
"Dryden":{"_anim","_nme","_prprn","_sb"},
"dryer":{"_anim","_sb"},
"Drysdale":{"_prprn"},
"dub":{"_loc_sr"},
"Dubai":{"_cty","_geo","_prprn"},
"dubbed":{"_loc_sr","_past"},
"dubbing":{"_loc_sr"},
"Dublin":{"_cty","_geo","_prprn"},
"Dubois":{"_anim","_nme","_prprn","_sb"},
"dubonnet":{"_prprn"},
"dubrovnik":{"_cty","_geo","_prprn"},
"dubs":{"_sb"},
"dubuque":{"_cty","_geo","_prprn"},
"Dubya":{"_prprn"},
"Duchamp":{"_anim","_nme","_prprn","_sb"},
"duchess":{"_anim","_fem","_sb"},
"duchy":{"_loc_sr"},
"duck-billed":{"_anim"},
"ducked":{"_past"},
"duckling":{"_anim"},
"ducklings":{"_anim"},
"ducks":{"_anim"},
"ducky":{"_anim","_sb"},
"duct":{"_loc_sr"},
"dud":{"_sb"},
"dude":{"_anim","_masc","_sb"},
"Dudley":{"_anim","_geo","_nme","_prprn","_sb"},
"duds":{"_sb"},
"dueled":{"_past"},
"dueler":{"_anim","_sb"},
"dueller":{"_anim","_sb"},
"duellist":{"_anim","_sb"},
"Duero":{"_geo","_prprn"},
"duffers":{"_anim","_sb"},
"Duffy":{"_anim","_nme","_prprn","_sb"},
"Dufy":{"_anim","_nme","_prprn","_sb"},
"dug":{"_loc_sr","_past"},
"dugong":{"_anim"},
"dullard":{"_anim","_sb"},
"Dulles":{"_anim","_nme","_prprn","_sb"},
"duluth":{"_cty","_geo","_prprn"},
"dumbfound":{"_psych"},
"dumbfounding":{"_psych"},
"dummied":{"_past"},
"dump":{"_loc_sr"},
"dumped":{"_loc_sr","_past"},
"dumping":{"_loc_sr"},
"dumps":{"_loc_sr"},
"dumpster":{"_loc_sr"},
"dumpsters":{"_anim","_sb"},
"dun-colored":{"_anim","_sb"},
"dun-coloured":{"_anim","_sb"},
"Dunbar":{"_anim","_geo","_nme","_prprn","_sb"},
"Duncan":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"dunce":{"_anim","_sb"},
"Dundee":{"_geo","_prprn"},
"dunderhead":{"_anim","_sb"},
"dune":{"_loc_sr"},
"dune-grass":{"_loc_sr"},
"dunes":{"_loc_sr"},
"dunk":{"_loc_sr"},
"dunkard":{"_prprn"},
"dunked":{"_loc_sr","_past"},
"Dunker":{"_anim","_sb"},
"dunkerque":{"_prprn"},
"dunkers":{"_anim","_sb"},
"Dunkirk":{"_cty","_geo","_prprn"},
"Dunlop":{"_anim","_nme","_prprn","_sb"},
"dupe":{"_anim","_sb"},
"duped":{"_past"},
"dupes":{"_anim","_sb"},
"duplicated":{"_past"},
"Durango":{"_cty","_geo","_prprn","_stte"},
"durant":{"_anim","_nme","_prprn","_sb"},
"Durante":{"_anim","_nme","_prprn","_sb"},
"duration":{"_tme"},
"durations":{"_tme"},
"durban":{"_cty","_geo","_prprn"},
"Durer":{"_anim","_nme","_prprn","_sb"},
"Durham":{"_cty","_geo","_prprn"},
"during":{"_tme"},
"Durkheim":{"_anim","_nme","_prprn","_sb"},
"durrell":{"_anim","_nme","_prprn","_sb"},
"durres":{"_cty","_geo","_prprn"},
"Duse":{"_anim","_nme","_prprn","_sb"},
"Dushanbe":{"_cty","_geo","_prprn"},
"dusk":{"_tme"},
"dusseldorf":{"_cty","_geo","_prprn"},
"dustbin":{"_loc_sr"},
"dustbowl":{"_loc_sr"},
"dusted":{"_loc_sr","_past"},
"dusting":{"_loc_sr"},
"dustman":{"_anim","_sb"},
"Dutchman":{"_anim","_masc","_prprn","_sb"},
"Dutton":{"_prprn"},
"Duvalier":{"_anim","_nme","_prprn","_sb"},
"DVD":{"_prprn"},
"DVDs":{"_prprn"},
"Dvorak":{"_anim","_nme","_prprn","_sb"},
"dwarfed":{"_past"},
"dwarfs":{"_anim","_sb"},
"Dwayne":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"dweeb":{"_sb"},
"dwelled":{"_past"},
"dwellings":{"_loc_sr"},
"dwelt":{"_past"},
"Dwight":{"_anim","_nme","_prprn","_sb"},
"dwindled":{"_past"},
"dy":{"_prprn"},
"dye":{"_loc_sr"},
"dyed":{"_loc_sr","_past"},
"dyeing":{"_loc_sr"},
"dykes":{"_anim","_fem","_sb"},
"Dylan":{"_anim","_fnme","_nme","_prprn","_sb"},
"dynamited":{"_past"},
"dynamiter":{"_anim","_sb"},
"dynamitist":{"_anim","_sb"},
"dyslexic":{"_anim","_sb"},
"Dyson":{"_prprn"},
"dyspeptic":{"_anim","_sb"},
"dystopias":{"_loc_sr"},
"e-mailed":{"_past"},
"each":{"_quant"},
"eagle":{"_anim"},
"eaglet":{"_anim"},
"Earhart":{"_anim","_nme","_prprn","_sb"},
"earl":{"_anim","_masc","_sb"},
"earless":{"_anim","_fem","_sb"},
"earlier":{"_tme"},
"earlier-announced":{"_tme"},
"earlier-expressed":{"_tme"},
"earlier-period":{"_tme"},
"earlier-reported":{"_tme"},
"earlier-than-expected":{"_tme"},
"earlier-the":{"_tme"},
"earliest":{"_tme"},
"early-blooming":{"_tme"},
"early-childhood":{"_tme"},
"early-departure":{"_tme"},
"early-flowering":{"_tme"},
"early-retirement":{"_tme"},
"early-season":{"_tme"},
"early-warning":{"_tme"},
"earmarked":{"_past"},
"earned":{"_past"},
"earned-income":{"_past"},
"earned-run":{"_past"},
"Earp":{"_anim","_nme","_prprn","_sb"},
"earthling":{"_anim","_sb"},
"earthlings":{"_anim","_sb"},
"earthwork":{"_loc_sr"},
"earthworms":{"_anim"},
"ease":{"_loc_sr"},
"eased":{"_loc_sr","_past"},
"easing":{"_loc_sr"},
"East":{"_prprn"},
"Easter":{"_prprn","_tme"},
"easterner":{"_anim","_sb"},
"eastertide":{"_prprn"},
"Eastman":{"_anim","_nme","_prprn","_sb"},
"Easton":{"_cty","_geo","_prprn"},
"Eastwood":{"_prprn"},
"eaten":{"_loc_sr"},
"eater":{"_anim","_sb"},
"eaters":{"_anim","_sb"},
"eating":{"_loc_sr"},
"Eaton":{"_anim","_nme","_prprn","_sb"},
"eats":{"_loc_sr"},
"eavesdropper":{"_anim","_sb"},
"ebbed":{"_loc_sr","_past"},
"ebbing":{"_loc_sr"},
"Ebert":{"_anim","_nme","_prprn","_sb"},
"eblis":{"_prprn"},
"ebn":{"_prprn"},
"Ebola":{"_prprn"},
"ebro":{"_geo","_prprn"},
"ebs":{"_prprn"},
"ebv":{"_prprn"},
"eccentrics":{"_anim","_sb"},
"Eccles":{"_anim","_nme","_prprn","_sb"},
"Ecclesiastes":{"_prprn"},
"ecclesiastic":{"_anim","_sb"},
"ecclesiasticus":{"_prprn"},
"ECG":{"_prprn"},
"echidna":{"_anim"},
"echoed":{"_past"},
"eck":{"_anim","_nme","_prprn","_sb"},
"eckhart":{"_anim","_nme","_prprn","_sb"},
"eclectic":{"_anim","_sb"},
"eclecticist":{"_anim","_sb"},
"eclipsed":{"_past"},
"ecm":{"_prprn"},
"econometrician":{"_anim","_sb"},
"economiser":{"_anim","_sb"},
"economist":{"_anim","_sb"},
"economists":{"_anim","_sb"},
"economizer":{"_anim","_sb"},
"ect":{"_prprn"},
"ectomorph":{"_anim","_sb"},
"Ecuador":{"_cntry","_geo","_prprn"},
"Ecuadorian":{"_anim","_prprn","_sb"},
"ecumenicists":{"_anim","_sb"},
"ecumenist":{"_anim","_sb"},
"ecumenists":{"_anim","_sb"},
"ed":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Ed.":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Edam":{"_cty","_geo","_prprn"},
"edda":{"_prprn"},
"Eddie":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Eddington":{"_anim","_nme","_prprn","_sb"},
"eddy":{"_loc_sr"},
"Ede":{"_cty","_geo","_prprn"},
"Edelman":{"_anim","_nme","_prprn","_sb"},
"Eden":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"edentate":{"_sb"},
"ederle":{"_anim","_nme","_prprn","_sb"},
"Edgar":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"edgewise":{"_loc"},
"edified":{"_past"},
"Edinburgh":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"edirne":{"_cty","_geo","_prprn"},
"Edison":{"_anim","_geo","_nme","_prprn","_sb"},
"Edith":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"editor":{"_anim","_sb"},
"editor-in-chief":{"_anim","_sb"},
"editorialists":{"_anim","_sb"},
"editors":{"_anim","_sb"},
"Edmonton":{"_cty","_geo","_prprn"},
"Edna":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Edouard":{"_prprn"},
"edp":{"_prprn"},
"Edsel":{"_prprn"},
"edta":{"_prprn"},
"educatee":{"_anim","_sb"},
"educationist":{"_anim","_sb"},
"educe":{"_loc_sr"},
"Edward":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Edwards":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"edwin":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Edwina":{"_prprn"},
"eec":{"_prprn"},
"eeg":{"_prprn"},
"eel-shaped":{"_anim"},
"effected":{"_loc_sr","_past"},
"effecter":{"_anim","_sb"},
"effecting":{"_loc_sr"},
"effendi":{"_anim","_sb"},
"egbert":{"_anim","_nme","_prprn","_sb"},
"egeria":{"_anim","_fem","_prprn","_sb"},
"egest":{"_loc_sr"},
"eggcup":{"_loc_sr"},
"egged":{"_past"},
"eglevsky":{"_anim","_nme","_prprn","_sb"},
"egoist":{"_anim","_sb"},
"egret":{"_anim"},
"Egypt":{"_cntry","_geo","_prprn"},
"Egyptian":{"_anim","_prprn","_sb"},
"Egyptians":{"_anim","_prprn","_sb"},
"egyptologist":{"_prprn"},
"egyptology":{"_prprn"},
"ehf":{"_prprn"},
"Ehrlich":{"_anim","_nme","_prprn","_sb"},
"Eichler":{"_prprn"},
"Eichmann":{"_anim","_nme","_prprn","_sb"},
"Eiffel":{"_anim","_nme","_prprn","_sb"},
"eigen":{"_anim","_nme","_prprn","_sb"},
"eight":{"_quant"},
"eight-acre":{"_num","_quant"},
"eight-and-a-half-foot":{"_num","_quant"},
"eight-bar":{"_num","_quant"},
"eight-bit":{"_num","_quant"},
"eight-by-ten":{"_num","_quant"},
"eight-cent":{"_num","_quant"},
"eight-day":{"_num","_quant"},
"eight-fold":{"_num","_quant"},
"eight-foot":{"_num","_quant"},
"eight-foot-high":{"_num","_quant"},
"eight-hour":{"_num","_quant"},
"eight-inch":{"_num","_quant"},
"eight-member":{"_num","_quant"},
"eight-membered":{"_num","_quant"},
"eight-mile-long":{"_num","_quant"},
"eight-month":{"_num","_quant"},
"eight-month-old":{"_num","_quant"},
"eight-page":{"_num","_quant"},
"eight-page-a-minute":{"_num","_quant"},
"eight-partner":{"_num","_quant"},
"eight-person":{"_num","_quant"},
"eight-piece":{"_num","_quant"},
"eight-sided":{"_quant"},
"eight-spot":{"_num","_quant"},
"eight-thirty":{"_num","_quant"},
"eight-time":{"_num","_quant"},
"eight-times":{"_num","_quant"},
"eight-week":{"_num","_quant"},
"eight-year-old":{"_num","_quant"},
"eighteen":{"_quant"},
"eighteen-year-old":{"_num","_quant"},
"eighter":{"_anim","_sb"},
"eightfold":{"_quant"},
"eighties":{"_num","_quant"},
"eighty":{"_quant"},
"eighty-eight":{"_num","_quant"},
"eighty-five":{"_num","_quant"},
"eighty-nine":{"_num","_quant"},
"eighty-one":{"_num","_quant"},
"eighty-seven":{"_num","_quant"},
"eighty-six":{"_num","_quant"},
"eighty-sixth":{"_num","_quant"},
"eighty-three":{"_num","_quant"},
"eighty-two":{"_num","_quant"},
"eighty-year-old":{"_num","_quant"},
"eijkman":{"_anim","_nme","_prprn","_sb"},
"Eileen":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"eindhoven":{"_cty","_geo","_prprn"},
"einthoven":{"_anim","_nme","_prprn","_sb"},
"Eire":{"_geo","_prprn"},
"Eisenach":{"_cty","_geo","_prprn"},
"Eisenhower":{"_anim","_nme","_prprn","_sb"},
"eisenstaedt":{"_anim","_nme","_prprn","_sb"},
"Eisenstein":{"_anim","_nme","_prprn","_sb"},
"either":{"_quant"},
"ejaculate":{"_loc_sr"},
"ejected":{"_past"},
"Ekaterinoslav":{"_prprn"},
"eked":{"_past"},
"ekg":{"_prprn"},
"Ekman":{"_prprn"},
"elaborated":{"_past"},
"Elaine":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"elam":{"_cntry","_geo","_prprn"},
"elamite":{"_anim","_prprn","_sb"},
"eland":{"_anim"},
"elapse":{"_loc_sr"},
"elapsed":{"_loc_sr","_past"},
"elasticised":{"_past"},
"elastoplast":{"_prprn"},
"elate":{"_psych"},
"elated":{"_past","_psych"},
"elating":{"_psych"},
"elavil":{"_prprn"},
"Elba":{"_geo","_prprn"},
"elbe":{"_geo","_prprn"},
"elder":{"_anim","_sb"},
"elderly":{"_anim","_sb"},
"elders":{"_anim","_sb"},
"eldest":{"_anim","_sb"},
"Eldon":{"_prprn"},
"Eleanor":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Eleazar":{"_prprn"},
"elected":{"_past"},
"elector":{"_anim","_sb"},
"electorate":{"_sb"},
"electors":{"_anim","_sb"},
"Electra":{"_prprn"},
"electricians":{"_anim","_sb"},
"electrified":{"_loc_sr","_past","_psych"},
"electrify":{"_loc_sr","_psych"},
"electrifying":{"_loc_sr","_psych"},
"electrocutioner":{"_anim","_sb"},
"electrologist":{"_anim","_sb"},
"electroplated":{"_past"},
"electroplater":{"_anim","_sb"},
"elects":{"_anim","_sb"},
"elephant":{"_anim"},
"elephant's-foot":{"_anim"},
"elephant-like":{"_anim"},
"elephant-tusk":{"_anim"},
"elephants":{"_anim"},
"elevates":{"_loc_sr","_psych"},
"elevating":{"_loc_sr","_psych"},
"eleven":{"_quant"},
"eleven-sided":{"_quant"},
"Elgar":{"_anim","_nme","_prprn","_sb"},
"Elgin":{"_cty","_geo","_prprn"},
"Eli":{"_anim","_fnme","_nme","_prprn","_sb"},
"Elias":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"elicited":{"_past"},
"elide":{"_loc_sr"},
"Elijah":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"eliminated":{"_past"},
"Elinor":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Eliot":{"_anim","_nme","_prprn","_sb"},
"Elisabeth":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"elisabethville":{"_geo","_prprn"},
"Elisha":{"_anim","_nme","_prprn","_sb"},
"elite":{"_anim","_sb"},
"elites":{"_anim","_sb"},
"Elizabeth":{"_anim","_cty","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"Elizabethan":{"_anim","_prprn","_sb"},
"Elizabethans":{"_anim","_prprn","_sb"},
"elk":{"_anim"},
"elk-wood":{"_anim"},
"elkhound":{"_anim"},
"Ella":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Ellen":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Ellesmere":{"_prprn"},
"elli":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Ellington":{"_anim","_nme","_prprn","_sb"},
"Elliot":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Ellis":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"ellison":{"_anim","_nme","_prprn","_sb"},
"Ellsworth":{"_anim","_nme","_prprn","_sb"},
"Elman":{"_anim","_nme","_prprn","_sb"},
"Elmer":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"elmont":{"_geo","_prprn"},
"elocutionist":{"_anim","_sb"},
"Eloise":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"eloped":{"_past"},
"Elsa":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Elsie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Elton":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"elucidated":{"_past"},
"eluded":{"_loc_sr","_past"},
"eludes":{"_loc_sr"},
"eluding":{"_loc_sr"},
"elul":{"_prprn"},
"eluted":{"_past"},
"elver":{"_anim"},
"Elvira":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Elvis":{"_prprn"},
"Ely":{"_prprn"},
"Elyria":{"_cty","_geo","_prprn"},
"elysium":{"_prprn"},
"emaciated":{"_past"},
"emanate":{"_loc_sr"},
"emanated":{"_loc_sr","_past"},
"emanating":{"_loc_sr"},
"emancipated":{"_loc_sr","_past"},
"emancipationist":{"_anim","_sb"},
"Emanuel":{"_prprn"},
"emasculated":{"_past"},
"embalm":{"_loc_sr"},
"embargoed":{"_past"},
"embark":{"_loc_sr"},
"embarked":{"_loc_sr","_past"},
"embarking":{"_loc_sr"},
"embarks":{"_loc_sr"},
"embarrass":{"_psych"},
"embarrassed":{"_past","_psych"},
"embarrassing":{"_psych"},
"embassies":{"_loc_sr"},
"embassy":{"_loc_sr"},
"embattled":{"_past"},
"embed":{"_loc_sr"},
"embedded":{"_loc_sr","_past"},
"embellished":{"_past"},
"embitter":{"_psych"},
"embittered":{"_past","_psych"},
"emblazoned":{"_past"},
"embodied":{"_past"},
"embodiment":{"_sb"},
"embodiments":{"_sb"},
"embolden":{"_psych"},
"emboldened":{"_past","_psych"},
"emboss":{"_loc_sr"},
"embossed":{"_loc_sr","_past"},
"embraced":{"_past"},
"embroidered":{"_past"},
"embroiderer":{"_anim","_sb"},
"embroil":{"_loc_sr"},
"embroiled":{"_loc_sr","_past"},
"embryologist":{"_anim","_sb"},
"emended":{"_past"},
"emerged":{"_past"},
"emeriti":{"_anim","_sb"},
"Emerson":{"_anim","_nme","_prprn","_sb"},
"emg":{"_prprn"},
"emigrant":{"_anim","_sb"},
"emigrants":{"_anim","_sb"},
"emigrate":{"_loc_sr"},
"emigrated":{"_loc_sr","_past"},
"emigrating":{"_loc_sr"},
"emigre":{"_anim","_sb"},
"emigree":{"_anim","_sb"},
"emigres":{"_anim","_sb"},
"Emil":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"emile":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"emilia":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"emilia-romagna":{"_geo","_prprn","_stte"},
"Emily":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Eminem":{"_prprn"},
"emir":{"_anim","_masc","_sb"},
"emirate":{"_loc_sr"},
"emissaries":{"_anim","_sb"},
"emissary":{"_anim","_sb"},
"emit":{"_loc_sr"},
"emits":{"_loc_sr"},
"emitting":{"_loc_sr"},
"Emma":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Emmanuel":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Emmental":{"_prprn"},
"Emmentaler":{"_prprn"},
"Emmenthal":{"_prprn"},
"Emmenthaler":{"_prprn"},
"emmet":{"_anim","_nme","_prprn","_sb"},
"Emmies":{"_prprn"},
"Emmy":{"_prprn"},
"Emmys":{"_prprn"},
"Emory":{"_prprn"},
"emote":{"_loc_sr"},
"emoted":{"_loc_sr","_past"},
"empanel":{"_loc_sr"},
"empedocles":{"_anim","_nme","_prprn","_sb"},
"emperor":{"_anim","_masc","_sb"},
"emperors":{"_anim","_masc","_sb"},
"emphasised":{"_past"},
"emphasized":{"_past"},
"empiric":{"_anim","_sb"},
"emplace":{"_loc_sr"},
"employee":{"_anim","_sb"},
"employee-benefit":{"_anim","_sb"},
"employee-benefits":{"_anim","_sb"},
"employee-bonus":{"_anim","_sb"},
"employee-contributed":{"_anim","_sb"},
"employee-health":{"_anim","_sb"},
"employee-incentive":{"_anim","_sb"},
"employee-management":{"_anim","_sb"},
"employee-owned":{"_anim","_sb"},
"employee-ownership":{"_anim","_sb"},
"employee-stock":{"_anim","_sb"},
"employees":{"_anim","_sb"},
"employer":{"_anim","_sb"},
"employer-offered":{"_anim","_sb"},
"employer-paid":{"_anim","_sb"},
"employer-provided":{"_anim","_sb"},
"employer-sponsored":{"_anim","_sb"},
"employers":{"_anim","_sb"},
"emporium":{"_loc_sr"},
"empowered":{"_past"},
"empress":{"_anim","_fem","_sb"},
"emptied":{"_past"},
"empties":{"_loc_sr"},
"empty-bellied":{"_loc_sr"},
"empty-shelved":{"_loc_sr"},
"empurpled":{"_past"},
"emu":{"_anim"},
"emulated":{"_past"},
"emulsified":{"_loc_sr","_past"},
"emulsifier":{"_anim","_sb"},
"emulsifiers":{"_anim","_sb"},
"emulsify":{"_loc_sr"},
"enabled":{"_past"},
"enact":{"_loc_sr"},
"enacted":{"_loc_sr","_past"},
"enacting":{"_loc_sr"},
"enacts":{"_loc_sr"},
"enamelled":{"_past"},
"enamor":{"_psych"},
"enamored":{"_past","_psych"},
"enate":{"_sb"},
"encamp":{"_loc_sr"},
"encamped":{"_loc_sr","_past"},
"encampment":{"_loc_sr"},
"encapsulate":{"_loc_sr"},
"Encarta":{"_prprn"},
"encased":{"_past"},
"enchain":{"_loc_sr"},
"enchained":{"_loc_sr","_past"},
"enchant":{"_psych"},
"enchanted":{"_past","_psych"},
"enchanter":{"_anim","_sb"},
"enchanting":{"_psych"},
"enchantress":{"_anim","_fem","_sb"},
"encipher":{"_loc_sr"},
"enciphered":{"_loc_sr","_past"},
"encircled":{"_past"},
"enclave":{"_anim","_sb"},
"enclaves":{"_anim","_sb"},
"enclose":{"_loc_sr"},
"encloses":{"_loc_sr"},
"encode":{"_loc_sr"},
"encoder":{"_anim","_sb"},
"encompassed":{"_loc_sr","_past"},
"encompasses":{"_loc_sr"},
"encountered":{"_past"},
"encourage":{"_psych"},
"encouraged":{"_past","_psych"},
"encourages":{"_psych"},
"encouraging":{"_psych"},
"encroach":{"_loc_sr"},
"encroached":{"_loc_sr","_past"},
"encroacher":{"_anim","_sb"},
"encroaching":{"_loc_sr"},
"encrusted":{"_past"},
"encrypting":{"_loc_sr"},
"encumbered":{"_loc_sr","_past"},
"encumbrances":{"_sb"},
"encyclopedist":{"_anim","_sb"},
"encysted":{"_past"},
"end-user":{"_anim","_sb"},
"endangered":{"_past"},
"endangered-species":{"_past"},
"endeared":{"_past"},
"endecott":{"_anim","_nme","_prprn","_sb"},
"ended":{"_past"},
"endicott":{"_anim","_nme","_prprn","_sb"},
"endlessly":{"_tme"},
"endocrinologists":{"_anim","_sb"},
"endomorph":{"_loc_sr"},
"endorse":{"_loc_sr"},
"endorsed":{"_loc_sr","_past"},
"endorsers":{"_anim","_sb"},
"endorses":{"_loc_sr"},
"endorsing":{"_loc_sr"},
"endowed":{"_past"},
"ene":{"_prprn"},
"enemies":{"_anim","_sb"},
"enemy":{"_anim","_sb"},
"enemy-Jew":{"_anim","_sb"},
"energized":{"_past"},
"enervate":{"_psych"},
"enervated":{"_past","_psych"},
"enervating":{"_psych"},
"enesco":{"_anim","_nme","_prprn","_sb"},
"Enfield":{"_cty","_geo","_prprn"},
"enfold":{"_loc_sr"},
"enforced":{"_past"},
"enforcer":{"_anim","_sb"},
"enforcers":{"_anim","_sb"},
"enfranchised":{"_past"},
"Eng":{"_prprn"},
"engage":{"_psych"},
"engaged":{"_past","_psych"},
"engages":{"_psych"},
"engaging":{"_psych"},
"Engels":{"_anim","_nme","_prprn","_sb"},
"engender":{"_loc_sr"},
"engendered":{"_loc_sr","_past"},
"engenders":{"_loc_sr"},
"engineer":{"_anim","_sb"},
"engineered":{"_past"},
"engineers":{"_anim","_sb"},
"England":{"_cntry","_geo","_prprn"},
"Englander":{"_anim","_sb"},
"Englanders":{"_anim","_sb"},
"English":{"_anim","_prprn","_sb"},
"english-gothic":{"_anim","_prprn","_sb"},
"English-speaking":{"_anim","_prprn","_sb"},
"english-weed":{"_anim","_prprn","_sb"},
"Englishman":{"_anim","_masc","_prprn","_sb"},
"Englishmen":{"_anim","_masc","_prprn","_sb"},
"Englishwoman":{"_anim","_fem","_prprn","_sb"},
"engrave":{"_loc_sr"},
"engraved":{"_loc_sr","_past"},
"engraves":{"_loc_sr"},
"engraving":{"_loc_sr"},
"engross":{"_psych"},
"engrossed":{"_past","_psych"},
"engrossing":{"_psych"},
"enhanced":{"_past"},
"enhancer":{"_anim","_sb"},
"enid":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"eniwetok":{"_geo","_prprn"},
"enjoined":{"_past"},
"enjoyed":{"_past"},
"enjoyer":{"_anim","_sb"},
"enkindled":{"_past"},
"enlarged":{"_past"},
"enlarger":{"_anim","_sb"},
"enlargers":{"_anim","_sb"},
"enlighten":{"_psych"},
"enlightened":{"_past","_psych"},
"enlightening":{"_psych"},
"enlistee":{"_anim","_sb"},
"enliven":{"_psych"},
"enlivened":{"_past","_psych"},
"enlivener":{"_anim","_sb"},
"enlivening":{"_psych"},
"enmesh":{"_loc_sr"},
"enmeshed":{"_loc_sr","_past"},
"Ennis":{"_prprn"},
"ennobling":{"_psych"},
"enologist":{"_anim","_sb"},
"Enos":{"_prprn"},
"enough":{"_quant"},
"enquired":{"_past"},
"enquirer":{"_anim","_sb"},
"enrage":{"_loc_sr","_psych"},
"enraged":{"_loc_sr","_past","_psych"},
"enriched":{"_past"},
"Enright":{"_prprn"},
"enrolled":{"_loc_sr","_past"},
"enrollee":{"_anim","_sb"},
"enrolling":{"_loc_sr"},
"ensconce":{"_loc_sr"},
"ensconced":{"_loc_sr","_past"},
"enshrine":{"_loc_sr"},
"enshrined":{"_loc_sr","_past"},
"ensile":{"_loc_sr"},
"enslaved":{"_loc_sr","_past"},
"enslaving":{"_loc_sr"},
"ensnare":{"_loc_sr"},
"ensnared":{"_loc_sr","_past"},
"ensnarled":{"_past"},
"ensued":{"_past"},
"ensured":{"_past"},
"entablature":{"_loc_sr"},
"entailed":{"_past"},
"entangle":{"_loc_sr"},
"entangled":{"_loc_sr","_past"},
"Entebbe":{"_cty","_geo","_prprn"},
"enter":{"_loc_sr"},
"entered":{"_loc_sr","_past"},
"enterpriser":{"_anim","_sb"},
"enters":{"_loc_sr"},
"entertain":{"_loc_sr","_psych"},
"entertained":{"_loc_sr","_past","_psych"},
"entertainer":{"_anim","_sb"},
"entertaining":{"_loc_sr","_psych"},
"entertains":{"_loc_sr","_psych"},
"enthral":{"_psych"},
"enthralled":{"_past"},
"enthrone":{"_loc_sr"},
"enthrones":{"_loc_sr"},
"enthuse":{"_psych"},
"enthusiast":{"_anim","_sb"},
"enthusiasts":{"_anim","_sb"},
"entice":{"_psych"},
"enticed":{"_past","_psych"},
"enticing":{"_psych"},
"entitled":{"_past"},
"entombed":{"_past"},
"entomologist":{"_anim","_sb"},
"entourage":{"_sb"},
"entrain":{"_loc_sr"},
"entranced":{"_loc_sr","_past","_psych"},
"entrancing":{"_loc_sr","_psych"},
"entrant":{"_anim","_sb"},
"entrants":{"_anim","_sb"},
"entrap":{"_loc_sr"},
"entreated":{"_past"},
"entrench":{"_loc_sr"},
"entrenched":{"_loc_sr","_past"},
"entrepot":{"_loc_sr"},
"entrepreneur":{"_anim","_sb"},
"entrepreneurs":{"_anim","_sb"},
"entrusted":{"_past"},
"entwined":{"_past"},
"enumerated":{"_past"},
"enumerator":{"_anim","_sb"},
"enured":{"_past"},
"envelope":{"_loc_sr"},
"enveloped":{"_past"},
"envelopes":{"_loc_sr"},
"envenom":{"_loc_sr"},
"envenomed":{"_loc_sr","_past"},
"environmentalist":{"_anim","_sb"},
"environmentalist-actor":{"_anim","_sb"},
"environmentalist-developer":{"_anim","_sb"},
"environmentalists":{"_anim","_sb"},
"environs":{"_loc_sr"},
"envisage":{"_loc_sr"},
"envisioning":{"_loc_sr"},
"envisions":{"_loc_sr"},
"enwrapped":{"_past"},
"enzymologist":{"_anim","_sb"},
"Eocene":{"_prprn"},
"eon":{"_tme"},
"eons":{"_tme"},
"eos":{"_anim","_fem","_prprn","_sb"},
"epa":{"_prprn"},
"Eph":{"_prprn"},
"ephesian":{"_anim","_prprn","_sb"},
"ephesians":{"_anim","_prprn","_sb"},
"ephesus":{"_cty","_geo","_prprn"},
"epicentre":{"_loc_sr"},
"epictetus":{"_anim","_nme","_prprn","_sb"},
"epicurean":{"_anim","_sb"},
"epicureanism":{"_prprn"},
"epicurus":{"_anim","_nme","_prprn","_sb"},
"epidemiologists":{"_anim","_sb"},
"epileptic":{"_anim","_sb"},
"epileptics":{"_anim","_sb"},
"epimetheus":{"_prprn"},
"Epiphany":{"_prprn"},
"epirus":{"_cntry","_geo","_prprn"},
"Episcopalian":{"_anim","_prprn","_sb"},
"Episcopalians":{"_anim","_sb"},
"epistemologist":{"_anim","_sb"},
"eponym":{"_anim","_sb"},
"eprom":{"_prprn"},
"Epsom":{"_prprn"},
"Epson":{"_prprn"},
"Epstein":{"_anim","_nme","_prprn","_sb"},
"equal-opportunity":{"_anim","_sb"},
"equaled":{"_past"},
"equaliser":{"_anim","_sb"},
"equalled":{"_past"},
"equals":{"_anim","_sb"},
"equated":{"_past"},
"equerry":{"_anim","_masc","_sb"},
"equestrians":{"_anim","_sb"},
"equilibrated":{"_past"},
"equinox":{"_tme"},
"equipped":{"_past"},
"equivocator":{"_anim","_sb"},
"era":{"_tme"},
"eradicated":{"_past"},
"eras":{"_tme"},
"erased":{"_past"},
"Erasmus":{"_anim","_nme","_prprn","_sb"},
"erato":{"_prprn"},
"eratosthenes":{"_anim","_nme","_prprn","_sb"},
"Erebus":{"_prprn"},
"erected":{"_past"},
"eremite":{"_anim","_sb"},
"Erewhon":{"_prprn"},
"Erfurt":{"_cty","_geo","_prprn"},
"Eric":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Erica":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Ericson":{"_anim","_nme","_prprn","_sb"},
"Ericsson":{"_anim","_nme","_prprn","_sb"},
"eridanus":{"_prprn"},
"Erie":{"_anim","_cty","_geo","_prprn","_sb"},
"Erik":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Erin":{"_anim","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"erinyes":{"_prprn"},
"eris":{"_anim","_fem","_nme","_prprn","_sb"},
"Eritrea":{"_cntry","_geo","_prprn"},
"erivan":{"_geo","_prprn"},
"ermine":{"_anim"},
"Ernest":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Ernie":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Ernst":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"eroded":{"_past"},
"Eros":{"_anim","_masc","_prprn","_sb"},
"erred":{"_past"},
"Errol":{"_prprn"},
"Erse":{"_prprn"},
"Erskine":{"_anim","_nme","_prprn","_sb"},
"erupt":{"_loc_sr"},
"erupted":{"_loc_sr","_past"},
"erupting":{"_loc_sr"},
"erupts":{"_loc_sr"},
"erving":{"_anim","_nme","_prprn","_sb"},
"esaki":{"_anim","_nme","_prprn","_sb"},
"Esau":{"_anim","_nme","_prprn","_sb"},
"escalader":{"_anim","_sb"},
"escalated":{"_past"},
"escaped":{"_past"},
"eschatologist":{"_anim","_sb"},
"eschew":{"_loc_sr"},
"eschewed":{"_loc_sr","_past"},
"eschewing":{"_loc_sr"},
"eschews":{"_loc_sr"},
"escort":{"_loc_sr"},
"escorted":{"_loc_sr","_past"},
"escorting":{"_loc_sr"},
"escrowed":{"_loc_sr","_past"},
"ese":{"_prprn"},
"esfahan":{"_geo","_prprn"},
"Esher":{"_geo","_prprn"},
"Eskimo":{"_prprn","_sb"},
"eskimo-aleut":{"_prprn","_sb"},
"Eskimos":{"_prprn","_sb"},
"esop":{"_prprn"},
"esp":{"_prprn"},
"Esperanto":{"_prprn"},
"espoo":{"_cty","_geo","_prprn"},
"espouse":{"_loc_sr"},
"espoused":{"_loc_sr","_past"},
"espouses":{"_loc_sr"},
"espousing":{"_loc_sr"},
"esquimau":{"_prprn"},
"esquire":{"_anim","_masc","_sb"},
"esr":{"_prprn"},
"essayed":{"_past"},
"essayer":{"_anim","_sb"},
"essen":{"_cty","_geo","_prprn"},
"essene":{"_prprn","_sb"},
"Essex":{"_anim","_geo","_nme","_prprn","_sb"},
"est":{"_prprn"},
"established":{"_past"},
"Establishment":{"_prprn","_sb"},
"estate-freeze":{"_loc_sr"},
"estate-tax":{"_loc_sr"},
"estates":{"_loc_sr"},
"Este":{"_anim","_nme","_prprn","_sb"},
"esteemed":{"_past"},
"Esther":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"esthetician":{"_anim","_sb"},
"Esthonia":{"_prprn"},
"Esthonian":{"_prprn"},
"estimated":{"_past"},
"estimator":{"_anim","_sb"},
"estimators":{"_anim","_sb"},
"Estonia":{"_cntry","_geo","_prprn"},
"Estonian":{"_anim","_prprn","_sb"},
"estranged":{"_past"},
"et":{"_prprn"},
"etch":{"_loc_sr"},
"etching":{"_loc_sr"},
"etd":{"_prprn"},
"eternally":{"_tme"},
"eternity":{"_tme"},
"Ethan":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Ethel":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"ethelbert":{"_anim","_nme","_prprn","_sb"},
"etherify":{"_loc_sr"},
"Ethiopia":{"_cntry","_geo","_prprn"},
"Ethiopians":{"_anim","_prprn","_sb"},
"ethnic":{"_anim","_sb"},
"ethnographer":{"_anim","_sb"},
"ethnologist":{"_anim","_sb"},
"etiologist":{"_anim","_sb"},
"Etna":{"_prprn"},
"Etruria":{"_cntry","_geo","_prprn"},
"Etruscan":{"_anim","_prprn","_sb"},
"etymologist":{"_anim","_sb"},
"Eucharist":{"_prprn"},
"Euclid":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Eugene":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"eugenia":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"euler":{"_anim","_nme","_prprn","_sb"},
"eulogist":{"_anim","_sb"},
"eulogize":{"_loc_sr"},
"eulogized":{"_loc_sr","_past"},
"eulogizers":{"_anim","_sb"},
"eumenides":{"_prprn"},
"Euphrates":{"_geo","_prprn"},
"euphrosyne":{"_prprn"},
"Eurasia":{"_geo","_loc_sr","_prprn"},
"Eurasian":{"_anim","_prprn","_sb"},
"Euratom":{"_prprn"},
"Euripides":{"_anim","_nme","_prprn","_sb"},
"Eurobond":{"_prprn"},
"Eurobonds":{"_prprn"},
"Eurocrat":{"_prprn"},
"Eurocrats":{"_prprn"},
"eurocurrency":{"_prprn"},
"Eurodollar":{"_prprn"},
"Eurofighter":{"_prprn"},
"Euromarket":{"_prprn"},
"Europa":{"_prprn"},
"Europe":{"_geo","_prprn"},
"European":{"_anim","_prprn","_sb"},
"Eurostat":{"_prprn"},
"Eurotunnel":{"_prprn"},
"Eurovision":{"_prprn"},
"euryale":{"_anim","_fem","_nme","_prprn","_sb"},
"Eurydice":{"_anim","_fem","_nme","_prprn","_sb"},
"eustachio":{"_anim","_nme","_prprn","_sb"},
"euterpe":{"_prprn"},
"ev":{"_prprn"},
"Eva":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"evacuated":{"_past"},
"evacuee":{"_anim","_sb"},
"evaded":{"_past"},
"evader":{"_anim","_sb"},
"evaders":{"_anim","_sb"},
"evaluated":{"_past"},
"evaluator":{"_anim","_sb"},
"Evan":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"evangelical":{"_anim","_sb"},
"Evangeline":{"_prprn"},
"evangelist":{"_anim","_sb"},
"evangelist-industrialist":{"_anim","_sb"},
"evangelists":{"_anim","_sb"},
"Evans":{"_anim","_nme","_prprn","_sb"},
"Evanston":{"_cty","_geo","_prprn"},
"evansville":{"_cty","_geo","_prprn"},
"evaporate":{"_loc_sr"},
"evaporated":{"_loc_sr","_past"},
"evaporates":{"_loc_sr"},
"Eve":{"_anim","_fem","_fnme","_nme","_prprn","_sb","_tme"},
"Evelyn":{"_anim","_nme","_prprn","_sb"},
"evened":{"_past"},
"evening-snow":{"_tme"},
"evenings":{"_tme"},
"evenki":{"_anim","_prprn","_sb"},
"eventide":{"_tme"},
"eventually":{"_tme"},
"ever":{"_tme"},
"ever-anxious":{"_tme"},
"ever-changing":{"_tme"},
"ever-dying":{"_tme"},
"ever-existent":{"_tme"},
"ever-expanding":{"_tme"},
"ever-faster":{"_tme"},
"ever-greater":{"_tme"},
"ever-growing":{"_tme"},
"ever-increasing":{"_tme"},
"ever-lovin":{"_tme"},
"ever-more":{"_tme"},
"ever-optimistic":{"_tme"},
"ever-quieter":{"_tme"},
"ever-so-Oxonian":{"_tme"},
"ever-successful":{"_tme"},
"ever-swelling":{"_tme"},
"ever-tightening":{"_tme"},
"ever-worsening":{"_tme"},
"everglades":{"_loc_sr"},
"evers":{"_anim","_nme","_prprn","_sb"},
"every":{"_quant","_univ"},
"every-day":{"_quant","_univ"},
"everybody":{"_anim","_sb","_univ"},
"Everyman":{"_prprn","_sb"},
"everyone":{"_anim","_sb","_univ"},
"everyplace":{"_loc","_univ"},
"everything":{"_univ"},
"everywhere":{"_loc","_univ"},
"evict":{"_loc_sr"},
"evicted":{"_loc_sr","_past"},
"evicting":{"_loc_sr"},
"evidenced":{"_past"},
"evildoers":{"_anim","_sb"},
"evinced":{"_past"},
"evoked":{"_past"},
"evolutionist":{"_anim","_sb"},
"evolutionists":{"_anim","_sb"},
"evolved":{"_past"},
"ew":{"_prprn"},
"ewe":{"_anim","_fem"},
"ewenki":{"_anim","_prprn","_sb"},
"ewer":{"_loc_sr"},
"ex":{"_anim","_sb"},
"ex-accountant":{"_anim","_sb"},
"ex-aides":{"_anim","_sb"},
"ex-Attorney":{"_anim","_sb"},
"ex-bandits":{"_anim","_sb"},
"ex-Beecham":{"_anim","_sb"},
"ex-brother-in-law":{"_anim","_sb"},
"ex-chief":{"_anim","_sb"},
"ex-convict":{"_anim","_sb"},
"ex-convicts":{"_anim","_sb"},
"ex-Cubs":{"_anim","_sb"},
"ex-dividend":{"_anim","_sb"},
"ex-employee":{"_anim","_sb"},
"ex-employees":{"_anim","_sb"},
"ex-employer":{"_anim","_sb"},
"ex-FDA":{"_anim","_sb"},
"ex-franchise":{"_anim","_sb"},
"ex-furniture":{"_anim","_sb"},
"ex-Gov":{"_anim","_sb"},
"ex-housing":{"_anim","_sb"},
"ex-hurler":{"_anim","_sb"},
"ex-husband":{"_anim","_sb"},
"ex-jazz":{"_anim","_sb"},
"ex-Justice":{"_anim","_sb"},
"ex-liberals":{"_anim","_sb"},
"ex-manager":{"_anim","_sb"},
"ex-marine":{"_anim","_sb"},
"ex-member":{"_anim","_sb"},
"ex-musician":{"_anim","_sb"},
"ex-National":{"_anim","_sb"},
"ex-officers":{"_anim","_sb"},
"ex-officio":{"_anim","_sb"},
"ex-partners":{"_anim","_sb"},
"ex-president":{"_anim","_sb"},
"ex-presidents":{"_anim","_sb"},
"ex-prison":{"_anim","_sb"},
"ex-prize":{"_anim","_sb"},
"ex-reporters":{"_anim","_sb"},
"ex-schoolteacher":{"_anim","_sb"},
"ex-serviceman":{"_anim","_sb"},
"ex-singer":{"_anim","_sb"},
"ex-smokers":{"_anim","_sb"},
"ex-spouse":{"_anim","_sb"},
"ex-Tory":{"_anim","_sb"},
"ex-truck":{"_anim","_sb"},
"ex-trucking":{"_anim","_sb"},
"ex-wife":{"_anim","_sb"},
"ex-wives":{"_anim","_sb"},
"ex-Yankee":{"_anim","_sb"},
"exacerbated":{"_past"},
"exacted":{"_past"},
"exaggerated":{"_past"},
"exalt":{"_loc_sr"},
"exalting":{"_loc_sr"},
"examined":{"_past"},
"exasperate":{"_psych"},
"exasperating":{"_psych"},
"excavated":{"_past"},
"excavators":{"_anim","_sb"},
"exceeded":{"_past"},
"Excellency":{"_prprn"},
"excepted":{"_past"},
"excerpted":{"_past"},
"exchanged":{"_past"},
"exchangers":{"_anim","_sb"},
"Exchequer":{"_prprn"},
"excise":{"_loc_sr"},
"excite":{"_psych"},
"excited":{"_past","_psych"},
"excites":{"_psych"},
"exciting":{"_psych"},
"exclaimed":{"_past"},
"excluded":{"_loc_sr","_past"},
"excludes":{"_loc_sr"},
"excluding":{"_loc_sr"},
"excogitator":{"_anim","_sb"},
"excoriated":{"_past"},
"excreted":{"_loc_sr","_past"},
"excreting":{"_loc_sr"},
"excruciate":{"_loc_sr"},
"excruciating":{"_loc_sr"},
"exculpate":{"_loc_sr"},
"exculpated":{"_loc_sr","_past"},
"excursionist":{"_anim","_sb"},
"excuse":{"_loc_sr"},
"excused":{"_loc_sr","_past"},
"excuser":{"_anim","_sb"},
"executant":{"_anim","_sb"},
"execute":{"_loc_sr"},
"executed":{"_loc_sr","_past"},
"executes":{"_loc_sr"},
"executing":{"_loc_sr"},
"executioner":{"_anim","_sb"},
"executive":{"_anim","_sb"},
"executive-branch":{"_anim","_sb"},
"executive-legislative":{"_anim","_sb"},
"executive-level":{"_anim","_sb"},
"executive-model":{"_anim","_sb"},
"executive-office":{"_anim","_sb"},
"executive-only":{"_anim","_sb"},
"executive-type":{"_anim","_sb"},
"executives":{"_anim","_sb"},
"executors":{"_anim","_sb"},
"exegete":{"_anim","_sb"},
"exemplified":{"_past"},
"exempt":{"_loc_sr"},
"exempting":{"_loc_sr"},
"exempts":{"_anim","_sb"},
"exercise":{"_loc_sr"},
"exercised":{"_loc_sr","_past"},
"exercising":{"_loc_sr"},
"exercycle":{"_prprn"},
"Exeter":{"_cty","_geo","_prprn"},
"exfoliate":{"_loc_sr"},
"exhaled":{"_past"},
"exhaust":{"_psych"},
"exhausted":{"_past","_psych"},
"exhausting":{"_psych"},
"exhibited":{"_loc_sr","_past"},
"exhibiting":{"_loc_sr"},
"exhibitioner":{"_anim","_sb"},
"exhibitor":{"_anim","_sb"},
"exhibitors":{"_anim","_sb"},
"exhilarate":{"_psych"},
"exhilarated":{"_past","_psych"},
"exhilarating":{"_psych"},
"exiled":{"_loc_sr","_past"},
"exiling":{"_loc_sr"},
"existed":{"_past"},
"exit":{"_loc_sr"},
"exited":{"_loc_sr","_past"},
"Exmoor":{"_geo","_prprn"},
"Exocet":{"_prprn"},
"exonerate":{"_loc_sr"},
"exonerated":{"_loc_sr","_past"},
"exonerating":{"_loc_sr"},
"exorciser":{"_anim","_sb"},
"exorcize":{"_loc_sr"},
"expanded":{"_past"},
"expansionists":{"_anim","_sb"},
"expatriate":{"_loc_sr"},
"expatriates":{"_anim","_sb"},
"expectorate":{"_loc_sr"},
"expectorator":{"_anim","_sb"},
"expedite":{"_loc_sr"},
"expedited":{"_loc_sr","_past"},
"expediting":{"_loc_sr"},
"expedition":{"_sb"},
"expeditions":{"_sb"},
"expelled":{"_loc_sr","_past"},
"expelling":{"_loc_sr"},
"expended":{"_past"},
"expender":{"_anim","_sb"},
"experienced":{"_past"},
"experimented":{"_past"},
"experimenters":{"_anim","_sb"},
"expert":{"_anim","_sb"},
"experts":{"_anim","_sb"},
"expired":{"_past"},
"explained":{"_past"},
"explicate":{"_loc_sr"},
"exploded":{"_past"},
"exploited":{"_past"},
"explore":{"_loc_sr"},
"explored":{"_loc_sr","_past"},
"explorer":{"_anim","_sb"},
"explores":{"_loc_sr"},
"exploring":{"_loc_sr"},
"exponent":{"_sb"},
"exponents":{"_sb"},
"exported":{"_loc_sr","_past"},
"exporter":{"_sb"},
"exporters":{"_sb"},
"exporting":{"_loc_sr"},
"exposed":{"_past"},
"expounded":{"_past"},
"expounder":{"_anim","_sb"},
"express":{"_loc_sr"},
"expressed":{"_loc_sr","_past"},
"expressing":{"_loc_sr"},
"expropriated":{"_past"},
"expunged":{"_loc_sr","_past"},
"expunging":{"_loc_sr"},
"expurgated":{"_past"},
"extended-body":{"_past"},
"extended-care":{"_past"},
"extended-payment":{"_past"},
"extended-wear":{"_past"},
"extent":{"_loc_sr"},
"exterminated":{"_past"},
"externally":{"_loc"},
"extinguished":{"_past"},
"extirpated":{"_past"},
"extoller":{"_anim","_sb"},
"extorted":{"_past"},
"extortioner":{"_anim","_sb"},
"extracted":{"_past"},
"extractors":{"_anim","_sb"},
"extradite":{"_loc_sr"},
"extradited":{"_loc_sr","_past"},
"extraditing":{"_loc_sr"},
"extrapolated":{"_past"},
"extravert":{"_anim","_sb"},
"Extremadura":{"_prprn"},
"extremist":{"_anim","_sb"},
"extremists":{"_anim","_sb"},
"extricate":{"_loc_sr"},
"extrovert":{"_anim","_sb"},
"extruded":{"_past"},
"extruder":{"_anim","_sb"},
"exuded":{"_past"},
"exulted":{"_past"},
"Eyck":{"_anim","_nme","_prprn","_sb"},
"eyed":{"_past"},
"eyewitness":{"_anim","_sb"},
"eyewitnesses":{"_anim","_sb"},
"ezekias":{"_anim","_nme","_prprn","_sb"},
"Ezekiel":{"_anim","_fnme","_nme","_prprn","_sb"},
"Ezra":{"_anim","_fnme","_nme","_prprn","_sb"},
"faa":{"_prprn"},
"Faberge":{"_anim","_nme","_prprn","_sb"},
"Fabian":{"_prprn","_sb"},
"fabianism":{"_prprn"},
"fabled":{"_past"},
"fabricated":{"_past"},
"fabulous":{"_psych"},
"facade":{"_loc_sr"},
"facades":{"_loc_sr"},
"faced":{"_past"},
"facilitator":{"_anim","_sb"},
"facilitators":{"_anim","_sb"},
"fact-finder":{"_anim","_sb"},
"factions":{"_anim","_sb"},
"factored":{"_past"},
"factories":{"_loc_sr"},
"factorize":{"_loc_sr"},
"factory-automation":{"_loc_sr"},
"factory-jobs":{"_loc_sr"},
"factory-like":{"_loc_sr"},
"factory-made":{"_loc_sr"},
"factory-modernization":{"_loc_sr"},
"factory-outlet":{"_loc_sr"},
"factotum":{"_anim","_sb"},
"faddist":{"_anim","_sb"},
"faded":{"_past"},
"Faeroes":{"_prprn"},
"Faeroese":{"_anim","_prprn","_sb"},
"Fafnir":{"_prprn"},
"fagged":{"_past"},
"faggoting":{"_loc_sr"},
"Fagin":{"_prprn"},
"fagot":{"_loc_sr"},
"fagoting":{"_loc_sr"},
"fahd":{"_anim","_nme","_prprn","_sb"},
"Fahrenheit":{"_anim","_nme","_prprn","_sb"},
"failed":{"_past"},
"failings":{"_sb"},
"fainted":{"_loc_sr","_past"},
"Fairbanks":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Fairfield":{"_cty","_geo","_prprn"},
"fairies":{"_anim"},
"fairy-land":{"_anim"},
"fairy-slipper":{"_anim"},
"fairyland":{"_loc_sr"},
"faisal":{"_anim","_nme","_prprn","_sb"},
"faisalabad":{"_cty","_geo","_prprn"},
"faithful":{"_sb"},
"faked":{"_past"},
"fakes":{"_sb"},
"fakir":{"_anim","_masc","_sb"},
"falangist":{"_prprn","_sb"},
"falcon":{"_anim"},
"falcon-gentil":{"_anim"},
"falcon-gentle":{"_anim","_fem"},
"falconers":{"_anim","_sb"},
"falcons":{"_anim"},
"Faldo":{"_prprn"},
"Falkland":{"_geo","_prprn"},
"falkner":{"_anim","_nme","_prprn","_sb"},
"fall":{"_loc_sr"},
"fall-blooming":{"_tme"},
"fall-board":{"_tme"},
"fall-flowering":{"_tme"},
"fall-off":{"_tme"},
"fall-outs":{"_sb"},
"Falla":{"_prprn"},
"faller":{"_anim","_sb"},
"Falmouth":{"_cty","_geo","_prprn"},
"falsetto":{"_anim","_masc","_sb"},
"falsified":{"_past"},
"falsifier":{"_anim","_sb"},
"Falstaff":{"_prprn"},
"falter":{"_loc_sr"},
"faltered":{"_loc_sr","_past"},
"falters":{"_loc_sr"},
"Falun":{"_prprn"},
"famed":{"_past"},
"familiarised":{"_past"},
"families":{"_anim","_sb"},
"family":{"_anim","_sb"},
"family-business":{"_anim","_sb"},
"family-centered":{"_anim","_sb"},
"family-community":{"_anim","_sb"},
"family-entertainment":{"_anim","_sb"},
"family-friendly":{"_anim","_sb"},
"family-oriented":{"_anim","_sb"},
"family-planning":{"_anim","_sb"},
"family-run":{"_anim","_sb"},
"family-welfare":{"_anim","_sb"},
"fanatics":{"_anim","_sb"},
"fancied":{"_past"},
"fancier":{"_anim","_sb"},
"fanned":{"_loc_sr","_past"},
"Fannie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"fanning":{"_loc_sr"},
"fantasist":{"_anim","_sb"},
"fantasize":{"_loc_sr"},
"fantasized":{"_loc_sr","_past"},
"fantastic":{"_sb"},
"faq":{"_prprn"},
"far":{"_loc"},
"Faraday":{"_anim","_prprn","_sb"},
"Farberware":{"_prprn"},
"fared":{"_past"},
"fargo":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"farm":{"_loc_sr"},
"farm-engineering":{"_loc_sr"},
"farm-equipment":{"_loc_sr"},
"farm-place":{"_loc_sr"},
"farm-policy":{"_loc_sr"},
"farm-product":{"_loc_sr"},
"farm-state":{"_loc_sr"},
"farm-subsidy":{"_loc_sr"},
"farm-supply":{"_loc_sr"},
"farm-trade":{"_loc_sr"},
"farmed":{"_past"},
"farmer":{"_anim","_sb"},
"farmer-type":{"_anim","_sb"},
"farmers":{"_anim","_sb"},
"farmhand":{"_anim","_sb"},
"farmhands":{"_anim","_sb"},
"farmington":{"_cty","_geo","_prprn"},
"farmland":{"_loc_sr"},
"farmlands":{"_loc_sr"},
"farms":{"_loc_sr"},
"farmstead":{"_loc_sr"},
"farmsteads":{"_loc_sr"},
"farmyard":{"_loc_sr"},
"Farnese":{"_anim","_nme","_prprn","_sb"},
"Farnham":{"_prprn"},
"faroese":{"_anim","_prprn","_sb"},
"farragut":{"_anim","_nme","_prprn","_sb"},
"Farrell":{"_anim","_nme","_prprn","_sb"},
"farrier":{"_anim","_sb"},
"Farsi":{"_prprn"},
"fart":{"_loc_sr"},
"farther":{"_loc"},
"farting":{"_loc_sr"},
"fascinated":{"_past","_psych"},
"fascinates":{"_psych"},
"fascinating":{"_psych"},
"Fascism":{"_prprn"},
"fascist":{"_sb"},
"fashionable":{"_sb"},
"Fassbinder":{"_anim","_nme","_prprn","_sb"},
"fast":{"_loc_sr"},
"fasting":{"_loc_sr"},
"Fatah":{"_prprn"},
"fatalist":{"_anim","_sb"},
"fatalists":{"_anim","_sb"},
"fathead":{"_anim","_sb"},
"father":{"_anim","_masc","_sb"},
"father-and-son":{"_anim","_masc","_sb"},
"father-brother":{"_anim","_masc","_sb"},
"father-confessor":{"_anim","_masc","_sb"},
"father-god":{"_anim","_masc","_sb"},
"father-murder":{"_anim","_masc","_sb"},
"father-son":{"_anim","_masc","_sb"},
"fathered":{"_past"},
"fatherland":{"_loc_sr"},
"fathers":{"_anim","_masc","_sb"},
"fatima":{"_anim","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"fatimah":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"fatso":{"_sb"},
"fatsoes":{"_sb"},
"fattened":{"_past"},
"fatty":{"_anim","_sb"},
"Faulkner":{"_anim","_nme","_prprn","_sb"},
"faultfinder":{"_anim","_sb"},
"faun":{"_anim","_masc","_sb"},
"fauna":{"_anim"},
"Fauntleroy":{"_prprn"},
"faunus":{"_anim","_masc","_nme","_prprn","_sb"},
"Faust":{"_prprn"},
"Faustus":{"_prprn"},
"Fauve":{"_prprn"},
"fauvist":{"_anim","_sb"},
"favor":{"_loc_sr"},
"favored":{"_loc_sr","_past"},
"favorer":{"_anim","_sb"},
"favoring":{"_loc_sr"},
"favorite":{"_sb"},
"favorites":{"_sb"},
"favour":{"_loc_sr"},
"favourite":{"_sb"},
"Fawcett":{"_prprn"},
"Fawkes":{"_anim","_nme","_prprn","_sb"},
"fawn-coloured":{"_anim"},
"fawned":{"_past"},
"fawner":{"_anim","_sb"},
"faxed":{"_past"},
"Faye":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"fayetteville":{"_cty","_geo","_prprn"},
"faze":{"_psych"},
"fazed":{"_past","_psych"},
"FBI":{"_prprn"},
"fcc":{"_prprn"},
"fcs":{"_prprn"},
"fda":{"_prprn"},
"fdic":{"_prprn"},
"fe":{"_prprn"},
"feared":{"_past"},
"feasted":{"_past"},
"feathered":{"_past"},
"featherweight":{"_anim","_sb"},
"featured":{"_past"},
"Feb":{"_prprn","_tme"},
"Feb.":{"_prprn","_tme"},
"Februaries":{"_prprn"},
"February":{"_prprn","_tme"},
"fechner":{"_anim","_nme","_prprn","_sb"},
"fed":{"_past"},
"federalized":{"_loc_sr","_past"},
"federated":{"_past"},
"Federico":{"_prprn"},
"feeder":{"_anim"},
"feeders":{"_anim"},
"feigned":{"_past"},
"felicia":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"feline":{"_sb"},
"Felix":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"fella":{"_anim","_masc","_sb"},
"fellah":{"_anim","_sb"},
"fellas":{"_anim","_masc","_sb"},
"felled":{"_past"},
"fellers":{"_anim","_sb"},
"Fellini":{"_anim","_nme","_prprn","_sb"},
"fellow":{"_anim","_masc","_sb"},
"fellow-countryman":{"_anim","_masc","_sb"},
"fellow-craftsmen":{"_anim","_masc","_sb"},
"fellow-creatures":{"_anim","_masc","_sb"},
"fellow-employees":{"_anim","_masc","_sb"},
"fellow-feeling":{"_anim","_masc","_sb"},
"fellow-men":{"_anim","_masc","_sb"},
"fellows":{"_anim","_masc","_sb"},
"felons":{"_anim","_sb"},
"felted":{"_past"},
"felucca":{"_loc_sr"},
"female":{"_anim","_fem","_sb"},
"female-dominated":{"_anim","_fem","_sb"},
"female-headed":{"_anim","_fem","_sb"},
"females":{"_anim","_fem","_sb"},
"feminist":{"_anim","_sb"},
"feminists":{"_anim","_sb"},
"femme":{"_anim","_fem","_sb"},
"femtosecond":{"_anim","_sb","_tme"},
"fen":{"_loc_sr"},
"fenced":{"_past"},
"fenced-in":{"_past"},
"fencer":{"_anim","_sb"},
"fended":{"_past"},
"Fenton":{"_prprn"},
"ferber":{"_anim","_nme","_prprn","_sb"},
"Fergus":{"_prprn"},
"Ferguson":{"_cty","_geo","_prprn"},
"fermat":{"_anim","_nme","_prprn","_sb"},
"fermented":{"_past"},
"fernery":{"_loc_sr"},
"ferrara":{"_cty","_geo","_prprn"},
"Ferrari":{"_prprn"},
"ferret-sized":{"_anim"},
"ferreted":{"_past"},
"ferrets":{"_anim"},
"ferried":{"_past"},
"Ferrier":{"_anim","_sb"},
"ferries":{"_fem"},
"Ferris":{"_prprn"},
"ferry":{"_fem"},
"ferryman":{"_anim","_sb"},
"fertiliser":{"_anim","_sb"},
"fertilized":{"_past"},
"fes":{"_geo","_prprn"},
"festoon":{"_loc_sr"},
"festooned":{"_loc_sr","_past"},
"festooning":{"_loc_sr"},
"fet":{"_prprn"},
"fetch":{"_loc_sr"},
"fetched":{"_loc_sr","_past"},
"fetching":{"_loc_sr"},
"feted":{"_past"},
"fetishist":{"_sb"},
"fetter":{"_loc_sr"},
"fettered":{"_loc_sr","_past"},
"fetuses":{"_anim"},
"Feuchtwanger":{"_anim","_nme","_prprn","_sb"},
"feudatory":{"_anim","_sb"},
"fevered":{"_past"},
"few":{"_quant","_sb"},
"fewer":{"_quant"},
"fewest":{"_quant","_sb"},
"Feynman":{"_anim","_nme","_prprn","_sb"},
"fha":{"_prprn"},
"fiance":{"_anim","_masc","_sb"},
"fiancee":{"_anim","_fem","_sb"},
"Fiberglas":{"_prprn"},
"fica":{"_prprn"},
"Fichte":{"_anim","_nme","_prprn","_sb"},
"fictionalise":{"_loc_sr"},
"fictionalize":{"_loc_sr"},
"fictionalized":{"_loc_sr","_past"},
"fiddler":{"_anim","_sb"},
"fidget":{"_loc_sr"},
"Fiedler":{"_anim","_nme","_prprn","_sb"},
"fief":{"_loc_sr"},
"field":{"_loc_sr"},
"field-based":{"_loc_sr"},
"field-crop":{"_loc_sr"},
"field-crop-seeds":{"_loc_sr"},
"field-flattening":{"_loc_sr"},
"field-goal":{"_loc_sr"},
"field-hands":{"_loc_sr"},
"field-officials":{"_loc_sr"},
"field-sequential":{"_loc_sr"},
"field-service":{"_loc_sr"},
"field-services":{"_loc_sr"},
"field-test":{"_loc_sr"},
"fielded":{"_loc_sr","_past"},
"fielders":{"_anim","_sb"},
"fielding":{"_loc_sr"},
"fields":{"_loc_sr"},
"fieldsman":{"_anim","_sb"},
"fieldworker":{"_anim","_sb"},
"Fiennes":{"_prprn"},
"fifo":{"_prprn"},
"fifteen":{"_quant"},
"fifteen-mile":{"_num","_quant"},
"fifteen-minute":{"_num","_quant"},
"fifteen-sixteenths":{"_num","_quant"},
"fifteenfold":{"_quant"},
"fifties":{"_num","_quant"},
"fifty":{"_num","_quant"},
"fifty-cent":{"_num","_quant"},
"fifty-dollar":{"_num","_quant"},
"fifty-fifth":{"_num","_quant"},
"fifty-five":{"_num","_quant"},
"fifty-four":{"_num","_quant"},
"fifty-nine":{"_num","_quant"},
"fifty-ninth":{"_num","_quant"},
"fifty-odd":{"_num","_quant"},
"fifty-pound":{"_num","_quant"},
"fifty-seven":{"_num","_quant"},
"fifty-six":{"_num","_quant"},
"fifty-three":{"_num","_quant"},
"fifty-two":{"_num","_quant"},
"Figaro":{"_prprn"},
"fight":{"_loc_sr"},
"fighter":{"_anim","_sb"},
"fighter-jet":{"_anim","_sb"},
"fighter-plane":{"_anim","_sb"},
"fighters":{"_anim","_sb"},
"fighting":{"_loc_sr"},
"figured":{"_past"},
"figurehead":{"_anim","_sb"},
"Fiji":{"_cntry","_geo","_prprn"},
"Fijian":{"_anim","_prprn","_sb"},
"fijis":{"_cntry","_geo","_prprn"},
"filched":{"_past"},
"file":{"_loc_sr"},
"file-like":{"_loc_sr"},
"file-those":{"_loc_sr"},
"filed":{"_loc_sr","_past"},
"filefish":{"_anim"},
"filer":{"_anim","_sb"},
"filers":{"_anim","_sb"},
"files":{"_loc_sr"},
"filiation":{"_sb"},
"filibuster":{"_anim","_sb"},
"filibusterer":{"_anim","_sb"},
"filibusters":{"_anim","_sb"},
"filing":{"_loc_sr"},
"Filipino":{"_anim","_prprn","_sb"},
"Filipinos":{"_anim","_prprn","_sb"},
"fill-in":{"_sb"},
"fill-ins":{"_sb"},
"filled":{"_past"},
"filleted":{"_loc_sr","_past"},
"Fillmore":{"_anim","_nme","_prprn","_sb"},
"filly":{"_anim"},
"filmmaker":{"_anim","_sb"},
"filmmakers":{"_anim","_sb"},
"Filofaxes":{"_prprn"},
"filter":{"_loc_sr"},
"filtered":{"_loc_sr","_past"},
"filtering":{"_loc_sr"},
"filtrate":{"_loc_sr"},
"finagled":{"_past"},
"finagler":{"_anim","_sb"},
"finalist":{"_anim","_sb"},
"finalists":{"_anim","_sb"},
"finalize":{"_loc_sr"},
"finalized":{"_loc_sr","_past"},
"finalizing":{"_loc_sr"},
"financed":{"_past"},
"financer":{"_anim","_sb"},
"financiers":{"_anim","_sb"},
"finback":{"_anim"},
"finch":{"_anim"},
"finder":{"_anim","_sb"},
"finders":{"_anim","_sb"},
"fine-tuned":{"_past"},
"fined":{"_past"},
"finessed":{"_past"},
"fingered":{"_past"},
"finish":{"_psych"},
"finished":{"_past","_psych"},
"finisher":{"_anim","_sb"},
"finishers":{"_anim","_sb"},
"finishing":{"_psych"},
"finishing-school":{"_psych"},
"finitely":{"_tme"},
"Finland":{"_cntry","_geo","_prprn"},
"Finn":{"_anim","_prprn","_sb"},
"finnbogadottir":{"_anim","_nme","_prprn","_sb"},
"finned":{"_past"},
"Finney":{"_anim","_nme","_prprn","_sb"},
"finnic":{"_prprn"},
"Finnish":{"_prprn","_sb"},
"finno-ugrian":{"_prprn"},
"finno-ugric":{"_prprn"},
"Finns":{"_anim","_prprn","_sb"},
"Finsbury":{"_prprn"},
"Fiona":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"fire-eater":{"_anim","_sb"},
"firebombed":{"_past"},
"firebox":{"_loc_sr"},
"firebreak":{"_loc_sr"},
"firebreaks":{"_loc_sr"},
"fired":{"_past"},
"firefighter":{"_sb"},
"firemen":{"_anim","_sb"},
"firenze":{"_geo","_prprn"},
"fireside":{"_loc_sr"},
"firetrap":{"_loc_sr"},
"firework":{"_loc_sr"},
"fireworks":{"_loc_sr"},
"firkin":{"_loc_sr"},
"firm":{"_anim","_sb"},
"firmed":{"_past"},
"firms":{"_anim","_sb"},
"first":{"_sb"},
"first-aid":{"_sb"},
"first-amendment":{"_sb"},
"first-come-first-served":{"_sb"},
"first-ever":{"_sb"},
"first-floor":{"_sb"},
"first-grader":{"_sb"},
"first-hand":{"_sb"},
"first-nighter":{"_anim","_sb"},
"first-person":{"_sb"},
"first-rater":{"_sb"},
"first-run":{"_sb"},
"first-strike":{"_sb"},
"first-time":{"_sb"},
"firstborn":{"_anim","_sb"},
"firsts":{"_sb"},
"firth":{"_loc_sr"},
"fiscal":{"_anim","_sb"},
"fiscal-agent":{"_anim","_sb"},
"fiscal-first":{"_anim","_sb"},
"fiscal-first-quarter":{"_anim","_sb"},
"fiscal-fourth":{"_anim","_sb"},
"fiscal-third":{"_anim","_sb"},
"fiscal-year":{"_anim","_sb"},
"fischer":{"_anim","_nme","_prprn","_sb"},
"fish":{"_anim"},
"fish-export":{"_anim"},
"fish-fly":{"_anim"},
"fish-processing":{"_anim"},
"fish-worship":{"_anim"},
"fished":{"_past"},
"fisher":{"_anim","_sb"},
"fisherman":{"_anim","_sb"},
"fishermen":{"_anim","_sb"},
"fishers":{"_anim","_sb"},
"fishes":{"_anim"},
"fishmonger":{"_anim","_sb"},
"fishmongers":{"_anim","_sb"},
"fishtail":{"_loc_sr"},
"fishwife":{"_anim","_fem","_sb"},
"Fiske":{"_anim","_nme","_prprn","_sb"},
"fissiped":{"_anim"},
"fissured":{"_past"},
"fisted":{"_loc_sr","_past"},
"fistula":{"_loc_sr"},
"fit":{"_past"},
"Fitch":{"_anim","_prprn","_sb"},
"Fitzgerald":{"_anim","_nme","_prprn","_sb"},
"Fitzsimmons":{"_anim","_nme","_prprn","_sb"},
"five":{"_quant"},
"five-a-week":{"_num","_quant"},
"five-and-a-half":{"_num","_quant"},
"five-and-twenty":{"_num","_quant"},
"five-blade":{"_num","_quant"},
"five-block":{"_num","_quant"},
"five-by-eight-inch":{"_num","_quant"},
"five-cent":{"_num","_quant"},
"five-column":{"_num","_quant"},
"five-consecutive":{"_num","_quant"},
"five-coordinate":{"_num","_quant"},
"five-count":{"_num","_quant"},
"five-course":{"_num","_quant"},
"five-cylinder":{"_num","_quant"},
"five-day":{"_num","_quant"},
"five-days-a-week":{"_num","_quant"},
"five-fold":{"_num","_quant"},
"five-foot":{"_num","_quant"},
"five-foot-wide":{"_num","_quant"},
"five-gallon":{"_num","_quant"},
"five-game":{"_num","_quant"},
"five-hitter":{"_num","_quant"},
"five-home":{"_num","_quant"},
"five-home-run":{"_num","_quant"},
"five-hour":{"_num","_quant"},
"five-hundred-dollar":{"_num","_quant"},
"five-hundred-year-old":{"_num","_quant"},
"five-hundredth":{"_num","_quant"},
"five-inch":{"_num","_quant"},
"five-judge":{"_num","_quant"},
"five-lobed":{"_num","_quant"},
"five-member":{"_num","_quant"},
"five-membered":{"_num","_quant"},
"five-mile":{"_num","_quant"},
"five-month":{"_num","_quant"},
"five-month-old":{"_num","_quant"},
"five-nation":{"_num","_quant"},
"five-needled":{"_quant"},
"five-party":{"_num","_quant"},
"five-percentage-point":{"_num","_quant"},
"five-person":{"_num","_quant"},
"five-petaled":{"_num","_quant"},
"five-petalled":{"_num","_quant"},
"five-pfennig":{"_num","_quant"},
"five-ply":{"_num","_quant"},
"five-point":{"_num","_quant"},
"five-pointed":{"_quant"},
"five-pound":{"_num","_quant"},
"five-round":{"_num","_quant"},
"five-row":{"_num","_quant"},
"five-session":{"_num","_quant"},
"five-seventeen":{"_num","_quant"},
"five-sided":{"_quant"},
"five-speed":{"_num","_quant"},
"five-spot":{"_num","_quant"},
"five-story":{"_num","_quant"},
"five-volume":{"_num","_quant"},
"five-week":{"_num","_quant"},
"five-year-old":{"_num","_quant"},
"five-years":{"_num","_quant"},
"fivefold":{"_quant"},
"fives":{"_num","_quant"},
"fix":{"_loc_sr"},
"fixated":{"_past"},
"fixed":{"_loc_sr","_past"},
"fixed-dollar":{"_loc_sr","_past"},
"fixed-income":{"_loc_sr","_past"},
"fixed-price":{"_loc_sr","_past"},
"fixed-rate":{"_loc_sr","_past"},
"fixed-repayment":{"_loc_sr","_past"},
"fixer":{"_anim","_sb"},
"fixer-upper":{"_anim","_sb"},
"fixers":{"_anim","_sb"},
"fixing":{"_loc_sr"},
"fizzled":{"_past"},
"Fla":{"_prprn","_stte"},
"Fla.":{"_prprn","_stte"},
"flabbergast":{"_psych"},
"flabbergasted":{"_past","_psych"},
"flag-waver":{"_anim","_sb"},
"flag-wavers":{"_anim","_sb"},
"flagellant":{"_anim","_sb"},
"flagged":{"_loc_sr","_past"},
"flagon":{"_loc_sr"},
"Flaherty":{"_anim","_nme","_prprn","_sb"},
"flailed":{"_past"},
"flake":{"_loc_sr"},
"flamed":{"_past"},
"flamingo":{"_anim"},
"flaminius":{"_anim","_nme","_prprn","_sb"},
"Flanagan":{"_anim","_nme","_prprn","_sb"},
"Flanders":{"_geo","_prprn"},
"flanked":{"_past"},
"flanker":{"_anim","_sb"},
"Flannery":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"flapped":{"_past"},
"flapper":{"_anim","_fem","_sb"},
"flappers":{"_anim","_fem","_sb"},
"flared":{"_past"},
"flashed":{"_past"},
"flask":{"_loc_sr"},
"flatfish":{"_anim"},
"flatfoot":{"_loc_sr"},
"flathead":{"_anim","_prprn","_sb"},
"flattened":{"_past"},
"flatter":{"_psych"},
"flattered":{"_past","_psych"},
"flattering":{"_psych"},
"flatworm":{"_anim"},
"Flaubert":{"_anim","_nme","_prprn","_sb"},
"flaunted":{"_past"},
"flavored":{"_past"},
"flavorer":{"_anim","_sb"},
"flavourer":{"_anim","_sb"},
"flawed":{"_past"},
"flea":{"_anim"},
"flea-infested":{"_anim"},
"fleabag":{"_loc_sr"},
"fleas":{"_anim"},
"flecked":{"_past"},
"fled":{"_past"},
"fledged":{"_past"},
"fledglings":{"_anim"},
"fleeced":{"_past"},
"fleer":{"_loc_sr"},
"fleeting":{"_loc_sr"},
"Fleming":{"_anim","_nme","_prprn","_sb"},
"Flemings":{"_anim","_nme","_prprn","_sb"},
"Flemish":{"_prprn"},
"flense":{"_loc_sr"},
"fleshpots":{"_loc_sr"},
"fletcher":{"_anim","_sb"},
"Fleury":{"_anim","_nme","_prprn","_sb"},
"flew":{"_past"},
"flex":{"_loc_sr"},
"flexed":{"_loc_sr","_past"},
"flibbertigibbet":{"_anim","_sb"},
"flicked":{"_past"},
"flicker":{"_loc_sr"},
"flickered":{"_loc_sr","_past"},
"flickering":{"_loc_sr"},
"flickertail":{"_anim"},
"flier":{"_anim","_sb"},
"fliers":{"_anim","_sb"},
"flies":{"_anim"},
"flighted":{"_loc_sr","_past"},
"flighting":{"_loc_sr"},
"flinch":{"_loc_sr"},
"flinching":{"_loc_sr"},
"flip":{"_loc_sr"},
"flipped":{"_loc_sr","_past"},
"flirts":{"_anim","_sb"},
"flit":{"_loc_sr"},
"flitch":{"_anim"},
"flitted":{"_loc_sr","_past"},
"flittered":{"_past"},
"flitting":{"_loc_sr"},
"floated":{"_past"},
"flocculated":{"_past"},
"flocked":{"_loc_sr","_past"},
"flocking":{"_loc_sr"},
"flocks":{"_anim"},
"Flodden":{"_geo","_loc_sr","_prprn"},
"flogger":{"_anim","_sb"},
"flood-insurance":{"_loc_sr"},
"flood-lighted":{"_loc_sr"},
"flood-prone":{"_loc_sr"},
"flooded":{"_past"},
"floodlighted":{"_past"},
"floodlit":{"_past"},
"floor-covering":{"_loc_sr"},
"floor-length":{"_loc_sr"},
"floor-level":{"_loc_sr"},
"flooring":{"_psych"},
"floors":{"_loc_sr"},
"floorwalker":{"_anim","_sb"},
"floozy":{"_anim","_fem","_sb"},
"flop":{"_loc_sr"},
"flopped":{"_loc_sr","_past"},
"Florence":{"_cty","_geo","_prprn"},
"Florentine":{"_anim","_prprn","_sb"},
"florey":{"_anim","_nme","_prprn","_sb"},
"Florida":{"_geo","_prprn","_stte"},
"Florio":{"_anim","_nme","_prprn","_sb"},
"florist":{"_anim","_sb"},
"flory":{"_anim","_nme","_prprn","_sb"},
"flounce":{"_loc_sr"},
"flounced":{"_loc_sr","_past"},
"flounder":{"_loc_sr"},
"floundered":{"_loc_sr","_past"},
"floundering":{"_loc_sr"},
"flounders":{"_anim"},
"floured":{"_past"},
"flourished":{"_loc_sr","_past"},
"flouted":{"_loc_sr","_past"},
"flouter":{"_anim","_sb"},
"flouting":{"_loc_sr"},
"flowed":{"_loc_sr","_past"},
"flowered":{"_past"},
"flubbed":{"_past"},
"fluke":{"_anim"},
"flung":{"_past"},
"flunk":{"_loc_sr"},
"flunked":{"_loc_sr","_past"},
"flunkey":{"_anim","_masc","_sb"},
"flunky":{"_anim","_sb"},
"flurried":{"_past"},
"flush-seamed":{"_loc_sr"},
"flushed":{"_past"},
"flushes":{"_loc_sr"},
"fluster":{"_psych"},
"flustered":{"_past","_psych"},
"fluttered":{"_loc_sr","_past"},
"fluttering":{"_loc_sr"},
"fly":{"_loc_sr"},
"fly-by-nighters":{"_anim","_sb"},
"fly-dotted":{"_anim"},
"flycatcher":{"_anim"},
"Flynn":{"_anim","_nme","_prprn","_sb"},
"flyover":{"_loc_sr"},
"flyweight":{"_anim","_sb"},
"FmHA":{"_prprn"},
"fnma":{"_prprn"},
"fo":{"_prprn"},
"foals":{"_anim"},
"foamed-core":{"_past"},
"foamed-in-place":{"_past"},
"focused":{"_loc_sr","_past"},
"focused-factory":{"_loc_sr","_past"},
"focusing":{"_loc_sr"},
"focussed":{"_loc_sr","_past"},
"focussing":{"_loc_sr"},
"foeman":{"_anim","_masc","_sb"},
"foetus":{"_anim","_sb"},
"Fogg":{"_prprn"},
"Foggia":{"_cty","_geo","_prprn"},
"foil":{"_loc_sr"},
"foiled":{"_loc_sr","_past"},
"foiling":{"_loc_sr"},
"foist":{"_loc_sr"},
"Fokine":{"_anim","_nme","_prprn","_sb"},
"Fokker":{"_anim","_nme","_prprn","_sb"},
"fold":{"_loc_sr"},
"folded":{"_loc_sr","_past"},
"folder":{"_loc_sr"},
"folders":{"_loc_sr"},
"folding":{"_loc_sr"},
"foliated":{"_past"},
"folk":{"_sb"},
"folk-lore":{"_sb"},
"folk-music":{"_sb"},
"folks":{"_anim","_sb"},
"follow":{"_loc_sr"},
"followed":{"_loc_sr","_past"},
"follower":{"_anim","_sb"},
"followers":{"_anim","_sb"},
"following":{"_loc_sr"},
"fomenter":{"_anim","_sb"},
"fondled":{"_past"},
"fondler":{"_anim","_sb"},
"Fonseca":{"_prprn"},
"font":{"_loc_sr","_sb"},
"Fontainebleau":{"_cty","_geo","_prprn"},
"Fontana":{"_cty","_geo","_prprn"},
"fontanne":{"_anim","_nme","_prprn","_sb"},
"Fonteyn":{"_anim","_nme","_prprn","_sb"},
"fonts":{"_loc_sr","_sb"},
"foodie":{"_anim","_sb"},
"fooled":{"_past"},
"fools":{"_anim","_sb"},
"footbath":{"_loc_sr"},
"footed":{"_loc_sr","_past"},
"foothill":{"_loc_sr"},
"foothills":{"_loc_sr"},
"foothold":{"_loc_sr"},
"footholds":{"_loc_sr"},
"footing":{"_loc_sr"},
"footnoted":{"_loc_sr","_past"},
"footpad":{"_anim","_sb"},
"footslog":{"_loc_sr"},
"fop":{"_anim","_masc","_sb"},
"forager":{"_anim","_sb"},
"foram":{"_anim"},
"foraminifer":{"_anim"},
"foray":{"_loc_sr"},
"forbad":{"_past"},
"forbade":{"_past"},
"forbears":{"_anim","_sb"},
"Forbes":{"_anim","_nme","_prprn","_sb"},
"forbore":{"_past"},
"forced":{"_loc_sr","_past"},
"forcing":{"_loc_sr"},
"Ford":{"_anim","_loc_sr","_prprn","_sb"},
"fords":{"_loc_sr"},
"forebear":{"_anim","_sb"},
"forecast":{"_past"},
"forecasted":{"_past"},
"forecaster":{"_anim","_sb"},
"forecasters":{"_anim","_sb"},
"foreclosed":{"_past"},
"forefather":{"_anim","_sb"},
"forefathers":{"_anim","_sb"},
"forefront":{"_loc_sr"},
"foreigner":{"_anim","_sb"},
"foreigners":{"_anim","_sb"},
"foreland":{"_loc_sr"},
"forenoon":{"_tme"},
"foreordain":{"_loc_sr"},
"foreordained":{"_loc_sr","_past"},
"foresaw":{"_past"},
"foreshadowed":{"_past"},
"foreshock":{"_loc_sr"},
"foreshorten":{"_loc_sr"},
"foreshortened":{"_loc_sr","_past"},
"foreshortening":{"_loc_sr"},
"forest":{"_loc_sr"},
"forest-product":{"_loc_sr"},
"forestall":{"_loc_sr"},
"forestalled":{"_loc_sr","_past"},
"forestalling":{"_loc_sr"},
"forested":{"_past"},
"forester":{"_anim","_sb"},
"forests":{"_loc_sr"},
"forevermore":{"_tme"},
"forgave":{"_past"},
"forgiver":{"_anim","_sb"},
"forgot":{"_past"},
"forked":{"_past"},
"forklift":{"_loc_sr"},
"formalised":{"_past"},
"formalize":{"_loc_sr"},
"formalized":{"_loc_sr","_past"},
"formalizes":{"_loc_sr"},
"Forman":{"_prprn"},
"Formby":{"_prprn"},
"formed":{"_past"},
"formed-tooth":{"_past"},
"formerly":{"_tme"},
"Formica":{"_prprn"},
"formosa":{"_cntry","_geo","_prprn"},
"formulate":{"_loc_sr"},
"formulated":{"_loc_sr","_past"},
"formulates":{"_loc_sr"},
"formulating":{"_loc_sr"},
"fornax":{"_prprn"},
"fornicator":{"_anim","_sb"},
"Forrest":{"_anim","_nme","_prprn","_sb"},
"Forster":{"_anim","_nme","_prprn","_sb"},
"forswore":{"_past"},
"fort":{"_loc_sr"},
"fort-lamy":{"_geo","_prprn"},
"forthwith":{"_tme"},
"forties":{"_num","_quant"},
"fortified":{"_loc_sr","_past"},
"fortify":{"_loc_sr"},
"fortnight":{"_tme"},
"fortran":{"_prprn"},
"fortress":{"_loc_sr"},
"fortress-like":{"_loc_sr"},
"fortresses":{"_loc_sr"},
"forts":{"_loc_sr"},
"fortuna":{"_anim","_fem","_nme","_prprn","_sb"},
"fortunate":{"_anim","_sb"},
"fortune-tellers":{"_anim","_sb"},
"fortuneteller":{"_anim","_sb"},
"forty":{"_quant"},
"forty-eight":{"_num","_quant"},
"forty-eighth":{"_num","_quant"},
"forty-fifth":{"_num","_quant"},
"forty-first":{"_num","_quant"},
"forty-fold":{"_num","_quant"},
"forty-four":{"_num","_quant"},
"forty-fourth":{"_num","_quant"},
"forty-nine":{"_num","_quant"},
"forty-niner":{"_anim","_sb"},
"forty-niners":{"_anim","_sb"},
"forty-ninth":{"_num","_quant"},
"forty-one":{"_num","_quant"},
"forty-second":{"_num","_quant"},
"forty-seven":{"_num","_quant"},
"forty-seventh":{"_num","_quant"},
"forty-six":{"_num","_quant"},
"forty-sixth":{"_num","_quant"},
"forty-third":{"_num","_quant"},
"forty-three":{"_num","_quant"},
"forum":{"_loc_sr"},
"forums":{"_loc_sr"},
"forward":{"_loc_sr"},
"forward-rate":{"_anim","_sb"},
"forwarded":{"_loc_sr","_past"},
"forwarding":{"_loc_sr"},
"fossilised":{"_past"},
"fossilist":{"_anim","_sb"},
"fossilize":{"_loc_sr"},
"fossilized":{"_loc_sr","_past"},
"Foucault":{"_anim","_nme","_prprn","_sb"},
"fought":{"_loc_sr","_past"},
"fought-for":{"_loc_sr","_past"},
"founded":{"_past"},
"founder":{"_anim","_sb"},
"founder-conductor":{"_anim","_sb"},
"founder-originator":{"_anim","_sb"},
"foundered":{"_past"},
"founders":{"_anim","_sb"},
"foundling":{"_anim","_sb"},
"foundress":{"_anim","_fem","_sb"},
"fountain":{"_loc_sr"},
"fountain-falls":{"_loc_sr"},
"fountain-head":{"_loc_sr"},
"fountains":{"_loc_sr"},
"four":{"_quant"},
"four-door":{"_num","_quant"},
"four-engined":{"_quant"},
"four-eyes":{"_num","_quant"},
"four-flusher":{"_anim","_sb"},
"four-fold":{"_num","_quant"},
"four-for-one":{"_num","_quant"},
"four-hundredth":{"_num","_quant"},
"four-mile":{"_num","_quant"},
"four-point":{"_num","_quant"},
"four-speed":{"_num","_quant"},
"four-square":{"_num","_quant"},
"four-stroke":{"_num","_quant"},
"four-wheel-drive":{"_num","_quant"},
"four-wheeled":{"_quant"},
"fourfold":{"_quant"},
"fourier":{"_anim","_nme","_prprn","_sb"},
"Fournier":{"_prprn"},
"fourscore":{"_num","_quant"},
"foursome":{"_anim","_sb"},
"fourteen":{"_num","_quant"},
"fourteen-nation":{"_num","_quant"},
"fourteen-team":{"_num","_quant"},
"fourteen-year-old":{"_num","_quant"},
"fowl":{"_anim"},
"Fowler":{"_anim","_sb"},
"fox-hounds":{"_anim"},
"fox-terrier":{"_anim"},
"fox-trot":{"_anim"},
"foxes":{"_anim"},
"foxhound":{"_anim"},
"fr":{"_prprn"},
"Fra":{"_prprn"},
"fractionate":{"_loc_sr"},
"fragment":{"_loc_sr"},
"fragmentize":{"_loc_sr"},
"Fragonard":{"_anim","_nme","_prprn","_sb"},
"framed":{"_past"},
"Framingham":{"_cty","_geo","_prprn"},
"franca":{"_cty","_geo","_prprn"},
"France":{"_anim","_cntry","_geo","_nme","_prprn","_sb"},
"Frances":{"_anim","_cntry","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"Francesca":{"_anim","_nme","_prprn","_sb"},
"franche-comte":{"_geo","_prprn","_stte"},
"franchised":{"_past"},
"Francis":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Franciscan":{"_prprn","_sb"},
"Franciscans":{"_prprn","_sb"},
"Francisco":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"franck":{"_anim","_nme","_prprn","_sb"},
"Franco":{"_anim","_nme","_prprn","_sb"},
"franco-american":{"_anim","_prprn","_sb"},
"Franconia":{"_geo","_prprn"},
"francophil":{"_prprn"},
"Francophile":{"_anim","_prprn","_sb"},
"Francophobe":{"_anim","_prprn","_sb"},
"Francophone":{"_prprn","_sb"},
"Frank":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"franked":{"_loc_sr","_past"},
"Frankenstein":{"_prprn"},
"Frankfort":{"_cty","_geo","_prprn"},
"Frankfurt":{"_geo","_prprn"},
"franking":{"_loc_sr"},
"frankish":{"_prprn"},
"Franklin":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"Fraser":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"fraternities":{"_anim","_sb"},
"fraternity":{"_anim","_sb"},
"fraternized":{"_past"},
"Fraulein":{"_anim","_fem","_prprn","_sb"},
"frayed":{"_past"},
"Frazer":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Frazier":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"frazzled":{"_past"},
"freaked":{"_past"},
"freckled":{"_past"},
"Fred":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Frederic":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Frederick":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"fredericksburg":{"_cty","_geo","_prprn"},
"fredericton":{"_cty","_geo","_prprn"},
"Fredric":{"_prprn"},
"Fredrick":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"free-associate":{"_loc_sr"},
"freebooter":{"_anim","_sb"},
"freebooters":{"_anim","_sb"},
"freed":{"_past"},
"freedman":{"_anim","_masc","_sb"},
"freedmen":{"_anim","_masc","_sb"},
"freedwoman":{"_anim","_fem","_sb"},
"freeholders":{"_anim","_sb"},
"freelancers":{"_anim","_sb"},
"freeload":{"_loc_sr"},
"freeloader":{"_anim","_sb"},
"freemason":{"_sb"},
"freestylers":{"_anim","_sb"},
"freethinker":{"_anim","_sb"},
"freethinkers":{"_anim","_sb"},
"Freetown":{"_cty","_geo","_prprn"},
"freewheeler":{"_anim","_sb"},
"freewheelers":{"_anim","_sb"},
"freeze-dried":{"_past"},
"freezer":{"_loc_sr"},
"freezers":{"_loc_sr"},
"freezing":{"_loc_sr","_wthr"},
"Fremantle":{"_prprn"},
"Fremont":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"French":{"_anim","_prprn","_sb"},
"French-fry":{"_loc_sr"},
"french-speaking":{"_loc_sr"},
"Frenchify":{"_loc_sr"},
"Frenchwoman":{"_anim","_fem","_prprn","_sb"},
"frenzied":{"_loc_sr","_past","_psych"},
"Freon":{"_prprn"},
"frequently":{"_tme"},
"frescoed":{"_loc_sr","_past"},
"frescoing":{"_loc_sr"},
"freshen":{"_loc_sr"},
"freshened":{"_loc_sr","_past"},
"freshener":{"_anim","_sb"},
"fresher":{"_anim","_sb"},
"freshman":{"_anim","_sb"},
"freshmen":{"_anim","_sb"},
"fresnel":{"_anim","_nme","_prprn","_sb"},
"Fresno":{"_cty","_geo","_prprn"},
"fret":{"_psych"},
"fretted":{"_past","_psych"},
"Freud":{"_anim","_nme","_prprn","_sb"},
"Freudian":{"_anim","_prprn","_sb"},
"frey":{"_anim","_masc","_nme","_prprn","_sb"},
"Freya":{"_anim","_fem","_nme","_prprn","_sb"},
"freyja":{"_prprn"},
"freyr":{"_prprn"},
"fri":{"_day","_prprn","_tme"},
"friar":{"_anim","_masc","_sb"},
"friar's-cowl":{"_anim","_masc","_sb"},
"friary":{"_loc_sr"},
"frick":{"_anim","_nme","_prprn","_sb"},
"Friday":{"_day","_prprn","_tme"},
"Fridays":{"_day","_prprn","_tme"},
"fried":{"_past"},
"Friedan":{"_anim","_nme","_prprn","_sb"},
"Friedman":{"_anim","_nme","_prprn","_sb"},
"Friedrich":{"_prprn"},
"friend":{"_anim","_sb"},
"friend-of-the-court":{"_anim","_sb"},
"Friends":{"_anim","_sb"},
"fries":{"_anim"},
"Friesian":{"_prprn"},
"friesland":{"_geo","_prprn"},
"frigate":{"_fem"},
"frigates":{"_fem"},
"Frigg":{"_anim","_fem","_nme","_prprn","_sb"},
"frigga":{"_prprn"},
"frighten":{"_psych"},
"frightening":{"_psych"},
"frightens":{"_psych"},
"frill":{"_loc_sr"},
"fringed":{"_past"},
"fringed-wrapped":{"_past"},
"Frisbee":{"_prprn"},
"frisch":{"_anim","_nme","_prprn","_sb"},
"Frisco":{"_prprn"},
"Frisian":{"_anim","_prprn","_sb"},
"frisk":{"_loc_sr"},
"frittered":{"_past"},
"friuli":{"_geo","_prprn"},
"frizz":{"_loc_sr"},
"frizzled":{"_past"},
"frobisher":{"_anim","_nme","_prprn","_sb"},
"froebel":{"_anim","_nme","_prprn","_sb"},
"frog":{"_anim"},
"frog's-bit":{"_anim"},
"frog-eating":{"_anim"},
"frog-haiku":{"_anim"},
"frogfish":{"_anim"},
"frogman":{"_anim","_sb"},
"frogmen":{"_anim","_sb"},
"frogs":{"_anim"},
"Froissart":{"_anim","_nme","_prprn","_sb"},
"Fromm":{"_anim","_nme","_prprn","_sb"},
"front-loaded":{"_past"},
"front-loaders":{"_anim","_sb"},
"front-page":{"_loc_sr"},
"front-runner":{"_anim","_sb"},
"front-runners":{"_anim","_sb"},
"frontage":{"_loc_sr"},
"frontbencher":{"_anim","_sb"},
"fronted":{"_past"},
"frontier":{"_loc_sr"},
"frontiers":{"_loc_sr"},
"frontiersman":{"_anim","_masc","_sb"},
"frontiersmen":{"_anim","_masc","_sb"},
"frontierswoman":{"_anim","_fem","_sb"},
"Frontpage":{"_prprn"},
"frosted":{"_past"},
"frown":{"_loc_sr"},
"frowned":{"_loc_sr","_past"},
"frowning":{"_loc_sr"},
"froze":{"_loc_sr","_past","_wthr"},
"frozen":{"_loc_sr","_wthr"},
"frozen-embryo":{"_loc_sr","_wthr"},
"frozen-food":{"_loc_sr","_wthr"},
"frozen-foods":{"_loc_sr","_wthr"},
"frozen-pizza":{"_loc_sr","_wthr"},
"frs":{"_prprn"},
"fruiterer":{"_anim","_sb"},
"frump":{"_anim","_sb"},
"frunze":{"_cty","_geo","_prprn"},
"frustrate":{"_loc_sr","_psych"},
"frustrated":{"_loc_sr","_past","_psych"},
"frustrates":{"_loc_sr","_psych"},
"frustrating":{"_loc_sr","_psych"},
"fry-pan":{"_anim"},
"fsh":{"_prprn"},
"ftc":{"_prprn"},
"fuchs":{"_anim","_nme","_prprn","_sb"},
"fucked-up":{"_past"},
"fucker":{"_anim","_sb"},
"fucoid":{"_sb"},
"fuddle":{"_loc_sr","_psych"},
"fuddled":{"_loc_sr","_past","_psych"},
"fuddy-duddy":{"_anim","_sb"},
"fudged":{"_past"},
"fueled":{"_loc_sr","_past"},
"fueling":{"_loc_sr"},
"fuentes":{"_anim","_nme","_prprn","_sb"},
"fug":{"_loc_sr"},
"fugitive":{"_anim","_sb"},
"fugitives":{"_anim","_sb"},
"Fuji":{"_cty","_geo","_prprn"},
"fuji-san":{"_cty","_geo","_prprn"},
"fujinoyama":{"_geo","_prprn"},
"fujiyama":{"_geo","_prprn"},
"fukien":{"_geo","_prprn"},
"fukuoka":{"_cty","_geo","_prprn"},
"Fukuyama":{"_cty","_geo","_prprn"},
"fula":{"_anim","_prprn","_sb"},
"fulani":{"_anim","_prprn","_sb"},
"fulbright":{"_anim","_nme","_prprn","_sb"},
"fulfill":{"_loc_sr"},
"fulfilled":{"_loc_sr","_past"},
"fulfilling":{"_loc_sr"},
"fulfills":{"_loc_sr"},
"Fulham":{"_prprn"},
"fullback":{"_anim","_sb"},
"fuller":{"_anim","_sb"},
"Fullerton":{"_cty","_geo","_prprn"},
"fulmar":{"_anim"},
"Fulton":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"fumble":{"_loc_sr"},
"fumbled":{"_loc_sr","_past"},
"fumbling":{"_loc_sr"},
"fumed":{"_past"},
"fumed-oak":{"_past"},
"fumigator":{"_anim","_sb"},
"funafuti":{"_geo","_prprn"},
"funambulist":{"_anim","_sb"},
"functionalist":{"_anim","_sb"},
"functionaries":{"_anim","_sb"},
"functioned":{"_past"},
"funded":{"_past"},
"fundraise":{"_loc_sr"},
"fundraising":{"_loc_sr"},
"funnel":{"_loc_sr"},
"funneled":{"_loc_sr","_past"},
"funneling":{"_loc_sr"},
"furcate":{"_loc_sr"},
"Furies":{"_anim","_fem","_prprn","_sb"},
"furled":{"_past"},
"furloughed":{"_past"},
"furnished":{"_past"},
"furnivall":{"_anim","_nme","_prprn","_sb"},
"furred":{"_past"},
"furriers":{"_anim","_sb"},
"furthered":{"_past"},
"fused":{"_loc_sr","_past"},
"fusilier":{"_anim","_sb"},
"fusing":{"_loc_sr"},
"fusspot":{"_anim","_sb"},
"futurity":{"_tme"},
"fuzzed":{"_past"},
"g-man":{"_prprn"},
"g-string":{"_prprn"},
"GA":{"_prprn","_stte"},
"gaba":{"_prprn"},
"Gabon":{"_cntry","_geo","_prprn"},
"Gabonese":{"_anim","_prprn","_sb"},
"Gabor":{"_anim","_nme","_prprn","_sb"},
"gaboriau":{"_anim","_nme","_prprn","_sb"},
"Gaborone":{"_cty","_geo","_prprn"},
"Gabriel":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Gabriela":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Gabrielle":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"gad":{"_loc_sr"},
"gadabout":{"_anim","_sb"},
"Gaddafi":{"_anim","_nme","_prprn","_sb"},
"gadflies":{"_anim","_sb"},
"gadfly":{"_anim","_sb"},
"gadgeteer":{"_anim","_sb"},
"Gadsden":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"gaea":{"_anim","_fem","_loc_sr","_nme","_prprn","_sb"},
"Gael":{"_prprn"},
"Gaelic":{"_prprn"},
"gaelic-speaking":{"_prprn"},
"gaffer":{"_anim","_sb"},
"gag":{"_loc_sr"},
"gagarin":{"_anim","_nme","_prprn","_sb"},
"gagged":{"_loc_sr","_past"},
"gaggle":{"_anim"},
"gagman":{"_anim","_masc","_sb"},
"gagster":{"_anim","_sb"},
"gaia":{"_prprn"},
"Gail":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"gain":{"_loc_sr"},
"gained":{"_loc_sr","_past"},
"Gainesville":{"_cty","_geo","_prprn"},
"gaining":{"_loc_sr"},
"Gainsborough":{"_anim","_nme","_prprn","_sb"},
"gaiseric":{"_anim","_nme","_prprn","_sb"},
"gaited":{"_loc_sr","_past"},
"Gaius":{"_anim","_nme","_prprn","_sb"},
"gal":{"_anim","_fem","_sb"},
"galago":{"_anim"},
"Galahad":{"_prprn"},
"galan":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Galata":{"_prprn"},
"galatia":{"_cntry","_geo","_prprn"},
"Galatians":{"_anim","_prprn","_sb"},
"Galaxy":{"_prprn"},
"galbraith":{"_anim","_nme","_prprn","_sb"},
"galen":{"_anim","_nme","_prprn","_sb"},
"galicia":{"_cntry","_geo","_prprn","_stte"},
"galician":{"_anim","_prprn","_sb"},
"Galilean":{"_anim","_prprn","_sb"},
"Galilee":{"_geo","_prprn"},
"Galileo":{"_prprn"},
"gallants":{"_anim","_masc","_sb"},
"gallaudet":{"_anim","_nme","_prprn","_sb"},
"Galle":{"_cty","_geo","_prprn"},
"galled":{"_past","_psych"},
"galleon":{"_fem"},
"galleries":{"_loc_sr"},
"gallery":{"_loc_sr"},
"galley":{"_fem"},
"galleys":{"_fem"},
"gallia":{"_geo","_prprn"},
"gallican":{"_prprn"},
"gallicanism":{"_prprn"},
"galling":{"_psych"},
"gallivant":{"_loc_sr"},
"gallop":{"_loc_sr"},
"galloped":{"_loc_sr","_past"},
"galloping":{"_loc_sr"},
"galloway":{"_anim","_geo","_nme","_prprn","_sb"},
"Gallup":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"galois":{"_anim","_nme","_prprn","_sb"},
"galoot":{"_sb"},
"gals":{"_anim","_fem","_sb"},
"Galsworthy":{"_anim","_nme","_prprn","_sb"},
"Galt":{"_prprn"},
"galton":{"_anim","_nme","_prprn","_sb"},
"galumph":{"_loc_sr"},
"galvani":{"_anim","_nme","_prprn","_sb"},
"galvaniser":{"_anim","_sb"},
"galvanize":{"_psych"},
"galvanized":{"_past","_psych"},
"galvanizer":{"_anim","_sb"},
"galvanizing":{"_psych"},
"Galveston":{"_cty","_geo","_prprn"},
"Galway":{"_geo","_prprn"},
"Gambia":{"_cntry","_geo","_prprn"},
"Gambian":{"_anim","_prprn","_sb"},
"gamble":{"_loc_sr"},
"gambled":{"_loc_sr","_past"},
"gambling":{"_loc_sr"},
"gambol":{"_loc_sr"},
"gamecock":{"_anim","_masc"},
"gamers":{"_anim","_sb"},
"gamesmen":{"_anim","_sb"},
"gamin":{"_sb"},
"gamine":{"_sb"},
"gammon":{"_loc_sr"},
"gamow":{"_anim","_nme","_prprn","_sb"},
"Gandalf":{"_prprn"},
"gander":{"_anim","_masc"},
"Gandhi":{"_anim","_nme","_prprn","_sb"},
"gang":{"_anim","_sb"},
"gang-rape":{"_anim","_sb"},
"ganger":{"_anim","_sb"},
"Ganges":{"_geo","_prprn"},
"gangs":{"_anim","_sb"},
"gangsters":{"_anim","_sb"},
"gannet":{"_anim"},
"gansu":{"_geo","_prprn","_stte"},
"Ganymede":{"_prprn","_sb"},
"Gao":{"_prprn"},
"gaolbird":{"_anim","_sb"},
"gaoler":{"_anim","_sb"},
"gap":{"_loc_sr"},
"gaped":{"_past"},
"gapped":{"_past"},
"gaps":{"_loc_sr"},
"garage":{"_loc_sr"},
"garaged":{"_loc_sr","_past"},
"garages":{"_loc_sr"},
"garand":{"_anim","_nme","_prprn","_sb"},
"garbled":{"_past"},
"garbo":{"_anim","_nme","_prprn","_sb"},
"garden":{"_loc_sr"},
"garden-shrub":{"_loc_sr"},
"Gardena":{"_cty","_geo","_prprn"},
"gardened":{"_loc_sr","_past"},
"gardener":{"_anim","_sb"},
"gardeners":{"_anim","_sb"},
"gardening":{"_loc_sr"},
"gardens":{"_loc_sr"},
"gardiner":{"_anim","_nme","_prprn","_sb"},
"Gardner":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Garfield":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"gargantua":{"_anim","_sb"},
"Garibaldi":{"_anim","_prprn","_sb"},
"garlanded":{"_past"},
"garmented":{"_past"},
"garnered":{"_past"},
"Garnett":{"_anim","_nme","_prprn","_sb"},
"garnish":{"_loc_sr"},
"garonne":{"_geo","_prprn"},
"garret":{"_loc_sr"},
"Garrett":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"garrick":{"_anim","_nme","_prprn","_sb"},
"garrison":{"_anim","_sb"},
"garrisoned":{"_loc_sr","_past"},
"garroter":{"_anim","_sb"},
"garrotter":{"_anim","_sb"},
"Gary":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"gasbag":{"_anim","_sb"},
"Gascony":{"_geo","_prprn","_stte"},
"gasherbrum":{"_geo","_prprn"},
"gasified":{"_loc_sr","_past"},
"gasify":{"_loc_sr"},
"gaskell":{"_anim","_nme","_prprn","_sb"},
"gasman":{"_anim","_sb"},
"gasp":{"_loc_sr"},
"gaspar":{"_anim","_nme","_prprn","_sb"},
"gasped":{"_loc_sr","_past"},
"gasping":{"_loc_sr"},
"gassed":{"_past"},
"Gasset":{"_prprn"},
"gastroenterologist":{"_anim","_sb"},
"gasworks":{"_loc_sr"},
"gatecrasher":{"_anim","_sb"},
"gatehouse":{"_loc_sr"},
"gatekeeper":{"_anim","_sb"},
"Gates":{"_prprn"},
"gathered":{"_past"},
"gatling":{"_anim","_nme","_prprn","_sb"},
"Gatorade":{"_prprn"},
"gatt":{"_prprn"},
"gaucho":{"_anim","_sb"},
"Gaudi":{"_anim","_nme","_prprn","_sb"},
"gauged":{"_past"},
"Gauguin":{"_anim","_nme","_prprn","_sb"},
"Gaul":{"_geo","_prprn"},
"Gauleiter":{"_prprn"},
"Gaulle":{"_prprn"},
"Gaultier":{"_prprn"},
"gaur":{"_anim","_loc_sr"},
"gautama":{"_anim","_nme","_prprn","_sb"},
"Gautier":{"_anim","_nme","_prprn","_sb"},
"gave":{"_loc_sr","_past"},
"gawain":{"_prprn"},
"gawker":{"_anim","_sb"},
"gay":{"_sb"},
"gay-bashing":{"_sb"},
"gay-ess":{"_sb"},
"gay-feather":{"_sb"},
"gay-lussac":{"_anim","_nme","_prprn","_sb"},
"gay-rights":{"_sb"},
"gay-student":{"_sb"},
"gayal":{"_anim"},
"Gayle":{"_anim","_fem","_fnme","_masc","_nme","_prprn","_sb"},
"gays":{"_sb"},
"Gaza":{"_cty","_geo","_prprn"},
"gazebo":{"_loc_sr"},
"gazed":{"_past"},
"gazes":{"_anim","_sb"},
"gb":{"_prprn"},
"gc":{"_prprn"},
"gca":{"_prprn"},
"gd":{"_prprn"},
"Gdansk":{"_cty","_geo","_prprn"},
"ge":{"_prprn"},
"geared":{"_past"},
"gecko":{"_anim"},
"Geddes":{"_anim","_nme","_prprn","_sb"},
"gee-gee":{"_anim"},
"geek":{"_sb"},
"geeks":{"_sb"},
"geese":{"_anim"},
"geezer":{"_anim","_masc","_sb"},
"gehenna":{"_loc_sr","_prprn"},
"Gehrig":{"_anim","_nme","_prprn","_sb"},
"Gehry":{"_prprn"},
"Geiger":{"_prprn"},
"geisel":{"_anim","_nme","_prprn","_sb"},
"geisha":{"_anim","_fem","_sb"},
"gelded":{"_past"},
"geldings":{"_anim","_masc"},
"gell-mann":{"_anim","_nme","_prprn","_sb"},
"gemara":{"_prprn"},
"Gemeinschaft":{"_prprn"},
"Gemini":{"_prprn","_sb"},
"gemmed":{"_past"},
"gemsbok":{"_anim"},
"genealogist":{"_anim","_sb"},
"general-appeal":{"_anim","_sb"},
"general-director":{"_anim","_sb"},
"general-interest":{"_anim","_sb"},
"general-management":{"_anim","_sb"},
"general-practice":{"_anim","_sb"},
"general-practitioner":{"_anim","_sb"},
"general-staff":{"_anim","_sb"},
"generalised":{"_past"},
"generalissimo":{"_anim","_sb"},
"generalist":{"_anim","_sb"},
"generalists":{"_anim","_sb"},
"generalized":{"_past"},
"generals":{"_anim","_sb"},
"generate":{"_loc_sr"},
"generated":{"_loc_sr","_past"},
"generates":{"_loc_sr"},
"generating":{"_loc_sr"},
"generation":{"_tme"},
"generation-skipping":{"_tme"},
"generations":{"_tme"},
"Genesee":{"_geo","_prprn"},
"Genesis":{"_prprn"},
"genet":{"_anim"},
"geneticist":{"_anim","_sb"},
"geneticists":{"_anim","_sb"},
"Geneva":{"_cty","_geo","_prprn"},
"genevan":{"_anim","_prprn","_sb"},
"Genevieve":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"genii":{"_anim","_sb"},
"genitor":{"_anim","_sb"},
"genius":{"_anim","_sb"},
"geniuses":{"_anim","_sb"},
"Genoa":{"_cty","_geo","_prprn"},
"Genova":{"_prprn"},
"genseric":{"_anim","_nme","_prprn","_sb"},
"gent":{"_anim","_masc","_sb"},
"gentile":{"_anim","_sb"},
"gentlefolk":{"_anim","_sb"},
"gentleman":{"_anim","_masc","_sb"},
"gentleman's-cane":{"_anim","_masc","_sb"},
"gentleman-at-arms":{"_anim","_masc","_sb"},
"gentlemen":{"_anim","_masc","_sb"},
"gentlewoman":{"_anim","_fem","_sb"},
"gentry":{"_anim","_sb"},
"Geoffrey":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"geographer":{"_anim","_sb"},
"geographers":{"_anim","_sb"},
"geography":{"_loc_sr"},
"geologist":{"_anim","_sb"},
"geologists":{"_anim","_sb"},
"geometrician":{"_anim","_sb"},
"geophysicist":{"_anim","_sb"},
"geophysics":{"_loc_sr"},
"Geordie":{"_anim","_prprn","_sb"},
"George":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Georges":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Georgetown":{"_cty","_geo","_prprn"},
"Georgia":{"_anim","_cntry","_fem","_fnme","_geo","_nme","_prprn","_sb","_stte"},
"Georgian":{"_anim","_prprn","_sb"},
"geraint":{"_prprn"},
"Gerald":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Geraldine":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Gerard":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"gerbil":{"_anim"},
"gerenuk":{"_anim"},
"geriatric":{"_sb"},
"geriatrician":{"_anim","_sb"},
"German":{"_anim","_prprn","_sb"},
"German-speaking":{"_anim","_prprn","_sb"},
"Germanic":{"_prprn"},
"germanism":{"_prprn"},
"germanist":{"_prprn"},
"Germans":{"_anim","_prprn","_sb"},
"Germantown":{"_cty","_geo","_prprn"},
"Germany":{"_cntry","_geo","_prprn"},
"germinated":{"_past"},
"Geronimo":{"_anim","_nme","_prprn","_sb"},
"gerontologist":{"_anim","_sb"},
"Gerry":{"_anim","_nme","_prprn","_sb"},
"gerrymander":{"_loc_sr"},
"gerrymandering":{"_loc_sr"},
"Gershwin":{"_anim","_nme","_prprn","_sb"},
"Gertrude":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"geryon":{"_prprn"},
"gesell":{"_anim","_nme","_prprn","_sb"},
"gesner":{"_anim","_nme","_prprn","_sb"},
"Gestapo":{"_prprn"},
"gesticulated":{"_past"},
"gestured":{"_past"},
"Gesualdo":{"_prprn"},
"Gethsemane":{"_geo","_loc_sr","_prprn"},
"Getty":{"_anim","_nme","_prprn","_sb"},
"Gettysburg":{"_cty","_geo","_prprn"},
"Getz":{"_prprn"},
"Ghana":{"_cntry","_geo","_prprn"},
"Ghanaian":{"_anim","_prprn","_sb"},
"Ghent":{"_cty","_geo","_prprn"},
"Ghiberti":{"_anim","_nme","_prprn","_sb"},
"ghost-busting":{"_anim","_sb"},
"ghosted":{"_loc_sr","_past"},
"ghosts":{"_anim","_sb"},
"ghostwriter":{"_anim","_sb"},
"ghouls":{"_anim","_sb"},
"ghq":{"_prprn"},
"ghz":{"_prprn"},
"GI":{"_anim","_prprn","_sb"},
"Giacometti":{"_anim","_nme","_prprn","_sb"},
"Giacomo":{"_prprn"},
"giant":{"_anim","_sb"},
"giantess":{"_anim","_fem","_sb"},
"giants":{"_anim","_sb"},
"gibbon":{"_anim"},
"Gibbs":{"_anim","_nme","_prprn","_sb"},
"Gibraltar":{"_geo","_prprn"},
"Gibraltarian":{"_anim","_prprn","_sb"},
"gibran":{"_anim","_nme","_prprn","_sb"},
"Gibson":{"_anim","_nme","_prprn","_sb"},
"gide":{"_anim","_nme","_prprn","_sb"},
"Gideon":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"gielgud":{"_anim","_nme","_prprn","_sb"},
"gifted":{"_past"},
"gig":{"_loc_sr"},
"giggler":{"_anim","_sb"},
"gigo":{"_prprn"},
"gikuyu":{"_anim","_prprn","_sb"},
"Gilbert":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Gilchrist":{"_prprn"},
"Gilda":{"_prprn"},
"gilded":{"_past"},
"Giles":{"_prprn"},
"gilgamesh":{"_prprn"},
"gill":{"_loc_sr"},
"Gillespie":{"_prprn"},
"Gillette":{"_anim","_nme","_prprn","_sb"},
"Gillian":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"gillie":{"_anim","_sb"},
"gilman":{"_anim","_nme","_prprn","_sb"},
"gilmer":{"_anim","_nme","_prprn","_sb"},
"Gina":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Ginnie":{"_prprn"},
"Ginsberg":{"_anim","_nme","_prprn","_sb"},
"Ginsburg":{"_prprn"},
"Gioconda":{"_prprn"},
"Giotto":{"_anim","_nme","_prprn","_sb"},
"gipsy":{"_anim","_sb"},
"giraffe":{"_anim"},
"Girard":{"_anim","_nme","_prprn","_sb"},
"Giraud":{"_anim","_nme","_prprn","_sb"},
"giraudoux":{"_anim","_nme","_prprn","_sb"},
"girded":{"_past"},
"girdle":{"_sb"},
"girl":{"_anim","_fem","_sb"},
"girl-friend":{"_anim","_fem","_sb"},
"girl-san":{"_anim","_fem","_sb"},
"girlfriend":{"_anim","_fem","_sb"},
"girlfriends":{"_anim","_fem","_sb"},
"girlhood":{"_sb"},
"girls":{"_anim","_fem","_sb"},
"gironde":{"_geo","_prprn"},
"girondist":{"_prprn"},
"gish":{"_anim","_nme","_prprn","_sb"},
"Giuseppe":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"give":{"_loc_sr"},
"given":{"_loc_sr"},
"gives":{"_loc_sr"},
"giving":{"_loc_sr"},
"Giza":{"_cty","_geo","_prprn"},
"gjellerup":{"_anim","_nme","_prprn","_sb"},
"glabella":{"_loc_sr"},
"glaciated":{"_past"},
"glad":{"_sb_is_jj"},
"gladden":{"_psych"},
"gladdened":{"_past","_psych"},
"glade":{"_loc_sr"},
"gladiator":{"_anim","_sb"},
"Gladstone":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Gladys":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"glamorized":{"_past"},
"glanced":{"_past"},
"glared":{"_past"},
"Glaris":{"_prprn"},
"Glaser":{"_anim","_nme","_prprn","_sb"},
"glassblower":{"_anim","_sb"},
"glassed":{"_past"},
"glassmaker":{"_anim","_sb"},
"glassware":{"_loc_sr"},
"glassworker":{"_anim","_sb"},
"Glaswegian":{"_prprn"},
"glazed":{"_past"},
"glazer":{"_anim","_sb"},
"glazier":{"_anim","_sb"},
"gleamed":{"_past"},
"gleaned":{"_past"},
"gleaner":{"_anim","_sb"},
"glebe":{"_loc_sr"},
"Glenda":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Glendale":{"_cty","_geo","_prprn"},
"glendower":{"_anim","_nme","_prprn","_sb"},
"Glenn":{"_anim","_fem","_fnme","_masc","_nme","_prprn","_sb"},
"glided":{"_loc_sr","_past"},
"glimpsed":{"_past"},
"glinka":{"_anim","_nme","_prprn","_sb"},
"glinted":{"_past"},
"glistened":{"_past"},
"glitterati":{"_anim","_sb"},
"glittered":{"_past"},
"gloated":{"_past"},
"gloater":{"_anim","_sb"},
"globalist":{"_anim","_sb"},
"globalists":{"_anim","_sb"},
"globalized":{"_past"},
"globefish":{"_anim"},
"glochidium":{"_anim"},
"glommed":{"_past"},
"Gloria":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"glorified":{"_past"},
"glossarist":{"_anim","_sb"},
"glottis":{"_loc_sr"},
"Gloucester":{"_cty","_geo","_prprn"},
"Gloucestershire":{"_prprn"},
"gloved":{"_past"},
"glover":{"_anim","_nme","_prprn","_sb"},
"glowed":{"_past"},
"glowered":{"_past"},
"gluck":{"_anim","_nme","_prprn","_sb"},
"glued":{"_past"},
"glutted":{"_past"},
"glutton":{"_anim","_sb"},
"gluttons":{"_anim","_sb"},
"glycerolized":{"_past"},
"GmbH":{"_prprn"},
"gmt":{"_prprn"},
"gnarled":{"_past"},
"gnat":{"_anim"},
"gnawed":{"_past"},
"gnawer":{"_anim","_sb"},
"gnome":{"_anim","_sb"},
"gnosticism":{"_prprn"},
"gnp":{"_prprn"},
"gnu":{"_anim"},
"go":{"_loc_sr"},
"go-between":{"_anim","_sb"},
"go-betweens":{"_anim","_sb"},
"go-getters":{"_anim","_sb"},
"goa":{"_anim"},
"goaded":{"_past"},
"goal":{"_loc_sr"},
"goal-directed":{"_loc_sr"},
"goal-kick":{"_loc_sr"},
"goal-line":{"_loc_sr"},
"goal-oriented":{"_loc_sr"},
"goal-values":{"_loc_sr"},
"goalie":{"_anim","_sb"},
"goalies":{"_anim","_sb"},
"goalkeeper":{"_anim","_sb"},
"goalmouth":{"_loc_sr"},
"goals":{"_loc_sr"},
"goaltender":{"_anim","_sb"},
"goat":{"_anim"},
"goat-drawn":{"_anim"},
"goatfish":{"_anim"},
"goatherd":{"_anim","_sb"},
"goats":{"_anim"},
"gobble":{"_loc_sr"},
"gobbled":{"_loc_sr","_past"},
"gobbler":{"_anim","_masc"},
"gobblers":{"_anim","_masc"},
"gobbling":{"_loc_sr"},
"gobi":{"_geo","_prprn"},
"goblet":{"_loc_sr"},
"goblet-shaped":{"_loc_sr"},
"god":{"_anim","_sb"},
"God-forsaken":{"_anim","_prprn","_sb"},
"God-given":{"_anim","_prprn","_sb"},
"god-like":{"_anim","_sb"},
"godard":{"_anim","_nme","_prprn","_sb"},
"godchild":{"_anim","_sb"},
"goddard":{"_anim","_nme","_prprn","_sb"},
"goddaughter":{"_anim","_fem","_sb"},
"goddess":{"_anim","_fem","_sb"},
"godfather":{"_anim","_masc","_sb"},
"Godfrey":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Godiva":{"_prprn"},
"godown":{"_loc_sr"},
"gods":{"_anim","_sb"},
"godson":{"_anim","_masc","_sb"},
"Godspeed":{"_prprn"},
"Godunov":{"_anim","_nme","_prprn","_sb"},
"Godwin":{"_anim","_nme","_prprn","_sb"},
"Goebbels":{"_anim","_nme","_prprn","_sb"},
"goer":{"_anim","_sb"},
"Goering":{"_anim","_nme","_prprn","_sb"},
"Goethals":{"_anim","_nme","_prprn","_sb"},
"Goethe":{"_anim","_nme","_prprn","_sb"},
"goggle":{"_loc_sr"},
"gogh":{"_anim","_nme","_prprn","_sb"},
"Gogol":{"_anim","_nme","_prprn","_sb"},
"goidelic":{"_prprn"},
"goin":{"_loc_sr"},
"going":{"_loc_sr"},
"Golconda":{"_cty","_geo","_prprn"},
"Golda":{"_prprn"},
"goldbeater":{"_anim","_sb"},
"Goldberg":{"_anim","_nme","_prprn","_sb"},
"goldeneye":{"_anim"},
"goldfield":{"_loc_sr"},
"goldfields":{"_loc_sr"},
"goldfinch":{"_anim"},
"goldfish":{"_anim"},
"Golding":{"_anim","_nme","_prprn","_sb"},
"Goldman":{"_anim","_nme","_prprn","_sb"},
"goldmine":{"_loc_sr"},
"goldoni":{"_anim","_nme","_prprn","_sb"},
"goldsboro":{"_cty","_geo","_prprn"},
"Goldschmidt":{"_prprn"},
"goldsmith":{"_anim","_sb"},
"Goldwyn":{"_anim","_nme","_prprn","_sb"},
"golem":{"_sb"},
"golfed":{"_past"},
"golfer":{"_anim","_sb"},
"golfers":{"_anim","_sb"},
"golgi":{"_anim","_nme","_prprn","_sb"},
"Golgotha":{"_geo","_loc_sr","_prprn"},
"Goliath":{"_anim","_prprn","_sb"},
"Goliaths":{"_anim","_prprn","_sb"},
"golliwog":{"_sb"},
"gomel":{"_cty","_geo","_prprn"},
"Gomorrah":{"_cty","_geo","_prprn"},
"Gompers":{"_anim","_nme","_prprn","_sb"},
"Goncharov":{"_prprn"},
"goncourt":{"_anim","_nme","_prprn","_sb"},
"gond":{"_anim","_prprn","_sb"},
"gondi":{"_prprn"},
"gondolier":{"_anim","_sb"},
"Gondwanaland":{"_prprn"},
"gone":{"_loc_sr"},
"goner":{"_anim","_sb"},
"gongorism":{"_prprn"},
"gonna":{"_futr","_probabl"},
"gonne":{"_anim","_nme","_prprn","_sb"},
"good-for-nothing":{"_anim","_sb"},
"goodbye":{"_sb"},
"goodman":{"_anim","_nme","_prprn","_sb"},
"goods":{"_loc_sr"},
"goods-producing":{"_loc_sr"},
"Goodwin":{"_anim","_nme","_prprn","_sb"},
"goody-goody":{"_anim","_sb"},
"goodyear":{"_anim","_nme","_prprn","_sb"},
"goof-off":{"_anim","_sb"},
"goof-offs":{"_anim","_sb"},
"goof-proof":{"_anim","_sb"},
"goofball":{"_sb"},
"goofed":{"_past"},
"goon":{"_anim","_sb"},
"goons":{"_anim","_sb"},
"goosander":{"_sb"},
"goose":{"_anim"},
"goose-tansy":{"_anim"},
"goosefish":{"_anim"},
"gop":{"_prprn"},
"gopher":{"_anim"},
"Gorbachev":{"_anim","_nme","_prprn","_sb"},
"Gordian":{"_prprn"},
"Gordimer":{"_prprn"},
"gored":{"_past"},
"gorgas":{"_anim","_nme","_prprn","_sb"},
"gorged":{"_past"},
"gorger":{"_anim","_sb"},
"gorgon":{"_anim","_fem","_sb"},
"gorilla":{"_anim"},
"gorillas":{"_anim"},
"gorki":{"_anim","_nme","_prprn","_sb"},
"Gorky":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Gorton":{"_anim","_nme","_prprn","_sb"},
"Goshen":{"_cty","_geo","_prprn"},
"gosling":{"_anim"},
"Gospel":{"_prprn"},
"gospeler":{"_anim","_sb"},
"Gosplan":{"_prprn"},
"gossiped":{"_past"},
"gossiper":{"_anim","_sb"},
"gossipmonger":{"_anim","_sb"},
"got":{"_past"},
"goteborg":{"_cty","_geo","_prprn"},
"goth":{"_anim","_prprn","_sb"},
"Gotham":{"_geo","_prprn"},
"Gothic":{"_prprn"},
"Gothicism":{"_prprn"},
"Gottschalk":{"_anim","_nme","_prprn","_sb"},
"gouda":{"_cty","_geo","_prprn"},
"goudy":{"_anim","_nme","_prprn","_sb"},
"gouged":{"_past"},
"gouger":{"_anim","_sb"},
"Gould":{"_anim","_nme","_prprn","_sb"},
"gounod":{"_anim","_nme","_prprn","_sb"},
"gourmand":{"_anim","_sb"},
"gourmandizer":{"_anim","_sb"},
"gourmet":{"_anim","_sb"},
"gourmet-food":{"_anim","_sb"},
"gourmets":{"_anim","_sb"},
"Gov.":{"_anim","_sb"},
"governed":{"_past"},
"governor":{"_anim","_sb"},
"governor-elect":{"_anim","_sb"},
"Governor-General":{"_anim","_sb"},
"governors":{"_anim","_sb"},
"governors-association":{"_anim","_sb"},
"Govs.":{"_anim","_prprn","_sb"},
"Govt":{"_prprn"},
"gowned":{"_past"},
"goy":{"_anim","_sb"},
"Goya":{"_prprn"},
"gpa":{"_prprn"},
"gpo":{"_prprn"},
"grabbed":{"_past"},
"Grace":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"graced":{"_past"},
"Graceland":{"_geo","_prprn"},
"gracie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"gradate":{"_loc_sr"},
"graded":{"_loc_sr","_past"},
"grading":{"_loc_sr"},
"graduate-student":{"_anim","_sb"},
"graduated":{"_past"},
"graduates":{"_anim","_sb"},
"Graf":{"_prprn"},
"graft":{"_loc_sr"},
"grafted":{"_loc_sr","_past"},
"grafting":{"_loc_sr"},
"Graham":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Grahame":{"_anim","_nme","_prprn","_sb"},
"grammarian":{"_anim","_sb"},
"grammarians":{"_anim","_sb"},
"Grammy":{"_prprn"},
"Grammys":{"_prprn"},
"grampus":{"_anim"},
"Granada":{"_cty","_geo","_prprn"},
"granary":{"_loc_sr"},
"grandad":{"_anim","_masc","_sb"},
"grandchildren":{"_anim","_sb"},
"granddaughter":{"_anim","_fem","_sb"},
"grandee":{"_anim","_masc","_sb"},
"grandees":{"_anim","_masc","_sb"},
"grandfather":{"_anim","_masc","_sb"},
"grandfather-father-to-son":{"_anim","_masc","_sb"},
"grandma":{"_anim","_fem","_sb"},
"grandmother":{"_anim","_fem","_sb"},
"grandmothers":{"_anim","_fem","_sb"},
"grandpa":{"_anim","_masc","_sb"},
"grandparent":{"_anim","_sb"},
"grandparents":{"_anim","_sb"},
"grandson":{"_anim","_masc","_sb"},
"grandsons":{"_anim","_masc","_sb"},
"granger":{"_anim","_sb"},
"granny":{"_anim","_fem","_sb"},
"granted":{"_past"},
"granter":{"_anim","_sb"},
"granulate":{"_loc_sr"},
"granulated":{"_loc_sr","_past"},
"Granville":{"_prprn"},
"granville-barker":{"_anim","_nme","_prprn","_sb"},
"graphed":{"_loc_sr","_past"},
"Grappelly":{"_prprn"},
"grappled":{"_past"},
"grappler":{"_anim","_sb"},
"grasped":{"_past"},
"grassed":{"_past"},
"grassers":{"_anim","_sb"},
"grasshoppers":{"_anim"},
"grassland":{"_loc_sr"},
"grassroots":{"_sb"},
"grassroots-fueled":{"_sb"},
"grate":{"_loc_sr","_psych"},
"grated":{"_loc_sr","_past","_psych"},
"gratified":{"_past","_psych"},
"gratify":{"_psych"},
"gratifying":{"_psych"},
"grating":{"_loc_sr","_psych"},
"Grattan":{"_anim","_nme","_prprn","_sb"},
"grave":{"_loc_sr"},
"graver":{"_anim","_sb"},
"graves":{"_loc_sr"},
"Gravesend":{"_geo","_prprn"},
"gravitate":{"_loc_sr"},
"gravitates":{"_loc_sr"},
"gravitating":{"_loc_sr"},
"Gray":{"_anim","_fnme","_nme","_prprn","_sb"},
"grayed":{"_past"},
"graz":{"_cty","_geo","_prprn"},
"graze":{"_loc_sr"},
"grazer":{"_anim","_sb"},
"grazers":{"_anim","_sb"},
"grazier":{"_anim","_sb"},
"grazing":{"_loc_sr"},
"greased":{"_loc_sr","_past"},
"greaser":{"_anim","_sb"},
"great":{"_sb"},
"great-aunt":{"_anim","_fem","_sb"},
"great-grandchildren":{"_sb"},
"great-grandson":{"_sb"},
"great-nephew":{"_sb"},
"great-niece":{"_sb"},
"great-nieces":{"_sb"},
"great-quality":{"_sb"},
"grebe":{"_anim"},
"Grecian":{"_anim","_prprn","_sb"},
"Greco":{"_anim","_nme","_prprn","_sb"},
"Greece":{"_cntry","_geo","_prprn"},
"Greek":{"_anim","_prprn","_sb"},
"greeley":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"greenbelt":{"_loc_sr"},
"Greene":{"_anim","_nme","_prprn","_sb"},
"greenfield":{"_cty","_geo","_prprn"},
"greenfly":{"_anim"},
"greengrocer":{"_anim","_sb"},
"greenhorn":{"_anim","_sb"},
"greenhouse-effect":{"_loc_sr"},
"greenhouse-gas":{"_loc_sr"},
"greenhouse-produced":{"_loc_sr"},
"Greenland":{"_geo","_prprn"},
"greenling":{"_loc_sr"},
"Greenock":{"_geo","_prprn"},
"Greenpeace":{"_prprn"},
"greenroom":{"_loc_sr"},
"Greensboro":{"_cty","_geo","_prprn"},
"greenskeeper":{"_anim","_sb"},
"Greenspan":{"_prprn"},
"greenville":{"_cty","_geo","_prprn"},
"greenway":{"_loc_sr"},
"Greenwich":{"_cty","_geo","_prprn"},
"Greer":{"_anim","_fnme","_nme","_prprn","_sb"},
"greeted":{"_past"},
"Greg":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Gregory":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Grenada":{"_cntry","_geo","_prprn"},
"Grenadian":{"_anim","_prprn","_sb"},
"grenadier":{"_anim","_sb"},
"Grenfell":{"_anim","_nme","_prprn","_sb"},
"Grenoble":{"_cty","_geo","_prprn"},
"Grenville":{"_anim","_nme","_prprn","_sb"},
"gresham":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Greta":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Gretchen":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Gretzky":{"_prprn"},
"Greville":{"_prprn"},
"grew":{"_loc_sr","_past"},
"Grey":{"_anim","_fnme","_nme","_prprn","_sb"},
"greybeard":{"_anim","_masc","_sb"},
"greyed":{"_past"},
"greyhound":{"_anim"},
"griddle":{"_loc_sr"},
"Grieg":{"_anim","_nme","_prprn","_sb"},
"grieve":{"_loc_sr","_psych"},
"grieved":{"_loc_sr","_past","_psych"},
"griever":{"_anim","_sb"},
"grieving":{"_loc_sr","_psych"},
"griffin":{"_anim"},
"Griffith":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"griffon":{"_anim"},
"grifter":{"_anim","_sb"},
"Grigori":{"_prprn"},
"grill":{"_loc_sr"},
"grilled":{"_loc_sr","_past"},
"grilled-chicken":{"_loc_sr","_past"},
"grilling":{"_loc_sr"},
"grimaced":{"_past"},
"Grimaldi":{"_prprn"},
"grime":{"_anim","_sb"},
"grimed":{"_past"},
"Grimm":{"_anim","_nme","_prprn","_sb"},
"Grinch":{"_prprn"},
"grind":{"_loc_sr"},
"grinder":{"_sb"},
"grinders":{"_sb"},
"grinding":{"_loc_sr"},
"gringo":{"_anim","_sb"},
"gringos":{"_anim","_sb"},
"grinned":{"_past"},
"grinner":{"_anim","_sb"},
"gripe":{"_loc_sr"},
"griped":{"_loc_sr","_past"},
"griping":{"_loc_sr"},
"gripped":{"_past"},
"Gris":{"_anim","_nme","_prprn","_sb"},
"Griselda":{"_prprn"},
"Grisham":{"_prprn"},
"grison":{"_anim"},
"grist":{"_anim"},
"grivet":{"_anim"},
"grizzlies":{"_anim"},
"grizzly":{"_anim"},
"Gro":{"_prprn"},
"grocer":{"_anim","_sb"},
"grocers":{"_anim","_sb"},
"groin":{"_loc_sr"},
"grok":{"_loc_sr","_past"},
"grokked":{"_loc_sr","_past"},
"grokking":{"_loc_sr"},
"Grolier":{"_prprn"},
"gromyko":{"_anim","_nme","_prprn","_sb"},
"groomed":{"_past"},
"groomsman":{"_anim","_masc","_sb"},
"groomsmen":{"_anim","_masc","_sb"},
"groover":{"_anim","_sb"},
"groped":{"_past"},
"gropius":{"_anim","_nme","_prprn","_sb"},
"gross-income":{"_num"},
"gross-profit":{"_num"},
"grossed":{"_past"},
"Grote":{"_anim","_nme","_prprn","_sb"},
"grotesque":{"_sb"},
"grotesques":{"_sb"},
"grotius":{"_anim","_nme","_prprn","_sb"},
"grouch":{"_sb"},
"ground":{"_loc_sr"},
"ground-based":{"_loc_sr"},
"ground-berry":{"_loc_sr"},
"ground-cargo":{"_loc_sr"},
"ground-floor":{"_loc_sr"},
"ground-glass":{"_loc_sr"},
"ground-handling":{"_loc_sr"},
"ground-hugging":{"_loc_sr"},
"ground-launched":{"_loc_sr"},
"ground-level":{"_loc_sr"},
"ground-shaker":{"_loc_sr"},
"ground-support":{"_loc_sr"},
"ground-swell":{"_loc_sr"},
"ground-truck":{"_loc_sr"},
"ground-water":{"_loc_sr"},
"grounded":{"_past"},
"groundhog":{"_anim"},
"groundkeeper":{"_anim","_sb"},
"grounds":{"_loc_sr"},
"grounds-care":{"_loc_sr"},
"groundsman":{"_anim","_sb"},
"group":{"_sb"},
"group-health":{"_sb"},
"group-identities":{"_sb"},
"group-identity":{"_sb"},
"grouped":{"_loc_sr","_past"},
"groupie":{"_anim","_sb"},
"grouping":{"_loc_sr"},
"groups":{"_sb"},
"grouse":{"_anim"},
"grouse-berry":{"_anim"},
"groused":{"_past"},
"grouses":{"_anim"},
"grovel":{"_loc_sr"},
"groveler":{"_anim","_sb"},
"groveling":{"_loc_sr"},
"groveller":{"_anim","_sb"},
"grovelling":{"_loc_sr"},
"grow":{"_loc_sr"},
"grow-or-die":{"_loc_sr"},
"grower":{"_anim","_sb"},
"growers":{"_anim","_sb"},
"growing":{"_loc_sr"},
"growing-waiting":{"_loc_sr"},
"growled":{"_loc_sr","_past"},
"grown":{"_loc_sr"},
"grown-up":{"_anim","_sb"},
"grown-ups":{"_anim","_sb"},
"grows":{"_loc_sr"},
"Grozny":{"_cty","_geo","_prprn"},
"Groznyy":{"_prprn"},
"gruel":{"_loc_sr"},
"grumbled":{"_past"},
"grumbler":{"_anim","_sb"},
"grundyism":{"_prprn"},
"grunt":{"_loc_sr"},
"grunted":{"_loc_sr","_past"},
"grunter":{"_anim","_sb"},
"grunting":{"_loc_sr"},
"grus":{"_prprn"},
"gryphon":{"_anim"},
"gsa":{"_prprn"},
"gsr":{"_prprn"},
"Guadalajara":{"_cty","_geo","_prprn"},
"Guadalcanal":{"_geo","_prprn"},
"Guadeloupe":{"_geo","_prprn"},
"Guam":{"_geo","_prprn"},
"guanaco":{"_anim"},
"Guanajuato":{"_prprn"},
"guangdong":{"_geo","_prprn","_stte"},
"guantanamo":{"_cty","_geo","_prprn"},
"guaranteed":{"_past"},
"guaranteed-neutral":{"_past"},
"guard":{"_anim","_sb"},
"guard-room":{"_anim","_sb"},
"guarded":{"_loc_sr","_past"},
"guardian":{"_anim","_loc_sr","_sb"},
"guardians":{"_anim","_loc_sr","_sb"},
"guarding":{"_loc_sr"},
"guardroom":{"_loc_sr"},
"Guards":{"_anim","_sb"},
"guardsman":{"_anim","_sb"},
"guarneri":{"_anim","_nme","_prprn","_sb"},
"guarnerius":{"_prprn"},
"Guatemala":{"_cntry","_cty","_geo","_prprn"},
"Guatemalan":{"_anim","_prprn","_sb"},
"guayaquil":{"_cty","_geo","_prprn"},
"gudgeon":{"_anim"},
"guenevere":{"_prprn"},
"guenon":{"_anim"},
"Guernsey":{"_anim","_geo","_prprn"},
"Guerrero":{"_anim","_nme","_prprn","_sb"},
"guerrilla":{"_anim","_sb"},
"guerrilla-held":{"_anim","_sb"},
"guerrillas":{"_anim","_sb"},
"guessed":{"_past"},
"guesser":{"_anim","_sb"},
"guest":{"_anim","_sb"},
"guests":{"_anim","_sb"},
"Guevara":{"_anim","_nme","_prprn","_sb"},
"guggenheim":{"_anim","_nme","_prprn","_sb"},
"Guglielmo":{"_prprn"},
"gui":{"_prprn"},
"Guiana":{"_geo","_prprn"},
"guided":{"_past"},
"guided-missile":{"_past"},
"guides":{"_anim","_sb"},
"Guildford":{"_geo","_prprn"},
"guildhall":{"_loc_sr"},
"Guilin":{"_cty","_geo","_prprn"},
"guillemot":{"_anim"},
"Guinea":{"_cntry","_geo","_prprn"},
"Guinea-Bissau":{"_cntry","_geo","_prprn"},
"Guinean":{"_anim","_prprn","_sb"},
"Guinevere":{"_anim","_fem","_nme","_prprn","_sb"},
"Guinness":{"_anim","_nme","_prprn","_sb"},
"guitarfish":{"_anim"},
"guitarist":{"_anim","_sb"},
"Guizot":{"_anim","_nme","_prprn","_sb"},
"Gujarat":{"_geo","_prprn"},
"gujarati":{"_anim","_prprn","_sb"},
"Gulf":{"_loc_sr"},
"gull":{"_anim"},
"gulled":{"_past"},
"gulliver":{"_prprn"},
"gulped":{"_past"},
"gulper":{"_anim","_sb"},
"gum":{"_loc_sr"},
"gum-lac":{"_loc_sr"},
"gum-like":{"_loc_sr"},
"gunboat":{"_loc_sr"},
"gunboats":{"_loc_sr"},
"gunfighter":{"_anim","_sb"},
"gunman":{"_anim","_masc","_sb"},
"gunmen":{"_anim","_masc","_sb"},
"Gunn":{"_prprn"},
"Gunnar":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"gunned":{"_past"},
"gunner":{"_anim","_sb"},
"gunrunner":{"_anim","_sb"},
"gunslinger":{"_anim","_sb"},
"gunslingers":{"_anim","_sb"},
"gunsmith":{"_anim","_sb"},
"Gunter":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Gunther":{"_anim","_nme","_prprn","_sb"},
"guppies":{"_anim"},
"guppy":{"_anim"},
"Gupta":{"_prprn"},
"Gur":{"_prprn"},
"gurgle":{"_loc_sr"},
"Gurkha":{"_anim","_prprn","_sb"},
"Gurkhas":{"_prprn"},
"guru":{"_anim","_sb"},
"gush":{"_loc_sr"},
"gushed":{"_loc_sr","_past"},
"gushing":{"_loc_sr"},
"Gustaf":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Gustav":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Gustavus":{"_prprn"},
"gutenberg":{"_anim","_nme","_prprn","_sb"},
"Guthrie":{"_anim","_nme","_prprn","_sb"},
"gutted":{"_past"},
"guttered":{"_past"},
"guttersnipe":{"_anim","_sb"},
"guvnor":{"_anim","_sb"},
"guy":{"_anim","_masc","_sb"},
"Guyana":{"_cntry","_geo","_prprn"},
"Guyanese":{"_anim","_prprn","_sb"},
"guys":{"_anim","_masc","_sb"},
"guzzled":{"_past"},
"Gwinnett":{"_prprn"},
"Gwyn":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"gymnasium":{"_loc_sr"},
"gymnasium-sized":{"_loc_sr"},
"gymnast":{"_anim","_sb"},
"gymnasts":{"_anim","_sb"},
"gynecologist":{"_anim","_sb"},
"gynecologists":{"_anim","_sb"},
"gyp":{"_anim","_sb"},
"gyps":{"_anim","_sb"},
"gypsies":{"_anim","_sb"},
"Gypsy":{"_anim","_prprn","_sb"},
"gyrated":{"_loc_sr","_past"},
"gyrating":{"_loc_sr"},
"h-bomb":{"_prprn"},
"Haarlem":{"_cty","_geo","_prprn"},
"Habakkuk":{"_prprn"},
"haber":{"_anim","_nme","_prprn","_sb"},
"haberdasher":{"_anim","_sb"},
"habitant":{"_anim","_sb"},
"habitants":{"_anim","_sb"},
"habitat":{"_loc_sr"},
"habitats":{"_loc_sr"},
"habited":{"_past"},
"habitue":{"_anim","_sb"},
"habitues":{"_anim","_sb"},
"Habsburg":{"_anim","_nme","_prprn","_sb"},
"hacked":{"_past"},
"hackee":{"_anim","_sb"},
"hacker":{"_anim","_sb"},
"hackers":{"_anim","_sb"},
"hackneyed":{"_past"},
"had":{"_past"},
"Haden":{"_prprn"},
"Hades":{"_anim","_loc_sr","_masc","_prprn","_sb"},
"hadji":{"_anim","_sb"},
"hadrian":{"_anim","_nme","_prprn","_sb"},
"hadrosaur":{"_anim"},
"haeckel":{"_anim","_nme","_prprn","_sb"},
"haematologist":{"_anim","_sb"},
"Hafiz":{"_anim","_prprn","_sb"},
"hag":{"_anim","_fem","_sb"},
"Hagen":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"hagerstown":{"_cty","_geo","_prprn"},
"Haggada":{"_prprn"},
"haggadah":{"_prprn"},
"Haggai":{"_prprn"},
"haggler":{"_anim","_sb"},
"hagiographa":{"_prprn"},
"hagiographer":{"_anim","_sb"},
"hagiographist":{"_anim","_sb"},
"hagiologist":{"_anim","_sb"},
"Hague":{"_prprn"},
"hahn":{"_anim","_nme","_prprn","_sb"},
"Hahnemann":{"_anim","_nme","_prprn","_sb"},
"haida":{"_anim","_prprn","_sb"},
"haifa":{"_cty","_geo","_prprn"},
"hailed":{"_loc_sr","_past","_wthr"},
"hailing":{"_loc_sr","_wthr"},
"haiphong":{"_cty","_geo","_prprn"},
"hairsbreadth":{"_loc_sr"},
"hairsplitter":{"_anim","_sb"},
"hairstylist":{"_anim","_sb"},
"Haiti":{"_cntry","_geo","_prprn"},
"Haitian":{"_anim","_prprn","_sb"},
"Haitians":{"_anim","_prprn","_sb"},
"haji":{"_anim","_sb"},
"hake":{"_anim"},
"hakenkreuz":{"_prprn"},
"halacha":{"_prprn"},
"halakah":{"_prprn"},
"haldane":{"_anim","_nme","_prprn","_sb"},
"Haldeman":{"_prprn"},
"halevy":{"_anim","_nme","_prprn","_sb"},
"Haley":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"half":{"_quant"},
"half-a-dozen":{"_quant"},
"half-a-million":{"_quant"},
"half-acceptance":{"_quant"},
"half-acre":{"_quant"},
"half-aloud":{"_quant"},
"half-an-hour":{"_quant"},
"half-billion":{"_quant"},
"half-block":{"_quant"},
"half-bottles":{"_quant"},
"half-brother":{"_anim","_masc","_sb"},
"half-brothers":{"_anim","_masc","_sb"},
"half-caste":{"_anim","_sb"},
"half-century":{"_quant"},
"half-chapter":{"_quant"},
"half-city":{"_quant"},
"half-clad":{"_quant"},
"half-closed":{"_quant"},
"half-clothed":{"_quant"},
"half-cock":{"_quant"},
"half-completed":{"_quant"},
"half-conscious":{"_quant"},
"half-court":{"_quant"},
"half-crazed":{"_quant"},
"half-crazy":{"_quant"},
"half-crocked":{"_quant"},
"half-cup":{"_quant"},
"half-darkness":{"_quant"},
"half-dozen":{"_num","_quant"},
"half-dressed":{"_quant"},
"half-drunk":{"_quant"},
"half-educated":{"_quant"},
"half-empty":{"_quant"},
"half-evergreen":{"_quant"},
"half-expressed":{"_quant"},
"half-faced":{"_quant"},
"half-filled":{"_quant"},
"half-forgotten":{"_quant"},
"half-full":{"_quant"},
"half-gainer":{"_quant"},
"half-grown":{"_quant"},
"half-holiday":{"_tme"},
"half-horse":{"_quant"},
"half-hour":{"_tme"},
"half-implemented":{"_quant"},
"half-inch":{"_quant"},
"half-industrial":{"_quant"},
"half-intensity":{"_quant"},
"half-interest":{"_quant"},
"half-jokingly":{"_quant"},
"half-man":{"_quant"},
"half-measure":{"_quant"},
"half-melted":{"_quant"},
"half-mile":{"_quant"},
"half-million":{"_quant"},
"half-mincing":{"_quant"},
"half-murmured":{"_quant"},
"half-off":{"_quant"},
"half-owned":{"_quant"},
"half-past":{"_quant"},
"half-pay":{"_quant"},
"half-percent":{"_quant"},
"half-pint":{"_sb"},
"half-point":{"_quant"},
"half-reached":{"_quant"},
"half-reformed":{"_quant"},
"half-relief":{"_quant"},
"half-reluctant":{"_quant"},
"half-seas-over":{"_quant"},
"half-seriously":{"_quant"},
"half-share":{"_quant"},
"half-sister":{"_anim","_fem","_sb"},
"half-size":{"_quant"},
"half-smile":{"_quant"},
"half-speed":{"_quant"},
"half-standard":{"_quant"},
"half-starved":{"_quant"},
"half-states":{"_quant"},
"half-straightened":{"_quant"},
"half-swamped":{"_quant"},
"half-swimming":{"_quant"},
"half-term":{"_quant"},
"half-transparent":{"_quant"},
"half-turned":{"_quant"},
"half-understood":{"_quant"},
"half-well":{"_quant"},
"half-year":{"_quant"},
"half-yearly":{"_quant"},
"halfback":{"_anim","_sb"},
"halfbacks":{"_anim","_sb"},
"halibut":{"_anim"},
"halicarnassus":{"_cty","_geo","_prprn"},
"Halifax":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"hall":{"_loc_sr"},
"hall-mark":{"_loc_sr"},
"Halle":{"_cty","_geo","_prprn"},
"halle-an-der-saale":{"_cty","_geo","_prprn"},
"halley":{"_anim","_nme","_prprn","_sb"},
"hallowed":{"_past"},
"Halloween":{"_prprn","_tme"},
"hallowmass":{"_prprn"},
"halls":{"_loc_sr"},
"halogenated":{"_past"},
"Hals":{"_anim","_nme","_prprn","_sb"},
"Halsey":{"_anim","_nme","_prprn","_sb"},
"halted":{"_past"},
"halter":{"_loc_sr"},
"halve":{"_loc_sr"},
"halved":{"_loc_sr","_past"},
"halves":{"_quant"},
"Hama":{"_cty","_geo","_prprn"},
"hamadryad":{"_anim","_fem","_sb"},
"Haman":{"_anim","_nme","_prprn","_sb"},
"Hamas":{"_prprn"},
"Hamburg":{"_cty","_geo","_prprn","_stte"},
"hamelin":{"_prprn"},
"hameln":{"_cty","_geo","_prprn"},
"Hamilton":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Hamiltonian":{"_prprn"},
"hamitic":{"_prprn"},
"hamito-semitic":{"_prprn"},
"hammarskjold":{"_anim","_nme","_prprn","_sb"},
"hammered":{"_past"},
"Hammersmith":{"_prprn"},
"Hammerstein":{"_anim","_nme","_prprn","_sb"},
"hammett":{"_anim","_nme","_prprn","_sb"},
"Hammond":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"hammurabi":{"_anim","_nme","_prprn","_sb"},
"hamper":{"_loc_sr"},
"hampered":{"_loc_sr","_past"},
"hampering":{"_loc_sr"},
"hampshire":{"_anim","_prprn"},
"Hampton":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"hamster":{"_anim"},
"hamstrung":{"_past"},
"hamsun":{"_anim","_nme","_prprn","_sb"},
"han-gook":{"_anim","_nme","_prprn","_sb"},
"Hancock":{"_anim","_nme","_prprn","_sb"},
"handcuffed":{"_past"},
"handed":{"_loc_sr","_past"},
"handed-down":{"_loc_sr","_past"},
"Handel":{"_anim","_loc_sr","_nme","_prprn","_sb"},
"handicapper":{"_anim","_sb"},
"handing":{"_loc_sr"},
"handle":{"_loc_sr"},
"handled":{"_loc_sr","_past"},
"handler":{"_anim","_sb"},
"handlers":{"_anim","_sb"},
"handmaid":{"_anim","_fem","_sb"},
"handmaiden":{"_anim","_fem","_sb"},
"handpicked":{"_past"},
"handshaker":{"_anim","_sb"},
"handyman":{"_anim","_masc","_sb"},
"handyman-carpenter":{"_anim","_masc","_sb"},
"handymen":{"_anim","_masc","_sb"},
"hangar":{"_loc_sr"},
"hangars":{"_loc_sr"},
"hangchow":{"_geo","_prprn"},
"hangdog":{"_sb"},
"hanged":{"_past"},
"hanger":{"_anim","_sb"},
"hanger-on":{"_anim","_sb"},
"hangers":{"_anim","_sb"},
"hangers-on":{"_anim","_sb"},
"hangout":{"_loc_sr"},
"hangouts":{"_loc_sr"},
"hangzhou":{"_cty","_geo","_prprn"},
"hankered":{"_past"},
"Hanna":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Hannah":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Hannibal":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"hannover":{"_geo","_prprn"},
"Hanoi":{"_cty","_geo","_prprn"},
"hanover":{"_anim","_cty","_geo","_nme","_prprn","_sb","_stte"},
"Hans":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Hansard":{"_prprn"},
"Hanson":{"_anim","_nme","_prprn","_sb"},
"hanukah":{"_prprn","_tme"},
"Hanukkah":{"_prprn"},
"hanuman":{"_anim"},
"haole":{"_sb"},
"happened":{"_past"},
"happy":{"_sb_is_jj"},
"Hapsburg":{"_anim","_nme","_prprn","_sb"},
"harangued":{"_past"},
"haranguer":{"_anim","_sb"},
"Harare":{"_cty","_geo","_prprn"},
"harass":{"_psych"},
"harassing":{"_psych"},
"harbored":{"_past"},
"harbors":{"_loc_sr"},
"harbour":{"_loc_sr"},
"hard-boiled":{"_loc_sr","_past"},
"hard-liner":{"_anim","_sb"},
"hard-liners":{"_anim","_sb"},
"harden":{"_psych"},
"hardened":{"_past","_psych"},
"hardening":{"_psych"},
"Hardin":{"_prprn"},
"Harding":{"_anim","_nme","_prprn","_sb"},
"hare":{"_loc_sr"},
"hare-brained":{"_anim"},
"harem":{"_loc_sr"},
"hares":{"_anim"},
"Hargreaves":{"_anim","_nme","_prprn","_sb"},
"Harlan":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Harlem":{"_geo","_prprn"},
"harlequin":{"_anim","_sb"},
"harlequin-snake":{"_anim","_sb"},
"Harley":{"_anim","_fnme","_nme","_prprn","_sb"},
"harlot":{"_anim","_fem","_sb"},
"Harlow":{"_anim","_geo","_nme","_prprn","_sb"},
"Harmonia":{"_prprn"},
"harmonised":{"_past"},
"harmoniser":{"_anim","_sb"},
"harmonize":{"_loc_sr"},
"harmonized":{"_loc_sr","_past"},
"harmonizer":{"_anim","_sb"},
"harmsworth":{"_anim","_nme","_prprn","_sb"},
"Harnack":{"_prprn"},
"harnessed":{"_past"},
"Harold":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"harpooner":{"_anim","_sb"},
"harpy":{"_anim","_fem","_sb"},
"harried":{"_past"},
"harrier":{"_anim"},
"Harriet":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Harriman":{"_anim","_nme","_prprn","_sb"},
"Harrington":{"_anim","_nme","_prprn","_sb"},
"harris":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Harrisburg":{"_cty","_geo","_prprn"},
"Harrison":{"_anim","_geo","_nme","_prprn","_sb"},
"harrowed":{"_past"},
"Harry":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"harshened":{"_past"},
"hart":{"_anim","_masc"},
"harte":{"_anim","_nme","_prprn","_sb"},
"hartebeest":{"_anim"},
"hartes":{"_anim","_nme","_prprn","_sb"},
"Hartford":{"_cty","_geo","_prprn"},
"Hartley":{"_prprn"},
"harvested":{"_past"},
"harvester":{"_anim","_sb"},
"harvestman":{"_anim","_masc","_sb"},
"Harvey":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"has-been":{"_anim","_sb"},
"hasdrubal":{"_anim","_nme","_prprn","_sb"},
"hashers":{"_anim","_sb"},
"hashing":{"_loc_sr"},
"hasid":{"_prprn","_sb"},
"hasidim":{"_prprn","_sb"},
"Hassam":{"_anim","_nme","_prprn","_sb"},
"hassel":{"_anim","_nme","_prprn","_sb"},
"hassid":{"_prprn"},
"hassidim":{"_prprn","_sb"},
"hassled":{"_past"},
"hastened":{"_loc_sr","_past"},
"hastens":{"_loc_sr"},
"Hastings":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"hatched":{"_past"},
"hatcheries":{"_loc_sr"},
"hatchery":{"_loc_sr"},
"hated":{"_past"},
"hatemonger":{"_anim","_sb"},
"hater":{"_anim","_sb"},
"Hathaway":{"_anim","_nme","_prprn","_sb"},
"hatted":{"_past"},
"hatter":{"_anim","_sb"},
"Hatteras":{"_prprn"},
"hattiesburg":{"_cty","_geo","_prprn"},
"Haughey":{"_prprn"},
"hauled":{"_past"},
"haulier":{"_anim","_sb"},
"haunt":{"_psych"},
"haunted":{"_past","_psych"},
"haunts":{"_loc_sr"},
"hausa":{"_anim","_prprn","_sb"},
"Haussmann":{"_anim","_nme","_prprn","_sb"},
"Havana":{"_cty","_geo","_prprn"},
"havasupai":{"_anim","_prprn","_sb"},
"Havel":{"_anim","_geo","_nme","_prprn","_sb"},
"haven":{"_loc_sr"},
"havens":{"_loc_sr"},
"haves":{"_anim","_sb"},
"Havisham":{"_prprn"},
"hawai'i":{"_geo","_prprn","_stte"},
"Hawaii":{"_geo","_prprn","_stte"},
"Hawaiian":{"_anim","_prprn","_sb"},
"hawing":{"_loc_sr"},
"hawk-faced":{"_anim"},
"hawk-hatching":{"_anim"},
"hawk-hunting":{"_anim"},
"Hawke":{"_prprn"},
"hawked":{"_past"},
"hawkers":{"_anim","_sb"},
"hawkins":{"_anim","_nme","_prprn","_sb"},
"hawks":{"_anim"},
"hawkyns":{"_anim","_nme","_prprn","_sb"},
"Haworth":{"_anim","_geo","_nme","_prprn","_sb"},
"Haydn":{"_anim","_nme","_prprn","_sb"},
"Haydon":{"_prprn"},
"Hayek":{"_anim","_nme","_prprn","_sb"},
"Hayes":{"_anim","_nme","_prprn","_sb"},
"haymaker":{"_anim","_sb"},
"Hayward":{"_cty","_geo","_prprn"},
"haywood":{"_anim","_nme","_prprn","_sb"},
"Hazlitt":{"_anim","_nme","_prprn","_sb"},
"hcg":{"_prprn"},
"hdl":{"_prprn"},
"hdtv":{"_prprn"},
"he":{"_anim","_masc","_sb"},
"he-goat":{"_anim","_masc","_sb"},
"he-goes-or-I-go":{"_anim","_masc","_sb"},
"he-huckleberry":{"_anim","_masc","_sb"},
"he-man":{"_anim","_masc","_sb"},
"Head":{"_anim","_prprn","_sb"},
"headcheese":{"_anim"},
"headed":{"_past"},
"headhunter":{"_anim","_sb"},
"headhunters":{"_anim","_sb"},
"headlands":{"_loc_sr"},
"headlined":{"_past"},
"headman":{"_anim","_sb"},
"headmistress":{"_anim","_fem","_sb"},
"headquartered":{"_past"},
"headquarters":{"_loc_sr"},
"headroom":{"_loc_sr"},
"healed":{"_past"},
"healer":{"_anim","_sb"},
"healers":{"_anim","_sb"},
"Healey":{"_prprn"},
"Healy":{"_anim","_nme","_prprn","_sb"},
"heaped":{"_loc_sr","_past"},
"heaping":{"_loc_sr"},
"heaps":{"_quant"},
"heard":{"_past"},
"hearers":{"_anim","_sb"},
"hearing-impaired":{"_anim","_sb"},
"Hearn":{"_anim","_nme","_prprn","_sb"},
"heartbreaker":{"_anim","_sb"},
"hearten":{"_psych"},
"heartened":{"_past","_psych"},
"heartening":{"_psych"},
"hearths":{"_loc_sr"},
"heartsease":{"_anim"},
"heartthrob":{"_anim","_sb"},
"heathen":{"_anim","_sb"},
"heaved":{"_past"},
"heaven":{"_loc_sr"},
"heavens":{"_loc_sr"},
"heavenwards":{"_loc"},
"heaver":{"_anim","_sb"},
"heavers":{"_anim","_sb"},
"heavies":{"_anim","_sb"},
"heaviside":{"_anim","_nme","_prprn","_sb"},
"heavy":{"_anim","_sb"},
"heavy-coated":{"_anim","_sb"},
"heavy-construction":{"_anim","_sb"},
"heavy-crude":{"_anim","_sb"},
"heavy-electrical-goods":{"_anim","_sb"},
"heavy-faced":{"_anim","_sb"},
"heavy-framed":{"_anim","_sb"},
"heavy-hitter":{"_anim","_sb"},
"heavy-limbed":{"_anim","_sb"},
"heavy-machine":{"_anim","_sb"},
"heavy-tracked":{"_anim","_sb"},
"heavy-truck":{"_anim","_sb"},
"heavy-weight":{"_anim","_sb"},
"heavyweight":{"_anim","_sb"},
"heavyweights":{"_anim","_sb"},
"hebbel":{"_anim","_nme","_prprn","_sb"},
"hebe":{"_anim","_fem","_nme","_prprn","_sb"},
"hebei":{"_geo","_prprn","_stte"},
"Hebraism":{"_prprn"},
"Hebraist":{"_prprn"},
"Hebrew":{"_prprn","_sb"},
"Hebrews":{"_prprn","_sb"},
"Hebridean":{"_prprn"},
"Hebrides":{"_geo","_prprn"},
"Hebron":{"_cty","_geo","_prprn"},
"hecate":{"_anim","_fem","_nme","_prprn","_sb"},
"hecht":{"_anim","_nme","_prprn","_sb"},
"heckled":{"_past"},
"hectare":{"_loc_sr"},
"hectares":{"_loc_sr"},
"hedged":{"_past"},
"hedgehog":{"_anim"},
"hedgehogs":{"_anim"},
"hedger":{"_anim","_sb"},
"hedgers":{"_anim","_sb"},
"hedjaz":{"_geo","_prprn"},
"heeded":{"_past"},
"heelers":{"_anim","_sb"},
"Hegel":{"_anim","_nme","_prprn","_sb"},
"Hegira":{"_prprn","_tme"},
"heidegger":{"_anim","_nme","_prprn","_sb"},
"Heidelberg":{"_cty","_geo","_prprn"},
"Heidi":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"heifer":{"_anim"},
"heifers":{"_anim"},
"Heifetz":{"_anim","_nme","_prprn","_sb"},
"heightened":{"_past"},
"Heine":{"_anim","_nme","_prprn","_sb"},
"Heinkel":{"_prprn"},
"heinlein":{"_anim","_nme","_prprn","_sb"},
"heinz":{"_anim","_nme","_prprn","_sb"},
"heir":{"_anim","_sb"},
"heir-apparent":{"_anim","_sb"},
"heir-at-law":{"_anim","_sb"},
"heir-designate":{"_anim","_sb"},
"heiress":{"_anim","_fem","_sb"},
"heirs":{"_anim","_sb"},
"Heisenberg":{"_anim","_nme","_prprn","_sb"},
"heisted":{"_past"},
"Hejira":{"_prprn"},
"Helen":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Helena":{"_anim","_cty","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"Heliopolis":{"_cty","_geo","_prprn"},
"helios":{"_prprn"},
"heliport":{"_loc_sr"},
"heliports":{"_loc_sr"},
"hell-fire":{"_loc_sr"},
"hell-kite":{"_loc_sr"},
"hell-kitten":{"_loc_sr"},
"hell-raising":{"_loc_sr"},
"hell-rooster":{"_loc_sr"},
"hellcat":{"_anim","_fem","_sb"},
"Hellene":{"_prprn"},
"Hellenic":{"_prprn"},
"Hellenism":{"_prprn"},
"Heller":{"_anim","_sb"},
"Hellespont":{"_geo","_prprn"},
"hellhole":{"_loc_sr"},
"hellhound":{"_sb"},
"hellion":{"_sb"},
"Hellman":{"_anim","_nme","_prprn","_sb"},
"hells":{"_loc_sr"},
"helmeted":{"_loc_sr","_past"},
"helmholtz":{"_anim","_nme","_prprn","_sb"},
"helmsman":{"_anim","_sb"},
"Heloise":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"helot":{"_anim","_sb"},
"helped":{"_past"},
"helper":{"_anim","_sb"},
"helpers":{"_anim","_sb"},
"helpmate":{"_anim","_sb"},
"Helsinki":{"_cty","_geo","_prprn"},
"heming":{"_anim","_nme","_prprn","_sb"},
"Hemingway":{"_anim","_nme","_prprn","_sb"},
"hemmed":{"_loc_sr","_past"},
"hemming":{"_loc_sr"},
"hemming-stitch":{"_loc_sr"},
"hemminge":{"_anim","_nme","_prprn","_sb"},
"hemophiliac":{"_anim","_sb"},
"hemophiliacs":{"_anim","_sb"},
"hemorrhaged":{"_past"},
"hen":{"_anim","_fem"},
"hen-of-the-woods":{"_anim","_fem"},
"hence":{"_loc"},
"henceforward":{"_tme"},
"henchman":{"_anim","_sb"},
"henchmen":{"_anim","_sb"},
"Henderson":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Hendrix":{"_anim","_nme","_prprn","_sb"},
"Hendry":{"_prprn"},
"henpecked":{"_past"},
"Henri":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Henrietta":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Henry":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"hens":{"_anim","_fem"},
"Henson":{"_anim","_nme","_prprn","_sb"},
"Henze":{"_prprn"},
"hepburn":{"_anim","_nme","_prprn","_sb"},
"hephaestus":{"_anim","_masc","_nme","_prprn","_sb"},
"hepworth":{"_anim","_nme","_prprn","_sb"},
"Hera":{"_anim","_fem","_nme","_prprn","_sb"},
"heracles":{"_prprn"},
"heraclitus":{"_anim","_nme","_prprn","_sb"},
"herakles":{"_prprn"},
"herald":{"_anim","_sb"},
"heralded":{"_past"},
"heraldist":{"_anim","_sb"},
"herat":{"_cty","_geo","_prprn"},
"herbalist":{"_anim","_sb"},
"herbart":{"_anim","_nme","_prprn","_sb"},
"Herbert":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"herculaneum":{"_cty","_geo","_prprn"},
"Hercules":{"_prprn"},
"hercules'-club":{"_prprn"},
"hercules'-clubs":{"_prprn"},
"hercules-club":{"_prprn"},
"herd-owner":{"_anim"},
"herded":{"_past"},
"herder":{"_anim","_sb"},
"herds":{"_anim"},
"herdsman":{"_anim","_sb"},
"herdsmen":{"_anim","_sb"},
"here-for":{"_loc_sr"},
"hereabout":{"_loc"},
"hereabouts":{"_loc"},
"hereditament":{"_loc_sr"},
"Hereford":{"_anim","_cty","_geo","_prprn"},
"herero":{"_anim","_prprn","_sb"},
"heretic":{"_anim","_sb"},
"heretics":{"_anim","_sb"},
"Herman":{"_anim","_nme","_prprn","_sb"},
"Hermann":{"_prprn"},
"hermaphrodite":{"_anim","_sb"},
"hermaphroditus":{"_prprn"},
"Hermes":{"_anim","_masc","_nme","_prprn","_sb"},
"Hermione":{"_prprn"},
"hermit":{"_anim","_sb"},
"hermitage":{"_loc_sr"},
"hermosillo":{"_cty","_geo","_prprn"},
"Hernando":{"_prprn"},
"herniated":{"_loc_sr","_past"},
"hero":{"_anim","_sb"},
"hero-worshippers":{"_anim","_sb"},
"Herod":{"_anim","_nme","_prprn","_sb"},
"Herodotus":{"_anim","_nme","_prprn","_sb"},
"heroes":{"_anim","_sb"},
"heroine":{"_anim","_fem","_sb"},
"heroines":{"_anim","_fem","_sb"},
"heron":{"_anim"},
"heronry":{"_loc_sr"},
"herons":{"_anim"},
"herpetologist":{"_anim","_sb"},
"herpetologists":{"_anim","_sb"},
"Herr":{"_anim","_prprn","_sb"},
"herrenvolk":{"_prprn"},
"Herrera":{"_anim","_nme","_prprn","_sb"},
"Herrick":{"_anim","_nme","_prprn","_sb"},
"Herschel":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"herself":{"_anim","_fem","_sb","_self"},
"hershey":{"_anim","_nme","_prprn","_sb"},
"Hertfordshire":{"_prprn"},
"Hertz":{"_anim","_prprn","_sb"},
"herzberg":{"_anim","_nme","_prprn","_sb"},
"Herzog":{"_prprn"},
"heshvan":{"_prprn"},
"hesiod":{"_anim","_nme","_prprn","_sb"},
"hesitater":{"_anim","_sb"},
"hesitator":{"_anim","_sb"},
"hesperides":{"_prprn"},
"hesperus":{"_prprn"},
"Hess":{"_anim","_nme","_prprn","_sb"},
"Hesse":{"_anim","_geo","_nme","_prprn","_sb"},
"Hester":{"_prprn"},
"hestia":{"_anim","_fem","_nme","_prprn","_sb"},
"hevesy":{"_anim","_nme","_prprn","_sb"},
"hewed":{"_past"},
"hewer":{"_anim","_sb"},
"Hewitt":{"_prprn"},
"hexed":{"_loc_sr","_past"},
"heyerdahl":{"_anim","_nme","_prprn","_sb"},
"heyrovsky":{"_anim","_nme","_prprn","_sb"},
"heyse":{"_anim","_nme","_prprn","_sb"},
"heyward":{"_anim","_nme","_prprn","_sb"},
"Heywood":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Hezbollah":{"_prprn"},
"hezekiah":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"hhs":{"_prprn"},
"hiatus":{"_loc_sr"},
"Hiawatha":{"_anim","_nme","_prprn","_sb"},
"hibbing":{"_cty","_geo","_prprn"},
"hibernate":{"_loc_sr"},
"hibernating":{"_loc_sr"},
"hibernia":{"_geo","_prprn"},
"hick":{"_anim","_sb"},
"hick-self":{"_anim","_sb"},
"Hickok":{"_anim","_nme","_prprn","_sb"},
"hid":{"_past"},
"Hidalgo":{"_sb","_stte"},
"hidatsa":{"_anim","_prprn","_sb"},
"hide-out":{"_anim"},
"hideaway":{"_loc_sr"},
"hideouts":{"_loc_sr"},
"hiders":{"_anim","_sb"},
"hides":{"_anim"},
"hierarch":{"_anim","_sb"},
"hierarchies":{"_anim","_sb"},
"hierarchy":{"_anim","_sb"},
"Hieronymus":{"_prprn"},
"Higgins":{"_anim","_nme","_prprn","_sb"},
"higginson":{"_anim","_nme","_prprn","_sb"},
"high-rise":{"_loc_sr"},
"high-rises":{"_loc_sr"},
"highball":{"_loc_sr"},
"highbrow":{"_anim","_sb"},
"highbrows":{"_anim","_sb"},
"higher-up":{"_anim","_sb"},
"highjacker":{"_anim","_sb"},
"highland":{"_loc_sr"},
"highlander":{"_anim","_sb"},
"highlands":{"_loc_sr"},
"highlighted":{"_past"},
"highlights":{"_loc_sr"},
"Highness":{"_anim","_prprn","_sb"},
"highs":{"_loc_sr","_prprn"},
"hightail":{"_loc_sr"},
"hightailing":{"_loc_sr"},
"highwayman":{"_anim","_masc","_sb"},
"hijacked":{"_past"},
"hijacker":{"_anim","_sb"},
"hijackers":{"_anim","_sb"},
"hike":{"_loc_sr"},
"hikers":{"_anim","_sb"},
"hiking":{"_loc_sr"},
"Hilary":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"hildebrand":{"_anim","_nme","_prprn","_sb"},
"hill":{"_loc_sr"},
"Hillary":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"hillbilly":{"_anim","_sb"},
"hillel":{"_anim","_nme","_prprn","_sb"},
"Hiller":{"_anim","_sb"},
"Hilliard":{"_anim","_nme","_prprn","_sb"},
"hillock":{"_loc_sr"},
"hills":{"_loc_sr"},
"hillside":{"_loc_sr"},
"hillsides":{"_loc_sr"},
"hilltop":{"_loc_sr"},
"hilltops":{"_loc_sr"},
"hilo":{"_cty","_geo","_prprn"},
"Hilton":{"_anim","_nme","_prprn","_sb"},
"him":{"_anim","_masc","_sb"},
"himalaya":{"_geo","_prprn"},
"Himalayas":{"_geo","_prprn"},
"Himmler":{"_anim","_nme","_prprn","_sb"},
"himself":{"_anim","_masc","_sb","_self"},
"hinayana":{"_prprn"},
"hinayanist":{"_prprn"},
"Hinckley":{"_geo","_prprn"},
"hind":{"_anim","_fem"},
"Hindemith":{"_anim","_nme","_prprn","_sb"},
"hindenburg":{"_anim","_nme","_prprn","_sb"},
"hinder":{"_loc_sr"},
"hindered":{"_loc_sr","_past"},
"hindering":{"_loc_sr"},
"hinders":{"_loc_sr"},
"Hindi":{"_prprn"},
"Hindoo":{"_prprn"},
"Hindustan":{"_geo","_prprn"},
"Hindustani":{"_prprn"},
"Hines":{"_anim","_nme","_prprn","_sb"},
"hinged":{"_loc_sr","_past"},
"hinny":{"_anim"},
"hinted":{"_past"},
"hinterland":{"_loc_sr"},
"hinterlands":{"_loc_sr"},
"hipparchus":{"_anim","_nme","_prprn","_sb"},
"hipped":{"_past"},
"hippie":{"_anim","_sb"},
"hippo":{"_anim"},
"Hippocrates":{"_anim","_nme","_prprn","_sb"},
"hippopotamus":{"_anim"},
"hipster":{"_anim","_sb"},
"hipsters":{"_anim","_sb"},
"Hiram":{"_prprn"},
"hired":{"_past"},
"hireling":{"_anim","_sb"},
"hirelings":{"_anim","_sb"},
"hirer":{"_anim","_sb"},
"Hirohito":{"_anim","_nme","_prprn","_sb"},
"Hiroshima":{"_cty","_geo","_prprn"},
"his":{"_anim","_masc","_sb"},
"Hispanic":{"_prprn","_sb"},
"Hispanics":{"_prprn"},
"Hispaniola":{"_geo","_prprn"},
"Hispano":{"_prprn"},
"hissed":{"_past"},
"hisser":{"_anim","_sb"},
"histologist":{"_anim","_sb"},
"historian":{"_anim","_sb"},
"historians":{"_anim","_sb"},
"historicized":{"_past"},
"historiographer":{"_anim","_sb"},
"Hitachi":{"_cty","_geo","_prprn"},
"Hitchcock":{"_anim","_nme","_prprn","_sb"},
"hitched":{"_past"},
"hitchhike":{"_loc_sr"},
"hitchhiker":{"_anim","_sb"},
"hitchings":{"_anim","_nme","_prprn","_sb"},
"hither":{"_loc"},
"hitherto":{"_tme"},
"Hitler":{"_anim","_nme","_prprn","_sb"},
"hitter":{"_anim","_sb"},
"hitters":{"_anim","_sb"},
"hitting":{"_loc_sr"},
"hitting-pitching":{"_loc_sr"},
"Hittite":{"_anim","_prprn","_sb"},
"hiv":{"_prprn"},
"hive":{"_loc_sr"},
"hives":{"_loc_sr"},
"Hizbollah":{"_prprn"},
"hmo":{"_prprn"},
"hmong":{"_anim","_prprn","_sb"},
"hn":{"_prprn"},
"HND":{"_prprn"},
"hoarfrost":{"_loc_sr"},
"hoaxer":{"_anim","_sb"},
"Hobart":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Hobbes":{"_anim","_nme","_prprn","_sb"},
"hobble":{"_loc_sr"},
"hobbled":{"_loc_sr","_past"},
"hobbledehoy":{"_anim","_sb"},
"hobbler":{"_anim","_sb"},
"hobbling":{"_loc_sr"},
"Hobbs":{"_cty","_geo","_prprn"},
"hobbyist":{"_anim","_sb"},
"hobbyists":{"_anim","_sb"},
"Hoboken":{"_cty","_geo","_prprn"},
"hobos":{"_anim","_sb"},
"Hobson":{"_prprn"},
"Hockney":{"_prprn"},
"hodeida":{"_cty","_geo","_prprn"},
"hoder":{"_anim","_sb"},
"Hodge":{"_prprn"},
"Hodgkin":{"_anim","_nme","_prprn","_sb"},
"Hoffa":{"_anim","_nme","_prprn","_sb"},
"Hoffman":{"_anim","_nme","_prprn","_sb"},
"hoffmann":{"_anim","_nme","_prprn","_sb"},
"Hofmann":{"_anim","_nme","_prprn","_sb"},
"Hogan":{"_anim","_prprn","_sb"},
"Hogarth":{"_anim","_nme","_prprn","_sb"},
"hogfish":{"_anim","_loc_sr"},
"Hogg":{"_anim","_prprn","_sb"},
"hogged":{"_past"},
"Hogmanay":{"_prprn"},
"hogs":{"_anim"},
"Hogue":{"_prprn"},
"hohenzollern":{"_anim","_nme","_prprn","_sb"},
"hohhot":{"_cty","_geo","_prprn"},
"hoisted":{"_past"},
"hoister":{"_anim","_sb"},
"Hokan":{"_prprn"},
"Hokkaido":{"_geo","_prprn","_stte"},
"Hokusai":{"_anim","_nme","_prprn","_sb"},
"Holbein":{"_anim","_nme","_prprn","_sb"},
"hold":{"_loc_sr"},
"holdall":{"_loc_sr"},
"holder":{"_anim","_sb"},
"holders":{"_anim","_sb"},
"holding":{"_loc_sr"},
"hole":{"_loc_sr"},
"hole-in-corner":{"_loc_sr"},
"hole-in-the-wall":{"_loc_sr"},
"holed":{"_past"},
"holes":{"_loc_sr"},
"holiday":{"_tme"},
"holiday-season":{"_tme"},
"holidaymaker":{"_anim","_sb"},
"holies":{"_loc_sr"},
"Holland":{"_cty","_geo","_prprn"},
"Hollander":{"_anim","_sb"},
"hollered":{"_past"},
"hollerith":{"_anim","_nme","_prprn","_sb"},
"Holliday":{"_anim","_nme","_prprn","_sb"},
"Holliger":{"_prprn"},
"hollow-back":{"_loc_sr"},
"hollow-eyed":{"_loc_sr"},
"hollow-horned":{"_loc_sr"},
"Holloway":{"_anim","_nme","_prprn","_sb"},
"hollows":{"_loc_sr"},
"Hollywood":{"_cty","_geo","_loc_sr","_prprn"},
"Holmes":{"_anim","_nme","_prprn","_sb"},
"holocene":{"_prprn"},
"Holstein":{"_geo","_prprn"},
"holstein-friesian":{"_anim","_prprn"},
"holstered":{"_loc_sr","_past"},
"Holt":{"_anim","_nme","_prprn","_sb"},
"holy":{"_loc_sr"},
"hombre":{"_sb"},
"home":{"_loc_sr"},
"home-acquisition":{"_loc_sr"},
"home-and-home":{"_loc_sr"},
"home-audience":{"_loc_sr"},
"home-baked":{"_loc_sr"},
"home-blend":{"_loc_sr"},
"home-bound":{"_loc_sr"},
"home-bred":{"_loc_sr"},
"home-building":{"_loc_sr"},
"home-buying":{"_loc_sr"},
"home-care":{"_loc_sr"},
"home-center":{"_loc_sr"},
"home-city":{"_loc_sr"},
"home-comings":{"_loc_sr"},
"home-computer":{"_loc_sr"},
"home-court":{"_loc_sr"},
"home-cured":{"_loc_sr"},
"home-delivered":{"_loc_sr"},
"home-delivery":{"_loc_sr"},
"home-entertainment":{"_loc_sr"},
"home-equity":{"_loc_sr"},
"home-farm":{"_loc_sr"},
"home-fashion":{"_loc_sr"},
"home-field":{"_loc_sr"},
"home-for-the-night":{"_loc_sr"},
"home-furnishing":{"_loc_sr"},
"home-furnishings":{"_loc_sr"},
"home-grown":{"_loc_sr"},
"home-health-care":{"_loc_sr"},
"home-improvement":{"_loc_sr"},
"home-loving":{"_loc_sr"},
"home-market":{"_loc_sr"},
"home-mortgage":{"_loc_sr"},
"home-nursing":{"_loc_sr"},
"home-office":{"_loc_sr"},
"home-owners":{"_loc_sr"},
"home-ownership":{"_loc_sr"},
"home-plate":{"_loc_sr"},
"home-produced":{"_loc_sr"},
"home-run":{"_loc_sr"},
"home-service":{"_loc_sr"},
"home-sharing":{"_loc_sr"},
"home-shopping":{"_loc_sr"},
"home-team":{"_loc_sr"},
"home-trading":{"_loc_sr"},
"home-video":{"_loc_sr"},
"homebody":{"_anim","_sb"},
"homeboy":{"_anim","_masc","_sb"},
"homebuilder":{"_anim","_sb"},
"homebuilders":{"_anim","_sb"},
"homeland":{"_loc_sr"},
"homelands":{"_loc_sr"},
"homeless":{"_anim","_sb"},
"homemakers":{"_anim","_sb"},
"homeowner":{"_anim","_sb"},
"homeowners":{"_anim","_sb"},
"Homer":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"homered":{"_past"},
"homes":{"_loc_sr"},
"homesteader":{"_anim","_sb"},
"homesteaders":{"_anim","_sb"},
"homesteads":{"_loc_sr"},
"homing":{"_loc_sr"},
"hominoid":{"_sb"},
"homo":{"_sb"},
"homo-hatred":{"_sb"},
"homoeopath":{"_anim","_sb"},
"homogenised":{"_past"},
"homogenized":{"_past"},
"homosexual":{"_anim","_sb"},
"homosexuals":{"_anim","_sb"},
"homunculus":{"_sb"},
"Hon":{"_prprn"},
"Hon.":{"_anim","_prprn","_sb"},
"Honan":{"_geo","_prprn"},
"honcho":{"_anim","_sb"},
"Hondo":{"_prprn"},
"Honduran":{"_anim","_prprn","_sb"},
"Hondurans":{"_anim","_prprn","_sb"},
"Honduras":{"_cntry","_geo","_prprn"},
"hone":{"_loc_sr"},
"Honecker":{"_prprn"},
"honed":{"_loc_sr","_past"},
"honegger":{"_anim","_nme","_prprn","_sb"},
"honeybee":{"_anim"},
"honeybees":{"_anim"},
"honeycombed":{"_past"},
"honeyed":{"_past"},
"honeymooned":{"_past"},
"honeymooner":{"_anim","_sb"},
"honeymooners":{"_anim","_sb"},
"Hong":{"_prprn"},
"Hongkong":{"_prprn"},
"honiara":{"_cty","_geo","_prprn"},
"honied":{"_past"},
"honker":{"_anim","_sb"},
"honkie":{"_anim","_sb"},
"Honolulu":{"_cty","_geo","_prprn"},
"honor":{"_loc_sr"},
"honored":{"_loc_sr","_past"},
"honoring":{"_loc_sr"},
"honoured":{"_past"},
"Honshu":{"_geo","_prprn"},
"hoodlums":{"_anim","_sb"},
"hoodoo":{"_sb"},
"hoodwinked":{"_past"},
"hoofed":{"_past"},
"hooke":{"_anim","_nme","_prprn","_sb"},
"hooked":{"_past"},
"hookers":{"_anim","_sb"},
"hooligan":{"_anim","_sb"},
"Hoosier":{"_prprn"},
"hooted":{"_past"},
"hop-picker":{"_sb"},
"hoped":{"_past"},
"hoped-for":{"_past"},
"hopeful":{"_anim","_sb"},
"hopeh":{"_prprn"},
"Hopei":{"_geo","_prprn"},
"hoper":{"_anim","_sb"},
"Hopi":{"_prprn","_sb"},
"Hopis":{"_prprn","_sb"},
"Hopkins":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"hopkinson":{"_anim","_nme","_prprn","_sb"},
"hopped":{"_loc_sr","_past"},
"hopping":{"_loc_sr"},
"hopscotch":{"_loc_sr"},
"Horace":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Horatio":{"_prprn"},
"Hordern":{"_prprn"},
"hornbill":{"_anim"},
"horned":{"_past"},
"horney":{"_anim","_nme","_prprn","_sb"},
"hornist":{"_anim","_sb"},
"horologer":{"_anim","_sb"},
"horologist":{"_anim","_sb"},
"Horowitz":{"_anim","_nme","_prprn","_sb"},
"horrendous":{"_psych"},
"horrible":{"_psych"},
"horrified":{"_past","_psych"},
"horrify":{"_psych"},
"horrifying":{"_psych"},
"horse-blanket":{"_anim"},
"horse-breeding":{"_anim"},
"horse-brier":{"_anim"},
"horse-cart":{"_anim"},
"horse-chestnut":{"_anim"},
"horse-drawn":{"_anim"},
"horse-head":{"_anim"},
"horse-meat":{"_anim"},
"horse-packing":{"_anim"},
"horse-pistol":{"_anim"},
"horse-player":{"_anim"},
"horse-playing":{"_anim"},
"horse-race":{"_anim"},
"horse-radish":{"_anim"},
"horse-steak":{"_anim"},
"horse-trade":{"_anim"},
"horsefly":{"_anim"},
"horses":{"_anim"},
"horseshoer":{"_anim","_sb"},
"horseshoers":{"_anim","_sb"},
"horst":{"_loc_sr"},
"Horta":{"_prprn"},
"horus":{"_anim","_masc","_nme","_prprn","_sb"},
"Hosea":{"_prprn"},
"hosier":{"_anim","_sb"},
"hospital":{"_loc_sr"},
"hospital-care":{"_loc_sr"},
"hospitalize":{"_loc_sr"},
"hospitalized":{"_loc_sr","_past"},
"hospitals":{"_loc_sr"},
"host":{"_anim","_sb"},
"host-specific":{"_anim","_sb"},
"hostage":{"_anim","_sb"},
"hostages":{"_anim","_sb"},
"hosted":{"_past"},
"hostel":{"_loc_sr"},
"hosteller":{"_anim","_sb"},
"hostess":{"_anim","_fem","_sb"},
"hostesses":{"_anim","_fem","_sb"},
"hostile":{"_sb"},
"hostile-bid":{"_sb"},
"hosts":{"_anim","_sb"},
"hotbed":{"_loc_sr"},
"hotel":{"_loc_sr"},
"hotel-casino":{"_loc_sr"},
"hotel-casinos":{"_loc_sr"},
"hotel-management":{"_loc_sr"},
"hotel-motel":{"_loc_sr"},
"hotel-restaurant":{"_loc_sr"},
"hotelier":{"_anim","_sb"},
"hoteliers":{"_anim","_sb"},
"hotelkeeper":{"_anim","_sb"},
"hotels":{"_loc_sr"},
"hotfoot":{"_loc_sr"},
"hothead":{"_anim","_sb"},
"hothouse":{"_loc_sr"},
"hothouses":{"_loc_sr"},
"Hottentot":{"_prprn"},
"Houdini":{"_anim","_nme","_prprn","_sb"},
"houghton":{"_anim","_nme","_prprn","_sb"},
"hounded":{"_past"},
"hounds":{"_anim"},
"hour":{"_tme"},
"hour-and-a-half":{"_tme"},
"hourglass":{"_loc_sr"},
"hourglass-shaped":{"_loc_sr"},
"houri":{"_anim","_fem","_sb"},
"housatonic":{"_geo","_prprn"},
"house-builder":{"_loc_sr"},
"house-building":{"_loc_sr"},
"house-cleaning":{"_loc_sr"},
"house-painting":{"_loc_sr"},
"house-trained":{"_past"},
"housebreaker":{"_anim","_sb"},
"housebreakers":{"_anim","_sb"},
"housed":{"_past"},
"housedog":{"_anim"},
"housefather":{"_anim","_masc","_sb"},
"housefly":{"_anim"},
"houseguest":{"_anim","_sb"},
"household":{"_anim","_sb"},
"household-products":{"_anim","_sb"},
"household-type":{"_anim","_sb"},
"householders":{"_anim","_sb"},
"households":{"_anim","_sb"},
"househusband":{"_anim","_masc","_sb"},
"housemaid":{"_anim","_fem","_sb"},
"housemaster":{"_anim","_masc","_sb"},
"housemate":{"_anim","_sb"},
"housemother":{"_anim","_fem","_sb"},
"houses":{"_loc_sr"},
"housewives":{"_anim","_fem","_sb"},
"housman":{"_anim","_nme","_prprn","_sb"},
"hove":{"_past"},
"hovel":{"_loc_sr"},
"hovels":{"_loc_sr"},
"hover":{"_loc_sr"},
"hovered":{"_loc_sr","_past"},
"hovering":{"_loc_sr"},
"how":{"_wh"},
"Howard":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"howe":{"_anim","_nme","_prprn","_sb"},
"howells":{"_anim","_nme","_prprn","_sb"},
"however":{"_wh"},
"howl":{"_wthr"},
"howled":{"_past","_wthr"},
"howler":{"_anim"},
"howlers":{"_anim"},
"howling":{"_wthr"},
"hoyden":{"_anim","_fem","_sb"},
"Hoylake":{"_prprn"},
"Hoyle":{"_prprn"},
"HQ":{"_prprn"},
"hrolf":{"_anim","_nme","_prprn","_sb"},
"hsian":{"_geo","_prprn"},
"hualapai":{"_anim","_prprn","_sb"},
"Huang":{"_prprn"},
"huascaran":{"_geo","_prprn"},
"Hubbard":{"_anim","_nme","_prprn","_sb"},
"hubble":{"_anim","_nme","_prprn","_sb"},
"hubby":{"_anim","_masc","_sb"},
"hubel":{"_anim","_nme","_prprn","_sb"},
"Hubert":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"huckleberry":{"_anim"},
"hud":{"_prprn"},
"huddler":{"_anim","_sb"},
"Hudson":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"huffed":{"_past"},
"Huggies":{"_prprn"},
"Huggins":{"_anim","_nme","_prprn","_sb"},
"Hugh":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Hughes":{"_anim","_nme","_prprn","_sb"},
"Hugo":{"_anim","_nme","_prprn","_sb"},
"huguenot":{"_prprn"},
"hula-hoop":{"_prprn"},
"human":{"_anim","_sb"},
"human-based":{"_anim","_sb"},
"human-centered":{"_anim","_sb"},
"human-centred":{"_anim","_sb"},
"human-generated":{"_anim","_sb"},
"human-leukocyte-derived":{"_anim","_sb"},
"human-resources":{"_anim","_sb"},
"human-rights":{"_anim","_sb"},
"human-robot":{"_anim","_sb"},
"human-sized":{"_anim","_sb"},
"human-sounding":{"_anim","_sb"},
"humanist":{"_anim","_sb"},
"humanists":{"_anim","_sb"},
"humanitarian":{"_anim","_sb"},
"humanity":{"_sb"},
"humankind":{"_anim","_sb"},
"humans":{"_anim","_sb"},
"humber":{"_geo","_prprn"},
"humble":{"_psych"},
"humbled":{"_past","_psych"},
"humbling":{"_psych"},
"humboldt":{"_anim","_nme","_prprn","_sb"},
"humdinger":{"_sb"},
"Hume":{"_anim","_nme","_prprn","_sb"},
"humidity":{"_loc_sr"},
"humified":{"_past"},
"humiliate":{"_psych"},
"humiliated":{"_past","_psych"},
"humiliates":{"_psych"},
"humiliating":{"_psych"},
"hummed":{"_past"},
"hummer":{"_anim","_sb"},
"hummingbird":{"_anim"},
"hummock":{"_loc_sr"},
"hummocks":{"_loc_sr"},
"humorist":{"_anim","_sb"},
"humorists":{"_anim","_sb"},
"humourist":{"_anim","_sb"},
"humped":{"_loc_sr","_past"},
"humperdinck":{"_anim","_nme","_prprn","_sb"},
"Humphrey":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Humphries":{"_prprn"},
"Hun":{"_anim","_prprn","_sb"},
"Hunan":{"_geo","_prprn","_stte"},
"hunchback":{"_anim","_sb"},
"hunched":{"_past"},
"hunched-up":{"_past"},
"hundred":{"_num","_quant"},
"hundred-and-eightieth":{"_num","_quant"},
"hundred-and-eighty-degree":{"_num","_quant"},
"hundred-and-fifteenth":{"_num","_quant"},
"hundred-and-fifth":{"_num","_quant"},
"hundred-and-fiftieth":{"_num","_quant"},
"hundred-and-fifty":{"_num","_quant"},
"hundred-and-fifty-fifth":{"_num","_quant"},
"hundred-and-first":{"_num","_quant"},
"hundred-and-fortieth":{"_num","_quant"},
"hundred-and-forty-fifth":{"_num","_quant"},
"hundred-and-ninetieth":{"_num","_quant"},
"hundred-and-seventieth":{"_num","_quant"},
"hundred-and-seventy-fifth":{"_num","_quant"},
"hundred-and-sixtieth":{"_num","_quant"},
"hundred-and-sixty-fifth":{"_num","_quant"},
"hundred-and-tenth":{"_num","_quant"},
"hundred-and-thirtieth":{"_num","_quant"},
"hundred-and-thirty-fifth":{"_num","_quant"},
"hundred-and-twentieth":{"_num","_quant"},
"hundred-and-twenty-fifth":{"_num","_quant"},
"hundred-leaf":{"_num","_quant"},
"hundred-odd":{"_num","_quant"},
"hundred-percenter":{"_num","_quant"},
"hundred-thousand-share":{"_num","_quant"},
"hundred-yen":{"_num","_quant"},
"hundredfold":{"_quant"},
"hundreds":{"_num","_quant"},
"hundreds-of-billions-of-yen":{"_num","_quant"},
"Hungarians":{"_anim","_prprn","_sb"},
"Hungary":{"_cntry","_geo","_prprn"},
"hunkered":{"_past"},
"hunkpapa":{"_anim","_prprn","_sb"},
"hunted":{"_past"},
"hunter":{"_anim","_sb"},
"hunter-gatherer":{"_anim","_sb"},
"hunter-gatherers":{"_anim","_sb"},
"hunters":{"_anim","_sb"},
"huntington":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"huntress":{"_anim","_fem","_sb"},
"huntsman":{"_anim","_masc","_sb"},
"Huntsville":{"_cty","_geo","_prprn"},
"Hurd":{"_prprn"},
"hurdled":{"_past"},
"hurled":{"_past"},
"hurler":{"_anim","_sb"},
"hurlers":{"_anim","_sb"},
"hurley":{"_anim","_nme","_prprn","_sb"},
"hurok":{"_anim","_nme","_prprn","_sb"},
"Huron":{"_prprn"},
"hurried":{"_loc_sr","_past"},
"hurry":{"_loc_sr"},
"hurrying":{"_loc_sr"},
"hurting":{"_psych"},
"hurtle":{"_loc_sr"},
"hurtled":{"_loc_sr","_past"},
"hurtling":{"_loc_sr"},
"hus":{"_anim","_nme","_prprn","_sb"},
"husain":{"_anim","_nme","_prprn","_sb"},
"husayn":{"_prprn"},
"husband":{"_anim","_masc","_sb"},
"husband-and-wife":{"_anim","_masc","_sb"},
"husband-stealer":{"_anim","_masc","_sb"},
"husbandman":{"_anim","_sb"},
"husbands":{"_anim","_masc","_sb"},
"hushed":{"_past"},
"hushed-up":{"_past"},
"husky-voiced":{"_anim","_sb"},
"huss":{"_anim","_nme","_prprn","_sb"},
"hussar":{"_anim","_sb"},
"Hussein":{"_anim","_nme","_prprn","_sb"},
"husserl":{"_anim","_nme","_prprn","_sb"},
"hussite":{"_prprn"},
"hussy":{"_anim","_fem","_sb"},
"hustings":{"_loc_sr"},
"hustle":{"_loc_sr"},
"hustlers":{"_anim","_sb"},
"Huston":{"_anim","_nme","_prprn","_sb"},
"hut":{"_loc_sr"},
"Hutchins":{"_anim","_nme","_prprn","_sb"},
"Hutchinson":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"huts":{"_loc_sr"},
"Hutton":{"_prprn"},
"Hutu":{"_prprn"},
"Huxley":{"_anim","_nme","_prprn","_sb"},
"huygens":{"_anim","_nme","_prprn","_sb"},
"hyades":{"_anim","_fem","_nme","_prprn","_sb"},
"hyaena":{"_anim"},
"Hyde":{"_anim","_nme","_prprn","_sb"},
"hyderabad":{"_cty","_geo","_prprn"},
"hydrated":{"_past"},
"hydrologist":{"_anim","_sb"},
"hydrolyzed":{"_past"},
"hydropathy":{"_loc_sr"},
"hydroplane":{"_loc_sr"},
"hydrosphere":{"_loc_sr"},
"hydrotherapy":{"_loc_sr"},
"hydrus":{"_prprn"},
"hyena":{"_anim"},
"hyenas":{"_anim"},
"hygeia":{"_anim","_fem","_nme","_prprn","_sb"},
"hymie":{"_prprn"},
"hyperion":{"_prprn"},
"hypertrophied":{"_past"},
"hyphenated":{"_past"},
"hypnos":{"_anim","_masc","_nme","_prprn","_sb"},
"hypnotic":{"_anim","_sb"},
"hypnotised":{"_past"},
"hypnotiser":{"_anim","_sb"},
"hypnotist":{"_anim","_sb"},
"hypnotize":{"_loc_sr","_psych"},
"hypnotized":{"_loc_sr","_past","_psych"},
"hypnotizer":{"_anim","_sb"},
"hypochondriac":{"_anim","_sb"},
"hypocrite":{"_anim","_sb"},
"hypocrites":{"_anim","_sb"},
"hyrax":{"_anim"},
"hysterics":{"_anim","_sb"},
"hz":{"_prprn"},
"i":{"_anim","_sb"},
"i-beam":{"_prprn"},
"ia":{"_prprn","_stte"},
"iaa":{"_prprn"},
"Iacocca":{"_prprn"},
"Iago":{"_prprn"},
"Ian":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"iapetus":{"_prprn"},
"ib.":{"_prprn"},
"ibadan":{"_cty","_geo","_prprn"},
"Iberia":{"_cntry","_geo","_prprn"},
"Iberian":{"_anim","_prprn","_sb"},
"ibex":{"_anim"},
"ibis":{"_anim"},
"Ibrahim":{"_prprn"},
"ibrd":{"_prprn"},
"Ibsen":{"_anim","_nme","_prprn","_sb"},
"ic":{"_prprn"},
"ICA":{"_cty","_geo","_prprn"},
"Icarus":{"_prprn"},
"icbm":{"_prprn"},
"icc":{"_prprn"},
"ice":{"_loc_sr"},
"ice-baggers":{"_loc_sr"},
"ice-breaker":{"_loc_sr"},
"ice-chest":{"_loc_sr"},
"ice-clogged":{"_loc_sr"},
"ice-core":{"_loc_sr"},
"ice-cream":{"_loc_sr"},
"ice-cubes":{"_loc_sr"},
"ice-feeling":{"_loc_sr"},
"ice-filled":{"_loc_sr"},
"ice-skater":{"_anim","_sb"},
"ice-wagon":{"_loc_sr"},
"iced":{"_past"},
"iced-tea":{"_past"},
"icefall":{"_loc_sr"},
"icehouse":{"_loc_sr"},
"Iceland":{"_cntry","_geo","_prprn"},
"Icelander":{"_anim","_prprn","_sb"},
"Icelandic":{"_prprn"},
"icelandic-speaking":{"_prprn"},
"iceman":{"_anim","_masc","_sb"},
"ichneumon":{"_anim"},
"ichthyologist":{"_anim","_sb"},
"ichthyosaurus":{"_anim"},
"iconoclast":{"_anim","_sb"},
"icu":{"_prprn"},
"ida":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Idaho":{"_geo","_prprn","_stte"},
"idealised":{"_past"},
"idealist":{"_anim","_sb"},
"identified":{"_past"},
"ides":{"_tme"},
"idiot-grin":{"_anim","_sb"},
"idiots":{"_anim","_sb"},
"idle":{"_loc_sr"},
"idled":{"_loc_sr","_past"},
"idling":{"_loc_sr"},
"idolater":{"_anim","_sb"},
"idolised":{"_past"},
"idoliser":{"_anim","_sb"},
"idolized":{"_past"},
"idolizer":{"_anim","_sb"},
"idp":{"_prprn"},
"IDs":{"_prprn"},
"Ifni":{"_geo","_prprn"},
"Igbo":{"_anim","_prprn","_sb"},
"Ignatius":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"ignited":{"_past"},
"igniter":{"_anim","_sb"},
"ignitor":{"_anim","_sb"},
"ignoramus":{"_anim","_sb"},
"ignored":{"_past"},
"Igor":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"iguana":{"_anim"},
"iguanas":{"_anim"},
"iguassu":{"_geo","_prprn"},
"Ike":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"il":{"_prprn","_stte"},
"ile-de-france":{"_geo","_prprn","_stte"},
"Iliad":{"_prprn"},
"ilion":{"_geo","_prprn"},
"ill-used":{"_past"},
"illampu":{"_geo","_prprn"},
"illimani":{"_geo","_prprn"},
"Illinois":{"_geo","_prprn","_stte"},
"illiterate":{"_anim","_sb"},
"illumined":{"_past"},
"illusionist":{"_anim","_sb"},
"illustrated":{"_past"},
"illustrator":{"_anim","_sb"},
"illustrators":{"_anim","_sb"},
"illyria":{"_geo","_prprn"},
"illyrian":{"_anim","_prprn","_sb"},
"ilo":{"_prprn"},
"Ilyushin":{"_prprn"},
"imaged":{"_past"},
"imagine":{"_loc_sr"},
"imagined":{"_loc_sr","_past"},
"imagining":{"_loc_sr"},
"imam":{"_anim","_masc","_sb"},
"IMAX":{"_prprn"},
"imbecile":{"_anim","_sb"},
"imbedded":{"_past"},
"imbibed":{"_past"},
"imbiber":{"_anim","_sb"},
"imbricate":{"_loc_sr"},
"imbricated":{"_loc_sr","_past"},
"imf":{"_prprn"},
"imitated":{"_past"},
"imitator":{"_anim","_sb"},
"imitators":{"_anim","_sb"},
"Immanuel":{"_prprn"},
"immediately":{"_tme"},
"immerse":{"_loc_sr"},
"immersed":{"_loc_sr","_past"},
"immigrant":{"_anim","_sb"},
"immigrants":{"_anim","_sb"},
"immigrate":{"_loc_sr"},
"immigrated":{"_loc_sr","_past"},
"immobilized":{"_past"},
"immortalized":{"_past"},
"immune-system":{"_anim","_sb"},
"immunised":{"_past"},
"immunologist":{"_anim","_sb"},
"impacted":{"_past"},
"impairer":{"_anim","_sb"},
"impala":{"_anim"},
"impale":{"_loc_sr"},
"impaled":{"_loc_sr","_past"},
"impaling":{"_loc_sr"},
"impassioned":{"_past","_psych"},
"impeached":{"_past"},
"impeded":{"_past"},
"imperil":{"_loc_sr"},
"imperiling":{"_loc_sr"},
"imperilled":{"_loc_sr","_past"},
"impersonalized":{"_past"},
"impersonated":{"_past"},
"implant":{"_loc_sr"},
"implanted":{"_loc_sr","_past"},
"implanting":{"_loc_sr"},
"implement":{"_loc_sr"},
"implemented":{"_loc_sr","_past"},
"implementer":{"_anim","_sb"},
"implementing":{"_loc_sr"},
"implicated":{"_past"},
"implied":{"_past"},
"implore":{"_loc_sr"},
"implored":{"_loc_sr","_past"},
"implores":{"_loc_sr"},
"imploring":{"_loc_sr"},
"import":{"_loc_sr"},
"imported":{"_loc_sr","_past"},
"imported-food":{"_loc_sr","_past"},
"importee":{"_anim","_sb"},
"importing":{"_loc_sr"},
"imposed":{"_past"},
"imposter":{"_anim","_sb"},
"impostor":{"_anim","_sb"},
"impounded":{"_past"},
"impoverish":{"_psych"},
"impoverished":{"_past","_psych"},
"impresario":{"_anim","_sb"},
"impress":{"_psych"},
"impressed":{"_past","_psych"},
"impresser":{"_anim","_sb"},
"impressing":{"_psych"},
"impressionist":{"_anim","_sb"},
"impressionists":{"_anim","_sb"},
"impressment":{"_sb"},
"imprinted":{"_loc_sr","_past"},
"imprison":{"_loc_sr"},
"imprisoned":{"_loc_sr","_past"},
"imprisoning":{"_loc_sr"},
"imprisons":{"_loc_sr"},
"improved":{"_past"},
"improver":{"_anim","_sb"},
"improviser":{"_anim","_sb"},
"improvisers":{"_anim","_sb"},
"impugn":{"_loc_sr"},
"impugned":{"_loc_sr","_past"},
"imputed":{"_past"},
"in":{"_loc"},
"in-accord-with-nature":{"_loc"},
"in-and-outer":{"_loc"},
"in-basket":{"_loc"},
"in-bounds":{"_loc"},
"in-chief":{"_loc"},
"in-crowd":{"_loc"},
"in-fighting":{"_loc"},
"in-group":{"_anim","_sb"},
"in-groups":{"_anim","_sb"},
"in-grown":{"_loc"},
"in-law":{"_sb"},
"in-laws":{"_anim","_sb"},
"in-line":{"_loc"},
"in-patient":{"_anim","_sb"},
"in-person":{"_loc"},
"in-plant":{"_loc"},
"in-situ":{"_loc"},
"in-state":{"_loc"},
"in-store":{"_loc"},
"in-tray":{"_loc"},
"in-your-face":{"_loc"},
"inactivated":{"_past"},
"inamorato":{"_anim","_masc","_sb"},
"inaugurate":{"_loc_sr"},
"inaugurated":{"_loc_sr","_past"},
"inaugurating":{"_loc_sr"},
"inbred":{"_past"},
"Inc":{"_prprn"},
"inc.":{"_prprn"},
"Inca":{"_prprn","_sb"},
"Incan":{"_prprn"},
"incapacitated":{"_past"},
"incarcerate":{"_loc_sr"},
"incarcerated":{"_loc_sr","_past"},
"Incarnation":{"_prprn","_tme"},
"incarnations":{"_tme"},
"incased":{"_past"},
"incensed":{"_past","_psych"},
"incepted":{"_past"},
"inceptor":{"_anim","_sb"},
"inched":{"_loc_sr","_past"},
"inching":{"_loc_sr"},
"inchon":{"_cty","_geo","_prprn"},
"incised":{"_past"},
"inciter":{"_anim","_sb"},
"inclining":{"_loc_sr"},
"inclosed":{"_past"},
"included":{"_past"},
"includee":{"_anim","_sb"},
"incognito":{"_anim","_sb"},
"incompetents":{"_anim","_sb"},
"Incorporated":{"_past"},
"incorrigible":{"_anim","_sb"},
"increased":{"_past"},
"incubate":{"_loc_sr"},
"incubated":{"_loc_sr","_past"},
"incubating":{"_loc_sr"},
"incubi":{"_anim","_masc","_sb"},
"incumbent":{"_anim","_sb"},
"incumbent-protection":{"_anim","_sb"},
"incumbents":{"_anim","_sb"},
"incurred":{"_past"},
"incurved":{"_past"},
"Ind":{"_prprn","_stte"},
"Ind.":{"_prprn","_stte"},
"indefinitely":{"_tme"},
"indent":{"_loc_sr"},
"inderal":{"_prprn"},
"indexed":{"_past"},
"India":{"_cntry","_geo","_prprn"},
"indiaman":{"_prprn"},
"Indian":{"_anim","_prprn","_sb"},
"Indiana":{"_anim","_geo","_nme","_prprn","_sb","_stte"},
"Indianapolis":{"_cty","_geo","_prprn"},
"Indic":{"_prprn"},
"indicated":{"_past"},
"indicted":{"_past"},
"Indies":{"_geo","_prprn"},
"indigent":{"_sb"},
"indigirka":{"_geo","_prprn"},
"indisposed":{"_past"},
"individual":{"_anim","_sb"},
"individual-contributor":{"_anim","_sb"},
"individual-investor":{"_anim","_sb"},
"individual-retirement-account":{"_anim","_sb"},
"individual-type":{"_anim","_sb"},
"individualised":{"_past"},
"individualist":{"_anim","_sb"},
"individualists":{"_anim","_sb"},
"individualized":{"_past"},
"individuals":{"_anim","_sb"},
"indo-aryan":{"_prprn","_sb"},
"Indo-China":{"_prprn"},
"Indo-European":{"_anim","_prprn","_sb"},
"indo-germanic":{"_prprn"},
"indo-hittite":{"_prprn"},
"indo-iranian":{"_prprn"},
"Indochina":{"_geo","_prprn"},
"indocin":{"_prprn"},
"indoctrinate":{"_loc_sr"},
"indoctrinated":{"_loc_sr","_past"},
"indoctrinating":{"_loc_sr"},
"Indonesia":{"_cntry","_geo","_prprn"},
"Indonesian":{"_anim","_prprn","_sb"},
"Indonesians":{"_anim","_prprn","_sb"},
"indorsed":{"_past"},
"indorser":{"_anim","_sb"},
"indra":{"_prprn"},
"indri":{"_anim"},
"indris":{"_anim"},
"induce":{"_loc_sr"},
"inducing":{"_loc_sr"},
"induct":{"_loc_sr"},
"inducted":{"_loc_sr","_past"},
"inductee":{"_anim","_sb"},
"indulged":{"_past"},
"industrialised":{"_past"},
"industrialists":{"_anim","_sb"},
"industrialized":{"_past"},
"indweller":{"_anim","_sb"},
"Indy":{"_anim","_nme","_prprn","_sb"},
"inebriate":{"_psych"},
"inebriated":{"_past","_psych"},
"Inez":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"infant":{"_anim","_sb"},
"infant-formula":{"_anim","_sb"},
"infant-mortality":{"_anim","_sb"},
"infantry":{"_anim","_sb"},
"infantrymen":{"_anim","_sb"},
"infatuate":{"_psych"},
"infatuated":{"_past","_psych"},
"infect":{"_loc_sr"},
"infected":{"_loc_sr","_past"},
"infecting":{"_loc_sr"},
"infer":{"_loc_sr"},
"inferior":{"_anim","_sb"},
"infest":{"_loc_sr"},
"infested":{"_loc_sr","_past"},
"infesting":{"_loc_sr"},
"infests":{"_loc_sr"},
"infidel":{"_anim","_sb"},
"infidels":{"_anim","_sb"},
"infield":{"_loc_sr"},
"infielder":{"_anim","_sb"},
"infielders":{"_anim","_sb"},
"infiltrate":{"_loc_sr"},
"infiltrated":{"_loc_sr","_past"},
"infiltrating":{"_loc_sr"},
"infinitely":{"_tme"},
"infix":{"_loc_sr"},
"inflamed":{"_past","_psych"},
"inflated":{"_past"},
"inflater":{"_anim","_sb"},
"inflator":{"_anim","_sb"},
"inflect":{"_loc_sr"},
"inflected":{"_loc_sr","_past"},
"inflecting":{"_loc_sr"},
"inflicted":{"_past"},
"influenced":{"_loc_sr","_past"},
"influencing":{"_loc_sr"},
"informant":{"_anim","_sb"},
"informants":{"_anim","_sb"},
"informed":{"_past"},
"informer":{"_anim","_sb"},
"infra":{"_loc"},
"infrequently":{"_tme"},
"infringe":{"_loc_sr"},
"infringed":{"_loc_sr","_past"},
"infringes":{"_loc_sr"},
"infringing":{"_loc_sr"},
"infuriate":{"_psych"},
"infuriated":{"_past","_psych"},
"infuriating":{"_psych"},
"infuse":{"_loc_sr"},
"infused":{"_loc_sr","_past"},
"inga":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"inge":{"_anim","_nme","_prprn","_sb"},
"ingenue":{"_anim","_fem","_sb"},
"Ingersoll":{"_anim","_nme","_prprn","_sb"},
"ingest":{"_loc_sr"},
"ingested":{"_loc_sr","_past"},
"inglenook":{"_loc_sr"},
"ingrained":{"_past"},
"ingrate":{"_sb"},
"ingrates":{"_sb"},
"Ingres":{"_anim","_nme","_prprn","_sb"},
"Ingrid":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"inh":{"_prprn"},
"inhabitant":{"_anim","_sb"},
"inhabitants":{"_anim","_sb"},
"inhaled":{"_past"},
"inherit":{"_loc_sr"},
"inherited":{"_loc_sr","_past"},
"inheritors":{"_anim","_sb"},
"inherits":{"_loc_sr"},
"inhibited":{"_past"},
"inholdings":{"_loc_sr"},
"inhume":{"_loc_sr"},
"inhumed":{"_loc_sr","_past"},
"initial":{"_loc_sr"},
"initialed":{"_loc_sr","_past"},
"initiated":{"_past"},
"initiates":{"_anim","_sb"},
"injector":{"_anim","_sb"},
"Injun":{"_prprn"},
"injured":{"_past"},
"inkpad":{"_loc_sr"},
"inlaid":{"_loc_sr","_past"},
"inlay":{"_loc_sr"},
"inlet":{"_loc_sr"},
"inlets":{"_loc_sr"},
"inmate":{"_anim","_sb"},
"inmates":{"_anim","_sb"},
"inn":{"_loc_sr"},
"inning":{"_tme"},
"innings":{"_tme"},
"innkeeper":{"_anim","_sb"},
"innocent":{"_anim","_sb"},
"innocents":{"_anim","_sb"},
"innovated":{"_past"},
"inns":{"_loc_sr"},
"innsbruck":{"_cty","_geo","_prprn"},
"innumerate":{"_anim","_sb"},
"inoculator":{"_anim","_sb"},
"input":{"_past"},
"inquired":{"_past"},
"Inquisition":{"_prprn"},
"ins":{"_prprn"},
"inscribed":{"_past"},
"insect":{"_anim"},
"insectivore":{"_anim"},
"insects":{"_anim"},
"inserted":{"_past"},
"inset":{"_past"},
"inshore":{"_loc"},
"inside":{"_loc_sr"},
"insider":{"_anim","_sb"},
"insider-selling":{"_anim","_sb"},
"insider-trading":{"_anim","_sb"},
"insiders":{"_anim","_sb"},
"insides":{"_loc_sr"},
"insisted":{"_past"},
"insomniac":{"_anim","_sb"},
"insomniacs":{"_anim","_sb"},
"inspected":{"_past"},
"inspector":{"_anim","_sb"},
"inspector-general":{"_anim","_sb"},
"inspectorate":{"_anim","_sb"},
"inspire":{"_psych"},
"inspired":{"_past","_psych"},
"inspirer":{"_anim","_sb"},
"inspires":{"_psych"},
"inspiring":{"_psych"},
"install":{"_loc_sr"},
"installing":{"_loc_sr"},
"instantly":{"_tme"},
"instigated":{"_past"},
"instil":{"_loc_sr"},
"instituted":{"_loc_sr","_past"},
"instituting":{"_loc_sr"},
"institutionalised":{"_past"},
"institutionalized":{"_past"},
"instructed":{"_past"},
"instructor":{"_anim","_sb"},
"instructors":{"_anim","_sb"},
"instructress":{"_anim","_fem","_sb"},
"instrumentalists":{"_anim","_sb"},
"instrumented":{"_past"},
"insulting":{"_psych"},
"insurer":{"_sb"},
"insurers":{"_sb"},
"insurgent":{"_anim","_sb"},
"integers":{"_sb"},
"integrate":{"_loc_sr"},
"integrated-circuit":{"_loc_sr","_past"},
"integrated-steel":{"_loc_sr","_past"},
"integrated-technologies":{"_loc_sr","_past"},
"integrating":{"_loc_sr"},
"Intel":{"_prprn"},
"intellectual":{"_anim","_sb"},
"intellectual-literary":{"_anim","_sb"},
"intellectual-property":{"_anim","_sb"},
"intellectuals":{"_anim","_sb"},
"intelligentsia":{"_sb"},
"Intelsat":{"_prprn"},
"intend":{"_loc_sr"},
"intended":{"_anim","_sb"},
"intending":{"_loc_sr"},
"intends":{"_loc_sr"},
"intensified":{"_past"},
"inter-American":{"_anim","_sb"},
"inter-Arab":{"_anim","_sb"},
"inter-bank":{"_loc_sr"},
"inter-city":{"_loc_sr"},
"inter-company":{"_anim","_sb"},
"inter-German":{"_anim","_sb"},
"inter-office":{"_loc_sr"},
"inter-plant":{"_loc_sr"},
"inter-town":{"_loc_sr"},
"inter-tribal":{"_anim","_sb"},
"interbred":{"_past"},
"intercalate":{"_loc_sr"},
"intercede":{"_loc_sr"},
"interceded":{"_loc_sr","_past"},
"intercepted":{"_past"},
"interceptor":{"_anim","_sb"},
"interceptors":{"_anim","_sb"},
"interchurch":{"_loc_sr"},
"intercompany":{"_anim","_sb"},
"intercrossed":{"_loc_sr","_past"},
"interested":{"_jj_ed","_past","_psych"},
"interesting":{"_jj_ing","_psych"},
"interests":{"_anim","_sb"},
"interfered":{"_past"},
"intergrated-steel":{"_loc_sr","_past","_psych"},
"Interior":{"_loc_sr"},
"interior-construction":{"_loc_sr"},
"interior-decorating":{"_loc_sr"},
"interior-furnishings":{"_loc_sr"},
"interiors":{"_loc_sr"},
"interlaken":{"_cty","_geo","_prprn"},
"interlingua":{"_prprn"},
"interlinked":{"_past"},
"interlock":{"_loc_sr"},
"interlocking":{"_loc_sr"},
"interlope":{"_loc_sr"},
"interloper":{"_anim","_sb"},
"interlopers":{"_anim","_sb"},
"intermediaries":{"_anim","_sb"},
"intermediator":{"_anim","_sb"},
"interminably":{"_tme"},
"intermixed":{"_past"},
"intern":{"_anim","_sb"},
"International":{"_prprn"},
"internationale":{"_prprn"},
"internationalized":{"_past"},
"interned":{"_loc_sr","_past"},
"internee":{"_anim","_sb"},
"interning":{"_loc_sr"},
"interns":{"_anim","_sb"},
"interpeople":{"_anim","_sb"},
"Interpol":{"_prprn"},
"interpolate":{"_loc_sr"},
"interpolated":{"_loc_sr","_past"},
"interposed":{"_past"},
"interpreted":{"_past"},
"interpreter":{"_anim","_sb"},
"interpreters":{"_anim","_sb"},
"interpretor":{"_anim","_sb"},
"interprovincial":{"_anim","_sb"},
"interred":{"_loc_sr","_past"},
"interrelate":{"_loc_sr"},
"interrelated":{"_loc_sr","_past"},
"interrupted":{"_past"},
"interspersed":{"_past"},
"interstice":{"_loc_sr"},
"interstices":{"_loc_sr"},
"interstratify":{"_loc_sr"},
"intertwined":{"_past"},
"interval":{"_loc_sr"},
"intervals":{"_loc_sr"},
"intervened":{"_past"},
"interviewed":{"_loc_sr","_past"},
"interviewee":{"_anim","_sb"},
"interviewees":{"_anim","_sb"},
"interviewer":{"_anim","_sb"},
"interviewing":{"_loc_sr"},
"interwar":{"_loc_sr"},
"intestate":{"_anim","_sb"},
"intimated":{"_past"},
"intimidate":{"_psych"},
"intimidating":{"_psych"},
"into":{"_loc"},
"intone":{"_loc_sr"},
"intoned":{"_loc_sr","_past"},
"intones":{"_loc_sr"},
"intoxicated":{"_past","_psych"},
"intoxicating":{"_psych"},
"intrigue":{"_loc_sr","_psych"},
"intrigued":{"_loc_sr","_past","_psych"},
"intriguer":{"_anim","_sb"},
"intriguing":{"_loc_sr","_psych"},
"introduced":{"_past"},
"introject":{"_loc_sr"},
"introjected":{"_loc_sr","_past"},
"introjects":{"_loc_sr"},
"introspect":{"_loc_sr"},
"introverted":{"_past"},
"intruded":{"_past"},
"intruder":{"_anim","_sb"},
"intruders":{"_anim","_sb"},
"intuitionist":{"_anim","_sb"},
"Inuit":{"_prprn","_sb"},
"inundate":{"_loc_sr"},
"inundating":{"_loc_sr"},
"inured":{"_past"},
"invaded":{"_past"},
"invalidated":{"_past"},
"invalidator":{"_anim","_sb"},
"invalids":{"_anim","_sb"},
"inventor":{"_anim","_sb"},
"inventors":{"_anim","_sb"},
"Inverness":{"_geo","_prprn"},
"invertebrates":{"_anim"},
"inverted":{"_loc_sr","_past"},
"invested":{"_past"},
"investigate":{"_loc_sr"},
"investigated":{"_loc_sr","_past"},
"investigates":{"_loc_sr"},
"investigating":{"_loc_sr"},
"investor":{"_anim","_sb"},
"investor-owned":{"_anim","_sb"},
"investor-relations":{"_anim","_sb"},
"invigilate":{"_loc_sr"},
"invigorate":{"_psych"},
"invigorated":{"_past","_psych"},
"invigorating":{"_psych"},
"invigorator":{"_anim","_sb"},
"invitees":{"_anim","_sb"},
"invoke":{"_loc_sr"},
"invoking":{"_loc_sr"},
"involve":{"_psych"},
"involved":{"_past","_psych"},
"involves":{"_psych"},
"involving":{"_psych"},
"inweave":{"_loc_sr"},
"io":{"_prprn"},
"iodised":{"_past"},
"Iomega":{"_prprn"},
"ionesco":{"_anim","_nme","_prprn","_sb"},
"ionia":{"_geo","_prprn"},
"ionian":{"_anim","_prprn","_sb"},
"Ionic":{"_prprn"},
"ionised":{"_past"},
"ionized":{"_past"},
"IOU":{"_prprn"},
"IOUs":{"_prprn"},
"Iowa":{"_anim","_geo","_prprn","_sb","_stte"},
"iphigenia":{"_prprn"},
"IPO":{"_prprn"},
"Ipswich":{"_geo","_prprn"},
"IQ":{"_prprn"},
"IRA":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Iran":{"_cntry","_geo","_prprn"},
"Iranian":{"_anim","_prprn","_sb"},
"Iranians":{"_anim","_prprn","_sb"},
"Iraq":{"_cntry","_geo","_prprn"},
"Iraqis":{"_anim","_prprn","_sb"},
"Ireland":{"_cntry","_geo","_prprn"},
"Irene":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Irian":{"_prprn"},
"Irish":{"_anim","_prprn","_sb"},
"Irishman":{"_anim","_masc","_prprn","_sb"},
"Irishmen":{"_anim","_masc","_prprn","_sb"},
"Irishwoman":{"_anim","_fem","_prprn","_sb"},
"irk":{"_psych"},
"irks":{"_psych"},
"Irma":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"ironmonger":{"_anim","_sb"},
"ironworker":{"_anim","_sb"},
"ironworks":{"_loc_sr"},
"Iroquoian":{"_prprn"},
"Iroquois":{"_prprn"},
"irradiated":{"_past"},
"Irrawaddy":{"_geo","_prprn"},
"irreconcilable":{"_sb"},
"irredentist":{"_anim","_sb"},
"irregulars":{"_anim","_sb"},
"irreligionist":{"_anim","_sb"},
"irritate":{"_psych"},
"irritated":{"_past","_psych"},
"irritates":{"_psych"},
"IRS":{"_prprn"},
"irtish":{"_prprn"},
"irtysh":{"_geo","_prprn"},
"Irvine":{"_cty","_geo","_prprn"},
"Irving":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"Irwin":{"_anim","_nme","_prprn","_sb"},
"Isaac":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Isabella":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Isabelle":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Isadora":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Isaiah":{"_anim","_fnme","_nme","_prprn","_sb"},
"isere":{"_geo","_prprn"},
"iseult":{"_prprn"},
"Isfahan":{"_cty","_geo","_prprn"},
"isherwood":{"_anim","_nme","_prprn","_sb"},
"Ishiguro":{"_prprn"},
"Ishmael":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Ishtar":{"_anim","_fem","_nme","_prprn","_sb"},
"Islam":{"_prprn"},
"Islamabad":{"_cty","_geo","_prprn"},
"islamism":{"_prprn"},
"Islamist":{"_prprn"},
"island":{"_geo","_loc_sr"},
"island-dweller":{"_geo","_loc_sr"},
"island-fantasy":{"_geo","_loc_sr"},
"island-hopping":{"_geo","_loc_sr"},
"islanders":{"_anim","_sb"},
"islands":{"_geo","_loc_sr"},
"Islay":{"_geo","_prprn"},
"Ismaili":{"_prprn","_sb"},
"ismailian":{"_prprn"},
"isocrates":{"_anim","_nme","_prprn","_sb"},
"isolated":{"_past"},
"Isolde":{"_prprn"},
"Israel":{"_cntry","_geo","_prprn"},
"Israeli":{"_anim","_prprn","_sb"},
"Israelis":{"_anim","_prprn","_sb"},
"issachar":{"_anim","_nme","_prprn","_sb"},
"issued":{"_loc_sr","_past"},
"issuer":{"_anim","_sb"},
"issuers":{"_anim","_sb"},
"issuing":{"_loc_sr"},
"issus":{"_geo","_prprn"},
"ist":{"_prprn"},
"Istanbul":{"_cty","_geo","_prprn"},
"it-wit":{"_anim","_sb"},
"Italia":{"_prprn"},
"Italian":{"_anim","_prprn","_sb"},
"italian-speaking":{"_anim","_prprn","_sb"},
"Italians":{"_anim","_prprn","_sb"},
"italicized":{"_loc_sr","_past"},
"Italy":{"_cntry","_geo","_prprn"},
"Itasca":{"_geo","_prprn"},
"itemized":{"_past"},
"Ithaca":{"_cty","_geo","_prprn"},
"ithaki":{"_geo","_prprn"},
"itinerant":{"_anim","_sb"},
"itineraries":{"_loc_sr"},
"itinerary":{"_loc_sr"},
"itinerate":{"_loc_sr"},
"Ito":{"_anim","_prprn","_sb"},
"IUD":{"_prprn"},
"iv":{"_prprn"},
"iva":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Ivan":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"iw":{"_prprn"},
"Iwo":{"_cty","_geo","_prprn"},
"iww":{"_prprn"},
"iyar":{"_prprn"},
"iyyar":{"_prprn"},
"izmir":{"_cty","_geo","_prprn"},
"jab":{"_loc_sr"},
"jabalpur":{"_cty","_geo","_prprn"},
"jabbed":{"_loc_sr","_past"},
"jabbing":{"_loc_sr"},
"Jack":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"jack-a-lantern":{"_anim","_sb"},
"jack-by-the-hedge":{"_anim","_sb"},
"jackal":{"_anim"},
"jackanapes":{"_sb"},
"jackass":{"_anim","_masc","_sb"},
"jackdaw":{"_anim"},
"jackdaws":{"_anim"},
"jacked":{"_past"},
"jacketed":{"_past"},
"Jackie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"jacks":{"_anim","_sb"},
"Jackson":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"Jacksonian":{"_prprn"},
"Jacksonville":{"_cty","_geo","_prprn"},
"Jacob":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Jacobean":{"_prprn","_sb"},
"Jacobi":{"_anim","_nme","_prprn","_sb"},
"Jacobin":{"_prprn"},
"Jacobite":{"_anim","_prprn","_sb"},
"Jacobsen":{"_prprn"},
"Jacqueline":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Jacuzzi":{"_prprn"},
"Jacuzzis":{"_prprn"},
"jade-green":{"_anim"},
"jade-handled":{"_anim"},
"jaded":{"_past"},
"jagatai":{"_anim","_nme","_prprn","_sb"},
"jagger":{"_anim","_sb"},
"jaguar":{"_anim"},
"jahweh":{"_prprn"},
"jail":{"_loc_sr"},
"jailbird":{"_anim","_sb"},
"jailed":{"_loc_sr","_past"},
"jailer":{"_anim","_sb"},
"jailhouse":{"_loc_sr"},
"jailing":{"_loc_sr"},
"jails":{"_loc_sr"},
"jain":{"_prprn"},
"Jainism":{"_prprn"},
"Jakarta":{"_cty","_geo","_prprn"},
"Jalalabad":{"_prprn"},
"jalopy":{"_fem"},
"jam":{"_loc_sr"},
"jam-packed":{"_past"},
"Jamaica":{"_cntry","_geo","_prprn"},
"Jamaican":{"_anim","_prprn","_sb"},
"James":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Jameson":{"_anim","_nme","_prprn","_sb"},
"Jamestown":{"_cty","_geo","_prprn"},
"jamison":{"_anim","_nme","_prprn","_sb"},
"jammed":{"_loc_sr","_past"},
"jammed-together":{"_loc_sr","_past"},
"jamming":{"_loc_sr"},
"jams":{"_sb"},
"Jan":{"_anim","_fem","_fnme","_masc","_nme","_prprn","_sb","_tme"},
"Jan.":{"_anim","_fem","_fnme","_masc","_nme","_prprn","_sb","_tme"},
"Janata":{"_prprn"},
"Jane":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Janesville":{"_cty","_geo","_prprn"},
"janglers":{"_anim","_sb"},
"Janice":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"janissary":{"_anim","_sb"},
"janitor":{"_anim","_sb"},
"janitors":{"_anim","_sb"},
"jansen":{"_anim","_nme","_prprn","_sb"},
"jansenism":{"_prprn"},
"jansenist":{"_prprn"},
"Jansky":{"_prprn"},
"January":{"_prprn","_tme"},
"Jap":{"_prprn"},
"Japan":{"_cntry","_geo","_prprn"},
"Japanese":{"_anim","_prprn","_sb"},
"japanese-speaking":{"_anim","_prprn","_sb"},
"japheth":{"_anim","_nme","_prprn","_sb"},
"Jaques":{"_prprn"},
"jar":{"_loc_sr","_psych"},
"jarred":{"_loc_sr","_past","_psych"},
"jarrell":{"_anim","_nme","_prprn","_sb"},
"Jarrett":{"_prprn"},
"jarring":{"_loc_sr","_psych"},
"jars":{"_loc_sr"},
"Jas":{"_prprn"},
"Jason":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"jat":{"_prprn","_sb"},
"jaundiced":{"_past"},
"jaunt":{"_loc_sr"},
"Javanese":{"_anim","_prprn","_sb"},
"Jawaharlal":{"_prprn"},
"jawed":{"_past"},
"jay":{"_anim"},
"Jaya":{"_prprn"},
"Jaycee":{"_prprn","_sb"},
"Jaycees":{"_prprn"},
"jays":{"_anim"},
"jaywalker":{"_anim","_sb"},
"jaywalkers":{"_anim","_sb"},
"Jeanne":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Jedi":{"_prprn"},
"Jeep":{"_prprn"},
"jeerer":{"_anim","_sb"},
"Jeff":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Jefferies":{"_prprn"},
"jeffers":{"_anim","_nme","_prprn","_sb"},
"Jefferson":{"_anim","_geo","_nme","_prprn","_sb"},
"Jeffersonian":{"_prprn"},
"Jeffrey":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Jekyll":{"_prprn"},
"Jell-O":{"_prprn"},
"jelled":{"_past"},
"jellied":{"_past"},
"jellify":{"_loc_sr"},
"jellyfish":{"_anim"},
"Jemima":{"_prprn"},
"jena":{"_cty","_geo","_prprn"},
"Jenkins":{"_anim","_nme","_prprn","_sb"},
"Jenner":{"_anim","_nme","_prprn","_sb"},
"jennet":{"_anim"},
"Jennifer":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"jenny":{"_anim"},
"jensen":{"_anim","_nme","_prprn","_sb"},
"jeopardized":{"_past"},
"jerboa":{"_anim"},
"Jeremiah":{"_fnme","_prprn"},
"Jeremy":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"jerez":{"_cty","_geo","_prprn"},
"Jericho":{"_cty","_geo","_prprn"},
"jerk-off":{"_anim","_sb"},
"jerked":{"_past"},
"Jerome":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Jerry":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Jersey":{"_geo","_prprn"},
"jespersen":{"_anim","_nme","_prprn","_sb"},
"Jesse":{"_anim","_fem","_fnme","_masc","_nme","_prprn","_sb"},
"Jessica":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Jesuit":{"_prprn","_sb"},
"Jesuits":{"_prprn","_sb"},
"Jesus":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Jetway":{"_prprn"},
"jevons":{"_anim","_nme","_prprn","_sb"},
"Jew":{"_anim","_prprn","_sb"},
"jew's-ear":{"_anim","_prprn","_sb"},
"jew's-ears":{"_anim","_prprn","_sb"},
"Jew-baiter":{"_anim","_prprn","_sb"},
"jew-bush":{"_anim","_prprn","_sb"},
"jeweled":{"_past"},
"jeweler":{"_anim","_sb"},
"jewelers":{"_anim","_sb"},
"jeweller":{"_anim","_sb"},
"jewess":{"_anim","_fem","_prprn","_sb"},
"jewfish":{"_anim"},
"Jewry":{"_prprn","_sb"},
"Jews":{"_anim","_prprn","_sb"},
"Jezebel":{"_anim","_fem","_prprn","_sb"},
"JFK":{"_prprn"},
"jhvh":{"_prprn"},
"Jiangsu":{"_geo","_prprn","_stte"},
"jib":{"_loc_sr"},
"jibe":{"_loc_sr"},
"jidda":{"_cty","_geo","_prprn"},
"jiggle":{"_loc_sr"},
"jihadist":{"_anim","_sb"},
"Jill":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"jillion":{"_num","_quant"},
"jillions":{"_num","_quant"},
"jilted":{"_past"},
"Jim":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"jimenez":{"_anim","_nme","_prprn","_sb"},
"jimmied":{"_past"},
"jingled":{"_past"},
"Jinnah":{"_anim","_nme","_prprn","_sb"},
"Jinshajiang":{"_prprn"},
"jinx":{"_anim","_sb"},
"jinxed":{"_past"},
"Jnr":{"_prprn"},
"joachim":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Joan":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Joanna":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Joanne":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Job":{"_anim","_masc","_prprn","_sb"},
"job-hunters":{"_anim","_sb"},
"jobber":{"_anim","_sb"},
"jobholder":{"_anim","_sb"},
"jobless":{"_anim","_sb"},
"jocasta":{"_prprn"},
"Jocelyn":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"jockeys":{"_anim","_sb"},
"jodhpur":{"_cty","_geo","_prprn"},
"Jodi":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Joe":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Joel":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"joffre":{"_anim","_nme","_prprn","_sb"},
"Joffrey":{"_prprn"},
"jog":{"_loc_sr"},
"jogger":{"_anim","_sb"},
"joggers":{"_anim","_sb"},
"jogging":{"_loc_sr"},
"Jogjakarta":{"_cty","_geo","_prprn"},
"Johann":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Johanna":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Johannesburg":{"_cty","_geo","_prprn"},
"John":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"johnny":{"_anim","_masc","_sb"},
"johnny-jump-up":{"_prprn"},
"johns":{"_anim","_masc","_sb"},
"Johnson":{"_anim","_nme","_prprn","_sb"},
"Johnston":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"joiners":{"_anim","_sb"},
"joins":{"_loc_sr"},
"joint":{"_loc_sr"},
"joint-implants":{"_loc_sr"},
"joint-production":{"_loc_sr"},
"joint-research":{"_loc_sr"},
"joint-return":{"_loc_sr"},
"joint-venture":{"_loc_sr"},
"joint-venturing":{"_loc_sr"},
"jointed":{"_past"},
"joked":{"_past"},
"joker":{"_anim","_sb"},
"jokers":{"_anim","_sb"},
"jokester":{"_anim","_sb"},
"Jolie":{"_prprn"},
"Joliet":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"joliot-curie":{"_anim","_nme","_prprn","_sb"},
"jolliet":{"_anim","_nme","_prprn","_sb"},
"Jolson":{"_anim","_nme","_prprn","_sb"},
"jolt":{"_loc_sr","_psych"},
"jolted":{"_loc_sr","_past","_psych"},
"jolting":{"_loc_sr","_psych"},
"Jonah":{"_anim","_fnme","_nme","_prprn","_sb"},
"Jonas":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Jonathan":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Jones":{"_anim","_prprn","_sb"},
"jonesboro":{"_cty","_geo","_prprn"},
"Joneses":{"_anim","_prprn","_sb"},
"Jonson":{"_anim","_nme","_prprn","_sb"},
"Joplin":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Jordan":{"_anim","_cntry","_fem","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"Jordanian":{"_anim","_prprn","_sb"},
"Jos":{"_prprn"},
"Joseph":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Josephine":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"josephus":{"_anim","_nme","_prprn","_sb"},
"Joshua":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Josiah":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Jospin":{"_prprn"},
"jostle":{"_loc_sr"},
"jostled":{"_loc_sr","_past"},
"jostling":{"_loc_sr"},
"jotted":{"_past"},
"jounce":{"_loc_sr"},
"journalist":{"_anim","_sb"},
"journalists":{"_anim","_sb"},
"journeyed":{"_loc_sr","_past"},
"journeyer":{"_anim","_sb"},
"journeying":{"_loc_sr"},
"journeyman":{"_anim","_sb"},
"joust":{"_loc_sr"},
"jousting":{"_loc_sr"},
"Jove":{"_prprn"},
"Jovian":{"_anim","_nme","_prprn","_sb"},
"jowett":{"_anim","_nme","_prprn","_sb"},
"Joyce":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Jr":{"_prprn"},
"Juan":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"juarez":{"_anim","_geo","_nme","_prprn","_sb"},
"Jubal":{"_anim","_nme","_prprn","_sb"},
"jubbulpore":{"_geo","_prprn"},
"judaea":{"_geo","_prprn"},
"Judaica":{"_prprn"},
"Judaism":{"_prprn"},
"Judas":{"_anim","_prprn","_sb"},
"Jude":{"_anim","_fnme","_nme","_prprn","_sb"},
"Judea":{"_geo","_prprn"},
"judeo-spanish":{"_prprn"},
"judge-made":{"_anim","_sb"},
"judged":{"_past"},
"judges":{"_anim","_sb"},
"Judith":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Judy":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"juggler":{"_anim","_sb"},
"jugglers":{"_anim","_sb"},
"juggling":{"_loc_sr"},
"Jules":{"_prprn"},
"Julia":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Julian":{"_anim","_fnme","_nme","_prprn","_sb"},
"Julie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Juliet":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Julius":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"jumble":{"_loc_sr"},
"jumbled":{"_loc_sr","_past"},
"jumbo":{"_sb"},
"jumbos":{"_sb"},
"jumped":{"_past"},
"jumper":{"_anim","_sb"},
"jumpers":{"_anim","_sb"},
"June":{"_anim","_fem","_fnme","_nme","_prprn","_sb","_tme"},
"Juneau":{"_cty","_geo","_prprn"},
"juneberry":{"_prprn"},
"Jung":{"_anim","_nme","_prprn","_sb"},
"Jungian":{"_prprn"},
"junior":{"_anim","_sb"},
"junior-grade":{"_anim","_sb"},
"junior-high":{"_anim","_sb"},
"junior-philosophical":{"_anim","_sb"},
"junior-senior":{"_anim","_sb"},
"junior-year-abroad":{"_anim","_sb"},
"juniors":{"_anim","_sb"},
"Junius":{"_prprn"},
"junked":{"_past"},
"Junker":{"_prprn","_sb"},
"Junkers":{"_anim","_prprn","_sb"},
"junketeering":{"_loc_sr"},
"junkie":{"_anim","_sb"},
"junkies":{"_anim","_sb"},
"Juno":{"_anim","_fem","_nme","_prprn","_sb"},
"junta":{"_anim","_sb"},
"Jupiter":{"_prprn"},
"Jurassic":{"_prprn"},
"juries":{"_anim","_sb"},
"jurisconsults":{"_anim","_sb"},
"jurists":{"_anim","_sb"},
"juror":{"_anim","_sb"},
"jurors":{"_anim","_sb"},
"jury":{"_anim","_sb"},
"jury-duty":{"_anim","_sb"},
"jury-rigged":{"_past"},
"jury-tampering":{"_anim","_sb"},
"juryman":{"_anim","_masc","_sb"},
"justice":{"_anim","_sb"},
"justices":{"_anim","_sb"},
"justified":{"_past"},
"justifier":{"_anim","_sb"},
"Justin":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Jutland":{"_geo","_prprn"},
"juvenal":{"_anim","_nme","_prprn","_sb"},
"juvenile":{"_anim","_sb"},
"juveniles":{"_anim","_sb"},
"juxtapositions":{"_loc_sr"},
"jv":{"_prprn"},
"k-meson":{"_prprn"},
"k2":{"_geo","_prprn"},
"kaaba":{"_prprn"},
"Kabila":{"_prprn"},
"Kabul":{"_cty","_geo","_prprn"},
"Kaczynski":{"_prprn"},
"Kaddish":{"_prprn"},
"kaffir":{"_anim","_sb"},
"kafiri":{"_prprn"},
"Kafka":{"_anim","_nme","_prprn","_sb"},
"kahn":{"_anim","_nme","_prprn","_sb"},
"kahoolawe":{"_geo","_prprn"},
"Kaiser":{"_anim","_nme","_prprn","_sb"},
"Kalahari":{"_prprn"},
"kalamazoo":{"_cty","_geo","_prprn"},
"Kalashnikov":{"_prprn"},
"Kali":{"_prprn"},
"kalimantan":{"_geo","_prprn"},
"kalinin":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"kaluga":{"_cty","_geo","_prprn"},
"kama":{"_anim","_geo","_masc","_nme","_prprn","_sb"},
"kamasutra":{"_prprn"},
"Kamchatka":{"_geo","_prprn"},
"kamet":{"_geo","_prprn"},
"kamikaze":{"_anim","_sb"},
"Kamloops":{"_cty","_geo","_prprn"},
"Kampala":{"_cty","_geo","_prprn"},
"Kampuchea":{"_cntry","_geo","_prprn"},
"Kan.":{"_prprn","_stte"},
"kananga":{"_cty","_geo","_prprn"},
"kanarese":{"_anim","_prprn","_sb"},
"Kanchenjunga":{"_geo","_prprn"},
"kandahar":{"_cty","_geo","_prprn"},
"kandinski":{"_prprn"},
"Kandinsky":{"_anim","_nme","_prprn","_sb"},
"kandy":{"_cty","_geo","_prprn"},
"Kane":{"_prprn"},
"kangaroo":{"_anim"},
"kangaroo's-foot":{"_anim"},
"kangaroo-committee":{"_anim"},
"kannada":{"_prprn"},
"kannada-speaking":{"_prprn"},
"Kano":{"_cty","_geo","_prprn"},
"kansa":{"_anim","_prprn","_sb"},
"Kansan":{"_anim","_prprn","_sb"},
"Kansas":{"_geo","_prprn","_stte"},
"kansu":{"_geo","_prprn"},
"Kant":{"_anim","_nme","_prprn","_sb"},
"Kapoor":{"_prprn"},
"Kara":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Karachi":{"_cty","_geo","_prprn"},
"karakul":{"_anim"},
"karbala":{"_cty","_geo","_prprn"},
"karelia":{"_geo","_prprn"},
"karelian":{"_anim","_prprn","_sb"},
"Karen":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Karl":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"karl-marx-stadt":{"_cty","_geo","_prprn"},
"karlfeldt":{"_anim","_nme","_prprn","_sb"},
"Karloff":{"_anim","_nme","_prprn","_sb"},
"Karlsruhe":{"_cty","_geo","_prprn"},
"Karnak":{"_geo","_prprn"},
"karok":{"_anim","_prprn","_sb"},
"Karpov":{"_prprn"},
"karsavina":{"_anim","_nme","_prprn","_sb"},
"Karzai":{"_prprn"},
"kasai":{"_geo","_prprn"},
"kasbah":{"_prprn"},
"Kashmir":{"_geo","_prprn"},
"Kashmiri":{"_anim","_prprn","_sb"},
"Kasparov":{"_prprn"},
"kastler":{"_anim","_nme","_prprn","_sb"},
"Katanga":{"_cntry","_geo","_prprn"},
"Kate":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"katharevusa":{"_prprn"},
"Katharine":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Katherine":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Kathleen":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Kathmandu":{"_geo","_prprn"},
"Kathryn":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Kathy":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Katmandu":{"_cty","_geo","_prprn"},
"katowice":{"_cty","_geo","_prprn"},
"katydid":{"_anim"},
"Katz":{"_anim","_nme","_prprn","_sb"},
"kauai":{"_geo","_prprn"},
"Kauffmann":{"_anim","_nme","_prprn","_sb"},
"kaufman":{"_anim","_nme","_prprn","_sb"},
"kaunas":{"_cty","_geo","_prprn"},
"kaunda":{"_anim","_nme","_prprn","_sb"},
"Kawasaki":{"_cty","_geo","_prprn"},
"Kay":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"kayak":{"_loc_sr"},
"kayoed":{"_past"},
"kazak":{"_anim","_prprn","_sb"},
"kazakh":{"_anim","_prprn","_sb"},
"Kazakhstan":{"_cntry","_geo","_prprn"},
"Kazan":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Ke":{"_prprn"},
"kean":{"_anim","_nme","_prprn","_sb"},
"Keaton":{"_anim","_nme","_prprn","_sb"},
"Keats":{"_anim","_nme","_prprn","_sb"},
"keble":{"_anim","_nme","_prprn","_sb"},
"kechua":{"_anim","_prprn","_sb"},
"Keegan":{"_prprn"},
"keel":{"_sb"},
"keel-shaped":{"_sb"},
"keeled":{"_past"},
"keen":{"_loc_sr"},
"keening":{"_loc_sr"},
"keepers":{"_anim","_sb"},
"keeshond":{"_anim"},
"Keitel":{"_anim","_nme","_prprn","_sb"},
"Keith":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Keller":{"_anim","_nme","_prprn","_sb"},
"Kelley":{"_anim","_fnme","_nme","_prprn","_sb"},
"kellogg":{"_anim","_nme","_prprn","_sb"},
"Kelly":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"kelpie":{"_anim","_sb"},
"Kelt":{"_prprn"},
"Kelvin":{"_anim","_prprn","_sb"},
"Kemble":{"_anim","_nme","_prprn","_sb"},
"Kempe":{"_prprn"},
"kendal":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Kendall":{"_anim","_geo","_nme","_prprn","_sb"},
"kendrew":{"_anim","_nme","_prprn","_sb"},
"Kenilworth":{"_geo","_prprn"},
"Kennan":{"_anim","_fnme","_nme","_prprn","_sb"},
"Kennedy":{"_anim","_nme","_prprn","_sb"},
"Kennelly":{"_anim","_nme","_prprn","_sb"},
"Kenner":{"_cty","_geo","_prprn"},
"Kenneth":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"kennewick":{"_cty","_geo","_prprn"},
"Kenny":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Kenosha":{"_cty","_geo","_prprn"},
"Kent":{"_anim","_cntry","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"kentish":{"_prprn"},
"Kentucky":{"_geo","_prprn","_stte"},
"Kenya":{"_cntry","_geo","_prprn"},
"Kenyan":{"_anim","_prprn","_sb"},
"Kenyans":{"_anim","_prprn","_sb"},
"keokuk":{"_anim","_nme","_prprn","_sb"},
"Kepler":{"_anim","_nme","_prprn","_sb"},
"kept":{"_past"},
"kerbela":{"_geo","_prprn"},
"Kerensky":{"_anim","_nme","_prprn","_sb"},
"Kern":{"_anim","_prprn","_sb"},
"kernel":{"_loc_sr"},
"kernels":{"_loc_sr"},
"Kerouac":{"_anim","_nme","_prprn","_sb"},
"Kerr":{"_prprn"},
"Kerry":{"_anim","_fem","_fnme","_masc","_nme","_prprn","_sb"},
"kestrel":{"_anim"},
"Keswick":{"_prprn"},
"ketch":{"_loc_sr"},
"ketches":{"_loc_sr"},
"Kettering":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Kevin":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Kevlar":{"_prprn"},
"Keynesian":{"_prprn"},
"KGB":{"_prprn"},
"khabarovsk":{"_cty","_geo","_prprn"},
"khachaturian":{"_anim","_nme","_prprn","_sb"},
"khadafy":{"_anim","_nme","_prprn","_sb"},
"khalif":{"_anim","_masc","_sb"},
"Khamenei":{"_prprn"},
"khan":{"_anim","_masc","_sb"},
"kharkov":{"_cty","_geo","_prprn"},
"Khartoum":{"_cty","_geo","_prprn"},
"Khatami":{"_prprn"},
"khios":{"_geo","_prprn"},
"Khmer":{"_anim","_prprn","_sb"},
"khoikhoi":{"_anim","_prprn","_sb"},
"khoikhoin":{"_anim","_prprn","_sb"},
"khoisan":{"_prprn"},
"khomeini":{"_anim","_nme","_prprn","_sb"},
"Khrushchev":{"_anim","_nme","_prprn","_sb"},
"khufu":{"_anim","_nme","_prprn","_sb"},
"kHz":{"_prprn"},
"kiang":{"_anim"},
"kibbutznik":{"_sb"},
"kibbutzniks":{"_sb"},
"kibe":{"_loc_sr"},
"kibitzer":{"_anim","_sb"},
"kickapoo":{"_anim","_prprn","_sb"},
"kicked":{"_past"},
"kicker":{"_sb"},
"kickers":{"_sb"},
"kid":{"_anim","_sb"},
"Kidd":{"_anim","_nme","_prprn","_sb"},
"kiddie":{"_anim","_sb"},
"kiddies":{"_anim","_sb"},
"Kidman":{"_prprn"},
"kidnap":{"_loc_sr"},
"kidnaped":{"_loc_sr","_past"},
"kidnaper":{"_anim","_sb"},
"kidnapped":{"_loc_sr","_past"},
"kidnappers":{"_anim","_sb"},
"kidnapping":{"_loc_sr"},
"kids":{"_anim","_sb"},
"Kiel":{"_cty","_geo","_prprn"},
"Kierkegaard":{"_anim","_nme","_prprn","_sb"},
"Kiev":{"_cty","_geo","_prprn"},
"Kigali":{"_cty","_geo","_prprn"},
"kike":{"_anim","_sb"},
"kikladhes":{"_geo","_prprn"},
"Kikuyu":{"_anim","_sb"},
"Kildare":{"_prprn"},
"Kilimanjaro":{"_prprn"},
"killed":{"_past"},
"Killeen":{"_cty","_geo","_prprn"},
"killer":{"_anim","_sb"},
"killers":{"_anim","_sb"},
"killifish":{"_anim"},
"killjoy":{"_anim","_sb"},
"kills":{"_anim"},
"Kilmer":{"_anim","_nme","_prprn","_sb"},
"kiln":{"_loc_sr"},
"kilocycle":{"_tme"},
"Kimberley":{"_cty","_geo","_prprn"},
"Kimberly":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"kindergartener":{"_anim","_sb"},
"kindergartner":{"_sb"},
"kindred":{"_anim","_sb"},
"kinds":{"_sb"},
"kine":{"_anim"},
"kinfolk":{"_sb"},
"king":{"_anim","_masc","_sb"},
"kingfish":{"_anim"},
"kingfisher":{"_anim"},
"kingpins":{"_anim","_sb"},
"kings":{"_anim","_masc","_sb"},
"Kingsley":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Kingston":{"_cty","_geo","_prprn"},
"kingstown":{"_cty","_geo","_prprn"},
"kinkajou":{"_anim"},
"kinked":{"_past"},
"Kinnock":{"_prprn"},
"Kinsey":{"_anim","_nme","_prprn","_sb"},
"kinsfolk":{"_sb"},
"Kinshasa":{"_cty","_geo","_prprn"},
"kinsman":{"_anim","_sb"},
"kinyarwanda":{"_prprn"},
"Kiowa":{"_anim","_prprn","_sb"},
"Kipling":{"_anim","_nme","_prprn","_sb"},
"kipper":{"_anim","_masc"},
"kirchhoff":{"_anim","_nme","_prprn","_sb"},
"kirchner":{"_anim","_nme","_prprn","_sb"},
"kirghiz":{"_anim","_cntry","_geo","_prprn","_sb"},
"Kirghizia":{"_cntry","_prprn"},
"Kirghizstan":{"_cntry","_prprn"},
"kirgiz":{"_cntry","_prprn"},
"Kirgizia":{"_cntry","_prprn"},
"kirgizstan":{"_cntry","_prprn"},
"Kiribati":{"_cntry","_geo","_prprn"},
"Kirin":{"_geo","_prprn"},
"Kirk":{"_prprn"},
"Kirkpatrick":{"_prprn"},
"kirkuk":{"_cty","_geo","_prprn"},
"Kirov":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Kishinev":{"_cty","_geo","_prprn"},
"kislev":{"_prprn"},
"kissed":{"_past"},
"kisser":{"_anim","_sb"},
"kissimmee":{"_cty","_geo","_prprn"},
"Kissinger":{"_anim","_nme","_prprn","_sb"},
"kiswahili":{"_prprn"},
"kitakyushu":{"_cty","_geo","_prprn"},
"kitchen":{"_loc_sr"},
"kitchen-sink":{"_loc_sr"},
"kitchen-table":{"_loc_sr"},
"kitchener":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"kitchens":{"_loc_sr"},
"kitten":{"_anim"},
"kitten-tails":{"_anim"},
"kittens":{"_anim"},
"kittiwake":{"_anim"},
"Kittredge":{"_anim","_nme","_prprn","_sb"},
"kitty-cat":{"_anim"},
"Kivu":{"_prprn"},
"Kiwanis":{"_prprn"},
"kiwi":{"_anim"},
"kiwi-sized":{"_anim"},
"KKK":{"_prprn"},
"klaipeda":{"_cty","_geo","_prprn"},
"klamath":{"_anim","_prprn","_sb"},
"Klan":{"_prprn"},
"klansman":{"_prprn","_sb"},
"Klansmen":{"_prprn"},
"Klaus":{"_prprn"},
"Klee":{"_anim","_nme","_prprn","_sb"},
"Kleenex":{"_prprn"},
"klein":{"_anim","_nme","_prprn","_sb"},
"kleist":{"_anim","_nme","_prprn","_sb"},
"Klemperer":{"_anim","_nme","_prprn","_sb"},
"kleptomaniac":{"_anim","_sb"},
"Klimt":{"_anim","_nme","_prprn","_sb"},
"Kline":{"_anim","_nme","_prprn","_sb"},
"Klondike":{"_geo","_prprn"},
"klopstock":{"_anim","_nme","_prprn","_sb"},
"klutz":{"_anim","_sb"},
"knacker":{"_anim","_sb"},
"knave":{"_anim","_masc","_sb"},
"kneading":{"_loc_sr"},
"kneeled":{"_loc_sr","_past"},
"kneeler":{"_anim","_sb"},
"kneeling":{"_loc_sr"},
"kneels":{"_loc_sr"},
"knelt":{"_loc_sr","_past"},
"Knesset":{"_prprn"},
"knew":{"_loc_sr","_past"},
"Knickerbocker":{"_prprn"},
"knight":{"_anim","_masc","_sb"},
"knighted":{"_past"},
"knights":{"_anim","_masc","_sb"},
"knit":{"_loc_sr","_past"},
"knitted":{"_loc_sr","_past"},
"knitter":{"_anim","_sb"},
"knitting":{"_loc_sr"},
"knocked":{"_past"},
"knocked-out":{"_past"},
"knocker":{"_anim","_sb"},
"knockers":{"_anim","_sb"},
"knossos":{"_cty","_geo","_prprn"},
"knotted":{"_past"},
"know":{"_loc_sr"},
"know-all":{"_anim","_sb"},
"know-it-all":{"_anim","_sb"},
"knower":{"_anim","_sb"},
"knowing":{"_loc_sr"},
"Knowles":{"_prprn"},
"known":{"_loc_sr"},
"knows":{"_loc_sr"},
"Knox":{"_anim","_nme","_prprn","_sb"},
"knoxville":{"_cty","_geo","_prprn"},
"knuckled":{"_past"},
"knucklehead":{"_sb"},
"Knut":{"_anim","_nme","_prprn","_sb"},
"Ko":{"_prprn"},
"KO'd":{"_past"},
"koala":{"_anim"},
"kobe":{"_cty","_geo","_prprn"},
"Koch":{"_anim","_nme","_prprn","_sb"},
"Kodiak":{"_prprn"},
"koestler":{"_anim","_nme","_prprn","_sb"},
"Koizumi":{"_prprn"},
"Kokoschka":{"_anim","_nme","_prprn","_sb"},
"koln":{"_geo","_prprn"},
"Komsomol":{"_prprn"},
"kongo":{"_anim","_prprn","_sb"},
"konoye":{"_anim","_nme","_prprn","_sb"},
"kook":{"_anim","_sb"},
"kookaburra":{"_anim"},
"kooks":{"_anim","_sb"},
"koopmans":{"_anim","_nme","_prprn","_sb"},
"kopje":{"_loc_sr"},
"Koran":{"_prprn"},
"Korda":{"_prprn"},
"kordofanian":{"_prprn"},
"Korea":{"_cntry","_geo","_prprn"},
"Korean":{"_anim","_prprn","_sb"},
"korinthos":{"_geo","_prprn"},
"korzybski":{"_anim","_nme","_prprn","_sb"},
"Kos":{"_geo","_prprn"},
"kosciusko":{"_anim","_nme","_prprn","_sb"},
"Kosovar":{"_prprn"},
"Kossuth":{"_anim","_nme","_prprn","_sb"},
"Kostunica":{"_prprn"},
"kota":{"_cty","_geo","_prprn"},
"Koussevitzky":{"_anim","_nme","_prprn","_sb"},
"kp":{"_prprn"},
"krafft-ebing":{"_anim","_nme","_prprn","_sb"},
"krakatau":{"_geo","_prprn"},
"Krakatoa":{"_prprn"},
"krakow":{"_geo","_prprn"},
"krasner":{"_anim","_nme","_prprn","_sb"},
"Krasnoyarsk":{"_cty","_geo","_prprn"},
"krebs":{"_anim","_nme","_prprn","_sb"},
"kreisler":{"_anim","_nme","_prprn","_sb"},
"Kremlin":{"_loc_sr","_prprn"},
"Krim":{"_prprn"},
"Krishna":{"_geo","_prprn"},
"Kristen":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Kristiansen":{"_prprn"},
"kroeber":{"_anim","_nme","_prprn","_sb"},
"kropotkin":{"_anim","_nme","_prprn","_sb"},
"Kruger":{"_anim","_nme","_prprn","_sb"},
"Krupp":{"_anim","_nme","_prprn","_sb"},
"kshatriya":{"_prprn"},
"Ku":{"_prprn"},
"Kubrick":{"_anim","_nme","_prprn","_sb"},
"kudu":{"_anim"},
"Kuhn":{"_anim","_nme","_prprn","_sb"},
"Kum":{"_prprn"},
"kumasi":{"_cty","_geo","_prprn"},
"kunlun":{"_geo","_prprn"},
"kura":{"_geo","_prprn"},
"Kurd":{"_anim","_prprn","_sb"},
"Kurdish":{"_anim","_prprn","_sb"},
"Kurdistan":{"_geo","_prprn"},
"Kurds":{"_prprn"},
"Kurland":{"_geo","_prprn"},
"Kurosawa":{"_anim","_nme","_prprn","_sb"},
"Kursk":{"_cty","_geo","_prprn"},
"Kurt":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"kutch":{"_geo","_prprn"},
"kutuzov":{"_anim","_nme","_prprn","_sb"},
"Kuwait":{"_cntry","_cty","_geo","_prprn"},
"Kuznets":{"_anim","_nme","_prprn","_sb"},
"kv":{"_prprn"},
"kw":{"_prprn"},
"kw-hr":{"_prprn"},
"kwa":{"_prprn"},
"kwajalein":{"_geo","_prprn"},
"kwakiutl":{"_anim","_prprn","_sb"},
"kwan-yin":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"kwangchow":{"_geo","_prprn"},
"kwangju":{"_cty","_geo","_prprn"},
"kwangtung":{"_geo","_prprn"},
"kwanza":{"_tme"},
"kwanzaa":{"_prprn","_tme"},
"kwazulu-natal":{"_geo","_prprn","_stte"},
"ky":{"_prprn","_stte"},
"Ky.":{"_prprn","_stte"},
"kyd":{"_anim","_nme","_prprn","_sb"},
"Kyle":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"kylie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Kyoto":{"_cty","_geo","_prprn"},
"Kyrgyzstan":{"_cntry","_prprn"},
"Kyushu":{"_geo","_prprn"},
"l'aquila":{"_cty","_geo","_prprn"},
"l'enfant":{"_anim","_nme","_prprn","_sb"},
"l-plate":{"_prprn"},
"L-shaped":{"_prprn"},
"La.":{"_prprn","_stte"},
"laager":{"_loc_sr"},
"Laban":{"_prprn"},
"labanotation":{"_prprn"},
"Labe":{"_cty","_geo","_prprn"},
"labelled":{"_past"},
"laboratories":{"_loc_sr"},
"laboratory":{"_loc_sr"},
"laboratory-services":{"_loc_sr"},
"laboratory-supply":{"_loc_sr"},
"labored":{"_past"},
"laboured":{"_past"},
"labourer":{"_anim","_sb"},
"labourite":{"_prprn"},
"Labrador":{"_geo","_prprn"},
"laced":{"_loc_sr","_past"},
"lacer":{"_anim","_sb"},
"lacerated":{"_past"},
"lacerta":{"_prprn"},
"lachaise":{"_anim","_nme","_prprn","_sb"},
"lachesis":{"_prprn"},
"lacing":{"_loc_sr"},
"lacked":{"_past"},
"lackeys":{"_anim","_sb"},
"laconia":{"_cty","_geo","_prprn"},
"lacteal":{"_loc_sr"},
"lacuna":{"_loc_sr"},
"lad":{"_anim","_masc","_sb"},
"laddie":{"_anim","_masc","_sb"},
"ladies":{"_anim","_fem","_sb"},
"ladies'-eardrop":{"_anim","_fem","_sb"},
"ladies'-eardrops":{"_anim","_fem","_sb"},
"ladin":{"_anim","_prprn","_sb"},
"lads":{"_anim","_masc","_sb"},
"lady":{"_anim","_fem","_sb"},
"lady's-eardrop":{"_anim","_fem","_sb"},
"lady's-eardrops":{"_anim","_fem","_sb"},
"lady's-finger":{"_anim","_fem","_sb"},
"lady-in-waiting":{"_anim","_fem","_sb"},
"lady-of-the-night":{"_anim","_fem","_sb"},
"lady-slipper":{"_anim","_fem","_sb"},
"ladybird":{"_anim"},
"ladyfish":{"_anim"},
"ladylove":{"_anim","_fem","_sb"},
"ladyship":{"_anim","_fem","_sb"},
"laertes":{"_prprn"},
"Lafayette":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"laffite":{"_anim","_nme","_prprn","_sb"},
"lafitte":{"_prprn"},
"lag":{"_loc_sr"},
"Lagerfeld":{"_prprn"},
"laggard":{"_anim","_sb"},
"laggards":{"_anim","_sb"},
"lagger":{"_anim","_sb"},
"lagging":{"_loc_sr"},
"lagomorph":{"_anim"},
"lagoon":{"_loc_sr"},
"lagoons":{"_loc_sr"},
"Lagos":{"_cty","_geo","_prprn"},
"Lagrange":{"_anim","_nme","_prprn","_sb"},
"Lahore":{"_cty","_geo","_prprn"},
"laicize":{"_loc_sr"},
"laid":{"_past"},
"laid-off":{"_past"},
"Laing":{"_anim","_nme","_prprn","_sb"},
"lair":{"_loc_sr"},
"laird":{"_anim","_sb"},
"lairs":{"_loc_sr"},
"laius":{"_prprn"},
"lake":{"_loc_sr"},
"lakefront":{"_loc_sr"},
"Lakeland":{"_cty","_geo","_prprn"},
"lakes":{"_loc_sr"},
"Lakewood":{"_cty","_geo","_prprn"},
"lakota":{"_prprn"},
"lallans":{"_prprn"},
"lama":{"_anim","_sb"},
"lamaism":{"_prprn"},
"lamaist":{"_prprn"},
"lamarck":{"_anim","_nme","_prprn","_sb"},
"Lamarckian":{"_prprn"},
"Lamarckism":{"_prprn"},
"lamasery":{"_loc_sr"},
"lamb":{"_anim"},
"lamb's-quarter":{"_anim"},
"lamb's-quarters":{"_anim"},
"lamb-chop":{"_anim"},
"lambasted":{"_past"},
"lambkin":{"_anim"},
"lambs":{"_anim"},
"lamented":{"_past"},
"lamenter":{"_anim","_sb"},
"lamia":{"_anim"},
"laminate":{"_loc_sr"},
"laminated":{"_loc_sr","_past"},
"laminating":{"_loc_sr"},
"laminator":{"_anim","_sb"},
"Lammas":{"_prprn"},
"lammed":{"_past"},
"lamplighter":{"_anim","_sb"},
"lamprey":{"_anim"},
"lan":{"_prprn"},
"lana":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Lancaster":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Lancelot":{"_prprn"},
"lancer":{"_anim","_sb"},
"lanchow":{"_geo","_prprn"},
"land":{"_loc_sr"},
"land-based":{"_loc_sr"},
"land-disposal":{"_loc_sr"},
"land-idling":{"_loc_sr"},
"land-locked":{"_loc_sr"},
"land-ownership":{"_loc_sr"},
"land-rich":{"_loc_sr"},
"land-use":{"_loc_sr"},
"landed":{"_loc_sr","_past"},
"landfall":{"_loc_sr"},
"landgrave":{"_anim","_masc","_sb"},
"landholder":{"_anim","_sb"},
"landing":{"_loc_sr"},
"landings":{"_loc_sr"},
"landlady":{"_anim","_fem","_sb"},
"landlord":{"_anim","_sb"},
"landlord-tenant":{"_anim","_sb"},
"landlords":{"_anim","_sb"},
"landmass":{"_loc_sr"},
"Landor":{"_anim","_nme","_prprn","_sb"},
"landowners":{"_anim","_sb"},
"landowska":{"_anim","_nme","_prprn","_sb"},
"lands":{"_loc_sr"},
"landscaped":{"_past"},
"landscaper":{"_anim","_sb"},
"landscapers":{"_anim","_sb"},
"landscapist":{"_anim","_sb"},
"landsmal":{"_prprn"},
"landsman":{"_anim","_sb"},
"landsteiner":{"_anim","_nme","_prprn","_sb"},
"landwards":{"_loc"},
"laney":{"_anim","_nme","_prprn","_sb"},
"Lang":{"_anim","_nme","_prprn","_sb"},
"Lange":{"_anim","_nme","_prprn","_sb"},
"Langer":{"_anim","_nme","_prprn","_sb"},
"langlaufer":{"_anim","_sb"},
"Langley":{"_anim","_cty","_fnme","_geo","_nme","_prprn","_sb"},
"langmuir":{"_anim","_nme","_prprn","_sb"},
"langobard":{"_prprn"},
"Langton":{"_anim","_nme","_prprn","_sb"},
"langtry":{"_anim","_nme","_prprn","_sb"},
"languedoc-roussillon":{"_geo","_prprn","_stte"},
"languish":{"_psych"},
"languished":{"_past","_psych"},
"languisher":{"_anim","_sb"},
"languishes":{"_psych"},
"languishing":{"_psych"},
"langur":{"_anim"},
"Lanier":{"_anim","_nme","_prprn","_sb"},
"Lansbury":{"_prprn"},
"Lansing":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"lantern":{"_loc_sr"},
"lantern-fly":{"_loc_sr"},
"lanterns":{"_loc_sr"},
"Lanzhou":{"_cty","_geo","_prprn"},
"lao":{"_anim","_prprn","_sb"},
"Lao-Tse":{"_prprn"},
"Lao-Tsu":{"_anim","_prprn","_sb"},
"lao-zi":{"_anim","_prprn","_sb"},
"laocoon":{"_prprn"},
"Laodicean":{"_anim","_prprn","_sb"},
"Laos":{"_anim","_cntry","_geo","_prprn","_sb"},
"Laotian":{"_anim","_prprn","_sb"},
"Laotians":{"_anim","_prprn","_sb"},
"lap-jointed":{"_loc_sr","_sb"},
"lap-shoulder":{"_loc_sr","_sb"},
"lap-strake":{"_loc_sr","_sb"},
"lap-straked":{"_loc_sr","_sb"},
"lap-streak":{"_loc_sr","_sb"},
"lap-streaked":{"_loc_sr","_sb"},
"lap-top":{"_loc_sr","_sb"},
"lapdog":{"_anim"},
"lapidarist":{"_anim","_sb"},
"laplace":{"_anim","_geo","_nme","_prprn","_sb"},
"Lapland":{"_geo","_prprn"},
"Lapp":{"_anim","_prprn","_sb"},
"laps":{"_loc_sr","_sb"},
"lapsed":{"_loc_sr","_past"},
"lapsing":{"_loc_sr"},
"Laputa":{"_prprn"},
"laputan":{"_prprn"},
"lapwing":{"_anim"},
"Lara":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"laramie":{"_cty","_geo","_prprn"},
"larcenist":{"_anim","_sb"},
"lardner":{"_anim","_nme","_prprn","_sb"},
"laredo":{"_cty","_geo","_prprn"},
"largemouth":{"_anim"},
"Larisa":{"_anim","_cty","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"lark":{"_anim"},
"Larkin":{"_loc_sr"},
"larks":{"_anim"},
"larousse":{"_anim","_nme","_prprn","_sb"},
"Larry":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"larvae":{"_anim"},
"LaSalle":{"_prprn"},
"Lascaux":{"_geo","_prprn"},
"lashed":{"_past"},
"Lasker":{"_prprn"},
"lass":{"_anim","_fem","_sb"},
"Lassus":{"_prprn"},
"last":{"_loc_sr"},
"lasted":{"_loc_sr","_past"},
"lastex":{"_prprn"},
"lasting":{"_loc_sr"},
"lastingly":{"_tme"},
"lasts":{"_loc_sr"},
"Latakia":{"_prprn"},
"late":{"_tme"},
"late-afternoon":{"_tme"},
"late-blooming":{"_tme"},
"late-day":{"_tme"},
"late-flowering":{"_tme"},
"late-in-the-day":{"_tme"},
"late-night":{"_tme"},
"late-payment":{"_tme"},
"late-ripening":{"_tme"},
"late-season":{"_tme"},
"late-spring-blooming":{"_tme"},
"late-summer":{"_tme"},
"late-term":{"_tme"},
"latecomer":{"_anim","_sb"},
"latecomers":{"_anim","_sb"},
"lately":{"_tme"},
"later":{"_tme"},
"Lateran":{"_prprn"},
"lathe":{"_loc_sr"},
"lathee":{"_anim","_sb"},
"lathered":{"_past"},
"Latin":{"_prprn"},
"Latin-American":{"_prprn"},
"Latina":{"_cty","_geo","_prprn","_sb"},
"Latinism":{"_prprn"},
"Latinist":{"_prprn"},
"Latinize":{"_loc_sr"},
"Latino":{"_anim","_prprn","_sb"},
"Latino-American":{"_anim","_prprn","_sb"},
"Latinos":{"_anim","_prprn","_sb"},
"latitudes":{"_loc_sr"},
"latitudinarian":{"_anim","_sb"},
"latium":{"_cntry","_geo","_prprn"},
"Latour":{"_prprn"},
"latrobe":{"_anim","_nme","_prprn","_sb"},
"Latvia":{"_cntry","_geo","_prprn"},
"Latvian":{"_anim","_prprn","_sb"},
"lauded":{"_past"},
"Lauder":{"_anim","_sb"},
"Laue":{"_anim","_nme","_prprn","_sb"},
"laughed":{"_past"},
"laughton":{"_anim","_nme","_prprn","_sb"},
"launch":{"_loc_sr"},
"launching":{"_loc_sr"},
"laundered":{"_past"},
"launderer":{"_anim","_sb"},
"launderers":{"_anim","_sb"},
"launderette":{"_loc_sr"},
"laundress":{"_anim","_fem","_sb"},
"laundries":{"_loc_sr"},
"laundry":{"_loc_sr"},
"laundry-type":{"_loc_sr"},
"Laura":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Laurasia":{"_prprn"},
"laureate":{"_anim","_sb"},
"laureates":{"_anim","_sb"},
"Laurel":{"_anim","_cty","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"laureled":{"_past"},
"laurelled":{"_past"},
"Lauren":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Laurence":{"_prprn"},
"laurens":{"_anim","_nme","_prprn","_sb"},
"lausanne":{"_cty","_geo","_prprn"},
"Laval":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"lavatory":{"_loc_sr"},
"lavish":{"_loc_sr"},
"lavished":{"_loc_sr","_past"},
"lavoisier":{"_anim","_nme","_prprn","_sb"},
"lawbreaker":{"_anim","_sb"},
"lawbreakers":{"_anim","_sb"},
"lawgiver":{"_anim","_sb"},
"lawmaker":{"_anim","_sb"},
"lawmakers":{"_anim","_sb"},
"Lawrence":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Lawson":{"_anim","_nme","_prprn","_sb"},
"Lawton":{"_cty","_geo","_prprn"},
"lawyer":{"_anim","_sb"},
"lawyers":{"_anim","_sb"},
"lay":{"_past"},
"lay-by":{"_loc_sr"},
"layabout":{"_anim","_sb"},
"layered":{"_loc_sr","_past"},
"layering":{"_loc_sr"},
"layman":{"_anim","_masc","_sb"},
"laymen":{"_anim","_masc","_sb"},
"Lazarus":{"_anim","_nme","_prprn","_sb"},
"Lazio":{"_prprn"},
"LCD":{"_prprn"},
"lcm":{"_prprn"},
"ld.":{"_prprn"},
"ldl":{"_prprn"},
"lea":{"_loc_sr"},
"leacock":{"_anim","_nme","_prprn","_sb"},
"lead":{"_loc_sr"},
"leaded":{"_past"},
"leader":{"_anim","_sb"},
"leaders":{"_anim","_sb"},
"leadsman":{"_sb"},
"leafed":{"_past"},
"leagued":{"_loc_sr","_past"},
"leaguer":{"_anim","_sb"},
"leaguers":{"_anim","_sb"},
"Leah":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"leaked":{"_past"},
"leakers":{"_anim","_sb"},
"Leakey":{"_anim","_nme","_prprn","_sb"},
"lean-to":{"_loc_sr"},
"leander":{"_prprn"},
"leaned":{"_past"},
"leap":{"_loc_sr"},
"leaped":{"_loc_sr","_past"},
"leaper":{"_anim","_sb"},
"leaping":{"_loc_sr"},
"leapt":{"_loc_sr","_past"},
"learn":{"_loc_sr"},
"learned":{"_loc_sr","_past"},
"learner":{"_anim","_sb"},
"learners":{"_anim","_sb"},
"learning":{"_ving"},
"lease":{"_loc_sr"},
"leased":{"_loc_sr","_past"},
"leasehold":{"_loc_sr"},
"leaseholder":{"_anim","_sb"},
"leasing":{"_loc_sr"},
"least":{"_quant"},
"least-developed-nation":{"_quant"},
"leathered":{"_past"},
"leatherjacket":{"_loc_sr"},
"leatherneck":{"_sb"},
"leave":{"_loc_sr"},
"leaved":{"_past"},
"leavened":{"_past"},
"Leavenworth":{"_cty","_geo","_prprn"},
"leaver":{"_anim","_sb"},
"Lebanese":{"_anim","_prprn","_sb"},
"Lebanon":{"_cntry","_cty","_geo","_prprn"},
"Leblanc":{"_prprn"},
"Lech":{"_geo","_prprn"},
"Lecky":{"_anim","_nme","_prprn","_sb"},
"lector":{"_anim","_sb"},
"lecturers":{"_anim","_sb"},
"led":{"_past"},
"Leda":{"_prprn"},
"ledbetter":{"_anim","_nme","_prprn","_sb"},
"Lederberg":{"_anim","_nme","_prprn","_sb"},
"Lee":{"_anim","_fem","_fnme","_masc","_nme","_prprn","_sb"},
"leechee":{"_anim","_sb"},
"leeches":{"_anim"},
"leered":{"_past"},
"leeuwenhoek":{"_anim","_nme","_prprn","_sb"},
"left-hander":{"_anim","_sb"},
"left-handers":{"_anim","_sb"},
"left-winger":{"_anim","_sb"},
"lefties":{"_sb"},
"leftist":{"_anim","_sb"},
"leftists":{"_anim","_sb"},
"legalized":{"_past"},
"legate":{"_anim","_sb"},
"legged":{"_loc_sr","_past"},
"legging":{"_loc_sr"},
"legionary":{"_anim","_sb"},
"legislate":{"_loc_sr"},
"legislating":{"_loc_sr"},
"legislator":{"_anim","_sb"},
"legislators":{"_anim","_sb"},
"legislature":{"_sb"},
"legislatures":{"_sb"},
"legitimized":{"_past"},
"lehar":{"_anim","_nme","_prprn","_sb"},
"Lehigh":{"_prprn"},
"Lehmann":{"_anim","_nme","_prprn","_sb"},
"leibnitz":{"_anim","_nme","_prprn","_sb"},
"Leibniz":{"_prprn"},
"Leicester":{"_anim","_geo","_nme","_prprn","_sb"},
"Leicestershire":{"_prprn"},
"leiden":{"_cty","_geo","_prprn"},
"Leighton":{"_anim","_nme","_prprn","_sb"},
"lemaitre":{"_anim","_nme","_prprn","_sb"},
"lemmings":{"_anim"},
"lemnos":{"_geo","_prprn"},
"Lemuel":{"_prprn"},
"lemur":{"_anim"},
"Lena":{"_geo","_prprn"},
"lenard":{"_anim","_nme","_prprn","_sb"},
"lengthened":{"_past"},
"Lenin":{"_anim","_nme","_prprn","_sb"},
"Leningrad":{"_cty","_geo","_prprn"},
"leninism":{"_prprn"},
"Leninist":{"_prprn"},
"Lennon":{"_anim","_nme","_prprn","_sb"},
"Lent":{"_past"},
"Leo":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Leon":{"_anim","_cntry","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"Leona":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Leonard":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"leonardo":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Leonidas":{"_prprn"},
"Leonore":{"_prprn"},
"Leontief":{"_anim","_nme","_prprn","_sb"},
"leopard":{"_anim"},
"leopard's-bane":{"_anim"},
"leopard-trimmed":{"_anim"},
"leopardess":{"_anim","_fem"},
"leopards":{"_anim"},
"Leopold":{"_prprn"},
"leopoldville":{"_geo","_prprn"},
"leper":{"_anim","_sb"},
"Leppard":{"_prprn"},
"leprechaun":{"_anim","_sb"},
"lepus":{"_prprn"},
"lermontov":{"_anim","_nme","_prprn","_sb"},
"lerner":{"_anim","_nme","_prprn","_sb"},
"LeRoy":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"lesbian":{"_anim","_fem","_sb"},
"lesbos":{"_geo","_prprn"},
"Leslie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Lesotho":{"_cntry","_geo","_prprn"},
"less":{"_quant"},
"less-advanced":{"_quant"},
"less-aggressive":{"_quant"},
"less-ambitious":{"_quant"},
"less-binding":{"_quant"},
"less-complicated":{"_quant"},
"less-conservative":{"_quant"},
"less-creditworthy":{"_quant"},
"less-cyclical":{"_quant"},
"less-developed":{"_quant"},
"less-developed-country":{"_quant"},
"less-dramatic":{"_quant"},
"less-educated":{"_quant"},
"less-effective":{"_quant"},
"less-established":{"_quant"},
"less-expensive":{"_quant"},
"less-experienced":{"_quant"},
"less-hurried":{"_quant"},
"less-indomitable":{"_quant"},
"less-influential":{"_quant"},
"less-intrusive":{"_quant"},
"less-obvious":{"_quant"},
"less-polluting":{"_quant"},
"less-popular":{"_quant"},
"less-profitable":{"_quant"},
"less-restrictive":{"_quant"},
"less-risky":{"_quant"},
"less-self-confident":{"_quant"},
"less-serious":{"_quant"},
"less-sweeping":{"_quant"},
"less-than-alarming":{"_quant"},
"less-than-altruistic":{"_quant"},
"less-than-amicable":{"_quant"},
"less-than-brilliant":{"_quant"},
"less-than-carload":{"_quant"},
"less-than-dazzling":{"_quant"},
"less-than-diffident":{"_quant"},
"less-than-exacting":{"_quant"},
"less-than-half-time":{"_quant"},
"less-than-perfect":{"_quant"},
"less-than-robust":{"_quant"},
"less-than-successful":{"_quant"},
"less-than-truckload":{"_quant"},
"less-toxic":{"_quant"},
"less-visible":{"_quant"},
"lessee":{"_anim","_sb"},
"lesseps":{"_anim","_nme","_prprn","_sb"},
"lesser":{"_quant"},
"lesser-developed":{"_quant"},
"lesser-developed-country":{"_quant"},
"lesser-known":{"_quant"},
"Lessing":{"_anim","_nme","_prprn","_sb"},
"Lester":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"lesvos":{"_geo","_prprn"},
"let":{"_past"},
"let alone":{"_past"},
"Letitia":{"_prprn"},
"leto":{"_prprn"},
"Lett":{"_anim","_prprn","_sb"},
"lettered":{"_past"},
"letterer":{"_anim","_sb"},
"lettish":{"_prprn"},
"leuctra":{"_geo","_prprn"},
"leuwenhoek":{"_anim","_nme","_prprn","_sb"},
"levanter":{"_loc_sr"},
"Levantine":{"_prprn"},
"leveled":{"_past"},
"levelled":{"_past"},
"leveller":{"_anim","_sb"},
"levels":{"_loc_sr"},
"Leven":{"_prprn"},
"leveraged":{"_past"},
"leveraged-buy-out":{"_past"},
"leveraged-takeover":{"_past"},
"leveret":{"_anim"},
"Leverkusen":{"_cty","_geo","_prprn"},
"Levi":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Levi's":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"levi-clad":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"levi-strauss":{"_anim","_nme","_prprn","_sb"},
"leviathan":{"_anim"},
"levied":{"_past"},
"Levite":{"_prprn","_sb"},
"Leviticus":{"_anim","_fnme","_nme","_prprn","_sb"},
"Levittown":{"_geo","_prprn"},
"Lewis":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"lewiston":{"_cty","_geo","_prprn"},
"lexicalised":{"_past"},
"lexicalized":{"_past"},
"lexicographer":{"_anim","_sb"},
"lexicologist":{"_anim","_sb"},
"leyden":{"_geo","_prprn"},
"Leyte":{"_geo","_prprn"},
"LF":{"_prprn"},
"lh":{"_prprn"},
"lhasa":{"_cty","_geo","_prprn"},
"lhotse":{"_geo","_prprn"},
"Li":{"_prprn"},
"liao":{"_anim","_nme","_prprn","_sb"},
"liars":{"_anim","_sb"},
"Libby":{"_anim","_nme","_prprn","_sb"},
"libeled":{"_past"},
"libeler":{"_anim","_sb"},
"liberal":{"_anim","_sb"},
"liberal-arts":{"_anim","_sb"},
"liberal-conservative":{"_anim","_sb"},
"liberal-democratic":{"_anim","_sb"},
"liberal-led":{"_anim","_sb"},
"liberalized":{"_past"},
"liberals":{"_anim","_sb"},
"liberated":{"_past"},
"Liberia":{"_cntry","_geo","_prprn"},
"libertarian":{"_anim","_sb"},
"libertarians":{"_anim","_sb"},
"libertine":{"_anim","_masc","_sb"},
"libertines":{"_anim","_masc","_sb"},
"librarian-board":{"_anim","_sb"},
"librarians":{"_anim","_sb"},
"library":{"_loc_sr"},
"librettist":{"_anim","_sb"},
"librettists":{"_anim","_sb"},
"Libreville":{"_cty","_geo","_prprn"},
"Librium":{"_prprn"},
"Libya":{"_cntry","_geo","_prprn"},
"Libyan":{"_anim","_prprn","_sb"},
"Libyans":{"_anim","_prprn","_sb"},
"licenced":{"_past"},
"licensed":{"_past"},
"licensee":{"_anim","_sb"},
"licensees":{"_anim","_sb"},
"licenser":{"_anim","_sb"},
"licentiate":{"_anim","_sb"},
"Lichtenstein":{"_anim","_nme","_prprn","_sb"},
"licked":{"_loc_sr","_past"},
"licking":{"_loc_sr"},
"lidded":{"_past"},
"Liebfraumilch":{"_prprn"},
"Liechtenstein":{"_cntry","_geo","_prprn"},
"Liechtensteiner":{"_anim","_prprn","_sb"},
"liederkranz":{"_prprn"},
"liege":{"_anim","_sb"},
"liepaja":{"_cty","_geo","_prprn"},
"Lieut":{"_prprn"},
"lieutenant":{"_anim","_sb"},
"lieutenant-governor":{"_anim","_sb"},
"lieutenants":{"_anim","_sb"},
"lifeguards":{"_anim","_sb"},
"lifetime":{"_tme"},
"lifetimes":{"_tme"},
"lifo":{"_prprn"},
"lifted":{"_loc_sr","_past"},
"lifting":{"_loc_sr"},
"liger":{"_anim"},
"lighted":{"_past"},
"lightened":{"_past"},
"lighter":{"_loc_sr"},
"lightning":{"_wthr"},
"lights-out":{"_sb"},
"lightweight":{"_anim","_sb"},
"lignify":{"_loc_sr"},
"liguria":{"_geo","_prprn","_stte"},
"liked":{"_past"},
"likeliest":{"_probabl"},
"likely":{"_probabl"},
"likened":{"_past"},
"Likud":{"_prprn"},
"Lilith":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"liliuokalani":{"_anim","_nme","_prprn","_sb"},
"lille":{"_cty","_geo","_prprn"},
"Lillian":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"lillie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Lilliput":{"_prprn"},
"Lilliputian":{"_prprn","_sb"},
"lilongwe":{"_cty","_geo","_prprn"},
"Lima":{"_cty","_geo","_prprn"},
"limbo":{"_loc_sr"},
"limeira":{"_cty","_geo","_prprn"},
"limekiln":{"_loc_sr"},
"Limerick":{"_geo","_prprn"},
"limner":{"_anim","_sb"},
"limnologist":{"_anim","_sb"},
"limnos":{"_geo","_prprn"},
"limousin":{"_geo","_prprn","_stte"},
"limped":{"_loc_sr","_past"},
"limpet":{"_anim"},
"limping":{"_loc_sr"},
"Limpopo":{"_geo","_prprn"},
"lin":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Lincoln":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Lincolnshire":{"_cty","_geo","_prprn"},
"Lind":{"_anim","_nme","_prprn","_sb"},
"Linda":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Lindbergh":{"_anim","_nme","_prprn","_sb"},
"Lindemann":{"_prprn"},
"lindesnes":{"_geo","_prprn"},
"lindsay":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Lindsey":{"_anim","_nme","_prprn","_sb"},
"linearize":{"_loc_sr"},
"linebacker":{"_anim","_sb"},
"linebackers":{"_anim","_sb"},
"lined":{"_past"},
"lineman":{"_anim","_sb"},
"linemen":{"_anim","_sb"},
"linesman":{"_anim","_sb"},
"ling-pao":{"_anim"},
"lingered":{"_past"},
"linguist":{"_anim","_sb"},
"linguist-anthropologist":{"_anim","_sb"},
"linked":{"_past"},
"linkman":{"_anim","_sb"},
"Linnaeus":{"_anim","_nme","_prprn","_sb"},
"linnet":{"_anim"},
"Linus":{"_prprn"},
"Linux":{"_prprn"},
"Linz":{"_cty","_geo","_prprn"},
"lion":{"_anim"},
"lion's-ear":{"_anim"},
"lion-hunter":{"_anim"},
"Lionel":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"lionesses":{"_anim","_fem"},
"lionfish":{"_anim"},
"lionized":{"_past"},
"lions":{"_anim"},
"lip-read":{"_past"},
"lip-synch":{"_loc_sr"},
"lipchitz":{"_anim","_nme","_prprn","_sb"},
"lipmann":{"_anim","_nme","_prprn","_sb"},
"liposomes":{"_loc_sr"},
"lipped":{"_past"},
"lippi":{"_anim","_nme","_prprn","_sb"},
"lippmann":{"_anim","_nme","_prprn","_sb"},
"lipscomb":{"_anim","_nme","_prprn","_sb"},
"liquefied":{"_past"},
"liquidators":{"_anim","_sb"},
"liquidiser":{"_anim","_sb"},
"liquidize":{"_loc_sr"},
"liquified":{"_past"},
"Lisa":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Lisbon":{"_cty","_geo","_prprn"},
"lisper":{"_anim","_sb"},
"listed":{"_past"},
"listen":{"_loc_sr"},
"listener-supported":{"_anim","_sb"},
"listeners":{"_anim","_sb"},
"listening":{"_loc_sr"},
"Lister":{"_anim","_prprn","_sb"},
"Liston":{"_prprn"},
"Liszt":{"_anim","_nme","_prprn","_sb"},
"lit":{"_past"},
"literate":{"_anim","_sb"},
"literati":{"_anim","_sb"},
"lithographer":{"_anim","_sb"},
"lithosphere":{"_loc_sr"},
"Lithuania":{"_cntry","_geo","_prprn"},
"Lithuanian":{"_anim","_prprn","_sb"},
"Lithuanians":{"_anim","_prprn","_sb"},
"litigants":{"_anim","_sb"},
"litigated":{"_loc_sr","_past"},
"litigators":{"_anim","_sb"},
"litterateur":{"_anim","_sb"},
"litterbug":{"_anim","_sb"},
"littered":{"_past"},
"litterer":{"_anim","_sb"},
"little":{"_quant"},
"little-feared":{"_quant"},
"little-girl":{"_quant"},
"little-noted":{"_quant"},
"little-noticed":{"_quant"},
"little-publicized":{"_quant"},
"little-town":{"_quant"},
"little-understood":{"_quant"},
"littler":{"_quant"},
"littlest":{"_quant"},
"littoral":{"_loc_sr"},
"liturgist":{"_anim","_sb"},
"lived":{"_past"},
"Livermore":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"liveryman":{"_anim","_masc","_sb"},
"Livingston":{"_anim","_geo","_nme","_prprn","_sb"},
"Livingstone":{"_anim","_nme","_prprn","_sb"},
"livonia":{"_cty","_geo","_prprn"},
"livonian":{"_anim","_prprn","_sb"},
"livonian-speaking":{"_anim","_prprn","_sb"},
"Livy":{"_anim","_nme","_prprn","_sb"},
"liza":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"lizard":{"_anim"},
"lizard's-tail":{"_anim"},
"lizardfish":{"_anim"},
"lizards":{"_anim"},
"Ljubljana":{"_cty","_geo","_prprn"},
"llama":{"_anim"},
"Llewellyn":{"_anim","_nme","_prprn","_sb"},
"Lloyd":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"llullaillaco":{"_geo","_prprn"},
"load":{"_loc_sr"},
"loaded":{"_loc_sr","_past"},
"loading":{"_loc_sr"},
"loafed":{"_loc_sr","_past"},
"loafer":{"_anim","_sb"},
"loafers":{"_anim","_sb"},
"loafing":{"_loc_sr"},
"loaned":{"_past"},
"loaner":{"_anim","_sb"},
"loathed":{"_past"},
"lob":{"_loc_sr"},
"lobbied":{"_loc_sr","_past"},
"lobbies":{"_loc_sr"},
"lobby":{"_loc_sr"},
"lobbying":{"_loc_sr"},
"lobbyist":{"_anim","_sb"},
"lobbyists":{"_anim","_sb"},
"lobito":{"_cty","_geo","_prprn"},
"lobo":{"_anim"},
"lobster":{"_anim"},
"lobsterman":{"_anim","_masc","_sb"},
"lobstermen":{"_anim","_masc","_sb"},
"lobsters":{"_anim"},
"local":{"_anim","_sb"},
"local-content":{"_anim","_sb"},
"local-control":{"_anim","_sb"},
"local-exchange":{"_anim","_sb"},
"local-government":{"_anim","_sb"},
"local-money":{"_anim","_sb"},
"local-news":{"_anim","_sb"},
"local-service":{"_anim","_sb"},
"locale":{"_loc_sr"},
"localised":{"_past"},
"localities":{"_loc_sr"},
"localized":{"_past"},
"locally":{"_loc"},
"locals":{"_anim","_sb"},
"located":{"_past"},
"locater":{"_anim","_sb"},
"location":{"_loc_sr"},
"location-minded":{"_loc_sr"},
"locations":{"_loc_sr"},
"locator":{"_anim","_sb"},
"Locke":{"_anim","_nme","_prprn","_sb"},
"locked":{"_past"},
"lockmaster":{"_anim","_sb"},
"lockup":{"_loc_sr"},
"locum":{"_anim","_sb"},
"locus":{"_loc_sr"},
"locust":{"_anim"},
"locusts":{"_anim"},
"Lodge":{"_anim","_prprn","_sb"},
"lodged":{"_past"},
"lodger":{"_anim","_sb"},
"lodgings":{"_loc_sr"},
"lodz":{"_cty","_geo","_prprn"},
"loeb":{"_anim","_nme","_prprn","_sb"},
"Loewe":{"_anim","_nme","_prprn","_sb"},
"loewi":{"_anim","_nme","_prprn","_sb"},
"Loewy":{"_anim","_nme","_prprn","_sb"},
"loft":{"_loc_sr"},
"lofts":{"_loc_sr"},
"Logan":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"logged":{"_loc_sr","_past"},
"logger":{"_anim","_sb"},
"logging":{"_loc_sr"},
"logician":{"_anim","_sb"},
"loginess":{"_anim","_fem","_sb"},
"logistician":{"_anim","_sb"},
"logomachist":{"_anim","_sb"},
"logrono":{"_cty","_geo","_prprn"},
"loins":{"_sb"},
"loir":{"_geo","_prprn"},
"Loire":{"_geo","_prprn"},
"Lois":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"loiter":{"_loc_sr"},
"loitering":{"_loc_sr"},
"Loki":{"_anim","_masc","_nme","_prprn","_sb"},
"Lolita":{"_prprn","_sb"},
"lolling":{"_loc_sr"},
"lollop":{"_loc_sr"},
"Lomas":{"_prprn"},
"Lomax":{"_anim","_nme","_prprn","_sb"},
"lombard":{"_anim","_geo","_nme","_prprn","_sb"},
"Lombardi":{"_anim","_nme","_prprn","_sb"},
"lombardy":{"_geo","_prprn"},
"London":{"_cty","_geo","_prprn"},
"Londonderry":{"_geo","_prprn"},
"Londoner":{"_anim","_sb"},
"loner":{"_anim","_sb"},
"loners":{"_anim","_sb"},
"long-term":{"_tme"},
"longed":{"_past"},
"longer-term":{"_tme"},
"Longfellow":{"_anim","_nme","_prprn","_sb"},
"longhorns":{"_anim"},
"Longmont":{"_cty","_geo","_prprn"},
"Longstreet":{"_anim","_nme","_prprn","_sb"},
"Longview":{"_cty","_geo","_prprn"},
"lookdown":{"_loc_sr"},
"looked":{"_loc_sr","_past"},
"lookee-loos":{"_anim","_sb"},
"looker":{"_anim","_sb"},
"looking":{"_loc_sr"},
"lookout":{"_anim"},
"loomed":{"_loc_sr","_past"},
"looming":{"_loc_sr"},
"loonies":{"_anim","_sb"},
"loony":{"_anim","_sb"},
"looped":{"_loc_sr","_past"},
"looping":{"_loc_sr"},
"loosened":{"_past"},
"looted":{"_past"},
"loped":{"_loc_sr","_past"},
"Lopez":{"_anim","_nme","_prprn","_sb"},
"loping":{"_loc_sr"},
"lopped":{"_past"},
"lopper":{"_anim","_sb"},
"Lorain":{"_cty","_geo","_prprn"},
"Lorca":{"_anim","_nme","_prprn","_sb"},
"Lord":{"_anim","_masc","_prprn","_sb"},
"Lorde":{"_prprn"},
"lords":{"_anim","_masc","_sb"},
"Lorelei":{"_prprn"},
"loren":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"lorentz":{"_anim","_nme","_prprn","_sb"},
"lorenz":{"_anim","_nme","_prprn","_sb"},
"Lorenzo":{"_prprn"},
"Loretta":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Lori":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Lorinda":{"_prprn"},
"Lorna":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Lorrain":{"_anim","_nme","_prprn","_sb"},
"Lorraine":{"_geo","_prprn","_stte"},
"lorre":{"_anim","_nme","_prprn","_sb"},
"lorries":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"lorry":{"_fem"},
"loser":{"_anim","_sb"},
"losers":{"_anim","_sb"},
"lost-profits":{"_past"},
"Lothario":{"_anim","_masc","_prprn","_sb"},
"lotter":{"_anim","_sb"},
"Lottie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"lotus-eater":{"_anim","_sb"},
"loudmouth":{"_anim","_sb"},
"Louis":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Louisa":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Louise":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Louisiana":{"_geo","_prprn","_stte"},
"Louisianian":{"_prprn"},
"Louisville":{"_cty","_geo","_prprn"},
"lounge":{"_loc_sr"},
"lounged":{"_loc_sr","_past"},
"lounger":{"_anim","_sb"},
"lounging":{"_loc_sr"},
"Lourie":{"_prprn"},
"louse":{"_anim"},
"lovebird":{"_anim"},
"lovebirds":{"_anim"},
"loved":{"_past"},
"Lovelace":{"_anim","_nme","_prprn","_sb"},
"lovelies":{"_anim","_sb"},
"Lovell":{"_anim","_nme","_prprn","_sb"},
"lovely":{"_anim","_sb"},
"lover":{"_anim","_sb"},
"lovers":{"_anim","_sb"},
"lowbrow":{"_anim","_sb"},
"Lowell":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"lowered":{"_past"},
"lowland":{"_loc_sr"},
"lowlands":{"_loc_sr"},
"loyalist":{"_anim","_sb"},
"loyalists":{"_anim","_sb"},
"loyang":{"_geo","_prprn"},
"Loyola":{"_anim","_nme","_prprn","_sb"},
"LP":{"_prprn"},
"lpn":{"_prprn"},
"Lu":{"_prprn"},
"Luanda":{"_cty","_geo","_prprn"},
"luba":{"_anim","_prprn","_sb"},
"lubavitcher":{"_prprn","_sb"},
"lubber":{"_anim","_sb"},
"Lubbock":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"lubeck":{"_cty","_geo","_prprn"},
"lubitsch":{"_anim","_nme","_prprn","_sb"},
"lublin":{"_cty","_geo","_prprn"},
"lubricator":{"_sb"},
"lubumbashi":{"_cty","_geo","_prprn"},
"Lubyanka":{"_prprn"},
"Lucca":{"_cty","_geo","_prprn"},
"luce":{"_anim","_nme","_prprn","_sb"},
"lucerne":{"_anim"},
"Lucia":{"_fem","_fnme","_prprn"},
"Lucian":{"_anim","_nme","_prprn","_sb"},
"Lucifer":{"_prprn"},
"Lucille":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Lucinda":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"lucite":{"_prprn"},
"Lucius":{"_prprn"},
"lucked":{"_past"},
"lucknow":{"_cty","_geo","_prprn"},
"Lucretia":{"_prprn"},
"Lucretius":{"_anim","_nme","_prprn","_sb"},
"lucubrate":{"_loc_sr"},
"lucullus":{"_anim","_nme","_prprn","_sb"},
"Lucy":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"luda":{"_geo","_prprn"},
"Luddite":{"_anim","_prprn","_sb"},
"Ludlow":{"_cty","_geo","_prprn"},
"Ludwigshafen":{"_cty","_geo","_prprn"},
"luff":{"_loc_sr"},
"Luftwaffe":{"_prprn"},
"Luger":{"_anim","_sb"},
"luggage":{"_loc_sr"},
"lugged":{"_past"},
"lugworm":{"_anim"},
"Luhrmann":{"_prprn"},
"lull":{"_psych"},
"lulled":{"_past","_psych"},
"Lully":{"_anim","_nme","_prprn","_sb"},
"lulu":{"_sb"},
"lumber":{"_loc_sr"},
"lumbered":{"_loc_sr","_past"},
"lumbering":{"_loc_sr"},
"lumberjack":{"_anim","_sb"},
"lumberman":{"_anim","_sb"},
"luminaries":{"_anim","_sb"},
"luminary":{"_anim","_sb"},
"lump":{"_loc_sr"},
"lumped":{"_loc_sr","_past"},
"lumper":{"_anim","_sb"},
"lumpfish":{"_anim"},
"lumping":{"_loc_sr"},
"Lumumba":{"_anim","_nme","_prprn","_sb"},
"luna":{"_anim","_fem","_nme","_prprn","_sb"},
"lunatic-fringe":{"_anim","_sb"},
"lunatics":{"_anim","_sb"},
"lunch":{"_tme"},
"lunch-box":{"_tme"},
"lunch-hour":{"_tme"},
"lunched":{"_past"},
"lunches":{"_tme"},
"lunchtime":{"_tme"},
"lund":{"_cty","_geo","_prprn"},
"Lundy":{"_anim","_nme","_prprn","_sb"},
"lunge":{"_loc_sr"},
"lunged":{"_loc_sr","_past"},
"lungfish":{"_anim"},
"lunging":{"_loc_sr"},
"lunt":{"_anim","_nme","_prprn","_sb"},
"luoyang":{"_cty","_geo","_prprn"},
"lurch":{"_loc_sr"},
"lurched":{"_loc_sr","_past"},
"lurcher":{"_anim"},
"lurching":{"_loc_sr"},
"lured":{"_past"},
"Lurie":{"_prprn"},
"lurk":{"_loc_sr"},
"lurked":{"_loc_sr","_past"},
"lurker":{"_anim","_sb"},
"lurking":{"_loc_sr"},
"lurks":{"_loc_sr"},
"Lusaka":{"_cty","_geo","_prprn"},
"lushes":{"_anim","_sb"},
"lushun":{"_cty","_geo","_prprn"},
"Lusitania":{"_geo","_prprn","_stte"},
"luta":{"_geo","_prprn"},
"lutanist":{"_anim","_sb"},
"Luth":{"_prprn"},
"Lutheran":{"_prprn","_sb"},
"Lutheranism":{"_prprn"},
"luthier":{"_anim","_sb"},
"Luthuli":{"_anim","_nme","_prprn","_sb"},
"Lutz":{"_prprn"},
"luwian":{"_prprn"},
"luxembourg-ville":{"_cntry","_cty","_geo","_prprn"},
"Luxembourger":{"_anim","_prprn","_sb"},
"luxembourgian":{"_prprn"},
"Luxemburg":{"_anim","_nme","_prprn","_sb"},
"luzon":{"_geo","_prprn"},
"LV":{"_cty","_geo","_prprn"},
"Lvov":{"_cty","_geo","_prprn"},
"lyallpur":{"_geo","_prprn"},
"lycia":{"_geo","_prprn","_stte"},
"lycian":{"_prprn"},
"Lycra":{"_prprn"},
"Lydia":{"_cntry","_geo","_prprn"},
"lydian":{"_prprn"},
"Lyle":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Lyly":{"_anim","_nme","_prprn","_sb"},
"Lymington":{"_prprn"},
"lymphatic":{"_loc_sr"},
"lynchburg":{"_cty","_geo","_prprn"},
"lynched":{"_past"},
"Lynn":{"_anim","_cty","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"Lyon":{"_anim","_geo","_nme","_prprn","_sb"},
"Lyonnais":{"_geo","_prprn","_stte"},
"lyophilised":{"_past"},
"Lyra":{"_prprn"},
"lyrebird":{"_anim","_sb"},
"lyricists":{"_anim","_sb"},
"lyrist":{"_anim","_sb"},
"Lys":{"_geo","_prprn"},
"lysander":{"_anim","_nme","_prprn","_sb"},
"lysenko":{"_anim","_nme","_prprn","_sb"},
"lysimachus":{"_anim","_nme","_prprn","_sb"},
"lysippus":{"_anim","_nme","_prprn","_sb"},
"Lysol":{"_prprn"},
"Lytton":{"_anim","_nme","_prprn","_sb"},
"ma":{"_anim","_fem","_sb"},
"ma'am":{"_anim","_fem","_sb"},
"Maastricht":{"_cty","_geo","_prprn"},
"Mac":{"_prprn"},
"macaque":{"_anim"},
"MacArthur":{"_anim","_nme","_prprn","_sb"},
"Macassar":{"_prprn"},
"macau":{"_geo","_prprn"},
"macaulay":{"_anim","_nme","_prprn","_sb"},
"Macbeth":{"_anim","_nme","_prprn","_sb"},
"MacDonald":{"_anim","_prprn","_sb"},
"macdowell":{"_anim","_nme","_prprn","_sb"},
"Mace":{"_prprn"},
"mace-bearer":{"_anim","_sb"},
"Macedon":{"_prprn"},
"Macedonia":{"_cntry","_geo","_prprn"},
"Macedonian":{"_anim","_prprn","_sb"},
"MacGregor":{"_prprn"},
"Mach":{"_prprn"},
"Machado":{"_prprn"},
"Machiavelli":{"_anim","_nme","_prprn","_sb"},
"machiavellianism":{"_prprn"},
"Machida":{"_cty","_geo","_prprn"},
"machinator":{"_anim","_sb"},
"machinist":{"_anim","_sb"},
"machinists":{"_anim","_sb"},
"machmeter":{"_prprn"},
"Mackenzie":{"_anim","_fnme","_nme","_prprn","_sb"},
"mackerel":{"_anim"},
"Mackinac":{"_prprn"},
"macleish":{"_anim","_nme","_prprn","_sb"},
"macleod":{"_anim","_nme","_prprn","_sb"},
"Macmillan":{"_anim","_nme","_prprn","_sb"},
"Macon":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Macquarie":{"_geo","_prprn"},
"Madagascan":{"_prprn"},
"Madagascar":{"_cntry","_geo","_prprn"},
"madam":{"_anim","_fem","_sb"},
"madden":{"_psych"},
"maddened":{"_past","_psych"},
"maddening":{"_psych"},
"made-for-television":{"_past"},
"made-for-TV":{"_past"},
"Madeira":{"_geo","_prprn"},
"Madeline":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Mademoiselle":{"_anim","_fem","_prprn","_sb"},
"Madison":{"_anim","_cty","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"madman":{"_anim","_masc","_sb"},
"madmen":{"_anim","_masc","_sb"},
"Madonna":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Madras":{"_cty","_geo","_prprn"},
"Madrid":{"_cty","_geo","_prprn","_stte"},
"madrigalist":{"_anim","_sb"},
"madwoman":{"_anim","_fem","_sb"},
"Mae":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"maelstrom":{"_loc_sr"},
"maenad":{"_anim","_fem","_sb"},
"maeterlinck":{"_anim","_nme","_prprn","_sb"},
"mafiosi":{"_prprn","_sb"},
"mafioso":{"_prprn","_sb"},
"magdalena":{"_geo","_prprn"},
"Magdalene":{"_prprn"},
"Magellan":{"_anim","_nme","_prprn","_sb"},
"Maggie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"maggot":{"_anim"},
"maggot-covered":{"_anim"},
"maggots":{"_anim"},
"Magh":{"_prprn"},
"Maghreb":{"_geo","_prprn"},
"Magi":{"_anim","_prprn","_sb"},
"magicians":{"_anim","_sb"},
"maginot":{"_anim","_nme","_prprn","_sb"},
"magistrate":{"_anim","_sb"},
"magistrates":{"_anim","_sb"},
"magnate":{"_anim","_sb"},
"magnetised":{"_past"},
"magnetized":{"_past"},
"Magnificat":{"_prprn"},
"magnifico":{"_anim","_sb"},
"magnified":{"_past"},
"Magog":{"_prprn"},
"magpie":{"_anim"},
"magpies":{"_anim"},
"Magritte":{"_anim","_nme","_prprn","_sb"},
"magus":{"_anim","_sb"},
"Magyar":{"_prprn","_sb"},
"mahan":{"_anim","_nme","_prprn","_sb"},
"maharaja":{"_anim","_masc","_sb"},
"maharani":{"_anim","_fem","_sb"},
"Maharashtra":{"_geo","_prprn"},
"mahatma":{"_anim","_masc","_sb"},
"Mahayana":{"_prprn"},
"Mahayanist":{"_prprn"},
"Mahdi":{"_prprn"},
"mahdism":{"_prprn"},
"mahdist":{"_prprn"},
"Mahfouz":{"_anim","_nme","_prprn","_sb"},
"mahican":{"_prprn"},
"Mahler":{"_anim","_nme","_prprn","_sb"},
"Mahomet":{"_prprn"},
"mahout":{"_anim","_sb"},
"mahratta":{"_anim","_prprn","_sb"},
"mahratti":{"_prprn"},
"maia":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"maid":{"_anim","_fem","_sb"},
"maiden":{"_anim","_fem","_sb"},
"maidenhood":{"_sb"},
"maidens":{"_anim","_fem","_sb"},
"maidu":{"_anim","_prprn","_sb"},
"maiduguri":{"_cty","_geo","_prprn"},
"mailbox":{"_loc_sr"},
"mailboxes":{"_loc_sr"},
"mailed":{"_loc_sr","_past"},
"mailed-fist-in-velvet-glove":{"_loc_sr","_past"},
"mailing":{"_loc_sr"},
"Maillol":{"_anim","_nme","_prprn","_sb"},
"mailroom":{"_loc_sr"},
"mailrooms":{"_loc_sr"},
"maimed":{"_loc_sr","_past"},
"maimer":{"_anim","_sb"},
"Maimonides":{"_anim","_nme","_prprn","_sb"},
"main":{"_loc_sr"},
"main-topmast":{"_loc_sr"},
"main-topsail":{"_loc_sr"},
"Maine":{"_geo","_prprn","_stte"},
"Mainer":{"_anim","_sb"},
"mainland":{"_loc_sr"},
"mainlander":{"_anim","_sb"},
"mainline":{"_loc_sr"},
"mainmast":{"_loc_sr"},
"mains":{"_loc_sr"},
"mainsail":{"_loc_sr"},
"mainstay":{"_sb"},
"mainstays":{"_sb"},
"mainstreamed":{"_loc_sr","_past"},
"maintained":{"_past"},
"maintainer":{"_anim","_sb"},
"Maintenon":{"_anim","_nme","_prprn","_sb"},
"Mainz":{"_cty","_geo","_prprn"},
"Maitland":{"_anim","_nme","_prprn","_sb"},
"Maj":{"_prprn"},
"Maj.":{"_anim","_prprn","_sb"},
"Majesty":{"_prprn"},
"major":{"_loc_sr"},
"major-burden-to-the-planet":{"_anim","_sb"},
"major-general":{"_anim","_sb"},
"major-market":{"_anim","_sb"},
"major-medical":{"_anim","_sb"},
"major-party":{"_anim","_sb"},
"Majorca":{"_geo","_prprn"},
"majordomo":{"_anim","_sb"},
"majored":{"_loc_sr","_past"},
"majorette":{"_anim","_sb"},
"majoring":{"_loc_sr"},
"majorities":{"_sb"},
"majority":{"_sb"},
"majority-held":{"_sb"},
"majority-owned":{"_sb"},
"majority-party":{"_sb"},
"majors":{"_anim","_sb"},
"makalu":{"_geo","_prprn"},
"Maker":{"_anim","_sb"},
"makers":{"_anim","_sb"},
"Malabar":{"_prprn"},
"malabo":{"_cty","_geo","_prprn"},
"malacca":{"_prprn"},
"Malachi":{"_anim","_fnme","_nme","_prprn","_sb"},
"malacologist":{"_anim","_sb"},
"maladroit":{"_sb"},
"Malaga":{"_cty","_geo","_prprn"},
"Malamud":{"_anim","_nme","_prprn","_sb"},
"malamute":{"_anim"},
"malathion":{"_prprn"},
"Malawi":{"_cntry","_geo","_prprn"},
"Malawian":{"_anim","_prprn","_sb"},
"Malay":{"_anim","_prprn","_sb"},
"Malaya":{"_geo","_prprn"},
"Malayalam":{"_prprn"},
"Malayan":{"_prprn"},
"malayo-polynesian":{"_prprn"},
"Malays":{"_anim","_prprn","_sb"},
"Malaysian":{"_anim","_prprn","_sb"},
"Malcolm":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Malden":{"_cty","_geo","_prprn"},
"Maldives":{"_cntry","_geo","_prprn"},
"male-dominated":{"_anim","_masc","_sb"},
"male-fertile":{"_anim","_masc","_sb"},
"male-headed":{"_anim","_masc","_sb"},
"male-only":{"_anim","_masc","_sb"},
"male-sterile":{"_anim","_masc","_sb"},
"malebranche":{"_anim","_nme","_prprn","_sb"},
"malecite":{"_anim","_prprn","_sb"},
"malefactor":{"_anim","_sb"},
"malefactors":{"_anim","_sb"},
"malemute":{"_anim"},
"Malenkov":{"_anim","_nme","_prprn","_sb"},
"males":{"_anim","_masc","_sb"},
"malevich":{"_anim","_nme","_prprn","_sb"},
"malfeasant":{"_anim","_sb"},
"Mali":{"_cntry","_geo","_prprn"},
"Malian":{"_anim","_prprn","_sb"},
"maligned":{"_past"},
"malingerer":{"_anim","_sb"},
"malingerers":{"_anim","_sb"},
"Malinowski":{"_anim","_nme","_prprn","_sb"},
"mall":{"_loc_sr"},
"mallard":{"_anim"},
"mallards":{"_anim"},
"mallarme":{"_anim","_nme","_prprn","_sb"},
"mallon":{"_anim","_nme","_prprn","_sb"},
"malls":{"_loc_sr"},
"Malmesbury":{"_prprn"},
"malmo":{"_cty","_geo","_prprn"},
"Malone":{"_anim","_nme","_prprn","_sb"},
"Malory":{"_anim","_nme","_prprn","_sb"},
"malpighi":{"_anim","_nme","_prprn","_sb"},
"Malraux":{"_anim","_nme","_prprn","_sb"},
"Malta":{"_cntry","_geo","_prprn"},
"Maltese":{"_anim","_prprn","_sb"},
"Malthus":{"_anim","_nme","_prprn","_sb"},
"Malthusian":{"_prprn"},
"malthusianism":{"_prprn"},
"maltreated":{"_loc_sr","_past"},
"maltreater":{"_anim","_sb"},
"maltster":{"_anim","_sb"},
"Malvern":{"_prprn"},
"mamas":{"_anim","_fem","_sb"},
"mamba":{"_anim"},
"mambas":{"_anim"},
"Mamet":{"_anim","_nme","_prprn","_sb"},
"mammal":{"_anim"},
"mammalogist":{"_anim","_sb"},
"mammies":{"_anim","_fem","_sb"},
"mammoth":{"_anim"},
"mammoths":{"_anim"},
"mammy":{"_anim","_fem","_sb"},
"man":{"_anim","_masc","_sb"},
"man-at-arms":{"_anim","_sb"},
"man-bites-dog":{"_anim","_masc","_sb"},
"man-child":{"_anim","_masc","_sb"},
"man-eater":{"_anim","_sb"},
"man-in-the-moon":{"_anim","_masc","_sb"},
"man-of-the-earth":{"_anim","_masc","_sb"},
"man-on-a-horse":{"_anim","_masc","_sb"},
"man-portable":{"_anim","_masc","_sb"},
"managed":{"_past"},
"managed-care":{"_past"},
"manager":{"_anim","_sb"},
"manageress":{"_anim","_fem","_sb"},
"managers":{"_anim","_sb"},
"Managua":{"_cty","_geo","_prprn"},
"manama":{"_cty","_geo","_prprn"},
"Manassas":{"_cty","_geo","_prprn"},
"manatee":{"_anim"},
"Manchester":{"_cty","_geo","_prprn"},
"Manchu":{"_anim","_prprn","_sb"},
"Manchuria":{"_geo","_prprn"},
"mandaean":{"_prprn"},
"Mandalay":{"_cty","_geo","_prprn"},
"Mandarin":{"_anim","_sb"},
"mandatary":{"_anim","_sb"},
"mandated":{"_past"},
"mande":{"_prprn"},
"mandean":{"_prprn","_sb"},
"Mandela":{"_anim","_nme","_prprn","_sb"},
"mandrill":{"_anim"},
"Manet":{"_anim","_nme","_prprn","_sb"},
"maneuvered":{"_past"},
"maneuverer":{"_anim","_sb"},
"mangabey":{"_anim"},
"manger":{"_loc_sr"},
"mangled":{"_past"},
"mangler":{"_anim","_sb"},
"manhandle":{"_loc_sr"},
"manhandled":{"_loc_sr","_past"},
"Manhattan":{"_cty","_geo","_prprn"},
"manhood":{"_sb","_tme"},
"maniac":{"_anim","_sb"},
"maniacs":{"_anim","_sb"},
"manic-depressive":{"_anim","_sb"},
"Manichaean":{"_prprn"},
"manichaeism":{"_prprn"},
"manichean":{"_prprn"},
"manichee":{"_prprn"},
"manicured":{"_past"},
"manicurist":{"_anim","_sb"},
"manifested":{"_past"},
"manikin":{"_anim","_masc","_sb"},
"manikins":{"_anim","_masc","_sb"},
"Manila":{"_cty","_geo","_prprn"},
"manipulated":{"_past"},
"manis":{"_anim","_nme","_prprn","_sb"},
"Manitoba":{"_geo","_prprn","_stte"},
"mankato":{"_cty","_geo","_prprn"},
"mankind":{"_anim","_sb"},
"Manley":{"_prprn"},
"Mann":{"_anim","_nme","_prprn","_sb"},
"mannequin":{"_anim","_sb"},
"mannheim":{"_cty","_geo","_prprn"},
"manor":{"_loc_sr"},
"manors":{"_loc_sr"},
"Mansfield":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"mansions":{"_loc_sr"},
"Manson":{"_anim","_nme","_prprn","_sb"},
"Mantegna":{"_anim","_nme","_prprn","_sb"},
"mantinea":{"_cty","_geo","_prprn"},
"mantled":{"_past"},
"Mantua":{"_cty","_geo","_prprn"},
"Manuel":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"manufactured":{"_loc_sr","_past"},
"manufacturer":{"_sb"},
"manufacturers":{"_sb"},
"manufactures":{"_loc_sr"},
"manumit":{"_loc_sr"},
"manumitted":{"_loc_sr","_past"},
"manumitter":{"_anim","_sb"},
"many-bodied":{"_quant"},
"many-chambered":{"_quant"},
"many-faced":{"_quant"},
"many-fold":{"_quant"},
"many-lobed":{"_quant"},
"many-much":{"_quant"},
"many-times":{"_quant"},
"manzanilla":{"_prprn"},
"Manzoni":{"_anim","_nme","_prprn","_sb"},
"mao":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"maoi":{"_prprn"},
"Maoism":{"_prprn"},
"Maoist":{"_anim","_sb"},
"Maori":{"_anim","_prprn","_sb"},
"map-reader":{"_anim","_sb"},
"mapped":{"_past"},
"mapper":{"_anim","_sb"},
"Maputo":{"_cty","_geo","_prprn"},
"maquisard":{"_prprn"},
"mara":{"_anim"},
"maracaibo":{"_cty","_geo","_prprn"},
"maracay":{"_cty","_geo","_prprn"},
"marat":{"_anim","_nme","_prprn","_sb"},
"maratha":{"_anim","_prprn","_sb"},
"marathi":{"_prprn"},
"Marathon":{"_geo","_prprn"},
"marathoner":{"_anim","_sb"},
"maraud":{"_loc_sr"},
"marbled":{"_past"},
"marbleised":{"_past"},
"marbleized":{"_past"},
"Marc":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"marceau":{"_anim","_nme","_prprn","_sb"},
"Marcel":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Marcella":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Marcellus":{"_anim","_nme","_prprn","_sb"},
"march":{"_loc_sr"},
"Marche":{"_geo","_prprn","_stte"},
"marched":{"_loc_sr","_past"},
"marcher":{"_anim","_sb"},
"marchers":{"_anim","_sb"},
"marches":{"_loc_sr"},
"marching":{"_loc_sr"},
"marchioness":{"_anim","_fem","_sb"},
"Marcia":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Marciano":{"_anim","_nme","_prprn","_sb"},
"marcionism":{"_prprn"},
"Marconi":{"_anim","_nme","_prprn","_sb"},
"Marcos":{"_anim","_nme","_prprn","_sb"},
"Marcus":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Marcuse":{"_anim","_nme","_prprn","_sb"},
"Marcy":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"marduk":{"_prprn"},
"mare":{"_anim","_fem"},
"mare-COOR":{"_anim","_fem"},
"Marenzio":{"_prprn"},
"mares":{"_anim","_fem"},
"Margaret":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Margate":{"_cty","_geo","_prprn"},
"Margaux":{"_prprn"},
"Margery":{"_prprn"},
"margin":{"_loc_sr"},
"margin-calls":{"_loc_sr"},
"margin-the":{"_loc_sr"},
"marginal":{"_anim","_sb"},
"marginal-rate":{"_anim","_sb"},
"margined":{"_past"},
"margins":{"_loc_sr"},
"Margulies":{"_prprn"},
"mari":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"maria":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Marian":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"marianas":{"_geo"},
"Marianne":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"maricopa":{"_anim","_prprn","_sb"},
"Marie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Marietta":{"_cty","_geo","_prprn"},
"Marilyn":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Marin":{"_anim","_nme","_prprn","_sb"},
"marina":{"_loc_sr"},
"marinas":{"_loc_sr"},
"marinate":{"_loc_sr"},
"marinated":{"_loc_sr","_past"},
"marinating":{"_loc_sr"},
"marine":{"_anim","_sb"},
"marine-products":{"_anim","_sb"},
"marine-related":{"_anim","_sb"},
"marine-research":{"_anim","_sb"},
"marine-shipping":{"_anim","_sb"},
"marine-transport":{"_anim","_sb"},
"marines":{"_anim","_sb"},
"marini":{"_anim","_nme","_prprn","_sb"},
"marino":{"_prprn"},
"Marion":{"_anim","_cty","_fem","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"Maris":{"_anim","_fnme","_nme","_prprn","_sb"},
"Marist":{"_prprn","_sb"},
"Maritain":{"_anim","_nme","_prprn","_sb"},
"Marjorie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"marked-up":{"_loc_sr","_past"},
"market-affecting":{"_loc_sr"},
"market-allocation":{"_loc_sr"},
"market-based":{"_loc_sr"},
"market-by-market":{"_loc_sr"},
"market-corporate":{"_loc_sr"},
"market-driven":{"_loc_sr"},
"market-hog":{"_loc_sr"},
"market-if-touched":{"_loc_sr"},
"market-inspired":{"_loc_sr"},
"market-jarring":{"_loc_sr"},
"market-maker":{"_loc_sr"},
"market-makers":{"_loc_sr"},
"market-making":{"_loc_sr"},
"market-monitoring":{"_loc_sr"},
"market-on-close":{"_loc_sr"},
"market-opening":{"_loc_sr"},
"market-oriented":{"_loc_sr"},
"market-place":{"_loc_sr"},
"market-ready":{"_loc_sr"},
"market-reform":{"_loc_sr"},
"market-related":{"_loc_sr"},
"market-research":{"_loc_sr"},
"market-revision":{"_loc_sr"},
"market-sensitive":{"_loc_sr"},
"market-share":{"_loc_sr"},
"market-sharing":{"_loc_sr"},
"market-specific":{"_loc_sr"},
"market-stabilizing":{"_loc_sr"},
"market-style":{"_loc_sr"},
"market-system":{"_loc_sr"},
"market-timing":{"_loc_sr"},
"market-watchers":{"_loc_sr"},
"market-weighted":{"_loc_sr"},
"marketeers":{"_anim","_sb"},
"marketer":{"_anim","_sb"},
"marketers":{"_anim","_sb"},
"marketplace":{"_loc_sr"},
"marketplaces":{"_loc_sr"},
"markets":{"_loc_sr"},
"Markham":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"markhor":{"_anim"},
"marking":{"_loc_sr"},
"markova":{"_anim","_nme","_prprn","_sb"},
"Marlborough":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Marlene":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Marley":{"_prprn"},
"Marlowe":{"_anim","_nme","_prprn","_sb"},
"Marmara":{"_prprn"},
"marmoset":{"_anim"},
"marmot":{"_anim"},
"Marne":{"_geo","_prprn"},
"Maroc":{"_prprn"},
"Maronite":{"_prprn","_sb"},
"maroon":{"_anim","_sb"},
"maroon-purple":{"_anim","_sb"},
"maroon-spotted":{"_anim","_sb"},
"marooned":{"_loc_sr","_past"},
"marquand":{"_anim","_nme","_prprn","_sb"},
"Marquette":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"marquis":{"_anim","_masc","_sb"},
"Marrakech":{"_prprn"},
"marrano":{"_prprn"},
"marred":{"_past"},
"married-couple":{"_sb"},
"married-put":{"_sb"},
"Marruecos":{"_prprn"},
"marry":{"_loc_sr"},
"marrying":{"_loc_sr"},
"Mars":{"_anim","_day","_masc","_prprn","_sb"},
"Marsala":{"_cty","_geo","_prprn"},
"Marsalis":{"_prprn"},
"Marseillaise":{"_prprn"},
"Marseille":{"_prprn"},
"marsh":{"_loc_sr"},
"Marsha":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"marshal":{"_loc_sr"},
"marshaling":{"_loc_sr"},
"Marshall":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"marshalled":{"_loc_sr","_past"},
"marshalling":{"_loc_sr"},
"marshals":{"_anim","_sb"},
"marshes":{"_loc_sr"},
"marshland":{"_loc_sr"},
"Marston":{"_anim","_nme","_prprn","_sb"},
"marsupial":{"_anim"},
"marten":{"_anim"},
"Martha":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Martian":{"_prprn"},
"Martians":{"_prprn"},
"martin":{"_anim"},
"Martineau":{"_anim","_nme","_prprn","_sb"},
"martinet":{"_anim","_sb"},
"Martini":{"_anim","_prprn","_sb"},
"Martinique":{"_geo","_prprn"},
"Martinis":{"_anim","_prprn","_sb"},
"martinmas":{"_prprn"},
"marts":{"_loc_sr"},
"martyr":{"_anim","_sb"},
"marveled":{"_past"},
"marvell":{"_anim","_nme","_prprn","_sb"},
"marvelled":{"_past"},
"marveller":{"_anim","_sb"},
"Marvin":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Marx":{"_anim","_nme","_prprn","_sb"},
"Marxism":{"_prprn"},
"Marxism-Leninism":{"_prprn"},
"Marxist":{"_anim","_prprn","_sb"},
"Marxists":{"_anim","_prprn","_sb"},
"Mary":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Maryland":{"_geo","_prprn","_stte"},
"Marylander":{"_anim","_sb"},
"mas":{"_anim","_fem","_sb"},
"Masada":{"_geo","_prprn"},
"masai":{"_anim","_prprn","_sb"},
"Masaryk":{"_anim","_nme","_prprn","_sb"},
"Masefield":{"_anim","_nme","_prprn","_sb"},
"maseru":{"_cty","_geo","_prprn"},
"mashed":{"_loc_sr","_past"},
"mashhad":{"_geo","_prprn"},
"mashing":{"_loc_sr"},
"masked":{"_past"},
"masker":{"_anim","_sb"},
"maskers":{"_anim","_sb"},
"Mason":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"masonite":{"_prprn"},
"masons":{"_anim","_sb"},
"Masora":{"_prprn"},
"Masorah":{"_prprn"},
"masquerader":{"_anim","_sb"},
"Mass":{"_prprn"},
"mass-producing":{"_loc_sr"},
"Mass.":{"_loc_sr"},
"Massa":{"_cty","_geo","_prprn"},
"Massachuset":{"_anim","_prprn","_sb"},
"Massachusett":{"_anim","_prprn","_sb"},
"Massachusetts":{"_geo","_prprn","_stte"},
"massacred":{"_past"},
"massaged":{"_past"},
"massager":{"_anim","_sb"},
"massasoit":{"_anim","_nme","_prprn","_sb"},
"massed":{"_loc_sr","_past"},
"Massenet":{"_anim","_nme","_prprn","_sb"},
"masseur":{"_anim","_masc","_sb"},
"masseurs":{"_anim","_masc","_sb"},
"masseuses":{"_anim","_fem","_sb"},
"Massey":{"_anim","_nme","_prprn","_sb"},
"massine":{"_anim","_nme","_prprn","_sb"},
"massing":{"_loc_sr"},
"master":{"_anim","_sb"},
"master-at-arms":{"_anim","_sb"},
"master-race":{"_anim","_sb"},
"MasterCard":{"_prprn"},
"mastered":{"_past"},
"masters":{"_anim","_sb"},
"masticate":{"_loc_sr"},
"mastiff":{"_anim"},
"mastodon":{"_anim"},
"mastodons":{"_anim"},
"matabele":{"_prprn"},
"Matamoros":{"_cty","_geo","_prprn"},
"match-up":{"_anim","_sb"},
"match-width":{"_anim","_sb"},
"matched":{"_past"},
"matcher":{"_anim","_sb"},
"matches":{"_anim","_sb"},
"matchmaker":{"_anim","_sb"},
"matchmakers":{"_anim","_sb"},
"matchup":{"_sb"},
"matchups":{"_sb"},
"mated":{"_loc_sr","_past"},
"materfamilias":{"_anim","_fem","_sb"},
"materialist":{"_anim","_sb"},
"materialized":{"_past"},
"mates":{"_anim","_sb"},
"mathematicians":{"_anim","_sb"},
"Mather":{"_anim","_nme","_prprn","_sb"},
"Mathews":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"mathias":{"_anim","_nme","_prprn","_sb"},
"Matilda":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"mating":{"_loc_sr"},
"matisse":{"_anim","_nme","_prprn","_sb"},
"Matlock":{"_prprn"},
"matriculated":{"_loc_sr","_past"},
"matrix":{"_loc_sr"},
"Matsu":{"_geo","_prprn"},
"Matt":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"matted":{"_past"},
"mattered":{"_past","_psych"},
"Matterhorn":{"_geo","_prprn"},
"Matthew":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Matthews":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Matthias":{"_prprn"},
"Maude":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Maugham":{"_anim","_nme","_prprn","_sb"},
"Maui":{"_geo","_prprn"},
"mauldin":{"_anim","_nme","_prprn","_sb"},
"maulers":{"_anim","_sb"},
"Maupassant":{"_anim","_nme","_prprn","_sb"},
"Maureen":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Mauriac":{"_anim","_nme","_prprn","_sb"},
"Maurice":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Mauritania":{"_cntry","_geo","_prprn"},
"Mauritanian":{"_anim","_prprn","_sb"},
"Mauritian":{"_anim","_prprn","_sb"},
"Mauritius":{"_cntry","_geo","_prprn"},
"maurois":{"_anim","_nme","_prprn","_sb"},
"Maury":{"_anim","_fnme","_nme","_prprn","_sb"},
"mauser":{"_anim","_nme","_prprn","_sb"},
"mausoleum":{"_loc_sr"},
"maverick":{"_anim","_sb"},
"mavericks":{"_anim","_sb"},
"Maximilian":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"maximized":{"_past"},
"Maxine":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Maxwell":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Maya":{"_anim","_prprn","_sb"},
"mayakovski":{"_anim","_nme","_prprn","_sb"},
"Mayan":{"_prprn"},
"Mayer":{"_anim","_nme","_prprn","_sb"},
"Mayfair":{"_geo","_prprn"},
"Mayflower":{"_prprn"},
"mayfly":{"_anim"},
"Maynard":{"_prprn"},
"Mayo":{"_anim","_prprn","_sb"},
"mayor":{"_anim","_sb"},
"mayoress":{"_anim","_fem","_sb"},
"mayors":{"_anim","_sb"},
"Mazar-e-Sharif":{"_prprn"},
"mazatlan":{"_cty","_geo","_prprn"},
"mazdaism":{"_prprn"},
"mazed":{"_past"},
"mazzini":{"_anim","_nme","_prprn","_sb"},
"mb":{"_stte"},
"MBA":{"_prprn"},
"Mbabane":{"_cty","_geo","_prprn"},
"Mbeki":{"_prprn"},
"mbundu":{"_anim","_prprn","_sb"},
"Mc":{"_prprn"},
"mcalester":{"_cty","_geo","_prprn"},
"McAllen":{"_cty","_geo","_prprn"},
"McBride":{"_anim","_nme","_prprn","_sb"},
"McCarthy":{"_anim","_nme","_prprn","_sb"},
"McCarthyism":{"_prprn"},
"McCartney":{"_anim","_nme","_prprn","_sb"},
"mccauley":{"_anim","_nme","_prprn","_sb"},
"McClellan":{"_anim","_nme","_prprn","_sb"},
"McConnell":{"_prprn"},
"McCormack":{"_anim","_nme","_prprn","_sb"},
"McCormick":{"_anim","_nme","_prprn","_sb"},
"McCoy":{"_prprn"},
"McCullers":{"_anim","_nme","_prprn","_sb"},
"McDonald":{"_anim","_nme","_prprn","_sb"},
"McEnroe":{"_prprn"},
"mcgraw":{"_anim","_nme","_prprn","_sb"},
"McGregor":{"_prprn"},
"mcguffey":{"_anim","_nme","_prprn","_sb"},
"McGwire":{"_prprn"},
"McIntosh":{"_prprn"},
"McKellen":{"_prprn"},
"McKenna":{"_anim","_nme","_prprn","_sb"},
"McKenzie":{"_anim","_nme","_prprn","_sb"},
"mckim":{"_anim","_nme","_prprn","_sb"},
"McKinley":{"_anim","_nme","_prprn","_sb"},
"McKinnon":{"_prprn"},
"McLuhan":{"_anim","_nme","_prprn","_sb"},
"McMahon":{"_prprn"},
"mcmaster":{"_anim","_nme","_prprn","_sb"},
"McMillan":{"_anim","_nme","_prprn","_sb"},
"McPherson":{"_anim","_nme","_prprn","_sb"},
"Md":{"_prprn","_stte"},
"Md.":{"_prprn","_stte"},
"me":{"_anim","_sb"},
"Mead":{"_anim","_prprn","_sb"},
"meade":{"_anim","_nme","_prprn","_sb"},
"mealtime":{"_tme"},
"mealybug":{"_anim"},
"meanie":{"_sb"},
"meant":{"_past"},
"measured":{"_past"},
"measurer":{"_anim","_sb"},
"meatpacker":{"_anim","_sb"},
"mecca":{"_loc_sr"},
"Meccano":{"_prprn"},
"mechanic":{"_anim","_sb"},
"mechanised":{"_past"},
"mechanized":{"_past"},
"medalist":{"_anim","_sb"},
"medallist":{"_anim","_sb"},
"medan":{"_cty","_geo","_prprn"},
"Medawar":{"_anim","_nme","_prprn","_sb"},
"meddle":{"_loc_sr"},
"meddling":{"_loc_sr"},
"Medea":{"_prprn"},
"Medellin":{"_cty","_geo","_prprn"},
"Medford":{"_cty","_geo","_prprn"},
"Media":{"_geo","_prprn"},
"mediated":{"_past"},
"mediator":{"_anim","_sb"},
"mediators":{"_anim","_sb"},
"Medibank":{"_prprn"},
"medic":{"_anim","_sb"},
"Medicaid":{"_prprn"},
"Medicare":{"_prprn"},
"medico":{"_anim","_sb"},
"medico-military":{"_anim","_sb"},
"medics":{"_anim","_sb"},
"Medina":{"_cty","_geo","_prprn"},
"meditated":{"_past"},
"Mediterranean":{"_geo","_prprn"},
"medoc":{"_geo","_prprn"},
"Medusa":{"_prprn"},
"Medvedev":{"_prprn"},
"meetinghouse":{"_loc_sr"},
"meg":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"megabillion":{"_num","_quant"},
"megacycle":{"_tme"},
"megaera":{"_prprn"},
"Megan":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Mehta":{"_prprn"},
"mei":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Meir":{"_anim","_nme","_prprn","_sb"},
"Meistersinger":{"_prprn","_sb"},
"meitner":{"_anim","_nme","_prprn","_sb"},
"Mekong":{"_geo","_prprn"},
"melanchthon":{"_anim","_nme","_prprn","_sb"},
"Melanesia":{"_geo","_prprn"},
"Melanesian":{"_prprn","_sb"},
"Melanie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"melba":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"melchior":{"_anim","_nme","_prprn","_sb"},
"melchite":{"_prprn"},
"meld":{"_loc_sr"},
"melding":{"_loc_sr"},
"Melinda":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Melissa":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"melkite":{"_prprn","_sb"},
"Mellon":{"_anim","_nme","_prprn","_sb"},
"mellowed":{"_past"},
"melpomene":{"_prprn"},
"Melrose":{"_cty","_geo","_prprn"},
"melted":{"_past"},
"melter":{"_anim","_sb"},
"Melville":{"_anim","_nme","_prprn","_sb"},
"Melvin":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"member":{"_anim","_sb"},
"members":{"_anim","_sb"},
"membership":{"_sb"},
"memberships":{"_sb"},
"Memel":{"_geo","_prprn"},
"memorialist":{"_anim","_sb"},
"memorialized":{"_past"},
"memoriser":{"_anim","_sb"},
"memorize":{"_loc_sr"},
"memorized":{"_loc_sr","_past"},
"memorizer":{"_anim","_sb"},
"Memphis":{"_cty","_geo","_prprn"},
"memsahib":{"_anim","_fem","_sb"},
"men":{"_anim","_masc","_sb"},
"men-folk":{"_anim","_masc","_sb"},
"menaced":{"_past"},
"menage":{"_sb"},
"menagerie":{"_anim"},
"menander":{"_anim","_nme","_prprn","_sb"},
"Mencius":{"_anim","_nme","_prprn","_sb"},
"mencken":{"_anim","_nme","_prprn","_sb"},
"mended":{"_past"},
"Mendel":{"_anim","_nme","_prprn","_sb"},
"mendeleev":{"_anim","_nme","_prprn","_sb"},
"Mendeleyev":{"_prprn"},
"mendelianism":{"_prprn"},
"mendelism":{"_prprn"},
"Mendelssohn":{"_anim","_nme","_prprn","_sb"},
"Menderes":{"_geo","_prprn"},
"Mendes":{"_prprn"},
"mendicant":{"_sb"},
"Mendoza":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Menelaus":{"_prprn"},
"menial":{"_anim","_sb"},
"menninger":{"_anim","_nme","_prprn","_sb"},
"Mennonite":{"_anim","_prprn","_sb"},
"Mennonites":{"_prprn"},
"menominee":{"_anim","_prprn","_sb"},
"menotti":{"_anim","_nme","_prprn","_sb"},
"mensa":{"_prprn"},
"menshevik":{"_prprn","_sb"},
"mention":{"_loc_sr"},
"mentioned":{"_loc_sr","_past"},
"mentioner":{"_anim","_sb"},
"mentioning":{"_loc_sr"},
"Menton":{"_prprn"},
"Mentor":{"_anim","_cty","_geo","_prprn","_sb"},
"mentors":{"_anim","_sb"},
"Menuhin":{"_anim","_nme","_prprn","_sb"},
"Mephistopheles":{"_prprn"},
"mercator":{"_anim","_nme","_prprn","_sb"},
"mercedario":{"_geo","_prprn"},
"mercenaries":{"_anim","_sb"},
"mercenary":{"_anim","_sb"},
"Mercer":{"_anim","_sb"},
"mercerised":{"_past"},
"mercerized":{"_past"},
"merchandised":{"_past"},
"merchandiser":{"_anim","_sb"},
"merchandisers":{"_anim","_sb"},
"merchant":{"_anim","_sb"},
"merchant-banking":{"_anim","_sb"},
"merchant-venturer":{"_anim","_sb"},
"merchants":{"_anim","_sb"},
"Merckx":{"_prprn"},
"Mercosur":{"_prprn"},
"Mercury":{"_anim","_masc","_prprn","_sb"},
"Meredith":{"_anim","_fnme","_nme","_prprn","_sb"},
"merged":{"_past"},
"mergenthaler":{"_anim","_nme","_prprn","_sb"},
"merida":{"_cty","_geo","_prprn"},
"Meriden":{"_cty","_geo","_prprn"},
"meridional":{"_anim","_sb"},
"merino":{"_anim"},
"merited":{"_past"},
"Merkel":{"_prprn"},
"Merleau-Ponty":{"_prprn"},
"Merlin":{"_prprn"},
"mermaid":{"_anim","_fem","_sb"},
"merman":{"_anim","_masc","_sb"},
"merovingian":{"_anim","_nme","_prprn","_sb"},
"Merrimack":{"_cty","_geo","_prprn"},
"merrymaker":{"_anim","_sb"},
"merthiolate":{"_prprn"},
"merton":{"_anim","_nme","_prprn","_sb"},
"Mervin":{"_prprn"},
"Mesa":{"_cty","_geo","_prprn"},
"Mescalero":{"_prprn"},
"mesh":{"_loc_sr"},
"meshed":{"_loc_sr","_past"},
"meshing":{"_loc_sr"},
"mesmer":{"_anim","_nme","_prprn","_sb"},
"mesmerised":{"_past"},
"mesmerist":{"_anim","_sb"},
"mesmerize":{"_psych"},
"mesmerized":{"_past","_psych"},
"mesmerizer":{"_anim","_sb"},
"mesmerizing":{"_psych"},
"mesoamerica":{"_geo","_prprn"},
"mesolithic":{"_prprn"},
"mesomorph":{"_sb"},
"Mesopotamia":{"_geo","_prprn"},
"mesozoic":{"_prprn"},
"messaging":{"_loc_sr"},
"messed":{"_past"},
"messenger":{"_anim","_sb"},
"messengers":{"_anim","_sb"},
"Messerschmitt":{"_prprn"},
"Messiaen":{"_prprn"},
"messiah":{"_anim","_sb"},
"messieurs":{"_anim","_prprn","_sb"},
"Messina":{"_cty","_geo","_prprn"},
"messmate":{"_anim","_sb"},
"Messrs":{"_anim","_masc","_prprn","_sb"},
"mestiza":{"_anim","_fem","_sb"},
"mestizo":{"_anim","_sb"},
"met":{"_past"},
"Meta":{"_geo","_prprn"},
"metabolized":{"_past"},
"metalized":{"_past"},
"metallurgist":{"_anim","_sb"},
"metalworker":{"_anim","_sb"},
"metalworkers":{"_anim","_sb"},
"metamorphose":{"_loc_sr"},
"metamorphosed":{"_loc_sr","_past"},
"metchnikoff":{"_anim","_nme","_prprn","_sb"},
"metchnikov":{"_prprn"},
"meted":{"_past"},
"meteorologist":{"_anim","_sb"},
"meteorologists":{"_anim","_sb"},
"metered":{"_past"},
"methedrine":{"_prprn"},
"Methodism":{"_prprn"},
"Methodist":{"_prprn","_sb"},
"Methuselah":{"_anim","_prprn","_sb"},
"methylated":{"_past"},
"metrify":{"_loc_sr"},
"metropolitan":{"_anim","_loc_sr","_sb"},
"metternich":{"_anim","_nme","_prprn","_sb"},
"Metz":{"_cty","_geo","_prprn"},
"meuse":{"_geo","_prprn"},
"meuse-argonne":{"_geo","_prprn"},
"mewed":{"_past"},
"mews":{"_loc_sr"},
"mexicali":{"_cty","_geo","_prprn"},
"Mexican":{"_anim","_prprn","_sb"},
"mexican-american":{"_anim","_prprn","_sb"},
"Mexicans":{"_anim","_prprn","_sb"},
"Mexico":{"_cntry","_geo","_prprn","_stte"},
"meyerbeer":{"_anim","_nme","_prprn","_sb"},
"meyerhof":{"_anim","_nme","_prprn","_sb"},
"mezzo":{"_anim","_sb"},
"mezzo-rilievo":{"_anim","_sb"},
"mezzo-soprano":{"_anim","_sb"},
"MFA":{"_prprn"},
"MHz":{"_prprn"},
"Miami":{"_anim","_cty","_geo","_loc_sr","_prprn","_sb"},
"miao":{"_prprn"},
"Micah":{"_anim","_fnme","_nme","_prprn","_sb"},
"Micawber":{"_prprn"},
"mice":{"_anim"},
"Mich":{"_prprn","_stte"},
"Mich.":{"_prprn","_stte"},
"Michael":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Michaelmas":{"_prprn"},
"micheas":{"_prprn"},
"Michelangelo":{"_prprn"},
"Michelin":{"_prprn"},
"Michelle":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Michelson":{"_anim","_nme","_prprn","_sb"},
"michener":{"_anim","_nme","_prprn","_sb"},
"Michigan":{"_geo","_prprn","_stte"},
"Michigander":{"_prprn"},
"mick":{"_anim","_sb"},
"Mickey":{"_anim","_fem","_fnme","_masc","_nme","_prprn","_sb"},
"micmac":{"_anim","_prprn","_sb"},
"microbe":{"_anim"},
"microbes":{"_anim"},
"microbiologist":{"_anim","_sb"},
"microcassette":{"_loc_sr"},
"microcosm":{"_sb"},
"microeconomist":{"_anim","_sb"},
"Micronesia":{"_cntry","_geo","_prprn"},
"microorganisms":{"_anim"},
"microscopium":{"_prprn"},
"microseconds":{"_tme"},
"microvan":{"_fem"},
"microwaving":{"_loc_sr"},
"mid":{"_tme"},
"mid-April":{"_anim","_fem","_sb","_tme"},
"mid-calf":{"_anim"},
"mid-century":{"_tme"},
"mid-eighties":{"_num","_quant"},
"mid-February":{"_tme"},
"mid-fifties":{"_num","_quant"},
"mid-forties":{"_num","_quant"},
"mid-January":{"_tme"},
"mid-July":{"_tme"},
"mid-March":{"_loc_sr","_tme"},
"mid-market":{"_loc_sr"},
"mid-morning":{"_tme"},
"mid-nineties":{"_num","_quant"},
"mid-season":{"_tme"},
"mid-section":{"_loc_sr"},
"mid-seventies":{"_num","_quant"},
"mid-sixties":{"_num","_quant"},
"mid-term":{"_tme"},
"mid-thirties":{"_num","_quant"},
"mid-twenties":{"_num","_quant"},
"mid-Victorian":{"_anim","_prprn","_sb"},
"mid-week":{"_tme"},
"midcontinent":{"_loc_sr"},
"middle":{"_loc_sr"},
"middle-age":{"_loc_sr"},
"middle-class":{"_loc_sr"},
"middle-Gaelic":{"_loc_sr"},
"middle-ground":{"_loc_sr"},
"middle-management":{"_loc_sr"},
"middle-market":{"_loc_sr"},
"middle-of-the-roaders":{"_loc_sr"},
"middle-priced":{"_loc_sr"},
"middle-range":{"_loc_sr"},
"middle-school":{"_loc_sr"},
"middleman":{"_anim","_sb"},
"middlemen":{"_anim","_sb"},
"middles":{"_loc_sr"},
"Middlesex":{"_prprn"},
"Middleton":{"_anim","_nme","_prprn","_sb"},
"Middletown":{"_cty","_geo","_prprn"},
"middleweight":{"_anim","_sb"},
"Mideast":{"_geo","_prprn"},
"Mideastern":{"_prprn"},
"midfielder":{"_anim","_sb"},
"midgard":{"_prprn"},
"midge":{"_anim"},
"Midi":{"_geo","_prprn"},
"Midland":{"_cty","_geo","_prprn"},
"Midlands":{"_geo","_prprn"},
"midmonth":{"_tme"},
"midmorning":{"_tme"},
"midnight":{"_tme"},
"midocean":{"_loc_sr"},
"midsession":{"_tme"},
"midshipman":{"_anim","_sb"},
"midshipmen":{"_anim","_sb"},
"midsummer":{"_tme"},
"midsummer-men":{"_tme"},
"midterm":{"_tme"},
"midweek":{"_tme"},
"Midwest":{"_geo","_prprn"},
"Midwestern":{"_prprn"},
"miffed":{"_past","_psych"},
"migrants":{"_anim","_sb"},
"migrate":{"_loc_sr"},
"migrated":{"_loc_sr","_past"},
"migrates":{"_loc_sr"},
"migrating":{"_loc_sr"},
"mikado":{"_anim","_sb"},
"mike":{"_loc_sr"},
"milady":{"_anim","_sb"},
"Milan":{"_cty","_geo","_prprn"},
"Milano":{"_prprn"},
"Mildred":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"miler":{"_anim","_sb"},
"Milford":{"_cty","_geo","_prprn"},
"Milhaud":{"_anim","_nme","_prprn","_sb"},
"militant":{"_anim","_sb"},
"militants":{"_anim","_sb"},
"militarised":{"_past"},
"militarized":{"_past"},
"militia":{"_sb"},
"militiaman":{"_anim","_masc","_sb"},
"militiamen":{"_anim","_masc","_sb"},
"militias":{"_sb"},
"milker":{"_anim","_sb"},
"milkmaid":{"_anim","_fem","_sb"},
"milkman":{"_anim","_masc","_sb"},
"milksop":{"_anim","_masc","_sb"},
"mill":{"_loc_sr"},
"mill-girl":{"_loc_sr"},
"mill-hand":{"_loc_sr"},
"mill-pond":{"_loc_sr"},
"mill-wheel":{"_loc_sr"},
"Millais":{"_anim","_nme","_prprn","_sb"},
"millay":{"_anim","_nme","_prprn","_sb"},
"milled":{"_loc_sr","_past"},
"millenarian":{"_anim","_sb"},
"millenarians":{"_anim","_sb"},
"millenarist":{"_anim","_sb"},
"millepede":{"_anim"},
"miller":{"_anim","_sb"},
"miller's-thumb":{"_anim","_sb"},
"millikan":{"_anim","_nme","_prprn","_sb"},
"milliner":{"_anim","_sb"},
"milling":{"_loc_sr"},
"million":{"_num","_quant"},
"million-and-counting":{"_num","_quant"},
"million-asset":{"_num","_quant"},
"million-common":{"_num","_quant"},
"million-dollar":{"_num","_quant"},
"million-dollar-plus":{"_num","_quant"},
"million-franc":{"_num","_quant"},
"million-gallon":{"_num","_quant"},
"million-mark":{"_num","_quant"},
"million-member":{"_num","_quant"},
"million-member-Teamsters":{"_num","_quant"},
"million-plus":{"_num","_quant"},
"million-pound":{"_num","_quant"},
"million-share":{"_num","_quant"},
"million-square-foot":{"_num","_quant"},
"million-ton":{"_num","_quant"},
"million-unit":{"_num","_quant"},
"millionaire":{"_anim","_sb"},
"millionaires":{"_anim","_sb"},
"millions":{"_num","_quant"},
"millipede":{"_anim"},
"millpond":{"_loc_sr"},
"millrace":{"_loc_sr"},
"mills":{"_loc_sr"},
"millwright":{"_anim","_sb"},
"Milne":{"_anim","_nme","_prprn","_sb"},
"milquetoast":{"_anim","_sb"},
"Milstein":{"_anim","_nme","_prprn","_sb"},
"Miltiades":{"_anim","_nme","_prprn","_sb"},
"Milton":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"Milwaukee":{"_cty","_geo","_prprn"},
"mime":{"_anim","_sb"},
"mimer":{"_anim","_sb"},
"mimic":{"_loc_sr"},
"mimicked":{"_loc_sr","_past"},
"mimicker":{"_anim","_sb"},
"mimicking":{"_loc_sr"},
"mimics":{"_anim","_sb"},
"mimir":{"_prprn"},
"mince":{"_loc_sr"},
"minced":{"_loc_sr","_past"},
"mindanao":{"_geo","_prprn"},
"minded":{"_past"},
"minden":{"_cty","_geo","_prprn"},
"mindoro":{"_geo","_prprn"},
"mined":{"_loc_sr","_past"},
"minefield":{"_loc_sr"},
"minefields":{"_loc_sr"},
"mineralized":{"_past"},
"mineralogist":{"_anim","_sb"},
"miners":{"_anim","_sb"},
"Minerva":{"_anim","_fem","_nme","_prprn","_sb"},
"mineworker":{"_anim","_sb"},
"mineworkers":{"_anim","_sb"},
"ming":{"_anim","_nme","_prprn","_sb"},
"mingle":{"_loc_sr"},
"mingle-mangle":{"_loc_sr"},
"mingled":{"_loc_sr","_past"},
"mingles":{"_loc_sr"},
"mingling":{"_loc_sr"},
"Mingus":{"_prprn"},
"mini-mill":{"_loc_sr"},
"miniaturise":{"_loc_sr"},
"miniaturist":{"_anim","_sb"},
"miniaturize":{"_loc_sr"},
"miniaturized":{"_loc_sr","_past"},
"minicamp":{"_anim","_loc_sr"},
"minimalist":{"_anim","_sb"},
"mining":{"_loc_sr"},
"minion":{"_anim","_sb"},
"minions":{"_anim","_sb"},
"ministers":{"_anim","_sb"},
"ministrant":{"_anim","_sb"},
"mink":{"_anim"},
"Minn":{"_prprn","_stte"},
"Minn.":{"_prprn","_stte"},
"Minna":{"_prprn"},
"Minneapolis":{"_cty","_geo","_prprn"},
"Minnelli":{"_prprn"},
"Minnesota":{"_geo","_prprn","_stte"},
"minnewit":{"_anim","_nme","_prprn","_sb"},
"minnow":{"_anim"},
"minoan":{"_anim","_prprn","_sb"},
"minor":{"_loc_sr"},
"minor-leaguer":{"_sb"},
"minor-sport":{"_anim","_sb"},
"minors":{"_anim","_sb"},
"Minos":{"_prprn"},
"Minotaur":{"_prprn","_sb"},
"Minsk":{"_cty","_geo","_prprn"},
"minstrel":{"_anim","_sb"},
"minstrels":{"_anim","_sb"},
"mint":{"_loc_sr"},
"mint-scented":{"_loc_sr"},
"minted":{"_past"},
"mints":{"_loc_sr"},
"minuit":{"_anim","_nme","_prprn","_sb"},
"minuteman":{"_anim","_sb"},
"Minutemen":{"_anim","_sb"},
"minutes":{"_tme"},
"minx":{"_anim","_sb"},
"miocene":{"_prprn"},
"mips":{"_prprn"},
"mirabeau":{"_anim","_nme","_prprn","_sb"},
"Miraflores":{"_prprn"},
"Miranda":{"_prprn"},
"mired":{"_past"},
"Miriam":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"misalign":{"_loc_sr"},
"misallocated":{"_past"},
"misapplied":{"_past"},
"misappropriated":{"_past"},
"misbegot":{"_past"},
"misbegotten":{"_anim","_sb"},
"misbelieve":{"_loc_sr"},
"misbeliever":{"_anim","_sb"},
"misbranded":{"_past"},
"miscalculated":{"_past"},
"miscarried":{"_past"},
"miscast":{"_loc_sr","_past"},
"mischarged":{"_loc_sr","_past"},
"mischarging":{"_loc_sr"},
"mischief-maker":{"_anim","_sb"},
"misclassified":{"_past"},
"misconstrued":{"_past"},
"miscreant":{"_anim","_sb"},
"miscreants":{"_anim","_sb"},
"misdemean":{"_loc_sr","_psych"},
"misdemeanants":{"_anim","_sb"},
"misdirectors":{"_anim","_sb"},
"miser":{"_anim","_sb"},
"misfired":{"_past"},
"misfit":{"_anim","_sb"},
"misfits":{"_anim","_sb"},
"misfortunate":{"_anim","_sb"},
"misgauged":{"_past"},
"misguide":{"_loc_sr"},
"misguided":{"_loc_sr","_past"},
"mishna":{"_prprn"},
"misinform":{"_loc_sr"},
"misinterpret":{"_loc_sr"},
"misinterpreted":{"_loc_sr","_past"},
"misinterpreters":{"_anim","_sb"},
"misjudged":{"_past"},
"mislabeled":{"_past"},
"mislaid":{"_loc_sr","_past"},
"mislay":{"_loc_sr"},
"misleader":{"_anim","_sb"},
"misleading":{"_loc_sr"},
"misleads":{"_loc_sr"},
"misled":{"_loc_sr","_past"},
"mismarry":{"_loc_sr"},
"mismatched":{"_past"},
"mismated":{"_past"},
"misnamed":{"_past"},
"misogamist":{"_anim","_sb"},
"misogynist":{"_anim","_sb"},
"misplace":{"_loc_sr"},
"misplaced":{"_loc_sr","_past"},
"misplacing":{"_loc_sr"},
"mispriced":{"_past"},
"misprint":{"_loc_sr"},
"misquoted":{"_past"},
"misread":{"_past"},
"misrelated":{"_past"},
"misrepresented":{"_past"},
"misrouted":{"_past"},
"missed":{"_past"},
"mission":{"_anim","_sb"},
"missionaries":{"_anim","_sb"},
"missionary":{"_anim","_sb"},
"missions":{"_anim","_sb"},
"Mississippi":{"_geo","_prprn","_stte"},
"Mississippian":{"_anim","_prprn","_sb"},
"missoula":{"_cty","_geo","_prprn"},
"Missouri":{"_anim","_geo","_prprn","_sb","_stte"},
"misspelled":{"_past"},
"misspent":{"_past"},
"misstated":{"_past"},
"missus":{"_anim","_fem","_sb"},
"missy":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"mist":{"_loc_sr"},
"mist-flower":{"_loc_sr"},
"mist-like":{"_loc_sr"},
"Mister":{"_anim","_prprn","_sb"},
"mistook":{"_past"},
"mistreated":{"_past"},
"mistress":{"_anim","_fem","_sb"},
"mistresses":{"_anim","_fem","_sb"},
"mistrusted":{"_past"},
"mists":{"_loc_sr"},
"misunderstanders":{"_anim","_sb"},
"misused":{"_past"},
"MIT":{"_prprn"},
"Mitchell":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"mite-box":{"_anim","_sb"},
"mithraism":{"_prprn"},
"mithraist":{"_prprn"},
"Mithras":{"_anim","_masc","_nme","_prprn","_sb"},
"mitigate":{"_loc_sr"},
"mitigated":{"_loc_sr","_past"},
"mitigates":{"_loc_sr"},
"mitigating":{"_loc_sr"},
"Mitropoulos":{"_anim","_nme","_prprn","_sb"},
"Mitterrand":{"_anim","_nme","_prprn","_sb"},
"mitzvah":{"_anim","_sb"},
"miwok":{"_anim","_prprn","_sb"},
"mix":{"_loc_sr"},
"mixed":{"_loc_sr","_past"},
"mixed-blood":{"_loc_sr","_past"},
"mixing":{"_loc_sr"},
"mixologist":{"_anim","_sb"},
"mixologists":{"_anim","_sb"},
"Miyazaki":{"_cty","_geo","_prprn"},
"mizzle":{"_loc_sr","_wthr"},
"Mladic":{"_prprn"},
"MLitt":{"_prprn"},
"Mlle":{"_anim","_fem","_prprn","_sb"},
"Mme":{"_prprn"},
"Mmes":{"_prprn"},
"mmpi":{"_prprn"},
"MN":{"_prprn","_stte"},
"Mnemosyne":{"_anim","_fem","_nme","_prprn","_sb"},
"Mo.":{"_prprn","_stte","_tme"},
"moa":{"_anim"},
"moaned":{"_past"},
"moated":{"_past"},
"mob":{"_anim"},
"mobilized":{"_past"},
"mobs":{"_anim"},
"mobster":{"_anim","_sb"},
"Mobutu":{"_prprn"},
"mocked":{"_past"},
"modeled":{"_loc_sr","_past"},
"modeler":{"_anim","_sb"},
"modeling":{"_loc_sr"},
"modeller":{"_anim","_sb"},
"moderate-rehabilitation":{"_anim","_sb"},
"moderate-size":{"_anim","_sb"},
"moderate-sized":{"_anim","_sb"},
"moderated":{"_past"},
"moderates":{"_anim","_sb"},
"moderationist":{"_anim","_sb"},
"moderator":{"_anim","_sb"},
"modern":{"_anim","_sb"},
"modern-dance":{"_anim","_sb"},
"modern-day":{"_anim","_sb"},
"modernised":{"_past"},
"moderns":{"_anim","_sb"},
"Modesto":{"_cty","_geo","_prprn"},
"modified":{"_loc_sr","_past"},
"modifies":{"_loc_sr"},
"modify":{"_loc_sr"},
"modifying":{"_loc_sr"},
"Modigliani":{"_anim","_nme","_prprn","_sb"},
"modiste":{"_anim","_sb"},
"modulated":{"_past"},
"Mogadiscio":{"_prprn"},
"Mogadishu":{"_cty","_geo","_prprn"},
"mogul":{"_anim","_sb"},
"moguls":{"_anim","_sb"},
"mohammad":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Mohammed":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Mohammedan":{"_prprn"},
"Mohammedanism":{"_prprn"},
"moharram":{"_prprn"},
"mohave":{"_anim","_prprn","_sb"},
"Mohawk":{"_anim","_prprn","_sb"},
"Mohican":{"_prprn"},
"moho":{"_prprn"},
"Moira":{"_prprn"},
"moistened":{"_past"},
"moistener":{"_anim","_sb"},
"moisture":{"_loc_sr"},
"mojave":{"_anim","_prprn","_sb"},
"moke":{"_anim","_sb"},
"Moldavia":{"_cntry","_geo","_prprn"},
"molded":{"_past"},
"Moldova":{"_cntry","_geo","_prprn"},
"molested":{"_past"},
"molester":{"_anim","_sb"},
"Molina":{"_prprn"},
"moline":{"_cty","_geo","_prprn"},
"molise":{"_geo","_prprn","_stte"},
"moll":{"_anim","_fem","_sb"},
"mollified":{"_loc_sr","_past","_psych"},
"mollify":{"_loc_sr","_psych"},
"mollusc":{"_anim"},
"mollycoddler":{"_anim","_sb"},
"molnar":{"_anim","_nme","_prprn","_sb"},
"molokai":{"_geo","_prprn"},
"Molotov":{"_anim","_nme","_prprn","_sb"},
"molter":{"_anim","_sb"},
"moluccas":{"_geo","_prprn"},
"mom":{"_anim","_fem","_sb"},
"mombasa":{"_cty","_geo","_prprn"},
"moment":{"_tme"},
"momentarily":{"_tme"},
"momently":{"_tme"},
"moments":{"_tme"},
"momma":{"_anim","_fem","_sb"},
"mommsen":{"_anim","_nme","_prprn","_sb"},
"mommy":{"_anim","_fem","_sb"},
"moms":{"_anim","_fem","_sb"},
"Momus":{"_anim","_masc","_nme","_prprn","_sb"},
"Mon":{"_anim","_day","_prprn","_sb","_tme"},
"Mon-Khmer":{"_prprn"},
"Mon.":{"_anim","_day","_prprn","_sb","_tme"},
"Mona":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"monacan":{"_anim","_prprn","_sb"},
"Monaco":{"_cntry","_geo","_prprn"},
"monaco-ville":{"_cntry","_geo","_prprn"},
"monarchists":{"_sb"},
"monas":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"monasteries":{"_loc_sr"},
"Mondale":{"_anim","_nme","_prprn","_sb"},
"Monday":{"_day","_prprn","_tme"},
"Mondays":{"_day","_prprn","_tme"},
"Mondrian":{"_anim","_nme","_prprn","_sb"},
"monegasque":{"_anim","_prprn","_sb"},
"moneran":{"_sb"},
"monetarist":{"_anim","_sb"},
"monetarists":{"_anim","_sb"},
"moneygrubber":{"_anim","_sb"},
"moneylender":{"_anim","_sb"},
"moneymakers":{"_anim","_sb"},
"Mongol":{"_anim","_prprn","_sb"},
"Mongolia":{"_cntry","_geo","_prprn"},
"Mongoloid":{"_prprn","_sb"},
"mongoose":{"_anim"},
"mongrel":{"_anim"},
"Monica":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"monitored":{"_past"},
"monitors":{"_anim","_sb"},
"monk":{"_anim","_masc","_sb"},
"monkey-gland":{"_anim","_sb"},
"monkey-wrench":{"_anim","_sb"},
"monkeys":{"_anim","_sb"},
"Monmouth":{"_anim","_nme","_prprn","_sb"},
"monnet":{"_anim","_nme","_prprn","_sb"},
"monochromat":{"_anim","_sb"},
"monod":{"_anim","_nme","_prprn","_sb"},
"monogamist":{"_anim","_sb"},
"monogrammed":{"_past"},
"monogynist":{"_anim","_sb"},
"monomaniac":{"_anim","_sb"},
"monophysite":{"_prprn"},
"monopoliser":{"_anim","_sb"},
"monopolist":{"_anim","_sb"},
"monopolists":{"_anim","_sb"},
"monopolized":{"_past"},
"monopolizer":{"_anim","_sb"},
"monotreme":{"_sb"},
"monotype":{"_sb"},
"Monroe":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Monrovia":{"_cty","_geo","_prprn"},
"Mons":{"_cty","_geo","_prprn"},
"monsignor":{"_anim","_masc","_sb"},
"monster":{"_anim"},
"monsters":{"_anim"},
"monstrance":{"_loc_sr"},
"Mont":{"_prprn","_stte"},
"Mont.":{"_prprn","_stte"},
"montagu":{"_anim","_nme","_prprn","_sb"},
"Montaigne":{"_anim","_nme","_prprn","_sb"},
"Montana":{"_geo","_prprn","_stte"},
"Montenegrin":{"_prprn"},
"Montenegro":{"_cntry","_geo","_prprn"},
"monterey":{"_cty","_geo","_prprn"},
"Monterrey":{"_cty","_geo","_prprn"},
"montesquieu":{"_anim","_nme","_prprn","_sb"},
"Montessori":{"_anim","_nme","_prprn","_sb"},
"Monteverdi":{"_anim","_nme","_prprn","_sb"},
"Montevideo":{"_cty","_geo","_prprn"},
"montez":{"_anim","_nme","_prprn","_sb"},
"montfort":{"_anim","_nme","_prprn","_sb"},
"montgolfier":{"_anim","_nme","_prprn","_sb"},
"Montgomery":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"month":{"_tme"},
"month-earlier":{"_tme"},
"month-end":{"_tme"},
"month-long":{"_tme"},
"month-old":{"_tme"},
"months":{"_tme"},
"months-long":{"_tme"},
"Monticello":{"_geo","_prprn","_stte"},
"Montmartre":{"_geo","_loc_sr","_prprn"},
"Montpelier":{"_cty","_geo","_prprn"},
"Montrachet":{"_prprn"},
"Montreal":{"_cty","_geo","_prprn"},
"Montreux":{"_prprn"},
"Montrose":{"_anim","_nme","_prprn","_sb"},
"Montserrat":{"_geo","_prprn"},
"monument":{"_loc_sr"},
"monuments":{"_loc_sr"},
"moocher":{"_anim","_sb"},
"mooed":{"_past"},
"Moog":{"_prprn"},
"moonfish":{"_anim"},
"Moonie":{"_prprn"},
"moonlighter":{"_anim","_sb"},
"moonshiner":{"_anim","_sb"},
"moonwalk":{"_loc_sr"},
"moor-bird":{"_loc_sr"},
"moored":{"_past"},
"moorfowl":{"_anim"},
"moorhen":{"_anim"},
"moorings":{"_loc_sr"},
"moors":{"_loc_sr"},
"moose":{"_anim"},
"moose-wood":{"_anim"},
"mopes":{"_anim","_sb"},
"mopped":{"_past"},
"mopper":{"_anim","_sb"},
"moppet":{"_anim","_sb"},
"mor":{"_prprn"},
"moralist":{"_anim","_sb"},
"moralize":{"_loc_sr"},
"moralizers":{"_anim","_sb"},
"moralizing":{"_loc_sr"},
"moravia":{"_anim","_geo","_nme","_prprn","_sb","_stte"},
"moravian":{"_anim","_prprn","_sb"},
"more":{"_quant"},
"more-active":{"_quant"},
"more-advanced":{"_quant"},
"more-affordable":{"_quant"},
"more-attractive":{"_quant"},
"more-conventional":{"_quant"},
"more-discriminating":{"_quant"},
"more-distinctive":{"_quant"},
"more-efficient":{"_quant"},
"more-entrenched":{"_quant"},
"more-established":{"_quant"},
"more-favored":{"_quant"},
"more-general":{"_quant"},
"more-generic":{"_quant"},
"more-hazardous":{"_quant"},
"more-informed":{"_quant"},
"more-level":{"_quant"},
"more-mainstream":{"_quant"},
"more-mundane":{"_quant"},
"more-muscular":{"_quant"},
"more-natural":{"_quant"},
"more-open":{"_quant"},
"more-or-less":{"_quant"},
"more-personal":{"_quant"},
"more-powerful":{"_quant"},
"more-pressing":{"_quant"},
"more-realistic":{"_quant"},
"more-selective":{"_quant"},
"more-sophisticated":{"_quant"},
"more-spontaneous":{"_quant"},
"more-stringent":{"_quant"},
"more-than-average":{"_quant"},
"more-than-ordinary":{"_quant"},
"more-than-terrible":{"_quant"},
"Moreau":{"_prprn"},
"moresque":{"_prprn"},
"Morgan":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"morgantown":{"_cty","_geo","_prprn"},
"morgen":{"_loc_sr"},
"Morgenthau":{"_anim","_nme","_prprn","_sb"},
"morgue":{"_loc_sr"},
"Morison":{"_anim","_nme","_prprn","_sb"},
"Morley":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Mormon":{"_anim","_prprn","_sb"},
"Mormonism":{"_prprn"},
"Mormons":{"_anim","_prprn","_sb"},
"morning":{"_tme"},
"morning-frightened":{"_tme"},
"morning-glory":{"_tme"},
"morning-session":{"_tme"},
"mornings":{"_tme"},
"Moro":{"_prprn","_sb"},
"Moroccan":{"_anim","_prprn","_sb"},
"Morocco":{"_cntry","_geo","_prprn"},
"moron":{"_anim","_sb"},
"Morpheus":{"_anim","_masc","_nme","_prprn","_sb"},
"Morris":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Morrison":{"_anim","_nme","_prprn","_sb"},
"morristown":{"_cty","_geo","_prprn"},
"mors":{"_geo","_prprn"},
"Morse":{"_anim","_nme","_prprn","_sb"},
"mortals":{"_anim","_sb"},
"mortar":{"_loc_sr"},
"mortars":{"_loc_sr"},
"mortgaged":{"_past"},
"mortgaged-backed":{"_past"},
"mortgagee":{"_anim","_sb"},
"mortgagor":{"_anim","_sb"},
"mortician":{"_anim","_sb"},
"morticians":{"_anim","_sb"},
"mortified":{"_past","_psych"},
"mortify":{"_psych"},
"mortifying":{"_psych"},
"mortimer":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Morton":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Moscow":{"_cty","_geo","_prprn"},
"Moseley":{"_anim","_nme","_prprn","_sb"},
"Moselle":{"_geo","_prprn"},
"Moses":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"mosey":{"_loc_sr"},
"Moslem":{"_prprn"},
"Mosley":{"_anim","_nme","_prprn","_sb"},
"mosque":{"_loc_sr"},
"mosques":{"_loc_sr"},
"mosquito":{"_anim"},
"mosquito-plagued":{"_anim"},
"mossbauer":{"_anim","_nme","_prprn","_sb"},
"most":{"_quant"},
"most-actives":{"_quant"},
"most-admired":{"_quant"},
"most-dangerous":{"_quant"},
"most-hazardous":{"_quant"},
"most-indebted":{"_quant"},
"most-influential":{"_quant"},
"most-jingoistic":{"_quant"},
"most-likely":{"_quant"},
"most-likely-successor":{"_quant"},
"most-livable":{"_quant"},
"most-obvious":{"_quant"},
"most-owned":{"_quant"},
"most-polluted":{"_quant"},
"most-prestigious":{"_quant"},
"most-recent":{"_quant"},
"most-recommended":{"_quant"},
"most-recommended-issues":{"_quant"},
"most-respected":{"_quant"},
"most-sold":{"_quant"},
"most-strident":{"_quant"},
"most-used":{"_quant"},
"most-valuable-player":{"_quant"},
"most-watched":{"_quant"},
"mosul":{"_cty","_geo","_prprn"},
"moth":{"_anim"},
"moth-like":{"_anim"},
"moth-resistant":{"_anim"},
"mothballing":{"_loc_sr"},
"mother":{"_anim","_fem","_sb"},
"mother-introject":{"_anim","_fem","_sb"},
"mother-of-thousands":{"_anim","_fem","_sb"},
"mother-only":{"_anim","_fem","_sb"},
"mothered":{"_past"},
"motherfucker":{"_anim","_sb"},
"mothers":{"_anim","_fem","_sb"},
"mothers-in-law":{"_anim","_fem","_sb"},
"motherwell":{"_anim","_nme","_prprn","_sb"},
"moths":{"_anim"},
"motioned":{"_past"},
"motivate":{"_loc_sr","_psych"},
"motivating":{"_loc_sr","_psych"},
"motivator":{"_anim","_sb"},
"Motley":{"_anim","_prprn","_sb"},
"motorcycled":{"_past"},
"motorcyclist":{"_anim","_sb"},
"motored":{"_loc_sr","_past"},
"motoring":{"_loc_sr"},
"motorised":{"_past"},
"motorists":{"_anim","_sb"},
"motorized":{"_past"},
"motorman":{"_anim","_sb"},
"Motown":{"_prprn"},
"Mott":{"_anim","_prprn","_sb"},
"mottled":{"_past"},
"mouflon":{"_anim"},
"mould":{"_loc_sr"},
"moulmein":{"_cty","_geo","_prprn"},
"moulter":{"_anim","_sb"},
"mound":{"_loc_sr"},
"mound-bird":{"_loc_sr"},
"mounded":{"_past"},
"mounds":{"_loc_sr"},
"mount":{"_loc_sr"},
"Mountain":{"_loc_sr"},
"mountain-bike":{"_loc_sr"},
"mountaineers":{"_anim","_loc_sr","_sb"},
"mountains":{"_loc_sr"},
"mounted":{"_loc_sr","_past"},
"mounter":{"_anim","_sb"},
"mountie":{"_prprn","_sb"},
"mounties":{"_prprn","_sb"},
"mounting":{"_loc_sr"},
"mourned":{"_past"},
"mourner":{"_anim","_sb"},
"mourners":{"_anim","_sb"},
"mouse":{"_anim"},
"mouse-colored":{"_anim"},
"mouse-eared":{"_anim"},
"mouse-sized":{"_anim"},
"mouser":{"_anim"},
"Moussorgsky":{"_prprn"},
"mouthed":{"_past"},
"move":{"_loc_sr"},
"moved":{"_loc_sr","_past"},
"mover":{"_anim","_sb"},
"movers":{"_anim","_sb"},
"moviegoers":{"_anim","_sb"},
"moviemakers":{"_anim","_sb"},
"mowed":{"_past"},
"Mozambican":{"_anim","_prprn","_sb"},
"Mozambiquans":{"_prprn"},
"Mozambique":{"_cntry","_geo","_prprn"},
"Mozart":{"_anim","_nme","_prprn","_sb"},
"MP":{"_anim","_prprn","_sb"},
"mr":{"_anim","_masc","_prprn","_sb"},
"mr.":{"_anim","_masc","_prprn","_sb"},
"mri":{"_prprn"},
"mrna":{"_prprn"},
"Mrs":{"_anim","_fem","_prprn","_sb"},
"Mrs.":{"_anim","_fem","_prprn","_sb"},
"Ms":{"_anim","_fem","_prprn","_sb"},
"ms-dos":{"_prprn"},
"Ms.":{"_anim","_fem","_prprn","_sb"},
"MSc":{"_prprn"},
"msh":{"_prprn"},
"mst":{"_prprn"},
"Mt":{"_prprn"},
"Mt.":{"_prprn"},
"mubarak":{"_anim","_nme","_prprn","_sb"},
"much":{"_quant"},
"much-abused":{"_quant"},
"much-anticipated":{"_quant"},
"much-awaited":{"_quant"},
"much-beloved":{"_quant"},
"much-copied":{"_quant"},
"much-coveted":{"_quant"},
"much-craved":{"_quant"},
"much-criticized":{"_quant"},
"much-delayed":{"_quant"},
"much-despised":{"_quant"},
"much-discussed":{"_quant"},
"much-heralded":{"_quant"},
"much-larger":{"_quant"},
"much-lauded":{"_quant"},
"much-needed":{"_quant"},
"much-publicized":{"_quant"},
"much-respected":{"_quant"},
"much-revised":{"_quant"},
"much-smaller":{"_quant"},
"much-thumbed":{"_quant"},
"much-watched":{"_quant"},
"mucker":{"_anim","_sb"},
"muckrake":{"_loc_sr"},
"muckraker":{"_anim","_sb"},
"muckraking":{"_loc_sr"},
"mud":{"_loc_sr"},
"mud-brick":{"_loc_sr"},
"mud-caked":{"_loc_sr"},
"mud-logger":{"_loc_sr"},
"mud-sweat-and-tears":{"_loc_sr"},
"mud-wrestle":{"_loc_sr"},
"muddle":{"_loc_sr","_psych"},
"muddled":{"_loc_sr","_past","_psych"},
"muddling":{"_loc_sr","_psych"},
"mudslinger":{"_anim","_sb"},
"muezzin":{"_anim","_sb"},
"muffed":{"_past"},
"muffled":{"_past"},
"mufti":{"_anim","_sb"},
"mug":{"_loc_sr"},
"mug.":{"_loc_sr"},
"Mugabe":{"_anim","_nme","_prprn","_sb"},
"mugged":{"_past"},
"mugger":{"_anim","_sb"},
"muggers":{"_anim","_sb"},
"muggins":{"_anim","_sb"},
"mugs":{"_loc_sr"},
"mugwump":{"_anim","_sb"},
"Muhammad":{"_anim","_nme","_prprn","_sb"},
"Muhammadan":{"_prprn"},
"Muhammadanism":{"_prprn"},
"muharram":{"_prprn"},
"muharrum":{"_prprn"},
"Muir":{"_anim","_nme","_prprn","_sb"},
"mujahedeen":{"_anim","_sb"},
"mujahideen":{"_anim","_sb"},
"mujahidin":{"_anim","_sb"},
"mukden":{"_geo","_prprn"},
"mulatto":{"_anim","_sb"},
"Muldoon":{"_anim","_nme","_prprn","_sb"},
"mule":{"_anim"},
"mule-drawn":{"_anim"},
"mules":{"_anim"},
"muleteer":{"_anim","_sb"},
"Mulhouse":{"_cty","_geo","_prprn"},
"muliebrity":{"_sb"},
"Muller":{"_anim","_prprn","_sb"},
"mullet":{"_anim"},
"mullets":{"_anim"},
"mulls":{"_loc_sr"},
"Mulroney":{"_anim","_nme","_prprn","_sb"},
"multi-billionaire":{"_anim","_sb"},
"multi-coloured":{"_sb"},
"multi-ethnic":{"_anim","_sb"},
"multi-million":{"_num","_quant"},
"multi-phase":{"_tme"},
"multi-state":{"_loc_sr"},
"multi-year":{"_tme"},
"multibank":{"_loc_sr"},
"multibillion":{"_num","_quant"},
"multicoloured":{"_sb"},
"multilocation":{"_loc_sr"},
"multimillion":{"_num","_quant"},
"multimillionaire":{"_anim","_sb"},
"multimillions":{"_num","_quant"},
"multipartisan":{"_anim","_sb"},
"multiphase":{"_tme"},
"multiple":{"_quant"},
"multiple-column":{"_quant"},
"multiple-paged":{"_quant"},
"multiple-purpose":{"_quant"},
"multiple-state":{"_quant"},
"multiple-use":{"_quant"},
"multiple-year":{"_quant"},
"multiples":{"_quant"},
"multiplex":{"_loc_sr"},
"multiplexers":{"_anim","_sb"},
"multiplexing":{"_loc_sr"},
"multiplied":{"_past"},
"multivariate":{"_loc_sr"},
"mum":{"_loc_sr"},
"mumbled":{"_past"},
"mumbler":{"_anim","_sb"},
"Mumford":{"_anim","_nme","_prprn","_sb"},
"mummer":{"_anim","_sb"},
"mummies":{"_sb"},
"mummified":{"_loc_sr","_past"},
"mummify":{"_loc_sr"},
"mummy":{"_sb"},
"mummy-brown":{"_sb"},
"Munchausen":{"_prprn"},
"munched":{"_past"},
"muncher":{"_anim","_sb"},
"munchhausen":{"_anim","_nme","_prprn","_sb"},
"munchkin":{"_sb"},
"Muncie":{"_cty","_geo","_prprn"},
"Munich":{"_cty","_geo","_prprn"},
"municipalities":{"_loc_sr"},
"Munro":{"_anim","_nme","_prprn","_sb"},
"Munster":{"_cty","_geo","_prprn","_stte"},
"Murat":{"_anim","_nme","_prprn","_sb"},
"murdered":{"_loc_sr","_past"},
"murderee":{"_anim","_sb"},
"murderer":{"_anim","_sb"},
"murderers":{"_anim","_sb"},
"murdering":{"_loc_sr"},
"Murdoch":{"_anim","_nme","_prprn","_sb"},
"Murfreesboro":{"_cty","_geo","_prprn"},
"Muriel":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"murillo":{"_anim","_nme","_prprn","_sb"},
"murmansk":{"_cty","_geo","_prprn"},
"murmured":{"_past"},
"murmurer":{"_anim","_sb"},
"Murphy":{"_anim","_prprn"},
"murray":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Murrow":{"_anim","_nme","_prprn","_sb"},
"murrumbidgee":{"_geo","_prprn"},
"Musca":{"_prprn"},
"muscadet":{"_prprn"},
"Muscat":{"_cty","_geo","_prprn"},
"muscled":{"_past"},
"muscleman":{"_anim","_masc","_sb"},
"musclemen":{"_anim","_masc","_sb"},
"Muscovite":{"_prprn"},
"muscovy":{"_geo","_prprn"},
"Muse":{"_loc_sr"},
"mused":{"_loc_sr","_past"},
"muser":{"_anim","_sb"},
"Muses":{"_anim","_sb"},
"museum":{"_loc_sr"},
"museums":{"_loc_sr"},
"Musharraf":{"_prprn"},
"musher":{"_anim","_sb"},
"mushroom":{"_loc_sr"},
"mushroomed":{"_loc_sr","_past"},
"mushrooming":{"_loc_sr"},
"musial":{"_anim","_nme","_prprn","_sb"},
"musician":{"_anim","_sb"},
"musicians":{"_anim","_sb"},
"musicologist":{"_anim","_sb"},
"musicologists":{"_anim","_sb"},
"Musil":{"_prprn"},
"musing":{"_loc_sr"},
"muskellunge":{"_anim","_sb"},
"musketeer":{"_anim","_sb"},
"muskhogean":{"_prprn"},
"muskogean":{"_prprn"},
"muskogee":{"_cty","_geo","_prprn"},
"muskrat":{"_anim"},
"Muslim":{"_prprn","_sb"},
"Muslims":{"_prprn","_sb"},
"musquash":{"_anim"},
"mussel":{"_anim","_sb"},
"mussels":{"_anim","_sb"},
"musset":{"_anim","_nme","_prprn","_sb"},
"Mussolini":{"_anim","_nme","_prprn","_sb"},
"Mussorgsky":{"_anim","_nme","_prprn","_sb"},
"mustang":{"_anim"},
"mustered":{"_past"},
"mutant":{"_anim","_sb"},
"mutated":{"_past"},
"muted":{"_past"},
"mutilated":{"_past"},
"mutilator":{"_anim","_sb"},
"mutsuhito":{"_anim","_nme","_prprn","_sb"},
"mutt":{"_anim","_sb"},
"mutter":{"_loc_sr"},
"muttered":{"_loc_sr","_past"},
"muttering":{"_loc_sr"},
"muttonfish":{"_anim","_loc_sr"},
"muttonhead":{"_anim","_sb"},
"mutts":{"_anim","_sb"},
"mutualist":{"_anim","_sb"},
"Muybridge":{"_anim","_nme","_prprn","_sb"},
"Muzak":{"_prprn"},
"muztag":{"_geo","_prprn"},
"muztagh":{"_geo","_prprn"},
"muzzler":{"_anim","_sb"},
"muzzling":{"_loc_sr"},
"MVP":{"_prprn"},
"Myanmar":{"_cntry","_geo","_prprn"},
"Mycenae":{"_cty","_geo","_prprn"},
"Mycenaean":{"_anim","_prprn","_sb"},
"mycologist":{"_anim","_sb"},
"mycophagist":{"_anim","_sb"},
"Myers":{"_anim","_nme","_prprn","_sb"},
"mylar":{"_prprn"},
"mynah":{"_anim"},
"myope":{"_anim","_sb"},
"Myra":{"_cty","_geo","_prprn"},
"myrdal":{"_anim","_nme","_prprn","_sb"},
"myself":{"_anim","_sb","_self"},
"Myron":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"mystic":{"_anim","_sb"},
"mystics":{"_anim","_sb"},
"mystified":{"_past","_psych"},
"mystifier":{"_anim","_sb"},
"mystify":{"_psych"},
"mystifying":{"_psych"},
"mythicize":{"_loc_sr"},
"mythologist":{"_anim","_sb"},
"mythologize":{"_loc_sr"},
"na":{"_prprn"},
"na-dene":{"_prprn"},
"nabbed":{"_past"},
"Nablus":{"_cty","_geo","_prprn"},
"nabob":{"_anim","_masc","_sb"},
"Nabokov":{"_anim","_nme","_prprn","_sb"},
"nad":{"_prprn"},
"Nader":{"_anim","_nme","_prprn","_sb"},
"Nadine":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"nadp":{"_prprn"},
"nafud":{"_geo","_prprn"},
"Naga":{"_prprn"},
"Nagano":{"_cty","_geo","_prprn"},
"Nagasaki":{"_cty","_geo","_prprn"},
"nagged":{"_past"},
"nagger":{"_anim","_sb"},
"Nagorno-Karabakh":{"_prprn"},
"Nagoya":{"_cty","_geo","_prprn"},
"nags":{"_anim","_sb"},
"Nagy":{"_prprn"},
"nahuatl":{"_prprn","_sb"},
"Nahum":{"_prprn"},
"naiad":{"_anim"},
"naif":{"_anim","_sb"},
"nailed":{"_past"},
"nailer":{"_anim","_sb"},
"Nairobi":{"_cty","_geo","_prprn"},
"naismith":{"_anim","_nme","_prprn","_sb"},
"naive":{"_anim","_sb"},
"najd":{"_geo","_prprn"},
"nalchik":{"_cty","_geo","_prprn"},
"Nam":{"_cntry","_geo","_prprn"},
"namby-pamby":{"_anim","_sb"},
"name-dropper":{"_anim","_sb"},
"name-droppers":{"_anim","_sb"},
"namer":{"_anim","_sb"},
"namesake":{"_anim","_sb"},
"Namibia":{"_cntry","_geo","_prprn"},
"namoi":{"_geo","_prprn"},
"nampa":{"_cty","_geo","_prprn"},
"namur":{"_cty","_geo","_prprn"},
"nan":{"_geo","_prprn"},
"nan-chang":{"_geo","_prprn"},
"nan-ning":{"_geo","_prprn"},
"nanaimo":{"_cty","_geo","_prprn"},
"Nanak":{"_anim","_nme","_prprn","_sb"},
"nanchang":{"_cty","_geo","_prprn"},
"Nancy":{"_anim","_cty","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"Nanjing":{"_cty","_geo","_prprn"},
"Nanking":{"_geo","_prprn"},
"nanning":{"_cty","_geo","_prprn"},
"nanny":{"_anim","_fem","_sb"},
"nanny-goat":{"_anim","_fem","_sb"},
"nansen":{"_anim","_nme","_prprn","_sb"},
"nantes":{"_cty","_geo","_prprn"},
"nanticoke":{"_anim","_cty","_geo","_prprn","_sb"},
"Nantucket":{"_geo","_prprn"},
"Naomi":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Napa":{"_cty","_geo","_prprn"},
"Naperville":{"_cty","_geo","_prprn"},
"napier":{"_anim","_nme","_prprn","_sb"},
"Naples":{"_cty","_geo","_prprn"},
"napoli":{"_geo","_prprn"},
"napped":{"_past"},
"Nara":{"_cty","_geo","_prprn"},
"Narbonne":{"_cty","_geo","_prprn"},
"narcist":{"_anim","_sb"},
"narcotised":{"_past"},
"narcotized":{"_past"},
"Narragansett":{"_anim","_prprn","_sb"},
"narrate":{"_loc_sr"},
"narrated":{"_loc_sr","_past"},
"narrator":{"_anim","_sb"},
"narrow":{"_loc_sr"},
"narrowed":{"_loc_sr","_past"},
"narrowing":{"_loc_sr"},
"narrows":{"_loc_sr"},
"narwhal":{"_anim"},
"NASA":{"_prprn"},
"nasalize":{"_loc_sr"},
"NASDAQ":{"_prprn"},
"naseby":{"_geo","_prprn"},
"Nash":{"_anim","_nme","_prprn","_sb"},
"Nashua":{"_cty","_geo","_prprn"},
"Nashville":{"_cty","_geo","_prprn"},
"Nassau":{"_cty","_geo","_prprn"},
"Nasser":{"_anim","_geo","_nme","_prprn","_sb"},
"Nast":{"_anim","_nme","_prprn","_sb"},
"Nat":{"_prprn"},
"Natalie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"natchez":{"_anim","_cty","_geo","_prprn","_sb"},
"Nathan":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Nathanael":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Nathaniel":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"nation":{"_loc_sr","_sb"},
"nation-building":{"_loc_sr","_sb"},
"nation-wide":{"_loc_sr","_sb"},
"National":{"_anim","_sb"},
"national-policy":{"_anim","_sb"},
"national-priority":{"_anim","_sb"},
"national-security":{"_anim","_sb"},
"national-service":{"_anim","_sb"},
"national-treasure":{"_anim","_sb"},
"nationalist":{"_anim","_sb"},
"nationalists":{"_anim","_sb"},
"nationalize":{"_loc_sr"},
"nationalized":{"_loc_sr","_past"},
"nationalizing":{"_loc_sr"},
"nationals":{"_anim","_sb"},
"nations":{"_loc_sr","_sb"},
"natives":{"_anim","_sb"},
"nativity":{"_loc_sr"},
"NATO":{"_prprn"},
"natta":{"_anim","_nme","_prprn","_sb"},
"natural":{"_sb"},
"natural-foods":{"_sb"},
"natural-gas":{"_sb"},
"natural-gas-pipeline":{"_sb"},
"natural-gas-pricing":{"_sb"},
"natural-law":{"_sb"},
"naturalised":{"_past"},
"naturalist":{"_anim","_sb"},
"naturalized":{"_past"},
"naught":{"_quant","_univ"},
"Nauru":{"_cntry","_geo","_prprn"},
"Nauruan":{"_anim","_prprn","_sb"},
"nauseate":{"_psych"},
"nauseated":{"_past","_psych"},
"nauseating":{"_psych"},
"Navaho":{"_anim","_prprn","_sb"},
"Navajo":{"_anim","_prprn","_sb"},
"navel":{"_loc_sr"},
"navels":{"_loc_sr"},
"navies":{"_loc_sr","_sb"},
"navigated":{"_past"},
"navigator":{"_anim","_sb"},
"navigators":{"_anim","_sb"},
"Navratilova":{"_anim","_nme","_prprn","_sb"},
"navvy":{"_anim","_sb"},
"navy":{"_loc_sr","_sb"},
"Naxos":{"_geo","_prprn"},
"naysayer":{"_anim","_sb"},
"naysayers":{"_anim","_sb"},
"Nazarene":{"_anim","_prprn","_sb"},
"Nazareth":{"_cty","_geo","_prprn"},
"Nazi":{"_prprn","_sb"},
"Naziism":{"_prprn"},
"nazimova":{"_anim","_nme","_prprn","_sb"},
"Nazis":{"_prprn","_sb"},
"Nazism":{"_prprn"},
"nbe":{"_prprn"},
"nbw":{"_prprn"},
"nc":{"_prprn","_stte"},
"ndebele":{"_anim","_prprn","_sb"},
"ndjamena":{"_cty","_geo","_prprn"},
"Ndola":{"_cty","_geo","_prprn"},
"Ne":{"_prprn"},
"ne'er-do-well":{"_anim","_sb"},
"Neal":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Neanderthal":{"_prprn","_sb"},
"Neanderthals":{"_prprn","_sb"},
"Neapolitan":{"_prprn"},
"near-absence":{"_loc"},
"near-at-hand":{"_loc"},
"near-complete":{"_loc"},
"near-completed":{"_loc"},
"near-completion":{"_loc"},
"near-equivalents":{"_loc"},
"near-hysteria":{"_loc"},
"near-identical":{"_loc"},
"near-irrelevant":{"_loc"},
"near-left":{"_loc"},
"near-limit":{"_loc"},
"near-luxury":{"_loc"},
"near-maddened":{"_loc"},
"near-majority":{"_loc"},
"near-manic":{"_loc"},
"near-market":{"_loc"},
"near-misses":{"_loc"},
"near-monopolies":{"_loc"},
"near-monopoly":{"_loc"},
"near-mutiny":{"_loc"},
"near-panic":{"_loc"},
"near-paralysis":{"_loc"},
"near-perfect":{"_loc"},
"near-recession":{"_loc"},
"near-record":{"_loc"},
"near-rich":{"_loc"},
"near-solid":{"_loc"},
"near-strangers":{"_loc"},
"near-synonyms":{"_loc"},
"near-term":{"_tme"},
"near-total":{"_loc"},
"near-unanimous":{"_loc"},
"near-unmatched":{"_loc"},
"nearby":{"_loc"},
"neared":{"_past"},
"neaten":{"_loc_sr"},
"Neb":{"_prprn","_stte"},
"nebe":{"_prprn"},
"nebn":{"_prprn"},
"Nebraska":{"_geo","_prprn","_stte"},
"Nebraskan":{"_prprn"},
"Nebuchadnezzar":{"_prprn"},
"nebulizer":{"_anim","_sb"},
"nec":{"_prprn"},
"necessitarian":{"_sb"},
"necessitated":{"_past"},
"neckar":{"_geo","_prprn"},
"necker":{"_anim","_nme","_prprn","_sb"},
"necromancer":{"_anim","_sb"},
"Ned":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Nederland":{"_cty","_geo","_prprn"},
"needed":{"_past"},
"needer":{"_anim","_sb"},
"needled":{"_past"},
"needlefish":{"_anim"},
"needlewoman":{"_anim","_sb"},
"needleworker":{"_anim","_sb"},
"neel":{"_anim","_nme","_prprn","_sb"},
"nefertiti":{"_anim","_nme","_prprn","_sb"},
"nefud":{"_geo","_prprn"},
"negated":{"_past"},
"negev":{"_geo","_prprn"},
"neglecter":{"_anim","_sb"},
"negotiated":{"_past"},
"negotiatress":{"_anim","_fem","_sb"},
"Negress":{"_anim","_fem","_prprn","_sb"},
"Negroes":{"_anim","_prprn","_sb"},
"negroid":{"_prprn","_sb"},
"Negus":{"_prprn"},
"Nehemiah":{"_anim","_fnme","_nme","_prprn","_sb"},
"Nehru":{"_anim","_nme","_prprn","_sb"},
"neighbor":{"_anim","_sb"},
"neighborhood":{"_loc_sr"},
"neighborhoods":{"_loc_sr"},
"neighbors":{"_anim","_sb"},
"neighbours":{"_anim","_sb"},
"Neil":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Neill":{"_prprn"},
"Neilson":{"_anim","_nme","_prprn","_sb"},
"Neisse":{"_geo","_prprn"},
"neither":{"_quant","_univ"},
"nejd":{"_geo","_prprn"},
"Nelson":{"_anim","_fnme","_masc","_prprn","_sb"},
"Nembutal":{"_prprn"},
"nemea":{"_geo","_prprn"},
"nemeses":{"_anim","_sb"},
"nenets":{"_anim","_prprn","_sb"},
"neo-darwinism":{"_prprn"},
"neo-lamarckism":{"_prprn"},
"neo-Nazis":{"_prprn","_sb"},
"neoclassicist":{"_anim","_sb"},
"neoliberal":{"_anim","_sb"},
"neophyte":{"_anim","_sb"},
"neophytes":{"_anim","_sb"},
"neoplatonism":{"_prprn"},
"neosho":{"_geo","_prprn"},
"Nepal":{"_cntry","_geo","_prprn"},
"Nepalese":{"_anim","_prprn","_sb"},
"nepali":{"_anim","_prprn","_sb"},
"nephew":{"_anim","_masc","_sb"},
"nephews":{"_anim","_masc","_sb"},
"Neptune":{"_anim","_geo","_masc","_nme","_prprn","_sb"},
"nerd":{"_anim","_sb"},
"nerd-and-geek":{"_anim","_sb"},
"nerds":{"_anim","_sb"},
"Nereid":{"_anim","_fem","_nme","_prprn","_sb"},
"nereus":{"_prprn"},
"nernst":{"_anim","_nme","_prprn","_sb"},
"Neruda":{"_anim","_nme","_prprn","_sb"},
"nervi":{"_anim","_nme","_prprn","_sb"},
"Nesbit":{"_prprn"},
"nesselrode":{"_prprn"},
"Nessie":{"_prprn"},
"nest-egg":{"_loc_sr"},
"nestle":{"_loc_sr"},
"nestled":{"_loc_sr","_past"},
"nestling":{"_loc_sr"},
"nestor":{"_anim","_sb"},
"nestorian":{"_prprn","_sb"},
"nestorius":{"_anim","_nme","_prprn","_sb"},
"nests":{"_loc_sr"},
"Netanyahu":{"_prprn"},
"Netherlands":{"_cntry","_geo","_prprn"},
"netkeeper":{"_anim","_sb"},
"netted":{"_past"},
"nettle":{"_psych"},
"nettled":{"_past","_psych"},
"networked":{"_past"},
"neumann":{"_anim","_nme","_prprn","_sb"},
"neurobiologist":{"_anim","_sb"},
"neurologist":{"_anim","_sb"},
"neurologists":{"_anim","_sb"},
"neuroscientist":{"_anim","_sb"},
"neurotic":{"_anim","_sb"},
"neutered":{"_past"},
"neutralised":{"_past"},
"neutralized":{"_past"},
"Nev":{"_prprn","_stte"},
"Nev.":{"_prprn","_stte"},
"neva":{"_geo","_prprn"},
"Nevada":{"_geo","_prprn","_stte"},
"nevelson":{"_anim","_nme","_prprn","_sb"},
"nevermore":{"_tme"},
"Nevis":{"_geo","_prprn"},
"new":{"_tme"},
"new-business":{"_tme"},
"new-car":{"_tme"},
"new-country":{"_tme"},
"new-found":{"_tme"},
"new-generation":{"_tme"},
"new-home":{"_tme"},
"new-issues":{"_tme"},
"new-job":{"_tme"},
"new-loan":{"_tme"},
"new-made":{"_tme"},
"new-model":{"_tme"},
"new-money":{"_tme"},
"new-product":{"_tme"},
"new-rich":{"_tme"},
"new-share":{"_tme"},
"new-spilled":{"_tme"},
"new-sprung":{"_tme"},
"new-styled":{"_tme"},
"new-telephone-line":{"_tme"},
"Newark":{"_cty","_geo","_prprn"},
"newburgh":{"_cty","_geo","_prprn"},
"Newbury":{"_prprn"},
"Newcastle":{"_cty","_geo","_prprn"},
"newcastle-upon-tyne":{"_cty","_geo","_prprn"},
"Newcomb":{"_anim","_nme","_prprn","_sb"},
"newcomers":{"_anim","_sb"},
"newer":{"_tme"},
"newest":{"_tme"},
"Newfoundland":{"_anim","_geo","_prprn","_stte"},
"Newgate":{"_prprn"},
"newly-appointed":{"_tme"},
"newly-created":{"_tme"},
"newly-emerging":{"_tme"},
"newly-married":{"_tme"},
"newly-plowed":{"_tme"},
"newly-scrubbed":{"_tme"},
"newly-weds":{"_tme"},
"newlywed":{"_anim","_sb"},
"newlyweds":{"_anim","_sb"},
"Newman":{"_anim","_nme","_prprn","_sb"},
"Newmarket":{"_cty","_geo","_prprn"},
"Newport":{"_cty","_geo","_prprn"},
"newsagent":{"_anim","_sb"},
"newsmen":{"_anim","_masc","_sb"},
"newsmonger":{"_anim","_sb"},
"newspaperman":{"_anim","_masc","_sb"},
"newspaperwoman":{"_anim","_fem","_sb"},
"newsroom":{"_loc_sr"},
"newsvendor":{"_anim","_sb"},
"newswoman":{"_anim","_fem","_sb"},
"newt":{"_anim"},
"Newton":{"_cty","_geo","_prprn"},
"Newtown":{"_cty","_geo","_prprn"},
"next-generation":{"_sb"},
"ney":{"_anim","_nme","_prprn","_sb"},
"ngf":{"_prprn"},
"NGO":{"_prprn"},
"ngu":{"_prprn"},
"nguni":{"_prprn","_sb"},
"NH":{"_prprn","_stte"},
"NI":{"_prprn"},
"ni-hard":{"_prprn"},
"ni-resist":{"_prprn"},
"Niagara":{"_geo","_prprn"},
"Niamey":{"_cty","_geo","_prprn"},
"Niarchos":{"_prprn"},
"nibbler":{"_anim","_sb"},
"nibblers":{"_anim","_sb"},
"nibelung":{"_prprn"},
"Nibelungenlied":{"_prprn"},
"nibs":{"_anim","_sb"},
"NiCad":{"_prprn"},
"nicaea":{"_cty","_geo","_prprn"},
"Nicaragua":{"_cntry","_geo","_prprn"},
"Nicaraguan":{"_anim","_prprn","_sb"},
"Nicaraguans":{"_anim","_prprn","_sb"},
"niche":{"_loc_sr"},
"niche-market":{"_loc_sr"},
"niches":{"_loc_sr"},
"Nicholas":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Nichols":{"_anim","_nme","_prprn","_sb"},
"Nicholson":{"_prprn"},
"Nick":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"nicked":{"_past"},
"nicklaus":{"_anim","_nme","_prprn","_sb"},
"nicknamed":{"_past"},
"Nicodemus":{"_prprn"},
"Nicolas":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Nicole":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Nicolson":{"_anim","_nme","_prprn","_sb"},
"Nicosia":{"_cty","_geo","_prprn"},
"Niebuhr":{"_anim","_nme","_prprn","_sb"},
"niece":{"_anim","_fem","_sb"},
"nieces":{"_anim","_fem","_sb"},
"nielsen":{"_anim","_nme","_prprn","_sb"},
"Niepce":{"_prprn"},
"Nietzsche":{"_anim","_nme","_prprn","_sb"},
"nifty":{"_sb"},
"Niger":{"_cntry","_geo","_prprn"},
"niger-congo":{"_prprn"},
"niger-kordofanian":{"_prprn"},
"Nigerian":{"_anim","_prprn","_sb"},
"Nigerians":{"_anim","_prprn","_sb"},
"nigerien":{"_anim","_prprn","_sb"},
"niggard":{"_anim","_sb"},
"nigger":{"_anim","_sb"},
"niggers":{"_anim","_sb"},
"niggling":{"_psych"},
"night":{"_tme"},
"night-coach":{"_tme"},
"night-line":{"_tme"},
"night-robe":{"_tme"},
"night-stop":{"_tme"},
"night-time":{"_tme"},
"night-watchman":{"_tme"},
"nightfall":{"_tme"},
"nighthawk":{"_anim","_sb"},
"nightingales":{"_anim"},
"nightjar":{"_anim"},
"nightrider":{"_sb"},
"nights":{"_tme"},
"nighttime":{"_tme"},
"nih":{"_prprn"},
"Nihon":{"_prprn"},
"Nijinsky":{"_anim","_nme","_prprn","_sb"},
"nijmegen":{"_cty","_geo","_prprn"},
"Nike":{"_anim","_fem","_nme","_prprn","_sb"},
"Nikko":{"_cty","_geo","_prprn"},
"nil":{"_quant"},
"Nile":{"_geo","_prprn"},
"nilo-saharan":{"_prprn"},
"nilotic":{"_prprn"},
"nilsson":{"_anim","_nme","_prprn","_sb"},
"nimitz":{"_anim","_nme","_prprn","_sb"},
"Nimrod":{"_anim","_prprn","_sb"},
"nin-sin":{"_anim","_nme","_prprn","_sb"},
"nincompoop":{"_anim","_sb"},
"nine-cent":{"_num","_quant"},
"nine-chambered":{"_quant"},
"nine-day":{"_num","_quant"},
"nine-digit":{"_num","_quant"},
"nine-fold":{"_num","_quant"},
"nine-game":{"_num","_quant"},
"nine-member":{"_num","_quant"},
"nine-membered":{"_num","_quant"},
"nine-month":{"_num","_quant"},
"nine-months":{"_num","_quant"},
"nine-point":{"_num","_quant"},
"nine-press":{"_num","_quant"},
"nine-sided":{"_quant"},
"nine-spot":{"_num","_quant"},
"nine-state":{"_num","_quant"},
"nine-story":{"_num","_quant"},
"nine-to-five":{"_num","_quant"},
"ninefold":{"_quant"},
"niner":{"_anim","_sb"},
"nineteen":{"_quant"},
"nineteen-year-old":{"_num","_quant"},
"nineties":{"_num","_quant"},
"ninety":{"_num","_quant"},
"ninety-eight":{"_num","_quant"},
"ninety-fifth":{"_num","_quant"},
"ninety-five":{"_num","_quant"},
"ninety-four":{"_num","_quant"},
"ninety-one":{"_num","_quant"},
"ninety-seven":{"_num","_quant"},
"ninety-three":{"_num","_quant"},
"ninety-two":{"_num","_quant"},
"Nineveh":{"_cty","_geo","_prprn"},
"Niobe":{"_prprn"},
"niobrara":{"_geo","_prprn"},
"nip":{"_loc_sr"},
"nipper":{"_anim","_sb"},
"nipping":{"_loc_sr"},
"nipples":{"_loc_sr"},
"Nippon":{"_geo","_prprn"},
"Nipponese":{"_prprn"},
"Nippur":{"_cty","_geo","_prprn"},
"nisan":{"_prprn"},
"nisei":{"_anim","_prprn","_sb"},
"nit":{"_anim"},
"nit-picking":{"_anim"},
"nit-picky":{"_anim"},
"nitpicker":{"_anim","_sb"},
"nitrify":{"_loc_sr"},
"Niven":{"_prprn"},
"nixed":{"_past"},
"Nixon":{"_anim","_nme","_prprn","_sb"},
"NJ":{"_prprn","_stte"},
"Nkrumah":{"_anim","_nme","_prprn","_sb"},
"nlrb":{"_prprn"},
"nmr":{"_prprn"},
"nne":{"_prprn"},
"nnw":{"_prprn"},
"no":{"_quant"},
"no-account":{"_anim","_sb"},
"no-back":{"_quant"},
"no-brainer":{"_quant"},
"no-bunkum":{"_quant"},
"no-confidence":{"_quant"},
"no-count":{"_quant"},
"no-drinking":{"_quant"},
"no-driving":{"_quant"},
"no-fat":{"_quant"},
"no-fly":{"_quant"},
"no-fuss":{"_quant"},
"no-good-bums":{"_quant"},
"no-growth":{"_quant"},
"no-inflation":{"_quant"},
"no-layoff":{"_quant"},
"no-man":{"_quant"},
"no-men":{"_quant"},
"no-mistakes":{"_quant"},
"no-more-nonsense":{"_quant"},
"no-muss":{"_quant"},
"no-new-tax":{"_quant"},
"no-new-taxes":{"_quant"},
"no-o":{"_quant"},
"no-profit":{"_quant"},
"no-show":{"_anim","_sb"},
"no-smoking":{"_quant"},
"no-star":{"_quant"},
"no-strike":{"_quant"},
"no-tax":{"_quant"},
"no-tax-increase":{"_quant"},
"no-trade":{"_quant"},
"no-trading":{"_quant"},
"no-valued":{"_quant","_univ"},
"no-walls-no-doors":{"_quant"},
"no-waste":{"_quant"},
"no.":{"_quant"},
"noaa":{"_prprn"},
"Noah":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Nobel":{"_anim","_nme","_prprn","_sb"},
"nobelist":{"_prprn"},
"nobleman":{"_anim","_masc","_sb"},
"noblemen":{"_anim","_masc","_sb"},
"nobles":{"_anim","_sb"},
"noblewoman":{"_anim","_fem","_sb"},
"nobody":{"_anim","_sb","_univ"},
"noctambulist":{"_anim","_sb"},
"nodded":{"_past"},
"Noel":{"_prprn","_tme"},
"noemi":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"nogales":{"_cty","_geo","_prprn"},
"noguchi":{"_anim","_nme","_prprn","_sb"},
"Nolan":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"nomad":{"_anim","_sb"},
"nominated":{"_past"},
"nominator":{"_anim","_sb"},
"nominee":{"_anim","_sb"},
"nominees":{"_anim","_sb"},
"non-academic":{"_anim","_sb"},
"non-affiliate":{"_sb"},
"non-alcoholic":{"_anim","_sb"},
"non-Aryan":{"_anim","_sb"},
"non-bank":{"_loc_sr"},
"non-binding":{"_sb"},
"non-brain":{"_loc_sr"},
"non-British":{"_anim","_sb"},
"non-casino":{"_loc_sr"},
"non-Castilians":{"_anim","_sb"},
"non-catholic":{"_sb"},
"non-Catholics":{"_sb"},
"non-church":{"_loc_sr"},
"non-clients":{"_anim","_sb"},
"non-Communist":{"_anim","_sb"},
"non-communists":{"_anim","_sb"},
"non-conformists":{"_anim","_sb"},
"non-contact":{"_anim","_sb"},
"non-convertible":{"_fem"},
"non-dealer":{"_anim","_sb"},
"non-disabled":{"_anim","_sb"},
"non-Dow":{"_anim","_sb"},
"non-duck":{"_anim"},
"non-economists":{"_anim","_sb"},
"non-elderly":{"_anim","_sb"},
"non-employee":{"_anim","_sb"},
"non-English":{"_anim","_sb"},
"non-executive":{"_anim","_sb"},
"non-exempt":{"_anim","_sb"},
"non-family":{"_anim","_sb"},
"non-farm":{"_loc_sr"},
"non-firm":{"_anim","_sb"},
"non-Ford":{"_anim","_loc_sr","_sb"},
"non-Germans":{"_anim","_sb"},
"non-God":{"_anim","_sb"},
"non-Greek":{"_anim","_sb"},
"non-Hispanic":{"_sb"},
"non-Hungarians":{"_anim","_sb"},
"non-Indian":{"_anim","_sb"},
"non-Indonesian":{"_anim","_sb"},
"non-insider":{"_anim","_sb"},
"non-intellectual":{"_anim","_sb"},
"non-Japanese":{"_anim","_sb"},
"non-Jew":{"_anim","_sb"},
"non-Jews":{"_anim","_sb"},
"non-junkies":{"_anim","_sb"},
"non-Korean":{"_anim","_sb"},
"non-lawyers":{"_anim","_sb"},
"non-Magyars":{"_sb"},
"non-market":{"_loc_sr"},
"non-member":{"_anim","_sb"},
"non-members":{"_anim","_sb"},
"non-Mexican":{"_anim","_sb"},
"non-New":{"_tme"},
"non-partisan":{"_anim","_sb"},
"non-party":{"_anim","_sb"},
"non-person":{"_anim","_sb"},
"non-police":{"_anim","_sb"},
"non-professional":{"_anim","_sb"},
"non-professionals":{"_anim","_sb"},
"non-public":{"_sb"},
"non-publishers":{"_anim","_sb"},
"non-readers":{"_anim","_sb"},
"non-religious":{"_anim","_sb"},
"non-resident":{"_anim","_sb"},
"non-residents":{"_anim","_sb"},
"non-romantic":{"_anim","_sb"},
"non-Russian":{"_anim","_sb"},
"non-scientist":{"_anim","_sb"},
"non-seamen":{"_anim","_sb"},
"non-slave":{"_anim","_sb"},
"non-smokers":{"_anim","_sb"},
"non-Socialist":{"_anim","_sb"},
"non-Soviet":{"_anim","_sb"},
"non-subscribers":{"_anim","_sb"},
"non-Tagalog":{"_anim","_sb"},
"non-time":{"_tme"},
"non-Tories":{"_sb"},
"non-traders":{"_anim","_sb"},
"non-user":{"_anim","_sb"},
"non-veterans":{"_anim","_sb"},
"non-writers":{"_anim","_sb"},
"non-zero":{"_num","_quant"},
"nonachiever":{"_anim","_sb"},
"nonaged":{"_sb"},
"nonagenarian":{"_anim","_sb"},
"nonallele":{"_sb"},
"nonbeing":{"_anim","_sb"},
"nonbeliever":{"_anim","_sb"},
"nonbelligerent":{"_anim","_sb"},
"nonbinding":{"_sb"},
"noncandidate":{"_anim","_sb"},
"noncombatant":{"_sb"},
"noncommunist":{"_anim","_sb"},
"nonconformist":{"_anim","_sb"},
"nonconformists":{"_anim","_sb"},
"nonconvertible":{"_fem"},
"noncriminal":{"_anim","_sb"},
"noncustomer":{"_anim","_sb"},
"nondoctrinaire":{"_anim","_sb"},
"nondrinker":{"_anim","_sb"},
"none":{"_quant","_univ"},
"nonexecutive":{"_anim","_sb"},
"nonexempt":{"_anim","_sb"},
"nonfarm":{"_loc_sr"},
"nonimmune":{"_anim","_sb"},
"nonintellectual":{"_anim","_sb"},
"nonmember":{"_anim","_sb"},
"nonmembers":{"_anim","_sb"},
"nonmodern":{"_anim","_sb"},
"nonmoving":{"_psych"},
"nonnative":{"_anim","_sb"},
"nonnatural":{"_sb"},
"nonpareil":{"_anim","_sb"},
"nonparticipant":{"_anim","_sb"},
"nonperformers":{"_sb"},
"nonperson":{"_anim","_sb"},
"nonplus":{"_psych"},
"nonplused":{"_past","_psych"},
"nonplussed":{"_past","_psych"},
"nonprofessional":{"_anim","_sb"},
"nonprogressive":{"_anim","_sb"},
"nonreader":{"_anim","_sb"},
"nonrepresentative":{"_anim","_sb"},
"nonresident":{"_sb"},
"nonruminant":{"_anim"},
"nonsensitive":{"_sb"},
"nonsmoker":{"_anim","_sb"},
"nonsmokers":{"_anim","_sb"},
"nonsocialist":{"_anim","_sb"},
"nonsovereign":{"_anim","_sb"},
"nonstarter":{"_sb"},
"nonstrikers":{"_anim","_sb"},
"nonsubmersible":{"_loc_sr"},
"nonterritorial":{"_anim","_sb"},
"nonunionised":{"_past"},
"nonunionized":{"_past"},
"nonwhite":{"_anim","_sb"},
"nonworker":{"_anim","_sb"},
"noodle":{"_loc_sr"},
"nook":{"_loc_sr"},
"nooks":{"_loc_sr"},
"noon":{"_tme"},
"noonday":{"_tme"},
"nootka":{"_anim","_prprn","_sb"},
"Nora":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Nord":{"_prprn"},
"Nordic":{"_anim","_prprn","_sb"},
"Norfolk":{"_cty","_geo","_prprn"},
"Norge":{"_prprn"},
"Noriega":{"_prprn"},
"normaliser":{"_anim","_sb"},
"normalized":{"_past"},
"normalizer":{"_anim","_sb"},
"Norman":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"norman-french":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"norn":{"_anim","_fem","_nme","_prprn","_sb"},
"norrish":{"_anim","_nme","_prprn","_sb"},
"Norseman":{"_prprn","_sb"},
"Norsemen":{"_prprn"},
"North":{"_anim","_prprn","_sb"},
"Northampton":{"_cty","_geo","_prprn"},
"Northamptonshire":{"_prprn"},
"Northerner":{"_anim","_prprn","_sb"},
"northerners":{"_anim","_sb"},
"northman":{"_prprn"},
"northrop":{"_anim","_nme","_prprn","_sb"},
"Northumberland":{"_prprn"},
"Northumbria":{"_cntry","_geo","_prprn"},
"Norton":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Norwalk":{"_cty","_geo","_prprn"},
"Norway":{"_cntry","_geo","_prprn"},
"Norwegians":{"_anim","_prprn","_sb"},
"nose-dived":{"_past"},
"nosed":{"_past"},
"nosedived":{"_past"},
"nosegay":{"_anim"},
"Nostradamus":{"_anim","_nme","_prprn","_sb"},
"notable":{"_anim","_sb"},
"notables":{"_anim","_sb"},
"notarized":{"_past"},
"notary":{"_anim","_sb"},
"notate":{"_loc_sr"},
"notched":{"_past"},
"notched-stick":{"_past"},
"noted":{"_past"},
"nothin":{"_univ"},
"nothing-down":{"_sb"},
"noticed":{"_past"},
"noticer":{"_anim","_sb"},
"notified":{"_past"},
"nouakchott":{"_cty","_geo","_prprn"},
"nought":{"_quant","_univ"},
"noun":{"_loc_sr"},
"nourished":{"_past"},
"Nov":{"_prprn","_tme"},
"nov-esperanto":{"_prprn","_tme"},
"nov-latin":{"_prprn","_tme"},
"Nov.":{"_prprn","_tme"},
"novelist":{"_anim","_sb"},
"novelists":{"_anim","_sb"},
"novelized":{"_past"},
"Novello":{"_prprn"},
"November":{"_prprn","_tme"},
"novgorod":{"_cty","_geo","_prprn"},
"novice":{"_anim","_sb"},
"novices":{"_anim","_sb"},
"novosibirsk":{"_cty","_geo","_prprn"},
"now":{"_tme"},
"now-deceased":{"_tme"},
"now-defunct":{"_tme"},
"now-discontinued":{"_tme"},
"now-dismembered":{"_tme"},
"now-dominant":{"_tme"},
"now-evident":{"_tme"},
"now-famous":{"_tme"},
"now-historic":{"_tme"},
"now-infamous":{"_tme"},
"now-legal":{"_tme"},
"now-misplaced":{"_tme"},
"now-notorious":{"_tme"},
"now-obscure":{"_tme"},
"now-ousted":{"_tme"},
"now-purged":{"_tme"},
"now-Rep":{"_tme"},
"now-repentant":{"_tme"},
"now-scuttled":{"_tme"},
"now-shaky":{"_tme"},
"now-shuttered":{"_tme"},
"now-smaller":{"_tme"},
"now-standard":{"_tme"},
"now-troubled":{"_tme"},
"now-vacant":{"_tme"},
"nowadays":{"_tme"},
"nowhere":{"_univ"},
"Noyes":{"_anim","_nme","_prprn","_sb"},
"nra":{"_prprn"},
"nrc":{"_prprn"},
"nsa":{"_prprn"},
"nsc":{"_prprn"},
"nsf":{"_prprn"},
"nt":{"_prprn","_stte"},
"nuanced":{"_loc_sr","_past"},
"Nubia":{"_cntry","_geo","_prprn"},
"Nubian":{"_anim","_prprn","_sb"},
"nucleate":{"_loc_sr"},
"nucleated":{"_loc_sr","_past"},
"nude":{"_anim","_sb"},
"nudes":{"_anim","_sb"},
"nudged":{"_past"},
"nudger":{"_anim","_sb"},
"nuisance":{"_anim","_sb"},
"nuisances":{"_anim","_sb"},
"nullified":{"_past"},
"nullipara":{"_anim","_fem","_sb"},
"numbed":{"_past"},
"number":{"_sb"},
"number-crunchers":{"_sb"},
"number-one":{"_sb"},
"numbered":{"_past"},
"numbers":{"_sb"},
"numen":{"_loc_sr"},
"numerologist":{"_anim","_sb"},
"numerous":{"_quant"},
"numidia":{"_cntry","_geo","_prprn"},
"numskull":{"_anim","_sb"},
"nun":{"_anim","_fem","_sb"},
"nunavut":{"_geo","_prprn","_stte"},
"nuncio":{"_anim","_sb"},
"nunnery":{"_loc_sr"},
"nuns":{"_anim","_fem","_sb"},
"Nuremberg":{"_cty","_geo","_prprn"},
"Nureyev":{"_anim","_nme","_prprn","_sb"},
"nurnberg":{"_geo","_prprn"},
"nurse-midwife":{"_anim","_sb"},
"nursemaid":{"_anim","_fem","_sb"},
"nurseries":{"_loc_sr"},
"nursery":{"_loc_sr"},
"nurseryman":{"_anim","_sb"},
"nursing":{"_loc_sr"},
"nursling":{"_anim","_sb"},
"nurtured":{"_past"},
"nurturer":{"_anim","_sb"},
"nutcase":{"_anim","_sb"},
"Nutrasweet":{"_prprn"},
"nutritionist":{"_anim","_sb"},
"nutritionists":{"_anim","_sb"},
"nutter":{"_anim","_sb"},
"nuzzled":{"_past"},
"nv":{"_prprn","_stte"},
"nw":{"_prprn"},
"nw.":{"_prprn"},
"nwbn":{"_prprn"},
"nwbw":{"_prprn"},
"NY":{"_prprn","_stte"},
"nyala":{"_anim"},
"nyasaland":{"_geo","_prprn"},
"Nye":{"_anim","_nme","_prprn","_sb"},
"nymph":{"_anim","_fem","_sb"},
"nymphet":{"_anim","_fem","_sb"},
"nympholept":{"_anim","_sb"},
"nymphomaniac":{"_anim","_fem","_sb"},
"nymphomaniacs":{"_anim","_fem","_sb"},
"nymphs":{"_anim","_fem","_sb"},
"nynorsk":{"_prprn"},
"NYSE":{"_prprn"},
"o'casey":{"_anim","_nme","_prprn","_sb"},
"o'clock":{"_tme"},
"o'er":{"_loc"},
"o'flaherty":{"_anim","_nme","_prprn","_sb"},
"oafs":{"_anim","_sb"},
"oahu":{"_geo","_prprn"},
"Oakland":{"_cty","_geo","_prprn"},
"Oakley":{"_anim","_nme","_prprn","_sb"},
"oarfish":{"_anim"},
"oarsman":{"_anim","_masc","_sb"},
"oarswoman":{"_anim","_fem","_sb"},
"OAS":{"_prprn"},
"oases":{"_loc_sr"},
"oasis":{"_loc_sr"},
"Oates":{"_anim","_nme","_prprn","_sb"},
"oaxaca":{"_cty","_geo","_prprn","_stte"},
"Obadiah":{"_anim","_fnme","_nme","_prprn","_sb"},
"Obasanjo":{"_prprn"},
"Oberhausen":{"_cty","_geo","_prprn"},
"obeyed":{"_past"},
"objected":{"_past"},
"objectors":{"_anim","_sb"},
"obliged":{"_past"},
"obliger":{"_anim","_sb"},
"obliterator":{"_anim","_sb"},
"obscurantist":{"_anim","_sb"},
"observatory":{"_loc_sr"},
"observed":{"_past"},
"observer":{"_anim","_sb"},
"observers":{"_anim","_sb"},
"obsess":{"_psych"},
"obsessional":{"_sb"},
"obsessive":{"_anim","_sb"},
"obsessive-compulsive":{"_sb"},
"obsoleted":{"_past"},
"obstructed":{"_past"},
"obstructer":{"_anim","_sb"},
"obstructionist":{"_anim","_sb"},
"obstructor":{"_anim","_sb"},
"obtain":{"_loc_sr"},
"obtained":{"_loc_sr","_past"},
"obtaining":{"_loc_sr"},
"occam":{"_anim","_nme","_prprn","_sb"},
"occasion":{"_tme"},
"occasionally":{"_tme"},
"occasioned":{"_past"},
"occasions":{"_tme"},
"Occident":{"_loc_sr","_prprn"},
"Occidental":{"_anim","_sb"},
"occidentalism":{"_prprn"},
"Occidentalize":{"_loc_sr"},
"occluded":{"_past"},
"occultist":{"_anim","_sb"},
"occupant":{"_anim","_sb"},
"occupants":{"_anim","_sb"},
"occupied":{"_past"},
"occupier":{"_anim","_sb"},
"occurred":{"_past"},
"ocean":{"_loc_sr"},
"ocean-pollution":{"_loc_sr"},
"ocean-shipping":{"_loc_sr"},
"ocean-thermal":{"_loc_sr"},
"Oceania":{"_geo","_prprn"},
"oceanid":{"_prprn"},
"oceanographer":{"_anim","_sb"},
"oceans":{"_loc_sr"},
"Oceanside":{"_cty","_geo","_prprn"},
"oceanus":{"_anim","_masc","_nme","_prprn","_sb"},
"ochoa":{"_anim","_nme","_prprn","_sb"},
"ochre":{"_loc_sr"},
"Ochs":{"_anim","_nme","_prprn","_sb"},
"ockham":{"_anim","_nme","_prprn","_sb"},
"oct":{"_prprn","_tme"},
"Oct.":{"_prprn","_tme"},
"Octans":{"_prprn"},
"Octavia":{"_prprn"},
"octavian":{"_anim","_nme","_prprn","_sb"},
"octet":{"_sb"},
"October":{"_prprn","_tme"},
"Octobers":{"_prprn","_tme"},
"octogenarians":{"_anim","_sb"},
"octopus":{"_anim"},
"oculist":{"_anim","_sb"},
"odalisque":{"_anim","_fem","_sb"},
"oddball":{"_anim","_sb"},
"oddballs":{"_anim","_sb"},
"oder":{"_geo","_prprn"},
"Odessa":{"_cty","_geo","_prprn"},
"Odets":{"_anim","_nme","_prprn","_sb"},
"Odin":{"_anim","_masc","_nme","_prprn","_sb"},
"odist":{"_anim","_sb"},
"odoacer":{"_anim","_nme","_prprn","_sb"},
"odovacar":{"_anim","_nme","_prprn","_sb"},
"odovakar":{"_prprn"},
"Odysseus":{"_prprn"},
"OED":{"_prprn"},
"Oedipus":{"_prprn"},
"oenologist":{"_anim","_sb"},
"off-Broadway":{"_prprn"},
"off-hours":{"_tme"},
"off-season":{"_tme"},
"offenbach":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"offend":{"_psych"},
"offended":{"_past","_psych"},
"offender":{"_anim","_sb"},
"offenders":{"_anim","_sb"},
"offending":{"_psych"},
"offends":{"_psych"},
"offered":{"_past"},
"offerer":{"_anim","_sb"},
"office":{"_loc_sr"},
"office-bearer":{"_loc_sr"},
"office-equipment":{"_loc_sr"},
"office-furniture":{"_loc_sr"},
"office-product":{"_loc_sr"},
"office-products":{"_loc_sr"},
"office-supplies":{"_loc_sr"},
"office-supply":{"_loc_sr"},
"office-systems":{"_loc_sr"},
"officeholder":{"_anim","_sb"},
"officeholders":{"_anim","_sb"},
"officer":{"_anim","_sb"},
"officers":{"_anim","_sb"},
"offices":{"_loc_sr"},
"official":{"_anim","_sb"},
"officials":{"_anim","_sb"},
"officials-cum-drug-traffickers":{"_anim","_sb"},
"officiant":{"_anim","_sb"},
"offset":{"_past"},
"offspring":{"_sb"},
"oft":{"_tme"},
"oft-quoted":{"_tme"},
"oft-repeated":{"_tme"},
"often":{"_tme"},
"often-criticized":{"_tme"},
"often-disparaged":{"_tme"},
"often-fatal":{"_tme"},
"often-heard":{"_tme"},
"often-ignored":{"_tme"},
"often-repeated":{"_tme"},
"oftener":{"_tme"},
"oftentimes":{"_tme"},
"Ogden":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"oglala":{"_anim","_prprn","_sb"},
"ogled":{"_past"},
"ogler":{"_anim","_sb"},
"Oglethorpe":{"_anim","_nme","_prprn","_sb"},
"ogre":{"_anim","_sb"},
"Ohio":{"_geo","_prprn","_stte"},
"Oi":{"_prprn"},
"oilcan":{"_loc_sr"},
"oiled":{"_loc_sr","_past"},
"oilfield":{"_loc_sr"},
"oilfields":{"_loc_sr"},
"oilman":{"_anim","_sb"},
"oilman-rancher":{"_anim","_sb"},
"Oistrakh":{"_prprn"},
"Ojibwa":{"_anim","_prprn","_sb"},
"ojibway":{"_anim","_prprn","_sb"},
"OK":{"_prprn","_stte"},
"Oka":{"_geo","_prprn"},
"okapi":{"_anim"},
"Okayama":{"_cty","_geo","_prprn"},
"Okeechobee":{"_prprn"},
"Okinawa":{"_geo","_prprn"},
"Okla.":{"_prprn","_stte"},
"Oklahoma":{"_geo","_prprn","_stte"},
"oktoberfest":{"_prprn","_tme"},
"Ol":{"_prprn"},
"ola":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Olaf":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Olav":{"_prprn"},
"old":{"_tme"},
"old-age":{"_tme"},
"old-boy":{"_tme"},
"old-grad-type":{"_tme"},
"old-growth":{"_tme"},
"old-guard":{"_tme"},
"old-hat":{"_tme"},
"old-maidish":{"_tme"},
"old-man-of-the-woods":{"_tme"},
"old-model":{"_tme"},
"old-name":{"_tme"},
"old-school":{"_tme"},
"old-style":{"_tme"},
"old-timer":{"_anim","_sb"},
"old-timers":{"_anim","_sb"},
"Oldenburg":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"older":{"_tme"},
"oldest":{"_tme"},
"oldfield":{"_anim","_nme","_prprn","_sb"},
"Oldham":{"_geo","_prprn"},
"oldster":{"_anim","_sb"},
"oldsters":{"_anim","_sb"},
"Olga":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"oligarch":{"_anim","_sb"},
"oligarchs":{"_anim","_sb"},
"oligocene":{"_prprn"},
"Oliphant":{"_prprn"},
"Olivares":{"_prprn"},
"oliver":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Olivia":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Olivier":{"_anim","_nme","_prprn","_sb"},
"olmec":{"_prprn"},
"olmsted":{"_anim","_nme","_prprn","_sb"},
"Olympia":{"_cty","_geo","_prprn"},
"Olympiad":{"_prprn"},
"Olympian":{"_anim","_prprn","_sb"},
"Olympians":{"_anim","_prprn","_sb"},
"Olympics":{"_prprn"},
"Olympus":{"_geo","_prprn"},
"Omaha":{"_anim","_cty","_geo","_prprn","_sb"},
"Omani":{"_anim","_prprn","_sb"},
"omayyad":{"_anim","_nme","_prprn","_sb"},
"OMB":{"_prprn"},
"ombudsman":{"_anim","_masc","_sb"},
"Omdurman":{"_cty","_geo","_prprn"},
"omitted":{"_past"},
"omiya":{"_cty","_geo","_prprn"},
"ommiad":{"_anim","_nme","_prprn","_sb"},
"omsk":{"_cty","_geo","_prprn"},
"on":{"_loc"},
"on-again-off-again":{"_loc"},
"on-and-off":{"_loc"},
"on-base":{"_loc"},
"on-budget":{"_loc"},
"on-campus":{"_loc"},
"on-field":{"_loc"},
"on-going":{"_loc"},
"on-key":{"_loc"},
"on-level":{"_loc"},
"on-license":{"_loc"},
"on-ramps":{"_loc"},
"on-set":{"_loc"},
"on-street":{"_loc"},
"on-sure":{"_loc"},
"on-the-go":{"_loc"},
"on-time":{"_loc"},
"onager":{"_anim"},
"Onassis":{"_anim","_nme","_prprn","_sb"},
"once-a-day":{"_tme"},
"once-a-month":{"_tme"},
"once-absolute":{"_tme"},
"once-bloated":{"_tme"},
"once-bustling":{"_tme"},
"once-closed":{"_tme"},
"once-cozy":{"_tme"},
"once-desirable":{"_tme"},
"once-devoted":{"_tme"},
"once-distinct":{"_tme"},
"once-downtrodden":{"_tme"},
"once-dry":{"_tme"},
"once-dull":{"_tme"},
"once-faltering":{"_tme"},
"once-fashionable":{"_tme"},
"once-grumpy":{"_tme"},
"once-high-flying":{"_tme"},
"once-indomitable":{"_tme"},
"once-loyal":{"_tme"},
"once-lucrative":{"_tme"},
"once-mighty":{"_tme"},
"once-moribund":{"_tme"},
"once-over-lightly":{"_tme"},
"once-popular":{"_tme"},
"once-prestigious":{"_tme"},
"once-prevailing":{"_tme"},
"once-private":{"_tme"},
"once-profitable":{"_tme"},
"once-promising":{"_tme"},
"once-proud":{"_tme"},
"once-rich":{"_tme"},
"once-sacred":{"_tme"},
"once-scandalous":{"_tme"},
"once-sleepy":{"_tme"},
"once-sporadic":{"_tme"},
"once-staid":{"_tme"},
"once-stately":{"_tme"},
"once-stodgy":{"_tme"},
"once-strong":{"_tme"},
"once-troubled":{"_tme"},
"once-unprofitable":{"_tme"},
"once-unthinkable":{"_tme"},
"once-vast":{"_tme"},
"oncologist":{"_anim","_sb"},
"Ondaatje":{"_prprn"},
"one":{"_quant"},
"one-act":{"_num","_quant"},
"one-act-play":{"_num","_quant"},
"one-and-one":{"_num","_quant"},
"one-arm":{"_num","_quant"},
"one-by-one":{"_num","_quant"},
"one-day":{"_num","_quant"},
"one-eighth":{"_num","_quant"},
"one-fifth":{"_num","_quant"},
"one-fourth":{"_num","_quant"},
"one-hundred-millionth":{"_num","_quant"},
"one-hundred-thousandth":{"_num","_quant"},
"one-in-a-million":{"_num","_quant"},
"one-millionth":{"_num","_quant"},
"one-night":{"_num","_quant"},
"one-of-a-kind":{"_num","_quant"},
"one-owner":{"_num","_quant"},
"one-parent":{"_num","_quant"},
"one-party":{"_num","_quant"},
"one-reel":{"_num","_quant"},
"one-room":{"_num","_quant"},
"one-shots":{"_num","_quant"},
"one-sixteenth":{"_num","_quant"},
"one-sixth":{"_num","_quant"},
"one-sixtieth":{"_num","_quant"},
"one-stop":{"_num","_quant"},
"one-tenth":{"_num","_quant"},
"one-third":{"_num","_quant"},
"one-thirty":{"_num","_quant"},
"one-trillionth":{"_num","_quant"},
"one-twelfth":{"_num","_quant"},
"one-twentieth":{"_num","_quant"},
"one-two-three":{"_num","_quant"},
"one-upsmanship":{"_num","_quant"},
"ones":{"_num","_quant"},
"onlooker":{"_anim","_sb"},
"Onondaga":{"_anim","_prprn","_sb"},
"onsager":{"_anim","_nme","_prprn","_sb"},
"onstage":{"_loc"},
"Ont.":{"_prprn"},
"Ontario":{"_cty","_geo","_prprn","_stte"},
"onwards":{"_loc"},
"ooh":{"_loc_sr"},
"ooze":{"_loc_sr"},
"oozed":{"_loc_sr","_past"},
"oozing":{"_loc_sr"},
"OPEC":{"_prprn"},
"open-access":{"_loc_sr"},
"open-bank":{"_loc_sr"},
"open-chain":{"_loc_sr"},
"open-checkbook":{"_loc_sr"},
"open-door":{"_loc_sr"},
"open-face":{"_loc_sr"},
"open-interest":{"_loc_sr"},
"open-market":{"_loc_sr"},
"open-meeting":{"_loc_sr"},
"open-necked":{"_loc_sr"},
"open-plan":{"_loc_sr"},
"open-shelf":{"_loc_sr"},
"open-skies":{"_loc_sr"},
"open-top":{"_loc_sr"},
"open-work":{"_loc_sr"},
"open-year":{"_loc_sr"},
"opened":{"_loc_sr","_past"},
"opener":{"_sb"},
"opening":{"_loc_sr"},
"opens":{"_loc_sr"},
"operagoer":{"_anim","_sb"},
"operagoers":{"_anim","_sb"},
"operated":{"_past"},
"operationalist":{"_anim","_sb"},
"operative":{"_anim","_sb"},
"operatives":{"_anim","_sb"},
"operator":{"_anim","_sb"},
"operator-assisted":{"_anim","_sb"},
"operator-services":{"_anim","_sb"},
"operators":{"_anim","_sb"},
"ophidian":{"_sb"},
"ophiuchus":{"_prprn"},
"oporto":{"_cty","_geo","_prprn"},
"opossum":{"_anim"},
"Oppenheimer":{"_anim","_nme","_prprn","_sb"},
"opponent":{"_anim","_sb"},
"opponents":{"_anim","_sb"},
"opportunist":{"_anim","_sb"},
"opposed":{"_past"},
"opposer":{"_anim","_sb"},
"opposite":{"_sb"},
"opposites":{"_sb"},
"oppressed":{"_past"},
"oppressor":{"_anim","_sb"},
"oppressors":{"_anim","_sb"},
"oppugn":{"_loc_sr"},
"opted":{"_past"},
"optician":{"_anim","_sb"},
"opticians":{"_anim","_sb"},
"optimist":{"_anim","_sb"},
"optimists":{"_anim","_sb"},
"optioned":{"_past"},
"optometrist":{"_anim","_sb"},
"oracles":{"_loc_sr"},
"oran":{"_cty","_geo","_prprn"},
"orangeade":{"_loc_sr"},
"Orangeman":{"_prprn","_sb"},
"Orangemen":{"_prprn","_sb"},
"orangery":{"_loc_sr"},
"orangutan":{"_anim"},
"orangutang":{"_anim"},
"orators":{"_anim","_sb"},
"oratory":{"_loc_sr"},
"orbison":{"_anim","_nme","_prprn","_sb"},
"orbit":{"_loc_sr"},
"orbited":{"_loc_sr","_past"},
"orbiting":{"_loc_sr"},
"orca":{"_anim"},
"orchard":{"_loc_sr"},
"orchardists":{"_anim","_sb"},
"orchards":{"_loc_sr"},
"orchestra":{"_sb"},
"orchestras":{"_sb"},
"orchestrate":{"_loc_sr"},
"orchestrated":{"_loc_sr","_past"},
"orchestrating":{"_loc_sr"},
"orchestrator":{"_anim","_sb"},
"orchid":{"_sb"},
"orchid-strewn":{"_sb"},
"orchids":{"_sb"},
"orcus":{"_anim","_masc","_nme","_prprn","_sb"},
"orczy":{"_anim","_nme","_prprn","_sb"},
"Ord":{"_prprn"},
"ordained":{"_past"},
"ordainer":{"_anim","_sb"},
"orderer":{"_anim","_sb"},
"ordinand":{"_anim","_sb"},
"Ordovician":{"_prprn"},
"ore":{"_loc_sr"},
"Ore.":{"_loc_sr","_prprn","_stte"},
"Oregon":{"_cty","_geo","_prprn","_stte"},
"Orel":{"_cty","_geo","_prprn"},
"Orem":{"_cty","_geo","_prprn"},
"Oresme":{"_prprn"},
"Orestes":{"_prprn"},
"orff":{"_anim","_nme","_prprn","_sb"},
"organised":{"_past"},
"organiser":{"_anim","_sb"},
"organisms":{"_anim"},
"organist":{"_anim","_sb"},
"organize":{"_loc_sr"},
"organized":{"_loc_sr","_past"},
"organized-crime":{"_loc_sr","_past"},
"organizes":{"_loc_sr"},
"organizing":{"_loc_sr"},
"orient":{"_loc_sr"},
"Oriental":{"_prprn","_sb"},
"orientalist":{"_anim","_sb"},
"orientated":{"_past"},
"oriented":{"_loc_sr","_past"},
"oriented-polypropylene":{"_loc_sr","_past"},
"orienting":{"_loc_sr"},
"origen":{"_anim","_nme","_prprn","_sb"},
"originate":{"_loc_sr"},
"originating":{"_loc_sr"},
"Orinoco":{"_geo","_prprn"},
"oriole":{"_anim"},
"orion":{"_prprn"},
"Orissa":{"_prprn"},
"oriya":{"_prprn"},
"orizaba":{"_cty","_geo","_prprn"},
"Orkney":{"_prprn"},
"Orlando":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"orleanais":{"_geo","_prprn","_stte"},
"orleanist":{"_prprn"},
"orleans":{"_cty","_geo","_prprn"},
"orlon":{"_prprn"},
"Orly":{"_anim","_cty","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"ormandy":{"_anim","_nme","_prprn","_sb"},
"ormazd":{"_prprn"},
"ormuzd":{"_prprn"},
"ornamentalist":{"_anim","_sb"},
"ornamented":{"_past"},
"ornithosis":{"_sb"},
"Orozco":{"_anim","_nme","_prprn","_sb"},
"orphan":{"_anim","_sb"},
"orphanage":{"_loc_sr"},
"orphanages":{"_loc_sr"},
"orphaned":{"_past"},
"orphans":{"_anim","_sb"},
"Orpheus":{"_anim","_masc","_nme","_prprn","_sb"},
"orpington":{"_prprn"},
"orr":{"_anim","_nme","_prprn","_sb"},
"Orson":{"_prprn"},
"ortega":{"_anim","_nme","_prprn","_sb"},
"orthodontist":{"_anim","_sb"},
"orthodontists":{"_anim","_sb"},
"Orthodox":{"_prprn"},
"orthoepist":{"_anim","_sb"},
"ortolan":{"_anim"},
"Orville":{"_prprn"},
"Orwell":{"_anim","_nme","_prprn","_sb"},
"oryx":{"_anim"},
"Osage":{"_anim","_prprn","_sb"},
"Osaka":{"_cty","_geo","_prprn"},
"osasco":{"_cty","_geo","_prprn"},
"Osborn":{"_anim","_nme","_prprn","_sb"},
"oscan":{"_anim","_prprn","_sb"},
"oscan-speaking":{"_anim","_prprn","_sb"},
"Oscar":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"oscillate":{"_loc_sr"},
"oscillated":{"_loc_sr","_past"},
"osco-umbrian":{"_prprn"},
"osculator":{"_anim","_sb"},
"OSF":{"_prprn"},
"OSHA":{"_prprn"},
"Oshkosh":{"_cty","_geo","_prprn"},
"Osiris":{"_anim","_masc","_nme","_prprn","_sb"},
"Osler":{"_anim","_nme","_prprn","_sb"},
"Oslo":{"_cty","_geo","_prprn"},
"osmanli":{"_prprn"},
"osprey":{"_anim"},
"ossete":{"_prprn"},
"ossified":{"_loc_sr","_past"},
"ossuary":{"_loc_sr"},
"osteologist":{"_anim","_sb"},
"osteopath":{"_anim","_sb"},
"ostiary":{"_anim","_sb"},
"ostler":{"_anim","_sb"},
"ostracize":{"_loc_sr"},
"ostrava":{"_cty","_geo","_prprn"},
"ostrich":{"_anim"},
"ostrogoth":{"_prprn"},
"Ostrovsky":{"_prprn"},
"ostwald":{"_anim","_nme","_prprn","_sb"},
"ostyak":{"_anim","_prprn","_sb"},
"ostyak-samoyed":{"_anim","_prprn","_sb"},
"Oswald":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"OTC":{"_prprn"},
"Othello":{"_prprn"},
"Otis":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"oto":{"_anim","_prprn","_sb"},
"otolaryngologist":{"_anim","_sb"},
"otologist":{"_anim","_sb"},
"otorhinolaryngologist":{"_anim","_sb"},
"Ottawa":{"_anim","_cty","_geo","_prprn","_sb"},
"otter":{"_anim"},
"otters":{"_anim"},
"ottumwa":{"_cty","_geo","_prprn"},
"oubliette":{"_loc_sr"},
"Ouija":{"_prprn"},
"oujda":{"_cty","_geo","_prprn"},
"ourselves":{"_anim","_sb","_self"},
"Ouse":{"_prprn"},
"ousel":{"_anim"},
"oust":{"_loc_sr"},
"ousting":{"_loc_sr"},
"out-and-outer":{"_anim","_sb"},
"out-dated":{"_past"},
"out-group":{"_anim","_sb"},
"out-of-bounds":{"_loc"},
"out-plunging":{"_loc_sr"},
"outbalance":{"_loc_sr"},
"outbid":{"_past"},
"outbred":{"_past"},
"outbuilding":{"_loc_sr"},
"outcaste":{"_anim","_sb"},
"outcasts":{"_sb"},
"outdated":{"_past"},
"outdid":{"_loc_sr","_past"},
"outdistance":{"_loc_sr"},
"outdistanced":{"_loc_sr","_past"},
"outdistancing":{"_loc_sr"},
"outdo":{"_loc_sr"},
"outdone":{"_loc_sr"},
"outdoorsman":{"_anim","_masc","_sb"},
"outdoorswoman":{"_anim","_fem","_sb"},
"outdraw":{"_loc_sr"},
"outdrew":{"_loc_sr","_past"},
"outfall":{"_loc_sr"},
"outfield":{"_loc_sr"},
"outfielder":{"_anim","_sb"},
"outfielders":{"_anim","_sb"},
"outflank":{"_loc_sr"},
"outfought":{"_past"},
"outfox":{"_loc_sr"},
"outgained":{"_loc_sr","_past"},
"outgeneral":{"_loc_sr"},
"outgeneraled":{"_loc_sr","_past"},
"outlander":{"_anim","_sb"},
"outlanders":{"_anim","_sb"},
"outlasted":{"_past"},
"outlawed":{"_past"},
"outlaws":{"_anim","_sb"},
"outleaped":{"_loc_sr","_past"},
"outlier":{"_anim","_sb"},
"outlined":{"_past"},
"outlived":{"_past"},
"outmaneuvered":{"_past"},
"outmanoeuvre":{"_loc_sr"},
"outmatch":{"_loc_sr"},
"outmoded":{"_past"},
"outnumbered":{"_past"},
"outpaced":{"_past"},
"outpatient":{"_anim","_sb"},
"outperform":{"_loc_sr"},
"outperformed":{"_loc_sr","_past"},
"outperforms":{"_loc_sr"},
"outplayed":{"_past"},
"outpost":{"_sb"},
"outraged":{"_past","_psych"},
"outrange":{"_loc_sr"},
"outrider":{"_anim","_sb"},
"outrigged":{"_past"},
"outrival":{"_loc_sr"},
"outroar":{"_loc_sr"},
"outsail":{"_loc_sr"},
"outscore":{"_loc_sr"},
"outscored":{"_loc_sr","_past"},
"outscoring":{"_loc_sr"},
"outsell":{"_loc_sr"},
"outselling":{"_loc_sr"},
"outsells":{"_loc_sr"},
"outsider":{"_anim","_sb"},
"outsiders":{"_anim","_sb"},
"outsized":{"_past"},
"outskirts":{"_loc","_loc_sr"},
"outslugged":{"_past"},
"outsmarted":{"_past"},
"outsold":{"_loc_sr","_past"},
"outspread":{"_past"},
"outstate":{"_loc_sr"},
"outstretched":{"_past"},
"outstrip":{"_loc_sr"},
"outstripped":{"_loc_sr","_past"},
"outstrips":{"_loc_sr"},
"outtrade":{"_loc_sr"},
"outvote":{"_loc_sr"},
"outwardly":{"_loc"},
"outwit":{"_loc_sr"},
"ouzel":{"_anim"},
"oven":{"_loc_sr"},
"oven-ready":{"_loc_sr"},
"oven-shaped":{"_loc_sr"},
"over-achievers":{"_anim","_sb"},
"overachiever":{"_anim","_sb"},
"overaged":{"_sb"},
"overawe":{"_psych"},
"overawed":{"_past","_psych"},
"overbear":{"_loc_sr"},
"overbearing":{"_loc_sr"},
"overbid":{"_past"},
"overbilled":{"_loc_sr","_past"},
"overbilling":{"_loc_sr"},
"overboard":{"_loc"},
"overbuilt":{"_past"},
"overburdened":{"_past"},
"overcall":{"_loc_sr"},
"overcame":{"_loc_sr","_past"},
"overcast":{"_past"},
"overcharged":{"_past"},
"overcomer":{"_anim","_sb"},
"overcoming":{"_loc_sr"},
"overcommitted":{"_past"},
"overcompensate":{"_loc_sr"},
"overcooked":{"_past"},
"overcooks":{"_anim","_sb"},
"overcooled":{"_past"},
"overcorrected":{"_past"},
"overcrossing":{"_loc_sr"},
"overcrowded":{"_past"},
"overdeveloped":{"_past"},
"overdosed":{"_past"},
"overdraw":{"_loc_sr"},
"overdrawn":{"_loc_sr"},
"overdressed":{"_past"},
"overemphasize":{"_loc_sr"},
"overemphasized":{"_loc_sr","_past"},
"overestimated":{"_past"},
"overexcited":{"_past","_psych"},
"overexercised":{"_loc_sr","_past"},
"overexploited":{"_past"},
"overextended":{"_past"},
"overfed":{"_past"},
"overflowed":{"_past"},
"overfly":{"_loc_sr"},
"overfunded":{"_past"},
"overhanded":{"_past"},
"overhaul":{"_loc_sr"},
"overhauled":{"_loc_sr","_past"},
"overhauling":{"_loc_sr"},
"overheated":{"_past"},
"overhyped":{"_past"},
"overindulged":{"_past"},
"overinvested":{"_past"},
"overjoyed":{"_past"},
"overlaid":{"_past"},
"overlap":{"_loc_sr"},
"overlapped":{"_loc_sr","_past"},
"overlay":{"_past"},
"overlayer":{"_loc_sr"},
"overleveraged":{"_past"},
"overloaded":{"_past"},
"overlooked":{"_past"},
"overlooks":{"_loc_sr"},
"overlord":{"_anim","_sb"},
"overmedicated":{"_past"},
"overmuch":{"_quant"},
"overoccupied":{"_past"},
"overpaid":{"_past"},
"overpass":{"_loc_sr"},
"overplanted":{"_loc_sr","_past"},
"overplayed":{"_past"},
"overpopulated":{"_past"},
"overpopulation":{"_sb"},
"overpowered":{"_past"},
"overpriced":{"_past"},
"overproducers":{"_anim","_sb"},
"overprotected":{"_past"},
"overrated":{"_past"},
"overreached":{"_past"},
"overreacted":{"_past"},
"overrefined":{"_past"},
"overregulated":{"_past"},
"overruled":{"_past"},
"oversaw":{"_past"},
"overseer":{"_anim","_sb"},
"overseers":{"_anim","_sb"},
"overshielding":{"_loc_sr"},
"overshot":{"_loc_sr","_past"},
"overside":{"_loc"},
"oversimplified":{"_past"},
"oversized":{"_past"},
"oversold":{"_past"},
"overspread":{"_past"},
"overstaffed":{"_past"},
"overstated":{"_past"},
"overstitched":{"_past"},
"overstored":{"_past"},
"overstrained":{"_past"},
"overstuffed":{"_past"},
"oversubscribed":{"_past"},
"oversupplied":{"_past"},
"overtake":{"_loc_sr"},
"overtaken":{"_loc_sr"},
"overtaking":{"_loc_sr"},
"overtax":{"_loc_sr"},
"overtaxed":{"_loc_sr","_past"},
"overthrow":{"_loc_sr"},
"overthrowing":{"_loc_sr"},
"overthrown":{"_loc_sr"},
"overtire":{"_psych"},
"overtook":{"_loc_sr","_past"},
"overused":{"_past"},
"overvaliant":{"_sb"},
"overvalued":{"_past"},
"overvaulting":{"_loc_sr"},
"overweighted":{"_loc_sr","_past"},
"overwhelm":{"_psych"},
"overwhelmed":{"_past","_psych"},
"overworked":{"_past"},
"Ovid":{"_anim","_nme","_prprn","_sb"},
"oviduct":{"_loc_sr"},
"oviedo":{"_cty","_geo","_prprn"},
"ovimbundu":{"_prprn"},
"ovulate":{"_loc_sr"},
"owed":{"_past"},
"Owen":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Owens":{"_anim","_nme","_prprn","_sb"},
"owensboro":{"_cty","_geo","_prprn"},
"owl":{"_anim"},
"owl-shaped":{"_anim"},
"owlet":{"_anim"},
"owls":{"_anim"},
"owned":{"_past"},
"owner":{"_anim","_sb"},
"owner-bred":{"_anim","_sb"},
"owner-driver":{"_anim","_sb"},
"owner-occupier":{"_anim","_sb"},
"owners":{"_anim","_sb"},
"ox":{"_anim","_masc"},
"ox-eyed":{"_anim","_masc"},
"Oxbridge":{"_prprn"},
"oxen":{"_anim","_masc"},
"Oxford":{"_cty","_geo","_prprn"},
"Oxfordshire":{"_prprn"},
"oxidised":{"_past"},
"oxidiser":{"_anim","_sb"},
"oxidize":{"_loc_sr"},
"oxidized":{"_loc_sr","_past"},
"Oxnard":{"_cty","_geo","_prprn"},
"oxonian":{"_anim","_prprn","_sb"},
"Oy":{"_prprn"},
"oyster":{"_anim"},
"oyster-fish":{"_anim"},
"oystercatcher":{"_anim"},
"oysters":{"_anim"},
"ozawa":{"_anim","_nme","_prprn","_sb"},
"p.m.":{"_ampm","_tme"},
"p.m.-conclusion":{"_ampm","_tme"},
"p.m.-midnight":{"_ampm","_tme"},
"P.O.":{"_prprn"},
"P.S.":{"_prprn"},
"pa":{"_anim","_masc","_sb"},
"Pa.":{"_anim","_masc","_prprn","_sb","_stte"},
"paba":{"_prprn"},
"Pabst":{"_prprn"},
"PAC":{"_prprn"},
"paca":{"_anim"},
"paced":{"_loc_sr","_past"},
"pacemakers":{"_anim","_sb"},
"Pachelbel":{"_prprn"},
"pachuco":{"_anim","_sb"},
"pachyderm":{"_anim"},
"pacificist":{"_anim","_sb"},
"pacified":{"_past","_psych"},
"pacifies":{"_psych"},
"Pacino":{"_prprn"},
"pack":{"_loc_sr"},
"packaged":{"_loc_sr","_past"},
"packaged-goods":{"_loc_sr","_past"},
"packaging":{"_loc_sr"},
"packed":{"_loc_sr","_past"},
"packer":{"_anim","_sb"},
"packers":{"_anim","_sb"},
"packing":{"_loc_sr"},
"PACs":{"_prprn"},
"padder":{"_anim","_sb"},
"paddlefish":{"_anim"},
"paddler":{"_anim","_sb"},
"Paddy":{"_prprn"},
"Paderewski":{"_anim","_nme","_prprn","_sb"},
"padlocked":{"_past"},
"padrone":{"_anim","_sb"},
"padua":{"_cty","_geo","_prprn"},
"paducah":{"_cty","_geo","_prprn"},
"paederast":{"_anim","_masc","_sb"},
"paediatrician":{"_anim","_sb"},
"Paestum":{"_cty","_geo","_prprn"},
"pagan":{"_anim","_sb"},
"Paganini":{"_anim","_nme","_prprn","_sb"},
"pageboy":{"_sb"},
"paget":{"_anim","_nme","_prprn","_sb"},
"paginated":{"_past"},
"paging":{"_loc_sr"},
"Pagnol":{"_prprn"},
"pagodas":{"_loc_sr"},
"paid":{"_past"},
"paid-for":{"_past"},
"paid-in":{"_past"},
"pails":{"_loc_sr"},
"Paine":{"_anim","_nme","_prprn","_sb"},
"pained":{"_past","_psych"},
"painted-in":{"_past"},
"painter":{"_anim","_sb"},
"painters":{"_anim","_sb"},
"paintings":{"_loc_sr"},
"pair":{"_sb"},
"paired":{"_loc_sr","_past"},
"pairing":{"_loc_sr"},
"pairs":{"_sb"},
"Paisley":{"_geo","_prprn"},
"paiute":{"_prprn","_sb"},
"Pak":{"_prprn"},
"Pakistan":{"_cntry","_geo","_prprn"},
"Pakistani":{"_anim","_prprn","_sb"},
"Pakistanis":{"_anim","_prprn","_sb"},
"paladin":{"_anim","_masc","_sb"},
"palatalised":{"_past"},
"palatalize":{"_loc_sr"},
"palatalized":{"_loc_sr","_past"},
"Palatine":{"_geo","_prprn"},
"Palau":{"_cntry","_geo","_prprn"},
"paled":{"_past"},
"paleface":{"_anim","_sb"},
"paleo-indian":{"_prprn"},
"paleocene":{"_prprn"},
"paleographer":{"_anim","_sb"},
"paleographist":{"_anim","_sb"},
"paleozoic":{"_prprn"},
"palermo":{"_cty","_geo","_prprn"},
"Palestine":{"_cty","_geo","_prprn"},
"Palestinian":{"_anim","_prprn","_sb"},
"Palestinians":{"_anim","_prprn","_sb"},
"palestra":{"_loc_sr"},
"palestrina":{"_anim","_nme","_prprn","_sb"},
"Paley":{"_anim","_nme","_prprn","_sb"},
"palfrey":{"_anim"},
"palgrave":{"_anim","_nme","_prprn","_sb"},
"pali":{"_prprn"},
"Palladio":{"_anim","_nme","_prprn","_sb"},
"pallas":{"_prprn"},
"pallbearer":{"_anim","_sb"},
"palletized":{"_past"},
"Palma":{"_cty","_geo","_prprn"},
"Palmdale":{"_prprn"},
"Palme":{"_anim","_nme","_prprn","_sb"},
"palmed":{"_loc_sr","_past"},
"palmer":{"_anim","_sb"},
"palmist":{"_anim","_sb"},
"palmister":{"_anim","_sb"},
"Palomar":{"_prprn"},
"palomino":{"_anim"},
"Palos":{"_prprn"},
"palpitate":{"_loc_sr"},
"palpitating":{"_loc_sr"},
"pals":{"_anim","_sb"},
"palsied":{"_past"},
"Paltrow":{"_prprn"},
"Pamela":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"pampas":{"_loc_sr"},
"pampered":{"_past"},
"pamperer":{"_anim","_sb"},
"pan":{"_loc_sr"},
"pan-European":{"_loc_sr"},
"pan-fry":{"_loc_sr"},
"pan-national":{"_loc_sr"},
"pan-nationalism":{"_loc_sr"},
"pan-tribal":{"_loc_sr"},
"panama":{"_sb"},
"Panamanian":{"_anim","_prprn","_sb"},
"pancake":{"_loc_sr"},
"panda":{"_anim"},
"pandar":{"_prprn"},
"panderer":{"_anim","_sb"},
"panders":{"_anim","_sb"},
"Pandora":{"_prprn","_sb"},
"panegyrist":{"_anim","_sb"},
"paneled":{"_past"},
"panelist":{"_sb"},
"panelists":{"_sb"},
"panellist":{"_anim","_sb"},
"Pangaea":{"_prprn"},
"pangea":{"_prprn"},
"Pangloss":{"_prprn"},
"panhandle":{"_loc_sr"},
"panicked":{"_past"},
"panini":{"_anim","_nme","_prprn","_sb"},
"panjabi":{"_prprn"},
"Panmunjom":{"_geo","_prprn"},
"panned":{"_loc_sr","_past"},
"panning":{"_loc_sr"},
"panorama":{"_loc_sr"},
"panoramas":{"_loc_sr"},
"pans":{"_loc_sr"},
"pant":{"_loc_sr"},
"panted":{"_loc_sr","_past"},
"panther":{"_anim"},
"panthers":{"_anim"},
"panting":{"_loc_sr"},
"pantomimed":{"_past"},
"pantomimist":{"_anim","_sb"},
"Panza":{"_prprn"},
"Paolo":{"_prprn"},
"Papandreou":{"_anim","_nme","_prprn","_sb"},
"papeete":{"_cty","_geo","_prprn"},
"paperhanger":{"_anim","_sb"},
"papoose":{"_anim","_sb"},
"Papua":{"_prprn"},
"Papuan":{"_anim","_prprn","_sb"},
"Para":{"_geo","_prprn"},
"paracelsus":{"_anim","_nme","_prprn","_sb"},
"parachuter":{"_anim","_sb"},
"parachutist":{"_anim","_sb"},
"paraclete":{"_prprn"},
"paraded":{"_loc_sr","_past"},
"parader":{"_anim","_sb"},
"parading":{"_loc_sr"},
"Paradise":{"_geo","_prprn"},
"paragon":{"_sb"},
"paragrapher":{"_anim","_sb"},
"paragraphing":{"_loc_sr"},
"Paraguay":{"_cntry","_geo","_prprn"},
"Paraguayan":{"_anim","_prprn","_sb"},
"parakeets":{"_anim"},
"paralleled":{"_past"},
"paralytic":{"_anim","_sb"},
"paralyzed":{"_past"},
"paramaribo":{"_cty","_geo","_prprn"},
"paramedic":{"_anim","_sb"},
"paramedics":{"_anim","_sb"},
"paramilitaries":{"_sb"},
"paramilitary":{"_sb"},
"paramour":{"_anim","_sb"},
"parana":{"_cty","_geo","_prprn"},
"paranoiac":{"_sb"},
"paranoid":{"_sb"},
"paraphrase":{"_loc_sr"},
"paraphrasing":{"_loc_sr"},
"paraplegic":{"_anim","_sb"},
"paraprofessional":{"_sb"},
"parapsychologist":{"_anim","_sb"},
"parasail":{"_loc_sr"},
"parasailing":{"_loc_sr"},
"paratrooper":{"_anim","_sb"},
"paratroopers":{"_anim","_sb"},
"parboiled":{"_past"},
"parcae":{"_prprn"},
"parceling":{"_loc_sr"},
"parcelling":{"_loc_sr"},
"parched":{"_past"},
"parcheesi":{"_prprn"},
"pardon":{"_loc_sr"},
"pardoner":{"_anim","_sb"},
"pared":{"_past"},
"pared-down":{"_past"},
"parent":{"_anim","_sb"},
"parent-child":{"_anim","_sb"},
"parent-company":{"_anim","_sb"},
"parent-teacher":{"_anim","_sb"},
"parented":{"_past"},
"parents":{"_anim","_sb"},
"pareto":{"_anim","_nme","_prprn","_sb"},
"pariah":{"_anim","_sb"},
"pariahs":{"_anim","_sb"},
"paris":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"parishes":{"_loc_sr"},
"parishioner":{"_anim","_sb"},
"parishioners":{"_anim","_sb"},
"Parisian":{"_prprn","_sb"},
"Parisians":{"_prprn","_sb"},
"park":{"_loc_sr"},
"parked":{"_past"},
"Parker":{"_anim","_sb"},
"parkersburg":{"_cty","_geo","_prprn"},
"parkinsonism":{"_prprn"},
"parkland":{"_loc_sr"},
"parks":{"_loc_sr"},
"parlay":{"_loc_sr"},
"parlayed":{"_loc_sr","_past"},
"Parliament":{"_sb"},
"parliamentarian":{"_anim","_sb"},
"parliamentarians":{"_anim","_sb"},
"parliaments":{"_sb"},
"parlor":{"_loc_sr"},
"parlors":{"_loc_sr"},
"parlour":{"_loc_sr"},
"parmenides":{"_anim","_nme","_prprn","_sb"},
"parnaiba":{"_geo","_prprn"},
"Parnassus":{"_geo","_prprn"},
"Parnell":{"_anim","_nme","_prprn","_sb"},
"parodied":{"_past"},
"parodist":{"_anim","_sb"},
"parolee":{"_anim","_sb"},
"parolees":{"_anim","_sb"},
"parousia":{"_prprn"},
"parr":{"_anim"},
"Parrish":{"_anim","_nme","_prprn","_sb"},
"parrot":{"_anim"},
"parrot-like":{"_anim"},
"parrotfish":{"_anim"},
"parrots":{"_anim"},
"Parry":{"_anim","_prprn","_sb"},
"parse":{"_loc_sr"},
"Parsee":{"_prprn","_sb"},
"Parsi":{"_prprn"},
"Parsifal":{"_prprn"},
"parsing":{"_loc_sr"},
"parsley":{"_sb"},
"parsons":{"_anim","_sb"},
"partaker":{"_anim","_sb"},
"parted":{"_loc_sr","_past"},
"parterre":{"_loc_sr"},
"Parthenon":{"_prprn"},
"parthia":{"_cntry","_geo","_prprn"},
"parthian":{"_anim","_prprn","_sb"},
"participant":{"_anim","_sb"},
"participants":{"_anim","_sb"},
"participated":{"_loc_sr","_past"},
"particularised":{"_past"},
"particularized":{"_past"},
"parties":{"_anim","_sb"},
"parting":{"_loc_sr"},
"partisan":{"_anim","_sb"},
"partisans":{"_anim","_sb"},
"partitioned":{"_loc_sr","_past"},
"partitioning":{"_loc_sr"},
"partitionist":{"_anim","_sb"},
"partner":{"_anim","_sb"},
"partner-in-charge":{"_anim","_sb"},
"partner-notification":{"_anim","_sb"},
"partnered":{"_past"},
"partners":{"_anim","_sb"},
"partook":{"_past"},
"partridge":{"_anim"},
"parts":{"_loc_sr"},
"parts-engineering":{"_loc_sr"},
"parts-suppliers":{"_loc_sr"},
"party":{"_anim","_sb"},
"party-giving":{"_anim","_sb"},
"party-spirited":{"_anim","_sb"},
"partygoer":{"_anim","_sb"},
"parvenu":{"_anim","_sb"},
"parvenus":{"_anim","_sb"},
"parvis":{"_loc_sr"},
"Pasadena":{"_cty","_geo","_prprn"},
"pasch":{"_prprn"},
"pashto":{"_prprn"},
"Pashtun":{"_prprn"},
"pasiphae":{"_anim","_fem","_nme","_prprn","_sb"},
"pass":{"_loc_sr"},
"Passaic":{"_cty","_geo","_prprn"},
"passed":{"_loc_sr","_past"},
"passee":{"_anim","_sb"},
"passenger":{"_anim","_sb"},
"passenger-car":{"_anim","_sb"},
"passenger-kilometers":{"_anim","_sb"},
"passenger-loading":{"_anim","_sb"},
"passenger-mile":{"_anim","_sb"},
"passenger-miles":{"_anim","_sb"},
"passenger-reservation":{"_anim","_sb"},
"passenger-restraint":{"_anim","_sb"},
"passenger-tire":{"_anim","_sb"},
"passenger-transportation":{"_anim","_sb"},
"passengers":{"_anim","_sb"},
"passing":{"_loc_sr"},
"Passover":{"_prprn","_tme"},
"past":{"_tme"},
"past-due":{"_tme"},
"past-fantasy":{"_tme"},
"past-oriented":{"_tme"},
"pasted":{"_past"},
"pasted-in":{"_past"},
"pastern":{"_anim"},
"Pasternak":{"_anim","_nme","_prprn","_sb"},
"Pasteur":{"_anim","_nme","_prprn","_sb"},
"pasteurised":{"_past"},
"pasteurized":{"_past"},
"pasto":{"_cty","_geo","_prprn"},
"pastor":{"_anim","_sb"},
"pastors":{"_anim","_sb"},
"pastries":{"_loc_sr"},
"pastry":{"_loc_sr"},
"pastry-lined":{"_loc_sr"},
"pasture":{"_loc_sr"},
"Pat":{"_anim","_fem","_fnme","_masc","_nme","_prprn","_sb"},
"Patagonia":{"_geo","_prprn"},
"patch":{"_loc_sr"},
"patched":{"_loc_sr","_past"},
"patching":{"_loc_sr"},
"patented":{"_loc_sr","_past"},
"patentee":{"_anim","_sb"},
"patenting":{"_loc_sr"},
"Pater":{"_anim","_masc","_prprn","_sb"},
"paterfamilias":{"_anim","_masc","_sb"},
"paterson":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"pathan":{"_anim","_prprn","_sb"},
"patient":{"_anim","_sb"},
"patient-advocacy":{"_anim","_sb"},
"patient-care":{"_anim","_sb"},
"patient-interview":{"_anim","_sb"},
"patient-physician":{"_anim","_sb"},
"patients":{"_anim","_sb"},
"patio":{"_loc_sr"},
"Patmore":{"_anim","_nme","_prprn","_sb"},
"Paton":{"_anim","_nme","_prprn","_sb"},
"patrai":{"_cty","_geo","_prprn"},
"patras":{"_prprn"},
"patrial":{"_anim","_sb"},
"patriarch":{"_anim","_masc","_sb"},
"Patricia":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"patrician":{"_anim","_sb"},
"Patrick":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"patriot":{"_anim","_sb"},
"patriots":{"_anim","_sb"},
"patroclus":{"_prprn"},
"patrolled":{"_loc_sr","_past"},
"patroller":{"_anim","_sb"},
"patrolling":{"_loc_sr"},
"patrolman":{"_anim","_sb"},
"patrolmen":{"_anim","_sb"},
"patron":{"_anim","_sb"},
"patronised":{"_past"},
"patronized":{"_past"},
"patrons":{"_anim","_sb"},
"patsies":{"_anim","_sb"},
"patted":{"_past"},
"pattered":{"_past"},
"patterned":{"_past"},
"patternmaker":{"_anim","_sb"},
"Patti":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Patton":{"_anim","_nme","_prprn","_sb"},
"Paul":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Paula":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"pauli":{"_anim","_nme","_prprn","_sb"},
"Pauline":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Pauling":{"_anim","_nme","_prprn","_sb"},
"pauper":{"_anim","_sb"},
"paused":{"_past"},
"paved":{"_past"},
"pavement":{"_loc_sr"},
"pavement-performance":{"_loc_sr"},
"pavements":{"_loc_sr"},
"Pavese":{"_prprn"},
"pavilion":{"_loc_sr"},
"pavilions":{"_loc_sr"},
"Pavlov":{"_anim","_nme","_prprn","_sb"},
"Pavlova":{"_anim","_nme","_prprn","_sb"},
"pavo":{"_prprn"},
"pawed":{"_past"},
"pawer":{"_anim","_sb"},
"pawnbroker":{"_anim","_sb"},
"pawnee":{"_anim","_prprn","_sb"},
"pawpaw":{"_anim"},
"Pawtucket":{"_cty","_geo","_prprn"},
"Pax":{"_prprn"},
"Paxton":{"_prprn"},
"pay-TV":{"_prprn"},
"payday":{"_tme"},
"PAYE":{"_prprn"},
"payee":{"_anim","_sb"},
"payers":{"_anim","_sb"},
"paynim":{"_anim","_sb"},
"Paz":{"_anim","_nme","_prprn","_sb"},
"pb":{"_prprn"},
"PBS":{"_prprn"},
"PCP":{"_prprn"},
"pd":{"_prprn"},
"PDA":{"_prprn"},
"pea":{"_sb"},
"pea-chick":{"_sb"},
"pea-green":{"_sb"},
"pea-souper":{"_sb"},
"Peabody":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"peacemakers":{"_anim","_sb"},
"peacetime":{"_tme"},
"peachick":{"_anim"},
"Peacock":{"_anim","_masc","_prprn","_sb"},
"peacock-blue":{"_anim","_masc"},
"peacock-throne":{"_anim","_masc"},
"peacocks":{"_anim","_masc"},
"peafowl":{"_anim"},
"peahen":{"_anim","_fem"},
"Peake":{"_prprn"},
"peaked":{"_past"},
"peal":{"_loc_sr"},
"Peale":{"_anim","_nme","_prprn","_sb"},
"pealing":{"_loc_sr"},
"pearl":{"_loc_sr"},
"Pearson":{"_anim","_nme","_prprn","_sb"},
"Peary":{"_anim","_nme","_prprn","_sb"},
"peas":{"_sb"},
"peasant":{"_anim","_sb"},
"peasants":{"_anim","_sb"},
"peccary":{"_anim"},
"Pechora":{"_geo","_prprn"},
"Peck":{"_anim","_prprn","_sb"},
"Pecos":{"_geo","_prprn"},
"peculate":{"_loc_sr"},
"peculator":{"_anim","_sb"},
"pedaled":{"_past"},
"pedaler":{"_anim","_sb"},
"pedant":{"_anim","_sb"},
"peddle":{"_loc_sr"},
"peddled":{"_loc_sr","_past"},
"peddlers":{"_anim","_sb"},
"peddles":{"_loc_sr"},
"peddling":{"_loc_sr"},
"pederast":{"_anim","_masc","_sb"},
"pedestrians":{"_anim","_loc_sr","_sb"},
"pediatricians":{"_anim","_sb"},
"pedlar":{"_anim","_sb"},
"Peebles":{"_prprn"},
"peed":{"_past"},
"peeled":{"_past"},
"peeper":{"_anim"},
"peer-group":{"_anim","_sb"},
"peered":{"_past"},
"peeress":{"_anim","_fem","_sb"},
"peers":{"_anim","_sb"},
"peeved":{"_past","_psych"},
"peewit":{"_anim"},
"Pegasus":{"_prprn"},
"pegged":{"_past"},
"Peggy":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"pehlevi":{"_prprn"},
"Pei":{"_anim","_nme","_prprn","_sb","_stte"},
"Peiping":{"_geo","_prprn"},
"Peirce":{"_anim","_nme","_prprn","_sb"},
"pekan":{"_anim"},
"pekinese":{"_anim"},
"Peking":{"_geo","_prprn"},
"Pekingese":{"_prprn"},
"pelagianism":{"_prprn"},
"peleus":{"_prprn"},
"Pelham":{"_prprn"},
"pelican":{"_anim"},
"pellet":{"_loc_sr"},
"Peloponnese":{"_geo","_prprn"},
"peloponnesus":{"_geo","_prprn"},
"pelt":{"_wthr"},
"pelter":{"_anim","_sb"},
"Pembroke":{"_prprn"},
"pen":{"_loc_sr"},
"pen-and-pencil":{"_loc_sr"},
"pen-friend":{"_loc_sr"},
"pen-tail":{"_loc_sr"},
"penalize":{"_loc_sr"},
"penalized":{"_loc_sr","_past"},
"penalizes":{"_loc_sr"},
"penalizing":{"_loc_sr"},
"Penang":{"_geo","_prprn"},
"penciled":{"_past"},
"pencilled":{"_past"},
"Pendleton":{"_anim","_nme","_prprn","_sb"},
"penetralia":{"_loc_sr"},
"penetrate":{"_loc_sr"},
"penetrator":{"_anim","_sb"},
"Penfield":{"_prprn"},
"penguin":{"_anim"},
"penguins":{"_anim"},
"peninsula":{"_geo","_loc_sr"},
"penitent":{"_anim","_sb"},
"Penn":{"_anim","_prprn","_sb"},
"Pennell":{"_anim","_nme","_prprn","_sb"},
"Penney":{"_anim","_nme","_prprn","_sb"},
"Pennines":{"_geo","_loc_sr","_prprn"},
"Pennsylvania":{"_geo","_prprn","_stte"},
"penobscot":{"_anim","_prprn","_sb"},
"penologist":{"_anim","_sb"},
"Penrose":{"_prprn"},
"pens":{"_loc_sr"},
"pensacola":{"_cty","_geo","_prprn"},
"pension":{"_sb"},
"pension-fund":{"_sb"},
"pension-industry":{"_sb"},
"pension-insurance":{"_sb"},
"pension-minded":{"_sb"},
"pension-plan":{"_sb"},
"pension-tax":{"_sb"},
"pensioners":{"_anim","_sb"},
"pensions":{"_sb"},
"pent":{"_loc_sr","_past"},
"Pentagon":{"_loc_sr","_prprn"},
"pentateuch":{"_prprn"},
"pentecostal":{"_prprn","_sb"},
"pentecostalism":{"_prprn"},
"pentecostalist":{"_prprn"},
"pentothal":{"_prprn"},
"penumbra":{"_loc_sr"},
"penutian":{"_prprn"},
"peon":{"_anim","_sb"},
"people":{"_anim","_sb"},
"people-oriented":{"_anim","_sb"},
"peopled":{"_past"},
"peoples":{"_anim","_sb"},
"Peoria":{"_anim","_cty","_geo","_prprn","_sb"},
"peppered":{"_past"},
"Pepys":{"_anim","_nme","_prprn","_sb"},
"Pera":{"_prprn"},
"perambulate":{"_loc_sr"},
"perambulating":{"_loc_sr"},
"perceive":{"_loc_sr"},
"perceiver":{"_anim","_sb"},
"perceiving":{"_loc_sr"},
"percenter":{"_anim","_sb"},
"percheron":{"_prprn"},
"percolate":{"_loc_sr"},
"percussionist":{"_anim","_sb"},
"Percy":{"_anim","_nme","_prprn","_sb"},
"Perdido":{"_prprn"},
"peregrinate":{"_loc_sr"},
"Pereira":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Perelman":{"_anim","_nme","_prprn","_sb"},
"perennially":{"_tme"},
"perfected":{"_past"},
"perfecter":{"_anim","_sb"},
"perfectionist":{"_anim","_sb"},
"perfectionists":{"_anim","_sb"},
"perforated":{"_past"},
"performed":{"_past"},
"performer":{"_sb"},
"performers":{"_sb"},
"perfumed":{"_past"},
"perfumer":{"_anim","_sb"},
"pergamum":{"_cty","_geo","_prprn"},
"Pergolesi":{"_anim","_nme","_prprn","_sb"},
"Periclean":{"_prprn"},
"Pericles":{"_anim","_nme","_prprn","_sb"},
"perigee":{"_loc_sr"},
"perinatologist":{"_anim","_sb"},
"period":{"_tme"},
"periodically":{"_tme"},
"periods":{"_tme"},
"peripatetic":{"_anim","_sb"},
"periphery":{"_loc_sr"},
"perished":{"_past"},
"perisher":{"_anim","_sb"},
"perjure":{"_loc_sr"},
"perjurer":{"_anim","_sb"},
"Perkins":{"_anim","_nme","_prprn","_sb"},
"Perlman":{"_anim","_nme","_prprn","_sb"},
"permalloy":{"_prprn"},
"permanency":{"_anim","_sb"},
"permeate":{"_loc_sr"},
"permeated":{"_loc_sr","_past"},
"permeates":{"_loc_sr"},
"permeating":{"_loc_sr"},
"permed":{"_past"},
"Permian":{"_prprn"},
"permitted":{"_past"},
"permute":{"_loc_sr"},
"Pernod":{"_prprn"},
"Peronist":{"_anim","_sb"},
"perpetually":{"_tme"},
"perpetuated":{"_past"},
"perplex":{"_psych"},
"perplexed":{"_past","_psych"},
"perplexing":{"_psych"},
"Perrier":{"_prprn"},
"Perrin":{"_anim","_nme","_prprn","_sb"},
"Perry":{"_anim","_fnme","_nme","_prprn","_sb"},
"Perse":{"_prprn"},
"Persephone":{"_prprn"},
"persepolis":{"_cty","_geo","_prprn"},
"Perseus":{"_prprn"},
"persevered":{"_loc_sr","_past"},
"perseveres":{"_loc_sr"},
"persevering":{"_loc_sr"},
"pershing":{"_anim","_nme","_prprn","_sb"},
"Persia":{"_cntry","_geo","_prprn"},
"Persians":{"_anim","_prprn","_sb"},
"persisted":{"_past"},
"person":{"_anim","_sb"},
"Persona":{"_sb"},
"personages":{"_anim","_sb"},
"personalised":{"_past"},
"personalities":{"_sb"},
"personality":{"_sb"},
"personalized":{"_past"},
"personhood":{"_sb"},
"personified":{"_past"},
"personnel":{"_anim","_sb"},
"persons":{"_anim","_sb"},
"perspired":{"_loc_sr","_past"},
"perspirer":{"_anim","_sb"},
"persuaded":{"_past"},
"persuader":{"_anim","_sb"},
"persuaders":{"_anim","_sb"},
"pertained":{"_past"},
"Perth":{"_cty","_geo","_prprn"},
"perturb":{"_psych"},
"perturbed":{"_past","_psych"},
"perturbing":{"_psych"},
"perutz":{"_anim","_nme","_prprn","_sb"},
"Peruvian":{"_anim","_prprn","_sb"},
"pervade":{"_loc_sr"},
"pervading":{"_loc_sr"},
"pesach":{"_prprn"},
"Pesaro":{"_cty","_geo","_prprn"},
"Peshawar":{"_cty","_geo","_prprn"},
"pessimist":{"_anim","_sb"},
"pest":{"_anim","_sb"},
"pestered":{"_past"},
"pesterer":{"_anim","_sb"},
"pesthole":{"_loc_sr"},
"pests":{"_anim","_sb"},
"pet-food":{"_anim"},
"pet-rabbit-raising":{"_anim"},
"Pete":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Peter":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Peterborough":{"_cty","_geo","_prprn"},
"petered":{"_past"},
"Petersburg":{"_cty","_geo","_prprn"},
"Peterson":{"_anim","_nme","_prprn","_sb"},
"Petipa":{"_prprn"},
"petitioned":{"_past"},
"petitioner":{"_anim","_sb"},
"petrarca":{"_prprn"},
"Petrarch":{"_anim","_nme","_prprn","_sb"},
"Petrarchan":{"_prprn"},
"petrel":{"_anim"},
"Petrie":{"_anim","_nme","_prprn","_sb"},
"petrify":{"_loc_sr","_psych"},
"petrifying":{"_loc_sr","_psych"},
"Petrograd":{"_geo","_prprn"},
"petronius":{"_anim","_nme","_prprn","_sb"},
"pets":{"_anim"},
"petted":{"_past"},
"petter":{"_anim","_sb"},
"pettifogger":{"_anim","_sb"},
"pewit":{"_anim"},
"Pfc":{"_prprn"},
"Ph.D.":{"_prprn"},
"phaethon":{"_anim","_masc","_nme","_prprn","_sb"},
"phalanger":{"_anim"},
"phalangist":{"_anim","_sb"},
"phalarope":{"_anim"},
"Pharaoh":{"_anim","_prprn","_sb"},
"pharaohs":{"_anim","_sb"},
"Pharisee":{"_anim","_prprn","_sb"},
"pharmacist":{"_anim","_sb"},
"pharmacists":{"_anim","_sb"},
"pharsalus":{"_cty","_geo","_prprn"},
"phased":{"_past"},
"phases":{"_tme"},
"PhD":{"_prprn"},
"pheasant":{"_anim"},
"pheasant's-eye":{"_anim"},
"pheasants":{"_anim"},
"Phelps":{"_anim","_nme","_prprn","_sb"},
"phenom":{"_sb"},
"Phidias":{"_anim","_nme","_prprn","_sb"},
"Phil":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Philadelphia":{"_cty","_geo","_prprn"},
"philander":{"_loc_sr"},
"philanderer":{"_anim","_sb"},
"philandering":{"_loc_sr"},
"philanthropists":{"_anim","_sb"},
"philatelist":{"_anim","_sb"},
"Philemon":{"_anim","_masc","_nme","_prprn","_sb"},
"philhellene":{"_anim","_sb"},
"Philip":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Philippe":{"_prprn"},
"Philippi":{"_geo","_prprn"},
"Philippians":{"_anim","_prprn","_sb"},
"Philippines":{"_cntry","_geo","_prprn"},
"philistia":{"_geo","_prprn"},
"philistine":{"_anim","_sb"},
"Phillip":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Phillips":{"_anim","_nme","_prprn","_sb"},
"Philo":{"_prprn"},
"philologist":{"_anim","_sb"},
"philologists":{"_anim","_sb"},
"philosopher":{"_anim","_sb"},
"philosophers":{"_anim","_sb"},
"philosophiser":{"_anim","_sb"},
"philosophized":{"_past"},
"philosophizer":{"_anim","_sb"},
"Phineas":{"_prprn"},
"phlebotomist":{"_anim","_sb"},
"phobic":{"_anim","_sb"},
"phobic-like":{"_anim","_sb"},
"Phobos":{"_prprn"},
"phoebus":{"_anim","_masc","_nme","_prprn","_sb"},
"Phoenicia":{"_cntry","_geo","_prprn"},
"Phoenician":{"_anim","_prprn","_sb"},
"phoned":{"_past"},
"phoner":{"_anim","_sb"},
"phonetician":{"_anim","_sb"},
"phonies":{"_anim","_sb"},
"phosphoresce":{"_loc_sr"},
"photofinishers":{"_anim","_sb"},
"photographed":{"_past"},
"photographer":{"_anim","_sb"},
"photographers":{"_anim","_sb"},
"photometrician":{"_anim","_sb"},
"photometrist":{"_anim","_sb"},
"phrase":{"_loc_sr"},
"phrasing":{"_loc_sr"},
"phrygia":{"_geo","_prprn"},
"phrygian":{"_anim","_prprn","_sb"},
"PHS":{"_prprn"},
"Phyfe":{"_anim","_nme","_prprn","_sb"},
"Phyllis":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"phylloxera":{"_anim"},
"physician":{"_anim","_sb"},
"physician-executive":{"_anim","_sb"},
"physician-owned":{"_anim","_sb"},
"physician-patient":{"_anim","_sb"},
"physicians":{"_anim","_sb"},
"physicist":{"_anim","_sb"},
"physicists":{"_anim","_sb"},
"phytologist":{"_anim","_sb"},
"Piaf":{"_anim","_nme","_prprn","_sb"},
"piaget":{"_anim","_nme","_prprn","_sb"},
"pianist":{"_anim","_sb"},
"pianist-comedian":{"_anim","_sb"},
"pianists":{"_anim","_sb"},
"pianola":{"_prprn"},
"picador":{"_anim","_sb"},
"Picard":{"_anim","_nme","_prprn","_sb"},
"picardy":{"_geo","_prprn"},
"Picasso":{"_anim","_nme","_prprn","_sb"},
"Piccadilly":{"_prprn"},
"piccaninny":{"_anim","_sb"},
"pichiciego":{"_anim"},
"pick":{"_loc_sr"},
"picked":{"_loc_sr","_past"},
"picker":{"_sb"},
"pickerel":{"_anim"},
"Pickering":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"pickers":{"_sb"},
"picketed":{"_past"},
"pickett":{"_anim","_nme","_prprn","_sb"},
"Pickford":{"_anim","_nme","_prprn","_sb"},
"picking":{"_loc_sr"},
"pickle":{"_loc_sr"},
"pickled":{"_loc_sr","_past"},
"pickles":{"_loc_sr"},
"picnicked":{"_loc_sr","_past"},
"picnicker":{"_anim","_sb"},
"picnickers":{"_anim","_sb"},
"picocassette":{"_loc_sr"},
"picoides":{"_tme"},
"Pictor":{"_prprn"},
"PID":{"_prprn"},
"piebald":{"_anim"},
"pieced":{"_past"},
"pied":{"_past"},
"pied-a-terre":{"_loc_sr"},
"piedmont":{"_loc_sr"},
"pierce":{"_loc_sr"},
"pierced":{"_loc_sr","_past"},
"piercing":{"_loc_sr"},
"Pierre":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"pierrot":{"_prprn","_sb"},
"pig":{"_anim"},
"pig-a-back":{"_anim"},
"pig-drunk":{"_anim"},
"pig-headedly":{"_anim"},
"pig-infested":{"_anim"},
"pig-sized":{"_anim"},
"pigeon":{"_anim"},
"pigeon-breasted":{"_anim"},
"pigeon-holed":{"_anim"},
"pigeonhole":{"_loc_sr"},
"pigeonholing":{"_loc_sr"},
"pigeons":{"_anim"},
"pigfish":{"_anim"},
"piggery":{"_loc_sr"},
"piggy":{"_anim"},
"piglets":{"_anim"},
"pigmented":{"_past"},
"pigmy":{"_anim","_sb"},
"Pigs":{"_anim"},
"pike":{"_anim","_loc_sr"},
"pike-perch":{"_anim","_loc_sr"},
"piker":{"_anim","_sb"},
"Pilate":{"_anim","_nme","_prprn","_sb"},
"pilchard":{"_anim"},
"piled":{"_past"},
"pilfering":{"_loc_sr"},
"Pilgrim":{"_anim","_sb"},
"pilgrims":{"_anim","_sb"},
"Pilipino":{"_prprn"},
"pillaged":{"_past"},
"pillared":{"_past"},
"pillock":{"_anim","_sb"},
"pilloried":{"_past"},
"pilot":{"_anim","_sb"},
"pilot-dominated":{"_anim","_sb"},
"pilot-management":{"_anim","_sb"},
"pilot-seniority":{"_anim","_sb"},
"pilot-union":{"_anim","_sb"},
"pilothouse":{"_loc_sr"},
"pilots":{"_anim","_sb"},
"Pils":{"_prprn"},
"Pilsner":{"_prprn"},
"pima":{"_anim","_prprn","_sb"},
"pimps":{"_anim","_sb"},
"pinata":{"_loc_sr"},
"pinch-hit":{"_past"},
"pinch-hitter":{"_anim","_sb"},
"pinch-hitters":{"_anim","_sb"},
"pinched":{"_past"},
"Pincus":{"_prprn"},
"pindar":{"_anim","_nme","_prprn","_sb"},
"pindaric":{"_prprn"},
"pinetum":{"_loc_sr"},
"pinfish":{"_anim"},
"pining":{"_loc_sr"},
"pinion":{"_loc_sr"},
"pinioned":{"_loc_sr","_past"},
"Pinkerton":{"_anim","_nme","_prprn","_sb"},
"pinko":{"_anim","_sb"},
"pinned":{"_past"},
"pinner":{"_anim","_sb"},
"Pinochet":{"_prprn"},
"pinpointed":{"_past"},
"pinsk":{"_cty","_geo","_prprn"},
"Pinter":{"_anim","_nme","_prprn","_sb"},
"pinto":{"_anim"},
"pioneer":{"_loc_sr"},
"pioneered":{"_loc_sr","_past"},
"pioneering":{"_loc_sr"},
"pioneers":{"_anim","_sb"},
"piped":{"_loc_sr","_past"},
"pipefish":{"_anim"},
"pipers":{"_anim","_sb"},
"piping":{"_loc_sr"},
"pipit":{"_anim"},
"pipsqueak":{"_anim","_sb"},
"Piraeus":{"_cty","_geo","_prprn"},
"Pirandello":{"_anim","_nme","_prprn","_sb"},
"Piranesi":{"_anim","_nme","_prprn","_sb"},
"piranha":{"_anim"},
"pirate":{"_anim","_sb"},
"pirated":{"_past"},
"pirates":{"_anim","_sb"},
"pirouette":{"_loc_sr"},
"Pisa":{"_cty","_geo","_prprn"},
"Pisces":{"_prprn"},
"Pissarro":{"_anim","_nme","_prprn","_sb"},
"pissed":{"_past","_wthr"},
"pissing":{"_wthr"},
"pistil":{"_sb"},
"pistils":{"_sb"},
"pistol-whipped":{"_past"},
"pitch":{"_loc_sr"},
"pitched":{"_loc_sr","_past"},
"pitcher":{"_anim","_loc_sr"},
"pitcher-coach":{"_anim","_loc_sr"},
"pitcher-shaped":{"_anim","_loc_sr"},
"pitchers":{"_anim","_loc_sr"},
"pitching":{"_loc_sr"},
"pitchman":{"_anim","_sb"},
"pitchmen":{"_anim","_sb"},
"pitied":{"_past"},
"pitman":{"_anim","_sb"},
"Pitt":{"_anim","_nme","_prprn","_sb"},
"Pitt-Rivers":{"_anim","_nme","_prprn","_sb"},
"pitter-patter":{"_loc_sr"},
"Pittsburgh":{"_cty","_geo","_prprn"},
"pittsfield":{"_cty","_geo","_prprn"},
"Pius":{"_prprn"},
"piute":{"_prprn","_sb"},
"Pizarro":{"_anim","_nme","_prprn","_sb"},
"pizzeria":{"_loc_sr"},
"pizzerias":{"_loc_sr"},
"pku":{"_prprn"},
"pl.":{"_prprn"},
"placated":{"_past","_psych"},
"placating":{"_psych"},
"place-kicking":{"_loc_sr"},
"place-names":{"_loc_sr"},
"place-worship":{"_loc_sr"},
"placed":{"_loc_sr","_past"},
"placeholder":{"_anim","_sb"},
"placekicker":{"_anim","_sb"},
"placeman":{"_anim","_sb"},
"placement":{"_loc_sr"},
"placements":{"_loc_sr"},
"Placentia":{"_cty","_geo","_prprn"},
"places":{"_loc_sr"},
"placing":{"_loc_sr"},
"plagiarised":{"_past"},
"plagiariser":{"_anim","_sb"},
"plagiarize":{"_loc_sr"},
"plagiarized":{"_loc_sr","_past"},
"plagiarizer":{"_anim","_sb"},
"plagiarizers":{"_anim","_sb"},
"plague":{"_psych"},
"plaguing":{"_psych"},
"plaice":{"_anim"},
"plain-spoken":{"_loc_sr"},
"plain-vanilla":{"_loc_sr"},
"plains":{"_loc_sr"},
"plainsman":{"_anim","_sb"},
"plaintiff":{"_anim","_sb"},
"plaintiffs":{"_anim","_sb"},
"plait":{"_loc_sr"},
"plaiter":{"_anim","_sb"},
"planchette":{"_sb"},
"Planck":{"_anim","_nme","_prprn","_sb"},
"plankton":{"_anim"},
"planner":{"_anim","_sb"},
"planners":{"_anim","_sb"},
"plano":{"_cty","_geo","_prprn"},
"plantagenet":{"_anim","_nme","_prprn","_sb"},
"plantation":{"_loc_sr"},
"plantations":{"_loc_sr"},
"planted":{"_loc_sr","_past"},
"planter":{"_anim","_sb"},
"planters":{"_anim","_sb"},
"planting":{"_loc_sr"},
"plaster":{"_loc_sr"},
"plastered":{"_loc_sr","_past"},
"plastering":{"_loc_sr"},
"plasticiser":{"_anim","_sb"},
"Plata":{"_prprn"},
"plataea":{"_cty","_geo","_prprn"},
"plated":{"_past"},
"platelayer":{"_anim","_sb"},
"plater":{"_anim","_sb"},
"Plath":{"_anim","_nme","_prprn","_sb"},
"platitudinarian":{"_anim","_sb"},
"platitudinize":{"_loc_sr"},
"Plato":{"_anim","_nme","_prprn","_sb"},
"Platonism":{"_prprn"},
"platonist":{"_prprn"},
"platoon":{"_loc_sr"},
"plattdeutsch":{"_prprn"},
"platte":{"_geo","_prprn"},
"platypus":{"_anim"},
"platyrrhine":{"_sb"},
"plausible":{"_probabl"},
"plausibly":{"_probabl"},
"plautus":{"_anim","_nme","_prprn","_sb"},
"play-acting":{"_loc_sr"},
"play-actor":{"_anim","_sb"},
"playboy":{"_anim","_masc","_sb"},
"played":{"_past"},
"played-out":{"_past"},
"player":{"_anim","_sb"},
"players":{"_anim","_sb"},
"playgoer":{"_anim","_sb"},
"playground":{"_loc_sr"},
"playgrounds":{"_loc_sr"},
"playpen":{"_loc_sr"},
"playroom":{"_loc_sr"},
"PlayStation":{"_prprn"},
"playsuit":{"_sb"},
"playtime":{"_tme"},
"playwright":{"_anim","_sb"},
"playwright-director":{"_anim","_sb"},
"playwrights":{"_anim","_sb"},
"plaza":{"_loc_sr"},
"plazas":{"_loc_sr"},
"pleaded":{"_past"},
"pleasing":{"_psych"},
"pleat":{"_loc_sr"},
"pleated":{"_loc_sr","_past"},
"pleating":{"_loc_sr"},
"pleb":{"_anim","_sb"},
"plebeian":{"_anim","_sb"},
"pledged":{"_past"},
"pledgee":{"_anim","_sb"},
"pledger":{"_anim","_sb"},
"Pleiades":{"_prprn"},
"Pleistocene":{"_prprn"},
"Plekhanov":{"_anim","_nme","_prprn","_sb"},
"plenty":{"_quant"},
"pleven":{"_cty","_geo","_prprn"},
"plevna":{"_prprn"},
"plier":{"_anim","_sb"},
"pliers":{"_anim","_sb"},
"pliny":{"_anim","_nme","_prprn","_sb"},
"Pliocene":{"_prprn"},
"PLO":{"_prprn"},
"plod":{"_loc_sr"},
"plodded":{"_loc_sr","_past"},
"plodder":{"_anim","_sb"},
"plodding":{"_loc_sr"},
"plopped":{"_past"},
"plot":{"_loc_sr"},
"plotinus":{"_anim","_nme","_prprn","_sb"},
"plotted":{"_loc_sr","_past"},
"plotting":{"_loc_sr"},
"ploughboy":{"_anim","_masc","_sb"},
"ploughed":{"_past"},
"ploughman":{"_anim","_sb"},
"plovdiv":{"_cty","_geo","_prprn"},
"plover":{"_anim"},
"plowboy":{"_sb"},
"plowed":{"_past"},
"plower":{"_anim","_sb"},
"plowman":{"_anim","_masc","_sb"},
"plucked":{"_past"},
"plug-ugly":{"_anim","_sb"},
"plugged":{"_past"},
"plugger":{"_anim","_sb"},
"plumbed":{"_past"},
"plumber":{"_anim","_sb"},
"plumbers":{"_anim","_sb"},
"plumbery":{"_loc_sr"},
"plumed":{"_past"},
"plummeted":{"_past"},
"plumped":{"_past"},
"plundered":{"_past"},
"plunge":{"_loc_sr"},
"plunged":{"_loc_sr","_past"},
"plunger":{"_anim","_sb"},
"plunging":{"_loc_sr"},
"plunker":{"_anim","_sb"},
"plunkers":{"_anim","_sb"},
"Plunkett":{"_prprn"},
"pluralist":{"_anim","_sb"},
"Plutarch":{"_anim","_nme","_prprn","_sb"},
"Pluto":{"_anim","_masc","_nme","_prprn","_sb"},
"plutocracy":{"_sb"},
"plutocrat":{"_anim","_sb"},
"ply":{"_loc_sr"},
"plying":{"_loc_sr"},
"Plymouth":{"_cty","_geo","_prprn"},
"plzen":{"_cty","_geo","_prprn"},
"pm":{"_ampm","_tme"},
"PO":{"_geo","_prprn"},
"poach":{"_loc_sr"},
"poached":{"_loc_sr","_past"},
"poacher":{"_anim","_loc_sr","_sb"},
"poachers":{"_anim","_loc_sr","_sb"},
"poaches":{"_loc_sr"},
"poaching":{"_loc_sr"},
"POB":{"_prprn"},
"Pocahontas":{"_anim","_nme","_prprn","_sb"},
"pocatello":{"_cty","_geo","_prprn"},
"pocked":{"_past"},
"pocketed":{"_loc_sr","_past"},
"pocketing":{"_loc_sr"},
"pockmarked":{"_past"},
"Poconos":{"_prprn"},
"pod":{"_loc_sr"},
"pods":{"_loc_sr"},
"Poe":{"_anim","_nme","_prprn","_sb"},
"poet":{"_anim","_sb"},
"poet-singer":{"_anim","_sb"},
"poetess":{"_anim","_fem","_sb"},
"poetiser":{"_anim","_sb"},
"poetize":{"_loc_sr"},
"poetizer":{"_anim","_sb"},
"poetizing":{"_loc_sr"},
"poets":{"_anim","_sb"},
"pointed":{"_past"},
"pointed-toe":{"_past"},
"pointsman":{"_anim","_sb"},
"poised":{"_loc_sr","_past"},
"poisoned":{"_past"},
"poitou":{"_geo","_prprn"},
"poitou-charentes":{"_geo","_prprn"},
"poked":{"_past"},
"Pola":{"_prprn"},
"Polack":{"_prprn","_sb"},
"Poland":{"_cntry","_geo","_prprn"},
"Polaris":{"_prprn"},
"polarized":{"_past"},
"Polaroid":{"_prprn"},
"polder":{"_loc_sr"},
"polemicist":{"_anim","_sb"},
"polemicize":{"_loc_sr"},
"police-dodging":{"_anim","_sb"},
"policed":{"_loc_sr","_past"},
"policeman":{"_anim","_masc","_sb"},
"policemen":{"_anim","_masc","_sb"},
"polices":{"_loc_sr"},
"policing":{"_loc_sr"},
"policy-makers":{"_anim","_sb"},
"policyholders":{"_anim","_sb"},
"policymaker":{"_anim","_sb"},
"policymakers":{"_anim","_sb"},
"poliomyelitis":{"_sb"},
"Polish":{"_anim","_prprn","_sb"},
"polisher":{"_anim","_sb"},
"politician":{"_anim","_sb"},
"politicians":{"_anim","_sb"},
"politico":{"_anim","_sb"},
"politico-plaintiffs":{"_anim","_sb"},
"politico-sociological":{"_anim","_sb"},
"politicos":{"_anim","_sb"},
"polled":{"_past"},
"pollinate":{"_loc_sr"},
"pollinated":{"_loc_sr","_past"},
"pollinating":{"_loc_sr"},
"pollinator":{"_anim","_sb"},
"Pollock":{"_anim","_prprn","_sb"},
"pollster":{"_anim","_sb"},
"polluted":{"_past"},
"polluter":{"_anim","_sb"},
"polluters":{"_anim","_sb"},
"Pollux":{"_prprn"},
"Polly":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Poltava":{"_cty","_geo","_prprn"},
"polyandrist":{"_anim","_sb"},
"polycarp":{"_anim","_nme","_prprn","_sb"},
"polydactyl":{"_anim","_sb"},
"polygamist":{"_anim","_sb"},
"polyglot":{"_anim","_sb"},
"polygynist":{"_anim","_sb"},
"polyhymnia":{"_prprn"},
"polymath":{"_anim","_sb"},
"Polynesia":{"_geo","_prprn"},
"Polynesian":{"_anim","_prprn","_sb"},
"polynya":{"_loc_sr"},
"polyp":{"_anim"},
"polyps":{"_anim"},
"polytechnic":{"_loc_sr"},
"pomaded":{"_past"},
"Pomerania":{"_geo","_prprn"},
"pomeranian":{"_anim","_prprn","_sb"},
"pommy":{"_anim","_sb"},
"pomo":{"_prprn","_sb"},
"Pomona":{"_cty","_geo","_prprn"},
"Pompadour":{"_anim","_prprn","_sb"},
"Pompeii":{"_cty","_geo","_prprn"},
"Pompey":{"_anim","_nme","_prprn","_sb"},
"ponca":{"_anim","_prprn","_sb"},
"Ponchielli":{"_anim","_nme","_prprn","_sb"},
"pond":{"_loc_sr"},
"pond-skater":{"_loc_sr"},
"ponder":{"_loc_sr"},
"pondered":{"_loc_sr","_past"},
"ponderer":{"_anim","_sb"},
"pondering":{"_loc_sr"},
"ponders":{"_loc_sr"},
"ponds":{"_loc_sr"},
"pongid":{"_anim"},
"ponied":{"_past"},
"ponies":{"_anim"},
"ponselle":{"_anim","_nme","_prprn","_sb"},
"Pontchartrain":{"_prprn"},
"Pontiac":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"pontifex":{"_anim","_masc","_sb"},
"pontiff":{"_anim","_masc","_sb"},
"pontoon":{"_loc_sr"},
"pontus":{"_cntry","_geo","_prprn"},
"pony-tail":{"_anim"},
"pooches":{"_anim"},
"poodle":{"_anim"},
"poodles":{"_anim"},
"poof":{"_anim","_masc","_sb"},
"pooh-poohed":{"_past"},
"pool":{"_loc_sr"},
"pool-care":{"_loc_sr"},
"pool-equipment":{"_loc_sr"},
"pool-equipped":{"_loc_sr"},
"pool-owners":{"_loc_sr"},
"pool-side":{"_loc_sr"},
"pool-table":{"_loc_sr"},
"Poole":{"_geo","_prprn"},
"pooled":{"_past"},
"pooler":{"_anim","_sb"},
"poolroom":{"_loc_sr"},
"pools":{"_loc_sr"},
"poolside":{"_loc_sr"},
"poorhouse":{"_loc_sr"},
"poove":{"_anim","_sb"},
"pope":{"_anim","_masc","_sb"},
"popinjay":{"_anim","_sb"},
"poppet":{"_sb"},
"popsicle":{"_prprn"},
"populariser":{"_anim","_sb"},
"popularized":{"_past"},
"popularizer":{"_anim","_sb"},
"populated":{"_past"},
"population":{"_sb"},
"populations":{"_sb"},
"populist":{"_anim","_sb"},
"populists":{"_anim","_sb"},
"porbeagle":{"_loc_sr"},
"porcupine":{"_anim"},
"porcupines":{"_anim"},
"pored":{"_past"},
"poriferan":{"_sb"},
"porker":{"_anim"},
"pornographer":{"_anim","_sb"},
"porpoise":{"_anim"},
"port":{"_loc_sr"},
"port-of-call":{"_loc_sr"},
"port-of-spain":{"_prprn"},
"port-shopping":{"_loc_sr"},
"port-side":{"_loc_sr"},
"porte":{"_prprn"},
"porter":{"_anim","_sb"},
"porters":{"_anim","_sb"},
"Portia":{"_prprn"},
"Portland":{"_cty","_geo","_prprn"},
"porto":{"_geo","_prprn"},
"portraitist":{"_anim","_sb"},
"portrayed":{"_loc_sr","_past"},
"portrayer":{"_anim","_sb"},
"portraying":{"_loc_sr"},
"portrays":{"_loc_sr"},
"ports":{"_loc_sr"},
"Portsmouth":{"_cty","_geo","_prprn"},
"Portugal":{"_cntry","_geo","_prprn"},
"Portuguese":{"_anim","_prprn","_sb"},
"poser":{"_anim","_sb"},
"poseurs":{"_anim","_sb"},
"position":{"_loc_sr"},
"position-building":{"_loc_sr"},
"position-squaring":{"_loc_sr"},
"positioned":{"_loc_sr","_past"},
"positioner":{"_anim","_sb"},
"possess":{"_psych"},
"possessed":{"_past","_psych"},
"possesses":{"_psych"},
"possessing":{"_psych"},
"possum":{"_anim"},
"post-colonial":{"_anim","_sb"},
"post-communist":{"_anim","_sb"},
"post-merger":{"_anim","_sb"},
"post-midnight":{"_tme"},
"post-minimalist":{"_anim","_sb"},
"post-operative":{"_anim","_sb"},
"post-paid":{"_past"},
"post-war":{"_loc_sr"},
"postdate":{"_loc_sr"},
"postdiluvian":{"_anim","_sb"},
"postdoc":{"_anim","_sb"},
"posted":{"_loc_sr","_past"},
"posterity":{"_sb"},
"postgraduate":{"_anim","_sb"},
"postilion":{"_anim","_sb"},
"postman":{"_anim","_sb"},
"postmaster":{"_anim","_masc","_sb"},
"postmasters":{"_anim","_masc","_sb"},
"postmen":{"_anim","_sb"},
"postmistress":{"_anim","_fem","_sb"},
"postmodernist":{"_anim","_sb"},
"postmortal":{"_anim","_sb"},
"postpone":{"_loc_sr"},
"postponed":{"_loc_sr","_past"},
"postponer":{"_anim","_sb"},
"postposition":{"_loc_sr"},
"postride":{"_loc_sr"},
"postulant":{"_anim","_sb"},
"postulated":{"_past"},
"postulator":{"_anim","_sb"},
"postured":{"_past"},
"posturer":{"_anim","_sb"},
"pot":{"_loc_sr"},
"pot-trained":{"_loc_sr"},
"potawatomi":{"_anim","_prprn","_sb"},
"potboy":{"_sb"},
"Potemkin":{"_anim","_nme","_prprn","_sb"},
"potentate":{"_anim","_sb"},
"potentates":{"_anim","_sb"},
"pothead":{"_anim","_sb"},
"pothunter":{"_anim","_sb"},
"Potomac":{"_geo","_prprn"},
"pots":{"_loc_sr"},
"potsdam":{"_cty","_geo","_prprn"},
"potted":{"_loc_sr","_past"},
"Potter":{"_anim","_prprn","_sb"},
"potterer":{"_anim","_sb"},
"potters":{"_anim","_sb"},
"potting":{"_loc_sr"},
"pottle":{"_loc_sr"},
"potto":{"_anim"},
"pouched":{"_past"},
"Poulenc":{"_anim","_nme","_prprn","_sb"},
"poulterer":{"_anim","_sb"},
"pounced":{"_past"},
"pounded":{"_loc_sr","_past"},
"pounding":{"_loc_sr"},
"pour":{"_wthr"},
"poured":{"_past","_wthr"},
"pouring":{"_wthr"},
"pours":{"_wthr"},
"Poussin":{"_anim","_nme","_prprn","_sb"},
"pouted":{"_past"},
"pouter":{"_anim","_sb"},
"POW":{"_prprn"},
"powdered":{"_loc_sr","_past"},
"powderer":{"_anim","_sb"},
"Powell":{"_anim","_nme","_prprn","_sb"},
"powerbroker":{"_anim","_sb"},
"powered":{"_past"},
"powerhouse":{"_anim","_sb"},
"powerhouses":{"_anim","_sb"},
"powhatan":{"_anim","_nme","_prprn","_sb"},
"Powys":{"_anim","_nme","_prprn","_sb"},
"Pozsony":{"_prprn"},
"pplo":{"_prprn"},
"practiced":{"_past"},
"practise":{"_loc_sr"},
"practised":{"_loc_sr","_past"},
"practitioner":{"_anim","_sb"},
"practitioners":{"_anim","_sb"},
"Prado":{"_prprn"},
"praetor":{"_anim","_sb"},
"praetorian":{"_anim","_sb"},
"Prague":{"_cty","_geo","_prprn"},
"praia":{"_cty","_geo","_prprn"},
"prairie":{"_loc_sr"},
"prairies":{"_loc_sr"},
"praised":{"_past"},
"praises":{"_sb"},
"prakrit":{"_prprn"},
"prancer":{"_anim","_sb"},
"prancing":{"_loc_sr"},
"Prandtl":{"_prprn"},
"prankster":{"_anim","_sb"},
"pranksters":{"_anim","_sb"},
"prat":{"_anim","_sb"},
"prater":{"_anim","_sb"},
"prawns":{"_anim"},
"Praxiteles":{"_anim","_nme","_prprn","_sb"},
"prayed":{"_past"},
"pre-arranged":{"_loc_sr","_past"},
"pre-cooked":{"_past"},
"pre-empted":{"_past"},
"pre-emptor":{"_anim","_sb"},
"pre-law":{"_loc_sr"},
"pre-loved":{"_past"},
"pre-owned":{"_past"},
"pre-packed":{"_loc_sr","_past"},
"pre-Reagan":{"_anim","_sb"},
"pre-recorded":{"_past"},
"pre-Roman":{"_anim","_masc","_sb"},
"pre-schools":{"_anim","_loc_sr"},
"pre-selected":{"_past"},
"pre-setting":{"_loc_sr"},
"pre-soaked":{"_past"},
"pre-Socratic":{"_prprn"},
"pre-Socratics":{"_prprn"},
"pre-sold":{"_past"},
"pre-teens":{"_tme"},
"pre-war":{"_loc_sr"},
"preach":{"_loc_sr"},
"preached":{"_loc_sr","_past"},
"preacher":{"_anim","_sb"},
"preachers":{"_anim","_sb"},
"preaches":{"_loc_sr"},
"preaching":{"_loc_sr"},
"preadolescent":{"_anim","_sb"},
"prearranged":{"_past"},
"preassembled":{"_past"},
"prebendary":{"_anim","_sb"},
"Precambrian":{"_prprn"},
"precast":{"_past"},
"precede":{"_loc_sr"},
"preceded":{"_loc_sr","_past"},
"precedes":{"_loc_sr"},
"preceding":{"_loc_sr"},
"precentor":{"_anim","_sb"},
"preceptor":{"_anim","_sb"},
"precess":{"_loc_sr"},
"precinct":{"_loc_sr"},
"precincts":{"_loc_sr"},
"precious":{"_anim","_sb"},
"precious-metals":{"_anim","_sb"},
"precipitate":{"_wthr"},
"precipitated":{"_past","_wthr"},
"precipitating":{"_wthr"},
"precipitator":{"_anim","_sb"},
"precluded":{"_past"},
"preconceived":{"_past"},
"preconcerted":{"_past"},
"preconditioned":{"_past"},
"precooked":{"_past"},
"precooled":{"_past"},
"precursor":{"_sb"},
"precursors":{"_sb"},
"precut":{"_loc_sr","_past"},
"predator":{"_anim"},
"predators":{"_anim"},
"predecessor":{"_anim","_sb"},
"predecessors":{"_anim","_sb"},
"predestinarian":{"_anim","_sb"},
"predestinationist":{"_anim","_sb"},
"predestined":{"_past"},
"predetermine":{"_loc_sr"},
"predicated":{"_past"},
"predicted":{"_past"},
"predictors":{"_anim","_sb"},
"predigested":{"_past"},
"predisposed":{"_past"},
"predominated":{"_past"},
"preexist":{"_loc_sr"},
"prefabricate":{"_loc_sr"},
"prefabricated":{"_loc_sr","_past"},
"prefaced":{"_past"},
"prefect":{"_anim","_sb"},
"prefecture":{"_loc_sr"},
"prefectures":{"_loc_sr"},
"prefer":{"_loc_sr"},
"preferred-dividend":{"_loc_sr","_past"},
"preferred-share":{"_loc_sr","_past"},
"preferred-stock":{"_loc_sr","_past"},
"preferring":{"_loc_sr"},
"prefers":{"_loc_sr"},
"preheated":{"_past"},
"prejudged":{"_past"},
"prejudiced":{"_past"},
"prelate":{"_anim","_sb"},
"prelates":{"_anim","_sb"},
"premediated":{"_past"},
"premier":{"_anim","_sb"},
"premises":{"_loc_sr"},
"Prendergast":{"_prprn"},
"preoccupied":{"_past","_psych"},
"preoccupies":{"_psych"},
"preoccupy":{"_psych"},
"preordained":{"_past"},
"prep":{"_loc_sr"},
"prepackaged":{"_past"},
"prepacked":{"_loc_sr","_past"},
"prepaid":{"_past"},
"prepaid-tuition":{"_past"},
"prepare":{"_loc_sr"},
"preparers":{"_anim","_sb"},
"prepares":{"_loc_sr"},
"preparing":{"_loc_sr"},
"prepositioning":{"_loc_sr"},
"prepping":{"_loc_sr"},
"preprepared":{"_loc_sr","_past"},
"prepubescent":{"_sb"},
"prerecord":{"_loc_sr"},
"prerecorded":{"_loc_sr","_past"},
"presaged":{"_past"},
"presbyope":{"_anim","_sb"},
"presbyter":{"_anim","_sb"},
"Presbyterian":{"_prprn","_sb"},
"Presbyterians":{"_sb"},
"preschoolers":{"_anim","_sb"},
"Prescott":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"prescribed":{"_past"},
"prescriber":{"_anim","_sb"},
"prescribers":{"_anim","_sb"},
"present-day":{"_tme"},
"present-time":{"_tme"},
"presented":{"_past"},
"presenter":{"_anim","_sb"},
"presenters":{"_anim","_sb"},
"presentist":{"_anim","_sb"},
"presently":{"_tme"},
"presents":{"_tme"},
"preservationist":{"_anim","_sb"},
"preservationists":{"_anim","_sb"},
"preserve":{"_loc_sr"},
"preserved":{"_loc_sr","_past"},
"preserver":{"_sb"},
"preserving":{"_loc_sr"},
"preset":{"_loc_sr","_past"},
"presided":{"_past"},
"president":{"_anim","_sb"},
"president-elect":{"_anim","_sb"},
"presidents":{"_anim","_sb"},
"Presley":{"_anim","_nme","_prprn","_sb"},
"press-ganged":{"_loc_sr","_past"},
"Pressburger":{"_prprn"},
"pressed":{"_past"},
"pressed-paper":{"_past"},
"presser":{"_anim","_sb"},
"pressers":{"_anim","_sb"},
"pressure-cook":{"_loc_sr"},
"pressure-cooker":{"_anim","_sb"},
"pressured":{"_past"},
"pressurized":{"_past"},
"pressurized-water":{"_past"},
"prestidigitators":{"_anim","_sb"},
"Preston":{"_geo","_prprn"},
"presumably":{"_probabl"},
"presumed":{"_past"},
"presumer":{"_anim","_sb"},
"presuppose":{"_loc_sr"},
"presupposes":{"_loc_sr"},
"preteen":{"_sb"},
"pretended":{"_past"},
"pretor":{"_anim","_sb"},
"Pretoria":{"_cty","_geo","_prprn"},
"prevailed":{"_past"},
"prevailer":{"_anim","_sb"},
"prevaricate":{"_loc_sr"},
"prevent":{"_loc_sr"},
"prevented":{"_loc_sr","_past"},
"preventing":{"_loc_sr"},
"prevents":{"_loc_sr"},
"previous":{"_tme"},
"previously":{"_tme"},
"prevised":{"_past"},
"Priam":{"_prprn"},
"priced":{"_past"},
"prick":{"_loc_sr"},
"pricking":{"_loc_sr"},
"prickled":{"_past"},
"prided":{"_past"},
"priest":{"_anim","_sb"},
"priest-doctor":{"_anim","_sb"},
"priestess":{"_anim","_fem","_sb"},
"Priestley":{"_anim","_nme","_prprn","_sb"},
"priests":{"_anim","_sb"},
"prig":{"_anim","_sb"},
"prim":{"_loc_sr"},
"primate":{"_anim","_sb"},
"prime":{"_sb"},
"prime-time":{"_sb"},
"primed":{"_past"},
"primes":{"_sb"},
"primipara":{"_anim","_fem","_sb"},
"primitive":{"_anim","_sb"},
"primitives":{"_anim","_sb"},
"primogeniture":{"_sb"},
"prince":{"_anim","_masc","_sb"},
"prince's-feather":{"_anim","_masc","_sb"},
"prince's-plume":{"_anim","_masc","_sb"},
"princes":{"_anim","_masc","_sb"},
"princess":{"_anim","_fem","_sb"},
"princesses":{"_anim","_fem","_sb"},
"Princeton":{"_geo","_prprn"},
"principal":{"_anim","_sb"},
"principals":{"_anim","_sb"},
"principe":{"_geo","_prprn"},
"printed":{"_past"},
"printer":{"_anim","_sb"},
"printers":{"_anim","_sb"},
"printmaker":{"_anim","_sb"},
"prior-review":{"_anim","_masc","_sb"},
"priories":{"_sb"},
"prioritised":{"_past"},
"priors":{"_anim","_masc","_sb"},
"priory":{"_sb"},
"Pripet":{"_geo","_prprn"},
"Priscilla":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"prison":{"_loc_sr"},
"prisoner":{"_anim","_sb"},
"prisoners":{"_anim","_sb"},
"prisons":{"_loc_sr"},
"Pristina":{"_prprn"},
"Pritchett":{"_anim","_nme","_prprn","_sb"},
"private":{"_anim","_sb"},
"privates":{"_anim","_sb"},
"privatized":{"_past"},
"prized":{"_past"},
"prizefighter":{"_anim","_sb"},
"prizefighters":{"_anim","_sb"},
"probably":{"_probabl"},
"probationer":{"_anim","_sb"},
"probationers":{"_anim","_sb"},
"probed":{"_past"},
"proceed":{"_loc_sr"},
"proceeded":{"_loc_sr","_past"},
"proceeding":{"_loc_sr"},
"processed":{"_loc_sr","_past"},
"processing":{"_loc_sr"},
"proclaimed":{"_past"},
"proconsul":{"_anim","_sb"},
"proconsuls":{"_anim","_sb"},
"procrastinate":{"_loc_sr"},
"procrastinated":{"_loc_sr","_past"},
"procrastinator":{"_anim","_sb"},
"Procrustes":{"_prprn"},
"proctologist":{"_anim","_sb"},
"proctors":{"_anim","_sb"},
"procured":{"_past"},
"procuress":{"_anim","_sb"},
"procyon":{"_prprn"},
"prodded":{"_past"},
"prodigal":{"_anim","_sb"},
"prodigals":{"_anim","_sb"},
"prodigies":{"_anim","_sb"},
"produced":{"_past"},
"producer":{"_anim","_sb"},
"producers":{"_anim","_sb"},
"prof":{"_anim","_sb"},
"Prof.":{"_anim","_sb"},
"profaned":{"_past"},
"professeur":{"_anim","_sb"},
"professional":{"_anim","_sb"},
"professionals":{"_anim","_sb"},
"professor":{"_anim","_sb"},
"professors":{"_anim","_sb"},
"proffered":{"_past"},
"profiled":{"_past"},
"profiteer":{"_loc_sr"},
"profiteering":{"_loc_sr"},
"profiteers":{"_anim","_sb"},
"profligate":{"_anim","_sb"},
"profligates":{"_anim","_sb"},
"profs":{"_anim","_sb"},
"progenitor":{"_anim","_sb"},
"progenitors":{"_anim","_sb"},
"programed":{"_loc_sr","_past"},
"programmed":{"_loc_sr","_past"},
"programmer":{"_anim","_sb"},
"programmers":{"_anim","_sb"},
"programming":{"_loc_sr"},
"progressed":{"_past"},
"progressive":{"_anim","_sb"},
"progressives":{"_anim","_sb"},
"prohibited":{"_past"},
"prohibitionist":{"_anim","_sb"},
"projected":{"_past"},
"projectionist":{"_anim","_sb"},
"projectionists":{"_anim","_sb"},
"prokhorov":{"_anim","_nme","_prprn","_sb"},
"Prokofiev":{"_anim","_nme","_prprn","_sb"},
"prole":{"_anim","_sb"},
"proletarian":{"_sb"},
"proliferating":{"_loc_sr"},
"prolong":{"_loc_sr"},
"prolonged":{"_loc_sr","_past"},
"prolonging":{"_loc_sr"},
"promenade":{"_loc_sr"},
"Prometheus":{"_prprn"},
"promised":{"_past"},
"promiser":{"_anim","_sb"},
"promisor":{"_anim","_sb"},
"promontory":{"_loc_sr"},
"promoted":{"_loc_sr","_past"},
"promoter":{"_anim","_sb"},
"promoters":{"_anim","_sb"},
"promotes":{"_loc_sr"},
"promoting":{"_loc_sr"},
"prompt":{"_loc_sr"},
"prompted":{"_loc_sr","_past"},
"prompter":{"_anim","_sb"},
"prompting":{"_loc_sr"},
"promulgate":{"_loc_sr"},
"promulgated":{"_loc_sr","_past"},
"promulgating":{"_loc_sr"},
"pronged":{"_past"},
"pronghorn":{"_anim"},
"pronounced":{"_past"},
"proofread":{"_past"},
"proofreader":{"_anim","_sb"},
"prop":{"_loc_sr"},
"propagandised":{"_past"},
"propagandist":{"_anim","_sb"},
"propagandists":{"_anim","_sb"},
"propagandize":{"_loc_sr"},
"propagandizes":{"_loc_sr"},
"propagate":{"_loc_sr"},
"propelled":{"_loc_sr","_past"},
"propelling":{"_loc_sr"},
"propels":{"_loc_sr"},
"Propertius":{"_anim","_nme","_prprn","_sb"},
"prophesied":{"_past"},
"prophesier":{"_anim","_sb"},
"prophet":{"_anim","_sb"},
"prophetess":{"_anim","_fem","_sb"},
"prophetesses":{"_anim","_fem","_sb"},
"prophets":{"_anim","_sb"},
"proponent":{"_anim","_sb"},
"proponents":{"_anim","_sb"},
"proposed":{"_past"},
"proposer":{"_anim","_sb"},
"proposers":{"_anim","_sb"},
"propositi":{"_sb"},
"propositioned":{"_past"},
"propositus":{"_sb"},
"propounded":{"_past"},
"propped":{"_loc_sr","_past"},
"propping":{"_loc_sr"},
"proprietor":{"_anim","_sb"},
"proprietors":{"_anim","_sb"},
"proprietress":{"_anim","_fem","_sb"},
"proprietresses":{"_anim","_fem","_sb"},
"prorated":{"_past"},
"prorogued":{"_past"},
"proscenium":{"_loc_sr"},
"proscribed":{"_past"},
"prosecuting":{"_loc_sr"},
"prosecutor":{"_anim","_sb"},
"proselyted":{"_past"},
"proselytes":{"_anim","_sb"},
"proselytised":{"_past"},
"proselytizer":{"_anim","_sb"},
"proselytizers":{"_anim","_sb"},
"Proserpina":{"_anim","_fem","_nme","_prprn","_sb"},
"prospered":{"_past"},
"prosthetist":{"_anim","_sb"},
"prostitute":{"_anim","_sb"},
"prostitutes":{"_anim","_sb"},
"prostrate":{"_loc_sr"},
"protagonist":{"_anim","_sb"},
"protagonists":{"_anim","_sb"},
"protected":{"_past"},
"protector":{"_anim","_sb"},
"protectors":{"_anim","_sb"},
"protegees":{"_anim","_fem","_sb"},
"proterozoic":{"_prprn"},
"Protestant":{"_anim","_prprn","_sb"},
"Protestantism":{"_prprn"},
"protested":{"_loc_sr","_past"},
"protesting":{"_loc_sr"},
"protestor":{"_anim","_sb"},
"protestors":{"_anim","_sb"},
"Protista":{"_prprn"},
"Proto-Norse":{"_prprn"},
"protozoa":{"_anim"},
"protozoan":{"_anim","_sb"},
"protozoans":{"_anim","_sb"},
"protozoologist":{"_anim","_sb"},
"protozoon":{"_anim"},
"protracted":{"_past"},
"protruded":{"_past"},
"proudhon":{"_anim","_nme","_prprn","_sb"},
"Proust":{"_anim","_nme","_prprn","_sb"},
"Provence":{"_geo","_prprn","_stte"},
"Proverbs":{"_prprn"},
"provided":{"_past"},
"providence":{"_anim"},
"provider":{"_anim","_sb"},
"providers":{"_anim","_sb"},
"provincial":{"_anim","_sb"},
"provisional":{"_anim","_sb"},
"provisioner":{"_anim","_sb"},
"Provo":{"_cty","_geo","_prprn"},
"provoked":{"_past","_psych"},
"provoker":{"_anim","_sb"},
"provokes":{"_psych"},
"provost":{"_anim","_sb"},
"provosts":{"_anim","_sb"},
"prowled":{"_loc_sr","_past"},
"prowler":{"_anim","_sb"},
"prowlers":{"_anim","_sb"},
"prowling":{"_loc_sr"},
"proxies":{"_anim","_sb"},
"proxy":{"_anim","_sb"},
"Prozac":{"_prprn"},
"prudes":{"_anim","_sb"},
"pruned":{"_past"},
"pruner":{"_anim","_sb"},
"pruners":{"_anim","_sb"},
"Prussia":{"_cntry","_geo","_prprn"},
"PS":{"_prprn"},
"psalm":{"_loc_sr"},
"pseud":{"_anim","_sb"},
"pseudoallele":{"_sb"},
"pseudohermaphrodite":{"_anim","_sb"},
"pseudoscorpion":{"_anim"},
"pseuds":{"_anim","_sb"},
"pst":{"_prprn"},
"psychiatrist":{"_anim","_sb"},
"psychiatrists":{"_anim","_sb"},
"psychic":{"_anim","_sb"},
"psychics":{"_anim","_sb"},
"psycho":{"_anim","_sb"},
"psycho-physiology":{"_anim","_sb"},
"psychoanalysed":{"_past"},
"psychoanalysts":{"_anim","_sb"},
"psychoanalyzed":{"_past"},
"psychologist":{"_anim","_sb"},
"psychologists":{"_anim","_sb"},
"psychopaths":{"_anim","_sb"},
"psychophysicist":{"_anim","_sb"},
"psychotic":{"_anim","_sb"},
"psychotics":{"_anim","_sb"},
"Pt":{"_prprn"},
"ptarmigan":{"_anim","_loc_sr"},
"ptarmigans":{"_anim","_loc_sr"},
"Pte":{"_prprn"},
"pteridologist":{"_anim","_sb"},
"PTO":{"_prprn"},
"Ptolemaist":{"_prprn"},
"Ptolemy":{"_anim","_nme","_prprn","_sb"},
"ptsd":{"_prprn"},
"pu":{"_prprn"},
"pub":{"_loc_sr"},
"pub-crawl":{"_loc_sr"},
"puberty":{"_tme"},
"public":{"_sb"},
"public-health":{"_sb"},
"public-housing":{"_sb"},
"public-policy":{"_sb"},
"public-relations":{"_sb"},
"public-school":{"_sb"},
"public-sector":{"_sb"},
"public-service":{"_sb"},
"public-television":{"_sb"},
"public-works":{"_sb"},
"publicans":{"_anim","_sb"},
"publicised":{"_past"},
"publiciser":{"_anim","_sb"},
"publicist":{"_anim","_sb"},
"publicists":{"_anim","_sb"},
"publicizer":{"_anim","_sb"},
"publisher":{"_anim","_sb"},
"publishers":{"_anim","_sb"},
"pubs":{"_loc_sr"},
"Puccini":{"_anim","_nme","_prprn","_sb"},
"pucker":{"_loc_sr"},
"puckered":{"_loc_sr","_past"},
"puckering":{"_loc_sr"},
"puddle":{"_loc_sr"},
"puddler":{"_anim","_sb"},
"puddlers":{"_anim","_sb"},
"puddles":{"_loc_sr"},
"puebla":{"_cty","_geo","_prprn","_stte"},
"pueblo":{"_loc_sr","_sb"},
"pueblos":{"_loc_sr","_sb"},
"puerperia":{"_sb"},
"puerperium":{"_sb"},
"puff":{"_loc_sr"},
"puffed":{"_loc_sr","_past"},
"puffer":{"_anim"},
"puffers":{"_anim"},
"puffin":{"_anim"},
"puffing":{"_loc_sr"},
"pug":{"_anim"},
"pug-dog":{"_anim"},
"pug-faced":{"_anim"},
"pug-nose":{"_anim"},
"pugged":{"_past"},
"pugilist":{"_anim","_sb"},
"pugilists":{"_anim","_sb"},
"Pugin":{"_prprn"},
"pugs":{"_anim"},
"puke":{"_loc_sr"},
"puking":{"_loc_sr"},
"Pula":{"_cty","_geo","_prprn"},
"Pulaski":{"_anim","_nme","_prprn","_sb"},
"puled":{"_past"},
"puler":{"_anim","_sb"},
"Pulitzer":{"_anim","_nme","_prprn","_sb"},
"pull-in":{"_loc_sr"},
"pulled":{"_past"},
"pullet":{"_anim"},
"pullets":{"_anim"},
"Pullman":{"_cty","_geo","_prprn"},
"Pullmans":{"_cty","_geo","_prprn"},
"pullulated":{"_past"},
"pulsated":{"_past"},
"pulsed":{"_loc_sr","_past"},
"pulsing":{"_loc_sr"},
"pulverised":{"_past"},
"pulverized":{"_past"},
"puma":{"_anim"},
"pumas":{"_anim"},
"pummeled":{"_past"},
"pump":{"_loc_sr"},
"pumped":{"_loc_sr","_past"},
"pumped-up":{"_loc_sr","_past"},
"pumping":{"_loc_sr"},
"punched":{"_past"},
"punched-card":{"_past"},
"punctuate":{"_loc_sr"},
"punctuated":{"_loc_sr","_past"},
"punctured":{"_past"},
"pundit":{"_anim","_sb"},
"pundits":{"_anim","_sb"},
"Pune":{"_prprn"},
"Punic":{"_prprn"},
"punished":{"_past"},
"Punjab":{"_geo","_prprn"},
"Punjabi":{"_anim","_prprn","_sb"},
"Punjabis":{"_anim","_prprn","_sb"},
"punk":{"_anim","_sb"},
"punkier":{"_anim","_sb"},
"punks":{"_anim","_sb"},
"punsters":{"_anim","_sb"},
"punt":{"_loc_sr"},
"punted":{"_loc_sr","_past"},
"pupa":{"_anim"},
"pupae":{"_anim"},
"pupas":{"_anim"},
"pupated":{"_past"},
"pupil":{"_anim","_sb"},
"pupils":{"_anim","_sb"},
"puppeteer":{"_anim","_sb"},
"puppeteers":{"_anim","_sb"},
"puppies":{"_anim"},
"Puppis":{"_prprn"},
"puppy":{"_anim"},
"puppy-fat":{"_anim"},
"puppy-love":{"_anim"},
"pups":{"_anim"},
"Purcell":{"_anim","_nme","_prprn","_sb"},
"purchased":{"_past"},
"purchasers":{"_anim","_sb"},
"purdah":{"_sb"},
"purebred":{"_anim"},
"purebreds":{"_anim"},
"puree":{"_loc_sr"},
"pureed":{"_loc_sr","_past"},
"pureeing":{"_loc_sr"},
"purgatory":{"_loc_sr"},
"purge":{"_loc_sr"},
"purged":{"_loc_sr","_past"},
"purging":{"_loc_sr"},
"purified":{"_past"},
"purifier":{"_anim","_sb"},
"purifiers":{"_anim","_sb"},
"Purim":{"_prprn","_tme"},
"purist":{"_anim","_sb"},
"purists":{"_anim","_sb"},
"puritan":{"_anim","_sb"},
"purl":{"_loc_sr"},
"purled":{"_loc_sr","_past"},
"purlieu":{"_loc_sr"},
"purling":{"_loc_sr"},
"purloin":{"_loc_sr"},
"purloined":{"_loc_sr","_past"},
"purported":{"_past"},
"purposed":{"_past"},
"pursed":{"_loc_sr","_past"},
"purser":{"_anim","_sb"},
"pursers":{"_anim","_sb"},
"pursued":{"_loc_sr","_past"},
"pursuers":{"_sb"},
"pursues":{"_loc_sr"},
"pursuing":{"_loc_sr"},
"pursuit":{"_sb"},
"pursuits":{"_sb"},
"purveyors":{"_anim","_sb"},
"Pusan":{"_cty","_geo","_prprn"},
"Pusey":{"_anim","_nme","_prprn","_sb"},
"Puseyism":{"_prprn"},
"pushed":{"_past"},
"pushers":{"_anim","_sb"},
"Pushkin":{"_anim","_nme","_prprn","_sb"},
"pushover":{"_anim","_sb"},
"pushovers":{"_anim","_sb"},
"puss":{"_anim"},
"pusses":{"_anim"},
"pussies":{"_anim"},
"pussy":{"_anim"},
"pussy-paw":{"_anim"},
"pussy-paws":{"_anim"},
"pussycat":{"_anim"},
"pussycats":{"_anim"},
"pustulated":{"_past"},
"put":{"_loc_sr","_past"},
"Putin":{"_prprn"},
"Putnam":{"_anim","_nme","_prprn","_sb"},
"putrefied":{"_past"},
"putted":{"_past"},
"puttered":{"_past"},
"putterer":{"_anim","_sb"},
"putting":{"_loc_sr"},
"Puttnam":{"_prprn"},
"putzed":{"_past"},
"puzzle":{"_psych"},
"puzzled":{"_jj_ed","_past","_psych"},
"puzzlers":{"_anim","_sb"},
"puzzling":{"_jj_ing","_psych"},
"PVC":{"_prprn"},
"Pvt.":{"_anim","_prprn","_sb"},
"PX":{"_prprn"},
"pye-dog":{"_anim"},
"Pygmalion":{"_prprn"},
"pygmies":{"_anim","_sb"},
"pygmy":{"_anim","_sb"},
"pyle":{"_anim","_nme","_prprn","_sb"},
"pynchon":{"_anim","_nme","_prprn","_sb"},
"Pyongyang":{"_cty","_geo","_prprn"},
"pyramid":{"_loc_sr"},
"pyramiding":{"_loc_sr"},
"Pyrenees":{"_geo","_prprn"},
"Pyrex":{"_prprn"},
"pyrographer":{"_anim","_sb"},
"pyromaniac":{"_anim","_sb"},
"pyromaniacs":{"_anim","_sb"},
"pyrrhus":{"_anim","_nme","_prprn","_sb"},
"Pythagoras":{"_anim","_nme","_prprn","_sb"},
"pythias":{"_prprn"},
"Python":{"_anim","_prprn"},
"pythons":{"_anim"},
"pyx":{"_loc_sr"},
"Pyxis":{"_prprn"},
"Qaddafi":{"_anim","_nme","_prprn","_sb"},
"qandahar":{"_geo","_prprn"},
"Qatar":{"_cntry","_geo","_prprn"},
"Qatari":{"_anim","_prprn","_sb"},
"QC":{"_prprn","_stte"},
"QED":{"_prprn"},
"qin":{"_anim","_nme","_prprn","_sb"},
"qing":{"_anim","_nme","_prprn","_sb"},
"quaalude":{"_prprn"},
"quacked":{"_past"},
"Quadragesima":{"_prprn"},
"quadrated":{"_past"},
"quadrillion":{"_num","_quant"},
"quadroon":{"_anim","_sb"},
"quadrumvirate":{"_anim","_sb"},
"quadruped":{"_anim"},
"quadrupeds":{"_anim"},
"quadrupled":{"_past"},
"quadruplet":{"_sb"},
"quadruplets":{"_sb"},
"quads":{"_loc_sr"},
"quaffer":{"_anim","_sb"},
"quagga":{"_anim"},
"quaggas":{"_anim"},
"quailing":{"_loc_sr"},
"Quaker":{"_prprn","_sb"},
"Quakeress":{"_anim","_fem","_sb"},
"Quakers":{"_prprn","_sb"},
"qualified":{"_past"},
"quantifier":{"_anim","_sb"},
"quantifiers":{"_anim","_sb"},
"quantised":{"_past"},
"quantized":{"_past"},
"quapaw":{"_anim","_prprn","_sb"},
"quarantined":{"_loc_sr","_past"},
"quarrel":{"_loc_sr"},
"quarreled":{"_loc_sr","_past"},
"quarreler":{"_anim","_sb"},
"quarrelers":{"_anim","_sb"},
"quarreling":{"_loc_sr"},
"quarreller":{"_anim","_sb"},
"quarrellers":{"_anim","_sb"},
"quarrier":{"_anim","_sb"},
"quarry":{"_loc_sr"},
"quarrying":{"_loc_sr"},
"quarter-circle":{"_tme"},
"quarter-hour":{"_tme"},
"quarter-inch":{"_tme"},
"quarter-mile":{"_tme"},
"quarter-moon":{"_tme"},
"quarter-point":{"_tme"},
"quarter-to-quarter":{"_tme"},
"quarter-tone":{"_tme"},
"quarter-vine":{"_tme"},
"quartermaster":{"_anim","_sb"},
"quartermasters":{"_anim","_sb"},
"quarters":{"_tme"},
"quartets":{"_sb"},
"quashed":{"_past"},
"Quasimodo":{"_anim","_nme","_prprn","_sb"},
"quavered":{"_past"},
"quay":{"_loc_sr"},
"Quayle":{"_anim","_nme","_prprn","_sb"},
"quays":{"_loc_sr"},
"quayside":{"_loc_sr"},
"Quebec":{"_cty","_geo","_prprn","_stte"},
"Quebecois":{"_anim","_prprn","_sb"},
"quechua":{"_anim","_prprn","_sb"},
"quechuan":{"_prprn"},
"queen":{"_anim","_fem","_sb"},
"queens":{"_anim","_fem","_sb"},
"Queensland":{"_geo","_prprn","_stte"},
"queer":{"_loc_sr"},
"queerer":{"_sb"},
"queerest":{"_sb"},
"queers":{"_anim","_masc","_sb"},
"quelled":{"_past"},
"Quemoy":{"_geo","_prprn"},
"quenched":{"_past"},
"querier":{"_anim","_sb"},
"quester":{"_anim","_sb"},
"questioned":{"_past"},
"questioners":{"_anim","_sb"},
"Quetzalcoatl":{"_anim","_masc","_nme","_prprn","_sb"},
"queue":{"_loc_sr"},
"queued":{"_loc_sr","_past"},
"queuing":{"_loc_sr"},
"Quezon":{"_prprn"},
"quick-froze":{"_past"},
"quickened":{"_past"},
"quickener":{"_anim","_sb"},
"quidnunc":{"_sb"},
"quieted":{"_past"},
"quietened":{"_past"},
"quilt":{"_loc_sr"},
"quilting":{"_loc_sr"},
"quin":{"_anim","_sb"},
"Quincy":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Quinn":{"_anim","_nme","_prprn","_sb"},
"Quinquagesima":{"_prprn"},
"quintets":{"_sb"},
"quintupled":{"_past"},
"quintuplet":{"_anim","_sb"},
"quipped":{"_past"},
"Quirinal":{"_geo","_loc_sr","_prprn"},
"quislings":{"_anim","_sb"},
"quit":{"_past"},
"Quito":{"_cty","_geo","_prprn"},
"quitter":{"_anim","_sb"},
"quitters":{"_anim","_sb"},
"quivered":{"_past"},
"Quixote":{"_prprn"},
"quizmaster":{"_anim","_sb"},
"quizmasters":{"_anim","_sb"},
"quizzed":{"_past"},
"quizzer":{"_anim","_sb"},
"quizzers":{"_anim","_sb"},
"qum":{"_geo","_prprn"},
"quote":{"_loc_sr"},
"quoted":{"_loc_sr","_past"},
"quoting":{"_loc_sr"},
"Quran":{"_prprn"},
"Rabaul":{"_prprn"},
"rabbis":{"_anim","_sb"},
"rabbit":{"_anim"},
"rabbit-hutch":{"_anim"},
"rabbit-warren":{"_anim"},
"rabbit-warrens":{"_anim"},
"rabbits":{"_anim"},
"rabble-rouser":{"_anim","_sb"},
"rabble-rousers":{"_anim","_sb"},
"Rabelais":{"_anim","_nme","_prprn","_sb"},
"Rabia":{"_prprn"},
"raccoon":{"_anim"},
"raccoons":{"_anim"},
"raced":{"_loc_sr","_past"},
"racehorses":{"_anim"},
"Rachel":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Racine":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"rack-rented":{"_past"},
"racked":{"_loc_sr","_past"},
"racker":{"_anim","_sb"},
"racketeer":{"_loc_sr"},
"racketeering":{"_loc_sr"},
"racketeers":{"_anim","_sb"},
"racking":{"_loc_sr"},
"raconteur":{"_anim","_sb"},
"raconteurs":{"_anim","_sb"},
"racoon":{"_anim"},
"racoons":{"_anim"},
"Radcliffe":{"_anim","_nme","_prprn","_sb"},
"Radetzky":{"_prprn"},
"radiate":{"_loc_sr"},
"radiated":{"_loc_sr","_past"},
"radiates":{"_loc_sr"},
"radical":{"_anim","_sb"},
"radicalised":{"_past"},
"radicalized":{"_past"},
"radicals":{"_anim","_sb"},
"radiobiologist":{"_anim","_sb"},
"radioed":{"_loc_sr","_past"},
"radiographed":{"_past"},
"radiographer":{"_anim","_sb"},
"radiographers":{"_anim","_sb"},
"radioing":{"_loc_sr"},
"radiotherapist":{"_anim","_sb"},
"radiotherapists":{"_anim","_sb"},
"Radnor":{"_prprn"},
"Rae":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"RAF":{"_prprn"},
"raffled":{"_loc_sr","_past"},
"raffling":{"_loc_sr"},
"Rafsanjani":{"_prprn"},
"raft":{"_loc_sr"},
"rafter":{"_anim","_sb"},
"rafters":{"_anim","_sb"},
"rafting":{"_loc_sr"},
"raftsman":{"_anim","_sb"},
"raftsmen":{"_anim","_sb"},
"ragamuffins":{"_anim","_sb"},
"raged":{"_loc_sr","_past","_psych"},
"ragged":{"_past"},
"raging":{"_loc_sr","_psych"},
"ragusa":{"_cty","_geo","_prprn"},
"raided":{"_loc_sr","_past"},
"raider":{"_sb"},
"raiders":{"_sb"},
"raiding":{"_loc_sr"},
"railbird":{"_anim","_sb"},
"railbirds":{"_anim","_sb"},
"railed":{"_past"},
"railroaders":{"_anim","_sb"},
"railroading":{"_loc_sr"},
"rain":{"_loc_sr"},
"rained":{"_loc_sr","_past","_wthr"},
"Rainier":{"_geo","_prprn"},
"raining":{"_loc_sr","_wthr"},
"rainmaker":{"_anim","_sb"},
"rainmakers":{"_anim","_sb"},
"rains":{"_loc_sr"},
"raise":{"_loc_sr"},
"raised":{"_loc_sr","_past"},
"raising":{"_loc_sr"},
"raja":{"_anim","_sb"},
"rajab":{"_prprn"},
"rajahs":{"_anim","_masc","_sb"},
"rajpoot":{"_prprn"},
"rajput":{"_prprn","_sb"},
"rake":{"_loc_sr"},
"raked":{"_loc_sr","_past"},
"rakehell":{"_sb"},
"raking":{"_loc_sr"},
"ralegh":{"_prprn"},
"Raleigh":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"rallied":{"_past"},
"Ralph":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"RAM":{"_anim","_masc","_prprn"},
"ram-jet":{"_anim","_masc"},
"rama":{"_prprn"},
"Ramadan":{"_prprn"},
"Ramallah":{"_prprn"},
"ramble":{"_loc_sr"},
"rambled":{"_loc_sr","_past"},
"rambler":{"_anim","_sb"},
"ramblers":{"_anim","_sb"},
"rambling":{"_loc_sr"},
"rambouillet":{"_anim","_prprn"},
"Rameau":{"_anim","_nme","_prprn","_sb"},
"ramee":{"_anim","_nme","_prprn","_sb"},
"ramified":{"_past"},
"Ramillies":{"_prprn"},
"rammed":{"_past"},
"rammer":{"_anim","_sb"},
"rammers":{"_anim","_sb"},
"Ramona":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"ramparts":{"_loc_sr"},
"Ramses":{"_prprn"},
"Ramsey":{"_anim","_nme","_prprn","_sb"},
"ran":{"_loc_sr","_past"},
"ranched":{"_loc_sr","_past"},
"rancher":{"_anim","_sb"},
"ranchers":{"_anim","_sb"},
"Rand":{"_anim","_fnme","_geo","_nme","_prprn","_sb"},
"Randolph":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"randomised":{"_past"},
"randomized":{"_past"},
"ranee":{"_anim","_fem","_sb"},
"rang":{"_past"},
"ranged":{"_loc_sr","_past"},
"rangeland":{"_loc_sr"},
"rangelands":{"_loc_sr"},
"ranger":{"_anim","_sb"},
"rangers":{"_anim","_sb"},
"ranging":{"_loc_sr"},
"Rangoon":{"_cty","_geo","_prprn"},
"rani":{"_anim","_fem","_sb"},
"ranier":{"_anim","_sb"},
"rank":{"_loc_sr"},
"Ranke":{"_anim","_nme","_prprn","_sb"},
"ranked":{"_loc_sr","_past"},
"ranker":{"_anim","_sb"},
"rankin":{"_anim","_nme","_prprn","_sb"},
"ranking":{"_loc_sr"},
"rankle":{"_psych"},
"rankled":{"_past","_psych"},
"rankles":{"_psych"},
"ransacked":{"_past"},
"ranted":{"_past"},
"ranter":{"_anim","_sb"},
"ranters":{"_anim","_sb"},
"raped":{"_past"},
"raper":{"_anim","_sb"},
"rapers":{"_anim","_sb"},
"Raphael":{"_anim","_fnme","_nme","_prprn","_sb"},
"rapists":{"_anim","_masc","_sb"},
"Rappahannock":{"_geo","_prprn"},
"rapped":{"_past"},
"rappel":{"_loc_sr"},
"rappelled":{"_loc_sr","_past"},
"rappeller":{"_anim","_sb"},
"rappelling":{"_loc_sr"},
"rapper":{"_anim","_sb"},
"rappers":{"_anim","_sb"},
"rapporteur":{"_anim","_sb"},
"rapporteurs":{"_anim","_sb"},
"rapscallion":{"_anim","_masc","_sb"},
"rarefied":{"_past"},
"rarely":{"_tme"},
"RAS":{"_prprn"},
"rascal":{"_anim","_sb"},
"rascals":{"_anim","_sb"},
"rased":{"_past"},
"Rashid":{"_prprn"},
"rasht":{"_cty","_geo","_prprn"},
"rask":{"_anim","_nme","_prprn","_sb"},
"rasmussen":{"_anim","_nme","_prprn","_sb"},
"rasped":{"_past"},
"Rasputin":{"_anim","_nme","_prprn","_sb"},
"Rasta":{"_prprn"},
"Rastafarian":{"_prprn"},
"Rastafarianism":{"_prprn"},
"Rastafarians":{"_prprn"},
"Rastas":{"_prprn"},
"rat":{"_anim"},
"rat-catcher":{"_anim"},
"ratcheted":{"_past"},
"rated":{"_past"},
"ratel":{"_anim"},
"ratepayer":{"_anim","_sb"},
"ratepayers":{"_anim","_sb"},
"ratfink":{"_anim","_sb"},
"ratfinks":{"_anim","_sb"},
"ratified":{"_past"},
"ratifier":{"_anim","_sb"},
"ratifiers":{"_anim","_sb"},
"ratings":{"_loc_sr"},
"ratiocinated":{"_past"},
"ratiocinator":{"_anim","_sb"},
"rationalised":{"_past"},
"rationalist":{"_anim","_sb"},
"rationalists":{"_anim","_sb"},
"rationalized":{"_past"},
"rats":{"_anim"},
"ratter":{"_anim"},
"ratters":{"_anim"},
"Rattigan":{"_anim","_nme","_prprn","_sb"},
"rattled":{"_past"},
"rattlesnake":{"_anim"},
"rattlesnakes":{"_anim"},
"Rauschenberg":{"_anim","_nme","_prprn","_sb"},
"ravage":{"_loc_sr"},
"ravaged":{"_loc_sr","_past"},
"ravager":{"_anim","_sb"},
"raved":{"_past"},
"ravenna":{"_cty","_geo","_prprn"},
"raver":{"_anim","_sb"},
"ravers":{"_anim","_sb"},
"ravish":{"_psych"},
"ravisher":{"_anim","_sb"},
"rawalpindi":{"_cty","_geo","_prprn"},
"ray":{"_anim"},
"rayleigh":{"_anim","_nme","_prprn","_sb"},
"Raymond":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"rays":{"_anim"},
"razed":{"_past"},
"razorback":{"_anim"},
"rb":{"_prprn"},
"rbc":{"_prprn"},
"rbi":{"_prprn"},
"rcmp":{"_prprn"},
"re-argued":{"_past"},
"re-armed":{"_past"},
"re-echoed":{"_past"},
"re-edited":{"_past"},
"re-educated":{"_past"},
"re-elected":{"_past"},
"re-emerged":{"_past"},
"re-emphasised":{"_past"},
"re-emphasized":{"_past"},
"re-enacted":{"_past"},
"re-enactor":{"_anim","_sb"},
"re-energised":{"_past"},
"re-energized":{"_past"},
"re-enforced":{"_past"},
"re-engineered":{"_past"},
"re-equipped":{"_past"},
"re-established":{"_past"},
"re-evaluated":{"_past"},
"re-examined":{"_past"},
"re-experienced":{"_past"},
"re-explained":{"_past"},
"re-explored":{"_loc_sr","_past"},
"re-explores":{"_loc_sr"},
"re-exploring":{"_loc_sr"},
"re-export":{"_loc_sr"},
"re-exported":{"_loc_sr","_past"},
"re-exporter":{"_anim","_sb"},
"re-exporting":{"_loc_sr"},
"re-exports":{"_loc_sr"},
"re-formed":{"_past"},
"re-offer":{"_anim","_sb"},
"re-offered":{"_past"},
"re-offers":{"_anim","_sb"},
"re-ran":{"_loc_sr","_past"},
"re-run":{"_loc_sr"},
"re-running":{"_loc_sr"},
"re-runs":{"_loc_sr"},
"reabsorbed":{"_past"},
"reaccelerate":{"_loc_sr"},
"reaccelerated":{"_loc_sr","_past"},
"reaccelerates":{"_loc_sr"},
"reaccelerating":{"_loc_sr"},
"reacquainted":{"_past"},
"reacquired":{"_past"},
"react":{"_loc_sr"},
"reacted":{"_loc_sr","_past"},
"reacting":{"_loc_sr"},
"reactionaries":{"_anim","_sb"},
"reactionary":{"_anim","_sb"},
"reactionist":{"_anim","_sb"},
"reactivated":{"_past"},
"reacts":{"_loc_sr"},
"read":{"_past"},
"readapted":{"_past"},
"readdress":{"_loc_sr"},
"readdressed":{"_loc_sr","_past"},
"readdresses":{"_loc_sr"},
"readdressing":{"_loc_sr"},
"reader":{"_anim","_sb"},
"readers":{"_anim","_sb"},
"readied":{"_past"},
"readjust":{"_loc_sr"},
"readjusted":{"_loc_sr","_past"},
"readmitted":{"_past"},
"readopt":{"_loc_sr"},
"readopted":{"_loc_sr","_past"},
"readopting":{"_loc_sr"},
"readopts":{"_loc_sr"},
"reaffirmed":{"_past"},
"reafforested":{"_past"},
"Reagan":{"_anim","_nme","_prprn","_sb"},
"Reaganomics":{"_prprn"},
"realign":{"_loc_sr"},
"realigned":{"_loc_sr","_past"},
"realigning":{"_loc_sr"},
"realised":{"_past"},
"realist":{"_anim","_sb"},
"realists":{"_anim","_sb"},
"reallocated":{"_past"},
"reallotted":{"_past"},
"realtor":{"_anim","_sb"},
"realtors":{"_anim","_sb"},
"reanimated":{"_past"},
"reaped":{"_past"},
"reappeared":{"_past"},
"reappoint":{"_loc_sr"},
"reappointed":{"_loc_sr","_past"},
"reappointing":{"_loc_sr"},
"reappoints":{"_loc_sr"},
"reapportioned":{"_past"},
"reappraised":{"_past"},
"rear-end":{"_loc_sr"},
"Reardon":{"_prprn"},
"rearmed":{"_past"},
"rearranged":{"_loc_sr","_past"},
"rearranges":{"_loc_sr"},
"reasoned":{"_past"},
"reassembled":{"_past"},
"reassessed":{"_past"},
"reassigned":{"_past"},
"reassumed":{"_past"},
"reassure":{"_psych"},
"reassures":{"_psych"},
"reassuring":{"_psych"},
"reattached":{"_past"},
"reattributed":{"_past"},
"Reaumur":{"_anim","_nme","_prprn","_sb"},
"reauthorised":{"_past"},
"reauthorized":{"_past"},
"reaved":{"_past"},
"reawakened":{"_past"},
"Reb":{"_prprn"},
"rebalanced":{"_past"},
"rebate":{"_loc_sr"},
"rebated":{"_loc_sr","_past"},
"Rebecca":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"rebekah":{"_prprn"},
"rebel":{"_anim","_sb"},
"rebelled":{"_past"},
"rebels":{"_anim","_sb"},
"rebooted":{"_past"},
"rebounded":{"_past"},
"rebounder":{"_anim","_sb"},
"rebounders":{"_anim","_sb"},
"rebuffed":{"_past"},
"rebuilder":{"_anim","_sb"},
"rebuilt":{"_past"},
"rebuker":{"_anim","_sb"},
"reburied":{"_loc_sr","_past"},
"reburies":{"_loc_sr"},
"rebury":{"_loc_sr"},
"rebutted":{"_past"},
"rebutter":{"_anim","_sb"},
"rebutters":{"_anim","_sb"},
"recalcitrant":{"_anim","_sb"},
"recalculated":{"_past"},
"recalled":{"_past"},
"recanted":{"_past"},
"recapitalized":{"_past"},
"recapture":{"_loc_sr"},
"recaptured":{"_loc_sr","_past"},
"recapturing":{"_loc_sr"},
"recast":{"_past"},
"recced":{"_past"},
"recede":{"_loc_sr"},
"receded":{"_loc_sr","_past"},
"receding":{"_loc_sr"},
"received":{"_past"},
"receiver":{"_anim","_sb"},
"receivers":{"_anim","_sb"},
"Recent":{"_tme"},
"recently":{"_tme"},
"recentralized":{"_past"},
"receptacles":{"_loc_sr"},
"receptionist":{"_anim","_sb"},
"receptionists":{"_anim","_sb"},
"recessed":{"_loc_sr","_past"},
"recession":{"_tme"},
"recessions":{"_tme"},
"recharged":{"_past"},
"rechartered":{"_past"},
"recharters":{"_anim","_sb"},
"rechecked":{"_past"},
"rechristen":{"_loc_sr"},
"rechristened":{"_loc_sr","_past"},
"rechristening":{"_loc_sr"},
"rechristens":{"_loc_sr"},
"recidivist":{"_anim","_sb"},
"recidivists":{"_anim","_sb"},
"recife":{"_cty","_geo","_prprn"},
"recipient":{"_anim","_sb"},
"recipients":{"_anim","_sb"},
"reciprocate":{"_loc_sr"},
"reciprocates":{"_loc_sr"},
"recirculate":{"_loc_sr"},
"recirculated":{"_loc_sr","_past"},
"recirculates":{"_loc_sr"},
"recirculating":{"_loc_sr"},
"recitalist":{"_anim","_sb"},
"recite":{"_loc_sr"},
"recited":{"_loc_sr","_past"},
"recites":{"_loc_sr"},
"reciting":{"_loc_sr"},
"reckoned":{"_past"},
"reckoner":{"_anim","_sb"},
"reckoners":{"_anim","_sb"},
"reclaim":{"_loc_sr"},
"reclaimed":{"_loc_sr","_past"},
"reclaiming":{"_loc_sr"},
"reclaims":{"_loc_sr"},
"reclassified":{"_loc_sr","_past"},
"reclassifies":{"_loc_sr"},
"reclassify":{"_loc_sr"},
"reclassifying":{"_loc_sr"},
"recluse":{"_anim","_sb"},
"recluses":{"_anim","_sb"},
"recoated":{"_past"},
"recode":{"_loc_sr"},
"recoded":{"_loc_sr","_past"},
"recodes":{"_loc_sr"},
"recoding":{"_loc_sr"},
"recognised":{"_past"},
"recognized":{"_past"},
"recoiled":{"_past"},
"recollected":{"_past"},
"recommenced":{"_past"},
"recommend":{"_loc_sr"},
"recommended":{"_loc_sr","_past"},
"recommending":{"_loc_sr"},
"recommends":{"_loc_sr"},
"recommitted":{"_past"},
"reconciler":{"_anim","_sb"},
"recondition":{"_loc_sr"},
"reconditioning":{"_loc_sr"},
"reconfigured":{"_past"},
"reconfirmed":{"_past"},
"reconnected":{"_past"},
"reconnoitre":{"_loc_sr"},
"reconnoitred":{"_loc_sr","_past"},
"reconnoitres":{"_loc_sr"},
"reconnoitring":{"_loc_sr"},
"reconsecrate":{"_loc_sr"},
"reconsidered":{"_past"},
"reconstituted":{"_loc_sr","_past"},
"reconstitutes":{"_loc_sr"},
"reconstituting":{"_loc_sr"},
"reconstructed":{"_past"},
"reconvened":{"_past"},
"reconverted":{"_past"},
"reconvicted":{"_past"},
"recopied":{"_past"},
"recorded":{"_past"},
"recounted":{"_past"},
"recouped":{"_past"},
"recovered":{"_past"},
"recoverer":{"_anim","_sb"},
"recreant":{"_anim","_sb"},
"recreants":{"_anim","_sb"},
"recreated":{"_past"},
"recrudesce":{"_loc_sr"},
"recrudesced":{"_loc_sr","_past"},
"recrudesces":{"_loc_sr"},
"recrudescing":{"_loc_sr"},
"recruited":{"_past"},
"recruiter":{"_anim","_sb"},
"recruiters":{"_anim","_sb"},
"recruits":{"_anim","_sb"},
"rectified":{"_past"},
"rector":{"_anim","_sb"},
"rectors":{"_anim","_sb"},
"recurred":{"_past"},
"recurved":{"_past"},
"recusant":{"_anim","_sb"},
"recused":{"_past"},
"recut":{"_past"},
"recycle":{"_loc_sr"},
"recycled":{"_loc_sr","_past"},
"recycler":{"_anim","_sb"},
"recycles":{"_loc_sr"},
"recycling":{"_loc_sr"},
"Red":{"_prprn"},
"redbreast":{"_anim"},
"redcap":{"_anim","_sb"},
"redcaps":{"_anim","_sb"},
"redcoat":{"_anim","_sb"},
"redcoats":{"_anim","_sb"},
"reddened":{"_past"},
"rededicated":{"_past"},
"redeem":{"_loc_sr"},
"redeemed":{"_loc_sr","_past"},
"redeemer":{"_anim","_sb"},
"redeeming":{"_loc_sr"},
"redeems":{"_loc_sr"},
"redefined":{"_past"},
"redelivered":{"_past"},
"redeploy":{"_loc_sr"},
"redeposit":{"_loc_sr"},
"redesigned":{"_loc_sr","_past"},
"redesigning":{"_loc_sr"},
"redetermined":{"_past"},
"redeveloper":{"_anim","_sb"},
"redevelopers":{"_anim","_sb"},
"redfish":{"_anim"},
"redfishes":{"_anim"},
"Redford":{"_geo","_prprn"},
"Redgrave":{"_anim","_nme","_prprn","_sb"},
"redhead":{"_anim","_sb"},
"redheads":{"_anim","_sb"},
"redial":{"_loc_sr"},
"redialed":{"_loc_sr","_past"},
"redialing":{"_loc_sr"},
"redialled":{"_loc_sr","_past"},
"redialling":{"_loc_sr"},
"redials":{"_loc_sr"},
"redid":{"_past"},
"redirected":{"_past"},
"rediscovered":{"_loc_sr","_past"},
"rediscovering":{"_loc_sr"},
"rediscovers":{"_loc_sr"},
"redispose":{"_loc_sr"},
"redisposed":{"_loc_sr","_past"},
"redisposes":{"_loc_sr"},
"redisposing":{"_loc_sr"},
"redistributionist":{"_anim","_sb"},
"redistrict":{"_loc_sr"},
"redistricted":{"_loc_sr","_past"},
"redistricts":{"_loc_sr"},
"Redmond":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"redneck":{"_anim","_sb"},
"rednecks":{"_anim","_sb"},
"redraft":{"_loc_sr"},
"redrafted":{"_loc_sr","_past"},
"redrafting":{"_loc_sr"},
"redrafts":{"_loc_sr"},
"redraw":{"_loc_sr"},
"redrawing":{"_loc_sr"},
"redrawn":{"_loc_sr"},
"redraws":{"_loc_sr"},
"redressed":{"_past"},
"redrew":{"_loc_sr","_past"},
"redshirted":{"_past"},
"redskin":{"_anim","_sb"},
"redstart":{"_sb"},
"reducers":{"_anim","_sb"},
"reduplicated":{"_past"},
"reechoed":{"_past"},
"Reed":{"_anim","_prprn","_sb"},
"reedbuck":{"_anim"},
"reeds":{"_loc_sr"},
"reeked":{"_past"},
"reel":{"_loc_sr"},
"reelected":{"_past"},
"reeled":{"_loc_sr","_past"},
"reeler":{"_anim","_sb"},
"reeling":{"_loc_sr"},
"reemphasized":{"_past"},
"reenacted":{"_past"},
"reenforced":{"_past"},
"reengineered":{"_past"},
"reentered":{"_past"},
"reevaluated":{"_past"},
"reeve":{"_loc_sr"},
"ref":{"_anim","_sb"},
"reface":{"_loc_sr"},
"refaced":{"_loc_sr","_past"},
"refaces":{"_loc_sr"},
"refacing":{"_loc_sr"},
"refectories":{"_loc_sr"},
"referees":{"_anim","_sb"},
"referred":{"_past"},
"refight":{"_loc_sr"},
"refighting":{"_loc_sr"},
"refights":{"_loc_sr"},
"refile":{"_loc_sr"},
"refiled":{"_loc_sr","_past"},
"refiles":{"_loc_sr"},
"refiling":{"_loc_sr"},
"refilled":{"_past"},
"refinanced":{"_past"},
"refined":{"_past"},
"refiner":{"_anim","_sb"},
"refineries":{"_loc_sr"},
"refiners":{"_anim","_sb"},
"refinery":{"_loc_sr"},
"refinished":{"_past"},
"refinisher":{"_anim","_sb"},
"reflated":{"_past"},
"reflect":{"_loc_sr"},
"reflected":{"_loc_sr","_past"},
"reflecting":{"_loc_sr"},
"reflectorized":{"_past"},
"reflects":{"_loc_sr"},
"reflexed":{"_past"},
"reflexologist":{"_anim","_sb"},
"reflexologists":{"_anim","_sb"},
"reflux":{"_loc_sr"},
"refluxing":{"_loc_sr"},
"refocus":{"_loc_sr"},
"refocused":{"_loc_sr","_past"},
"refocuses":{"_loc_sr"},
"refocusing":{"_loc_sr"},
"refold":{"_loc_sr"},
"refolding":{"_loc_sr"},
"refolds":{"_loc_sr"},
"reforested":{"_past"},
"reforged":{"_past"},
"Reformation":{"_prprn"},
"reformed":{"_past"},
"reformist":{"_anim","_sb"},
"reformists":{"_anim","_sb"},
"reformulate":{"_loc_sr"},
"reformulated":{"_loc_sr","_past"},
"refract":{"_loc_sr"},
"refracted":{"_loc_sr","_past"},
"refrained":{"_past"},
"refresh":{"_psych"},
"refreshed":{"_past","_psych"},
"refreshing":{"_psych"},
"refrigerated":{"_past"},
"refrigerator":{"_loc_sr"},
"refrigerators":{"_loc_sr"},
"reft":{"_past"},
"refuge":{"_loc_sr"},
"refugee":{"_anim","_sb"},
"refugees":{"_anim","_sb"},
"refurbished":{"_past"},
"refused":{"_past"},
"refuser":{"_anim","_sb"},
"refusers":{"_anim","_sb"},
"refuted":{"_past"},
"refuter":{"_anim","_sb"},
"regained":{"_past"},
"regaled":{"_past"},
"Regan":{"_prprn"},
"regarded":{"_past"},
"regencies":{"_anim","_sb"},
"regency":{"_anim","_sb"},
"regents":{"_anim","_sb"},
"regimented":{"_loc_sr","_past"},
"regina":{"_cty","_geo","_prprn"},
"Reginald":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"regiomontanus":{"_anim","_nme","_prprn","_sb"},
"region":{"_loc_sr"},
"region-by-region":{"_loc_sr"},
"regions":{"_loc_sr"},
"register":{"_loc_sr"},
"registered":{"_loc_sr","_past"},
"registering":{"_loc_sr"},
"registrants":{"_anim","_sb"},
"registrar":{"_anim","_sb"},
"registrars":{"_anim","_sb"},
"registries":{"_loc_sr"},
"registry":{"_loc_sr"},
"regorged":{"_past"},
"regretted":{"_past"},
"regrew":{"_loc_sr","_past"},
"reground":{"_loc_sr","_past"},
"regroup":{"_loc_sr"},
"regrouped":{"_loc_sr","_past"},
"regrouping":{"_loc_sr"},
"regrowing":{"_loc_sr"},
"regrown":{"_loc_sr"},
"regrows":{"_loc_sr"},
"regular":{"_anim","_sb"},
"regularised":{"_past"},
"regularly":{"_tme"},
"regulars":{"_anim","_sb"},
"regulated":{"_past"},
"regurgitate":{"_loc_sr"},
"regurgitated":{"_loc_sr","_past"},
"regurgitating":{"_loc_sr"},
"rehabbed":{"_past"},
"rehabilitate":{"_loc_sr"},
"rehabilitated":{"_loc_sr","_past"},
"rehabilitating":{"_loc_sr"},
"reharmonize":{"_loc_sr"},
"rehash":{"_loc_sr"},
"rehashed":{"_loc_sr","_past"},
"rehashing":{"_loc_sr"},
"rehearse":{"_loc_sr"},
"rehearsing":{"_loc_sr"},
"rehnquist":{"_anim","_nme","_prprn","_sb"},
"rehouse":{"_loc_sr"},
"rehoused":{"_loc_sr","_past"},
"rehouses":{"_loc_sr"},
"rehousing":{"_loc_sr"},
"Reich":{"_anim","_nme","_prprn","_sb"},
"Reichenberg":{"_prprn"},
"Reichstag":{"_prprn"},
"reichstein":{"_anim","_nme","_prprn","_sb"},
"Reid":{"_anim","_nme","_prprn","_sb"},
"reified":{"_past"},
"reigned":{"_past"},
"reigns":{"_tme"},
"Reilly":{"_prprn"},
"reimbursed":{"_past"},
"reimposed":{"_past"},
"reincarnated":{"_past"},
"reincorporated":{"_past"},
"reined":{"_past"},
"reinforced":{"_past"},
"reinforcements":{"_sb"},
"Reinhardt":{"_anim","_nme","_prprn","_sb"},
"reinstall":{"_loc_sr"},
"reinstalled":{"_loc_sr","_past"},
"reinstate":{"_loc_sr"},
"reinstated":{"_loc_sr","_past"},
"reinstating":{"_loc_sr"},
"reinstituting":{"_loc_sr"},
"reinsured":{"_past"},
"reinsurer":{"_anim","_sb"},
"reinsurers":{"_anim","_sb"},
"reintegrated":{"_past"},
"reinterpreted":{"_past"},
"reintroduced":{"_past"},
"reinvented":{"_past"},
"reinvest":{"_loc_sr"},
"reinvested":{"_loc_sr","_past"},
"reinvestigating":{"_loc_sr"},
"reinvesting":{"_loc_sr"},
"reinvigorated":{"_past"},
"reissue":{"_loc_sr"},
"reissued":{"_loc_sr","_past"},
"reit":{"_prprn"},
"reiterated":{"_past"},
"rejected":{"_past"},
"rejoiced":{"_past"},
"rejoin":{"_loc_sr"},
"rejoined":{"_loc_sr","_past"},
"rejoining":{"_loc_sr"},
"rejoins":{"_loc_sr"},
"rejuvenated":{"_past"},
"rekindled":{"_past"},
"relace":{"_loc_sr"},
"relapse":{"_loc_sr"},
"relapsed":{"_loc_sr","_past"},
"relapsing":{"_loc_sr"},
"relation":{"_anim","_sb"},
"relations":{"_anim","_sb"},
"relative":{"_anim","_sb"},
"relative-in-law":{"_anim","_sb"},
"relatives":{"_anim","_sb"},
"relativity":{"_sb"},
"relaunch":{"_loc_sr"},
"relaunched":{"_loc_sr","_past"},
"relax":{"_psych"},
"relaxed":{"_past","_psych"},
"relaxes":{"_psych"},
"relaxing":{"_psych"},
"relay":{"_loc_sr"},
"relayed":{"_past"},
"relearns":{"_loc_sr"},
"relegate":{"_loc_sr"},
"relegated":{"_loc_sr","_past"},
"relegating":{"_loc_sr"},
"relented":{"_past"},
"relentlessly":{"_tme"},
"relics":{"_sb"},
"relied":{"_past"},
"relieve":{"_psych"},
"relieved":{"_past","_psych"},
"reliever":{"_anim","_sb"},
"relievers":{"_anim","_sb"},
"relieves":{"_psych"},
"relieving":{"_psych"},
"religious":{"_anim","_sb"},
"relinquished":{"_past"},
"relished":{"_past"},
"relistening":{"_loc_sr"},
"relive":{"_loc_sr"},
"relives":{"_loc_sr"},
"reloaded":{"_past"},
"relocate":{"_loc_sr"},
"remade":{"_past"},
"remain":{"_loc_sr,_vlink"},
"remained":{"_loc_sr","_past"},
"remaining":{"_loc_sr"},
"remand":{"_loc_sr"},
"remanded":{"_loc_sr","_past"},
"remanding":{"_loc_sr"},
"remarked":{"_loc_sr","_past"},
"remarking":{"_loc_sr"},
"Remarque":{"_anim","_prprn","_sb"},
"remarried":{"_past"},
"remedied":{"_past"},
"remember":{"_loc_sr"},
"remembered":{"_loc_sr","_past"},
"remembering":{"_loc_sr"},
"remembers":{"_loc_sr"},
"remilitarised":{"_past"},
"remilitarize":{"_loc_sr"},
"remilitarized":{"_loc_sr","_past"},
"remilitarizing":{"_loc_sr"},
"reminded":{"_past"},
"Remington":{"_anim","_nme","_prprn","_sb"},
"reminisced":{"_past"},
"remised":{"_past"},
"remit":{"_loc_sr"},
"remodel":{"_loc_sr"},
"remodeled":{"_loc_sr","_past"},
"remodeling":{"_loc_sr"},
"remonstrated":{"_loc_sr","_past"},
"remora":{"_anim"},
"remoralised":{"_past"},
"remoralized":{"_loc_sr","_past"},
"remoralizes":{"_loc_sr"},
"remoralizing":{"_loc_sr"},
"remoras":{"_anim"},
"remoulded":{"_past"},
"remove":{"_loc_sr"},
"removers":{"_anim","_sb"},
"removing":{"_loc_sr"},
"remunerated":{"_past"},
"remunerator":{"_anim","_sb"},
"remunerators":{"_anim","_sb"},
"Remus":{"_prprn"},
"Renaissance":{"_prprn"},
"renamed":{"_past"},
"renationalised":{"_past"},
"renationalize":{"_loc_sr"},
"renationalized":{"_loc_sr","_past"},
"renationalizes":{"_loc_sr"},
"renationalizing":{"_loc_sr"},
"rendered":{"_past"},
"rendezvoused":{"_past"},
"Renee":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"reneged":{"_past"},
"renegotiated":{"_past"},
"renewed":{"_past"},
"Renfrew":{"_prprn"},
"Rennie":{"_prprn"},
"reno":{"_cty","_geo","_prprn"},
"renoir":{"_anim","_nme","_prprn","_sb"},
"renormalised":{"_past"},
"renormalized":{"_loc_sr","_past"},
"renormalizes":{"_loc_sr"},
"renormalizing":{"_loc_sr"},
"renounced":{"_past"},
"renovate":{"_loc_sr"},
"renovating":{"_loc_sr"},
"renovator":{"_anim","_sb"},
"renovators":{"_anim","_sb"},
"rent":{"_past"},
"rented":{"_past"},
"renter":{"_anim","_sb"},
"renters":{"_anim","_sb"},
"rentier":{"_anim","_sb"},
"reopened":{"_past"},
"reorganised":{"_past"},
"reorganized":{"_past"},
"reorient":{"_loc_sr"},
"reorientated":{"_past"},
"rep":{"_anim","_sb"},
"Rep.":{"_anim","_prprn","_sb"},
"repack":{"_loc_sr"},
"repackage":{"_loc_sr"},
"repackaged":{"_loc_sr","_past"},
"repackaging":{"_loc_sr"},
"repaid":{"_past"},
"repainted":{"_past"},
"repaired":{"_past"},
"repairer":{"_anim","_sb"},
"repairers":{"_anim","_sb"},
"repairman":{"_anim","_masc","_sb"},
"repairmen":{"_anim","_masc","_sb"},
"repass":{"_loc_sr"},
"repassage":{"_loc_sr"},
"repassed":{"_loc_sr","_past"},
"repasses":{"_loc_sr"},
"repassing":{"_loc_sr"},
"repatriated":{"_loc_sr","_past"},
"repeated":{"_past"},
"repel":{"_psych"},
"repelled":{"_past","_psych"},
"repelling":{"_psych"},
"repels":{"_psych"},
"repercussed":{"_past"},
"rephrased":{"_past"},
"repined":{"_past"},
"replace":{"_loc_sr"},
"replaced":{"_loc_sr","_past"},
"replaces":{"_loc_sr"},
"replacing":{"_loc_sr"},
"replanted":{"_past"},
"replaster":{"_loc_sr"},
"replastered":{"_loc_sr","_past"},
"replastering":{"_loc_sr"},
"replasters":{"_loc_sr"},
"replenished":{"_past"},
"replicated":{"_past"},
"replied":{"_loc_sr","_past"},
"reply":{"_loc_sr"},
"replying":{"_loc_sr"},
"repointed":{"_past"},
"reported":{"_past"},
"reporter":{"_anim","_sb"},
"reporters":{"_anim","_sb"},
"reposed":{"_past"},
"reposited":{"_past"},
"reposition":{"_loc_sr"},
"repositioning":{"_loc_sr"},
"repositories":{"_loc_sr"},
"repository":{"_loc_sr"},
"repossessed":{"_past"},
"repot":{"_loc_sr"},
"reprehended":{"_past"},
"representative":{"_anim","_sb"},
"representatives":{"_anim","_sb"},
"repressed":{"_past"},
"repriced":{"_past"},
"reproacher":{"_anim","_sb"},
"reproachers":{"_anim","_sb"},
"reprobated":{"_past"},
"reprobates":{"_anim","_sb"},
"reproduced":{"_past"},
"reprover":{"_anim","_sb"},
"reps":{"_anim","_sb"},
"reptile":{"_anim"},
"reptiles":{"_anim"},
"reptilia":{"_loc_sr"},
"reptilian":{"_anim"},
"Republican":{"_anim","_prprn","_sb"},
"republicans":{"_anim","_sb"},
"repulse":{"_psych"},
"repulsed":{"_past","_psych"},
"repurchased":{"_past"},
"reputed":{"_past"},
"requalified":{"_past"},
"requested":{"_past"},
"requester":{"_anim","_sb"},
"requesters":{"_anim","_sb"},
"requiem":{"_sb"},
"requiems":{"_sb"},
"required":{"_past"},
"requisitioned":{"_past"},
"reroof":{"_loc_sr"},
"reroofed":{"_loc_sr","_past"},
"reroofing":{"_loc_sr"},
"reroofs":{"_loc_sr"},
"reroute":{"_loc_sr"},
"rerouted":{"_past"},
"reroutes":{"_loc_sr"},
"rerouting":{"_loc_sr"},
"rescaled":{"_past"},
"rescheduled":{"_past"},
"rescinded":{"_past"},
"rescriptor":{"_anim","_sb"},
"rescue":{"_loc_sr"},
"rescued":{"_loc_sr","_past"},
"rescuing":{"_loc_sr"},
"resealed":{"_past"},
"researched":{"_past"},
"researcher":{"_anim","_sb"},
"researchers":{"_anim","_sb"},
"reseated":{"_past"},
"resected":{"_past"},
"reseeded":{"_past"},
"reseller":{"_anim","_sb"},
"resellers":{"_anim","_sb"},
"resembled":{"_past"},
"resend":{"_loc_sr"},
"resends":{"_loc_sr"},
"resent":{"_loc_sr","_past"},
"resented":{"_past"},
"reserved":{"_past"},
"reservist":{"_anim","_sb"},
"reservists":{"_anim","_sb"},
"reservoirs":{"_loc_sr"},
"reset":{"_past"},
"resettle":{"_loc_sr"},
"resettled":{"_loc_sr","_past"},
"resettles":{"_loc_sr"},
"resettling":{"_loc_sr"},
"reshaped":{"_past"},
"reshipped":{"_past"},
"reshot":{"_past"},
"resht":{"_geo","_prprn"},
"reshuffled":{"_past"},
"resided":{"_past"},
"residence":{"_loc_sr"},
"residences":{"_loc_sr"},
"resident":{"_anim","_sb"},
"residents":{"_anim","_sb"},
"resift":{"_loc_sr"},
"resifted":{"_loc_sr","_past"},
"resifting":{"_loc_sr"},
"resifts":{"_loc_sr"},
"resiled":{"_past"},
"resinated":{"_past"},
"resisted":{"_past"},
"resized":{"_past"},
"resold":{"_past"},
"resoled":{"_past"},
"resolved":{"_past"},
"resonated":{"_past"},
"resorbed":{"_past"},
"resort":{"_loc_sr"},
"resorts":{"_loc_sr"},
"resourced":{"_past"},
"respected":{"_past"},
"respecter":{"_anim","_sb"},
"respecters":{"_anim","_sb"},
"responded":{"_past"},
"respondent":{"_anim","_sb"},
"respondents":{"_anim","_sb"},
"responders":{"_anim","_sb"},
"restaffed":{"_past"},
"restage":{"_loc_sr"},
"restaged":{"_loc_sr","_past"},
"restages":{"_loc_sr"},
"restaging":{"_loc_sr"},
"restarted":{"_past"},
"restarters":{"_anim","_sb"},
"restate":{"_loc_sr"},
"restated":{"_loc_sr","_past"},
"restates":{"_loc_sr"},
"restating":{"_loc_sr"},
"restaurant":{"_loc_sr"},
"restaurants":{"_loc_sr"},
"restaurateur":{"_anim","_sb"},
"rested":{"_past"},
"rester":{"_anim","_sb"},
"restituted":{"_past"},
"restocked":{"_past"},
"Restoration":{"_prprn"},
"restore":{"_loc_sr"},
"restored":{"_loc_sr","_past"},
"restorers":{"_anim","_sb"},
"restores":{"_loc_sr"},
"restoring":{"_loc_sr"},
"restrain":{"_loc_sr"},
"restrained":{"_loc_sr","_past"},
"restrainer":{"_anim","_sb"},
"restraining":{"_loc_sr"},
"restrains":{"_loc_sr"},
"restricted":{"_past"},
"restroom":{"_loc_sr"},
"restrooms":{"_loc_sr"},
"restructured":{"_past"},
"restudied":{"_loc_sr","_past"},
"restudies":{"_loc_sr"},
"restudying":{"_loc_sr"},
"restyle":{"_loc_sr"},
"restyles":{"_loc_sr"},
"restyling":{"_loc_sr"},
"resublimed":{"_past"},
"resubmitted":{"_past"},
"resulted":{"_past"},
"resumed":{"_past"},
"resupplied":{"_past"},
"resurfaced":{"_past"},
"resurrect":{"_loc_sr"},
"resurrected":{"_loc_sr","_past"},
"resurrecting":{"_loc_sr"},
"resurrects":{"_loc_sr"},
"resuscitated":{"_past"},
"resuspended":{"_past"},
"retailed":{"_loc_sr","_past"},
"retailer":{"_anim","_sb"},
"retailers":{"_anim","_sb"},
"retailing":{"_loc_sr"},
"retained":{"_past"},
"retainers":{"_anim","_sb"},
"retaliated":{"_past"},
"retarded":{"_anim","_sb"},
"retarding":{"_loc_sr"},
"retargeted":{"_past"},
"rethought":{"_past"},
"reticulated":{"_past"},
"retied":{"_past"},
"retina":{"_loc_sr"},
"retinas":{"_loc_sr"},
"retire":{"_loc_sr"},
"retired":{"_loc_sr","_past"},
"retiree":{"_anim","_sb"},
"retirement":{"_tme"},
"retirements":{"_tme"},
"retires":{"_loc_sr"},
"retiring":{"_loc_sr"},
"retooled":{"_past"},
"retorted":{"_past"},
"retoucher":{"_anim","_sb"},
"retrace":{"_loc_sr"},
"retraced":{"_loc_sr","_past"},
"retracing":{"_loc_sr"},
"retracted":{"_past"},
"retrained":{"_past"},
"retranslated":{"_past"},
"retransmit":{"_loc_sr"},
"retransmits":{"_loc_sr"},
"retransmitted":{"_loc_sr","_past"},
"retransmitting":{"_loc_sr"},
"retreat":{"_loc_sr"},
"retreatant":{"_anim","_sb"},
"retreated":{"_loc_sr","_past"},
"retreating":{"_loc_sr"},
"retried":{"_past"},
"retrievers":{"_anim"},
"retrofitted":{"_past"},
"retrograde":{"_loc_sr"},
"retrogress":{"_loc_sr"},
"retrogressed":{"_loc_sr","_past"},
"retrogresses":{"_loc_sr"},
"retrogressing":{"_loc_sr"},
"Retrovir":{"_prprn"},
"returnable":{"_loc_sr"},
"returned":{"_loc_sr","_past"},
"returnee":{"_anim","_sb"},
"returnees":{"_anim","_sb"},
"returner":{"_anim","_sb"},
"returning":{"_loc_sr"},
"Reuben":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"reunified":{"_past"},
"reunited":{"_past"},
"reupholstered":{"_past"},
"reused":{"_past"},
"Reuter":{"_anim","_nme","_prprn","_sb"},
"Reuther":{"_anim","_nme","_prprn","_sb"},
"Rev.":{"_anim","_prprn","_sb"},
"revalued":{"_past"},
"revamped":{"_past"},
"revealed":{"_past"},
"Revelation":{"_prprn"},
"reveled":{"_loc_sr","_past"},
"revelling":{"_loc_sr"},
"revenant":{"_anim"},
"revenuer":{"_anim","_sb"},
"revenuers":{"_anim","_sb"},
"reverberated":{"_past"},
"revered":{"_past"},
"Reverend":{"_anim","_prprn","_sb"},
"reverse":{"_loc_sr"},
"reversed":{"_loc_sr","_past"},
"reversing":{"_loc_sr"},
"reversioner":{"_anim","_sb"},
"reversionist":{"_anim","_sb"},
"revetted":{"_past"},
"reviewed":{"_loc_sr","_past"},
"reviewer":{"_anim","_sb"},
"reviewers":{"_anim","_sb"},
"reviewing":{"_loc_sr"},
"reviled":{"_past"},
"revise":{"_loc_sr"},
"revised":{"_loc_sr","_past"},
"revises":{"_loc_sr"},
"revising":{"_loc_sr"},
"revisited":{"_past"},
"revitalised":{"_past"},
"revitalized":{"_past"},
"revivalist":{"_anim","_sb"},
"revivalists":{"_anim","_sb"},
"revived":{"_past"},
"revivified":{"_past"},
"revoked":{"_past"},
"revolted":{"_past","_psych"},
"revolting":{"_psych"},
"revolutionaries":{"_anim","_sb"},
"revolutionary":{"_anim","_sb"},
"revolutionised":{"_past"},
"revolutionist":{"_anim","_sb"},
"revolutionists":{"_anim","_sb"},
"revolutionized":{"_past"},
"revolved":{"_past"},
"revved":{"_past"},
"rewarded":{"_past"},
"reword":{"_loc_sr"},
"rewording":{"_loc_sr"},
"reworked":{"_past"},
"rewrap":{"_loc_sr"},
"rewrapped":{"_loc_sr","_past"},
"rewrapping":{"_loc_sr"},
"rewraps":{"_loc_sr"},
"rewrite":{"_loc_sr"},
"rewriter":{"_anim","_sb"},
"rewriters":{"_anim","_sb"},
"rewriting":{"_loc_sr"},
"rewritten":{"_loc_sr"},
"rewrote":{"_loc_sr","_past"},
"Rex":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Reykjavik":{"_cty","_geo","_prprn"},
"reynolds":{"_anim","_nme","_prprn","_sb"},
"Rh":{"_prprn"},
"rhadamanthus":{"_prprn"},
"rhaeto-romance":{"_prprn"},
"rhapsodised":{"_past"},
"rhapsodized":{"_past"},
"Rhea":{"_anim","_fem","_prprn","_sb"},
"rheims":{"_cty","_geo","_prprn"},
"Rheingold":{"_prprn"},
"Rhenish":{"_prprn"},
"rhetorician":{"_anim","_sb"},
"rhetoricians":{"_anim","_sb"},
"rheumatic":{"_anim","_sb"},
"rheumatics":{"_anim","_sb"},
"rheumatologist":{"_anim","_sb"},
"rheumatologists":{"_anim","_sb"},
"Rhin":{"_prprn"},
"rhine":{"_anim","_geo","_nme","_prprn","_sb"},
"Rhineland":{"_geo","_prprn"},
"rhino":{"_anim"},
"rhinoceros":{"_anim"},
"rhinos":{"_anim"},
"Rhoda":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"rhodes":{"_anim","_geo","_nme","_prprn","_sb"},
"rhodesia":{"_cntry","_geo","_prprn"},
"rhone":{"_geo","_prprn"},
"rhone-alpes":{"_geo","_prprn"},
"rhymed":{"_past"},
"rhymer":{"_anim","_sb"},
"rhymers":{"_anim","_sb"},
"rhymester":{"_anim","_sb"},
"rhymesters":{"_anim","_sb"},
"Rhys":{"_anim","_nme","_prprn","_sb"},
"RI":{"_prprn","_stte"},
"ribald":{"_sb"},
"ribbed":{"_past"},
"ribbonfish":{"_anim"},
"ricardo":{"_anim","_nme","_prprn","_sb"},
"rich":{"_anim","_sb"},
"Richard":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Richards":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"richardson":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"richelieu":{"_anim","_geo","_nme","_prprn","_sb"},
"richler":{"_anim","_nme","_prprn","_sb"},
"Richmond":{"_cty","_geo","_prprn"},
"rick":{"_loc_sr"},
"rickenbacker":{"_anim","_nme","_prprn","_sb"},
"rickover":{"_anim","_nme","_prprn","_sb"},
"ricochet":{"_loc_sr"},
"ricocheted":{"_loc_sr","_past"},
"rid":{"_past"},
"ridden":{"_loc_sr"},
"riddle":{"_loc_sr"},
"riddled":{"_loc_sr","_past"},
"riddling":{"_loc_sr"},
"ride":{"_loc_sr"},
"rider-fashion":{"_anim","_sb"},
"riders":{"_anim","_sb"},
"ridged":{"_past"},
"ridgeling":{"_anim","_masc"},
"ridiculed":{"_past"},
"ridiculer":{"_anim","_sb"},
"riding":{"_loc_sr"},
"ridley":{"_loc_sr"},
"Riefenstahl":{"_prprn"},
"riemann":{"_anim","_nme","_prprn","_sb"},
"Riesling":{"_prprn"},
"riesman":{"_anim","_nme","_prprn","_sb"},
"riffraff":{"_sb"},
"riflemen":{"_anim","_sb"},
"Rig-Veda":{"_prprn"},
"riga":{"_cty","_geo","_prprn"},
"rigel":{"_prprn"},
"right-hander":{"_anim","_sb"},
"right-handers":{"_anim","_sb"},
"right-winger":{"_anim","_sb"},
"right-wingers":{"_anim","_sb"},
"rightist":{"_anim","_sb"},
"rightists":{"_anim","_sb"},
"rigidified":{"_past"},
"riksmal":{"_prprn"},
"rile":{"_psych"},
"riled":{"_past","_psych"},
"riles":{"_psych"},
"Riley":{"_anim","_fnme","_nme","_prprn","_sb"},
"Rilke":{"_anim","_nme","_prprn","_sb"},
"rimbaud":{"_anim","_nme","_prprn","_sb"},
"rimed":{"_past"},
"Rimini":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"rimmed":{"_past"},
"Rimsky-Korsakov":{"_prprn"},
"ringed":{"_past"},
"ringers":{"_anim","_sb"},
"ringling":{"_anim","_nme","_prprn","_sb"},
"ringmaster":{"_anim","_sb"},
"ringmasters":{"_anim","_sb"},
"ringside":{"_loc_sr"},
"ringsider":{"_anim","_sb"},
"ringsiders":{"_anim","_sb"},
"ringtail":{"_anim"},
"rink":{"_loc_sr"},
"rinks":{"_loc_sr"},
"rinsing":{"_loc_sr"},
"Rio":{"_geo","_prprn"},
"rioted":{"_loc_sr","_past"},
"rioter":{"_anim","_sb"},
"rioters":{"_anim","_sb"},
"rioting":{"_loc_sr"},
"ripened":{"_past"},
"Ripley":{"_anim","_nme","_prprn","_sb"},
"riposted":{"_past"},
"ripped":{"_past"},
"ripper":{"_anim","_sb"},
"rippers":{"_anim","_sb"},
"ripple":{"_loc_sr"},
"rippled":{"_loc_sr","_past"},
"rippling":{"_loc_sr"},
"risk-taker":{"_anim","_sb"},
"risk-takers":{"_anim","_sb"},
"risked":{"_loc_sr","_past"},
"risking":{"_loc_sr"},
"Rita":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Ritalin":{"_prprn"},
"rittenhouse":{"_anim","_nme","_prprn","_sb"},
"ritualised":{"_past"},
"ritualist":{"_anim","_sb"},
"ritualized":{"_past"},
"rival":{"_anim","_sb"},
"rivalled":{"_past"},
"river":{"_loc_sr"},
"river-bed":{"_loc_sr"},
"river-beds":{"_loc_sr"},
"rivera":{"_anim","_nme","_prprn","_sb"},
"riverfront":{"_loc_sr"},
"rivers":{"_loc_sr"},
"riverside":{"_loc_sr"},
"rivet":{"_psych"},
"riveted":{"_past","_psych"},
"riveter":{"_anim","_sb"},
"riveters":{"_anim","_sb"},
"riveting":{"_psych"},
"Riviera":{"_geo","_prprn","_stte"},
"Riyadh":{"_cty","_geo","_prprn"},
"RN":{"_prprn"},
"RNA":{"_prprn"},
"rnase":{"_prprn"},
"roach":{"_anim"},
"roaches":{"_anim"},
"roadman":{"_anim","_sb"},
"roadmen":{"_anim","_sb"},
"roadside":{"_loc_sr"},
"roadsides":{"_loc_sr"},
"roadstead":{"_loc_sr"},
"roam":{"_loc_sr"},
"roamed":{"_loc_sr","_past"},
"Roaming":{"_loc_sr"},
"roams":{"_loc_sr"},
"roan":{"_anim"},
"Roanoke":{"_cty","_geo","_prprn"},
"roans":{"_anim"},
"roar":{"_loc_sr"},
"roared":{"_loc_sr","_past"},
"roaring":{"_loc_sr"},
"roasted":{"_past"},
"robbed":{"_past"},
"robber":{"_anim","_sb"},
"robbers":{"_anim","_sb"},
"robbins":{"_anim","_nme","_prprn","_sb"},
"robe":{"_loc_sr"},
"robed":{"_loc_sr","_past"},
"Robert":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Roberta":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Roberts":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"robertson":{"_anim","_nme","_prprn","_sb"},
"robeson":{"_anim","_nme","_prprn","_sb"},
"Robespierre":{"_anim","_nme","_prprn","_sb"},
"robin":{"_anim"},
"robing":{"_loc_sr"},
"robins":{"_anim"},
"Robinson":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"robot":{"_anim"},
"robots":{"_anim"},
"rochambeau":{"_anim","_nme","_prprn","_sb"},
"Rochdale":{"_geo","_prprn"},
"Rochester":{"_cty","_geo","_prprn"},
"rocked":{"_loc_sr","_past"},
"Rockefeller":{"_anim","_nme","_prprn","_sb"},
"rocketing":{"_loc_sr"},
"Rockford":{"_cty","_geo","_prprn"},
"Rockies":{"_geo","_prprn"},
"rockin":{"_loc_sr"},
"rocking":{"_loc_sr"},
"rocking-chair":{"_loc_sr"},
"rocking-chairs":{"_loc_sr"},
"rocking-horse":{"_loc_sr"},
"rocking-horses":{"_loc_sr"},
"Rockingham":{"_anim","_nme","_prprn","_sb"},
"Rockwell":{"_anim","_nme","_prprn","_sb"},
"rococo":{"_prprn"},
"Roddick":{"_prprn"},
"rodents":{"_anim","_sb"},
"Roderick":{"_prprn"},
"rodgers":{"_anim","_nme","_prprn","_sb"},
"Rodin":{"_anim","_nme","_prprn","_sb"},
"Rodney":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Rodrigo":{"_prprn"},
"roe":{"_anim"},
"roebling":{"_anim","_nme","_prprn","_sb"},
"roebuck":{"_anim","_masc"},
"roes":{"_anim"},
"Roger":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"rogers":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"roget":{"_anim","_nme","_prprn","_sb"},
"rogues":{"_anim","_sb"},
"roiled":{"_past"},
"roister":{"_loc_sr"},
"roisterers":{"_anim","_sb"},
"Roland":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"role-played":{"_past"},
"rolf":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Rolfe":{"_anim","_nme","_prprn","_sb"},
"roll":{"_loc_sr"},
"Rolland":{"_anim","_nme","_prprn","_sb"},
"rolled":{"_loc_sr","_past"},
"rolled-up":{"_loc_sr","_past"},
"roller-skate":{"_loc_sr"},
"roller-skater":{"_anim","_sb"},
"rollick":{"_loc_sr"},
"rollicking":{"_loc_sr"},
"rolling":{"_loc_sr"},
"rolling-mill":{"_loc_sr"},
"rolling-mills":{"_loc_sr"},
"rolling-pin":{"_loc_sr"},
"rolling-pins":{"_loc_sr"},
"rolling-steel":{"_loc_sr"},
"rolling-stock":{"_loc_sr"},
"rolling-writer":{"_loc_sr"},
"Rollins":{"_prprn"},
"rollo":{"_anim","_nme","_prprn","_sb"},
"roly-polies":{"_sb"},
"roly-poly":{"_sb"},
"Romaic":{"_prprn"},
"Roman":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"romancer":{"_anim","_sb"},
"romancers":{"_anim","_sb"},
"Romanesque":{"_loc_sr","_prprn"},
"Romani":{"_prprn"},
"Romania":{"_cntry","_geo","_prprn"},
"romanian":{"_anim","_prprn","_sb"},
"Romanic":{"_prprn"},
"Romanies":{"_prprn"},
"Romanism":{"_prprn"},
"Romanist":{"_anim","_prprn","_sb"},
"Romano":{"_anim","_nme","_prprn","_sb"},
"romanoff":{"_prprn"},
"Romanov":{"_anim","_nme","_prprn","_sb"},
"Romansch":{"_prprn"},
"Romansh":{"_prprn"},
"romantic":{"_anim","_sb"},
"romanticised":{"_past"},
"romanticized":{"_past"},
"romantics":{"_anim","_sb"},
"Romany":{"_prprn"},
"romberg":{"_anim","_nme","_prprn","_sb"},
"rome":{"_cty","_geo","_prprn"},
"Romeo":{"_anim","_masc","_prprn","_sb"},
"rommel":{"_anim","_nme","_prprn","_sb"},
"Romney":{"_anim","_nme","_prprn","_sb"},
"romped":{"_past"},
"romulus":{"_cty","_geo","_prprn"},
"ron":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Ronald":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"roofed":{"_loc_sr","_past"},
"roofers":{"_anim","_sb"},
"roofing":{"_loc_sr"},
"rook":{"_anim"},
"rookery":{"_loc_sr"},
"rookie":{"_anim","_sb"},
"rookies":{"_anim","_sb"},
"room":{"_loc_sr"},
"room-mate":{"_loc_sr"},
"room-mates":{"_loc_sr"},
"roomed":{"_past"},
"roomer":{"_anim","_sb"},
"roomers":{"_anim","_sb"},
"roommate":{"_anim","_loc_sr","_sb"},
"roommates":{"_anim","_loc_sr","_sb"},
"rooms":{"_loc_sr"},
"Rooney":{"_prprn"},
"Roosevelt":{"_anim","_geo","_nme","_prprn","_sb"},
"roosters":{"_anim"},
"rooted":{"_past"},
"rooter":{"_anim","_sb"},
"rooters":{"_anim","_sb"},
"rootled":{"_past"},
"roped":{"_past"},
"ropedancer":{"_anim","_sb"},
"ropedancers":{"_anim","_sb"},
"roper":{"_anim","_sb"},
"ropers":{"_anim","_sb"},
"ropewalk":{"_loc_sr"},
"Roquefort":{"_prprn"},
"rorqual":{"_anim"},
"Rosa":{"_anim","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"Rosalie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Rosalind":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Rosalyn":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"rosarian":{"_anim","_sb"},
"rosarians":{"_anim","_sb"},
"Rosario":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"Roscoe":{"_prprn"},
"rose":{"_past"},
"rose-bud":{"_sb"},
"rose-coloured":{"_sb"},
"rose-hip":{"_sb"},
"rose-hips":{"_sb"},
"rose-tinted":{"_sb"},
"rose-water":{"_sb"},
"rose-window":{"_sb"},
"rose-windows":{"_sb"},
"Roseau":{"_cty","_geo","_prprn"},
"rosefish":{"_anim","_loc_sr"},
"rosefishes":{"_anim","_loc_sr"},
"Rosenberg":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"roses":{"_sb"},
"rosicrucian":{"_prprn","_sb"},
"Ross":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Rossetti":{"_anim","_nme","_prprn","_sb"},
"Rossini":{"_anim","_nme","_prprn","_sb"},
"rostand":{"_anim","_nme","_prprn","_sb"},
"rostock":{"_cty","_geo","_prprn"},
"rostov":{"_cty","_geo","_prprn"},
"rostra":{"_loc_sr"},
"rostrum":{"_loc_sr"},
"rostrums":{"_loc_sr"},
"roswell":{"_cty","_geo","_prprn"},
"rotarian":{"_prprn","_sb"},
"rotated":{"_past"},
"ROTC":{"_prprn"},
"roth":{"_anim","_nme","_prprn","_sb"},
"Rothko":{"_anim","_nme","_prprn","_sb"},
"Rothschild":{"_anim","_nme","_prprn","_sb"},
"rotl":{"_loc_sr"},
"rotter":{"_anim","_sb"},
"Rotterdam":{"_cty","_geo","_prprn"},
"rotters":{"_anim","_sb"},
"rottweiler":{"_anim"},
"rottweilers":{"_anim"},
"rotunda":{"_loc_sr"},
"rotundas":{"_loc_sr"},
"roue":{"_sb"},
"rouged":{"_past"},
"rough":{"_anim","_sb"},
"rough-dried":{"_past"},
"rough-house":{"_anim","_sb"},
"roughed":{"_past"},
"roughened":{"_past"},
"roughhouse":{"_loc_sr"},
"roughneck":{"_anim","_sb"},
"roughnecks":{"_anim","_sb"},
"roughrider":{"_anim","_sb"},
"roughriders":{"_anim","_sb"},
"Roumania":{"_prprn"},
"Roumanian":{"_prprn"},
"rounded":{"_past"},
"roundhead":{"_prprn"},
"roundhouse":{"_loc_sr"},
"roundsman":{"_anim","_sb"},
"roundsmen":{"_anim","_sb"},
"rous":{"_anim","_nme","_prprn","_sb"},
"rouse":{"_loc_sr"},
"roused":{"_loc_sr","_past"},
"rousing":{"_loc_sr"},
"Rousseau":{"_anim","_nme","_prprn","_sb"},
"roustabout":{"_anim","_sb"},
"roustabouts":{"_anim","_sb"},
"routed":{"_loc_sr","_past"},
"routinely":{"_tme"},
"routing":{"_loc_sr"},
"rove":{"_loc_sr"},
"roved":{"_loc_sr","_past"},
"rover":{"_anim","_sb"},
"rovers":{"_anim","_sb"},
"roving":{"_loc_sr"},
"rowdies":{"_anim","_sb"},
"Rowe":{"_anim","_nme","_prprn","_sb"},
"rowers":{"_anim","_sb"},
"rowing-boat":{"_loc_sr"},
"rowing-boats":{"_loc_sr"},
"Rowley":{"_prprn"},
"Roxanne":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Roy":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"royal":{"_anim","_sb"},
"royalist":{"_anim","_sb"},
"royalists":{"_anim","_sb"},
"royals":{"_anim","_sb"},
"royalties":{"_anim","_sb"},
"royalty":{"_anim","_sb"},
"Royce":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"ru":{"_prprn"},
"Ruanda":{"_geo","_prprn"},
"Ruanda-Urundi":{"_geo","_prprn"},
"rubbed":{"_past"},
"rubber-stamped":{"_past"},
"rubberised":{"_past"},
"rubberized":{"_past"},
"Ruben":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Rubens":{"_anim","_nme","_prprn","_sb"},
"Rubicon":{"_prprn"},
"Rubinstein":{"_anim","_nme","_prprn","_sb"},
"rubricated":{"_past"},
"rubricator":{"_anim","_sb"},
"ruck":{"_loc_sr"},
"rudderfish":{"_anim"},
"ruddled":{"_past"},
"Rudolph":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"ruffed":{"_past"},
"ruffian":{"_anim","_sb"},
"ruffle":{"_loc_sr","_psych"},
"ruffled":{"_loc_sr","_past","_psych"},
"Rufus":{"_prprn"},
"rugby":{"_sb"},
"ruhr":{"_geo","_prprn"},
"ruined":{"_past"},
"ruiner":{"_anim","_sb"},
"ruins":{"_loc_sr"},
"ruled":{"_past"},
"ruler":{"_anim","_sb"},
"rulers":{"_anim","_sb"},
"Rumania":{"_cntry","_geo","_prprn"},
"rumanian":{"_prprn"},
"rumbled":{"_past"},
"Rumford":{"_prprn"},
"ruminant":{"_anim"},
"ruminants":{"_anim"},
"ruminate":{"_loc_sr"},
"ruminated":{"_loc_sr","_past"},
"ruminator":{"_anim","_sb"},
"ruminators":{"_anim","_sb"},
"rummage":{"_loc_sr"},
"rummaged":{"_loc_sr","_past"},
"rummaging":{"_loc_sr"},
"rumored":{"_past"},
"rumormonger":{"_loc_sr"},
"rumormongers":{"_anim","_sb"},
"rumourmonger":{"_anim","_sb"},
"rumourmongers":{"_anim","_sb"},
"Rumpelstiltskin":{"_prprn"},
"rumple":{"_loc_sr"},
"rumpled":{"_loc_sr","_past"},
"rumpling":{"_loc_sr"},
"rumrunner":{"_anim","_sb"},
"Rumsfeld":{"_prprn"},
"run":{"_loc_sr"},
"runaway":{"_anim","_sb"},
"runaways":{"_anim","_sb"},
"Runcie":{"_anim","_nme","_prprn","_sb"},
"rundstedt":{"_anim","_nme","_prprn","_sb"},
"runner":{"_anim","_sb"},
"runner-up":{"_sb"},
"runners-up":{"_sb"},
"running":{"_loc_sr"},
"runts":{"_sb"},
"runway":{"_loc_sr"},
"Runyon":{"_anim","_nme","_prprn","_sb"},
"Rupert":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"ruptured":{"_past"},
"ruralist":{"_anim","_sb"},
"Ruritania":{"_prprn"},
"rush":{"_loc_sr"},
"Rushdie":{"_prprn"},
"rushed":{"_loc_sr","_past"},
"rusher":{"_anim","_sb"},
"rushing":{"_loc_sr"},
"Rushmore":{"_prprn"},
"Rusk":{"_anim","_prprn","_sb"},
"ruskin":{"_anim","_nme","_prprn","_sb"},
"Russ":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"russell":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Russes":{"_prprn"},
"Russia":{"_cntry","_geo","_prprn"},
"Russian":{"_anim","_prprn","_sb"},
"Russians":{"_anim","_prprn","_sb"},
"rusted":{"_past"},
"rustic":{"_anim","_sb"},
"rusticate":{"_loc_sr"},
"rusticated":{"_loc_sr","_past"},
"rusticates":{"_loc_sr"},
"rusticating":{"_loc_sr"},
"rustics":{"_anim","_sb"},
"rustle":{"_loc_sr"},
"rustled":{"_loc_sr","_past"},
"rustlers":{"_anim","_sb"},
"rustlin":{"_loc_sr"},
"rustling":{"_loc_sr"},
"Ruth":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Rutherford":{"_anim","_fnme","_geo","_loc_sr","_masc","_nme","_prprn","_sb"},
"Rutland":{"_cty","_geo","_prprn"},
"Rutledge":{"_anim","_nme","_prprn","_sb"},
"rutted":{"_past"},
"RV":{"_prprn"},
"Rwandan":{"_anim","_prprn","_sb"},
"Ryan":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Ryder":{"_anim","_nme","_prprn","_sb"},
"sa":{"_prprn"},
"Saadi":{"_prprn"},
"saale":{"_geo","_prprn"},
"saarinen":{"_anim","_nme","_prprn","_sb"},
"Saba":{"_geo","_prprn"},
"Sabah":{"_geo","_prprn"},
"sabaoth":{"_prprn"},
"Sabbatarian":{"_anim","_prprn","_sb"},
"Sabbath":{"_prprn"},
"sabellian":{"_prprn"},
"sabine":{"_anim","_prprn","_sb"},
"sable":{"_anim"},
"sables":{"_anim"},
"saboteur":{"_anim","_sb"},
"saboteurs":{"_anim","_sb"},
"sabra":{"_anim","_sb"},
"saccharified":{"_loc_sr","_past"},
"saccharifies":{"_loc_sr"},
"saccharify":{"_loc_sr"},
"saccharifying":{"_loc_sr"},
"Sacco":{"_anim","_nme","_prprn","_sb"},
"saceur":{"_prprn"},
"Sachs":{"_anim","_nme","_prprn","_sb"},
"sacked":{"_loc_sr","_past"},
"sacramento":{"_cty","_geo","_prprn"},
"sacrificed":{"_past"},
"sacrificer":{"_anim","_sb"},
"sacristan":{"_anim","_sb"},
"sacristans":{"_anim","_sb"},
"sacristies":{"_loc_sr"},
"sacristy":{"_loc_sr"},
"sad":{"_sb_is_jj"},
"sadat":{"_anim","_nme","_prprn","_sb"},
"sadden":{"_psych"},
"saddened":{"_past","_psych"},
"saddled":{"_past"},
"saddler":{"_anim","_sb"},
"saddlers":{"_anim","_sb"},
"sadducee":{"_prprn","_sb"},
"sade":{"_anim","_nme","_prprn","_sb"},
"sadhu":{"_anim","_masc","_sb"},
"sadhus":{"_anim","_masc","_sb"},
"Sadie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"safar":{"_prprn"},
"safe":{"_loc_sr"},
"safe-cracker":{"_loc_sr"},
"safe-cracking":{"_loc_sr"},
"safe-driving":{"_loc_sr"},
"safebreaker":{"_anim","_sb"},
"safecracker":{"_anim","_sb"},
"Safi":{"_cty","_geo","_prprn"},
"sag":{"_loc_sr"},
"Sagan":{"_anim","_nme","_prprn","_sb"},
"sage":{"_anim","_sb"},
"sage-brush":{"_anim","_sb"},
"sages":{"_anim","_sb"},
"sagged":{"_loc_sr","_past"},
"sagging":{"_loc_sr"},
"saginaw":{"_cty","_geo","_prprn"},
"Sagitta":{"_prprn"},
"Sagittarian":{"_anim","_prprn","_sb"},
"Sagittarius":{"_prprn"},
"sahaptin":{"_prprn","_sb"},
"Sahara":{"_geo","_prprn"},
"sahib":{"_anim","_masc","_sb"},
"sahibs":{"_anim","_masc","_sb"},
"said":{"_past"},
"Saigon":{"_geo","_prprn"},
"sail":{"_loc_sr"},
"sailed":{"_loc_sr","_past"},
"sailfish":{"_anim"},
"sailing":{"_loc_sr"},
"sailor":{"_anim","_sb"},
"sailors":{"_anim","_sb"},
"sailplaned":{"_past"},
"sailplaner":{"_anim","_sb"},
"sailplaners":{"_anim","_sb"},
"Sainsbury":{"_prprn"},
"saint-saens":{"_anim","_nme","_prprn","_sb"},
"sainted":{"_past"},
"Saintsbury":{"_prprn"},
"saipan":{"_geo","_prprn"},
"sajama":{"_geo","_prprn"},
"sakharov":{"_anim","_nme","_prprn","_sb"},
"sakkara":{"_geo","_prprn"},
"saladin":{"_anim","_nme","_prprn","_sb"},
"salamanders":{"_anim"},
"Salerno":{"_cty","_geo","_prprn"},
"saleroom":{"_loc_sr"},
"salerooms":{"_loc_sr"},
"salesclerk":{"_anim","_sb"},
"salesclerks":{"_anim","_sb"},
"salesgirls":{"_anim","_fem","_sb"},
"salesladies":{"_anim","_fem","_sb"},
"salesman":{"_anim","_masc","_sb"},
"salesmen":{"_anim","_masc","_sb"},
"salespeople":{"_anim","_sb"},
"salesroom":{"_loc_sr"},
"salesrooms":{"_loc_sr"},
"saleswoman":{"_anim","_fem","_sb"},
"saleswomen":{"_anim","_fem","_sb"},
"salian":{"_prprn"},
"salient":{"_loc_sr"},
"salients":{"_loc_sr"},
"Salinas":{"_cty","_geo","_prprn"},
"Salinger":{"_anim","_nme","_prprn","_sb"},
"Salisbury":{"_cty","_geo","_prprn"},
"Salish":{"_prprn"},
"salishan":{"_prprn"},
"salmacis":{"_prprn"},
"salmonella":{"_anim"},
"Salome":{"_anim","_nme","_prprn","_sb"},
"salomon":{"_anim","_nme","_prprn","_sb"},
"Salonica":{"_prprn"},
"Salonika":{"_geo","_prprn"},
"salons":{"_loc_sr"},
"saloon":{"_loc_sr"},
"saloons":{"_loc_sr"},
"saltated":{"_past"},
"saltcellar":{"_loc_sr"},
"salted":{"_past"},
"salter":{"_anim","_sb"},
"saltshaker":{"_loc_sr"},
"saltworks":{"_loc_sr"},
"saluki":{"_anim"},
"salutatorian":{"_anim","_sb"},
"saluted":{"_past"},
"saluter":{"_anim","_sb"},
"Salvador":{"_cty","_geo","_prprn"},
"Salvadoran":{"_anim","_prprn","_sb"},
"Salvadorean":{"_prprn"},
"salvage":{"_loc_sr"},
"salvaged":{"_loc_sr","_past"},
"salvager":{"_anim","_sb"},
"salvaging":{"_loc_sr"},
"salvor":{"_anim","_sb"},
"salvors":{"_anim","_sb"},
"Salyut":{"_prprn"},
"Salzburg":{"_cty","_geo","_prprn"},
"Salzgitter":{"_cty","_geo","_prprn"},
"Sam":{"_anim","_fem","_fnme","_masc","_nme","_prprn","_sb"},
"sama-veda":{"_prprn"},
"Samantha":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Samar":{"_geo","_prprn"},
"samaria":{"_cty","_geo","_prprn"},
"Samaritan":{"_anim","_prprn","_sb"},
"Samaritans":{"_anim","_prprn","_sb"},
"samarkand":{"_cty","_geo","_prprn"},
"sambar":{"_anim"},
"sami":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"samoa":{"_geo","_prprn"},
"Samoan":{"_anim","_prprn","_sb"},
"samovar":{"_loc_sr"},
"samovars":{"_loc_sr"},
"Samoyed":{"_anim","_prprn"},
"samplers":{"_anim","_sb"},
"Sampras":{"_prprn"},
"Samson":{"_anim","_masc","_nme","_prprn","_sb"},
"Samuel":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Samuelson":{"_anim","_nme","_prprn","_sb"},
"samurai":{"_anim","_sb"},
"San":{"_anim","_prprn","_sb"},
"Sana":{"_cty","_geo","_prprn"},
"Sanaa":{"_prprn"},
"sanchez":{"_anim","_nme","_prprn","_sb"},
"sanctified":{"_past"},
"sanctuaries":{"_loc_sr"},
"sanctum":{"_loc_sr"},
"sanctums":{"_loc_sr"},
"sandbag":{"_loc_sr"},
"sandbagger":{"_anim","_sb"},
"sandbaggers":{"_anim","_sb"},
"sandblaster":{"_anim","_sb"},
"sandburg":{"_anim","_nme","_prprn","_sb"},
"Sanderson":{"_prprn"},
"sandfish":{"_anim"},
"Sandhurst":{"_geo","_prprn"},
"Sandinista":{"_prprn"},
"sandpiper":{"_anim"},
"sandpipers":{"_anim"},
"sandpit":{"_loc_sr"},
"sandpits":{"_loc_sr"},
"Sandra":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"sandwiched":{"_past"},
"Sanford":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"sang":{"_loc_sr","_past"},
"sanger":{"_anim","_nme","_prprn","_sb"},
"sanitationist":{"_anim","_sb"},
"sanitationists":{"_anim","_sb"},
"sanitised":{"_past"},
"sanitized":{"_past"},
"sank":{"_loc_sr","_past"},
"Sanskrit":{"_prprn"},
"santa":{"_anim","_prprn","_sb"},
"Santander":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Santayana":{"_anim","_nme","_prprn","_sb"},
"santee":{"_geo","_prprn"},
"santiago":{"_cty","_geo","_prprn"},
"santos":{"_cty","_geo","_prprn"},
"saone":{"_geo","_prprn"},
"saphar":{"_prprn"},
"saphead":{"_anim","_sb"},
"sapir":{"_anim","_nme","_prprn","_sb"},
"saponified":{"_past"},
"saponifier":{"_anim","_sb"},
"sapped":{"_past"},
"sapper":{"_anim","_sb"},
"sappers":{"_anim","_sb"},
"Sappho":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Sapporo":{"_cty","_geo","_prprn"},
"saqqara":{"_geo","_prprn"},
"Sara":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Saracen":{"_anim","_prprn","_sb"},
"saragossa":{"_cty","_geo","_prprn"},
"Sarah":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"sarajevo":{"_cty","_geo","_prprn"},
"Sarandon":{"_prprn"},
"Sarasota":{"_cty","_geo","_prprn"},
"saratoga":{"_cty","_geo","_prprn"},
"saratov":{"_cty","_geo","_prprn"},
"sarawak":{"_geo","_prprn"},
"Sardanapalus":{"_prprn"},
"sardine":{"_anim"},
"sardines":{"_anim"},
"Sardinia":{"_geo","_prprn"},
"Sardinian":{"_anim","_prprn","_sb"},
"sardis":{"_cty","_geo","_prprn"},
"Sargent":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Sark":{"_geo","_prprn"},
"sarnoff":{"_anim","_nme","_prprn","_sb"},
"saroyan":{"_anim","_nme","_prprn","_sb"},
"sarpedon":{"_prprn"},
"sartre":{"_anim","_nme","_prprn","_sb"},
"Sarum":{"_prprn"},
"SAS":{"_prprn"},
"Sasebo":{"_cty","_geo","_prprn"},
"sashay":{"_loc_sr"},
"sashayed":{"_loc_sr","_past"},
"Saskatchewan":{"_geo","_prprn","_stte"},
"sassabies":{"_anim"},
"sassaby":{"_anim"},
"sassed":{"_past"},
"Sassenach":{"_prprn"},
"sat":{"_loc_sr","_past"},
"Satan":{"_anim","_masc","_nme","_prprn","_sb"},
"satanism":{"_prprn"},
"sated":{"_past"},
"satiated":{"_past"},
"satie":{"_anim","_nme","_prprn","_sb"},
"satirised":{"_past"},
"satirists":{"_anim","_sb"},
"satisfied":{"_past","_psych"},
"satisfier":{"_anim","_sb"},
"satisfies":{"_psych"},
"satisfy":{"_psych"},
"satisfying":{"_psych"},
"satrap":{"_anim","_sb"},
"Saturday":{"_day","_prprn","_tme"},
"saturn":{"_anim","_masc","_nme","_prprn","_sb"},
"satyagraha":{"_prprn"},
"satyr":{"_anim","_masc","_sb"},
"satyrs":{"_anim","_masc","_sb"},
"Saud":{"_anim","_nme","_prprn","_sb"},
"Saudi":{"_anim","_prprn","_sb"},
"Saudis":{"_anim","_prprn","_sb"},
"sauk":{"_anim","_prprn","_sb"},
"Saul":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Saunders":{"_anim","_nme","_prprn","_sb"},
"saunter":{"_loc_sr"},
"saunterer":{"_anim","_sb"},
"saurian":{"_anim"},
"saussure":{"_anim","_nme","_prprn","_sb"},
"saute":{"_loc_sr"},
"sauteed":{"_loc_sr","_past"},
"sauteing":{"_loc_sr"},
"Sauternes":{"_prprn"},
"savage":{"_anim","_sb"},
"savanna":{"_loc_sr"},
"Savannah":{"_cty","_geo","_prprn"},
"savannas":{"_loc_sr"},
"savant":{"_anim","_sb"},
"savants":{"_anim","_sb"},
"save":{"_loc_sr"},
"saving":{"_loc_sr"},
"savior":{"_anim","_sb"},
"saviors":{"_anim","_sb"},
"Saviour":{"_anim","_sb"},
"saviours":{"_anim","_sb"},
"Savona":{"_cty","_geo","_prprn"},
"savonarola":{"_anim","_nme","_prprn","_sb"},
"savoured":{"_past"},
"Savoy":{"_anim","_geo","_prprn","_sb","_stte"},
"saw":{"_past"},
"sawbones":{"_anim","_sb"},
"sawfish":{"_anim"},
"sawyer":{"_anim","_sb"},
"sawyers":{"_anim","_sb"},
"Saxe":{"_anim","_nme","_prprn","_sb"},
"saxe-coburg-gotha":{"_anim","_nme","_prprn","_sb"},
"saxe-gothea":{"_anim","_nme","_prprn","_sb"},
"saxes":{"_anim","_nme","_prprn","_sb"},
"saxist":{"_anim","_sb"},
"Saxon":{"_anim","_prprn","_sb"},
"Saxons":{"_prprn"},
"Saxony":{"_geo","_prprn"},
"saxophonist":{"_anim","_sb"},
"saxophonists":{"_anim","_sb"},
"sba":{"_prprn"},
"sbe":{"_prprn"},
"sbw":{"_prprn"},
"scab":{"_anim"},
"scabbed":{"_past"},
"scablands":{"_loc_sr"},
"scabs":{"_anim"},
"Scala":{"_prprn"},
"scalawag":{"_anim","_sb"},
"scalawags":{"_anim","_sb"},
"scalded":{"_past"},
"scaled":{"_past"},
"scaled-down":{"_past"},
"Scalia":{"_anim","_nme","_prprn","_sb"},
"scallion":{"_anim"},
"scallions":{"_anim"},
"scallops":{"_anim"},
"scallywag":{"_anim","_sb"},
"scallywags":{"_anim","_sb"},
"scalper":{"_anim","_sb"},
"scalpers":{"_anim","_sb"},
"scammed":{"_past"},
"scammer":{"_anim","_sb"},
"scammers":{"_anim","_sb"},
"scamp":{"_anim","_sb"},
"scamper":{"_loc_sr"},
"scampering":{"_loc_sr"},
"scan":{"_loc_sr"},
"scandalised":{"_past"},
"scandalized":{"_past","_psych"},
"scandalizes":{"_psych"},
"scandalizing":{"_psych"},
"scandalmonger":{"_anim","_sb"},
"scandalmongers":{"_anim","_sb"},
"Scandinavia":{"_geo","_prprn"},
"scandinavian":{"_anim","_prprn","_sb"},
"scanned":{"_loc_sr","_past"},
"scanning":{"_loc_sr"},
"scapegoated":{"_past"},
"scapegoats":{"_anim","_sb"},
"scapegrace":{"_anim","_sb"},
"scarab":{"_anim"},
"scaramouch":{"_prprn"},
"scaramouche":{"_prprn"},
"Scarborough":{"_geo","_prprn"},
"scare":{"_psych"},
"scared":{"_past","_psych"},
"scaremonger":{"_anim","_sb"},
"scaremongers":{"_anim","_sb"},
"scarer":{"_anim","_sb"},
"scarified":{"_past"},
"scaring":{"_psych"},
"Scarlatti":{"_anim","_nme","_prprn","_sb"},
"scarp":{"_loc_sr"},
"scarped":{"_loc_sr","_past"},
"scarping":{"_loc_sr"},
"scarred":{"_past"},
"scat":{"_loc_sr"},
"scathed":{"_past"},
"scatter":{"_loc_sr"},
"scatterbrain":{"_anim","_sb"},
"scatterbrains":{"_anim","_sb"},
"scauper":{"_anim","_sb"},
"scavengers":{"_anim","_sb"},
"scenarist":{"_anim","_sb"},
"scenarists":{"_anim","_sb"},
"scend":{"_loc_sr"},
"sceneshifter":{"_anim","_sb"},
"scented":{"_past"},
"sceptered":{"_past"},
"sceptic":{"_anim","_sb"},
"sceptics":{"_anim","_sb"},
"sceptred":{"_past"},
"Schaumburg":{"_geo","_prprn"},
"scheduled":{"_loc_sr","_past"},
"scheduler":{"_anim","_sb"},
"scheduling":{"_loc_sr"},
"scheele":{"_anim","_nme","_prprn","_sb"},
"Scheherazade":{"_prprn"},
"scheldt":{"_geo","_prprn"},
"Schelling":{"_anim","_nme","_prprn","_sb"},
"schematised":{"_past"},
"schematize":{"_loc_sr"},
"schematized":{"_loc_sr","_past"},
"schematizes":{"_loc_sr"},
"schematizing":{"_loc_sr"},
"Schenectady":{"_cty","_geo","_prprn"},
"schiaparelli":{"_anim","_nme","_prprn","_sb"},
"Schiele":{"_prprn"},
"Schiff":{"_prprn"},
"Schiller":{"_anim","_prprn","_sb"},
"schipperke":{"_anim"},
"schismatic":{"_anim","_sb"},
"schizoid":{"_sb"},
"schizoids":{"_sb"},
"schizophrenics":{"_anim","_sb"},
"Schleiermacher":{"_anim","_nme","_prprn","_sb"},
"schlepper":{"_anim","_sb"},
"schlesinger":{"_anim","_nme","_prprn","_sb"},
"Schleswig-Holstein":{"_geo","_prprn"},
"schliemann":{"_anim","_nme","_prprn","_sb"},
"schlimazel":{"_sb"},
"schlockmeister":{"_anim","_sb"},
"schmidt":{"_anim","_nme","_prprn","_sb"},
"schmo":{"_anim","_sb"},
"schmoes":{"_anim","_sb"},
"schmoozer":{"_anim","_sb"},
"schmuck":{"_anim","_sb"},
"schnabel":{"_anim","_nme","_prprn","_sb"},
"schnauzer":{"_anim"},
"schnook":{"_sb"},
"schnooks":{"_sb"},
"schnorrer":{"_anim","_sb"},
"Schoenberg":{"_prprn"},
"scholar":{"_anim","_sb"},
"scholars":{"_anim","_sb"},
"schonberg":{"_anim","_nme","_prprn","_sb"},
"school":{"_anim","_loc_sr"},
"school-age":{"_anim","_loc_sr"},
"school-days":{"_anim","_loc_sr"},
"school-leaver":{"_anim","_loc_sr"},
"school-leavers":{"_anim","_loc_sr"},
"school-marm":{"_anim","_loc_sr"},
"school-marms":{"_anim","_loc_sr"},
"schoolboys":{"_anim","_masc","_sb"},
"schoolchild":{"_sb"},
"schoolcraft":{"_anim","_nme","_prprn","_sb"},
"schooled":{"_past"},
"schoolgirls":{"_sb"},
"schoolhouse":{"_loc_sr"},
"schoolhouses":{"_loc_sr"},
"schoolman":{"_anim","_masc","_sb"},
"schoolmarm":{"_anim","_fem","_sb"},
"schoolmarms":{"_anim","_fem","_sb"},
"schoolmasters":{"_anim","_masc","_sb"},
"schoolmates":{"_anim","_sb"},
"schoolmen":{"_anim","_masc","_sb"},
"schoolmistress":{"_anim","_fem","_sb"},
"schoolmistresses":{"_anim","_fem","_sb"},
"schools":{"_anim","_loc_sr"},
"schoolteachers":{"_anim","_sb"},
"schoolyard":{"_loc_sr"},
"schoolyards":{"_loc_sr"},
"schooner":{"_fem","_loc_sr"},
"schooners":{"_fem","_loc_sr"},
"Schopenhauer":{"_anim","_nme","_prprn","_sb"},
"schrodinger":{"_anim","_nme","_prprn","_sb"},
"Schroeder":{"_prprn"},
"Schubert":{"_anim","_nme","_prprn","_sb"},
"schulz":{"_anim","_nme","_prprn","_sb"},
"Schumacher":{"_prprn"},
"Schuman":{"_anim","_nme","_prprn","_sb"},
"schumann":{"_anim","_nme","_prprn","_sb"},
"Schumpeter":{"_anim","_nme","_prprn","_sb"},
"schuss":{"_loc_sr"},
"Schuster":{"_prprn"},
"Schuyler":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Schuylkill":{"_geo","_prprn"},
"schwann":{"_anim","_nme","_prprn","_sb"},
"Schwarzkopf":{"_prprn"},
"schweitzer":{"_anim","_nme","_prprn","_sb"},
"Schweiz":{"_prprn"},
"Schwerin":{"_cty","_geo","_prprn"},
"scid":{"_prprn"},
"scientist":{"_anim","_sb"},
"scientists":{"_anim","_sb"},
"scintillate":{"_loc_sr"},
"scintillated":{"_loc_sr","_past"},
"scintillates":{"_loc_sr"},
"scions":{"_anim"},
"scipio":{"_anim","_nme","_prprn","_sb"},
"scissored":{"_past"},
"scoffed":{"_past"},
"scoffer":{"_anim","_sb"},
"scoffers":{"_anim","_sb"},
"scofflaw":{"_anim","_sb"},
"Scofield":{"_prprn"},
"scolded":{"_past"},
"scolder":{"_anim","_sb"},
"scolds":{"_anim","_sb"},
"scooped":{"_past"},
"scoops":{"_loc_sr"},
"scoot":{"_loc_sr"},
"scooted":{"_loc_sr","_past"},
"scooting":{"_loc_sr"},
"scope":{"_loc_sr"},
"scorched":{"_past"},
"score":{"_num"},
"score-board":{"_num"},
"score-card":{"_num"},
"score-cards":{"_num"},
"scored":{"_loc_sr","_past"},
"scorekeeper":{"_anim","_sb"},
"scorekeepers":{"_anim","_sb"},
"scorer":{"_anim","_sb"},
"scorers":{"_anim","_sb"},
"scores":{"_num"},
"scoring":{"_loc_sr"},
"scorned":{"_past"},
"scorner":{"_anim","_sb"},
"scorpio":{"_prprn"},
"scorpion":{"_anim"},
"scorpions":{"_anim"},
"Scorpios":{"_prprn"},
"scorpius":{"_prprn"},
"Scorsese":{"_prprn"},
"Scot":{"_anim","_prprn","_sb"},
"Scotch":{"_anim","_prprn","_sb"},
"Scotchman":{"_prprn"},
"Scotchmen":{"_prprn"},
"Scotchwoman":{"_prprn"},
"Scotchwomen":{"_prprn"},
"Scotia":{"_geo","_prprn"},
"Scotland":{"_cntry","_geo","_prprn"},
"Scots":{"_anim","_prprn","_sb"},
"Scotsman":{"_anim","_masc","_prprn","_sb"},
"Scotsmen":{"_anim","_masc","_prprn","_sb"},
"Scotswoman":{"_anim","_fem","_prprn","_sb"},
"Scotswomen":{"_prprn"},
"Scott":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Scottie":{"_anim","_prprn"},
"Scottish":{"_anim","_prprn","_sb"},
"Scottsdale":{"_cty","_geo","_prprn"},
"Scotty":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"scoundrels":{"_anim","_sb"},
"scour":{"_loc_sr"},
"scoured":{"_loc_sr","_past"},
"scourger":{"_anim","_sb"},
"scouring":{"_loc_sr"},
"Scouser":{"_anim","_sb"},
"scout":{"_loc_sr"},
"scouted":{"_loc_sr","_past"},
"scouter":{"_anim","_sb"},
"scouters":{"_anim","_sb"},
"scouting":{"_loc_sr"},
"scoutmaster":{"_anim","_sb"},
"scouts":{"_anim","_sb"},
"scowl":{"_loc_sr"},
"scowled":{"_loc_sr","_past"},
"scowling":{"_loc_sr"},
"scpo":{"_prprn"},
"scrag":{"_sb"},
"scram":{"_loc_sr"},
"scramble":{"_loc_sr"},
"scrambling":{"_loc_sr"},
"scranton":{"_cty","_geo","_prprn"},
"scrape":{"_loc_sr"},
"scraped":{"_loc_sr","_past"},
"scraping":{"_loc_sr"},
"scrapped":{"_past"},
"scrapper":{"_anim","_sb"},
"scrappers":{"_anim","_sb"},
"scratch":{"_loc_sr"},
"scratched":{"_loc_sr","_past"},
"scratcher":{"_anim","_sb"},
"scratching":{"_loc_sr"},
"scrawl":{"_loc_sr"},
"scrawled":{"_loc_sr","_past"},
"scrawler":{"_anim","_sb"},
"screamed":{"_loc_sr","_past"},
"screech":{"_loc_sr"},
"screeched":{"_loc_sr","_past"},
"screecher":{"_anim","_sb"},
"screeching":{"_loc_sr"},
"screened":{"_past"},
"screener":{"_anim","_sb"},
"screeners":{"_anim","_sb"},
"screenwriter":{"_anim","_sb"},
"screwballer":{"_anim","_sb"},
"screwed":{"_past"},
"screwed-up":{"_past"},
"scriabin":{"_anim","_nme","_prprn","_sb"},
"scribbled":{"_past"},
"scribbler":{"_anim","_sb"},
"scribblers":{"_anim","_sb"},
"scribe":{"_loc_sr"},
"scribes":{"_anim","_sb"},
"scried":{"_past"},
"scrimmage":{"_loc_sr"},
"scrimped":{"_past"},
"Scripps":{"_anim","_nme","_prprn","_sb"},
"scripted":{"_past"},
"scriptorium":{"_loc_sr"},
"Scripture":{"_prprn"},
"Scriptures":{"_prprn"},
"scriptwriters":{"_anim","_sb"},
"scroll":{"_loc_sr"},
"scrooge":{"_anim","_sb"},
"scrooges":{"_anim","_sb"},
"scrounged":{"_past"},
"scrubbed":{"_past"},
"scrubber":{"_anim","_fem","_sb"},
"scrubbers":{"_anim","_fem","_sb"},
"scrubland":{"_loc_sr"},
"scrublands":{"_loc_sr"},
"scrum":{"_loc_sr"},
"scrummage":{"_loc_sr"},
"scrutineer":{"_anim","_sb"},
"scrutineers":{"_anim","_sb"},
"scrutinised":{"_past"},
"scrutiniser":{"_anim","_sb"},
"scrutinizer":{"_anim","_sb"},
"scsi":{"_prprn"},
"scud":{"_loc_sr"},
"scudding":{"_loc_sr"},
"scuff":{"_loc_sr"},
"scuffer":{"_anim","_sb"},
"sculled":{"_past"},
"sculleries":{"_loc_sr"},
"scullery":{"_loc_sr"},
"scullion":{"_anim","_sb"},
"sculptors":{"_anim","_sb"},
"sculptress":{"_anim","_fem","_sb"},
"sculptresses":{"_anim","_fem","_sb"},
"sculpturer":{"_anim","_sb"},
"scup":{"_loc_sr"},
"scurried":{"_loc_sr","_past"},
"scurry":{"_loc_sr"},
"scurrying":{"_loc_sr"},
"Scylla":{"_anim","_fem","_prprn"},
"scythed":{"_past"},
"scythia":{"_geo","_prprn"},
"scythian":{"_anim","_prprn","_sb"},
"sd":{"_prprn","_stte"},
"sea":{"_loc_sr"},
"sea-borne":{"_loc_sr"},
"sea-bream":{"_loc_sr"},
"sea-breeze":{"_loc_sr"},
"sea-breezes":{"_loc_sr"},
"sea-coast":{"_loc_sr"},
"sea-cow":{"_loc_sr"},
"sea-damp":{"_loc_sr"},
"sea-dog":{"_loc_sr"},
"sea-dogs":{"_loc_sr"},
"sea-duty":{"_loc_sr"},
"sea-ear":{"_loc_sr"},
"sea-food":{"_loc_sr"},
"sea-green":{"_loc_sr"},
"sea-horse":{"_loc_sr"},
"sea-horses":{"_loc_sr"},
"sea-kale":{"_loc_sr"},
"sea-legs":{"_loc_sr"},
"sea-lion":{"_loc_sr"},
"sea-lions":{"_loc_sr"},
"sea-pink":{"_loc_sr"},
"sea-poose":{"_loc_sr"},
"sea-shore":{"_loc_sr"},
"sea-urchin":{"_loc_sr"},
"sea-wall":{"_loc_sr"},
"sea-walls":{"_loc_sr"},
"sea-way":{"_loc_sr"},
"sea-ways":{"_loc_sr"},
"seabed":{"_loc_sr"},
"seabird":{"_anim"},
"seabirds":{"_anim"},
"Seaborg":{"_anim","_nme","_prprn","_sb"},
"seafarer":{"_anim","_sb"},
"seafarers":{"_anim","_sb"},
"seafood":{"_anim"},
"seagull":{"_anim"},
"seagulls":{"_anim"},
"seahorses":{"_anim"},
"seals":{"_anim"},
"sealyham":{"_prprn"},
"seaman":{"_anim","_sb"},
"seamed":{"_past"},
"seamen":{"_anim","_sb"},
"seamster":{"_anim","_sb"},
"seamstresses":{"_anim","_fem","_sb"},
"Sean":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"searched":{"_past"},
"seared":{"_past"},
"Searle":{"_prprn"},
"seas":{"_loc_sr"},
"seashore":{"_loc_sr"},
"seashores":{"_loc_sr"},
"season-ticket":{"_tme"},
"season-tickets":{"_tme"},
"seasoned":{"_past"},
"seasons":{"_tme"},
"seat-back":{"_loc_sr"},
"seat-belt":{"_loc_sr"},
"seated":{"_past"},
"seats":{"_loc_sr"},
"seattle":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"seaward":{"_loc_sr"},
"seawards":{"_loc_sr"},
"seawater":{"_loc_sr"},
"Sebastian":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"sebastopol":{"_geo","_prprn"},
"sebe":{"_prprn"},
"sebs":{"_prprn"},
"secede":{"_loc_sr"},
"seceded":{"_loc_sr","_past"},
"seceding":{"_loc_sr"},
"sechuana":{"_prprn"},
"secluded":{"_loc_sr","_past"},
"secludes":{"_loc_sr"},
"secluding":{"_loc_sr"},
"second":{"_anim","_sb","_tme"},
"second-best":{"_anim","_sb","_tme"},
"second-floor":{"_anim","_sb","_tme"},
"second-guessed":{"_past"},
"second-in-command":{"_anim","_sb"},
"seconds":{"_anim","_sb","_tme"},
"secretaries":{"_anim","_sb"},
"secretaries-general":{"_anim","_sb"},
"secretary":{"_anim","_sb"},
"secretary-general":{"_anim","_sb"},
"secrete":{"_loc_sr"},
"secretor":{"_anim","_sb"},
"sectarist":{"_anim","_sb"},
"section":{"_loc_sr"},
"sectionalised":{"_past"},
"sectionalize":{"_loc_sr"},
"sectionalized":{"_loc_sr","_past"},
"sectionalizes":{"_loc_sr"},
"sectionalizing":{"_loc_sr"},
"sectioned":{"_loc_sr","_past"},
"sections":{"_loc_sr"},
"secular":{"_sb"},
"secularised":{"_past"},
"secularize":{"_loc_sr"},
"secularized":{"_loc_sr","_past"},
"secularizes":{"_loc_sr"},
"secularizing":{"_loc_sr"},
"secure":{"_loc_sr"},
"secured":{"_loc_sr","_past"},
"securing":{"_loc_sr"},
"sedalia":{"_cty","_geo","_prprn"},
"Seddon":{"_prprn"},
"Seder":{"_prprn"},
"Sedgwick":{"_prprn"},
"seduce":{"_psych"},
"seduced":{"_past","_psych"},
"seduces":{"_psych"},
"seducing":{"_psych"},
"seductresses":{"_anim","_fem","_sb"},
"seedbed":{"_loc_sr"},
"seeded":{"_past"},
"seedsman":{"_anim","_sb"},
"seedsmen":{"_anim","_sb"},
"Seeger":{"_anim","_nme","_prprn","_sb"},
"Seeland":{"_prprn"},
"seem":{"_vlink"},
"seemed":{"_past","_vlink"},
"seems":{"_vlink"},
"seeped":{"_loc_sr","_past"},
"seeping":{"_loc_sr"},
"seers":{"_anim","_sb"},
"seethe":{"_loc_sr"},
"seething":{"_loc_sr"},
"segal":{"_anim","_nme","_prprn","_sb"},
"segmented":{"_loc_sr","_past"},
"segmenting":{"_loc_sr"},
"Segovia":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"segregate":{"_loc_sr"},
"segregated":{"_loc_sr","_past"},
"segregationist":{"_anim","_sb"},
"segregationists":{"_anim","_sb"},
"segregator":{"_anim","_sb"},
"segue":{"_loc_sr"},
"Seifert":{"_anim","_nme","_prprn","_sb"},
"seigneur":{"_anim","_masc","_sb"},
"seignior":{"_anim","_masc","_sb"},
"seizer":{"_anim","_sb"},
"seizers":{"_anim","_sb"},
"Sejm":{"_prprn"},
"selachian":{"_sb"},
"Selassie":{"_prprn"},
"seldom":{"_tme"},
"selected":{"_past"},
"selector":{"_sb"},
"selectors":{"_sb"},
"selectwoman":{"_anim","_fem","_sb"},
"selene":{"_anim","_fem","_nme","_prprn","_sb"},
"Seles":{"_prprn"},
"self-activating":{"_loc_sr"},
"self-administered":{"_past"},
"self-censorship":{"_anim","_sb"},
"self-certainty":{"_anim","_sb"},
"self-chosen":{"_loc_sr"},
"self-collected":{"_loc_sr","_past","_psych"},
"self-constituted":{"_past"},
"self-declared":{"_past"},
"self-defeat":{"_loc_sr"},
"self-deluded":{"_past","_psych"},
"self-designated":{"_past"},
"self-destructed":{"_past"},
"self-determination":{"_loc_sr","_sb"},
"self-diagnostic":{"_anim","_sb"},
"self-disciplined":{"_past"},
"self-disgust":{"_psych"},
"self-enforced":{"_past"},
"self-established":{"_past"},
"self-feeder":{"_anim","_sb"},
"self-fertilised":{"_past"},
"self-fertilized":{"_past"},
"self-financed":{"_past"},
"self-generated":{"_loc_sr","_past"},
"self-loader":{"_anim","_sb"},
"self-moving":{"_loc_sr"},
"self-multilation":{"_anim","_sb"},
"self-perceived":{"_loc_sr","_past"},
"self-policing":{"_loc_sr"},
"self-pollinated":{"_loc_sr","_past"},
"self-pollinating":{"_loc_sr"},
"self-prescribed":{"_past"},
"self-professed":{"_past"},
"self-propelling":{"_loc_sr"},
"self-realized":{"_past"},
"self-redefinition":{"_anim","_sb"},
"self-referent":{"_anim","_sb"},
"self-regulator":{"_anim","_sb"},
"self-renewal":{"_anim","_sb"},
"self-restraining":{"_loc_sr"},
"self-seeker":{"_anim","_sb"},
"self-sowed":{"_loc_sr","_past"},
"self-starter":{"_anim","_sb"},
"self-starters":{"_anim","_sb"},
"self-sustained":{"_loc_sr","_past"},
"self-tender":{"_anim","_sb"},
"self-tilth":{"_anim","_sb"},
"self-torture":{"_psych"},
"self-victimized":{"_past"},
"self-whispered":{"_past"},
"seljuk":{"_anim","_nme","_prprn","_sb"},
"Selkirk":{"_anim","_nme","_prprn","_sb"},
"seller":{"_anim","_sb"},
"Sellers":{"_anim","_sb"},
"sellotape":{"_loc_sr"},
"sellotaped":{"_loc_sr","_past"},
"sellotaping":{"_loc_sr"},
"selma":{"_cty","_geo","_prprn"},
"seltzer":{"_loc_sr"},
"selves":{"_anim","_sb"},
"Selznick":{"_anim","_nme","_prprn","_sb"},
"semaphored":{"_loc_sr","_past"},
"semaphoring":{"_loc_sr"},
"semarang":{"_cty","_geo","_prprn"},
"Semenov":{"_anim","_nme","_prprn","_sb"},
"semester":{"_tme"},
"semesters":{"_tme"},
"semi-catatonic":{"_anim","_sb"},
"semi-celebrities":{"_anim","_sb"},
"semi-circle":{"_loc_sr"},
"semi-climber":{"_anim","_sb"},
"semi-conductor":{"_anim","_sb"},
"semi-conductors":{"_anim","_sb"},
"semi-finalist":{"_anim","_sb"},
"semi-finalists":{"_anim","_sb"},
"semi-literate":{"_anim","_sb"},
"semi-local":{"_anim","_sb"},
"semi-major":{"_anim","_sb"},
"semi-minor":{"_anim","_sb"},
"semi-nude":{"_anim","_sb"},
"semi-precious":{"_anim","_sb"},
"semi-private":{"_anim","_sb"},
"semi-professional":{"_anim","_sb"},
"semi-public":{"_sb"},
"semi-retired":{"_anim","_sb"},
"semi-wild":{"_loc_sr"},
"semidesert":{"_loc_sr"},
"semifinalists":{"_anim","_sb"},
"seminarian":{"_anim","_sb"},
"seminarians":{"_anim","_sb"},
"seminarist":{"_anim","_sb"},
"seminole":{"_anim","_prprn","_sb"},
"semiologist":{"_anim","_sb"},
"semiologists":{"_anim","_sb"},
"semiotician":{"_anim","_sb"},
"semioticians":{"_anim","_sb"},
"Semiramis":{"_prprn"},
"Semite":{"_prprn","_sb"},
"Semitic":{"_prprn"},
"semitropic":{"_loc_sr"},
"semitropics":{"_loc_sr"},
"sempstress":{"_anim","_fem","_sb"},
"Sen":{"_anim","_prprn","_sb"},
"Sen.":{"_anim","_prprn","_sb"},
"senator":{"_anim","_sb"},
"senators":{"_anim","_sb"},
"send-up":{"_anim","_sb"},
"sendee":{"_anim","_sb"},
"sender":{"_anim","_sb"},
"senders":{"_anim","_sb"},
"sending":{"_loc_sr"},
"sends":{"_loc_sr"},
"seneca":{"_anim","_nme","_prprn","_sb"},
"Senegal":{"_cntry","_geo","_prprn"},
"Senegalese":{"_anim","_prprn","_sb"},
"seneschal":{"_anim","_sb"},
"senior":{"_anim","_sb"},
"seniors":{"_anim","_sb"},
"sennacherib":{"_anim","_nme","_prprn","_sb"},
"sennett":{"_anim","_nme","_prprn","_sb"},
"senor":{"_anim","_sb"},
"Senora":{"_prprn"},
"senores":{"_anim","_sb"},
"Senorita":{"_prprn"},
"sensationalised":{"_past"},
"sensationalized":{"_past"},
"sensed":{"_past"},
"sensitised":{"_past"},
"sensitiser":{"_anim","_sb"},
"sensitive":{"_sb"},
"sensitive-area":{"_sb"},
"sensitives":{"_sb"},
"sensitized":{"_past"},
"sensitizer":{"_anim","_sb"},
"sensualist":{"_anim","_sb"},
"sensualists":{"_anim","_sb"},
"sentenced":{"_past"},
"sentimentalised":{"_past"},
"sentinels":{"_anim","_sb"},
"sentries":{"_anim","_sb"},
"sentry":{"_anim","_sb"},
"sentry-box":{"_anim","_sb"},
"sentry-boxes":{"_anim","_sb"},
"Seoul":{"_cty","_geo","_prprn"},
"Sep":{"_prprn","_tme"},
"sepals":{"_anim"},
"separate":{"_loc_sr"},
"separated":{"_loc_sr","_past"},
"separates":{"_loc_sr"},
"separating":{"_loc_sr"},
"separatist":{"_anim","_sb"},
"separatists":{"_anim","_sb"},
"sephardi":{"_prprn"},
"Sept":{"_prprn","_tme"},
"september":{"_prprn","_tme"},
"Septembers":{"_prprn","_tme"},
"septet":{"_sb"},
"septets":{"_sb"},
"septuagenarian":{"_anim","_sb"},
"septuagenarians":{"_anim","_sb"},
"Septuagesima":{"_prprn"},
"Septuagint":{"_prprn"},
"sepulchred":{"_past"},
"sepulchres":{"_loc_sr"},
"sequenced":{"_loc_sr","_past"},
"sequester":{"_loc_sr"},
"sequestered":{"_loc_sr","_past"},
"sequestering":{"_loc_sr"},
"sequestrated":{"_past"},
"sequined":{"_past"},
"sequoya":{"_anim","_nme","_prprn","_sb"},
"Sequoyah":{"_prprn"},
"serb":{"_anim","_prprn","_sb"},
"serbia":{"_cntry","_geo","_prprn"},
"serbian":{"_anim","_prprn","_sb"},
"Serbo-Croat":{"_prprn"},
"Serbo-Croatian":{"_prprn"},
"serenaded":{"_past"},
"serf":{"_anim","_sb"},
"serfs":{"_anim","_sb"},
"sergeant":{"_anim","_sb"},
"sergeant-major":{"_anim","_sb"},
"sergeant-majors":{"_anim","_sb"},
"sergeants":{"_anim","_sb"},
"serger":{"_anim","_sb"},
"serialised":{"_past"},
"serialize":{"_loc_sr"},
"serialized":{"_loc_sr","_past"},
"sericulturist":{"_anim","_sb"},
"serjeant-at-arms":{"_anim","_sb"},
"serjeants-at-arms":{"_anim","_sb"},
"serkin":{"_anim","_nme","_prprn","_sb"},
"sermonised":{"_past"},
"sermoniser":{"_anim","_sb"},
"sermonizer":{"_anim","_sb"},
"serologist":{"_anim","_sb"},
"serow":{"_anim"},
"serpens":{"_prprn"},
"serpent":{"_anim"},
"serpents":{"_anim"},
"Serra":{"_anim","_nme","_prprn","_sb"},
"serrated":{"_past"},
"serval":{"_anim"},
"servant":{"_anim","_sb"},
"servants":{"_anim","_sb"},
"servers":{"_anim","_sb"},
"serviced":{"_loc_sr","_past"},
"serviceman":{"_anim","_masc","_sb"},
"servicemen":{"_anim","_masc","_sb"},
"servicers":{"_anim","_sb"},
"servicewoman":{"_anim","_fem","_sb"},
"servicewomen":{"_anim","_fem","_sb"},
"servicing":{"_loc_sr"},
"servitor":{"_anim","_masc","_sb"},
"servitors":{"_anim","_masc","_sb"},
"Sesshu":{"_prprn"},
"session":{"_tme"},
"sessions":{"_tme"},
"set":{"_loc_sr","_past"},
"Seth":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"seton":{"_anim","_nme","_prprn","_sb"},
"setswana":{"_prprn"},
"setter":{"_anim"},
"setters":{"_anim"},
"setting":{"_loc_sr"},
"settings":{"_sb"},
"settle":{"_loc_sr"},
"settled":{"_loc_sr","_past"},
"settler":{"_anim","_sb"},
"settlers":{"_anim","_sb"},
"settling":{"_loc_sr"},
"settlor":{"_anim","_sb"},
"setubal":{"_cty","_geo","_prprn"},
"seurat":{"_anim","_nme","_prprn","_sb"},
"Seuss":{"_anim","_nme","_prprn","_sb"},
"sevastopol":{"_cty","_geo","_prprn"},
"seven":{"_quant"},
"sevenfold":{"_quant"},
"sevens":{"_num","_quant"},
"seventeen":{"_num","_quant"},
"seventies":{"_num","_quant"},
"several":{"_quant"},
"severed":{"_past"},
"Severn":{"_geo","_prprn"},
"Seveso":{"_prprn"},
"seville":{"_cty","_geo","_prprn"},
"Sevin":{"_prprn"},
"sewage":{"_loc_sr"},
"seward":{"_anim","_nme","_prprn","_sb"},
"sewed":{"_past"},
"Sewell":{"_anim","_nme","_prprn","_sb"},
"sewellel":{"_anim"},
"sex":{"_sb"},
"sex-discrimination":{"_sb"},
"sex-education":{"_sb"},
"sexagenarian":{"_anim","_sb"},
"sexagenarians":{"_anim","_sb"},
"sexed":{"_past"},
"sexes":{"_sb"},
"sexist":{"_anim","_sb"},
"sexists":{"_anim","_sb"},
"sexologist":{"_anim","_sb"},
"sexologists":{"_anim","_sb"},
"sexpots":{"_anim","_fem","_sb"},
"sextets":{"_sb"},
"sextons":{"_anim","_sb"},
"sextuplet":{"_sb"},
"sexualised":{"_past"},
"sexualized":{"_past"},
"Seychelles":{"_cntry","_geo","_prprn"},
"Seychellois":{"_anim","_prprn","_sb"},
"seymour":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"sgml":{"_prprn"},
"Sgt":{"_prprn"},
"shaaban":{"_prprn"},
"Shabbat":{"_prprn"},
"Shabuoth":{"_prprn","_tme"},
"shacked":{"_past"},
"shackled":{"_past"},
"shading":{"_loc_sr"},
"shadow":{"_loc_sr"},
"shadow-box":{"_loc_sr"},
"shadow-boxed":{"_loc_sr"},
"shadow-boxing":{"_loc_sr"},
"shadowed":{"_loc_sr","_past"},
"shadower":{"_anim","_sb"},
"shadowing":{"_loc_sr"},
"shadows":{"_loc_sr"},
"Shaffer":{"_prprn"},
"shagged":{"_past"},
"shah":{"_anim","_sb"},
"Shahaptian":{"_prprn"},
"Shahn":{"_anim","_nme","_prprn","_sb"},
"shake":{"_loc_sr"},
"shakedown":{"_loc_sr"},
"shakedowns":{"_loc_sr"},
"shaken":{"_loc_sr"},
"Shaker":{"_loc_sr"},
"shakers":{"_loc_sr"},
"shakespeare":{"_anim","_nme","_prprn","_sb"},
"Shakespearian":{"_prprn"},
"shaking":{"_loc_sr"},
"shakti":{"_prprn"},
"shaktism":{"_prprn"},
"shaktist":{"_prprn"},
"shaman":{"_anim","_sb"},
"shamans":{"_anim","_sb"},
"Shamash":{"_anim","_masc","_nme","_prprn","_sb"},
"shamble":{"_loc_sr"},
"shambled":{"_loc_sr","_past"},
"shambles":{"_loc_sr"},
"shambling":{"_loc_sr"},
"shamed":{"_past","_psych"},
"Shamir":{"_prprn"},
"shammer":{"_anim","_sb"},
"shammers":{"_anim","_sb"},
"shampooed":{"_past"},
"shan":{"_prprn","_sb"},
"Shane":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"shang":{"_anim","_nme","_prprn","_sb"},
"Shanghai":{"_loc_sr"},
"shanghaier":{"_anim","_sb"},
"Shangri-La":{"_loc_sr","_prprn"},
"shankar":{"_anim","_nme","_prprn","_sb"},
"shannon":{"_anim","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"Shansi":{"_geo","_prprn"},
"Shantou":{"_cty","_geo","_prprn"},
"Shantung":{"_geo","_prprn"},
"shaped":{"_loc_sr","_past"},
"shaping":{"_loc_sr"},
"Shapiro":{"_anim","_nme","_prprn","_sb"},
"Shapley":{"_anim","_nme","_prprn","_sb"},
"shards":{"_loc_sr"},
"share":{"_loc_sr"},
"sharecropped":{"_past"},
"sharecroppers":{"_anim","_sb"},
"shared":{"_loc_sr","_past"},
"shareholder":{"_anim","_sb"},
"shareowner":{"_anim","_sb"},
"shareowners":{"_anim","_sb"},
"shari":{"_geo","_prprn"},
"sharing":{"_loc_sr"},
"shark":{"_anim"},
"shark-skin":{"_anim"},
"sharks":{"_anim"},
"Sharon":{"_anim","_cty","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"sharper":{"_anim","_sb"},
"sharpshooter":{"_anim","_sb"},
"sharpshooters":{"_anim","_sb"},
"shatter":{"_loc_sr","_psych"},
"shattered":{"_loc_sr","_past","_psych"},
"shattering":{"_loc_sr","_psych"},
"shave":{"_loc_sr"},
"shaved":{"_loc_sr","_past"},
"shavers":{"_anim","_sb"},
"Shavian":{"_prprn"},
"shaving":{"_loc_sr"},
"Shavuot":{"_prprn","_tme"},
"Shaw":{"_anim","_nme","_prprn","_sb"},
"shawn":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Shawnee":{"_anim","_cty","_geo","_prprn","_sb"},
"shawwal":{"_prprn"},
"Shays":{"_anim","_prprn","_sb"},
"she":{"_anim","_fem","_sb"},
"she-bop":{"_anim","_fem","_sb"},
"she-goat":{"_anim","_fem","_sb"},
"sheared":{"_past"},
"shearer":{"_anim","_sb"},
"sheatfish":{"_anim"},
"sheathe":{"_loc_sr"},
"sheathed":{"_past"},
"sheathing":{"_loc_sr"},
"shebat":{"_prprn"},
"shebeen":{"_loc_sr"},
"Sheboygan":{"_cty","_geo","_prprn"},
"sheep-dog":{"_anim"},
"sheep-dogs":{"_anim"},
"sheep-fold":{"_anim"},
"sheep-tick":{"_anim"},
"sheepdog":{"_anim"},
"sheepdogs":{"_anim"},
"sheepfold":{"_loc_sr"},
"sheepherder":{"_anim","_sb"},
"sheered":{"_past"},
"sheeted":{"_past"},
"sheetrock":{"_prprn"},
"Sheffield":{"_geo","_prprn"},
"shegetz":{"_sb"},
"sheika":{"_anim","_fem","_sb"},
"sheikdom":{"_loc_sr"},
"sheikh":{"_anim","_sb"},
"sheikhdom":{"_loc_sr"},
"Sheila":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"shelduck":{"_anim"},
"shelled":{"_loc_sr","_past"},
"sheller":{"_anim","_sb"},
"Shelley":{"_anim","_fnme","_nme","_prprn","_sb"},
"shellfish":{"_anim"},
"shelling":{"_loc_sr"},
"shelter":{"_loc_sr"},
"sheltered":{"_loc_sr","_past"},
"shelters":{"_loc_sr"},
"shelve":{"_loc_sr"},
"shelver":{"_anim","_sb"},
"shelving":{"_loc_sr"},
"shem":{"_anim","_nme","_prprn","_sb"},
"Shensi":{"_geo","_prprn"},
"Shenyang":{"_cty","_geo","_prprn"},
"Shenzhen":{"_prprn"},
"Shepard":{"_anim","_nme","_prprn","_sb"},
"shepherded":{"_past"},
"shepherdess":{"_anim","_fem","_sb"},
"Sheppard":{"_prprn"},
"Sheraton":{"_anim","_nme","_prprn","_sb"},
"sheridan":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"sheriff":{"_anim","_sb"},
"sheriffs":{"_anim","_sb"},
"sherman":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Sherpa":{"_anim","_prprn","_sb"},
"sherrington":{"_anim","_nme","_prprn","_sb"},
"Sherwood":{"_anim","_nme","_prprn","_sb"},
"Shetland":{"_prprn"},
"Shevardnadze":{"_prprn"},
"Shevat":{"_prprn"},
"shevchenko":{"_anim","_nme","_prprn","_sb"},
"Shia":{"_prprn"},
"Shiah":{"_anim","_prprn","_sb"},
"shied":{"_loc_sr","_past"},
"shield":{"_loc_sr"},
"shielder":{"_anim","_sb"},
"shielding":{"_loc_sr"},
"shies":{"_loc_sr"},
"shift":{"_loc_sr"},
"shifting":{"_loc_sr"},
"Shiism":{"_prprn"},
"Shiite":{"_prprn","_sb"},
"Shiites":{"_prprn"},
"Shikoku":{"_geo","_prprn"},
"Shillong":{"_prprn"},
"shills":{"_anim","_sb"},
"Shiloh":{"_geo","_prprn"},
"shimmered":{"_past"},
"shingler":{"_anim","_sb"},
"Shinto":{"_prprn"},
"shintoism":{"_prprn"},
"Shintoist":{"_prprn"},
"ship-breaker":{"_fem"},
"shipbuilders":{"_anim","_sb"},
"shipbuilding":{"_loc_sr"},
"Shipley":{"_prprn"},
"shipmates":{"_anim","_sb"},
"shipowner":{"_anim","_sb"},
"shipowners":{"_anim","_sb"},
"shipped":{"_past"},
"shippers":{"_anim","_sb"},
"ships":{"_fem"},
"shipside":{"_loc_sr"},
"shipwright":{"_anim","_sb"},
"shipyard":{"_loc_sr"},
"shipyards":{"_loc_sr"},
"Shiraz":{"_cty","_geo","_prprn"},
"shirer":{"_anim","_nme","_prprn","_sb"},
"shirked":{"_past"},
"Shirley":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"shirr":{"_loc_sr"},
"shirring":{"_loc_sr"},
"shithead":{"_anim","_sb"},
"shitter":{"_anim","_sb"},
"shitting":{"_loc_sr"},
"Shiva":{"_prprn"},
"shivaism":{"_prprn"},
"shivaist":{"_prprn"},
"shiver":{"_loc_sr"},
"shivered":{"_loc_sr","_past"},
"shivering":{"_loc_sr"},
"shoals":{"_anim","_loc_sr"},
"shoat":{"_anim"},
"shocked":{"_past","_psych"},
"shocking":{"_psych"},
"shockley":{"_anim","_nme","_prprn","_sb"},
"shoeblack":{"_anim","_sb"},
"shoehorned":{"_past"},
"Shona":{"_prprn"},
"shone":{"_past"},
"shooed":{"_past"},
"shopaholic":{"_anim","_sb"},
"shopkeeper":{"_anim","_sb"},
"shopkeepers":{"_anim","_sb"},
"shoplift":{"_loc_sr"},
"shoplifter":{"_anim","_sb"},
"shoplifters":{"_anim","_sb"},
"shoplifting":{"_loc_sr"},
"shopped":{"_past"},
"shopper":{"_anim","_sb"},
"shoppers":{"_anim","_sb"},
"shopping":{"_ving"},
"shops":{"_loc_sr"},
"shore":{"_loc_sr"},
"shored":{"_past"},
"shoreline":{"_loc_sr"},
"shorelines":{"_loc_sr"},
"shores":{"_loc_sr"},
"short-circuited":{"_past"},
"short-term":{"_tme"},
"shorted":{"_past"},
"shortened":{"_past"},
"shortener":{"_anim","_sb"},
"shorthorn":{"_anim"},
"shortly":{"_tme"},
"Shoshone":{"_anim","_prprn","_sb"},
"shoshoni":{"_anim","_prprn","_sb"},
"shostakovich":{"_anim","_nme","_prprn","_sb"},
"should":{"_loc_sr","_past"},
"shouldered":{"_loc_sr","_past"},
"shove":{"_loc_sr"},
"shoved":{"_loc_sr","_past"},
"shovel":{"_loc_sr"},
"shoveled":{"_loc_sr","_past"},
"shoveling":{"_loc_sr"},
"shover":{"_anim","_sb"},
"shoving":{"_loc_sr"},
"show-off":{"_anim","_sb"},
"Showa":{"_prprn"},
"showcases":{"_loc_sr"},
"showed":{"_past"},
"shower":{"_loc_sr","_wthr"},
"showered":{"_loc_sr","_past","_wthr"},
"showering":{"_loc_sr","_wthr"},
"showgirl":{"_anim","_fem","_sb"},
"showgirls":{"_anim","_fem","_sb"},
"showmen":{"_anim","_sb"},
"showplace":{"_loc_sr"},
"showroom":{"_loc_sr"},
"showrooms":{"_loc_sr"},
"shrank":{"_loc_sr","_past"},
"shredded":{"_loc_sr","_past"},
"shreveport":{"_cty","_geo","_prprn"},
"shrew":{"_anim"},
"shrewmouse":{"_anim"},
"Shrewsbury":{"_cty","_geo","_prprn"},
"shrieked":{"_past"},
"shrike":{"_anim"},
"shrilled":{"_past"},
"shrimp":{"_anim"},
"shrimp-fish":{"_anim"},
"shrimper":{"_anim","_sb"},
"shrimpers":{"_anim","_sb"},
"shrimpfish":{"_anim"},
"shrine":{"_loc_sr"},
"shrines":{"_loc_sr"},
"shrink":{"_loc_sr"},
"shrinks":{"_loc_sr"},
"shriveled":{"_past"},
"shrivelled":{"_past"},
"Shropshire":{"_anim","_geo","_prprn"},
"shroud":{"_loc_sr"},
"shrouded":{"_loc_sr","_past"},
"shrouding":{"_loc_sr"},
"shrovetide":{"_prprn","_tme"},
"shrugged":{"_past"},
"shrunk":{"_loc_sr","_past"},
"shrunken":{"_loc_sr"},
"shuddered":{"_past"},
"shunned":{"_past"},
"shut-in":{"_anim","_sb"},
"shuttered":{"_past"},
"shutting":{"_loc_sr"},
"shuttlecock":{"_loc_sr"},
"shuttled":{"_loc_sr","_past"},
"shuttling":{"_loc_sr"},
"shy":{"_loc_sr"},
"shying":{"_loc_sr"},
"shyster":{"_anim","_sb"},
"Siam":{"_cntry","_geo","_prprn"},
"siamang":{"_anim"},
"Siamese":{"_anim","_prprn","_sb"},
"sian":{"_geo","_prprn"},
"sib":{"_anim","_sb"},
"Sibelius":{"_anim","_nme","_prprn","_sb"},
"Siberia":{"_geo","_prprn"},
"sibling":{"_anim","_sb"},
"siblings":{"_anim","_sb"},
"sibyl":{"_anim","_fem","_sb"},
"sichuan":{"_geo","_prprn","_stte"},
"Sicilians":{"_anim","_sb"},
"sicily":{"_geo","_prprn","_stte"},
"sickbay":{"_loc_sr"},
"sickened":{"_past","_psych"},
"sickening":{"_psych"},
"Siddons":{"_anim","_nme","_prprn","_sb"},
"sided":{"_past"},
"sidekick":{"_anim","_sb"},
"sidelined":{"_past"},
"sideman":{"_sb"},
"sidemen":{"_sb"},
"sidestepped":{"_past"},
"sidetracked":{"_loc_sr","_past"},
"sideways":{"_loc"},
"sidle":{"_loc_sr"},
"sidled":{"_loc_sr","_past"},
"sidney":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"sidon":{"_cty","_geo","_prprn"},
"Sidra":{"_prprn"},
"SIDS":{"_prprn"},
"Siegfried":{"_prprn"},
"Siemens":{"_anim","_prprn","_sb"},
"Siena":{"_cty","_geo","_prprn"},
"Sienkiewicz":{"_anim","_nme","_prprn","_sb"},
"Sierra":{"_loc_sr"},
"sieve":{"_loc_sr"},
"sift":{"_loc_sr"},
"sifted":{"_loc_sr","_past"},
"sifter":{"_loc_sr"},
"sifting":{"_loc_sr"},
"sigh":{"_loc_sr"},
"sighed":{"_loc_sr","_past"},
"sighing":{"_loc_sr"},
"sight-read":{"_past"},
"sighted":{"_past"},
"sightsee":{"_loc_sr"},
"sightseeing":{"_loc_sr"},
"sightseer":{"_anim","_sb"},
"sightseers":{"_anim","_sb"},
"Sigmund":{"_prprn"},
"sign":{"_loc_sr"},
"signaled":{"_past"},
"signaller":{"_anim","_sb"},
"signalman":{"_anim","_sb"},
"signatories":{"_anim","_sb"},
"signatory":{"_anim","_sb"},
"signed":{"_loc_sr","_past"},
"signers":{"_anim","_sb"},
"signified":{"_past"},
"signifier":{"_anim","_sb"},
"signing":{"_loc_sr"},
"signor":{"_anim","_sb"},
"signora":{"_anim","_sb"},
"signore":{"_anim","_sb"},
"signorina":{"_anim","_sb"},
"sigurd":{"_prprn"},
"Sihanouk":{"_anim","_nme","_prprn","_sb"},
"sihasapa":{"_anim","_prprn","_sb"},
"sika":{"_anim"},
"sikh":{"_prprn"},
"Sikhism":{"_prprn"},
"Sikhs":{"_prprn"},
"sikkim":{"_cntry","_geo","_prprn"},
"Sikorski":{"_prprn"},
"sikorsky":{"_anim","_nme","_prprn","_sb"},
"Silas":{"_prprn"},
"silenced":{"_past"},
"Silesia":{"_geo","_prprn","_stte"},
"silhouetted":{"_past"},
"silicate":{"_loc_sr"},
"silicates":{"_loc_sr"},
"silkworm":{"_anim"},
"sill":{"_sb"},
"sills":{"_sb"},
"silly":{"_anim","_sb"},
"Silone":{"_anim","_nme","_prprn","_sb"},
"Silurian":{"_prprn"},
"silvanus":{"_anim","_masc","_nme","_prprn","_sb"},
"silverback":{"_anim"},
"silverfish":{"_anim"},
"silverfishes":{"_anim"},
"silversmith":{"_anim","_sb"},
"silverworker":{"_anim","_sb"},
"silvia":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"simenon":{"_anim","_nme","_prprn","_sb"},
"Simeon":{"_anim","_nme","_prprn","_sb"},
"simmered":{"_past"},
"Simon":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"simperer":{"_anim","_sb"},
"simperers":{"_anim","_sb"},
"simple":{"_anim"},
"simples":{"_anim"},
"simpleton":{"_anim","_sb"},
"simplified":{"_past"},
"simpson":{"_anim","_nme","_prprn","_sb"},
"simulate":{"_loc_sr"},
"simulated":{"_loc_sr","_past"},
"simulates":{"_loc_sr"},
"Sinai":{"_prprn"},
"sinatra":{"_anim","_nme","_prprn","_sb"},
"Sinbad":{"_prprn"},
"since":{"_tme"},
"sinclair":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"sind":{"_geo","_prprn"},
"sindhi":{"_anim","_prprn","_sb"},
"sing":{"_loc_sr"},
"singapore":{"_cntry","_geo","_prprn"},
"Singaporean":{"_anim","_prprn","_sb"},
"singed":{"_past"},
"singer":{"_anim","_sb"},
"singer-songwriter":{"_anim","_sb"},
"singers":{"_anim","_sb"},
"Singh":{"_prprn"},
"Singhalese":{"_anim","_prprn","_sb"},
"singing":{"_loc_sr"},
"single-handed":{"_past"},
"singled":{"_past"},
"sings":{"_loc_sr"},
"Sinhala":{"_prprn"},
"Sinitic":{"_prprn"},
"sink":{"_loc_sr"},
"sinking":{"_loc_sr"},
"sinking-fund":{"_loc_sr"},
"sinks":{"_loc_sr"},
"sinners":{"_anim","_sb"},
"Sino-Soviet":{"_prprn"},
"sintered":{"_past"},
"sinus":{"_loc_sr"},
"sinuses":{"_loc_sr"},
"siouan":{"_prprn"},
"Sioux":{"_prprn","_sb"},
"sip":{"_loc_sr"},
"siphoned":{"_past"},
"sipped":{"_loc_sr","_past"},
"sippers":{"_anim","_sb"},
"sipping":{"_loc_sr"},
"siqueiros":{"_anim","_nme","_prprn","_sb"},
"sir":{"_anim","_masc","_sb"},
"sirdar":{"_anim","_sb"},
"sired":{"_past"},
"sirius":{"_prprn"},
"sirrah":{"_anim","_sb"},
"Sisley":{"_anim","_nme","_prprn","_sb"},
"sister":{"_anim","_fem","_sb"},
"sister-in-law":{"_anim","_fem","_sb"},
"sisters":{"_anim","_fem","_sb"},
"sisters-in-law":{"_anim","_fem","_sb"},
"Sisyphus":{"_prprn"},
"sit":{"_loc_sr"},
"site":{"_loc_sr"},
"sites":{"_loc_sr"},
"siting":{"_loc_sr"},
"sits":{"_loc_sr"},
"sitter":{"_anim","_sb"},
"sitters":{"_anim","_sb"},
"sitting":{"_loc_sr"},
"situate":{"_loc_sr"},
"situated":{"_loc_sr","_past"},
"sitwell":{"_anim","_nme","_prprn","_sb"},
"siva":{"_prprn"},
"Sivan":{"_prprn"},
"six":{"_quant"},
"six-figure":{"_num","_quant"},
"six-footer":{"_anim","_sb"},
"sixer":{"_anim","_sb"},
"sixfold":{"_quant"},
"sixteen":{"_quant"},
"sixty":{"_quant"},
"sizzled":{"_past"},
"sk-ampicillin":{"_prprn","_stte"},
"skagerak":{"_prprn"},
"skagerrak":{"_geo","_prprn"},
"skagit":{"_geo","_prprn"},
"skagway":{"_cty","_geo","_prprn"},
"Skase":{"_prprn"},
"skate":{"_anim"},
"skateboard":{"_loc_sr"},
"skateboarding":{"_loc_sr"},
"skated":{"_loc_sr","_past"},
"skater":{"_anim","_sb"},
"skaters":{"_anim","_sb"},
"skates":{"_anim"},
"skating":{"_loc_sr"},
"skaw":{"_geo","_prprn"},
"skeat":{"_anim","_nme","_prprn","_sb"},
"skein":{"_anim"},
"Skelton":{"_anim","_nme","_prprn","_sb"},
"skeptic":{"_anim","_sb"},
"skeptics":{"_anim","_sb"},
"sketched":{"_past"},
"skewed":{"_past"},
"ski":{"_loc_sr"},
"skidded":{"_past"},
"skier":{"_anim","_sb"},
"skiers":{"_anim","_sb"},
"skies":{"_loc_sr"},
"skiing":{"_loc_sr"},
"skim":{"_loc_sr"},
"skimmed":{"_loc_sr","_past"},
"skimming":{"_loc_sr"},
"skin-dive":{"_loc_sr"},
"skin-diver":{"_anim","_sb"},
"skinflint":{"_anim","_sb"},
"skinheads":{"_anim","_sb"},
"skinned":{"_past"},
"Skinner":{"_anim","_prprn","_sb"},
"skinnerian":{"_prprn"},
"skinny-dipper":{"_anim","_sb"},
"skip":{"_loc_sr"},
"skipped":{"_loc_sr","_past"},
"skipper":{"_anim","_sb"},
"skippers":{"_anim","_sb"},
"skipping":{"_loc_sr"},
"skips":{"_loc_sr"},
"skirmishing":{"_loc_sr"},
"skirted":{"_loc_sr","_past"},
"skirting":{"_loc_sr"},
"skivvies":{"_anim","_sb"},
"Skokie":{"_geo","_prprn"},
"Skopje":{"_cty","_geo","_prprn"},
"Skoplje":{"_prprn"},
"skua":{"_anim"},
"skulk":{"_loc_sr"},
"skulking":{"_loc_sr"},
"skunk":{"_loc_sr"},
"skunk-weed":{"_anim"},
"sky":{"_loc_sr"},
"skydive":{"_loc_sr"},
"skydiving":{"_loc_sr"},
"Skye":{"_prprn"},
"skyjacked":{"_past"},
"skyjackers":{"_anim","_sb"},
"skyrocket":{"_loc_sr"},
"skyrocketed":{"_loc_sr","_past"},
"skyrocketing":{"_loc_sr"},
"Skyros":{"_geo","_prprn"},
"skyscrapers":{"_loc_sr"},
"sl":{"_prprn"},
"slab":{"_loc_sr"},
"slabber":{"_anim","_sb"},
"slackened":{"_past"},
"slag":{"_loc_sr"},
"slaked":{"_past"},
"slammed":{"_past"},
"slanted":{"_past"},
"slapped":{"_past"},
"slashed":{"_past"},
"slasher":{"_anim","_sb"},
"slated":{"_past"},
"Slatkin":{"_prprn"},
"slatted":{"_past"},
"slaughtered":{"_past"},
"slaughterhouse":{"_loc_sr"},
"Slav":{"_prprn","_sb"},
"slave-owners":{"_anim","_sb"},
"slavered":{"_past"},
"slaves":{"_anim","_sb"},
"Slavic":{"_prprn"},
"Slavonic":{"_prprn"},
"Slavs":{"_prprn"},
"sle":{"_prprn"},
"sledge":{"_loc_sr"},
"sleep":{"_loc_sr"},
"sleeper":{"_anim","_sb"},
"sleeps":{"_loc_sr"},
"sleepwalk":{"_loc_sr"},
"sleepwalked":{"_loc_sr","_past"},
"sleepwalkers":{"_anim","_sb"},
"sleepwalking":{"_loc_sr"},
"sleigh":{"_loc_sr"},
"slept":{"_loc_sr","_past"},
"sleuthhound":{"_anim"},
"slew":{"_past"},
"sliced":{"_loc_sr","_past"},
"slicing":{"_loc_sr"},
"slicked":{"_past"},
"slicker":{"_anim","_sb"},
"slickers":{"_anim","_sb"},
"slid":{"_loc_sr","_past"},
"sliding":{"_loc_sr"},
"slighted":{"_past"},
"slimed":{"_past"},
"slimmed":{"_past"},
"slink":{"_loc_sr"},
"slip":{"_loc_sr"},
"slipped":{"_loc_sr","_past"},
"slipping":{"_loc_sr"},
"slipstream":{"_loc_sr"},
"slit":{"_past"},
"slither":{"_loc_sr"},
"slitter":{"_anim","_sb"},
"slitters":{"_anim","_sb"},
"sliver":{"_loc_sr"},
"slivered":{"_loc_sr","_past"},
"Sloan":{"_anim","_nme","_prprn","_sb"},
"Sloane":{"_prprn"},
"slob":{"_anim","_sb"},
"slobber":{"_loc_sr"},
"slobberer":{"_anim","_sb"},
"slog":{"_loc_sr"},
"slogging":{"_loc_sr"},
"slop":{"_loc_sr"},
"sloped":{"_loc_sr","_past"},
"sloping":{"_loc_sr"},
"slopped":{"_loc_sr","_past"},
"slopping":{"_loc_sr"},
"sloshed":{"_loc_sr","_past"},
"sloshing":{"_loc_sr"},
"slotted":{"_past"},
"slouch":{"_loc_sr"},
"Slovak":{"_anim","_prprn","_sb"},
"Slovakia":{"_cntry","_geo","_prprn"},
"Slovakian":{"_prprn"},
"sloven":{"_anim","_sb"},
"slovene":{"_anim","_prprn","_sb"},
"Slovenia":{"_cntry","_geo","_prprn"},
"Slovenian":{"_anim","_prprn","_sb"},
"slowcoach":{"_anim","_sb"},
"slowed":{"_past"},
"slowpoke":{"_anim"},
"slowworm":{"_anim"},
"slubbed":{"_loc_sr","_past"},
"slug":{"_anim"},
"slugged":{"_past"},
"slugger":{"_anim","_sb"},
"sluggers":{"_anim","_sb"},
"slugs":{"_anim"},
"sluiced":{"_past"},
"slumbered":{"_past"},
"slump":{"_loc_sr"},
"slumped":{"_loc_sr","_past"},
"slums":{"_loc_sr"},
"slung":{"_past"},
"slurped":{"_past"},
"slurred":{"_past"},
"slut":{"_anim","_fem","_sb"},
"slyboots":{"_sb"},
"smacked":{"_past"},
"smarted":{"_loc_sr","_past"},
"smarting":{"_loc_sr"},
"smear":{"_loc_sr"},
"smeared":{"_loc_sr","_past"},
"smelled":{"_past"},
"smelt":{"_past"},
"smelts":{"_anim"},
"smetana":{"_anim","_nme","_prprn","_sb"},
"smew":{"_sb"},
"smiled":{"_past"},
"smirch":{"_loc_sr"},
"smirked":{"_past"},
"smirker":{"_anim","_sb"},
"smite":{"_psych"},
"Smith":{"_anim","_prprn","_sb"},
"Smithson":{"_anim","_nme","_prprn","_sb"},
"smock":{"_loc_sr"},
"smoke":{"_loc_sr"},
"smoked":{"_loc_sr","_past"},
"smoker":{"_anim","_sb"},
"smokers":{"_anim","_sb"},
"Smokies":{"_prprn"},
"smoking":{"_loc_sr"},
"smolensk":{"_cty","_geo","_prprn"},
"smollett":{"_anim","_nme","_prprn","_sb"},
"smoothed":{"_past"},
"smoothened":{"_past"},
"smoothie":{"_anim","_sb"},
"smothered":{"_past"},
"smotherer":{"_anim","_sb"},
"smudged":{"_past"},
"smuggled":{"_loc_sr","_past"},
"smuggling":{"_loc_sr"},
"smyrna":{"_cty","_geo","_prprn"},
"Smyth":{"_anim","_nme","_prprn","_sb"},
"sn":{"_prprn"},
"snacked":{"_past"},
"snag":{"_loc_sr"},
"snagged":{"_loc_sr","_past"},
"snail":{"_anim"},
"snail-flower":{"_anim"},
"snails":{"_anim"},
"snake":{"_loc_sr"},
"snake-charmer":{"_anim"},
"snake-fish":{"_anim"},
"snake-head":{"_anim"},
"snake-like":{"_anim"},
"snake-oil":{"_anim"},
"snake-rail":{"_anim"},
"snaked":{"_loc_sr","_past"},
"snakefish":{"_anim"},
"snakes":{"_anim"},
"snap":{"_loc_sr"},
"snapped":{"_loc_sr","_past"},
"snapper":{"_anim"},
"snapping":{"_loc_sr"},
"snared":{"_loc_sr","_past"},
"snarer":{"_anim","_sb"},
"snaring":{"_loc_sr"},
"snarl":{"_loc_sr"},
"snarled":{"_loc_sr","_past"},
"snarling":{"_loc_sr"},
"snatch":{"_loc_sr"},
"snatched":{"_loc_sr","_past"},
"snead":{"_anim","_nme","_prprn","_sb"},
"sneak":{"_loc_sr"},
"sneaked":{"_loc_sr","_past"},
"sneaking":{"_loc_sr"},
"sneered":{"_past"},
"sneerer":{"_anim","_sb"},
"sneeze":{"_loc_sr"},
"sneezed":{"_loc_sr","_past"},
"snickered":{"_past"},
"sniffed":{"_loc_sr","_past"},
"sniffing":{"_loc_sr"},
"sniggered":{"_past"},
"sniped":{"_loc_sr","_past"},
"snipefish":{"_anim"},
"sniper":{"_anim","_sb"},
"snipers":{"_anim","_sb"},
"snipes":{"_anim"},
"snitched":{"_past"},
"snitcher":{"_anim","_sb"},
"snob":{"_anim","_sb"},
"snobs":{"_anim","_sb"},
"snook":{"_loc_sr"},
"snooker":{"_loc_sr"},
"snoop":{"_loc_sr"},
"snooper":{"_anim","_sb"},
"snooping":{"_loc_sr"},
"snorted":{"_past"},
"snow":{"_loc_sr"},
"snow-covered":{"_loc_sr"},
"snow-fence":{"_loc_sr"},
"snowball":{"_loc_sr"},
"snowbird":{"_anim","_sb"},
"snowbirds":{"_anim","_sb"},
"snowboarders":{"_anim","_sb"},
"snowed":{"_past","_wthr"},
"snowflakes":{"_loc_sr"},
"snowing":{"_wthr"},
"snowplow":{"_loc_sr"},
"snows":{"_loc_sr"},
"snubbed":{"_past"},
"snuck":{"_loc_sr","_past"},
"snuff":{"_loc_sr"},
"snuffed":{"_loc_sr","_past"},
"snuffers":{"_anim","_sb"},
"snuffler":{"_anim","_sb"},
"snuggery":{"_loc_sr"},
"snuggle":{"_loc_sr"},
"snuggled":{"_loc_sr","_past"},
"snuggling":{"_loc_sr"},
"so-and-so":{"_sb"},
"soaked":{"_past"},
"soar":{"_loc_sr"},
"soared":{"_loc_sr","_past"},
"soaring":{"_loc_sr"},
"sobbed":{"_past"},
"sober":{"_psych"},
"sobered":{"_past","_psych"},
"sobering":{"_psych"},
"sobersides":{"_sb"},
"socage":{"_loc_sr"},
"Sochi":{"_cty","_geo","_prprn"},
"socialised":{"_past"},
"socialiser":{"_anim","_sb"},
"socialist":{"_anim","_sb"},
"socialite":{"_anim","_sb"},
"socialites":{"_anim","_sb"},
"socialize":{"_loc_sr"},
"socialized":{"_loc_sr","_past"},
"socializes":{"_loc_sr"},
"socializing":{"_loc_sr"},
"societies":{"_sb"},
"society":{"_sb"},
"socinian":{"_prprn"},
"socinus":{"_anim","_nme","_prprn","_sb"},
"sockets":{"_loc_sr"},
"socrates":{"_anim","_nme","_prprn","_sb"},
"sod":{"_loc_sr"},
"sodalist":{"_sb"},
"Soddy":{"_anim","_nme","_prprn","_sb"},
"Sodom":{"_cty","_geo","_prprn"},
"sods":{"_loc_sr"},
"Sofia":{"_anim","_cty","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"softened":{"_past"},
"softies":{"_anim","_sb"},
"softy":{"_anim","_sb"},
"SoHo":{"_geo","_prprn"},
"soiled":{"_past"},
"Soissons":{"_cty","_geo","_prprn"},
"Sokol":{"_prprn"},
"solaced":{"_loc_sr","_past","_psych"},
"Solana":{"_prprn"},
"sold":{"_past"},
"soldered":{"_past"},
"soldier":{"_anim","_sb"},
"soldier-fish":{"_anim","_sb"},
"soldiers":{"_anim","_sb"},
"soled":{"_past"},
"soledad":{"_cty","_geo","_prprn"},
"Solent":{"_geo","_prprn"},
"solicit":{"_loc_sr"},
"solicited":{"_loc_sr","_past"},
"soliciting":{"_loc_sr"},
"solicitor":{"_anim","_sb"},
"solicitors":{"_anim","_sb"},
"solicits":{"_loc_sr"},
"solidified":{"_past"},
"Solihull":{"_geo","_prprn"},
"solingen":{"_cty","_geo","_prprn"},
"solitary":{"_anim","_sb"},
"solo":{"_loc_sr"},
"soloist":{"_anim","_sb"},
"Solomon":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Solon":{"_anim","_prprn","_sb"},
"solstice":{"_tme"},
"solvay":{"_anim","_nme","_prprn","_sb"},
"solved":{"_past"},
"solzhenitsyn":{"_anim","_nme","_prprn","_sb"},
"Somali":{"_anim","_prprn","_sb"},
"Somalia":{"_cntry","_geo","_prprn"},
"Somalian":{"_anim","_prprn","_sb"},
"some":{"_quant"},
"somebody":{"_anim","_sb"},
"someone":{"_anim","_sb"},
"somersault":{"_loc_sr"},
"somersaulting":{"_loc_sr"},
"Somerville":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"sometime":{"_tme"},
"sometimes":{"_tme"},
"Somme":{"_geo","_prprn"},
"somnambulate":{"_loc_sr"},
"somnambulates":{"_loc_sr"},
"somniloquist":{"_anim","_sb"},
"son":{"_anim","_masc","_sb"},
"son-of-a-bitch":{"_anim","_masc","_sb"},
"Sondheim":{"_anim","_nme","_prprn","_sb"},
"songbirds":{"_anim"},
"songwriter":{"_anim","_sb"},
"songwriters":{"_anim","_sb"},
"sonora":{"_cty","_geo","_prprn","_stte"},
"sons":{"_anim","_masc","_sb"},
"sons-in-law":{"_anim","_masc","_sb"},
"Sontag":{"_anim","_nme","_prprn","_sb"},
"Soo":{"_prprn"},
"soon":{"_tme"},
"sooner":{"_anim","_sb"},
"soonest":{"_tme"},
"soothe":{"_psych"},
"soothed":{"_past","_psych"},
"soothsayer":{"_anim","_sb"},
"soothsayers":{"_anim","_sb"},
"sop":{"_loc_sr"},
"Sophia":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"sophisticated":{"_past","_psych"},
"sophisticates":{"_anim","_sb"},
"Sophocles":{"_anim","_nme","_prprn","_sb"},
"sophomore":{"_anim","_sb"},
"sophomores":{"_anim","_sb"},
"sopping":{"_loc_sr"},
"sopranos":{"_sb"},
"sorbian":{"_prprn"},
"Sorbonne":{"_prprn"},
"soreheads":{"_anim","_sb"},
"sorensen":{"_anim","_nme","_prprn","_sb"},
"sores":{"_loc_sr"},
"Soros":{"_prprn"},
"sorrel":{"_anim"},
"sorrower":{"_anim","_sb"},
"sorted":{"_past"},
"sorts":{"_anim","_sb"},
"SOS":{"_prprn"},
"sot":{"_anim","_sb"},
"sothis":{"_prprn"},
"sotho":{"_prprn"},
"Soto":{"_anim","_nme","_prprn","_sb"},
"soubrette":{"_anim","_fem","_sb"},
"sough":{"_loc_sr"},
"soughing":{"_loc_sr"},
"sought":{"_past"},
"soul":{"_anim","_sb"},
"soul-stirring":{"_anim","_sb"},
"souls":{"_anim","_sb"},
"sounded":{"_past"},
"souped-up":{"_past"},
"Souphanouvong":{"_prprn"},
"source":{"_loc_sr"},
"sources":{"_loc_sr"},
"soured":{"_past"},
"sourpuss":{"_anim","_sb"},
"Sousa":{"_anim","_nme","_prprn","_sb"},
"souse":{"_loc_sr"},
"sousing":{"_loc_sr"},
"souslik":{"_anim"},
"sousse":{"_cty","_geo","_prprn"},
"Souter":{"_anim","_nme","_prprn","_sb"},
"South":{"_prprn"},
"Southampton":{"_anim","_geo","_nme","_prprn","_sb"},
"southerner":{"_anim","_sb"},
"southey":{"_anim","_nme","_prprn","_sb"},
"Southfield":{"_cty","_geo","_prprn"},
"southpaw":{"_anim","_sb"},
"Southport":{"_geo","_prprn"},
"soutine":{"_anim","_nme","_prprn","_sb"},
"sovereign":{"_anim","_sb"},
"sovereigns":{"_anim","_sb"},
"soviet":{"_anim","_sb"},
"Sovietologist":{"_prprn"},
"soviets":{"_anim","_sb"},
"sow":{"_loc_sr"},
"sowed":{"_loc_sr","_past"},
"Soweto":{"_cty","_geo","_prprn"},
"sowing":{"_loc_sr"},
"sown":{"_loc_sr"},
"sows":{"_anim"},
"Soyuz":{"_prprn"},
"spa":{"_loc_sr"},
"space":{"_loc_sr"},
"space-age":{"_loc_sr"},
"spaced":{"_past"},
"spacer":{"_anim","_sb"},
"spacers":{"_anim","_sb"},
"spaces":{"_loc_sr"},
"spade":{"_loc_sr"},
"spadefish":{"_anim"},
"spain":{"_cntry","_geo","_prprn"},
"Spalding":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"spandau":{"_geo","_prprn"},
"spandrels":{"_loc_sr"},
"spangled":{"_past"},
"Spaniard":{"_anim","_prprn","_sb"},
"spaniel":{"_anim"},
"Spanish":{"_anim","_prprn","_sb"},
"Spanish-American":{"_anim","_prprn","_sb"},
"spank":{"_loc_sr"},
"spanking":{"_loc_sr"},
"spanned":{"_past"},
"spar":{"_loc_sr"},
"spare":{"_loc_sr"},
"spared":{"_loc_sr","_past"},
"sparid":{"_sb"},
"sparing":{"_loc_sr"},
"sparker":{"_anim","_sb"},
"sparkle":{"_loc_sr"},
"sparkling":{"_loc_sr"},
"sparred":{"_loc_sr","_past"},
"sparring":{"_loc_sr"},
"sparrow":{"_anim"},
"sparrows":{"_anim"},
"sparta":{"_cty","_geo","_prprn"},
"Spartan":{"_prprn"},
"spas":{"_loc_sr"},
"spat":{"_past"},
"spatter":{"_loc_sr"},
"spattered":{"_loc_sr","_past"},
"spattering":{"_loc_sr"},
"spawn":{"_loc_sr"},
"spawned":{"_loc_sr","_past"},
"spawning":{"_loc_sr"},
"spawns":{"_anim"},
"spayed":{"_past"},
"speakeasy":{"_loc_sr"},
"speaker":{"_anim","_sb"},
"speakers":{"_anim","_sb"},
"speared":{"_past"},
"spearheaded":{"_past"},
"specialiser":{"_anim","_sb"},
"specialist":{"_anim","_sb"},
"specialists":{"_anim","_sb"},
"specialized":{"_past"},
"specializer":{"_anim","_sb"},
"specified":{"_past"},
"specifier":{"_anim","_sb"},
"specimens":{"_anim","_sb"},
"specked":{"_past"},
"speckled":{"_past"},
"spectator":{"_anim","_sb"},
"spectators":{"_anim","_sb"},
"Spector":{"_prprn"},
"speculate":{"_loc_sr"},
"speculated":{"_loc_sr","_past"},
"sped":{"_loc_sr","_past"},
"speechwriter":{"_anim","_sb"},
"speechwriters":{"_anim","_sb"},
"speed":{"_loc_sr"},
"speeded":{"_loc_sr","_past"},
"speeding":{"_loc_sr"},
"speer":{"_anim","_nme","_prprn","_sb"},
"speke":{"_anim","_nme","_prprn","_sb"},
"spelaeologist":{"_anim","_sb"},
"spell":{"_loc_sr"},
"spellbinding":{"_psych"},
"spellers":{"_anim","_sb"},
"Spence":{"_prprn"},
"Spencer":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Spencerian":{"_prprn"},
"spend":{"_loc_sr"},
"spenders":{"_anim","_sb"},
"spending":{"_loc_sr"},
"spends":{"_loc_sr"},
"spendthrifts":{"_anim","_sb"},
"spengler":{"_anim","_nme","_prprn","_sb"},
"Spenser":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"spent":{"_loc_sr","_past"},
"Sperry":{"_anim","_nme","_prprn","_sb"},
"spew":{"_loc_sr"},
"spewed":{"_loc_sr","_past"},
"spewing":{"_loc_sr"},
"Speyer":{"_cty","_geo","_prprn"},
"spf":{"_prprn"},
"spiced":{"_past"},
"spider":{"_anim"},
"spiders":{"_anim"},
"spied":{"_past"},
"spielberg":{"_anim","_nme","_prprn","_sb"},
"spies":{"_anim","_sb"},
"spiked":{"_past"},
"spillane":{"_anim","_nme","_prprn","_sb"},
"spilled":{"_past"},
"spin":{"_loc_sr"},
"spindle":{"_loc_sr"},
"spindled":{"_loc_sr","_past"},
"spinning":{"_loc_sr"},
"Spinoza":{"_anim","_nme","_prprn","_sb"},
"spiral":{"_loc_sr"},
"spiraling":{"_loc_sr"},
"spirit":{"_anim","_sb"},
"spirited":{"_past","_psych"},
"spirits":{"_anim","_sb"},
"spit":{"_loc_sr","_past","_wthr"},
"spitfire":{"_anim","_sb"},
"spitsbergen":{"_geo","_prprn"},
"spiv":{"_anim","_sb"},
"splashed":{"_loc_sr","_past"},
"splashing":{"_loc_sr"},
"splattered":{"_past"},
"splayed":{"_past"},
"spliced":{"_past"},
"splices":{"_loc_sr"},
"splinter":{"_loc_sr"},
"splintered":{"_loc_sr","_past"},
"splintering":{"_loc_sr"},
"split":{"_past"},
"splotches":{"_loc_sr"},
"splurge":{"_loc_sr"},
"spock":{"_anim","_nme","_prprn","_sb"},
"Spode":{"_anim","_nme","_prprn","_sb"},
"spoilsport":{"_anim","_sb"},
"spoilt":{"_past"},
"Spokane":{"_cty","_geo","_prprn"},
"spoke":{"_past"},
"spokesman":{"_anim","_masc","_sb"},
"spokesmen":{"_anim","_masc","_sb"},
"spokeswoman":{"_anim","_fem","_sb"},
"sponge":{"_anim"},
"sponged":{"_loc_sr","_past"},
"sponges":{"_anim"},
"sponging":{"_loc_sr"},
"sponsors":{"_anim","_sb"},
"spook":{"_psych"},
"spooked":{"_past","_psych"},
"spoon-fed":{"_past"},
"spooned":{"_loc_sr","_past"},
"spores":{"_anim"},
"sported":{"_past"},
"sportscaster":{"_anim","_sb"},
"sportsman":{"_anim","_masc","_sb"},
"sportsmen":{"_anim","_masc","_sb"},
"sportswriters":{"_anim","_sb"},
"spot":{"_loc_sr"},
"spot-weld":{"_loc_sr"},
"spot-welder":{"_loc_sr"},
"spot-welding":{"_loc_sr"},
"spotlighted":{"_past"},
"spotlights":{"_loc_sr"},
"spotsylvania":{"_geo","_prprn"},
"spotted":{"_past","_wthr"},
"spotting":{"_wthr"},
"spouse":{"_anim","_sb"},
"spouses":{"_anim","_sb"},
"spout":{"_loc_sr"},
"spouting":{"_loc_sr"},
"sprained":{"_past"},
"sprang":{"_loc_sr","_past"},
"sprat":{"_anim","_loc_sr"},
"sprawl":{"_loc_sr"},
"sprawled":{"_loc_sr","_past"},
"sprawling":{"_loc_sr"},
"spray":{"_loc_sr"},
"spraying":{"_loc_sr"},
"spread-eagle":{"_loc_sr"},
"sprigger":{"_anim","_sb"},
"spring":{"_loc_sr","_tme"},
"springbuck":{"_anim"},
"Springfield":{"_cty","_geo","_prprn"},
"springing":{"_loc_sr"},
"springs":{"_loc_sr","_tme"},
"Springsteen":{"_prprn"},
"springtime":{"_tme"},
"sprinkle":{"_loc_sr","_wthr"},
"sprinkled":{"_loc_sr","_past","_wthr"},
"sprinkling":{"_loc_sr","_wthr"},
"sprint":{"_loc_sr"},
"sprinted":{"_loc_sr","_past"},
"sprinting":{"_loc_sr"},
"sprouted":{"_past"},
"spruced":{"_past"},
"sprung":{"_loc_sr","_past"},
"spun":{"_loc_sr","_past"},
"spurned":{"_past"},
"spurner":{"_anim","_sb"},
"spurred":{"_past"},
"spurt":{"_loc_sr"},
"spurted":{"_loc_sr","_past"},
"spurting":{"_loc_sr"},
"sputter":{"_loc_sr"},
"sputtered":{"_loc_sr","_past"},
"squab":{"_anim"},
"squabble":{"_loc_sr"},
"squabbled":{"_loc_sr","_past"},
"squabbler":{"_anim","_sb"},
"squad":{"_anim","_sb"},
"squads":{"_anim","_sb"},
"squandered":{"_past"},
"squared":{"_loc_sr","_past"},
"squaring":{"_loc_sr"},
"squashed":{"_loc_sr","_past"},
"squashing":{"_loc_sr"},
"squatted":{"_loc_sr","_past"},
"squatter":{"_anim","_sb"},
"squatting":{"_loc_sr"},
"squaw":{"_anim","_fem","_sb"},
"squeaked":{"_past"},
"squealed":{"_past"},
"squeezed":{"_past"},
"squelch":{"_loc_sr"},
"squelched":{"_loc_sr","_past"},
"squelcher":{"_anim","_sb"},
"squid":{"_anim"},
"squinched":{"_past"},
"squinted":{"_past"},
"squinter":{"_anim","_sb"},
"squire":{"_anim","_masc","_sb"},
"squires":{"_anim","_masc","_sb"},
"squirm":{"_loc_sr"},
"squirming":{"_loc_sr"},
"squirms":{"_loc_sr"},
"squirrel":{"_anim"},
"squirreled":{"_past"},
"squirrelfish":{"_anim"},
"squirrels":{"_anim"},
"squirt":{"_loc_sr"},
"squirted":{"_loc_sr","_past"},
"squirting":{"_loc_sr"},
"Sr":{"_prprn"},
"Sri":{"_anim","_prprn","_sb"},
"ssa":{"_prprn"},
"sse":{"_prprn"},
"ssw":{"_prprn"},
"stab":{"_loc_sr"},
"stabbed":{"_loc_sr","_past"},
"stabbing":{"_loc_sr"},
"stabilised":{"_past"},
"stabilized":{"_past"},
"stable":{"_loc_sr"},
"stabled":{"_loc_sr","_past"},
"stables":{"_loc_sr"},
"stabling":{"_loc_sr"},
"stack":{"_loc_sr"},
"stackers":{"_anim","_sb"},
"stacking":{"_loc_sr"},
"Stacy":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"stadium":{"_loc_sr"},
"stadiums":{"_loc_sr"},
"stael":{"_anim","_nme","_prprn","_sb"},
"staff":{"_anim"},
"staffa":{"_geo","_prprn"},
"staffed":{"_past"},
"staffer":{"_sb"},
"staffers":{"_sb"},
"Stafford":{"_geo","_prprn"},
"Staffordshire":{"_prprn"},
"staffs":{"_anim"},
"stag":{"_anim"},
"staged":{"_past"},
"stagger":{"_loc_sr","_psych"},
"staggered":{"_past","_psych"},
"staggerer":{"_anim","_sb"},
"staggering":{"_psych"},
"staghound":{"_anim"},
"stagira":{"_cty","_geo","_prprn"},
"stagirus":{"_prprn"},
"stagnated":{"_past"},
"stags":{"_anim"},
"stained":{"_past"},
"stains":{"_loc_sr"},
"stairwells":{"_loc_sr"},
"staked":{"_loc_sr","_past"},
"staking":{"_loc_sr"},
"stalemated":{"_loc_sr","_past"},
"stalin":{"_anim","_nme","_prprn","_sb"},
"Stalingrad":{"_geo","_prprn"},
"stalinism":{"_prprn"},
"stalinist":{"_prprn"},
"stalk":{"_loc_sr"},
"stalked":{"_loc_sr","_past"},
"stalking":{"_loc_sr"},
"stall":{"_loc_sr"},
"stalled":{"_loc_sr","_past"},
"stalling":{"_loc_sr"},
"stallion":{"_anim"},
"stalwart":{"_anim","_sb"},
"stalwarts":{"_anim","_sb"},
"Stamford":{"_cty","_geo","_prprn"},
"stammered":{"_past"},
"stamped":{"_past"},
"stampede":{"_loc_sr"},
"stampeded":{"_loc_sr","_past"},
"stand-in":{"_anim","_sb"},
"stand-ins":{"_anim","_sb"},
"standard-bearer":{"_anim","_sb"},
"standardised":{"_past"},
"standardiser":{"_anim","_sb"},
"standardizer":{"_anim","_sb"},
"standish":{"_anim","_nme","_prprn","_sb"},
"Stanford":{"_anim","_nme","_prprn","_sb"},
"Stanislavsky":{"_anim","_nme","_prprn","_sb"},
"Stanley":{"_anim","_cty","_fnme","_geo","_nme","_prprn","_sb"},
"Stans":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Stanton":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"stapler":{"_anim","_sb"},
"starched":{"_past"},
"stared":{"_past"},
"starer":{"_anim","_sb"},
"starfish":{"_anim"},
"stargazer":{"_anim","_sb"},
"Stark":{"_anim","_prprn","_sb"},
"Starkey":{"_prprn"},
"starlet":{"_anim","_fem","_sb"},
"starling":{"_anim"},
"Starr":{"_anim","_nme","_prprn","_sb"},
"starred":{"_past"},
"started":{"_past"},
"starter":{"_sb"},
"starters":{"_sb"},
"startle":{"_psych"},
"startling":{"_psych"},
"starts":{"_loc_sr"},
"starve":{"_loc_sr"},
"starved":{"_loc_sr","_past"},
"starveling":{"_sb"},
"stashed":{"_loc_sr","_past"},
"state":{"_loc_sr"},
"state-of-the-art":{"_loc_sr"},
"stated":{"_loc_sr","_past"},
"statehooders":{"_anim","_sb"},
"statehouse":{"_loc_sr"},
"states":{"_loc_sr"},
"statesmen":{"_anim","_masc","_sb"},
"stating":{"_loc_sr"},
"station":{"_loc_sr"},
"stationed":{"_loc_sr","_past"},
"stationing":{"_loc_sr"},
"stations":{"_loc_sr"},
"statist":{"_anim","_sb"},
"statisticians":{"_anim","_sb"},
"stavanger":{"_cty","_geo","_prprn"},
"staved":{"_past"},
"stay":{"_loc_sr"},
"stayed":{"_loc_sr","_past"},
"staying":{"_loc_sr"},
"std":{"_prprn"},
"stead":{"_loc_sr"},
"steadied":{"_past"},
"steam":{"_loc_sr"},
"steamed":{"_past"},
"steamer":{"_loc_sr"},
"steamers":{"_loc_sr"},
"steams":{"_loc_sr"},
"steamship":{"_loc_sr"},
"steamships":{"_loc_sr"},
"steed":{"_anim"},
"steele":{"_anim","_nme","_prprn","_sb"},
"steeled":{"_past"},
"steelmaker":{"_anim","_sb"},
"steelmakers":{"_anim","_sb"},
"steelworkers":{"_anim","_sb"},
"Steen":{"_anim","_nme","_prprn","_sb"},
"steenbok":{"_anim"},
"steep":{"_loc_sr"},
"steeped":{"_loc_sr","_past"},
"steered":{"_past"},
"steers":{"_anim","_masc"},
"Steffens":{"_anim","_nme","_prprn","_sb"},
"Steichen":{"_anim","_nme","_prprn","_sb"},
"Stein":{"_anim","_prprn","_sb"},
"steinbeck":{"_anim","_nme","_prprn","_sb"},
"steinberg":{"_anim","_nme","_prprn","_sb"},
"steinbok":{"_anim"},
"steinem":{"_anim","_nme","_prprn","_sb"},
"Steiner":{"_anim","_nme","_prprn","_sb"},
"steinman":{"_anim","_nme","_prprn","_sb"},
"Steinmetz":{"_anim","_nme","_prprn","_sb"},
"Steinway":{"_anim","_nme","_prprn","_sb"},
"stemmed":{"_past"},
"stemmer":{"_anim","_sb"},
"stendhal":{"_anim","_nme","_prprn","_sb"},
"stengel":{"_anim","_nme","_prprn","_sb"},
"stepbrother":{"_anim","_masc","_sb"},
"stepchild":{"_anim","_sb"},
"stepchildren":{"_anim","_sb"},
"stepdaughter":{"_anim","_fem","_sb"},
"stepfather":{"_anim","_masc","_sb"},
"Stephanie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Stephen":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Stephens":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Stephenson":{"_anim","_nme","_prprn","_sb"},
"stepmothers":{"_anim","_fem","_sb"},
"stepped":{"_past"},
"steppes":{"_loc_sr"},
"stepsister":{"_anim","_fem","_sb"},
"stereotyped":{"_loc_sr","_past"},
"sterilised":{"_past"},
"steriliser":{"_anim","_sb"},
"sterilized":{"_past"},
"Sternberg":{"_anim","_nme","_prprn","_sb"},
"Sterne":{"_anim","_nme","_prprn","_sb"},
"sterope":{"_prprn"},
"Stetson":{"_prprn"},
"Stetsons":{"_prprn"},
"Stettin":{"_geo","_prprn"},
"Steuben":{"_anim","_nme","_prprn","_sb"},
"stevedore":{"_anim","_sb"},
"Steven":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"stevens":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Stevenson":{"_anim","_nme","_prprn","_sb"},
"steward":{"_anim","_sb"},
"stewardess":{"_anim","_fem","_sb"},
"stewardesses":{"_anim","_fem","_sb"},
"stewards":{"_anim","_sb"},
"Stewart":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"stheno":{"_prprn"},
"stick":{"_loc_sr"},
"sticker":{"_sb"},
"stickers":{"_sb"},
"sticking":{"_loc_sr"},
"sticks":{"_loc_sr"},
"stieglitz":{"_anim","_nme","_prprn","_sb"},
"stiffed":{"_past"},
"stiffened":{"_past"},
"stiffs":{"_anim","_sb"},
"stifle":{"_psych"},
"stifled":{"_past","_psych"},
"stifles":{"_psych"},
"stifling":{"_psych"},
"stigmatic":{"_anim","_sb"},
"stillbirth":{"_anim","_sb"},
"stillbirths":{"_anim","_sb"},
"stillroom":{"_loc_sr"},
"stilted":{"_loc_sr","_past"},
"stilwell":{"_anim","_nme","_prprn","_sb"},
"Stimson":{"_anim","_nme","_prprn","_sb"},
"stimulate":{"_loc_sr","_psych"},
"stimulating":{"_loc_sr","_psych"},
"stinging":{"_psych"},
"stingray":{"_anim"},
"stingrays":{"_anim"},
"stinker":{"_anim","_sb"},
"stinkpot":{"_anim","_sb"},
"stinter":{"_anim","_sb"},
"stipendiary":{"_anim","_sb"},
"stipple":{"_loc_sr"},
"stippled":{"_loc_sr","_past"},
"stippler":{"_anim","_sb"},
"stipulated":{"_past"},
"stir":{"_loc_sr"},
"Stirling":{"_geo","_prprn"},
"stirred":{"_loc_sr","_past"},
"stirring":{"_loc_sr"},
"stitched":{"_past"},
"stocked":{"_past"},
"Stockhausen":{"_prprn"},
"stockholder":{"_anim","_sb"},
"stockholders":{"_anim","_sb"},
"Stockholm":{"_cty","_geo","_prprn"},
"stockist":{"_anim","_sb"},
"stockjobber":{"_anim","_sb"},
"stockpiling":{"_loc_sr"},
"stockroom":{"_loc_sr"},
"stocktaker":{"_anim","_sb"},
"stockton":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"stockyards":{"_loc_sr"},
"stoic":{"_anim","_sb"},
"stoked":{"_past"},
"Stokowski":{"_anim","_nme","_prprn","_sb"},
"stole":{"_past"},
"stomp":{"_loc_sr"},
"stomped":{"_loc_sr","_past"},
"stomping":{"_loc_sr"},
"Stone":{"_anim","_prprn","_sb"},
"stoned":{"_past"},
"stonefish":{"_anim"},
"stonehenge":{"_geo","_prprn"},
"stonewall":{"_loc_sr"},
"stonewalled":{"_loc_sr","_past"},
"stonewalling":{"_loc_sr"},
"stoneware":{"_loc_sr"},
"stood":{"_past"},
"stooges":{"_anim","_sb"},
"stool":{"_loc_sr"},
"stoolpigeon":{"_anim","_sb"},
"stoop":{"_loc_sr"},
"stooping":{"_loc_sr"},
"Stoppard":{"_prprn"},
"stopped":{"_past"},
"stoppered":{"_past"},
"store":{"_loc_sr"},
"storehouses":{"_loc_sr","_sb"},
"storekeepers":{"_anim","_sb"},
"storied":{"_past"},
"stork":{"_anim"},
"stormed":{"_past","_wthr"},
"storming":{"_wthr"},
"storytellers":{"_anim","_sb"},
"stout":{"_sb"},
"stout-hearted":{"_sb"},
"stow":{"_loc_sr"},
"stowaway":{"_anim","_sb"},
"stowe":{"_anim","_nme","_prprn","_sb"},
"stowed":{"_loc_sr","_past"},
"stowing":{"_loc_sr"},
"stp":{"_prprn"},
"Strachey":{"_anim","_nme","_prprn","_sb"},
"strad":{"_prprn"},
"straddle":{"_loc_sr"},
"straddled":{"_loc_sr","_past"},
"straddling":{"_loc_sr"},
"stradivari":{"_anim","_nme","_prprn","_sb"},
"Stradivarius":{"_prprn"},
"strafer":{"_anim","_sb"},
"straggle":{"_loc_sr"},
"straggled":{"_loc_sr","_past"},
"straggling":{"_loc_sr"},
"straight":{"_loc_sr"},
"straight-armed":{"_past"},
"straight-billed":{"_loc_sr"},
"straightened":{"_past"},
"straighteners":{"_anim","_sb"},
"straights":{"_loc_sr"},
"straightway":{"_tme"},
"strained":{"_past"},
"strait":{"_loc_sr"},
"straits":{"_loc_sr"},
"strands":{"_loc_sr"},
"stranger":{"_anim","_sb"},
"strangers":{"_anim","_sb"},
"strap":{"_loc_sr"},
"strapped":{"_loc_sr","_past"},
"strasbourg":{"_cty","_geo","_prprn"},
"strategist":{"_anim","_sb"},
"strategists":{"_anim","_sb"},
"Stratford-upon-Avon":{"_geo","_prprn"},
"stratified":{"_loc_sr","_past"},
"Straus":{"_anim","_nme","_prprn","_sb"},
"Strauss":{"_anim","_nme","_prprn","_sb"},
"stravinsky":{"_anim","_nme","_prprn","_sb"},
"stray":{"_loc_sr"},
"strayed":{"_loc_sr","_past"},
"strayer":{"_anim","_sb"},
"straying":{"_loc_sr"},
"strays":{"_anim"},
"streaked":{"_loc_sr","_past"},
"stream":{"_loc_sr"},
"stream-of-consciousness":{"_loc_sr"},
"streamed":{"_past"},
"streamline":{"_loc_sr"},
"streamlined":{"_loc_sr","_past"},
"streamlining":{"_loc_sr"},
"streams":{"_loc_sr"},
"streamside":{"_loc_sr"},
"Streep":{"_prprn"},
"Streisand":{"_prprn"},
"strengthened":{"_past"},
"stressed":{"_past"},
"stretcher-bearer":{"_anim","_sb"},
"strickland":{"_anim","_nme","_prprn","_sb"},
"stride":{"_loc_sr"},
"striding":{"_loc_sr"},
"strikebreakers":{"_anim","_sb"},
"striker":{"_anim","_sb"},
"strikers":{"_anim","_sb"},
"Strindberg":{"_anim","_nme","_prprn","_sb"},
"stringing":{"_loc_sr"},
"strip-mined":{"_loc_sr","_past"},
"striped":{"_past"},
"striper":{"_sb"},
"stripling":{"_anim","_sb"},
"stripped":{"_past"},
"stripper":{"_anim","_sb"},
"strippers":{"_anim","_sb"},
"stripteaser":{"_anim","_sb"},
"strode":{"_loc_sr","_past"},
"stroheim":{"_anim","_nme","_prprn","_sb"},
"stroll":{"_loc_sr"},
"strolled":{"_loc_sr","_past"},
"stroller":{"_anim","_sb"},
"strollers":{"_anim","_sb"},
"strolling":{"_loc_sr"},
"strong-armer":{"_anim","_sb"},
"stronghold":{"_loc_sr"},
"strongholds":{"_loc_sr"},
"strongman":{"_anim","_sb"},
"stropped":{"_loc_sr","_past"},
"strove":{"_past"},
"struck":{"_past"},
"structured":{"_loc_sr","_past"},
"structuring":{"_loc_sr"},
"struggled":{"_past"},
"strung":{"_loc_sr","_past"},
"strut":{"_loc_sr"},
"strutted":{"_loc_sr","_past"},
"strutting":{"_loc_sr"},
"stuart":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"stubbed":{"_past"},
"Stubbs":{"_anim","_nme","_prprn","_sb"},
"stuck":{"_loc_sr","_past"},
"stud":{"_anim","_masc"},
"studded":{"_past"},
"student":{"_anim","_sb"},
"students":{"_anim","_sb"},
"studhorse":{"_anim"},
"studied":{"_loc_sr","_past"},
"studs":{"_anim","_masc"},
"studying":{"_loc_sr"},
"stumble":{"_loc_sr"},
"stumbled":{"_loc_sr","_past"},
"stumbling":{"_loc_sr"},
"stumbling-block":{"_loc_sr"},
"stump":{"_loc_sr"},
"stumped":{"_loc_sr","_past"},
"stumping":{"_loc_sr"},
"stun":{"_psych"},
"stung":{"_past","_psych"},
"stunning":{"_psych"},
"stunted":{"_past"},
"stupefied":{"_past","_psych"},
"stupefying":{"_psych"},
"stupid":{"_anim","_sb"},
"stutter":{"_loc_sr"},
"Stuttgart":{"_cty","_geo","_prprn"},
"stuyvesant":{"_anim","_nme","_prprn","_sb"},
"styled":{"_loc_sr","_past"},
"styler":{"_anim","_sb"},
"styling":{"_loc_sr"},
"stylised":{"_past"},
"stylists":{"_anim","_sb"},
"stylized":{"_loc_sr","_past"},
"stymied":{"_past"},
"styron":{"_anim","_nme","_prprn","_sb"},
"Styx":{"_geo","_prprn"},
"Su":{"_prprn"},
"sub-group":{"_loc_sr"},
"subaltern":{"_anim","_sb"},
"subcontractor":{"_anim","_sb"},
"subcontractors":{"_anim","_sb"},
"subdirector":{"_anim","_sb"},
"subdivide":{"_loc_sr"},
"subdued":{"_past"},
"subduer":{"_anim","_sb"},
"subeditor":{"_anim","_sb"},
"subject":{"_anim","_sb"},
"subjected":{"_past"},
"subjects":{"_anim","_sb"},
"subjugator":{"_anim","_sb"},
"sublieutenant":{"_anim","_sb"},
"sublimated":{"_past"},
"sublimed":{"_past"},
"submariners":{"_anim","_sb"},
"submerge":{"_loc_sr"},
"submerged":{"_loc_sr","_past"},
"submerging":{"_loc_sr"},
"submersed":{"_past"},
"submitted":{"_past"},
"subnational":{"_anim","_sb"},
"subocean":{"_loc_sr"},
"subordinate":{"_loc_sr"},
"subordinating":{"_loc_sr"},
"subordinator":{"_anim","_sb"},
"suborner":{"_anim","_sb"},
"subparagraph":{"_loc_sr"},
"subparts":{"_loc_sr"},
"subpoenaed":{"_past"},
"subscribed":{"_past"},
"subscriber":{"_anim","_sb"},
"subscribers":{"_anim","_sb"},
"subsections":{"_loc_sr"},
"subsided":{"_past"},
"subsidised":{"_past"},
"subsidiser":{"_anim","_sb"},
"subsidized":{"_past"},
"subsister":{"_anim","_sb"},
"subspace":{"_loc_sr"},
"subspaces":{"_loc_sr"},
"substantiated":{"_past"},
"substations":{"_loc_sr"},
"substituted":{"_past"},
"substitutes":{"_sb"},
"subsumed":{"_past"},
"subtended":{"_past"},
"subtitled":{"_past"},
"subtopia":{"_loc_sr"},
"subtracted":{"_past"},
"subtracter":{"_anim","_sb"},
"subtreasury":{"_loc_sr"},
"subtropic":{"_loc_sr"},
"subtypes":{"_sb"},
"suburb":{"_loc_sr"},
"suburbanised":{"_past"},
"suburbanite":{"_anim","_sb"},
"suburbanites":{"_anim","_sb"},
"suburbanized":{"_past"},
"suburbs":{"_loc_sr"},
"subversive":{"_anim","_sb"},
"subversives":{"_anim","_sb"},
"subvocaliser":{"_anim","_sb"},
"subvocalize":{"_loc_sr"},
"subvocalizer":{"_anim","_sb"},
"succeed":{"_loc_sr"},
"succeeded":{"_loc_sr","_past"},
"succeeder":{"_anim","_sb"},
"succeeding":{"_loc_sr"},
"succeeds":{"_loc_sr"},
"successor":{"_sb"},
"successors":{"_sb"},
"succorer":{"_anim","_sb"},
"Succoth":{"_prprn","_tme"},
"succourer":{"_anim","_sb"},
"succumbed":{"_past"},
"sucked":{"_loc_sr","_past"},
"suckered":{"_past"},
"suckers":{"_anim","_sb"},
"sucking":{"_loc_sr"},
"suckle":{"_loc_sr"},
"suckled":{"_loc_sr","_past"},
"Sucre":{"_cty","_geo","_prprn"},
"sudan":{"_cntry","_geo","_prprn"},
"sudanese":{"_anim","_prprn","_sb"},
"sudatorium":{"_loc_sr"},
"sudbury":{"_cty","_geo","_prprn"},
"sudra":{"_prprn"},
"sue":{"_loc_sr"},
"sued":{"_loc_sr","_past"},
"suer":{"_anim","_sb"},
"Suez":{"_cty","_geo","_prprn"},
"suffered":{"_past"},
"sufferer":{"_anim","_sb"},
"sufferers":{"_anim","_sb"},
"sufficent":{"_anim","_sb"},
"suffocated":{"_past"},
"suffragettes":{"_anim","_fem","_sb"},
"suffused":{"_past"},
"Sufi":{"_prprn"},
"Sufism":{"_prprn"},
"suggested":{"_past"},
"suharto":{"_anim","_nme","_prprn","_sb"},
"suing":{"_loc_sr"},
"Suisse":{"_prprn"},
"suited":{"_past"},
"suitor":{"_anim","_masc","_sb"},
"suitors":{"_anim","_masc","_sb"},
"sukarno":{"_anim","_nme","_prprn","_sb"},
"Sukkoth":{"_prprn","_tme"},
"sulawesi":{"_geo","_prprn"},
"sulfuretted":{"_past"},
"sulfurized":{"_past"},
"sulked":{"_past"},
"sulla":{"_anim","_nme","_prprn","_sb"},
"sullivan":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"sulphured":{"_past"},
"sulphuretted":{"_past"},
"sultans":{"_anim","_sb"},
"sumatra":{"_geo","_prprn"},
"Sumerian":{"_prprn","_sb"},
"summarized":{"_past"},
"summed":{"_past"},
"summer":{"_tme"},
"summer-long":{"_tme"},
"summers":{"_tme"},
"summertime":{"_tme"},
"summoned":{"_past"},
"sumner":{"_anim","_fnme","_nme","_prprn","_sb"},
"Sumter":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"sun":{"_day"},
"sun-baked":{"_day"},
"sun-kissed":{"_day"},
"sun-ray":{"_day"},
"sun-suit":{"_day"},
"sun-tan":{"_day"},
"sun-tanned":{"_day"},
"sun-worship":{"_day"},
"Sun.":{"_day","_prprn","_tme"},
"sunbathe":{"_loc_sr"},
"sunbather":{"_anim","_sb"},
"Sunbelt":{"_geo","_prprn"},
"Sunday":{"_day","_prprn","_tme"},
"Sundays":{"_day","_prprn","_tme"},
"sunderland":{"_geo","_prprn"},
"sundown":{"_tme"},
"sunfish":{"_anim"},
"Sung":{"_loc_sr","_past"},
"Sunni":{"_prprn"},
"sunning":{"_loc_sr"},
"sunnite":{"_prprn"},
"Sunnyvale":{"_cty","_geo","_prprn"},
"sunroof":{"_loc_sr"},
"sunset":{"_tme"},
"sunsets":{"_tme"},
"suntrap":{"_loc_sr"},
"sup":{"_loc_sr"},
"superagent":{"_anim","_sb"},
"superannuate":{"_loc_sr"},
"superannuated":{"_loc_sr","_past"},
"superceded":{"_past"},
"superconductor":{"_anim","_sb"},
"superconductors":{"_anim","_sb"},
"superficies":{"_loc_sr"},
"superimposed":{"_past"},
"superintendent":{"_anim","_sb"},
"superintendents":{"_anim","_sb"},
"superior":{"_anim","_sb"},
"superiors":{"_anim","_sb"},
"superman":{"_anim","_masc","_sb"},
"supermarketeer":{"_anim","_sb"},
"supermarketer":{"_anim","_sb"},
"supersafe":{"_loc_sr"},
"superscribe":{"_loc_sr"},
"superseded":{"_past"},
"superstar":{"_anim","_sb"},
"superstars":{"_anim","_sb"},
"superstate":{"_loc_sr"},
"supertwister":{"_anim","_sb"},
"supervene":{"_loc_sr"},
"supervened":{"_loc_sr","_past"},
"supervised":{"_past"},
"supervisor":{"_anim","_sb"},
"supervisors":{"_anim","_sb"},
"supper":{"_tme"},
"suppers":{"_tme"},
"supping":{"_loc_sr"},
"supplanted":{"_past"},
"supplemented":{"_past"},
"suppliant":{"_anim","_sb"},
"supplicant":{"_anim","_sb"},
"supplied":{"_past"},
"supplier":{"_anim","_sb"},
"suppliers":{"_anim","_sb"},
"supported":{"_loc_sr","_past"},
"supporter":{"_anim","_sb"},
"supporters":{"_anim","_sb"},
"supporting":{"_loc_sr"},
"supposed":{"_past"},
"supposedly":{"_probabl"},
"suppressed":{"_past"},
"suppressor":{"_sb"},
"suppressors":{"_sb"},
"supra":{"_loc"},
"supra-personal":{"_loc"},
"supremacist":{"_anim","_sb"},
"suprematist":{"_anim","_sb"},
"surety":{"_anim","_sb"},
"surfaced":{"_past"},
"surfboarder":{"_anim","_sb"},
"surfeited":{"_past"},
"surfer":{"_anim","_sb"},
"surfers":{"_anim","_sb"},
"surfing":{"_loc_sr"},
"surge":{"_loc_sr"},
"surged":{"_loc_sr","_past"},
"surgeon":{"_anim","_sb"},
"surgeons":{"_anim","_sb"},
"surgeries":{"_loc_sr"},
"surgery":{"_loc_sr"},
"surging":{"_loc_sr"},
"suricate":{"_anim"},
"Surinam":{"_cntry","_prprn"},
"Suriname":{"_cntry","_geo","_prprn"},
"surmised":{"_past"},
"surmounted":{"_past"},
"surmounter":{"_anim","_sb"},
"surpasses":{"_loc_sr"},
"surpassing":{"_loc_sr"},
"surprised":{"_past","_psych"},
"surpriser":{"_anim","_sb"},
"surprising":{"_psych"},
"surrealist":{"_anim","_sb"},
"surrealists":{"_anim","_sb"},
"surrendered":{"_past"},
"surrenderer":{"_anim","_sb"},
"Surrey":{"_geo","_prprn"},
"surrogate":{"_anim","_sb"},
"surrogates":{"_anim","_sb"},
"surround":{"_loc_sr"},
"surrounded":{"_loc_sr","_past"},
"surrounding":{"_loc_sr"},
"survey":{"_loc_sr"},
"surveyed":{"_past"},
"surveyor":{"_anim","_sb"},
"survivalist":{"_anim","_sb"},
"survivalists":{"_anim","_sb"},
"survived":{"_past"},
"survivor":{"_anim","_sb"},
"survivors":{"_anim","_sb"},
"susa":{"_cty","_geo","_prprn"},
"susah":{"_geo","_prprn"},
"Susan":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"susanna":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"susiana":{"_geo","_prprn"},
"suslik":{"_anim"},
"suspected":{"_past"},
"suspects":{"_anim","_sb"},
"suspended":{"_past"},
"susquehanna":{"_prprn"},
"sussex":{"_cntry","_geo","_prprn"},
"sustain":{"_loc_sr"},
"sustained":{"_loc_sr","_past"},
"sustaining":{"_loc_sr"},
"sustains":{"_loc_sr"},
"Sutcliffe":{"_prprn"},
"Sutherland":{"_anim","_nme","_prprn","_sb"},
"Sutton":{"_anim","_nme","_prprn","_sb"},
"SUV":{"_prprn"},
"Suva":{"_cty","_geo","_prprn"},
"Suvorov":{"_anim","_nme","_prprn","_sb"},
"svalbard":{"_geo","_prprn"},
"svedberg":{"_anim","_nme","_prprn","_sb"},
"Svengali":{"_anim","_prprn","_sb"},
"Sverdlovsk":{"_cty","_geo","_prprn"},
"sverdrup":{"_anim","_nme","_prprn","_sb"},
"Svevo":{"_prprn"},
"SW":{"_prprn"},
"swabbed":{"_past"},
"swagger":{"_loc_sr"},
"swaggered":{"_loc_sr","_past"},
"swaggering":{"_loc_sr"},
"Swahili":{"_anim","_prprn","_sb"},
"swain":{"_anim","_masc","_sb"},
"swallow":{"_loc_sr"},
"swallowed":{"_loc_sr","_past"},
"swallowing":{"_loc_sr"},
"swallows":{"_loc_sr"},
"swam":{"_loc_sr","_past"},
"swami":{"_anim","_sb"},
"swammerdam":{"_anim","_nme","_prprn","_sb"},
"swamp":{"_loc_sr"},
"swamped":{"_past"},
"swamps":{"_loc_sr"},
"swan":{"_loc_sr"},
"swans":{"_anim"},
"swansea":{"_cty","_geo","_prprn"},
"swanson":{"_anim","_nme","_prprn","_sb"},
"Swapo":{"_prprn"},
"swapped":{"_past"},
"sward":{"_loc_sr"},
"swarm":{"_loc_sr"},
"swarmed":{"_loc_sr","_past"},
"swarming":{"_loc_sr"},
"swarms":{"_anim"},
"swashbuckler":{"_anim","_sb"},
"swathe":{"_loc_sr"},
"swathed":{"_loc_sr","_past"},
"swathing":{"_loc_sr"},
"swayed":{"_past"},
"swayer":{"_anim","_sb"},
"Swazi":{"_anim","_prprn","_sb"},
"Swaziland":{"_cntry","_geo","_prprn"},
"SWbS":{"_prprn"},
"SWbW":{"_prprn"},
"sweat":{"_loc_sr"},
"sweated":{"_loc_sr","_past"},
"sweating":{"_loc_sr"},
"Swed":{"_prprn"},
"Swede":{"_anim","_prprn","_sb"},
"sweden":{"_cntry","_geo","_prprn"},
"swedenborg":{"_anim","_nme","_prprn","_sb"},
"swedish":{"_prprn"},
"sweeper":{"_sb"},
"sweepers":{"_sb"},
"sweetened":{"_past"},
"sweetheart":{"_anim","_sb"},
"sweethearts":{"_anim","_sb"},
"sweetie":{"_anim","_sb"},
"swell":{"_loc_sr"},
"swelled":{"_loc_sr","_past"},
"swellhead":{"_anim","_sb"},
"swelling":{"_loc_sr"},
"sweltering":{"_wthr"},
"swept":{"_past"},
"swerved":{"_past"},
"swift":{"_anim"},
"swig":{"_loc_sr"},
"swim":{"_loc_sr"},
"swimming":{"_loc_sr"},
"swinburne":{"_anim","_nme","_prprn","_sb"},
"swindled":{"_past"},
"swine":{"_anim"},
"swing":{"_loc_sr"},
"swinger":{"_anim","_sb"},
"swinging":{"_loc_sr"},
"swiped":{"_past"},
"swirl":{"_loc_sr"},
"swirled":{"_loc_sr","_past"},
"swirling":{"_loc_sr"},
"swish":{"_loc_sr"},
"swished":{"_loc_sr","_past"},
"Swiss":{"_anim","_prprn","_sb"},
"Swiss-German":{"_anim","_prprn","_sb"},
"switch-hit":{"_past"},
"switch-hitter":{"_anim","_sb"},
"switched":{"_past"},
"switchers":{"_anim","_sb"},
"Switzer":{"_prprn"},
"switzerland":{"_cntry","_geo","_prprn"},
"swiveling":{"_loc_sr"},
"swooped":{"_loc_sr","_past"},
"swooping":{"_loc_sr"},
"swoosh":{"_loc_sr"},
"swordfish":{"_anim"},
"swordsman":{"_anim","_masc","_sb"},
"swore":{"_past"},
"swum":{"_loc_sr"},
"swung":{"_loc_sr","_past"},
"Sy":{"_prprn"},
"sybarite":{"_anim","_sb"},
"Sybil":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"sycophants":{"_anim","_sb"},
"Sydney":{"_anim","_cty","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"syllabify":{"_loc_sr"},
"syllabled":{"_loc_sr","_past"},
"syllogist":{"_anim","_sb"},
"syllogizer":{"_anim","_sb"},
"sylvanus":{"_prprn"},
"Sylvester":{"_prprn"},
"Sylvia":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"symboliser":{"_anim","_sb"},
"symbolist":{"_anim","_sb"},
"symbolists":{"_anim","_sb"},
"symbolized":{"_past"},
"symbolizer":{"_anim","_sb"},
"symonds":{"_anim","_nme","_prprn","_sb"},
"Symons":{"_anim","_nme","_prprn","_sb"},
"sympathiser":{"_anim","_sb"},
"sympathized":{"_past"},
"sympathizers":{"_anim","_sb"},
"synagogue":{"_loc_sr"},
"synchronised":{"_past"},
"synchroniser":{"_anim","_sb"},
"syncopator":{"_anim","_sb"},
"syndic":{"_anim","_sb"},
"syndicate":{"_sb"},
"syndicated":{"_loc_sr","_past"},
"syndicates":{"_sb"},
"syndicating":{"_loc_sr"},
"syndicators":{"_anim","_sb"},
"Synge":{"_anim","_nme","_prprn","_sb"},
"synonymist":{"_anim","_sb"},
"synthesised":{"_past"},
"synthesized":{"_past"},
"synthesizers":{"_sb"},
"Syracuse":{"_cty","_geo","_prprn"},
"syria":{"_cntry","_geo","_prprn"},
"Syrian":{"_anim","_prprn","_sb"},
"syrup":{"_loc_sr"},
"systematiser":{"_anim","_sb"},
"systematist":{"_anim","_sb"},
"systematized":{"_past"},
"systemiser":{"_anim","_sb"},
"systemizer":{"_anim","_sb"},
"szechuan":{"_geo","_prprn"},
"szechwan":{"_geo","_prprn"},
"szell":{"_anim","_nme","_prprn","_sb"},
"szilard":{"_anim","_nme","_prprn","_sb"},
"Szold":{"_anim","_nme","_prprn","_sb"},
"T-bill":{"_prprn"},
"T-bond":{"_prprn"},
"T-cell":{"_prprn"},
"T-junction":{"_loc_sr","_prprn"},
"T-man":{"_prprn"},
"T-shirts":{"_prprn"},
"T-square":{"_prprn"},
"taal":{"_geo","_prprn"},
"Tabasco":{"_geo","_prprn","_stte"},
"tabbed":{"_past"},
"tabby":{"_anim"},
"tabled":{"_loc_sr","_past"},
"tabling":{"_loc_sr"},
"tabriz":{"_cty","_geo","_prprn"},
"tabularize":{"_loc_sr"},
"tacitus":{"_anim","_nme","_prprn","_sb"},
"tacked":{"_past"},
"tackled":{"_past"},
"tackler":{"_anim","_sb"},
"Tacoma":{"_cty","_geo","_prprn"},
"tactician":{"_anim","_sb"},
"tacticians":{"_anim","_sb"},
"tad":{"_sb"},
"Tadjik":{"_prprn"},
"tadpole":{"_anim"},
"tadpoles":{"_anim"},
"Tadzhik":{"_anim","_prprn","_sb"},
"Tadzhikistan":{"_cntry","_geo","_prprn"},
"taegu":{"_cty","_geo","_prprn"},
"Taft":{"_anim","_nme","_prprn","_sb"},
"Tagalog":{"_anim","_prprn","_sb"},
"tagged":{"_past"},
"Tagore":{"_anim","_nme","_prprn","_sb"},
"tagus":{"_geo","_prprn"},
"tahiti":{"_geo","_prprn"},
"Tahitian":{"_anim","_prprn","_sb"},
"Tahoe":{"_prprn"},
"Tai":{"_prprn"},
"taichung":{"_cty","_geo","_prprn"},
"tailed":{"_past"},
"tailored":{"_past"},
"tainted":{"_past"},
"taipeh":{"_prprn"},
"Taipei":{"_cty","_geo","_prprn"},
"Taisho":{"_prprn"},
"taiwan":{"_cntry","_geo","_prprn"},
"taiwanese":{"_anim","_prprn","_sb"},
"taiyuan":{"_cty","_geo","_prprn"},
"Tajik":{"_anim","_prprn","_sb"},
"tajiki":{"_prprn"},
"Tajikistan":{"_cntry","_geo","_prprn"},
"Takao":{"_prprn"},
"take":{"_loc_sr"},
"taken":{"_loc_sr"},
"takin":{"_loc_sr"},
"taking":{"_loc_sr"},
"talapoin":{"_anim"},
"Talbot":{"_anim","_nme","_prprn","_sb"},
"talebearer":{"_anim","_sb"},
"tales":{"_anim","_sb"},
"taleteller":{"_anim","_sb"},
"Taliban":{"_prprn"},
"talien":{"_geo","_prprn"},
"Taliesin":{"_prprn"},
"taliped":{"_anim","_sb"},
"talked":{"_past"},
"Tallahassee":{"_cty","_geo","_prprn"},
"tallapoosa":{"_geo","_prprn"},
"tallchief":{"_anim","_nme","_prprn","_sb"},
"Talleyrand":{"_prprn"},
"tallied":{"_past"},
"Tallinn":{"_cty","_geo","_prprn"},
"tallyman":{"_anim","_sb"},
"Talmud":{"_prprn"},
"tamandua":{"_anim"},
"tamarau":{"_anim"},
"tamarin":{"_anim"},
"Tambo":{"_prprn"},
"tamburlaine":{"_anim","_nme","_prprn","_sb"},
"tamed":{"_past"},
"Tamerlane":{"_anim","_nme","_prprn","_sb"},
"Tamil":{"_anim","_prprn","_sb"},
"tamm":{"_anim","_nme","_prprn","_sb"},
"Tammuz":{"_prprn"},
"Tammy":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"tampa":{"_cty","_geo","_prprn"},
"Tampax":{"_prprn"},
"tampere":{"_cty","_geo","_prprn"},
"tampico":{"_cty","_geo","_prprn"},
"tan":{"_loc_sr"},
"Tana":{"_prprn"},
"Tancred":{"_anim","_nme","_prprn","_sb"},
"taney":{"_anim","_nme","_prprn","_sb"},
"Tang":{"_anim","_prprn","_sb"},
"Tanganyika":{"_cntry","_geo","_prprn"},
"tangle":{"_loc_sr"},
"tangled":{"_loc_sr","_past"},
"tangoed":{"_past"},
"tangshan":{"_cty","_geo","_prprn"},
"tanguy":{"_anim","_nme","_prprn","_sb"},
"tank":{"_loc_sr"},
"tanked":{"_loc_sr","_past"},
"tanking":{"_loc_sr"},
"tanks":{"_loc_sr"},
"tanned":{"_loc_sr","_past"},
"tanner":{"_anim","_sb"},
"tanning":{"_loc_sr"},
"tanoan":{"_prprn"},
"tantaliser":{"_anim","_sb"},
"tantalized":{"_past"},
"tantalizer":{"_anim","_sb"},
"tanzania":{"_cntry","_geo","_prprn"},
"Tanzanian":{"_anim","_prprn","_sb"},
"Tao":{"_prprn"},
"Taoism":{"_prprn"},
"taoist":{"_prprn"},
"Taos":{"_cty","_geo","_prprn","_sb"},
"tapered":{"_past"},
"tapestried":{"_past"},
"tappan":{"_anim","_nme","_prprn","_sb"},
"tapped":{"_past"},
"tapster":{"_anim","_sb"},
"Tara":{"_anim","_fem","_fnme","_geo","_nme","_prprn","_sb"},
"tarahumara":{"_anim","_prprn","_sb"},
"Tarantino":{"_prprn"},
"tarawa":{"_geo","_prprn"},
"tarbell":{"_anim","_nme","_prprn","_sb"},
"tardily":{"_tme"},
"tare":{"_anim"},
"targeted":{"_past"},
"tarheel":{"_prprn"},
"Tarkington":{"_anim","_nme","_prprn","_sb"},
"tarnished":{"_past"},
"Tarnopol":{"_prprn"},
"tarred":{"_past"},
"tarry":{"_loc_sr"},
"tartar":{"_anim","_sb"},
"tartarus":{"_prprn"},
"tartu":{"_cty","_geo","_prprn"},
"Tartuffe":{"_anim","_sb"},
"Tarzan":{"_prprn"},
"tashkent":{"_cty","_geo","_prprn"},
"tasman":{"_anim","_nme","_prprn","_sb"},
"tasmania":{"_geo","_prprn","_stte"},
"Tass":{"_prprn"},
"tasseled":{"_past"},
"tasselled":{"_past"},
"Tasso":{"_anim","_nme","_prprn","_sb"},
"tasted":{"_past"},
"Tatar":{"_prprn"},
"tatary":{"_geo","_prprn"},
"Tate":{"_anim","_nme","_prprn","_sb"},
"Tati":{"_prprn"},
"tatterdemalion":{"_anim","_sb"},
"tattered":{"_past"},
"tattoo":{"_loc_sr"},
"Tatum":{"_anim","_nme","_prprn","_sb"},
"taught":{"_past"},
"taunt":{"_loc_sr"},
"taunted":{"_loc_sr","_past"},
"taunting":{"_loc_sr"},
"Taunton":{"_cty","_geo","_prprn"},
"taurus":{"_prprn"},
"Tawney":{"_anim","_nme","_prprn","_sb"},
"taxed":{"_past"},
"taxer":{"_anim","_sb"},
"taxied":{"_loc_sr","_past"},
"taxiing":{"_loc_sr"},
"taxpayer":{"_anim","_sb"},
"taxpayers":{"_anim","_sb"},
"tay":{"_geo","_prprn"},
"tay-sachs":{"_geo","_prprn"},
"taylor":{"_anim","_cty","_fem","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"tayra":{"_anim"},
"TB":{"_prprn"},
"tbilisi":{"_cty","_geo","_prprn"},
"tchaikovsky":{"_anim","_nme","_prprn","_sb"},
"TCP":{"_prprn"},
"te":{"_prprn"},
"teacher":{"_anim","_sb"},
"teachers":{"_anim","_sb"},
"teal":{"_anim"},
"teamed":{"_past"},
"teammate":{"_sb"},
"teammates":{"_sb"},
"teamsters":{"_anim","_sb"},
"tearaway":{"_anim","_sb"},
"teasdale":{"_anim","_nme","_prprn","_sb"},
"teased":{"_past"},
"tebaldi":{"_anim","_nme","_prprn","_sb"},
"tebet":{"_prprn"},
"technicians":{"_anim","_sb"},
"technicolor":{"_prprn"},
"technocrat":{"_anim","_sb"},
"technocrats":{"_anim","_sb"},
"Tecumseh":{"_anim","_nme","_prprn","_sb"},
"tecumtha":{"_prprn"},
"Ted":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"tee":{"_loc_sr"},
"teed":{"_loc_sr","_past"},
"teem":{"_wthr"},
"teemed":{"_past","_wthr"},
"teeming":{"_wthr"},
"teems":{"_wthr"},
"teenager":{"_anim","_sb"},
"teenagers":{"_anim","_sb"},
"teens":{"_tme"},
"teeter":{"_loc_sr"},
"teetered":{"_loc_sr","_past"},
"teetering":{"_loc_sr"},
"teetotaler":{"_anim","_sb"},
"teflon":{"_prprn"},
"teg":{"_anim"},
"tegucigalpa":{"_cty","_geo","_prprn"},
"teheran":{"_prprn"},
"tehran":{"_cty","_geo","_prprn"},
"Tejano":{"_prprn"},
"telecast":{"_loc_sr","_past"},
"telecasting":{"_loc_sr"},
"telecommuting":{"_loc_sr"},
"teleconference":{"_loc_sr"},
"teleconferencing":{"_loc_sr"},
"telecopier":{"_prprn"},
"telegraph":{"_loc_sr"},
"telegraphed":{"_loc_sr","_past"},
"telegraphers":{"_anim","_sb"},
"telegraphing":{"_loc_sr"},
"Telemann":{"_anim","_nme","_prprn","_sb"},
"telemarketers":{"_anim","_sb"},
"telemeter":{"_loc_sr"},
"telepathist":{"_anim","_sb"},
"telephoned":{"_past"},
"telephoner":{"_anim","_sb"},
"Teleprompter":{"_prprn"},
"telescoped":{"_past"},
"telescopium":{"_prprn"},
"televised":{"_past"},
"Telford":{"_geo","_prprn"},
"tell":{"_loc_sr"},
"tell-tale":{"_loc_sr"},
"teller":{"_anim","_sb"},
"tellers":{"_anim","_sb"},
"telling":{"_loc_sr"},
"tells":{"_loc_sr"},
"tellurian":{"_anim","_sb"},
"telugu":{"_anim","_prprn","_sb"},
"temperature":{"_loc_sr"},
"temperatures":{"_loc_sr"},
"tempered":{"_past"},
"temple":{"_loc_sr"},
"temples":{"_loc_sr"},
"temporarily":{"_tme"},
"temporary":{"_anim","_sb"},
"temporiser":{"_anim","_sb"},
"temporized":{"_past"},
"temporizer":{"_anim","_sb"},
"tempted":{"_past","_psych"},
"tempts":{"_psych"},
"temuco":{"_cty","_geo","_prprn"},
"ten":{"_quant"},
"tenant":{"_anim","_sb"},
"tenanted":{"_past"},
"tenants":{"_anim","_sb"},
"tench":{"_anim"},
"tended":{"_past"},
"tender":{"_loc_sr"},
"tendered":{"_loc_sr","_past"},
"tenderfoot":{"_anim","_sb"},
"tendering":{"_loc_sr"},
"tenderised":{"_past"},
"tenderiser":{"_anim","_sb"},
"tenderized":{"_past"},
"tenders":{"_anim","_sb"},
"tenements":{"_loc_sr"},
"Tenerife":{"_geo","_prprn"},
"tenfold":{"_quant"},
"Tenn":{"_prprn","_stte"},
"Tenn.":{"_prprn","_stte"},
"Tennessean":{"_prprn"},
"Tenniel":{"_anim","_nme","_prprn","_sb"},
"tennis":{"_sb"},
"Tennyson":{"_anim","_nme","_prprn","_sb"},
"tenor":{"_anim","_sb"},
"tenorist":{"_anim","_sb"},
"tenors":{"_anim","_sb"},
"tenrec":{"_anim"},
"tens":{"_num","_quant"},
"tensed":{"_past"},
"tenting":{"_loc_sr"},
"tepic":{"_cty","_geo","_prprn"},
"tercel":{"_anim","_masc"},
"Terence":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"teresa":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"tereshkova":{"_anim","_nme","_prprn","_sb"},
"tergiversator":{"_anim","_sb"},
"term":{"_tme"},
"termed":{"_past"},
"terminated":{"_past"},
"termites":{"_anim"},
"terms":{"_tme"},
"tern":{"_anim"},
"terrace":{"_loc_sr"},
"terraces":{"_loc_sr"},
"terrain":{"_loc_sr"},
"terrains":{"_loc_sr"},
"terrestrial":{"_anim","_sb"},
"terrier":{"_anim"},
"terriers":{"_anim"},
"terrified":{"_past","_psych"},
"terrifies":{"_psych"},
"terrify":{"_psych"},
"terrifying":{"_psych"},
"Territorial":{"_anim","_sb"},
"territories":{"_loc_sr"},
"Territory":{"_loc_sr"},
"terrorist":{"_anim","_sb"},
"terrorists":{"_anim","_sb"},
"terrorize":{"_psych"},
"terrorized":{"_past","_psych"},
"terrorizing":{"_psych"},
"Terry":{"_anim","_fem","_fnme","_masc","_nme","_prprn","_sb"},
"tertullian":{"_anim","_nme","_prprn","_sb"},
"Terylene":{"_prprn"},
"tessellate":{"_loc_sr"},
"testatrix":{"_anim","_fem","_sb"},
"tested":{"_past"},
"testers":{"_sb"},
"testified":{"_past"},
"Tet":{"_prprn"},
"Tethys":{"_anim","_fem","_nme","_prprn","_sb"},
"teton":{"_prprn","_sb"},
"Teutonic":{"_prprn"},
"Teutonist":{"_prprn"},
"tevet":{"_prprn"},
"tewkesbury":{"_geo","_prprn"},
"Tex":{"_prprn","_stte"},
"Tex.":{"_prprn","_stte"},
"Texan":{"_anim","_prprn","_sb"},
"texarkana":{"_cty","_geo","_prprn"},
"Texas":{"_geo","_prprn","_stte"},
"textured":{"_past"},
"Thackeray":{"_anim","_nme","_prprn","_sb"},
"Thaddeus":{"_prprn"},
"Thai":{"_anim","_prprn","_sb"},
"thailand":{"_cntry","_geo","_prprn"},
"Thais":{"_anim","_prprn","_sb"},
"Thales":{"_anim","_nme","_prprn","_sb"},
"thames":{"_geo","_prprn"},
"thammuz":{"_prprn"},
"Thanatos":{"_prprn"},
"thanked":{"_past"},
"Thanksgiving":{"_prprn","_tme"},
"Thant":{"_anim","_nme","_prprn","_sb"},
"tharp":{"_anim","_nme","_prprn","_sb"},
"Thatcher":{"_anim","_sb"},
"Thatcherism":{"_prprn"},
"Thatcherite":{"_prprn"},
"thaw":{"_loc_sr","_wthr"},
"thawed":{"_loc_sr","_past","_wthr"},
"thawing":{"_loc_sr","_wthr"},
"Thayer":{"_anim","_nme","_prprn","_sb"},
"the":{"_art"},
"theater":{"_loc_sr"},
"theatergoers":{"_anim","_sb"},
"theaters":{"_loc_sr"},
"theatre":{"_loc_sr"},
"theatres":{"_loc_sr"},
"Theban":{"_prprn"},
"Thebes":{"_cty","_geo","_prprn"},
"Thelma":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Themistocles":{"_anim","_nme","_prprn","_sb"},
"then":{"_tme"},
"thence":{"_tme"},
"thenceforth":{"_tme"},
"Theodore":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Theodosian":{"_prprn"},
"theologians":{"_anim","_sb"},
"theologiser":{"_anim","_sb"},
"theologist":{"_anim","_sb"},
"theologizer":{"_anim","_sb"},
"theoreticians":{"_anim","_sb"},
"theoriser":{"_anim","_sb"},
"theorist":{"_anim","_sb"},
"theorized":{"_past"},
"therapists":{"_anim","_sb"},
"Theravada":{"_prprn"},
"there":{"_loc_sr"},
"thereabout":{"_loc"},
"thereafter":{"_tme"},
"therein":{"_loc"},
"theresa":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"thereunder":{"_loc"},
"thereupon":{"_tme"},
"Thermopylae":{"_geo","_prprn"},
"thermoregulator":{"_anim","_sb"},
"theropod":{"_anim"},
"thespis":{"_anim","_nme","_prprn","_sb"},
"thessalonica":{"_prprn"},
"thessaloniki":{"_cty","_geo","_prprn"},
"thessaly":{"_geo","_prprn"},
"Thetis":{"_anim","_fem","_nme","_prprn","_sb"},
"thickhead":{"_anim","_sb"},
"thief":{"_anim","_sb"},
"thieves":{"_anim","_sb"},
"thimblerig":{"_anim","_sb"},
"think":{"_loc_sr"},
"thinkers":{"_anim","_sb"},
"thinking":{"_loc_sr"},
"thinks":{"_loc_sr"},
"thinned":{"_past"},
"Thiokol":{"_prprn"},
"thirsted":{"_past"},
"thirteen":{"_quant"},
"thirties":{"_num","_quant"},
"thirty":{"_quant"},
"thither":{"_loc"},
"Thomas":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Thomism":{"_prprn"},
"Thompson":{"_anim","_nme","_prprn","_sb"},
"thomson":{"_anim","_nme","_prprn","_sb"},
"thor":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"thoreau":{"_anim","_nme","_prprn","_sb"},
"Thorndike":{"_anim","_nme","_prprn","_sb"},
"Thornton":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"thoroughbred":{"_anim"},
"thoroughbreds":{"_anim"},
"thorpe":{"_anim","_nme","_prprn","_sb"},
"thousand":{"_quant"},
"Thrace":{"_cntry","_geo","_prprn"},
"Thracian":{"_anim","_prprn","_sb"},
"Thraco-Phrygian":{"_prprn"},
"thrall":{"_anim","_sb"},
"thrashed":{"_past"},
"thread":{"_loc_sr"},
"threaded":{"_loc_sr","_past"},
"threading":{"_loc_sr"},
"threatened":{"_past"},
"three":{"_quant"},
"three-D":{"_prprn"},
"three-day":{"_num","_quant"},
"three-door":{"_num","_quant"},
"three-fourths":{"_num","_quant"},
"three-hour":{"_num","_quant"},
"three-mile":{"_num","_quant"},
"three-point":{"_num","_quant"},
"three-quarter":{"_anim","_num","_sb"},
"three-quarters":{"_anim","_num","_sb"},
"three-way":{"_num","_quant"},
"threefold":{"_quant"},
"threes":{"_num","_quant"},
"threescore":{"_num","_quant"},
"threesome":{"_anim","_sb"},
"threshed":{"_past"},
"thresher":{"_sb"},
"threw":{"_loc_sr","_past"},
"thrice":{"_tme"},
"thrill":{"_psych"},
"thrilled":{"_past","_psych"},
"thrilling":{"_psych"},
"throbbed":{"_past"},
"throng":{"_loc_sr"},
"thronged":{"_loc_sr","_past"},
"throngs":{"_anim","_sb"},
"throstle":{"_anim"},
"throttle":{"_loc_sr"},
"throttled":{"_loc_sr","_past"},
"throttler":{"_anim","_sb"},
"throttling":{"_loc_sr"},
"throw":{"_loc_sr"},
"throwing":{"_loc_sr"},
"thrown":{"_loc_sr"},
"thrust":{"_past"},
"thucydides":{"_anim","_nme","_prprn","_sb"},
"thug":{"_anim","_sb"},
"thugs":{"_anim","_sb"},
"thule":{"_cty","_geo","_prprn"},
"thumbed":{"_past"},
"thumped":{"_past"},
"Thun":{"_prprn"},
"thundered":{"_past","_wthr"},
"thundering":{"_wthr"},
"thurber":{"_anim","_nme","_prprn","_sb"},
"thuringia":{"_geo","_prprn"},
"thursday":{"_day","_prprn","_tme"},
"Thursdays":{"_day","_prprn","_tme"},
"thwarted":{"_past"},
"thwarter":{"_anim","_sb"},
"Ti":{"_prprn"},
"Tianjin":{"_cty","_geo","_prprn"},
"tiber":{"_geo","_prprn"},
"Tiberius":{"_anim","_nme","_prprn","_sb"},
"Tibet":{"_cntry","_geo","_prprn"},
"Tibetan":{"_anim","_prprn","_sb"},
"Tibetans":{"_anim","_prprn","_sb"},
"ticked":{"_past"},
"tickled":{"_past"},
"ticks":{"_anim"},
"Ticonderoga":{"_geo","_prprn"},
"tide":{"_loc_sr"},
"tidelands":{"_loc_sr"},
"tides":{"_loc_sr"},
"tideway":{"_loc_sr"},
"tidied":{"_loc_sr","_past"},
"tidy":{"_loc_sr"},
"tidying":{"_loc_sr"},
"Tieck":{"_anim","_nme","_prprn","_sb"},
"tied":{"_past"},
"Tientsin":{"_geo","_prprn"},
"Tiepolo":{"_anim","_nme","_prprn","_sb"},
"tier":{"_loc_sr"},
"tiered":{"_loc_sr","_past"},
"tiering":{"_loc_sr"},
"Tiflis":{"_geo","_prprn"},
"tiger":{"_anim"},
"tigers":{"_anim"},
"tightened":{"_past"},
"tightener":{"_anim","_sb"},
"tightwad":{"_anim","_sb"},
"tiglon":{"_anim"},
"Tigris":{"_geo","_prprn"},
"Tijuana":{"_cty","_geo","_prprn"},
"tike":{"_anim","_sb"},
"Tilden":{"_anim","_nme","_prprn","_sb"},
"tiled":{"_past"},
"tillage":{"_loc_sr"},
"tilled":{"_past"},
"tiller":{"_loc_sr"},
"Tillich":{"_anim","_nme","_prprn","_sb"},
"Tilly":{"_anim","_nme","_prprn","_sb"},
"tilted":{"_past"},
"Tim":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"timber":{"_loc_sr"},
"Timberlake":{"_prprn"},
"timberlands":{"_loc_sr"},
"timbers":{"_loc_sr"},
"timbuktu":{"_cty","_geo","_prprn"},
"time":{"_tme"},
"time-fuse":{"_tme"},
"time-poor":{"_tme"},
"time-switch":{"_tme"},
"time-table":{"_tme"},
"time-zone":{"_tme"},
"timed":{"_past"},
"timers":{"_anim","_sb"},
"times":{"_tme"},
"timeserver":{"_anim","_sb"},
"timor":{"_geo","_prprn"},
"Timorese":{"_anim","_prprn","_sb"},
"Timothy":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Timur":{"_prprn"},
"Tina":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"tinbergen":{"_anim","_nme","_prprn","_sb"},
"tindal":{"_anim","_nme","_prprn","_sb"},
"tindale":{"_prprn"},
"tinged":{"_past"},
"tinkled":{"_past"},
"tinned":{"_past"},
"tinner":{"_anim","_sb"},
"Tinseltown":{"_prprn"},
"tinted":{"_loc_sr","_past"},
"tinting":{"_loc_sr"},
"Tintoretto":{"_anim","_nme","_prprn","_sb"},
"Tippecanoe":{"_geo","_prprn"},
"tipped":{"_past"},
"Tipperary":{"_cty","_geo","_prprn"},
"Tippett":{"_prprn"},
"tipple":{"_loc_sr"},
"tippling":{"_loc_sr"},
"tipstaff":{"_anim","_sb"},
"tipsters":{"_anim","_sb"},
"tiptoe":{"_loc_sr"},
"tiptoed":{"_loc_sr","_past"},
"tiptoeing":{"_loc_sr"},
"Tirana":{"_prprn"},
"tire":{"_psych"},
"tired":{"_past","_psych"},
"Tiresias":{"_prprn"},
"tiring":{"_psych"},
"tiro":{"_anim","_sb"},
"Tirol":{"_geo","_prprn"},
"tishri":{"_prprn"},
"tisiphone":{"_prprn"},
"titaness":{"_prprn"},
"Titania":{"_anim","_fem","_nme","_prprn","_sb"},
"Titanic":{"_prprn"},
"Titian":{"_anim","_prprn","_sb"},
"titillate":{"_psych"},
"titillated":{"_past","_psych"},
"titillating":{"_psych"},
"titled":{"_past"},
"tito":{"_anim","_nme","_prprn","_sb"},
"titrator":{"_anim","_sb"},
"titterer":{"_anim","_sb"},
"tittering":{"_loc_sr"},
"titters":{"_loc_sr"},
"tittup":{"_loc_sr"},
"titular":{"_anim","_sb"},
"titus":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Tivoli":{"_cty","_geo","_prprn"},
"Tizard":{"_prprn"},
"tko":{"_prprn"},
"tlc":{"_prprn"},
"Tlingit":{"_anim","_prprn","_sb"},
"TM":{"_prprn"},
"TMV":{"_prprn"},
"tn":{"_prprn","_stte"},
"TNF":{"_prprn"},
"toad":{"_anim"},
"toadies":{"_anim","_sb"},
"toasted":{"_past"},
"Tobago":{"_geo","_prprn"},
"Tobagonian":{"_anim","_prprn","_sb"},
"Tobey":{"_anim","_nme","_prprn","_sb"},
"Tobias":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Tobin":{"_anim","_nme","_prprn","_sb"},
"Tobit":{"_prprn"},
"toboggan":{"_loc_sr"},
"tobogganing":{"_loc_sr"},
"tobogganist":{"_anim","_sb"},
"Tobruk":{"_prprn"},
"Tocantins":{"_geo","_prprn"},
"tocharian":{"_anim","_prprn","_sb"},
"tocqueville":{"_anim","_nme","_prprn","_sb"},
"today":{"_tme"},
"Todd":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"toddle":{"_loc_sr"},
"toddler":{"_anim","_sb"},
"toed":{"_past"},
"toeholds":{"_loc_sr"},
"Togo":{"_cntry","_geo","_prprn"},
"Togolese":{"_anim","_prprn","_sb"},
"toiled":{"_past"},
"Tojo":{"_prprn"},
"tokay":{"_prprn"},
"toke":{"_loc_sr"},
"tokyo":{"_cty","_geo","_prprn"},
"tolbukhin":{"_cty","_geo","_prprn"},
"Toledo":{"_cty","_geo","_prprn"},
"tolerated":{"_past"},
"Tolkien":{"_anim","_nme","_prprn","_sb"},
"tolled":{"_past"},
"toller":{"_anim","_sb"},
"Tolstoy":{"_anim","_nme","_prprn","_sb"},
"toltec":{"_anim","_prprn","_sb"},
"Tom":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"tomb":{"_loc_sr"},
"tombaugh":{"_anim","_nme","_prprn","_sb"},
"Tombigbee":{"_geo","_prprn"},
"tomboy":{"_anim","_fem","_sb"},
"tombs":{"_loc_sr"},
"Tommy":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"tomorrow":{"_tme"},
"tomtit":{"_anim"},
"ton":{"_quant"},
"toned":{"_past"},
"Tonga":{"_cntry","_geo","_prprn"},
"Tongan":{"_anim","_prprn","_sb"},
"tongue-tied":{"_past"},
"tonguefish":{"_anim"},
"tonight":{"_tme"},
"Tonkin":{"_geo","_prprn"},
"tonnages":{"_loc_sr"},
"tons":{"_quant"},
"Tony":{"_anim","_fem","_fnme","_masc","_nme","_prprn","_sb"},
"Tonya":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Tooke":{"_anim","_nme","_prprn","_sb"},
"toot":{"_loc_sr"},
"tooted":{"_loc_sr","_past"},
"toothed":{"_past"},
"topeka":{"_cty","_geo","_prprn"},
"topped":{"_past"},
"tor":{"_loc_sr"},
"Torah":{"_prprn"},
"torchbearer":{"_anim","_sb"},
"torched":{"_past"},
"tore":{"_past"},
"toreador":{"_anim","_sb"},
"Tories":{"_prprn","_sb"},
"Torino":{"_geo","_prprn"},
"tormented":{"_past"},
"tormentors":{"_anim","_sb"},
"toronto":{"_cty","_geo","_prprn"},
"torpedoed":{"_past"},
"Torquemada":{"_anim","_nme","_prprn","_sb"},
"torquer":{"_anim","_sb"},
"torquers":{"_anim","_sb"},
"Torrance":{"_cty","_geo","_prprn"},
"torrent":{"_loc_sr"},
"torrents":{"_loc_sr"},
"torreon":{"_cty","_geo","_prprn"},
"torricelli":{"_anim","_nme","_prprn","_sb"},
"tortoise":{"_anim"},
"tortoises":{"_anim"},
"Tortola":{"_geo","_prprn"},
"tortured":{"_past","_psych"},
"torturing":{"_psych"},
"Tory":{"_prprn","_sb"},
"toscanini":{"_anim","_nme","_prprn","_sb"},
"tossed":{"_past"},
"tossers":{"_anim","_sb"},
"tot":{"_anim","_sb"},
"totaled":{"_past"},
"totaliser":{"_anim","_sb"},
"totalled":{"_past"},
"toted":{"_past"},
"totterer":{"_anim","_sb"},
"tottering":{"_loc_sr"},
"toucan":{"_anim"},
"touch-type":{"_loc_sr"},
"touching":{"_psych"},
"toughened":{"_past"},
"toughs":{"_anim","_sb"},
"toulon":{"_cty","_geo","_prprn"},
"toulouse":{"_cty","_geo","_prprn"},
"toulouse-lautrec":{"_anim","_nme","_prprn","_sb"},
"toured":{"_loc_sr","_past"},
"touring":{"_loc_sr"},
"tourist":{"_anim","_sb"},
"tourists":{"_anim","_sb"},
"tourney":{"_loc_sr"},
"tousled":{"_past"},
"touted":{"_past"},
"touter":{"_anim","_sb"},
"towed":{"_past"},
"tower":{"_loc_sr"},
"towers":{"_loc_sr"},
"town":{"_loc_sr"},
"Townes":{"_anim","_nme","_prprn","_sb"},
"towns":{"_loc_sr"},
"townsend":{"_anim","_nme","_prprn","_sb"},
"townsfolk":{"_anim","_sb"},
"township":{"_loc_sr"},
"townships":{"_loc_sr"},
"townsmen":{"_anim","_masc","_sb"},
"townspeople":{"_sb"},
"toxicologists":{"_anim","_sb"},
"Toynbee":{"_anim","_nme","_prprn","_sb"},
"toyohashi":{"_cty","_geo","_prprn"},
"toyota":{"_cty","_geo","_prprn"},
"traced":{"_past"},
"tracers":{"_anim","_sb"},
"tracked":{"_past"},
"tract":{"_loc_sr"},
"Tractarianism":{"_prprn"},
"tracts":{"_loc_sr"},
"Tracy":{"_anim","_cty","_fem","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"traded":{"_loc_sr","_past"},
"trademarked":{"_past"},
"traders":{"_anim","_sb"},
"Tradescant":{"_prprn"},
"tradesmen":{"_anim","_masc","_sb"},
"tradespeople":{"_sb"},
"trading":{"_loc_sr"},
"traditionalized":{"_past"},
"traduced":{"_past"},
"Trafalgar":{"_prprn"},
"trafficked":{"_loc_sr","_past"},
"traffickers":{"_anim","_sb"},
"trailed":{"_past"},
"train":{"_fem"},
"trainbearer":{"_anim","_sb"},
"trained":{"_loc_sr","_past"},
"trainees":{"_anim","_sb"},
"trainer":{"_anim","_sb"},
"trainers":{"_anim","_sb"},
"training":{"_loc_sr"},
"trains":{"_fem"},
"traipsing":{"_loc_sr"},
"traitors":{"_anim","_sb"},
"traitress":{"_anim","_fem","_sb"},
"trajan":{"_anim","_nme","_prprn","_sb"},
"tramontane":{"_anim","_sb"},
"tramp":{"_loc_sr"},
"tramped":{"_loc_sr","_past"},
"tramper":{"_anim","_sb"},
"trampler":{"_anim","_sb"},
"tramps":{"_anim","_sb"},
"transact":{"_loc_sr"},
"transacted":{"_loc_sr","_past"},
"transcaucasia":{"_geo","_prprn"},
"transcended":{"_loc_sr","_past"},
"transcending":{"_loc_sr"},
"transcribed":{"_past"},
"transfer":{"_loc_sr"},
"transferors":{"_anim","_sb"},
"transferrer":{"_anim","_sb"},
"transferring":{"_loc_sr"},
"transfers":{"_anim","_sb"},
"transfix":{"_psych"},
"transfixed":{"_past","_psych"},
"transfixing":{"_psych"},
"transform":{"_loc_sr"},
"transforming":{"_loc_sr"},
"transforms":{"_loc_sr"},
"transfuse":{"_loc_sr"},
"transfused":{"_loc_sr","_past"},
"transgress":{"_loc_sr"},
"transgressed":{"_loc_sr","_past"},
"transient":{"_anim","_sb"},
"transients":{"_anim","_sb"},
"transistorised":{"_past"},
"Transkei":{"_cntry","_geo","_prprn"},
"translates":{"_loc_sr"},
"translators":{"_anim","_sb"},
"transmit":{"_loc_sr"},
"transmits":{"_loc_sr"},
"transmitted":{"_loc_sr","_past"},
"transmitters":{"_sb"},
"transmitting":{"_loc_sr"},
"transmogrified":{"_loc_sr","_past"},
"transmogrify":{"_loc_sr"},
"transmute":{"_loc_sr"},
"transmuted":{"_loc_sr","_past"},
"transpire":{"_loc_sr"},
"transpiring":{"_loc_sr"},
"transplanted":{"_loc_sr","_past"},
"transplanting":{"_loc_sr"},
"transported":{"_loc_sr","_past"},
"transporting":{"_loc_sr"},
"transposed":{"_past"},
"transude":{"_loc_sr"},
"transvaal":{"_geo","_prprn"},
"transvestite":{"_anim","_sb"},
"transvestites":{"_anim","_sb"},
"transylvania":{"_geo","_prprn"},
"trapped":{"_past"},
"Trappist":{"_prprn","_sb"},
"trapshooter":{"_anim","_sb"},
"Trasimeno":{"_prprn"},
"traumatized":{"_past"},
"Travancore":{"_prprn"},
"travel":{"_loc_sr"},
"traveled":{"_loc_sr","_past"},
"traveler":{"_anim","_sb"},
"travelers":{"_anim","_sb"},
"traveling":{"_loc_sr"},
"travelled":{"_loc_sr","_past"},
"traveller":{"_anim","_sb"},
"travellers":{"_anim","_sb"},
"travelling":{"_loc_sr"},
"traverse":{"_loc_sr"},
"traversed":{"_loc_sr","_past"},
"traverser":{"_anim","_sb"},
"traversing":{"_loc_sr"},
"tread":{"_loc_sr"},
"treading":{"_loc_sr"},
"treads":{"_loc_sr"},
"treasured":{"_past"},
"treasurer":{"_anim","_sb"},
"treasurers":{"_anim","_sb"},
"treasuries":{"_loc_sr"},
"treasury":{"_loc_sr"},
"treated":{"_past"},
"trebled":{"_past"},
"treed":{"_past"},
"trekked":{"_past"},
"trembled":{"_past"},
"Trenchard":{"_prprn"},
"trenchermen":{"_anim","_sb"},
"trended":{"_loc_sr","_past"},
"trending":{"_loc_sr"},
"trendsetter":{"_anim","_sb"},
"trendy":{"_anim","_sb"},
"trent":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"Trento":{"_geo","_prprn"},
"trenton":{"_cty","_geo","_prprn"},
"trespass":{"_loc_sr"},
"trespassed":{"_loc_sr","_past"},
"trespassing":{"_loc_sr"},
"trevelyan":{"_anim","_nme","_prprn","_sb"},
"Trevino":{"_anim","_nme","_prprn","_sb"},
"Trevithick":{"_anim","_nme","_prprn","_sb"},
"Triad":{"_sb"},
"triangulate":{"_loc_sr"},
"Triangulum":{"_prprn"},
"Triassic":{"_prprn"},
"tribal":{"_anim","_sb"},
"tribe":{"_anim","_sb"},
"TriBeCa":{"_prprn"},
"tribes":{"_anim","_sb"},
"tribesmen":{"_anim","_masc","_sb"},
"tribologist":{"_anim","_sb"},
"tricked":{"_past"},
"trickled":{"_past"},
"tried":{"_past"},
"trifled":{"_past"},
"trifler":{"_anim","_sb"},
"trig":{"_loc_sr"},
"triggered":{"_past"},
"trigonometrician":{"_anim","_sb"},
"trilingual":{"_anim","_sb"},
"trilled":{"_past"},
"trillion":{"_num","_quant"},
"trillions":{"_num","_quant"},
"trilobite":{"_anim"},
"trimesters":{"_tme"},
"trimmed":{"_past"},
"trimmer":{"_sb"},
"trimurti":{"_anim","_prprn","_sb"},
"Trinidadian":{"_anim","_prprn","_sb"},
"Trinitarian":{"_anim","_prprn","_sb"},
"Trinity":{"_prprn"},
"trio":{"_anim","_sb"},
"tripled":{"_past"},
"triplet":{"_anim","_sb"},
"triplets":{"_anim","_sb"},
"Tripoli":{"_cty","_geo","_prprn"},
"trisect":{"_loc_sr"},
"tristan":{"_prprn"},
"tristram":{"_prprn"},
"Triton":{"_anim","_masc","_prprn","_sb"},
"triumphed":{"_past"},
"triumvir":{"_anim","_sb"},
"tRNA":{"_prprn"},
"trod":{"_loc_sr","_past"},
"trodden":{"_loc_sr"},
"troglodytes":{"_anim","_sb"},
"Trojan":{"_anim","_prprn","_sb"},
"Trollope":{"_anim","_nme","_prprn","_sb"},
"trolls":{"_anim","_sb"},
"trombonist":{"_anim","_sb"},
"trondheim":{"_cty","_geo","_prprn"},
"troop":{"_sb"},
"trooper":{"_anim","_sb"},
"troopers":{"_anim","_sb"},
"trooping":{"_loc_sr"},
"troops":{"_sb"},
"tropics":{"_loc_sr"},
"trot":{"_loc_sr"},
"Trotsky":{"_anim","_nme","_prprn","_sb"},
"Trotskyism":{"_prprn"},
"Trotskyist":{"_anim","_prprn","_sb"},
"trotted":{"_loc_sr","_past"},
"troubadour":{"_anim","_sb"},
"trouble-shooter":{"_anim","_sb"},
"troubled":{"_past","_psych"},
"troublemakers":{"_anim","_sb"},
"troubling":{"_psych"},
"trouper":{"_anim","_sb"},
"troupes":{"_anim","_sb"},
"trout":{"_anim"},
"Troy":{"_cty","_geo","_prprn"},
"Troyes":{"_cty","_geo","_prprn"},
"truck":{"_fem"},
"trucked":{"_past"},
"trucker":{"_anim","_sb"},
"truckers":{"_anim","_sb"},
"truckler":{"_anim","_sb"},
"trucks":{"_fem"},
"Trudeau":{"_anim","_nme","_prprn","_sb"},
"trudged":{"_loc_sr","_past"},
"trudger":{"_anim","_sb"},
"trudging":{"_loc_sr"},
"truffaut":{"_anim","_nme","_prprn","_sb"},
"Trujillo":{"_cty","_geo","_prprn"},
"Truman":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"trumbo":{"_anim","_nme","_prprn","_sb"},
"trumbull":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"trumped-up":{"_past"},
"trumpeted":{"_past"},
"trumpeter":{"_anim","_sb"},
"trundled":{"_loc_sr","_past"},
"trundling":{"_loc_sr"},
"trunkfish":{"_anim","_loc_sr"},
"trussed":{"_past"},
"trusted":{"_loc_sr","_past"},
"trustee":{"_anim","_sb"},
"trustees":{"_anim","_sb"},
"trusteth":{"_loc_sr"},
"trusting":{"_loc_sr"},
"trustor":{"_anim","_sb"},
"trusty":{"_anim","_sb"},
"tsarist":{"_anim","_sb"},
"tshiluba":{"_prprn"},
"Tshombe":{"_prprn"},
"tsimshian":{"_anim","_prprn","_sb"},
"tsushima":{"_geo","_prprn"},
"tswana":{"_anim","_prprn","_sb"},
"Tu":{"_prprn"},
"tuareg":{"_anim","_prprn","_sb"},
"tuatara":{"_sb"},
"tub":{"_loc_sr"},
"tub-cart":{"_loc_sr"},
"tubed":{"_past"},
"tubercular":{"_anim","_sb"},
"tubman":{"_anim","_nme","_prprn","_sb"},
"tubs":{"_loc_sr"},
"tucana":{"_prprn"},
"Tuck":{"_loc_sr"},
"tucked":{"_loc_sr","_past"},
"tucson":{"_cty","_geo","_prprn"},
"tudor":{"_anim","_nme","_prprn","_sb"},
"Tue":{"_day","_prprn","_tme"},
"tuesday":{"_day","_prprn","_tme"},
"Tuesdays":{"_day","_prprn","_tme"},
"tufted":{"_past"},
"Tuileries":{"_prprn"},
"tulsa":{"_cty","_geo","_prprn"},
"tumbled":{"_past"},
"tuna":{"_anim"},
"tune":{"_loc_sr"},
"tuned":{"_loc_sr","_past"},
"tung":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Tungus":{"_prprn"},
"tungusic":{"_prprn"},
"tunguska":{"_geo","_prprn"},
"tunic":{"_sb"},
"tuning":{"_loc_sr"},
"tunis":{"_cty","_geo","_prprn","_stte"},
"Tunisia":{"_cntry","_geo","_prprn"},
"Tunisian":{"_anim","_prprn","_sb"},
"tunneled":{"_past"},
"Tunney":{"_anim","_nme","_prprn","_sb"},
"tunny":{"_anim"},
"tupi":{"_prprn","_sb"},
"tupi-guarani":{"_prprn"},
"Tupolev":{"_prprn"},
"Tupperware":{"_prprn"},
"tupungato":{"_geo","_prprn"},
"Turcoman":{"_prprn"},
"Turgenev":{"_anim","_nme","_prprn","_sb"},
"turgot":{"_anim","_nme","_prprn","_sb"},
"turin":{"_cty","_geo","_prprn"},
"Turk":{"_anim","_prprn","_sb"},
"Turkestan":{"_geo","_prprn"},
"turkey":{"_anim"},
"turkeys":{"_anim"},
"Turki":{"_prprn"},
"Turkic":{"_prprn"},
"turkish":{"_prprn"},
"Turkistan":{"_geo","_prprn"},
"Turkmen":{"_anim","_prprn","_sb"},
"Turkmenia":{"_prprn"},
"Turkmenistan":{"_cntry","_geo","_prprn"},
"Turkoman":{"_prprn"},
"Turks":{"_anim","_prprn","_sb"},
"turn-of-the-century":{"_tme"},
"turn-out":{"_tme"},
"turnaround":{"_loc_sr"},
"turnarounds":{"_loc_sr"},
"Turnbull":{"_prprn"},
"turned":{"_loc_sr","_past"},
"Turner":{"_anim","_prprn","_sb"},
"turnings":{"_loc_sr"},
"turnkey":{"_anim","_sb"},
"turnouts":{"_sb"},
"turns":{"_tme"},
"Turpin":{"_prprn"},
"turtle":{"_anim"},
"turtle-neck":{"_anim"},
"turtledove":{"_anim"},
"turtler":{"_anim","_sb"},
"turtles":{"_anim"},
"tuscaloosa":{"_cty","_geo","_prprn"},
"Tuscan":{"_anim","_prprn","_sb"},
"Tuscany":{"_geo","_prprn","_stte"},
"Tuscarora":{"_anim","_prprn","_sb"},
"tusked":{"_past"},
"tussled":{"_past"},
"Tutankhamen":{"_anim","_nme","_prprn","_sb"},
"tutors":{"_anim","_sb"},
"Tutsi":{"_prprn"},
"Tutu":{"_anim","_prprn","_sb"},
"Tuvalu":{"_cntry","_geo","_prprn"},
"TVs":{"_prprn"},
"twaddler":{"_anim","_sb"},
"Twain":{"_quant"},
"twat":{"_anim","_sb"},
"tweaked":{"_past"},
"tweezed":{"_past"},
"Twelfthtide":{"_prprn"},
"twelve":{"_quant"},
"twelvefold":{"_quant"},
"twenties":{"_num","_quant"},
"twenty-one":{"_num","_quant"},
"twerp":{"_anim","_sb"},
"twiddle":{"_loc_sr"},
"twiddled":{"_loc_sr","_past"},
"twiddler":{"_anim","_sb"},
"twiddling":{"_loc_sr"},
"twigged":{"_past"},
"twilight":{"_tme"},
"twin":{"_anim","_sb"},
"twin-engined":{"_anim","_sb"},
"twined":{"_past"},
"twirling":{"_loc_sr"},
"twisted":{"_past"},
"twister":{"_anim","_sb"},
"twitch":{"_loc_sr"},
"twitching":{"_loc_sr"},
"twittered":{"_past"},
"two":{"_quant"},
"two-a-penny":{"_num","_quant"},
"two-and-a-half":{"_num","_quant"},
"two-base":{"_num","_quant"},
"two-door":{"_num","_quant"},
"two-footed":{"_quant"},
"two-line":{"_num","_quant"},
"two-man":{"_num","_quant"},
"two-stroke":{"_num","_quant"},
"two-thirds":{"_num","_quant"},
"two-tier":{"_num","_quant"},
"two-timed":{"_past"},
"two-timer":{"_anim","_sb"},
"twos":{"_num","_quant"},
"twosome":{"_sb"},
"Tyburn":{"_prprn"},
"tycoons":{"_anim","_sb"},
"tylenol":{"_prprn"},
"tyler":{"_anim","_cty","_fem","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"Tyndale":{"_anim","_nme","_prprn","_sb"},
"Tyndall":{"_anim","_nme","_prprn","_sb"},
"tyne":{"_geo","_prprn"},
"type":{"_sb"},
"typecasting":{"_loc_sr"},
"types":{"_sb"},
"typeset":{"_loc_sr","_past"},
"typesetters":{"_anim","_sb"},
"typesetting":{"_loc_sr"},
"typewritten":{"_loc_sr"},
"Typhoeus":{"_prprn"},
"Typhon":{"_prprn"},
"typified":{"_loc_sr","_past"},
"typifies":{"_loc_sr"},
"typify":{"_loc_sr"},
"typifying":{"_loc_sr"},
"typist":{"_anim","_sb"},
"typists":{"_anim","_sb"},
"Tyr":{"_anim","_masc","_nme","_prprn","_sb"},
"tyrannosaurus":{"_anim"},
"tyrant":{"_anim","_sb"},
"tyrants":{"_anim","_sb"},
"Tyrol":{"_geo","_prprn"},
"Tyrolean":{"_prprn"},
"Tyrone":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"tzarina":{"_anim","_fem","_sb"},
"tzarist":{"_anim","_sb"},
"U-boat":{"_prprn"},
"U.S.A.":{"_cntry","_prprn"},
"Udall":{"_prprn"},
"ufa":{"_cty","_geo","_prprn"},
"UFO":{"_prprn"},
"UFOs":{"_prprn"},
"Uganda":{"_cntry","_geo","_prprn"},
"Ugandan":{"_anim","_prprn","_sb"},
"ugaritic":{"_prprn"},
"ugli":{"_prprn"},
"ugly":{"_anim","_sb"},
"ugrian":{"_prprn","_sb"},
"ugric":{"_prprn"},
"uhland":{"_anim","_nme","_prprn","_sb"},
"uighur":{"_anim","_prprn","_sb"},
"uigur":{"_anim","_prprn","_sb"},
"UK":{"_cntry","_geo","_prprn"},
"Ukraine":{"_cntry","_geo","_prprn"},
"Ukrainian":{"_anim","_prprn","_sb"},
"Ulaanbaatar":{"_cty","_geo","_prprn"},
"ulanova":{"_anim","_nme","_prprn","_sb"},
"Ulbricht":{"_anim","_nme","_prprn","_sb"},
"ulcer":{"_loc_sr"},
"ulcerated":{"_past"},
"ulcers":{"_loc_sr"},
"Ulster":{"_cntry","_geo","_prprn"},
"ultramontane":{"_anim","_sb"},
"Ulysses":{"_prprn"},
"umpires":{"_anim","_sb"},
"umpteen":{"_num","_quant"},
"un":{"_prprn"},
"Una":{"_prprn"},
"unabused":{"_past"},
"unaccounted":{"_past"},
"unachieved":{"_past"},
"unaddicted":{"_past"},
"unaerated":{"_loc_sr","_past"},
"unaffixed":{"_past"},
"unai":{"_anim"},
"unamended":{"_past"},
"unamortized":{"_past"},
"unamused":{"_past","_psych"},
"unamusing":{"_psych"},
"unannealed":{"_past"},
"unanswered":{"_past"},
"unappareled":{"_loc_sr","_past"},
"unarmed":{"_past"},
"unarmoured":{"_past"},
"unassigned":{"_past"},
"unassured":{"_past"},
"unattired":{"_loc_sr","_past"},
"unau":{"_anim"},
"unauthorized":{"_past"},
"unawakened":{"_past"},
"unbaffled":{"_past","_psych"},
"unbalanced":{"_past"},
"unbanded":{"_loc_sr","_past"},
"unbaptised":{"_past"},
"unbarred":{"_past"},
"unbending":{"_loc_sr"},
"unbeneficed":{"_past"},
"unbent":{"_loc_sr","_past"},
"unbitter":{"_anim","_sb"},
"unbolted":{"_past"},
"unbooked":{"_past"},
"unbound":{"_past"},
"unbox":{"_loc_sr"},
"unbraced":{"_past"},
"unbraid":{"_loc_sr"},
"unbrainwashed":{"_past"},
"unbranching":{"_loc_sr"},
"unbridle":{"_loc_sr"},
"unbundle":{"_loc_sr","_sb"},
"unbundled":{"_loc_sr","_past","_sb"},
"unburden":{"_loc_sr"},
"unburdened":{"_loc_sr","_past"},
"unburned":{"_past"},
"unburnished":{"_past"},
"unbuttoned":{"_past"},
"uncalled":{"_loc_sr","_past"},
"uncamphorated":{"_past"},
"uncapped":{"_past"},
"uncataloged":{"_past"},
"unchallenged":{"_past"},
"unchanged":{"_past"},
"unchlorinated":{"_past"},
"uncial":{"_prprn"},
"uncivilised":{"_past"},
"uncle":{"_anim","_masc","_sb"},
"unclenched":{"_loc_sr","_past"},
"uncles":{"_anim","_masc","_sb"},
"unclipped":{"_past"},
"unclogged":{"_past"},
"unclothed":{"_past"},
"uncoached":{"_past"},
"uncoiled":{"_past"},
"uncollaborated":{"_loc_sr","_past"},
"uncombined":{"_loc_sr","_past"},
"uncomforted":{"_past","_psych"},
"uncommercialised":{"_past"},
"uncomprehended":{"_loc_sr","_past"},
"unconcealed":{"_past"},
"unconfessed":{"_past"},
"unconfined":{"_past"},
"unconfirmed":{"_past"},
"unconfused":{"_past","_psych"},
"unconquered":{"_past"},
"unconstipated":{"_past"},
"unconstrained":{"_past"},
"unconsumed":{"_past"},
"unconsummated":{"_past"},
"unconvinced":{"_past"},
"uncorked":{"_past"},
"uncorrelated":{"_loc_sr","_past"},
"uncorrupted":{"_past"},
"uncouple":{"_loc_sr"},
"uncovered":{"_past"},
"uncrate":{"_loc_sr"},
"uncross":{"_loc_sr"},
"uncrystallised":{"_past"},
"uncurled":{"_past"},
"uncurved":{"_loc_sr","_past"},
"undeceive":{"_loc_sr"},
"undeceived":{"_loc_sr","_past"},
"undecomposed":{"_loc_sr","_past"},
"undedicated":{"_past"},
"undefeated":{"_loc_sr","_past"},
"undefended":{"_past"},
"undefiled":{"_past"},
"undefined":{"_past"},
"undepicted":{"_loc_sr","_past"},
"under":{"_loc"},
"under-secretary":{"_anim","_sb"},
"underachiever":{"_anim","_sb"},
"underachievers":{"_anim","_sb"},
"underact":{"_loc_sr"},
"underappreciated":{"_past"},
"underbid":{"_past"},
"undercapitalized":{"_past"},
"undercoated":{"_past"},
"undercut":{"_past"},
"underdevelop":{"_loc_sr"},
"underdog":{"_sb"},
"underdogs":{"_sb"},
"underdressed":{"_past"},
"underemployed":{"_sb"},
"underestimated":{"_past"},
"underfed":{"_past"},
"underfoot":{"_loc"},
"underfunded":{"_past"},
"undergirded":{"_past"},
"undergo":{"_loc_sr"},
"undergoes":{"_loc_sr"},
"undergoing":{"_loc_sr"},
"undergone":{"_loc_sr"},
"undergraduates":{"_anim","_sb"},
"undergrow":{"_loc_sr"},
"underinvestigated":{"_loc_sr","_past"},
"underived":{"_loc_sr","_past"},
"underlay":{"_past"},
"underlined":{"_past"},
"underling":{"_anim","_sb"},
"underlings":{"_anim","_sb"},
"undermined":{"_past"},
"undernourished":{"_past"},
"underpaid":{"_past"},
"underperformed":{"_past"},
"underperformer":{"_anim","_sb"},
"underperformers":{"_anim","_sb"},
"underpinned":{"_past"},
"underplay":{"_loc_sr"},
"underplayed":{"_loc_sr","_past"},
"underprepared":{"_loc_sr","_past"},
"underpriced":{"_past"},
"underrate":{"_loc_sr"},
"underrated":{"_loc_sr","_past"},
"underreported":{"_past"},
"underscored":{"_past"},
"undersealed":{"_past"},
"undersecretary":{"_anim","_sb"},
"underseller":{"_anim","_sb"},
"underserved":{"_past"},
"undersold":{"_past"},
"understaffed":{"_past"},
"understated":{"_past"},
"understood":{"_past"},
"understudied":{"_past"},
"undertake":{"_loc_sr"},
"undertaken":{"_loc_sr"},
"undertaker":{"_anim","_sb"},
"undertakes":{"_loc_sr"},
"undertaking":{"_loc_sr"},
"undertook":{"_loc_sr","_past"},
"underused":{"_loc_sr","_past"},
"underutilized":{"_past"},
"undervalued":{"_past"},
"underwent":{"_loc_sr","_past"},
"Underwood":{"_anim","_prprn","_sb"},
"underworld":{"_loc_sr"},
"underwriter":{"_anim","_sb"},
"underwrote":{"_past"},
"undescended":{"_loc_sr","_past"},
"undesirable":{"_anim","_sb"},
"undesired":{"_past"},
"undetected":{"_past"},
"undiagnosed":{"_past"},
"undid":{"_past"},
"undifferentiated":{"_past"},
"undigested":{"_loc_sr","_past"},
"undiluted":{"_past"},
"undiminished":{"_past"},
"undimmed":{"_past"},
"undine":{"_anim","_fem"},
"undisciplined":{"_past"},
"undisclosed":{"_past"},
"undiscovered":{"_loc_sr","_past"},
"undisguised":{"_past"},
"undismayed":{"_past","_psych"},
"undisputed":{"_past"},
"undisrupted":{"_loc_sr","_past"},
"undistributed":{"_loc_sr","_past"},
"undiversified":{"_past"},
"undock":{"_loc_sr"},
"undocumented":{"_anim","_sb"},
"undoer":{"_anim","_sb"},
"undrained":{"_past","_psych"},
"undraped":{"_past"},
"undrawn":{"_loc_sr"},
"undressed":{"_past"},
"undulate":{"_loc_sr"},
"undulated":{"_loc_sr","_past"},
"unelected":{"_past"},
"unembarrassed":{"_past","_psych"},
"unembellished":{"_past"},
"unembodied":{"_past"},
"unencumbered":{"_loc_sr","_past"},
"unended":{"_past"},
"unenforced":{"_past"},
"unenlivened":{"_past","_psych"},
"unenticing":{"_psych"},
"unentitled":{"_past"},
"unenunciated":{"_past"},
"unenvied":{"_past"},
"unequalised":{"_past"},
"unequalized":{"_past"},
"unequipped":{"_past"},
"unescorted":{"_loc_sr","_past"},
"unexamined":{"_past"},
"unexceeded":{"_past"},
"unexcelled":{"_past"},
"unexciting":{"_psych"},
"unexecuted":{"_loc_sr","_past"},
"unexercised":{"_loc_sr","_past"},
"unexpended":{"_past"},
"unexplained":{"_past"},
"unexploded":{"_past"},
"unexplored":{"_loc_sr","_past"},
"unfastened":{"_past"},
"unfastener":{"_anim","_sb"},
"unfattened":{"_past"},
"unfazed":{"_past","_psych"},
"unfed":{"_past"},
"unfelt":{"_loc_sr","_past"},
"unfertilised":{"_past"},
"unfertilized":{"_past"},
"unfettered":{"_past"},
"unfired":{"_past"},
"unfixed":{"_loc_sr","_past"},
"unflavoured":{"_past"},
"unfleshed":{"_past"},
"unflurried":{"_past"},
"unflustered":{"_past","_psych"},
"unfold":{"_loc_sr"},
"unfolded":{"_loc_sr","_past"},
"unfolding":{"_loc_sr"},
"unfolds":{"_loc_sr"},
"unfortunate":{"_anim","_sb"},
"unfortunates":{"_anim","_sb"},
"unfreeze":{"_loc_sr","_wthr"},
"unfretted":{"_past","_psych"},
"unfrightened":{"_past","_psych"},
"unfrock":{"_loc_sr"},
"unfrocking":{"_loc_sr"},
"unfrosted":{"_past"},
"unfrozen":{"_loc_sr","_wthr"},
"unfurled":{"_past"},
"Ungaretti":{"_prprn"},
"ungarmented":{"_past"},
"Ungava":{"_prprn"},
"ungeared":{"_past"},
"unglued":{"_past"},
"unguided":{"_past"},
"ungummed":{"_past"},
"unhampered":{"_loc_sr","_past"},
"unhardened":{"_past","_psych"},
"unharmed":{"_past"},
"unheaded":{"_past"},
"unhealed":{"_past"},
"unheated":{"_past"},
"unhedged":{"_past"},
"unheeded":{"_past"},
"unheralded":{"_past"},
"unhinge":{"_loc_sr"},
"unhinged":{"_loc_sr","_past"},
"unhomogenised":{"_past"},
"unhomogenized":{"_past"},
"unhook":{"_loc_sr"},
"unhoped":{"_past"},
"unhurried":{"_loc_sr","_past"},
"unhurt":{"_past","_psych"},
"unhusked":{"_past"},
"Uniat":{"_prprn","_sb"},
"unicorn":{"_anim"},
"unicorns":{"_anim"},
"unificationists":{"_anim","_sb"},
"unified":{"_past"},
"unifier":{"_anim","_sb"},
"uniformed":{"_past"},
"unilateralist":{"_anim","_sb"},
"unilateralists":{"_anim","_sb"},
"unimagined":{"_loc_sr","_past"},
"unimpregnated":{"_past"},
"unimpressed":{"_past","_psych"},
"unimprisoned":{"_loc_sr","_past"},
"unincorporated":{"_past"},
"unindicted":{"_past"},
"unindustrialised":{"_past"},
"unindustrialized":{"_past"},
"uninebriated":{"_past","_psych"},
"uninfected":{"_loc_sr","_past"},
"uninfluenced":{"_loc_sr","_past"},
"uninitiated":{"_sb"},
"uninspected":{"_past"},
"unintoxicated":{"_past","_psych"},
"unionised":{"_past"},
"unionist":{"_anim","_sb"},
"unionists":{"_anim","_sb"},
"unionize":{"_loc_sr"},
"unit":{"_anim","_sb"},
"Unitarian":{"_prprn","_sb"},
"Unitarians":{"_prprn","_sb"},
"unite":{"_loc_sr"},
"united":{"_loc_sr","_past"},
"unites":{"_loc_sr"},
"uniting":{"_loc_sr"},
"unitize":{"_loc_sr"},
"unitized":{"_loc_sr","_past"},
"units":{"_anim","_sb"},
"universalist":{"_prprn"},
"universe":{"_loc_sr"},
"universities":{"_loc_sr"},
"university":{"_loc_sr"},
"unjacketed":{"_past"},
"unjointed":{"_past"},
"unjustified":{"_past"},
"unkindled":{"_past"},
"unknown":{"_anim","_sb"},
"unknowns":{"_anim","_sb"},
"unlabeled":{"_past"},
"unlaced":{"_past"},
"unlade":{"_loc_sr"},
"unlamented":{"_past"},
"unlashed":{"_past"},
"unlatched":{"_past"},
"unlaundered":{"_past"},
"unlaureled":{"_past"},
"unlaurelled":{"_past"},
"unleaded":{"_past"},
"unlearn":{"_loc_sr"},
"unlearned":{"_loc_sr","_past"},
"unleash":{"_loc_sr"},
"unleashed":{"_loc_sr","_past"},
"unleashes":{"_loc_sr"},
"unleashing":{"_loc_sr"},
"unleveled":{"_past"},
"unlicenced":{"_past"},
"unlighted":{"_loc_sr","_past"},
"unlined":{"_past"},
"unlinked":{"_past"},
"unlipped":{"_past"},
"unlit":{"_past"},
"unloaded":{"_past"},
"unlocked":{"_past"},
"unloved":{"_past"},
"unlubricated":{"_past"},
"unmade":{"_past"},
"unmagnified":{"_past"},
"unmalted":{"_loc_sr","_past"},
"unmanaged":{"_past"},
"unmanned":{"_past"},
"unmapped":{"_past"},
"unmarred":{"_past"},
"unmarried":{"_anim","_sb"},
"unmated":{"_loc_sr","_past"},
"unmaterialized":{"_past"},
"unmechanised":{"_past"},
"unmentioned":{"_loc_sr","_past"},
"unmeshed":{"_loc_sr","_past"},
"unmingled":{"_loc_sr","_past"},
"unmodernised":{"_past"},
"unmotorised":{"_past"},
"unmutilated":{"_past"},
"unnamed":{"_past"},
"unnaturalised":{"_past"},
"unnaturalized":{"_past"},
"unnerve":{"_psych"},
"unnerved":{"_past","_psych"},
"unnerving":{"_psych"},
"unnotched":{"_past"},
"unnoted":{"_past"},
"unnoticed":{"_past"},
"Uno":{"_prprn"},
"unobserved":{"_past"},
"unorganised":{"_past"},
"unoriented":{"_loc_sr","_past"},
"unpacked":{"_loc_sr","_past"},
"unpadded":{"_past"},
"unpainted":{"_past"},
"unpaired":{"_loc_sr","_past"},
"unpasteurised":{"_past"},
"unpatronised":{"_past"},
"unpatronized":{"_past"},
"unpaved":{"_past"},
"unpegged":{"_past"},
"unperceived":{"_loc_sr","_past"},
"unperceiving":{"_loc_sr"},
"unperplexed":{"_past","_psych"},
"unpersuaded":{"_past"},
"unpillared":{"_past"},
"unplagued":{"_past","_psych"},
"unplanted":{"_loc_sr","_past"},
"unpleased":{"_past","_psych"},
"unpleasing":{"_psych"},
"unploughed":{"_past"},
"unplowed":{"_past"},
"unpointed":{"_past"},
"unpolluted":{"_past"},
"unpotted":{"_loc_sr","_past"},
"unprotected":{"_past"},
"unproved":{"_past"},
"unprovoking":{"_psych"},
"unpublicized":{"_past"},
"unpublished":{"_past"},
"unpunctured":{"_past"},
"Unq":{"_prprn"},
"unquenched":{"_past"},
"unranked":{"_loc_sr","_past"},
"unraveled":{"_past"},
"unraveler":{"_anim","_sb"},
"unraveller":{"_anim","_sb"},
"unreassuring":{"_psych"},
"unrecognised":{"_past"},
"unrecognized":{"_past"},
"unrecorded":{"_past"},
"unredeemed":{"_loc_sr","_past"},
"unreduced":{"_past"},
"unreflected":{"_loc_sr","_past"},
"unrefrigerated":{"_past"},
"unregenerated":{"_past"},
"unreinforced":{"_past"},
"unrelated":{"_past"},
"unreported":{"_past"},
"unresolved":{"_past"},
"unrestricted":{"_past"},
"unretouched":{"_past"},
"unrevived":{"_past"},
"unrimed":{"_past"},
"unroll":{"_loc_sr"},
"unrolled":{"_loc_sr","_past"},
"unrolls":{"_loc_sr"},
"unrouged":{"_past"},
"unsaid":{"_past"},
"unsalted":{"_past"},
"unsanctioned":{"_past"},
"unsaponified":{"_past"},
"unsatisfied":{"_past","_psych"},
"unscented":{"_past"},
"unscheduled":{"_loc_sr","_past"},
"unscramble":{"_loc_sr"},
"unscrewed":{"_past"},
"unsealed":{"_past"},
"unseat":{"_loc_sr"},
"unseated":{"_loc_sr","_past"},
"unseating":{"_loc_sr"},
"unsecured":{"_loc_sr","_past"},
"unseeded":{"_past"},
"unsegmented":{"_loc_sr","_past"},
"unsettle":{"_loc_sr","_psych"},
"unsettled":{"_loc_sr","_past","_psych"},
"unsettling":{"_loc_sr","_psych"},
"unshackled":{"_past"},
"unshaded":{"_loc_sr","_past"},
"unshaken":{"_loc_sr"},
"unshared":{"_loc_sr","_past"},
"unsharpened":{"_past"},
"unshaved":{"_loc_sr","_past"},
"unsheared":{"_past"},
"unsheathed":{"_past"},
"unshed":{"_past"},
"unsheltered":{"_loc_sr","_past"},
"unshielded":{"_loc_sr","_past"},
"unsilenced":{"_past"},
"unsmoothed":{"_past"},
"unsnarled":{"_past"},
"unsoiled":{"_past"},
"unsold":{"_past"},
"unsolved":{"_past"},
"unsown":{"_loc_sr"},
"unspaced":{"_past"},
"unspecialised":{"_past"},
"unspecified":{"_past"},
"unspoiled":{"_past"},
"unsprayed":{"_loc_sr","_past"},
"unstained":{"_past"},
"unstanched":{"_past"},
"unstated":{"_loc_sr","_past"},
"unsterilised":{"_past"},
"unstimulated":{"_loc_sr","_past","_psych"},
"unstoppered":{"_past"},
"unstuck":{"_loc_sr","_past"},
"unsubdivided":{"_loc_sr","_past"},
"unsubordinated":{"_loc_sr","_past"},
"unsubsidized":{"_past"},
"unsubstantiated":{"_past"},
"unsuited":{"_past"},
"unsupported":{"_loc_sr","_past"},
"unsurpassed":{"_loc_sr","_past"},
"unsurprising":{"_psych"},
"unswagged":{"_past"},
"unswaggering":{"_loc_sr"},
"unsweetened":{"_past"},
"unsyllabled":{"_loc_sr","_past"},
"unsynchronised":{"_past"},
"untainted":{"_past"},
"untangle":{"_loc_sr"},
"untarnished":{"_past"},
"untaxed":{"_past"},
"untempting":{"_psych"},
"untended":{"_past"},
"untested":{"_past"},
"untethered":{"_past"},
"unthinking":{"_loc_sr"},
"untied":{"_past"},
"untier":{"_loc_sr"},
"until":{"_tme"},
"untilled":{"_past"},
"untipped":{"_past"},
"untired":{"_past","_psych"},
"untoothed":{"_past"},
"untouchable":{"_sb"},
"untouched":{"_past","_psych"},
"untoughened":{"_past"},
"untracked":{"_past"},
"untrained":{"_loc_sr","_past"},
"untravelled":{"_loc_sr","_past"},
"untraversed":{"_loc_sr","_past"},
"untreated":{"_past"},
"untrimmed":{"_past"},
"untrusting":{"_loc_sr"},
"untucked":{"_loc_sr","_past"},
"untufted":{"_past"},
"untune":{"_loc_sr"},
"unturned":{"_loc_sr","_past"},
"ununderstood":{"_past"},
"unvaccinated":{"_loc_sr","_past"},
"unvanquished":{"_loc_sr","_past"},
"unvaried":{"_loc_sr","_past"},
"unvarying":{"_loc_sr"},
"unveiled":{"_past"},
"unvented":{"_past"},
"unventilated":{"_past"},
"unverbalised":{"_past"},
"unverbalized":{"_loc_sr","_past"},
"unverified":{"_past"},
"unvisited":{"_loc_sr","_past"},
"unvitrified":{"_loc_sr","_past"},
"unvoiced":{"_past"},
"unvulcanised":{"_past"},
"unvulcanized":{"_loc_sr","_past"},
"unwanted":{"_past"},
"unwarmed":{"_loc_sr","_past"},
"unwavering":{"_loc_sr"},
"unweaned":{"_past"},
"unwebbed":{"_past"},
"unwelcome":{"_psych"},
"unwell":{"_fem"},
"unwired":{"_loc_sr","_past"},
"unwished":{"_past"},
"unwrapped":{"_past"},
"upbraider":{"_anim","_sb"},
"updated":{"_past"},
"Updike":{"_anim","_nme","_prprn","_sb"},
"upend":{"_loc_sr"},
"upended":{"_loc_sr","_past"},
"upending":{"_loc_sr"},
"Upham":{"_prprn"},
"upheld":{"_past"},
"upholstered":{"_past"},
"uplands":{"_loc_sr"},
"uplift":{"_psych"},
"uplifted":{"_past","_psych"},
"uplifting":{"_psych"},
"upped":{"_past"},
"uppercase":{"_loc_sr"},
"Uppsala":{"_cty","_geo","_prprn"},
"upraised":{"_past"},
"uprooted":{"_past"},
"uprooter":{"_anim","_sb"},
"Upsala":{"_prprn"},
"upset":{"_past","_psych"},
"upsets":{"_psych"},
"upsetter":{"_anim","_sb"},
"upsetting":{"_psych"},
"upstaged":{"_past"},
"upstairs":{"_loc_sr"},
"upstarts":{"_anim","_sb"},
"upturned":{"_past"},
"upwind":{"_loc"},
"Uralic":{"_prprn"},
"Uranus":{"_prprn"},
"urbanised":{"_past"},
"urbanized":{"_past"},
"urchin":{"_anim","_masc","_sb"},
"Urdu":{"_prprn"},
"urged":{"_past"},
"urinal":{"_loc_sr"},
"urinals":{"_loc_sr"},
"urinate":{"_loc_sr"},
"urologist":{"_anim","_sb"},
"Ursula":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Ursuline":{"_prprn","_sb"},
"Uruguay":{"_cntry","_geo","_prprn"},
"Uruguayan":{"_anim","_prprn","_sb"},
"us":{"_anim","_sb"},
"USA":{"_cntry","_geo","_prprn"},
"used":{"_loc_sr","_past"},
"Usenet":{"_prprn"},
"user":{"_anim","_sb"},
"users":{"_anim","_sb"},
"ushered":{"_past"},
"ustinov":{"_geo","_prprn"},
"usurer":{"_anim","_sb"},
"usurped":{"_past"},
"Utah":{"_geo","_prprn","_stte"},
"Utahan":{"_prprn"},
"ute":{"_anim","_prprn","_sb"},
"utensil":{"_loc_sr"},
"utensils":{"_loc_sr"},
"utilised":{"_past"},
"utiliser":{"_anim","_sb"},
"utilitarian":{"_anim","_sb"},
"utilized":{"_past"},
"utilizer":{"_anim","_sb"},
"Uto-Aztecan":{"_prprn"},
"utopia":{"_loc_sr"},
"utopias":{"_loc_sr"},
"Utrecht":{"_cty","_geo","_prprn"},
"utrillo":{"_anim","_nme","_prprn","_sb"},
"Utsunomiya":{"_cty","_geo","_prprn"},
"utter":{"_loc_sr"},
"uttered":{"_loc_sr","_past"},
"uttering":{"_loc_sr"},
"UV":{"_prprn"},
"Uzbek":{"_anim","_prprn","_sb"},
"Uzbekistan":{"_cntry","_geo","_prprn"},
"Uzi":{"_prprn"},
"V-shaped":{"_prprn"},
"Va":{"_prprn","_stte"},
"Va.":{"_prprn","_stte"},
"vacationed":{"_past"},
"vacationers":{"_anim","_sb"},
"vacationist":{"_anim","_sb"},
"vacationland":{"_loc_sr"},
"Vacaville":{"_cty","_geo","_prprn"},
"vaccinate":{"_loc_sr"},
"vaccinated":{"_loc_sr","_past"},
"vaccinating":{"_loc_sr"},
"vaccinator":{"_anim","_sb"},
"vacillated":{"_loc_sr","_past"},
"vacillating":{"_loc_sr"},
"vacuumed":{"_past"},
"vagabonds":{"_anim","_sb"},
"vagrant":{"_anim","_sb"},
"Vajpayee":{"_prprn"},
"Valais":{"_prprn"},
"Valdemar":{"_prprn"},
"valedictorian":{"_anim","_sb"},
"Valencia":{"_cntry","_cty","_geo","_prprn","_stte"},
"Valens":{"_anim","_nme","_prprn","_sb"},
"valentine":{"_anim","_sb"},
"Valentino":{"_anim","_nme","_prprn","_sb"},
"Valerie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"valetudinarian":{"_anim","_sb"},
"Valhalla":{"_geo","_prprn"},
"valiant":{"_sb"},
"Valladolid":{"_cty","_geo","_prprn"},
"valley":{"_loc_sr"},
"Valois":{"_anim","_geo","_nme","_prprn","_sb"},
"Valparaiso":{"_cty","_geo","_prprn"},
"valued":{"_past"},
"vamper":{"_anim","_sb"},
"vampires":{"_anim","_sb"},
"van":{"_fem"},
"Vancouver":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"vandal":{"_anim","_sb"},
"vandalism":{"_loc_sr"},
"vandalized":{"_past"},
"vandals":{"_anim","_sb"},
"vanderbilt":{"_anim","_nme","_prprn","_sb"},
"Vandyke":{"_anim","_nme","_prprn","_sb"},
"Vane":{"_anim","_prprn","_sb"},
"Vanessa":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"vanishing":{"_loc_sr"},
"vanquish":{"_loc_sr"},
"vans":{"_fem"},
"Vanuatu":{"_cntry","_geo","_prprn"},
"vaporiser":{"_anim","_sb"},
"vaporize":{"_loc_sr"},
"vapourised":{"_past"},
"vaquero":{"_anim","_masc","_sb"},
"Varese":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"variate":{"_loc_sr"},
"varied":{"_loc_sr","_past"},
"variegated":{"_past"},
"varies":{"_loc_sr"},
"various":{"_quant"},
"varix":{"_loc_sr"},
"varnished":{"_past"},
"varnisher":{"_anim","_sb"},
"vary":{"_loc_sr"},
"varying":{"_loc_sr"},
"vasa":{"_loc_sr"},
"vase":{"_loc_sr"},
"vases":{"_loc_sr"},
"vassal":{"_anim","_sb"},
"vassals":{"_anim","_sb"},
"vat":{"_loc_sr"},
"Vatican":{"_cntry","_geo","_prprn"},
"vaticinator":{"_anim","_sb"},
"vats":{"_loc_sr"},
"Vaudois":{"_prprn"},
"Vaughan":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Vaughn":{"_anim","_fnme","_nme","_prprn","_sb"},
"vault":{"_loc_sr"},
"vaulted":{"_loc_sr","_past"},
"vaulting":{"_loc_sr"},
"vaunted":{"_past"},
"Vauxhall":{"_prprn"},
"VCR":{"_prprn"},
"VDU":{"_prprn"},
"Veblen":{"_anim","_nme","_prprn","_sb"},
"veered":{"_past"},
"Vega":{"_anim","_nme","_prprn","_sb"},
"vegan":{"_anim","_sb"},
"Vegas":{"_anim","_nme","_prprn","_sb"},
"vegetarians":{"_anim","_sb"},
"vegetate":{"_loc_sr"},
"veined":{"_past"},
"Velcro":{"_prprn"},
"veldt":{"_loc_sr"},
"vendee":{"_anim","_sb"},
"vender":{"_anim","_sb"},
"vendor":{"_anim","_sb"},
"vendors":{"_anim","_sb"},
"venerated":{"_past"},
"venerator":{"_anim","_sb"},
"Veneto":{"_geo","_prprn","_stte"},
"Venezuela":{"_cntry","_geo","_prprn"},
"Venezuelan":{"_anim","_prprn","_sb"},
"Venice":{"_cty","_geo","_prprn"},
"vented":{"_past"},
"ventilated":{"_past"},
"ventricles":{"_loc_sr"},
"Ventura":{"_cty","_geo","_prprn"},
"ventured":{"_past"},
"venturers":{"_anim","_sb"},
"Venturi":{"_anim","_prprn","_sb"},
"Vera":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Veracruz":{"_cty","_geo","_prprn","_stte"},
"veranda":{"_loc_sr"},
"verandas":{"_loc_sr"},
"verbalised":{"_past"},
"verbaliser":{"_anim","_sb"},
"verbalize":{"_loc_sr"},
"verbalized":{"_loc_sr","_past"},
"verbalizer":{"_anim","_sb"},
"Verde":{"_prprn"},
"Verdi":{"_anim","_nme","_prprn","_sb"},
"verged":{"_past"},
"verifiers":{"_anim","_sb"},
"Vermeer":{"_anim","_nme","_prprn","_sb"},
"vermiculated":{"_past"},
"vermin":{"_anim"},
"Vermont":{"_geo","_prprn","_stte"},
"Vermonter":{"_anim","_sb"},
"vernacular":{"_loc_sr"},
"Verne":{"_anim","_nme","_prprn","_sb"},
"Vernon":{"_cty","_geo","_prprn"},
"Veronica":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Versace":{"_prprn"},
"Versailles":{"_cty","_geo","_prprn"},
"versed":{"_loc_sr","_past"},
"versify":{"_loc_sr"},
"vertebrate":{"_anim","_sb"},
"vertebrates":{"_anim","_sb"},
"vervet":{"_anim"},
"Verwoerd":{"_anim","_nme","_prprn","_sb"},
"vessel":{"_loc_sr"},
"vessels":{"_loc_sr"},
"vest":{"_loc_sr"},
"vesta":{"_anim","_fem","_nme","_prprn","_sb"},
"vestibule":{"_loc_sr"},
"vestibules":{"_loc_sr"},
"vesting":{"_loc_sr"},
"vestrywoman":{"_anim","_fem","_sb"},
"Vesuvio":{"_prprn"},
"Vesuvius":{"_prprn"},
"veteran":{"_anim","_sb"},
"veterans":{"_anim","_sb"},
"veterinarians":{"_anim","_sb"},
"vetoed":{"_loc_sr","_past"},
"vetoing":{"_loc_sr"},
"vets":{"_anim","_sb"},
"vetted":{"_past"},
"vex":{"_psych"},
"vexer":{"_anim","_sb"},
"vi":{"_prprn"},
"Viagra":{"_prprn"},
"Viareggio":{"_cty","_geo","_prprn"},
"vibist":{"_anim","_sb"},
"vibrate":{"_loc_sr"},
"vibrated":{"_loc_sr","_past"},
"vibrating":{"_loc_sr"},
"vicar":{"_anim","_sb"},
"vicars":{"_anim","_sb"},
"vice-chancellor":{"_anim","_sb"},
"vice-president":{"_anim","_sb"},
"vice-presidents":{"_anim","_sb"},
"vicegerent":{"_anim","_sb"},
"Vicente":{"_prprn"},
"Vicenza":{"_cty","_geo","_prprn"},
"Vichy":{"_cty","_geo","_prprn"},
"vicinal":{"_loc"},
"Vicki":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Vicksburg":{"_cty","_geo","_prprn"},
"Vicky":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"victim":{"_anim","_sb"},
"victimised":{"_past"},
"victimiser":{"_anim","_sb"},
"victimized":{"_past"},
"victims":{"_anim","_sb"},
"Victor":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Victoria":{"_anim","_cty","_fem","_fnme","_geo","_nme","_prprn","_sb","_stte"},
"Victorian":{"_anim","_prprn","_sb"},
"Victorians":{"_anim","_prprn","_sb"},
"victors":{"_anim","_sb"},
"victualler":{"_anim","_sb"},
"vicuna":{"_anim"},
"Vidal":{"_anim","_nme","_prprn","_sb"},
"videotaped":{"_loc_sr","_past"},
"vied":{"_past"},
"Vienna":{"_cty","_geo","_prprn"},
"Vienne":{"_geo","_prprn"},
"Viennese":{"_anim","_prprn","_sb"},
"Vientiane":{"_cty","_geo","_prprn"},
"Vietnam":{"_cntry","_geo","_prprn"},
"Vietnamese":{"_anim","_prprn","_sb"},
"viewed":{"_past"},
"vigilante":{"_anim","_sb"},
"Vignola":{"_anim","_nme","_prprn","_sb"},
"Viking":{"_prprn","_sb"},
"Vikings":{"_prprn","_sb"},
"Vila":{"_cty","_geo","_prprn"},
"vilified":{"_past"},
"vilifier":{"_anim","_sb"},
"Villa":{"_anim","_prprn","_sb"},
"villagers":{"_anim","_sb"},
"villain":{"_anim","_sb"},
"villains":{"_anim","_sb"},
"Villard":{"_anim","_nme","_prprn","_sb"},
"villein":{"_anim","_sb"},
"Vilnius":{"_cty","_geo","_prprn"},
"vinaigrette":{"_loc_sr"},
"Vincent":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Vinci":{"_prprn"},
"vindicate":{"_loc_sr"},
"vindicated":{"_loc_sr","_past"},
"Vineland":{"_cty","_geo","_prprn"},
"vinery":{"_loc_sr"},
"vineyard":{"_loc_sr"},
"vineyards":{"_loc_sr"},
"Vinson":{"_anim","_nme","_prprn","_sb"},
"vintager":{"_anim","_sb"},
"vintners":{"_anim","_sb"},
"violated":{"_past"},
"violators":{"_anim","_sb"},
"violinists":{"_anim","_sb"},
"violist":{"_anim","_sb"},
"violoncellist":{"_anim","_sb"},
"viper":{"_anim"},
"vipers":{"_anim"},
"Viren":{"_prprn"},
"Virgil":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Virgin":{"_anim","_prprn","_sb"},
"Virginia":{"_anim","_fem","_fnme","_geo","_nme","_prprn","_sb","_stte"},
"Virginian":{"_anim","_prprn","_sb"},
"virgins":{"_anim","_sb"},
"virile":{"_masc"},
"virtuosi":{"_anim","_sb"},
"virtuoso":{"_anim","_sb"},
"virtuosos":{"_anim","_sb"},
"virus":{"_anim"},
"viruses":{"_anim"},
"vis":{"_geo","_prprn"},
"viscacha":{"_anim"},
"visionaries":{"_anim","_sb"},
"visionary":{"_anim","_sb"},
"visit":{"_loc_sr"},
"visited":{"_loc_sr","_past"},
"visiting":{"_loc_sr"},
"visitor":{"_anim","_sb"},
"visitors":{"_anim","_sb"},
"visored":{"_past"},
"visualised":{"_past"},
"visualiser":{"_anim","_sb"},
"visualize":{"_loc_sr"},
"visualized":{"_loc_sr","_past"},
"visualizes":{"_loc_sr"},
"vitaliser":{"_anim","_sb"},
"vitalizer":{"_anim","_sb"},
"vitiated":{"_past"},
"vitrified":{"_loc_sr","_past"},
"Vitus":{"_prprn"},
"Vivaldi":{"_anim","_nme","_prprn","_sb"},
"viverrine":{"_sb"},
"Vivian":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"vivified":{"_past"},
"vixen":{"_anim","_fem"},
"Viyella":{"_prprn"},
"vizier":{"_anim","_sb"},
"Vladimir":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"Vladivostok":{"_cty","_geo","_prprn"},
"vocaliser":{"_anim","_sb"},
"vocalists":{"_anim","_sb"},
"vociferate":{"_loc_sr"},
"vociferator":{"_anim","_sb"},
"Vogel":{"_prprn"},
"voiced":{"_loc_sr","_past"},
"voicing":{"_loc_sr"},
"voided":{"_past"},
"volatilised":{"_past"},
"volatilized":{"_past"},
"vole":{"_anim"},
"Volga":{"_geo","_prprn"},
"Volgograd":{"_cty","_geo","_prprn"},
"Volta":{"_anim","_geo","_nme","_prprn","_sb"},
"Voltaire":{"_anim","_nme","_prprn","_sb"},
"volunteered":{"_past"},
"volunteers":{"_anim","_sb"},
"voluptuary":{"_anim","_sb"},
"volvox":{"_anim"},
"vomit":{"_loc_sr"},
"vomited":{"_loc_sr","_past"},
"vomiter":{"_anim","_sb"},
"vomiting":{"_loc_sr"},
"Vonnegut":{"_anim","_nme","_prprn","_sb"},
"Voronezh":{"_cty","_geo","_prprn"},
"Voroshilov":{"_anim","_nme","_prprn","_sb"},
"Vosges":{"_geo","_prprn"},
"voted":{"_past"},
"voter":{"_anim","_sb"},
"voters":{"_anim","_sb"},
"vouchee":{"_anim","_sb"},
"vowed":{"_past"},
"vower":{"_anim","_sb"},
"Voyager":{"_anim","_sb"},
"Vries":{"_prprn"},
"vroom":{"_loc_sr"},
"Vt.":{"_prprn","_stte"},
"Vulcan":{"_anim","_masc","_nme","_prprn","_sb"},
"vulcanised":{"_past"},
"vulcaniser":{"_anim","_sb"},
"vulcanized":{"_loc_sr","_past"},
"vulcanizer":{"_anim","_sb"},
"vulgarian":{"_anim","_sb"},
"vulgariser":{"_anim","_sb"},
"vulgarizer":{"_anim","_sb"},
"Vulpecula":{"_prprn"},
"vulture":{"_anim"},
"vulture-like":{"_anim"},
"vultures":{"_anim"},
"Waal":{"_geo","_prprn"},
"Wabash":{"_geo","_prprn"},
"wacko":{"_anim","_sb"},
"Waco":{"_cty","_geo","_prprn"},
"wad":{"_loc_sr"},
"wadded":{"_loc_sr","_past"},
"wadding":{"_loc_sr"},
"waddle":{"_loc_sr"},
"waddlers":{"_anim","_sb"},
"wade":{"_loc_sr"},
"waded":{"_loc_sr","_past"},
"waders":{"_anim","_sb"},
"waffled":{"_past"},
"waft":{"_loc_sr"},
"wafting":{"_loc_sr"},
"wag":{"_loc_sr"},
"wage":{"_loc_sr"},
"waged":{"_loc_sr","_past"},
"wager":{"_loc_sr"},
"wagering":{"_loc_sr"},
"wagged":{"_loc_sr","_past"},
"wagging":{"_loc_sr"},
"waggled":{"_loc_sr","_past"},
"waggling":{"_loc_sr"},
"waggoner":{"_anim","_sb"},
"waging":{"_loc_sr"},
"Wagner":{"_anim","_nme","_prprn","_sb"},
"Wagnerian":{"_prprn"},
"wagoner":{"_anim","_sb"},
"waif":{"_anim","_sb"},
"Waikiki":{"_geo","_prprn"},
"wailed":{"_past"},
"Wain":{"_prprn"},
"wainscoted":{"_past"},
"wainwright":{"_anim","_sb"},
"wait":{"_loc_sr"},
"Waite":{"_anim","_nme","_prprn","_sb"},
"waited":{"_loc_sr","_past"},
"waiter":{"_anim","_sb"},
"waiters":{"_anim","_sb"},
"waiting":{"_loc_sr"},
"waitress":{"_anim","_fem","_sb"},
"waitresses":{"_anim","_fem","_sb"},
"waived":{"_past"},
"Wakayama":{"_cty","_geo","_prprn"},
"Wakefield":{"_cty","_geo","_prprn"},
"wakened":{"_loc_sr","_past"},
"wakening":{"_loc_sr"},
"waker":{"_anim","_sb"},
"Waksman":{"_anim","_nme","_prprn","_sb"},
"Walcott":{"_prprn"},
"Waldenses":{"_prprn"},
"Waldensian":{"_prprn"},
"Waldheim":{"_anim","_nme","_prprn","_sb"},
"Waldo":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Wales":{"_cntry","_geo","_prprn"},
"walk":{"_loc_sr"},
"walk-in":{"_anim","_loc_sr","_sb"},
"walk-on":{"_anim","_sb"},
"walkabout":{"_tme"},
"walker":{"_anim","_sb"},
"walking":{"_loc_sr"},
"Wallace":{"_anim","_fnme","_nme","_prprn","_sb"},
"walled":{"_past"},
"Wallenberg":{"_prprn"},
"Wallenstein":{"_anim","_nme","_prprn","_sb"},
"Waller":{"_anim","_nme","_prprn","_sb"},
"wallow":{"_loc_sr"},
"wallowed":{"_loc_sr","_past"},
"Walpole":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"walrus":{"_anim"},
"walruses":{"_anim"},
"Walsh":{"_anim","_nme","_prprn","_sb"},
"Walter":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Waltham":{"_cty","_geo","_prprn"},
"Walton":{"_anim","_nme","_prprn","_sb"},
"wamble":{"_loc_sr"},
"Wanda":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"wandered":{"_loc_sr","_past"},
"wanderers":{"_anim","_sb"},
"wandering":{"_loc_sr"},
"Wanderjahr":{"_prprn"},
"wane":{"_loc_sr"},
"waned":{"_loc_sr","_past"},
"wangler":{"_anim","_sb"},
"waning":{"_loc_sr"},
"wanter":{"_anim","_sb"},
"wapiti":{"_anim"},
"Warburg":{"_anim","_nme","_prprn","_sb"},
"warded":{"_past"},
"warden":{"_anim","_sb"},
"wardens":{"_anim","_sb"},
"wardress":{"_anim","_sb"},
"wardrobe":{"_loc_sr"},
"wardrobes":{"_loc_sr"},
"wards":{"_loc_sr"},
"warehouse":{"_loc_sr"},
"warehouses":{"_loc_sr"},
"warlord":{"_anim","_sb"},
"warlords":{"_anim","_sb"},
"warm":{"_loc_sr"},
"warmed":{"_loc_sr","_past"},
"warming":{"_loc_sr"},
"warms":{"_loc_sr"},
"warned":{"_past"},
"warped":{"_past"},
"warranted":{"_past"},
"warrantor":{"_anim","_sb"},
"warred":{"_loc_sr","_past"},
"warren":{"_loc_sr"},
"warrener":{"_anim","_sb"},
"warring":{"_loc_sr"},
"warrior":{"_anim","_sb"},
"warriors":{"_anim","_sb"},
"Warsaw":{"_cty","_geo","_prprn"},
"wartime":{"_tme"},
"Warwick":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Warwickshire":{"_prprn"},
"was":{"_past,_vlink"},
"washed":{"_past"},
"washer":{"_anim","_sb"},
"washerwoman":{"_anim","_fem","_sb"},
"washhouse":{"_loc_sr"},
"Washington":{"_anim","_cty","_geo","_nme","_prprn","_sb","_stte"},
"washwoman":{"_anim","_sb"},
"wasp":{"_anim"},
"wassailer":{"_anim","_sb"},
"waste":{"_loc_sr"},
"wasted":{"_past"},
"wastes":{"_loc_sr"},
"wastewater":{"_loc_sr"},
"wastrel":{"_anim","_sb"},
"watchdog":{"_anim"},
"watchdogs":{"_anim"},
"watchers":{"_anim","_sb"},
"water-ski":{"_loc_sr"},
"water-skiing":{"_loc_sr"},
"Waterbury":{"_cty","_geo","_prprn"},
"watercolorists":{"_anim","_sb"},
"watercolourist":{"_anim","_sb"},
"watered-silk":{"_past"},
"waterfall":{"_loc_sr"},
"waterfalls":{"_loc_sr"},
"Waterford":{"_cty","_geo","_prprn"},
"Watergate":{"_prprn"},
"Waterhouse":{"_prprn"},
"waterlogged":{"_past"},
"Waterloo":{"_cty","_geo","_prprn"},
"waterproofed":{"_past"},
"watersheds":{"_loc_sr"},
"waterside":{"_loc_sr"},
"waterways":{"_loc_sr"},
"waterworks":{"_loc_sr"},
"Watson":{"_anim","_nme","_prprn","_sb"},
"Watson-Watt":{"_anim","_nme","_prprn","_sb"},
"Watt":{"_anim","_prprn","_sb"},
"Watts":{"_geo","_prprn"},
"Watutsi":{"_prprn"},
"Waugh":{"_anim","_nme","_prprn","_sb"},
"Waukegan":{"_cty","_geo","_prprn"},
"Waukesha":{"_cty","_geo","_prprn"},
"wave":{"_loc_sr"},
"waved":{"_loc_sr","_past"},
"waver":{"_loc_sr"},
"wavered":{"_loc_sr","_past"},
"wavering":{"_loc_sr"},
"waves":{"_loc_sr","_sb"},
"waving":{"_loc_sr"},
"wax":{"_loc_sr"},
"waxing":{"_loc_sr"},
"waylaid":{"_loc_sr","_past"},
"Wayland":{"_prprn"},
"waylay":{"_loc_sr"},
"Wayne":{"_anim","_cty","_fnme","_geo","_masc","_nme","_prprn","_sb"},
"We":{"_anim","_sb"},
"weakened":{"_past"},
"weakener":{"_anim","_sb"},
"weakfish":{"_anim","_loc_sr"},
"weakling":{"_anim","_sb"},
"weaned":{"_past"},
"weaponed":{"_past"},
"wear":{"_loc_sr"},
"wearer":{"_anim","_sb"},
"wearied":{"_past"},
"wearing":{"_loc_sr"},
"weathered":{"_loc_sr","_past"},
"weathering":{"_loc_sr"},
"weave":{"_loc_sr"},
"weavers":{"_anim","_sb"},
"webb":{"_anim","_nme","_prprn","_sb"},
"webbed":{"_past"},
"Webster":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"wed":{"_past"},
"wedded":{"_past"},
"wedel":{"_loc_sr"},
"wedged":{"_past"},
"Wedgwood":{"_anim","_nme","_prprn","_sb"},
"Wednesday":{"_day","_prprn","_tme"},
"Wednesdays":{"_day","_prprn","_tme"},
"wee":{"_loc_sr"},
"weeded":{"_past"},
"week":{"_tme"},
"weekday":{"_tme"},
"weekends":{"_tme"},
"weeknight":{"_tme"},
"weeknights":{"_tme"},
"weeks":{"_tme"},
"Weems":{"_anim","_nme","_prprn","_sb"},
"weepers":{"_anim","_sb"},
"weevil":{"_anim"},
"weevils":{"_anim"},
"Wegener":{"_anim","_nme","_prprn","_sb"},
"Wei":{"_anim","_nme","_prprn","_sb"},
"weighed":{"_past"},
"weighted":{"_loc_sr","_past"},
"weighting":{"_loc_sr"},
"weightlifter":{"_anim","_sb"},
"Weil":{"_anim","_nme","_prprn","_sb"},
"Weill":{"_anim","_nme","_prprn","_sb"},
"Weimar":{"_cty","_geo","_prprn"},
"Weinberg":{"_anim","_nme","_prprn","_sb"},
"weirdie":{"_anim","_sb"},
"weirdo":{"_anim","_sb"},
"Weissmuller":{"_anim","_nme","_prprn","_sb"},
"Welby":{"_prprn"},
"welcome":{"_psych"},
"welcomed":{"_past","_psych"},
"welcomes":{"_psych"},
"welcoming":{"_psych"},
"welded":{"_past"},
"Weldon":{"_prprn"},
"welfarist":{"_anim","_sb"},
"well-baby":{"_loc_sr"},
"well-born":{"_loc_sr"},
"well-to-do":{"_anim","_sb"},
"well-turned-out":{"_loc_sr"},
"well-wisher":{"_anim","_sb"},
"well-wishers":{"_anim","_sb"},
"Welland":{"_cty","_geo","_prprn"},
"Welles":{"_anim","_nme","_prprn","_sb"},
"Wellesley":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Wellington":{"_cty","_geo","_prprn"},
"wells":{"_loc_sr"},
"Welsh":{"_anim","_prprn","_sb"},
"Welshman":{"_anim","_masc","_prprn","_sb"},
"welterweight":{"_anim","_sb"},
"weltschmerz":{"_prprn"},
"Wenceslas":{"_prprn"},
"wench":{"_loc_sr"},
"wencher":{"_anim","_sb"},
"wend":{"_loc_sr"},
"Wendy":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"went":{"_loc_sr","_past"},
"Wentworth":{"_anim","_nme","_prprn","_sb"},
"wept":{"_past"},
"were":{"_past,_vlink"},
"werewolf":{"_anim","_sb"},
"werewolves":{"_anim","_sb"},
"Wergeland":{"_prprn"},
"Werner":{"_anim","_nme","_prprn","_sb"},
"Wesker":{"_prprn"},
"Wesleyan":{"_prprn","_sb"},
"West":{"_anim","_prprn","_sb"},
"wester":{"_loc_sr"},
"Western":{"_prprn"},
"westerner":{"_anim","_sb"},
"Westinghouse":{"_anim","_nme","_prprn","_sb"},
"Westland":{"_cty","_geo","_prprn"},
"Westminster":{"_cty","_geo","_prprn"},
"Westphalia":{"_geo","_prprn"},
"Westwood":{"_prprn"},
"wet":{"_past"},
"wether":{"_anim","_masc"},
"wetlands":{"_loc_sr"},
"whacked":{"_past"},
"whale":{"_anim"},
"whales":{"_anim"},
"Wharton":{"_anim","_nme","_prprn","_sb"},
"wharves":{"_loc_sr"},
"what":{"_wh"},
"whatever":{"_wh"},
"whatsoever":{"_wh"},
"Wheaton":{"_cty","_geo","_prprn"},
"wheedled":{"_past"},
"wheedler":{"_anim","_sb"},
"wheelbarrow":{"_loc_sr"},
"Wheeler":{"_anim","_prprn","_sb"},
"wheeler-dealers":{"_anim","_sb"},
"wheezed":{"_past"},
"whelk":{"_anim"},
"when":{"_tme","_wh"},
"whence":{"_loc","_wh"},
"whenever":{"_tme","_wh"},
"where":{"_loc","_wh"},
"whereabouts":{"_loc_sr"},
"whereby":{"_wh"},
"wherein":{"_loc","_wh"},
"whereof":{"_wh"},
"whereon":{"_wh"},
"wheresoever":{"_wh"},
"wherever":{"_wh"},
"wherewith":{"_wh"},
"whether":{"_wh"},
"whetted":{"_past"},
"which":{"_wh"},
"whichever":{"_wh"},
"whiff":{"_loc_sr"},
"whiffer":{"_anim","_sb"},
"Whigs":{"_prprn","_sb"},
"while":{"_tme"},
"whined":{"_past"},
"whiners":{"_anim","_sb"},
"whinnied":{"_past"},
"whipped":{"_past"},
"whipper-in":{"_anim","_sb"},
"whippersnapper":{"_anim","_sb"},
"whippet":{"_anim"},
"Whipple":{"_anim","_nme","_prprn","_sb"},
"whipsawed":{"_past"},
"whir":{"_loc_sr"},
"whirl":{"_loc_sr"},
"whirled":{"_loc_sr","_past"},
"whirler":{"_anim","_sb"},
"whirling":{"_loc_sr"},
"whirred":{"_past"},
"whisk":{"_loc_sr"},
"whisked":{"_loc_sr","_past"},
"whisking":{"_loc_sr"},
"whispered":{"_past"},
"whisperer":{"_anim","_sb"},
"whistled":{"_past"},
"Whit":{"_prprn"},
"Whitaker":{"_prprn"},
"Whitbread":{"_prprn"},
"Whitby":{"_cty","_geo","_prprn"},
"white":{"_anim","_sb"},
"white-shoe":{"_anim","_sb"},
"whitefish":{"_anim"},
"Whitehall":{"_cty","_geo","_prprn"},
"Whitehead":{"_anim","_prprn","_sb"},
"Whiteley":{"_prprn"},
"whitened":{"_past"},
"whites":{"_anim","_sb"},
"whitethroat":{"_anim"},
"whitewashed":{"_past"},
"Whitman":{"_anim","_nme","_prprn","_sb"},
"Whitney":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Whitsun":{"_prprn"},
"Whitsunday":{"_prprn","_tme"},
"Whitsuntide":{"_prprn","_tme"},
"Whittier":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Whittington":{"_anim","_nme","_prprn","_sb"},
"whittle":{"_loc_sr"},
"whittled":{"_loc_sr","_past"},
"whizzed":{"_past"},
"who":{"_anim","_sb","_wh"},
"whoever":{"_anim","_sb","_wh"},
"wholesale":{"_loc_sr"},
"wholesaler":{"_anim","_sb"},
"wholesaling":{"_loc_sr"},
"whom":{"_anim","_sb","_wh"},
"whooped":{"_past"},
"whorehouse":{"_loc_sr"},
"whoremaster":{"_anim","_masc","_sb"},
"whores":{"_anim","_sb"},
"whoreson":{"_sb"},
"whose":{"_anim","_sb","_wh"},
"whupped":{"_past"},
"why":{"_wh"},
"Wichita":{"_cty","_geo","_prprn"},
"wicked":{"_past"},
"Wickliffe":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"widened":{"_past"},
"widow":{"_anim","_fem","_sb"},
"widowed":{"_past"},
"widower":{"_anim","_masc","_sb"},
"widowers":{"_anim","_masc","_sb"},
"widows":{"_anim","_fem","_sb"},
"Wieland":{"_anim","_nme","_prprn","_sb"},
"wielded":{"_past"},
"Wien":{"_anim","_nme","_prprn","_sb"},
"Wiener":{"_anim","_prprn","_sb"},
"Wiesbaden":{"_cty","_geo","_prprn"},
"Wiesel":{"_anim","_nme","_prprn","_sb"},
"Wiesenthal":{"_prprn"},
"wife":{"_anim","_fem","_sb"},
"wigged":{"_past"},
"Wiggins":{"_anim","_nme","_prprn","_sb"},
"wiggle":{"_loc_sr"},
"wiggled":{"_loc_sr","_past"},
"wiggling":{"_loc_sr"},
"wight":{"_anim","_sb"},
"wigwag":{"_loc_sr"},
"Wilberforce":{"_anim","_nme","_prprn","_sb"},
"Wilbur":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"wild":{"_loc_sr"},
"wildcat":{"_loc_sr"},
"wildcatter":{"_anim","_sb"},
"wildebeest":{"_anim"},
"wilderness":{"_loc_sr"},
"Wilfred":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Wilfrid":{"_prprn"},
"Wilhelm":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Wilhelmina":{"_anim","_nme","_prprn","_sb"},
"Wilkes":{"_anim","_nme","_prprn","_sb"},
"Wilkes-Barre":{"_cty","_geo","_prprn"},
"Wilkins":{"_anim","_nme","_prprn","_sb"},
"Wilkinson":{"_anim","_nme","_prprn","_sb"},
"will":{"_futr","_probabl"},
"Willamette":{"_geo","_prprn"},
"Willard":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"willed":{"_past"},
"William":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Williams":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Williamsburg":{"_cty","_geo","_prprn"},
"Williamson":{"_anim","_nme","_prprn","_sb"},
"Willie":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Willis":{"_anim","_fnme","_nme","_prprn","_sb"},
"Wilma":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Wilmington":{"_cty","_geo","_prprn"},
"wilted":{"_past"},
"Wilton":{"_cty","_geo","_prprn"},
"Wimbledon":{"_geo","_prprn"},
"wimp":{"_anim","_sb"},
"wimple":{"_loc_sr"},
"win":{"_loc_sr"},
"wince":{"_loc_sr"},
"winced":{"_loc_sr","_past"},
"Winchester":{"_cty","_geo","_prprn"},
"wincing":{"_loc_sr"},
"winded":{"_past"},
"Windhoek":{"_cty","_geo","_prprn"},
"window":{"_loc_sr"},
"window-dress":{"_loc_sr"},
"window-washing":{"_loc_sr"},
"windows":{"_loc_sr"},
"Windsor":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"windsurf":{"_loc_sr"},
"wined":{"_past"},
"winemaker":{"_anim","_sb"},
"winemakers":{"_anim","_sb"},
"winepress":{"_loc_sr"},
"winged":{"_loc_sr","_past"},
"winger":{"_anim","_sb"},
"winging":{"_loc_sr"},
"winked":{"_past"},
"Winnebago":{"_anim","_prprn","_sb"},
"winner":{"_anim","_sb"},
"winners":{"_anim","_sb"},
"Winnie":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"winning":{"_loc_sr"},
"Winnipeg":{"_cty","_geo","_prprn"},
"Winnipesaukee":{"_prprn"},
"winnowing":{"_loc_sr"},
"Winslet":{"_prprn"},
"Winslow":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Winston":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Winston-Salem":{"_cty","_geo","_prprn"},
"winter":{"_tme"},
"wintered":{"_past"},
"Winterthur":{"_cty","_geo","_prprn"},
"wintertime":{"_tme"},
"Winthrop":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Winton":{"_prprn"},
"wipe":{"_loc_sr"},
"wiped":{"_loc_sr","_past"},
"wipes":{"_loc_sr"},
"wiping":{"_loc_sr"},
"wired":{"_loc_sr","_past"},
"wireman":{"_anim","_sb"},
"wireworm":{"_anim"},
"wiring":{"_loc_sr"},
"Wis":{"_prprn","_stte"},
"Wis.":{"_prprn","_stte"},
"Wisconsin":{"_geo","_prprn","_stte"},
"wisecracked":{"_past"},
"Wiseman":{"_anim","_nme","_prprn","_sb"},
"wisent":{"_anim"},
"wished":{"_past"},
"Wister":{"_anim","_nme","_prprn","_sb"},
"witch":{"_loc_sr"},
"witches":{"_anim","_fem","_sb"},
"withdraw":{"_loc_sr","_psych"},
"withdrawer":{"_anim","_sb"},
"withdrawing":{"_loc_sr","_psych"},
"withdrawn":{"_loc_sr","_psych"},
"withdraws":{"_loc_sr","_psych"},
"withdrew":{"_loc_sr","_past","_psych"},
"wither":{"_loc_sr"},
"withered":{"_loc_sr","_past"},
"withering":{"_loc_sr"},
"Witherspoon":{"_anim","_nme","_prprn","_sb"},
"withhold":{"_loc_sr"},
"withholder":{"_anim","_sb"},
"withholding":{"_loc_sr"},
"withholds":{"_loc_sr"},
"withstander":{"_anim","_sb"},
"witness":{"_anim","_sb"},
"witnessed":{"_past"},
"witnesser":{"_anim","_sb"},
"witnesses":{"_anim","_sb"},
"Witt":{"_prprn"},
"Wittenberg":{"_cty","_geo","_prprn"},
"wives":{"_anim","_fem","_sb"},
"wiz":{"_anim","_sb"},
"wizard":{"_anim","_masc","_sb"},
"wizards":{"_anim","_masc","_sb"},
"WLAN":{"_prprn"},
"Wo":{"_prprn"},
"wobble":{"_loc_sr"},
"wobbled":{"_loc_sr","_past"},
"wobbling":{"_loc_sr"},
"woke":{"_past"},
"wolf-sized":{"_anim"},
"wolf-whistle":{"_anim"},
"Wolfe":{"_anim","_nme","_prprn","_sb"},
"Wolfensohn":{"_prprn"},
"Wolfsburg":{"_cty","_geo","_prprn"},
"Wolof":{"_anim","_prprn","_sb"},
"wolves":{"_anim"},
"womaniser":{"_anim","_sb"},
"womb-leasing":{"_loc_sr"},
"wombs":{"_loc_sr"},
"women":{"_anim","_fem","_sb"},
"won":{"_loc_sr","_past"},
"wondered":{"_past"},
"wonted":{"_past"},
"Woodbridge":{"_cty","_geo","_prprn"},
"woodchucks":{"_anim"},
"woodcutters":{"_anim","_sb"},
"wooded":{"_past"},
"woodland":{"_loc_sr"},
"woodlouse":{"_anim"},
"Woodrow":{"_prprn"},
"Woods":{"_anim","_prprn","_sb"},
"woodshed":{"_loc_sr"},
"Woodstock":{"_cty","_geo","_prprn"},
"Woodward":{"_anim","_nme","_prprn","_sb"},
"woodworms":{"_anim"},
"wooed":{"_past"},
"Woolf":{"_anim","_nme","_prprn","_sb"},
"woolgatherer":{"_anim","_sb"},
"woolgathering":{"_loc_sr"},
"Woollcott":{"_anim","_nme","_prprn","_sb"},
"Woolworth":{"_anim","_nme","_prprn","_sb"},
"Wootton":{"_prprn"},
"wop":{"_anim","_sb"},
"wops":{"_anim","_sb"},
"Worcester":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Worcestershire":{"_prprn"},
"Word":{"_prprn"},
"worded":{"_loc_sr","_past"},
"wording":{"_loc_sr"},
"wordsmith":{"_anim","_sb"},
"Wordsworth":{"_anim","_nme","_prprn","_sb"},
"wore":{"_loc_sr","_past"},
"work-in":{"_loc_sr"},
"workaholic":{"_anim","_sb"},
"workbasket":{"_loc_sr"},
"workday":{"_tme"},
"workdays":{"_tme"},
"worked":{"_past"},
"worker":{"_anim","_sb"},
"workers":{"_anim","_sb"},
"workhorse":{"_anim","_sb"},
"workmen":{"_anim","_masc","_sb"},
"workplace":{"_loc_sr"},
"workplaces":{"_loc_sr"},
"workshop":{"_loc_sr"},
"workshops":{"_loc_sr"},
"workstation":{"_loc_sr"},
"workstations":{"_loc_sr"},
"world":{"_loc_sr"},
"world-wide":{"_loc_sr"},
"worldling":{"_anim","_sb"},
"worlds":{"_loc_sr"},
"worms":{"_anim"},
"worried":{"_past","_psych"},
"worriers":{"_anim","_sb"},
"worry":{"_psych"},
"worrying":{"_psych"},
"worsened":{"_past"},
"worshiper":{"_anim","_sb"},
"worshipers":{"_anim","_sb"},
"worshipped":{"_past"},
"worshipper":{"_anim","_sb"},
"worshippers":{"_anim","_sb"},
"worthy":{"_anim","_sb"},
"would":{"_past","_probabl"},
"wound":{"_past"},
"wounded":{"_past"},
"wounds":{"_loc_sr"},
"wowed":{"_past"},
"Wozniak":{"_prprn"},
"wracked":{"_past"},
"wrangled":{"_past"},
"wrangler":{"_anim","_sb"},
"wranglers":{"_anim","_sb"},
"wrap":{"_loc_sr"},
"wrapping":{"_loc_sr"},
"wreaking":{"_loc_sr"},
"wreathe":{"_loc_sr"},
"wreathed":{"_loc_sr","_past"},
"wrecked":{"_past"},
"wren":{"_anim"},
"wrenched":{"_past"},
"wrester":{"_anim","_sb"},
"wrestled":{"_past"},
"wriggle":{"_loc_sr"},
"wriggled":{"_loc_sr","_past"},
"Wright":{"_anim","_prprn","_sb"},
"wrinkled":{"_past"},
"write":{"_loc_sr"},
"writer":{"_anim","_sb"},
"writers":{"_anim","_sb"},
"writes":{"_loc_sr"},
"writhed":{"_loc_sr","_past"},
"writhing":{"_loc_sr"},
"writing":{"_loc_sr"},
"written":{"_loc_sr"},
"wrongdoers":{"_anim","_sb"},
"wronged":{"_past"},
"wrote":{"_loc_sr","_past"},
"wrought":{"_past"},
"wrought-iron":{"_past"},
"Wu":{"_prprn"},
"Wycliffe":{"_anim","_nme","_prprn","_sb"},
"Wyeth":{"_anim","_nme","_prprn","_sb"},
"Wyndham":{"_prprn"},
"Wyo":{"_prprn","_stte"},
"Wyo.":{"_prprn","_stte"},
"Wyoming":{"_cty","_geo","_prprn","_stte"},
"wysiwyg":{"_prprn"},
"X-chromosome":{"_prprn"},
"X-rayed":{"_past"},
"X-rays":{"_prprn"},
"Xanadu":{"_loc_sr","_prprn"},
"Xanax":{"_prprn"},
"Xavier":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Xe":{"_prprn"},
"Xerox":{"_prprn"},
"Xhosa":{"_anim","_prprn","_sb"},
"Xiang":{"_prprn"},
"xl":{"_prprn"},
"Xmas":{"_prprn","_tme"},
"Xu":{"_prprn"},
"ya":{"_anim","_sb"},
"yacht":{"_fem","_loc_sr"},
"yachters":{"_anim","_sb"},
"yachting":{"_loc_sr"},
"yachts":{"_fem","_loc_sr"},
"yachtsman":{"_anim","_masc","_sb"},
"yachtsmen":{"_anim","_masc","_sb"},
"yahoo":{"_anim","_sb"},
"yahoos":{"_anim","_sb"},
"Yajur-Veda":{"_prprn"},
"Yakima":{"_anim","_cty","_geo","_prprn","_sb"},
"yaks":{"_anim"},
"Yakut":{"_anim","_prprn","_sb"},
"Yale":{"_anim","_nme","_prprn","_sb"},
"Yalta":{"_cty","_geo","_prprn"},
"Yamashita":{"_anim","_nme","_prprn","_sb"},
"yammer":{"_loc_sr"},
"Yangtze":{"_prprn"},
"yanked":{"_past"},
"Yankees":{"_anim","_prprn","_sb"},
"yanker":{"_anim","_sb"},
"yap":{"_anim"},
"Yaqui":{"_anim","_prprn","_sb"},
"Yardie":{"_prprn"},
"yawn":{"_loc_sr"},
"yawning":{"_loc_sr"},
"yaws":{"_sb"},
"year":{"_tme"},
"year-long":{"_tme"},
"year-round":{"_tme"},
"yearling":{"_anim"},
"yearlings":{"_anim"},
"yearner":{"_anim","_sb"},
"years":{"_tme"},
"Yeats":{"_anim","_nme","_prprn","_sb"},
"yellowed":{"_past"},
"Yellowknife":{"_cty","_geo","_prprn"},
"Yellowstone":{"_geo","_prprn"},
"yelped":{"_past"},
"Yeltsin":{"_prprn"},
"Yemen":{"_cntry","_geo","_prprn"},
"Yemenis":{"_anim","_prprn","_sb"},
"yenta":{"_sb"},
"yeoman":{"_anim","_sb"},
"Yerevan":{"_cty","_geo","_prprn"},
"yes-man":{"_anim","_sb"},
"yesterday":{"_tme"},
"yeti":{"_anim"},
"yid":{"_anim","_sb"},
"Yiddish":{"_prprn"},
"yielded":{"_past"},
"yielder":{"_anim","_sb"},
"yodeller":{"_anim","_sb"},
"yogi":{"_anim","_sb"},
"yokel":{"_anim","_sb"},
"yokels":{"_anim","_sb"},
"Yokohama":{"_cty","_geo","_prprn"},
"Yokosuka":{"_cty","_geo","_prprn"},
"Yolanda":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Yonkers":{"_cty","_geo","_prprn"},
"York":{"_anim","_cty","_geo","_nme","_prprn","_sb"},
"Yorkshire":{"_geo","_prprn"},
"Yorktown":{"_geo","_prprn"},
"you":{"_anim","_sb"},
"young":{"_anim","_sb"},
"youngster":{"_anim","_sb"},
"youngsters":{"_anim","_sb"},
"Youngstown":{"_cty","_geo","_prprn"},
"younker":{"_sb"},
"yourself":{"_anim","_sb"},
"yourselves":{"_anim","_sb"},
"youth":{"_anim","_sb","_tme"},
"Yquem":{"_prprn"},
"yr":{"_tme"},
"yrs":{"_tme"},
"yrs.":{"_tme"},
"Yu":{"_prprn"},
"Yucatec":{"_anim","_prprn","_sb"},
"Yugoslav":{"_anim","_prprn","_sb"},
"Yugoslavia":{"_cntry","_geo","_prprn"},
"Yugoslavs":{"_anim","_prprn","_sb"},
"yuk":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Yuletide":{"_prprn"},
"Yuma":{"_anim","_cty","_geo","_prprn","_sb"},
"Yuman":{"_prprn"},
"Yvonne":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Zacharias":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Zachary":{"_anim","_fnme","_masc","_nme","_prprn","_sb"},
"Zagreb":{"_cty","_geo","_prprn"},
"Zama":{"_geo","_prprn"},
"Zambia":{"_cntry","_geo","_prprn"},
"Zambian":{"_anim","_prprn","_sb"},
"Zamora":{"_cty","_geo","_prprn"},
"Zanzibar":{"_cty","_geo","_prprn"},
"Zapata":{"_anim","_nme","_prprn","_sb"},
"Zapotec":{"_anim","_prprn","_sb"},
"Zapotecan":{"_prprn"},
"Zappa":{"_prprn"},
"zapped":{"_past"},
"Zealand":{"_geo","_prprn"},
"zealots":{"_anim","_sb"},
"zebra":{"_anim"},
"zebu":{"_anim"},
"Zechariah":{"_anim","_nme","_prprn","_sb"},
"Zeffirelli":{"_prprn"},
"Zelig":{"_prprn"},
"Zellweger":{"_prprn"},
"Zemlinsky":{"_prprn"},
"Zen":{"_prprn"},
"Zend-Avesta":{"_prprn"},
"Zephaniah":{"_anim","_fnme","_nme","_prprn","_sb"},
"Zeppelin":{"_anim","_prprn","_sb"},
"Zermatt":{"_geo","_prprn"},
"zero":{"_num","_quant"},
"zeroed":{"_past"},
"zeros":{"_num","_quant"},
"Zetland":{"_prprn"},
"Zeus":{"_anim","_masc","_nme","_prprn","_sb"},
"Zhejiang":{"_geo","_prprn","_stte"},
"Zhou":{"_anim","_nme","_prprn","_sb"},
"Zhu":{"_prprn"},
"Ziegfeld":{"_anim","_nme","_prprn","_sb"},
"Ziegler":{"_anim","_nme","_prprn","_sb"},
"zigzagging":{"_loc_sr"},
"zilch":{"_anim","_sb"},
"zillion":{"_num","_quant"},
"zillions":{"_num","_quant"},
"Zimbabwe":{"_cntry","_cty","_geo","_prprn"},
"Zimbabwean":{"_anim","_prprn","_sb"},
"Zimmer":{"_prprn"},
"Zinjanthropus":{"_prprn"},
"Zion":{"_cty","_geo","_prprn"},
"Zionism":{"_prprn"},
"Zionist":{"_prprn"},
"zip":{"_loc_sr"},
"Zoe":{"_anim","_fem","_fnme","_nme","_prprn","_sb"},
"Zola":{"_anim","_nme","_prprn","_sb"},
"zombies":{"_anim","_sb"},
"zone":{"_loc_sr"},
"zoned":{"_loc_sr","_past"},
"zones":{"_loc_sr"},
"zookeeper":{"_anim","_sb"},
"zoologist":{"_anim","_sb"},
"zoom":{"_loc_sr"},
"zoomed":{"_loc_sr","_past"},
"zoophyte":{"_anim"},
"Zorn":{"_anim","_nme","_prprn","_sb"},
"Zoroastrian":{"_prprn"},
"Zoroastrianism":{"_prprn"},
"Zug":{"_prprn"},
"Zulu":{"_anim","_prprn","_sb"},
"Zuni":{"_prprn"},
"Zurich":{"_cty","_geo","_prprn"},
"Zweig":{"_anim","_nme","_prprn","_sb"},
"Zworykin":{"_anim","_nme","_prprn","_sb"},
"Zyrian":{"_prprn"},
"they":{"_sb"},
"them":{"_sb"},
"themselves":{"_sb","_self"},
"her":{"_sb"},
"I":{"_sb"},
"i":{"_sb"},
",":{"_]","_["}, # right wall 
".":{"_]"},
"!":{"_]"},
"?":{"_]"},
"'":{"_]","_["},
'"':{"_]","_["},
}