# word pairs with editdistance(w1,w2) = 1
wordlist_ed1 = {  
'a':	{'ab','ac','ad','af','ag','ai','ak','al','am','an','ar','as','at','au','av','ax','az','b','ba','c','ca','d','da','e','ea','f','fa','g','ga','h','ha','i','ia','j','k','ka','l','la','ma','na','o','p','pa','q','r','ra','sa','t','ta','u','v','va','w','wa','x','y','ya','z','za'},
'aaron':	{'akron','apron','baron'},
'ab':	{'a','aba','abc','abm','abs','ac','ad','af','ag','ai','ak','al','alb','am','an','ar','as','at','au','av','ax','az','b','bb','cab','dab','db','eb','fab','gab','gb','jab','kb','lab','lb','mb','nab','nb','ob','pb','rb','sb','tab','tb','yb'},
'aba':	{'ab','abc','abm','abs','ada','aka','ala','ana','ara','ba','baba','mba','saba','sba'},
'abandon':	{'abandons'},
'abandons':	{'abandon'},
'abbreviation':	{'abbreviations'},
'abbreviations':	{'abbreviation'},
'abc':	{'ab','aba','abm','abs','ac','arc','bc','cbc'},
'abel':	{'axel','babel','bel','label'},
'aberration':	{'aberrations'},
'aberrations':	{'aberration'},
'abide':	{'abode','aide','aside'},
'abiding':	{'aiding'},
'ability':	{'agility'},
'able':	{'abler','ably','ale','axle','cable','fable','gable','sable','table'},
'abler':	{'able','ambler'},
'ably':	{'able','ally'},
'abm':	{'ab','aba','abc','abs','aim','am','arm','atm','bm'},
'aboard':	{'board'},
'abode':	{'abide','above','anode','bode'},
'abort':	{'about'},
'abortion':	{'abortions'},
'abortions':	{'abortion'},
'abound':	{'around','bound'},
'about':	{'abort','bout'},
'above':	{'abode'},
'abrasive':	{'abrasives'},
'abrasives':	{'abrasive'},
'abreast':	{'breast'},
'abridged':	{'bridged'},
'abroad':	{'broad'},
'abs':	{'ab','aba','abc','abm','ads','ans','as','ass','bbs','bs','cabs','labs','pbs','tabs'},
'absence':	{'absences'},
'absences':	{'absence'},
'absent':	{'assent'},
'absorb':	{'absorbs'},
'absorbed':	{'absorber'},
'absorber':	{'absorbed'},
'absorbs':	{'absorb'},
'absorption':	{'adsorption'},
'abstract':	{'abstracts'},
'abstraction':	{'abstractions'},
'abstractions':	{'abstraction'},
'abstracts':	{'abstract'},
'abundance':	{'abundances'},
'abundances':	{'abundance'},
'abuse':	{'abused','abuser','abuses','amuse'},
'abused':	{'abuse','abuser','abuses','amused'},
'abuser':	{'abuse','abused','abusers','abuses'},
'abusers':	{'abuser','abuses'},
'abuses':	{'abuse','abused','abuser','abusers','amuses','buses'},
'abusing':	{'amusing'},
'ac':	{'a','ab','abc','ace','act','ad','af','ag','ai','ak','al','am','an','ar','arc','as','at','au','av','ax','az','bc','c','cc','dc','ec','kc','lac','mac','mc','nc','pac','pc','sac','sc','tc','vac','wac'},
'acacia':	{'acadia'},
'academia':	{'academic'},
'academic':	{'academia','academics'},
'academics':	{'academic','academies'},
'academies':	{'academics'},
'acadia':	{'acacia','arcadia'},
'accelerate':	{'accelerated','accelerates'},
'accelerated':	{'accelerate','accelerates'},
'accelerates':	{'accelerate','accelerated'},
'accelerator':	{'accelerators'},
'accelerators':	{'accelerator'},
'accent':	{'accents','accept','ascent'},
'accented':	{'accepted'},
'accents':	{'accent','accepts'},
'accept':	{'accent','accepts'},
'accepted':	{'accented'},
'accepts':	{'accents','accept'},
'accessed':	{'accesses'},
'accesses':	{'accessed'},
'accident':	{'accidents'},
'accidental':	{'occidental'},
'accidents':	{'accident'},
'accommodate':	{'accommodated','accommodates'},
'accommodated':	{'accommodate','accommodates'},
'accommodates':	{'accommodate','accommodated'},
'accommodation':	{'accommodations'},
'accommodations':	{'accommodation'},
'accompanied':	{'accompanies'},
'accompanies':	{'accompanied'},
'accomplished':	{'accomplishes'},
'accomplishes':	{'accomplished'},
'accomplishment':	{'accomplishments'},
'accomplishments':	{'accomplishment'},
'accord':	{'accords'},
'accords':	{'accord'},
'account':	{'accounts'},
'accountant':	{'accountants'},
'accountants':	{'accountant'},
'accounts':	{'account'},
'accrual':	{'accruals'},
'accruals':	{'accrual'},
'accrue':	{'accrued'},
'accrued':	{'accrue'},
'accumulate':	{'accumulated','accumulates'},
'accumulated':	{'accumulate','accumulates'},
'accumulates':	{'accumulate','accumulated'},
'accumulation':	{'accumulations'},
'accumulations':	{'accumulation'},
'accusation':	{'accusations'},
'accusations':	{'accusation'},
'accuse':	{'accused','accuses'},
'accused':	{'accuse','accuses'},
'accuses':	{'accuse','accused'},
'accustom':	{'accustoms'},
'accustoms':	{'accustom'},
'ace':	{'ac','aces','ache','acme','acne','acre','act','ade','age','ale','ape','are','ate','ave','awe','axe','aye','ce','face','ice','lace','mace','pace','race'},
'aces':	{'ace','aches','acres','acts','ages','ales','apes','ares','axes','ayes','faces','laces','paces','races'},
'ache':	{'ace','ached','aches','acme','acne','acre','ashe','cache'},
'ached':	{'ache','aches','acted','arched','cached'},
'aches':	{'aces','ache','ached','acres','arches','ashes','caches'},
'achieve':	{'achieved','achieves'},
'achieved':	{'achieve','achieves'},
'achievement':	{'achievements'},
'achievements':	{'achievement'},
'achieves':	{'achieve','achieved'},
'aching':	{'acting','arching','caching'},
'acid':	{'acids','aid','amid','arid','avid','cid'},
'acids':	{'acid','aids'},
'acknowledge':	{'acknowledged','acknowledges'},
'acknowledged':	{'acknowledge','acknowledges'},
'acknowledgement':	{'acknowledgements','acknowledgment'},
'acknowledgements':	{'acknowledgement','acknowledgments'},
'acknowledges':	{'acknowledge','acknowledged'},
'acknowledgment':	{'acknowledgement','acknowledgments'},
'acknowledgments':	{'acknowledgements','acknowledgment'},
'acme':	{'ace','ache','acne','acre'},
'acne':	{'ace','ache','acme','acre','anne'},
'acorn':	{'adorn','corn','scorn'},
'acoustic':	{'acoustics'},
'acoustics':	{'acoustic'},
'acquaintance':	{'acquaintances'},
'acquaintances':	{'acquaintance'},
'acquire':	{'acquired','acquires'},
'acquired':	{'acquire','acquires'},
'acquires':	{'acquire','acquired'},
'acquisition':	{'acquisitions'},
'acquisitions':	{'acquisition'},
'acre':	{'ace','ache','acme','acne','acres','are'},
'acres':	{'aces','aches','acre','apres','ares'},
'acronym':	{'acronyms'},
'acronyms':	{'acronym'},
'across':	{'cross'},
'act':	{'ac','ace','acts','aft','alt','ant','apt','art','at','ct','fact','oct','pact','pct','tact'},
'acted':	{'ached'},
'acting':	{'aching'},
'action':	{'actions','auction','faction'},
'actions':	{'action','auctions','factions'},
'activate':	{'activated','activates'},
'activated':	{'activate','activates'},
'activates':	{'activate','activated'},
'activism':	{'activist'},
'activist':	{'activism','activists'},
'activists':	{'activist'},
'actor':	{'actors','astor','factor'},
'actors':	{'actor','factors'},
'acts':	{'aces','act','ants','arts','facts'},
'actual':	{'factual'},
'actuator':	{'actuators'},
'actuators':	{'actuator'},
'acute':	{'cute'},
'ad':	{'a','ab','ac','ada','add','ade','adj','ado','adp','ads','af','ag','ai','aid','ak','al','am','an','and','ar','as','at','au','av','ax','az','bad','cad','cd','d','dad','dd','ed','fad','gd','had','id','lad','mad','md','nd','od','pad','pd','rad','sad','sd','tad','vd','wad'},
'ada':	{'aba','ad','adam','add','ade','adj','ado','adp','ads','aka','ala','ana','ara','da','dada','eda','fda','ida','nada','pda'},
'adam':	{'ada','adams','dam','madam'},
'adams':	{'adam','dams'},
'adapt':	{'adapts','adept','adopt'},
'adaptation':	{'adaptations'},
'adaptations':	{'adaptation'},
'adapted':	{'adapter','adopted'},
'adapter':	{'adapted','adapters','adaptor'},
'adapters':	{'adapter','adaptors','adopters'},
'adapting':	{'adopting'},
'adaptive':	{'adoptive'},
'adaptor':	{'adapter','adaptors'},
'adaptors':	{'adapters','adaptor'},
'adapts':	{'adapt','adopts'},
'add':	{'ad','ada','addi','adds','ade','adj','ado','adp','ads','aid','and','dd','odd'},
'added':	{'adder','aided','padded'},
'adder':	{'added','alder','ladder','madder','sadder'},
'addi':	{'add','adds'},
'addict':	{'addicts'},
'addiction':	{'addictions','addition'},
'addictions':	{'addiction','additions'},
'addictive':	{'additive'},
'addicts':	{'addict'},
'adding':	{'aiding','padding'},
'addition':	{'addiction','additions','audition'},
'additions':	{'addictions','addition','auditions'},
'additive':	{'addictive','additives'},
'additives':	{'additive'},
'addressed':	{'addressee','addresses'},
'addressee':	{'addressed','addresses'},
'addresses':	{'addressed','addressee'},
'adds':	{'add','addi','ads','aids','dds','odds'},
'ade':	{'ace','ad','ada','add','aden','adj','ado','adp','ads','age','aide','ale','ape','are','ate','ave','awe','axe','aye','bade','de','fade','jade','made','ode','sade','wade'},
'aden':	{'ade','amen','aren','den','eden','laden'},
'adept':	{'adapt','adopt'},
'adhere':	{'adhered','adheres'},
'adhered':	{'adhere','adheres'},
'adheres':	{'adhere','adhered'},
'adhesive':	{'adhesives'},
'adhesives':	{'adhesive'},
'adj':	{'ad','ada','add','ade','ado','adp','ads','dj'},
'adjective':	{'adjectives'},
'adjectives':	{'adjective'},
'adjust':	{'adjusts'},
'adjusted':	{'adjuster'},
'adjuster':	{'adjusted'},
'adjustment':	{'adjustments'},
'adjustments':	{'adjustment'},
'adjusts':	{'adjust'},
'admin':	{'admins','admit','armin'},
'administer':	{'administers'},
'administers':	{'administer'},
'administrate':	{'administrates'},
'administrates':	{'administrate'},
'administration':	{'administrations'},
'administrations':	{'administration'},
'administrator':	{'administrators'},
'administrators':	{'administrator'},
'admins':	{'admin','admits'},
'admirable':	{'admirably'},
'admirably':	{'admirable'},
'admire':	{'admired','admires'},
'admired':	{'admire','admires'},
'admirers':	{'admires'},
'admires':	{'admire','admired','admirers'},
'admission':	{'admissions'},
'admissions':	{'admission'},
'admit':	{'admin','admits'},
'admits':	{'admins','admit'},
'ado':	{'ad','ada','add','ade','adj','adp','ads','ago','apo','do'},
'adobe':	{'adore'},
'adolescent':	{'adolescents'},
'adolescents':	{'adolescent'},
'adopt':	{'adapt','adept','adopts'},
'adopted':	{'adapted'},
'adopters':	{'adapters'},
'adopting':	{'adapting'},
'adoption':	{'adoptions'},
'adoptions':	{'adoption'},
'adoptive':	{'adaptive'},
'adopts':	{'adapts','adopt'},
'adore':	{'adobe','adored','adorn'},
'adored':	{'adore','adorned'},
'adorn':	{'acorn','adore'},
'adorned':	{'adored'},
'adp':	{'ad','ada','add','ade','adj','ado','ads','alp','amp','app','asp','atp','dp','edp','gdp'},
'ads':	{'abs','ad','ada','add','adds','ade','adj','ado','adp','aids','ans','as','ass','dads','dds','eds','lads','pads'},
'adsorption':	{'absorption'},
'adult':	{'adults'},
'adults':	{'adult'},
'advance':	{'advanced','advances'},
'advanced':	{'advance','advances'},
'advancement':	{'advancements'},
'advancements':	{'advancement'},
'advances':	{'advance','advanced'},
'advantage':	{'advantaged','advantages'},
'advantaged':	{'advantage','advantages'},
'advantages':	{'advantage','advantaged'},
'advent':	{'advert'},
'adventure':	{'adventurer','adventures'},
'adventurer':	{'adventure','adventurers','adventures'},
'adventurers':	{'adventurer','adventures'},
'adventures':	{'adventure','adventurer','adventurers'},
'adverse':	{'averse'},
'advert':	{'advent','adverts','avert'},
'advertise':	{'advertised','advertiser','advertises'},
'advertised':	{'advertise','advertiser','advertises'},
'advertisement':	{'advertisements'},
'advertisements':	{'advertisement'},
'advertiser':	{'advertise','advertised','advertisers','advertises'},
'advertisers':	{'advertiser','advertises'},
'advertises':	{'advertise','advertised','advertiser','advertisers'},
'adverts':	{'advert'},
'advice':	{'advise'},
'advise':	{'advice','advised','adviser','advises'},
'advised':	{'advise','adviser','advises'},
'adviser':	{'advise','advised','advisers','advises'},
'advisers':	{'adviser','advises','advisors'},
'advises':	{'advise','advised','adviser','advisers'},
'advisors':	{'advisers','advisory'},
'advisory':	{'advisors'},
'advocate':	{'advocated','advocates'},
'advocated':	{'advocate','advocates'},
'advocates':	{'advocate','advocated'},
'aer':	{'air','apr','ar','ber','der','er','fer','ger','her','ker','per','yer'},
'aerial':	{'aerials','atrial','serial'},
'aerials':	{'aerial','serials'},
'aerobic':	{'aerobics'},
'aerobics':	{'aerobic'},
'aeroplane':	{'aeroplanes'},
'aeroplanes':	{'aeroplane'},
'aerosol':	{'aerosols'},
'aerosols':	{'aerosol'},
'aesthetic':	{'aesthetics','anesthetic'},
'aesthetics':	{'aesthetic'},
'af':	{'a','ab','ac','ad','aft','ag','ai','ak','al','am','an','ar','as','at','au','av','ax','az','cf','f','ff','gf','hf','if','of','raf','rf'},
'afar':	{'agar','far'},
'affair':	{'affairs'},
'affairs':	{'affair'},
'affect':	{'affects','effect'},
'affected':	{'effected'},
'affecting':	{'effecting'},
'affection':	{'affections'},
'affections':	{'affection'},
'affective':	{'effective'},
'affectively':	{'effectively'},
'affects':	{'affect','effects'},
'affidavit':	{'affidavits'},
'affidavits':	{'affidavit'},
'affiliate':	{'affiliated','affiliates'},
'affiliated':	{'affiliate','affiliates'},
'affiliates':	{'affiliate','affiliated'},
'affiliation':	{'affiliations'},
'affiliations':	{'affiliation'},
'affirm':	{'affirms'},
'affirms':	{'affirm'},
'affluent':	{'effluent'},
'afford':	{'affords'},
'affords':	{'afford'},
'afield':	{'field'},
'afloat':	{'float'},
'africa':	{'african'},
'african':	{'africa'},
'afro':	{'fro'},
'aft':	{'act','af','alt','ant','apt','art','at','daft','eft','ft','oft','raft','taft'},
'after':	{'alter','aster'},
'afternoon':	{'afternoons'},
'afternoons':	{'afternoon'},
'afterward':	{'afterwards'},
'afterwards':	{'afterward'},
'ag':	{'a','ab','ac','ad','af','age','ago','ai','ak','al','am','an','ang','ar','as','at','au','aug','av','ax','az','bag','dag','fag','g','gag','hg','jag','kg','lag','mag','mg','nag','rag','sag','tag'},
'again':	{'gain'},
'agar':	{'afar','gar'},
'agate':	{'gate'},
'age':	{'ace','ade','ag','aged','ages','ago','ale','ape','are','ate','ave','awe','axe','aye','cage','gage','ge','page','rage','sage','wage'},
'aged':	{'age','ages','axed','caged','waged'},
'ageing':	{'aging'},
'agenda':	{'agendas'},
'agendas':	{'agenda'},
'agent':	{'agents','argent','gent'},
'agents':	{'agent','gents'},
'ages':	{'aces','age','aged','ales','apes','ares','axes','ayes','cages','pages','sages','wages'},
'aggregate':	{'aggregated','aggregates'},
'aggregated':	{'aggregate','aggregates'},
'aggregates':	{'aggregate','aggregated'},
'agility':	{'ability'},
'aging':	{'ageing','axing','caging','paging','raging','waging'},
'ago':	{'ado','ag','age','apo','argo','ego','go'},
'agra':	{'ara','aura'},
'agree':	{'agreed','agrees'},
'agreed':	{'agree','agrees','greed'},
'agreement':	{'agreements'},
'agreements':	{'agreement'},
'agrees':	{'agree','agreed'},
'ahead':	{'head'},
'ahem':	{'chem','hem','them'},
'ai':	{'a','ab','ac','ad','af','ag','aid','aim','air','ak','al','ali','am','an','ar','as','at','au','av','ax','az','bai','bi','ci','di','gi','hi','i','ii','ji','ki','li','mi','ni','pi','qi','ri','sai','si','tai','ti','vi','wai','wi','xi','yi'},
'aid':	{'acid','ad','add','ai','aide','aids','aim','air','amid','and','arid','avid','bid','cid','did','hid','id','kid','laid','lid','maid','mid','paid','raid','rid','said'},
'aide':	{'abide','ade','aid','aided','aides','aids','aside','hide','ride','side','tide','wide'},
'aided':	{'added','aide','aides','aimed','aired','raided','sided'},
'aides':	{'aide','aided','aids','andes','hides','rides','sides','tides'},
'aiding':	{'abiding','adding','ailing','aiming','airing','hiding','riding','siding'},
'aids':	{'acids','adds','ads','aid','aide','aides','aims','airs','bids','kids','lids','maids','raids','rids','sids'},
'ailing':	{'aiding','aiming','airing','failing','filing','mailing','nailing','piling','railing','sailing','tiling','wailing'},
'aim':	{'abm','ai','aid','aims','air','am','arm','atm','dim','him','rim','vim'},
'aimed':	{'aided','aired','armed','timed'},
'aiming':	{'aiding','ailing','airing','timing'},
'aims':	{'aids','aim','airs','arms','rims'},
'air':	{'aer','ai','aid','aim','airs','airy','apr','ar','fair','fir','hair','ir','lair','pair','sir'},
'airbag':	{'airbags'},
'airbags':	{'airbag'},
'aired':	{'aided','aimed','fired','haired','hired','paired','tired','wired'},
'airfare':	{'airfares'},
'airfares':	{'airfare'},
'airing':	{'aiding','ailing','aiming','firing','hiring','pairing','tiring','wiring'},
'airline':	{'airlines'},
'airlines':	{'airline'},
'airplane':	{'airplanes'},
'airplanes':	{'airplane'},
'airport':	{'airports'},
'airports':	{'airport'},
'airs':	{'aids','aims','air','airy','fairs','hairs','irs','pairs'},
'airway':	{'fairway'},
'airy':	{'air','airs','awry','dairy','fairy','hairy'},
'aisle':	{'aisles','isle','lisle'},
'aisles':	{'aisle'},
'ak':	{'a','ab','ac','ad','af','ag','ai','aka','al','am','an','ar','ark','as','ask','at','au','av','ax','az','bk','k','oak','ok','uk','yak'},
'aka':	{'aba','ada','ak','ala','ana','ara','ka','ska'},
'akin':	{'kin','skin'},
'akron':	{'aaron','apron'},
'al':	{'a','ab','ac','ad','af','ag','ai','ak','ala','alb','ale','ali','all','alp','alt','am','an','ar','as','asl','at','au','av','ax','az','bl','cl','dal','el','fl','gal','il','l','ll','mal','ml','pal','tl','xl'},
'ala':	{'aba','ada','aka','al','alas','alb','ale','ali','all','alla','alp','alt','ana','ara','gala','la','mala','ola','tala'},
'alarm':	{'alarms'},
'alarms':	{'alarm'},
'alas':	{'ala','ales','alias','alps','atlas'},
'alaska':	{'alaskan'},
'alaskan':	{'alaska'},
'alb':	{'ab','al','ala','ale','ali','all','alp','alt','lb','llb'},
'albania':	{'albanian'},
'albanian':	{'albania'},
'albeit':	{'albert'},
'albert':	{'albeit','alberta','alert'},
'alberta':	{'albert'},
'album':	{'albums','alum'},
'albums':	{'album'},
'alcoholic':	{'alcoholics'},
'alcoholics':	{'alcoholic'},
'alder':	{'adder','alger','alter','calder','elder','older'},
'ale':	{'able','ace','ade','age','al','ala','alb','ales','ali','all','aloe','alp','alt','ape','are','ate','ave','awe','axe','axle','aye','bale','dale','gale','hale','le','male','ole','pale','sale','tale','vale','yale'},
'alert':	{'albert','alerts','avert'},
'alerted':	{'averted'},
'alerts':	{'alert'},
'ales':	{'aces','ages','alas','ale','alps','apes','ares','axes','axles','ayes','bales','les','males','pales','sales','tales','wales'},
'algae':	{'algal'},
'algal':	{'algae'},
'algebra':	{'algebras'},
'algebras':	{'algebra'},
'alger':	{'alder','alter','anger','auger'},
'algeria':	{'algerian'},
'algerian':	{'algeria'},
'algorithm':	{'algorithms'},
'algorithms':	{'algorithm'},
'ali':	{'ai','al','ala','alb','ale','all','alp','alt','bali','cali','dali','kali','li','mali'},
'alias':	{'alas','arias'},
'alien':	{'aliens','align','allen','lien'},
'alienate':	{'alienated'},
'alienated':	{'alienate'},
'aliens':	{'alien','liens'},
'align':	{'alien'},
'alignment':	{'alignments'},
'alignments':	{'alignment'},
'alike':	{'alive','like'},
'alive':	{'alike','clive','live','olive'},
'all':	{'al','ala','alb','ale','ali','alla','ally','alp','alt','asl','ball','call','ell','fall','gall','hall','ill','ll','mall','pall','tall','wall'},
'alla':	{'ala','all','allah','ally','calla'},
'allah':	{'alla'},
'allegation':	{'allegations'},
'allegations':	{'allegation'},
'allege':	{'alleged','alleges','allele'},
'alleged':	{'allege','alleges'},
'alleges':	{'allege','alleged','alleles'},
'allele':	{'allege','alleles'},
'alleles':	{'alleges','allele'},
'allen':	{'alien','alley','fallen'},
'allergen':	{'allergens'},
'allergens':	{'allergen'},
'alley':	{'allen','alleys','alloy','ally','galley','halley','valley'},
'alleys':	{'alley','alloys','valleys'},
'alliance':	{'alliances'},
'alliances':	{'alliance'},
'allied':	{'allies','rallied','tallied'},
'allies':	{'allied','allis','rallies'},
'allis':	{'allies'},
'allocate':	{'allocated','allocates'},
'allocated':	{'allocate','allocates'},
'allocates':	{'allocate','allocated'},
'allocation':	{'allocations'},
'allocations':	{'allocation'},
'allotment':	{'allotments'},
'allotments':	{'allotment'},
'allow':	{'allows','alloy'},
'allowance':	{'allowances'},
'allowances':	{'allowance'},
'allows':	{'allow','alloys'},
'alloy':	{'alley','allow','alloys','ally'},
'alloys':	{'alleys','allows','alloy'},
'ally':	{'ably','all','alla','alley','alloy','bally','cally','rally','sally','tally','wally'},
'almanac':	{'almanacs'},
'almanacs':	{'almanac'},
'almond':	{'almonds'},
'almonds':	{'almond'},
'aloe':	{'ale','alone'},
'aloft':	{'loft'},
'aloha':	{'alpha'},
'alone':	{'aloe','along','clone','lone','malone'},
'along':	{'alone','among','long'},
'aloud':	{'cloud','loud'},
'alp':	{'adp','al','ala','alb','ale','ali','all','alps','alt','amp','app','asp','atp','lp'},
'alpha':	{'aloha'},
'alps':	{'alas','ales','alp','amps','apps'},
'also':	{'alto'},
'alt':	{'act','aft','al','ala','alb','ale','ali','all','alp','alto','ant','apt','art','at','blt','halt','malt','salt'},
'altar':	{'alter'},
'alter':	{'after','alder','alger','altar','alters','aster','halter','salter','walter'},
'alteration':	{'alterations'},
'alterations':	{'alteration'},
'alternate':	{'alternates'},
'alternates':	{'alternate'},
'alternative':	{'alternatives'},
'alternatives':	{'alternative'},
'alters':	{'alter'},
'altitude':	{'altitudes','aptitude','attitude'},
'altitudes':	{'altitude','attitudes'},
'alto':	{'also','alt','altos','auto'},
'altos':	{'alto','autos'},
'alum':	{'album','plum','slum'},
'aluminium':	{'aluminum'},
'aluminum':	{'aluminium'},
'am':	{'a','ab','abm','ac','ad','af','ag','ai','aim','ak','al','amp','an','ar','arm','as','at','atm','au','av','ax','az','bm','cam','cm','dam','em','fm','gm','ham','hm','jam','km','lam','mm','nm','pm','ram','rm','sam','sm','tam','tm','um','wm','yam'},
'amateur':	{'amateurs'},
'amateurs':	{'amateur'},
'amaze':	{'amazed','maze'},
'amazed':	{'amaze'},
'ambassador':	{'ambassadors'},
'ambassadors':	{'ambassador'},
'amber':	{'ambler','ember'},
'ambition':	{'ambitions'},
'ambitions':	{'ambition','ambitious'},
'ambitious':	{'ambitions'},
'ambler':	{'abler','amber','gambler','rambler'},
'ambulance':	{'ambulances'},
'ambulances':	{'ambulance'},
'amen':	{'aden','amend','aren','men','omen'},
'amend':	{'amen','amends','mend'},
'amended':	{'mended'},
'amending':	{'mending'},
'amendment':	{'amendments'},
'amendments':	{'amendment'},
'amends':	{'amend','mends'},
'america':	{'american'},
'american':	{'america','americana'},
'americana':	{'american'},
'amid':	{'acid','aid','arid','avid','mid'},
'amidst':	{'midst'},
'amigo':	{'amigos','amino'},
'amigos':	{'amigo'},
'amine':	{'amino','famine','mine'},
'amino':	{'amigo','amine'},
'among':	{'along','hmong'},
'amos':	{'amps'},
'amount':	{'amounts','mount'},
'amounted':	{'mounted'},
'amounting':	{'mounting'},
'amounts':	{'amount','mounts'},
'amour':	{'armour'},
'amp':	{'adp','alp','am','amps','app','asp','atp','camp','damp','imp','lamp','mp','ramp'},
'ample':	{'apple','sample'},
'amplified':	{'amplifier'},
'amplifier':	{'amplified','amplifiers'},
'amplifiers':	{'amplifier'},
'amplitude':	{'amplitudes'},
'amplitudes':	{'amplitude'},
'amps':	{'alps','amos','amp','apps','camps','lamps','ramps'},
'amuse':	{'abuse','amused','amuses','muse'},
'amused':	{'abused','amuse','amuses'},
'amusement':	{'amusements'},
'amusements':	{'amusement'},
'amuses':	{'abuses','amuse','amused'},
'amusing':	{'abusing'},
'an':	{'a','ab','ac','ad','af','ag','ai','ak','al','am','ana','and','ang','ans','ant','any','ar','as','at','au','av','ax','az','ban','can','en','fan','han','in','jan','lan','man','mn','nan','on','pan','ran','rn','sn','tan','tn','un','van','wan','zn'},
'ana':	{'aba','ada','aka','ala','an','anal','and','ang','anna','ans','ant','any','ara','dana','dna','na','rana','rna','una'},
'anaesthesia':	{'anesthesia'},
'anal':	{'ana','canal'},
'analog':	{'analogs','analogy'},
'analogies':	{'analogues'},
'analogs':	{'analog','analogy'},
'analogue':	{'analogues'},
'analogues':	{'analogies','analogue'},
'analogy':	{'analog','analogs'},
'analyse':	{'analysed','analyser','analyses','analyst','analyze'},
'analysed':	{'analyse','analyser','analyses','analyzed'},
'analyser':	{'analyse','analysed','analysers','analyses','analyzer'},
'analysers':	{'analyser','analyses','analyzers'},
'analyses':	{'analyse','analysed','analyser','analysers','analysis','analysts','analyzes'},
'analysing':	{'analyzing'},
'analysis':	{'analyses','analysts'},
'analyst':	{'analyse','analysts'},
'analysts':	{'analyses','analysis','analyst'},
'analytic':	{'analytics'},
'analytics':	{'analytic'},
'analyze':	{'analyse','analyzed','analyzer','analyzes'},
'analyzed':	{'analysed','analyze','analyzer','analyzes'},
'analyzer':	{'analyser','analyze','analyzed','analyzers','analyzes'},
'analyzers':	{'analysers','analyzer','analyzes'},
'analyzes':	{'analyses','analyze','analyzed','analyzer','analyzers'},
'analyzing':	{'analysing'},
'anarchist':	{'anarchists'},
'anarchists':	{'anarchist'},
'ancestor':	{'ancestors'},
'ancestors':	{'ancestor'},
'anchor':	{'anchors'},
'anchors':	{'anchor'},
'ancient':	{'ancients'},
'ancients':	{'ancient'},
'and':	{'ad','add','aid','an','ana','ang','ans','ant','any','band','end','hand','land','nd','rand','sand','wand'},
'andersen':	{'anderson'},
'anderson':	{'andersen'},
'andes':	{'aides','antes'},
'andrew':	{'andrews'},
'andrews':	{'andrew'},
'anecdote':	{'anecdotes'},
'anecdotes':	{'anecdote'},
'anesthesia':	{'anaesthesia'},
'anesthetic':	{'aesthetic'},
'anew':	{'knew','new'},
'ang':	{'ag','an','ana','and','ans','ant','any','aug','bang','dang','fang','gang','hang','pang','rang','sang','tang','yang'},
'angel':	{'anger'},
'angelic':	{'angelica'},
'angelica':	{'angelic'},
'anger':	{'alger','angel','angers','angler','auger','danger','hanger','manger','ranger','sanger'},
'angers':	{'anger','anglers','bangers','dangers','hangers'},
'angle':	{'angled','angler','angles','ankle','bangle','dangle','tangle'},
'angled':	{'angle','angler','angles','mangled','tangled'},
'angler':	{'anger','angle','angled','anglers','angles','antler'},
'anglers':	{'angers','angler','angles'},
'angles':	{'angle','angled','angler','anglers','ankles','bangles'},
'anglia':	{'ganglia'},
'angling':	{'dangling'},
'angola':	{'angolan'},
'angolan':	{'angola'},
'angus':	{'anus','argus'},
'animal':	{'animals'},
'animals':	{'animal'},
'animate':	{'animated'},
'animated':	{'animate'},
'animation':	{'animations'},
'animations':	{'animation'},
'anion':	{'anon','onion','union'},
'ankle':	{'angle','ankles'},
'ankles':	{'angles','ankle','anklets'},
'anklets':	{'ankles'},
'anna':	{'ana','anne','wanna'},
'annals':	{'annuals'},
'anne':	{'acne','anna','annex','ante'},
'annex':	{'anne'},
'annexed':	{'annexes'},
'annexes':	{'annexed'},
'annotate':	{'annotated'},
'annotated':	{'annotate'},
'annotation':	{'annotations'},
'annotations':	{'annotation'},
'announce':	{'announced','announcer','announces'},
'announced':	{'announce','announcer','announces'},
'announcement':	{'announcements'},
'announcements':	{'announcement'},
'announcer':	{'announce','announced','announces'},
'announces':	{'announce','announced','announcer'},
'annoy':	{'annoys'},
'annoyance':	{'annoyances'},
'annoyances':	{'annoyance'},
'annoys':	{'annoy'},
'annual':	{'annuals'},
'annuals':	{'annals','annual'},
'anode':	{'abode','node'},
'anon':	{'anion','avon','canon','non'},
'ans':	{'abs','ads','an','ana','and','ang','ant','ants','anus','any','as','ass','bans','cans','cns','dans','ens','fans','ins','mans','pans','sans','vans'},
'answer':	{'answers'},
'answered':	{'answerer'},
'answerer':	{'answered'},
'answers':	{'answer'},
'ant':	{'act','aft','alt','an','ana','and','ang','ans','ante','anti','ants','any','apt','art','at','aunt','cant','int','kant','nt','ont','pant','rant','tnt','want'},
'antagonist':	{'antagonists'},
'antagonists':	{'antagonist'},
'antarctic':	{'antarctica'},
'antarctica':	{'antarctic'},
'ante':	{'anne','ant','antes','anti','ants','arte','ate','dante'},
'antenna':	{'antennae','antennas'},
'antennae':	{'antenna','antennas'},
'antennas':	{'antenna','antennae'},
'anterior':	{'interior'},
'antes':	{'andes','ante','ants','nantes'},
'anthem':	{'anthems'},
'anthems':	{'anthem'},
'anthony':	{'antony'},
'anti':	{'ant','ante','ants'},
'antibiotic':	{'antibiotics'},
'antibiotics':	{'antibiotic'},
'anticipate':	{'anticipated','anticipates'},
'anticipated':	{'anticipate','anticipates'},
'anticipates':	{'anticipate','anticipated'},
'antidepressant':	{'antidepressants'},
'antidepressants':	{'antidepressant'},
'antigen':	{'antigens'},
'antigens':	{'antigen'},
'antioxidant':	{'antioxidants'},
'antioxidants':	{'antioxidant'},
'antique':	{'antiques'},
'antiques':	{'antique'},
'antler':	{'angler'},
'antony':	{'anthony'},
'ants':	{'acts','ans','ant','ante','antes','anti','anus','arts','aunts','pants','rants','wants'},
'anus':	{'angus','ans','ants','gnus','janus','onus'},
'any':	{'an','ana','and','ang','ans','ant','many','ny'},
'anyway':	{'anyways'},
'anyways':	{'anyway'},
'aorta':	{'sorta'},
'apart':	{'part'},
'apartment':	{'apartments'},
'apartments':	{'apartment'},
'ape':	{'ace','ade','age','ale','apes','apex','apo','app','apr','apt','are','ate','ave','awe','axe','aye','cape','pe','rape','tape'},
'apes':	{'aces','ages','ales','ape','apex','apps','apres','ares','axes','ayes','capes','rapes','tapes'},
'apex':	{'ape','apes'},
'apiece':	{'piece'},
'apo':	{'ado','ago','ape','app','apr','apt','capo','gpo','po'},
'apologetic':	{'apologetics'},
'apologetics':	{'apologetic'},
'apologies':	{'apologises','apologizes'},
'apologise':	{'apologised','apologises','apologize'},
'apologised':	{'apologise','apologises','apologized'},
'apologises':	{'apologies','apologise','apologised','apologizes'},
'apologize':	{'apologise','apologized','apologizes'},
'apologized':	{'apologised','apologize','apologizes'},
'apologizes':	{'apologies','apologises','apologize','apologized'},
'apostle':	{'apostles'},
'apostles':	{'apostle'},
'app':	{'adp','alp','amp','ape','apo','apps','apr','apt','asp','atp'},
'appalachia':	{'appalachian'},
'appalachian':	{'appalachia'},
'appeal':	{'appeals','appear'},
'appealed':	{'appeared'},
'appealing':	{'appearing'},
'appeals':	{'appeal','appears'},
'appear':	{'appeal','appears'},
'appearance':	{'appearances'},
'appearances':	{'appearance'},
'appeared':	{'appealed'},
'appearing':	{'appealing'},
'appears':	{'appeals','appear'},
'appellant':	{'appellants'},
'appellants':	{'appellant'},
'append':	{'appends'},
'appendices':	{'appendixes'},
'appendixes':	{'appendices'},
'appends':	{'append'},
'appetizer':	{'appetizers'},
'appetizers':	{'appetizer'},
'applaud':	{'applauds'},
'applauds':	{'applaud'},
'apple':	{'ample','apples','applet','apply'},
'apples':	{'apple','applet','applets','applies'},
'applet':	{'apple','apples','applets'},
'applets':	{'apples','applet'},
'appliance':	{'appliances'},
'appliances':	{'appliance'},
'applicant':	{'applicants'},
'applicants':	{'applicant'},
'application':	{'applications'},
'applications':	{'application'},
'applied':	{'applies'},
'applies':	{'apples','applied'},
'apply':	{'apple','aptly'},
'appoint':	{'appoints'},
'appointed':	{'appointee'},
'appointee':	{'appointed','appointees'},
'appointees':	{'appointee'},
'appointment':	{'appointments'},
'appointments':	{'appointment'},
'appoints':	{'appoint'},
'appraisal':	{'appraisals'},
'appraisals':	{'appraisal'},
'appraised':	{'appraiser'},
'appraiser':	{'appraised','appraisers'},
'appraisers':	{'appraiser'},
'appreciable':	{'appreciably'},
'appreciably':	{'appreciable'},
'appreciate':	{'appreciated','appreciates'},
'appreciated':	{'appreciate','appreciates'},
'appreciates':	{'appreciate','appreciated'},
'apprentice':	{'apprentices'},
'apprentices':	{'apprentice'},
'apprenticeship':	{'apprenticeships'},
'apprenticeships':	{'apprenticeship'},
'approached':	{'approaches'},
'approaches':	{'approached'},
'appropriate':	{'appropriated'},
'appropriated':	{'appropriate'},
'appropriation':	{'appropriations'},
'appropriations':	{'appropriation'},
'approval':	{'approvals'},
'approvals':	{'approval'},
'approve':	{'approved','approves'},
'approved':	{'approve','approves'},
'approves':	{'approve','approved'},
'approximate':	{'approximated','approximates'},
'approximated':	{'approximate','approximates'},
'approximates':	{'approximate','approximated'},
'approximation':	{'approximations'},
'approximations':	{'approximation'},
'apps':	{'alps','amps','apes','app'},
'apr':	{'aer','air','ape','apo','app','apt','ar','cpr','pr'},
'apres':	{'acres','apes','ares','pres'},
'apron':	{'aaron','akron','aprons'},
'aprons':	{'apron'},
'apt':	{'act','aft','alt','ant','ape','apo','app','apr','art','at','capt','opt','pt'},
'aptitude':	{'altitude','attitude'},
'aptly':	{'apply'},
'aqua':	{'qua'},
'aquarium':	{'aquariums','aquarius'},
'aquariums':	{'aquarium','aquarius'},
'aquarius':	{'aquarium','aquariums'},
'aquatic':	{'aquatics'},
'aquatics':	{'aquatic'},
'aquifer':	{'aquifers'},
'aquifers':	{'aquifer'},
'ar':	{'a','ab','ac','ad','aer','af','ag','ai','air','ak','al','am','an','apr','ara','arc','are','ark','arm','art','as','at','au','av','ax','az','bar','br','car','cr','dar','dr','ear','er','far','fr','gar','hr','ir','jar','jr','kr','lr','mar','mr','oar','or','par','pr','qr','r','sr','tar','ur','var','war','yr','zr'},
'ara':	{'aba','ada','agra','aka','ala','ana','ar','arab','arc','are','area','aria','ark','arm','art','aura','bra','era','ira','mara','nara','nra','para','ra','tara'},
'arab':	{'ara','crab','grab'},
'arabia':	{'arabian','arabic'},
'arabian':	{'arabia'},
'arabic':	{'arabia'},
'arable':	{'parable'},
'arbitrator':	{'arbitrators'},
'arbitrators':	{'arbitrator'},
'arbor':	{'armor','harbor'},
'arc':	{'abc','ac','ar','ara','arch','arcs','are','ark','arm','art','marc','nrc','prc'},
'arcade':	{'arcane'},
'arcadia':	{'acadia'},
'arcane':	{'arcade'},
'arch':	{'arc','arcs','march'},
'archaeology':	{'archeology'},
'arched':	{'ached','archer','arches','marched'},
'archeology':	{'archaeology'},
'archer':	{'arched','archery','arches'},
'archery':	{'archer'},
'arches':	{'aches','arched','archer','marches'},
'arching':	{'aching','marching'},
'architect':	{'architects'},
'architects':	{'architect'},
'architecture':	{'architectures'},
'architectures':	{'architecture'},
'archive':	{'archived','archives'},
'archived':	{'archive','archives'},
'archives':	{'archive','archived'},
'arcs':	{'arc','arch','ares','arms','arts'},
'ardent':	{'argent'},
'are':	{'ace','acre','ade','age','ale','ape','ar','ara','arc','area','aren','ares','ark','arm','arse','art','arte','ate','ave','awe','axe','aye','bare','care','dare','ere','fare','hare','ire','mare','ore','pre','rare','ware'},
'area':	{'ara','are','areas','aren','arena','ares','aria','urea'},
'areas':	{'area','arenas','ares','arias'},
'aren':	{'aden','amen','are','area','arena','ares','karen','tren','wren'},
'arena':	{'area','aren','arenas'},
'arenas':	{'areas','arena'},
'ares':	{'aces','acres','ages','ales','apes','apres','arcs','are','area','areas','aren','aries','arms','arts','axes','ayes','bares','cares','dares','fares','mares','ores','pres','res','wares'},
'argent':	{'agent','ardent','sargent','urgent'},
'argentina':	{'argentine'},
'argentine':	{'argentina'},
'argo':	{'ago','argon','argos','arno','cargo','ergo','fargo','largo'},
'argon':	{'argo','argos','arson','jargon'},
'argos':	{'argo','argon','argosy','argus'},
'argosy':	{'argos'},
'arguable':	{'arguably'},
'arguably':	{'arguable'},
'argue':	{'argued','argues','argus'},
'argued':	{'argue','argues'},
'argues':	{'argue','argued','argus'},
'argument':	{'arguments'},
'arguments':	{'argument'},
'argus':	{'angus','argos','argue','argues'},
'aria':	{'ara','area','arias','arid','asia','maria'},
'arias':	{'alias','areas','aria','aries'},
'arid':	{'acid','aid','amid','aria','avid','grid','rid'},
'aries':	{'ares','arias','arises','armies','caries','cries','dries','fries','tries','varies'},
'arise':	{'arisen','arises','arose','arse','rise'},
'arisen':	{'arise','arises','risen'},
'arises':	{'aries','arise','arisen','crises','rises'},
'arising':	{'rising'},
'ark':	{'ak','ar','ara','arc','are','arm','art','ask','bark','dark','lark','mark','park'},
'arm':	{'abm','aim','am','ar','ara','arc','are','ark','arms','army','art','atm','farm','harm','rm','warm'},
'armed':	{'aimed','farmed','harmed','warmed'},
'armenia':	{'armenian'},
'armenian':	{'armenia'},
'armies':	{'aries'},
'armin':	{'admin'},
'armor':	{'arbor','armory','armour'},
'armored':	{'armoured'},
'armory':	{'armor'},
'armour':	{'amour','armor'},
'armoured':	{'armored'},
'armpit':	{'armpits'},
'armpits':	{'armpit'},
'arms':	{'aims','arcs','ares','arm','army','arts','farms','harms','warms'},
'army':	{'arm','arms'},
'arno':	{'argo','brno'},
'aroma':	{'aromas','roma'},
'aromas':	{'aroma'},
'arose':	{'arise','arouse','arse','prose','rose'},
'around':	{'abound','ground','round'},
'arouse':	{'arose','aroused','grouse','rouse'},
'aroused':	{'arouse'},
'arrange':	{'arranged','arranger','arranges'},
'arranged':	{'arrange','arranger','arranges'},
'arrangement':	{'arrangements'},
'arrangements':	{'arrangement'},
'arranger':	{'arrange','arranged','arranges'},
'arranges':	{'arrange','arranged','arranger'},
'array':	{'arrays'},
'arrays':	{'array'},
'arrest':	{'arrests'},
'arrests':	{'arrest'},
'arrival':	{'arrivals'},
'arrivals':	{'arrival'},
'arrive':	{'arrived','arrives'},
'arrived':	{'arrive','arrives'},
'arrives':	{'arrive','arrived'},
'arrow':	{'arrows','barrow','harrow','marrow','narrow'},
'arrows':	{'arrow','narrows'},
'arse':	{'are','arise','arose','arte','parse'},
'arson':	{'argon','carson','parson'},
'art':	{'act','aft','alt','ant','apt','ar','ara','arc','are','ark','arm','arte','arts','at','bart','cart','crt','dart','fart','hart','kart','mart','part','tart'},
'arte':	{'ante','are','arse','art','arts','ate','harte'},
'article':	{'articles','particle'},
'articles':	{'article','particles'},
'articulate':	{'articulated','particulate'},
'articulated':	{'articulate'},
'artifact':	{'artifacts'},
'artifacts':	{'artifact'},
'artisan':	{'artisans','partisan'},
'artisans':	{'artisan'},
'artist':	{'artists'},
'artistic':	{'autistic'},
'artists':	{'artist'},
'arts':	{'acts','ants','arcs','ares','arms','art','arte','carts','darts','karts','parts','tarts','warts'},
'artwork':	{'artworks'},
'artworks':	{'artwork'},
'aryan':	{'bryan'},
'as':	{'a','ab','abs','ac','ad','ads','af','ag','ai','ak','al','am','an','ans','ar','ash','ask','asl','asp','ass','at','au','av','ax','az','bs','cs','es','gas','has','hs','is','ks','mas','ms','oas','os','pas','ps','ss','ts','us','vs','was'},
'asap':	{'asp','sap'},
'ascend':	{'ascent'},
'ascent':	{'accent','ascend','assent','nascent','scent'},
'ascot':	{'mascot','scot'},
'ash':	{'as','ashe','ask','asl','asp','ass','bash','cash','dash','hash','lash','mash','nash','rash','sash','sh','wash'},
'ashamed':	{'shamed'},
'ashe':	{'ache','ash','ashes','she'},
'ashes':	{'aches','ashe','asses','dashes','hashes','lashes','shes','washes'},
'ashore':	{'shore'},
'ashtray':	{'astray'},
'asia':	{'aria','asian'},
'asian':	{'asia','avian'},
'aside':	{'abide','aide','side'},
'ask':	{'ak','ark','as','ash','asks','asl','asp','ass','mask','task'},
'asked':	{'askew','masked','tasked'},
'askew':	{'asked','skew'},
'asking':	{'masking','tasking'},
'asks':	{'ask','ass','masks','tasks'},
'asl':	{'al','all','as','ash','ask','asp','ass'},
'asleep':	{'sleep'},
'asp':	{'adp','alp','amp','app','as','asap','ash','ask','asl','ass','atp','esp','gasp','wasp'},
'aspect':	{'aspects'},
'aspects':	{'aspect'},
'aspiration':	{'aspirations'},
'aspirations':	{'aspiration'},
'aspire':	{'spire'},
'aspirin':	{'aspiring'},
'aspiring':	{'aspirin'},
'ass':	{'abs','ads','ans','as','ash','ask','asks','asl','asp','bass','lass','mass','pass','ss','sss'},
'assam':	{'assay'},
'assassin':	{'assassins'},
'assassins':	{'assassin'},
'assault':	{'assaults'},
'assaults':	{'assault'},
'assay':	{'assam','assays','essay'},
'assays':	{'assay','essays'},
'assemblage':	{'assemblages'},
'assemblages':	{'assemblage'},
'assemble':	{'assembled','assembler','assembles','assembly'},
'assembled':	{'assemble','assembler','assembles'},
'assembler':	{'assemble','assembled','assembles'},
'assembles':	{'assemble','assembled','assembler','assemblies'},
'assemblies':	{'assembles'},
'assembly':	{'assemble'},
'assent':	{'absent','ascent','assert','asset'},
'assert':	{'assent','asserts','asset'},
'asserted':	{'assorted'},
'assertion':	{'assertions'},
'assertions':	{'assertion'},
'asserts':	{'assert','assets'},
'asses':	{'ashes','assess','asset','assets','basses','masses','passes'},
'assess':	{'asses','assets'},
'assessed':	{'assesses'},
'assesses':	{'assessed'},
'assessment':	{'assessments'},
'assessments':	{'assessment'},
'assessor':	{'assessors'},
'assessors':	{'assessor'},
'asset':	{'assent','assert','asses','assets','basset'},
'assets':	{'asserts','asses','assess','asset'},
'asshole':	{'assholes'},
'assholes':	{'asshole'},
'assign':	{'assigns'},
'assignment':	{'assignments'},
'assignments':	{'assignment'},
'assigns':	{'assign'},
'assimilate':	{'assimilated'},
'assimilated':	{'assimilate'},
'assist':	{'assists','bassist'},
'assistant':	{'assistants'},
'assistants':	{'assistant'},
'assists':	{'assist'},
'associate':	{'associated','associates'},
'associated':	{'associate','associates'},
'associates':	{'associate','associated'},
'association':	{'associations'},
'associations':	{'association'},
'assorted':	{'asserted'},
'assume':	{'assumed','assumes','assure'},
'assumed':	{'assume','assumes','assured'},
'assumes':	{'assume','assumed','assures'},
'assuming':	{'assuring'},
'assumption':	{'assumptions'},
'assumptions':	{'assumption'},
'assurance':	{'assurances'},
'assurances':	{'assurance'},
'assure':	{'assume','assured','assures'},
'assured':	{'assumed','assure','assures'},
'assures':	{'assumes','assure','assured'},
'assuring':	{'assuming'},
'aster':	{'after','alter','astor','caster','easter','ester','faster','master','raster'},
'asterisk':	{'asterisks'},
'asterisks':	{'asterisk'},
'asteroid':	{'asteroids','steroid'},
'asteroids':	{'asteroid','steroids'},
'astonished':	{'astonishes'},
'astonishes':	{'astonished'},
'astor':	{'actor','aster','castor','pastor'},
'astral':	{'astray'},
'astray':	{'ashtray','astral','stray'},
'astronaut':	{'astronauts'},
'astronauts':	{'astronaut'},
'astronomer':	{'astronomers'},
'astronomers':	{'astronomer'},
'asymmetric':	{'symmetric'},
'asymmetrical':	{'symmetrical'},
'asymmetry':	{'symmetry'},
'asymptomatic':	{'symptomatic'},
'asynchronous':	{'synchronous'},
'at':	{'a','ab','ac','act','ad','af','aft','ag','ai','ak','al','alt','am','an','ant','apt','ar','art','as','ate','atm','atp','au','av','ax','az','bat','cat','ct','dat','eat','et','fat','ft','hat','ht','it','kat','kt','lat','mat','mt','nt','oat','pat','pt','rat','sat','t','tat','ut','vat','vt','wat'},
'ate':	{'ace','ade','age','ale','ante','ape','are','arte','at','atm','atp','ave','awe','axe','aye','date','fate','gate','hate','late','mate','pate','rate','tate','te','ute'},
'atheism':	{'atheist'},
'atheist':	{'atheism','atheists'},
'atheists':	{'atheist'},
'athena':	{'athens'},
'athens':	{'athena'},
'athlete':	{'athletes'},
'athletes':	{'athlete'},
'athletic':	{'athletics'},
'athletics':	{'athletic'},
'atlantic':	{'atlantis'},
'atlantis':	{'atlantic'},
'atlas':	{'alas'},
'atm':	{'abm','aim','am','arm','at','ate','atom','atp','tm'},
'atmosphere':	{'atmospheres'},
'atmospheres':	{'atmosphere'},
'atoll':	{'toll'},
'atom':	{'atm','atoms','atop','tom'},
'atoms':	{'atom'},
'atop':	{'atom','atp','stop','top'},
'atp':	{'adp','alp','amp','app','asp','at','ate','atm','atop','ftp'},
'atrial':	{'aerial','trial'},
'atrophy':	{'trophy'},
'attach':	{'attack'},
'attached':	{'attaches','attacked'},
'attaches':	{'attached'},
'attaching':	{'attacking'},
'attachment':	{'attachments'},
'attachments':	{'attachment'},
'attack':	{'attach','attacks'},
'attacked':	{'attached','attacker'},
'attacker':	{'attacked','attackers'},
'attackers':	{'attacker'},
'attacking':	{'attaching'},
'attacks':	{'attack'},
'attain':	{'attains'},
'attainment':	{'attainments'},
'attainments':	{'attainment'},
'attains':	{'attain'},
'attempt':	{'attempts'},
'attempts':	{'attempt'},
'attend':	{'attends'},
'attendance':	{'attendances'},
'attendances':	{'attendance'},
'attendant':	{'attendants'},
'attendants':	{'attendant'},
'attended':	{'attendee'},
'attendee':	{'attended','attendees'},
'attendees':	{'attendee'},
'attends':	{'attend'},
'attic':	{'attica'},
'attica':	{'attic','attila'},
'attila':	{'attica'},
'attitude':	{'altitude','aptitude','attitudes'},
'attitudes':	{'altitudes','attitude'},
'attorney':	{'attorneys'},
'attorneys':	{'attorney'},
'attract':	{'attracts'},
'attraction':	{'attractions'},
'attractions':	{'attraction'},
'attracts':	{'attract'},
'attribute':	{'attributed','attributes'},
'attributed':	{'attribute','attributes'},
'attributes':	{'attribute','attributed'},
'atypical':	{'typical'},
'au':	{'a','ab','ac','ad','af','ag','ai','ak','al','am','an','ar','as','at','aug','aux','av','ax','az','cu','du','eu','gu','ju','lu','mu','nu','pu','ru','su','tau','u','wu','zu'},
'auction':	{'action','auctions','suction'},
'auctioneer':	{'auctioneers'},
'auctioneers':	{'auctioneer'},
'auctions':	{'actions','auction'},
'audience':	{'audiences'},
'audiences':	{'audience'},
'audio':	{'audit'},
'audit':	{'audio','audits'},
'audition':	{'addition','auditions'},
'auditions':	{'additions','audition'},
'auditor':	{'auditors','auditory'},
'auditors':	{'auditor','auditory'},
'auditory':	{'auditor','auditors'},
'audits':	{'audit'},
'aug':	{'ag','ang','au','aux','bug','dug','hug','jug','lug','mug','pug','rug','tug'},
'auger':	{'alger','anger'},
'august':	{'augusta'},
'augusta':	{'august'},
'aunt':	{'ant','aunts','aunty','cunt','haunt','hunt','punt'},
'auntie':	{'untie'},
'aunts':	{'ants','aunt','aunty','haunts','hunts'},
'aunty':	{'aunt','aunts'},
'aura':	{'agra','ara','aural'},
'aural':	{'aura','mural','rural'},
'austen':	{'austin'},
'austin':	{'austen'},
'australasia':	{'australasian'},
'australasian':	{'australasia'},
'australia':	{'australian'},
'australian':	{'australia'},
'austria':	{'austrian'},
'austrian':	{'austria'},
'authenticate':	{'authenticated'},
'authenticated':	{'authenticate'},
'author':	{'authors'},
'authorisation':	{'authorization'},
'authorise':	{'authorised','authorize'},
'authorised':	{'authorise','authorized'},
'authorization':	{'authorisation','authorizations'},
'authorizations':	{'authorization'},
'authorize':	{'authorise','authorized','authorizes'},
'authorized':	{'authorised','authorize','authorizes'},
'authorizes':	{'authorize','authorized'},
'authors':	{'author'},
'autistic':	{'artistic'},
'auto':	{'alto','autos'},
'autograph':	{'autographs'},
'autographs':	{'autograph'},
'automate':	{'automated','automates'},
'automated':	{'automate','automates'},
'automates':	{'automate','automated'},
'automation':	{'automaton'},
'automaton':	{'automation'},
'automobile':	{'automobiles'},
'automobiles':	{'automobile'},
'autos':	{'altos','auto'},
'aux':	{'au','aug','ax','tux'},
'av':	{'a','ab','ac','ad','af','ag','ai','ak','al','am','an','ar','as','at','au','ave','ax','az','cv','ev','iv','jv','lv','nv','rv','tv','uv','v','wv','xv'},
'avatar':	{'avatars'},
'avatars':	{'avatar'},
'ave':	{'ace','ade','age','ale','ape','are','ate','av','awe','axe','aye','cave','eve','fave','gave','have','pave','rave','save','ve','wave'},
'avenge':	{'avenged','avenger','avenue'},
'avenged':	{'avenge','avenger'},
'avenger':	{'avenge','avenged'},
'avenue':	{'avenge','avenues','venue'},
'avenues':	{'avenue','venues'},
'average':	{'averaged','averages'},
'averaged':	{'average','averages'},
'averages':	{'average','averaged'},
'averse':	{'adverse','verse'},
'aversion':	{'version'},
'avert':	{'advert','alert','overt'},
'averted':	{'alerted'},
'avian':	{'asian'},
'avid':	{'acid','aid','amid','arid','avoid','david','ovid'},
'avoid':	{'avid','avoids','void'},
'avoids':	{'avoid','voids'},
'avon':	{'anon','von'},
'await':	{'awaits','wait'},
'awaited':	{'waited'},
'awaiting':	{'waiting'},
'awaits':	{'await','waits'},
'awake':	{'awaken','aware','awoke','wake'},
'awaken':	{'awake','awoken','waken'},
'award':	{'awards','aware','ward'},
'awards':	{'award','wards'},
'aware':	{'awake','award','ware'},
'away':	{'awry','sway','way'},
'awe':	{'ace','ade','age','ale','ape','are','ate','ave','axe','aye','owe','we'},
'awful':	{'lawful'},
'awfully':	{'lawfully'},
'awhile':	{'while'},
'awning':	{'awnings','owning'},
'awnings':	{'awning'},
'awoke':	{'awake','awoken','woke'},
'awoken':	{'awaken','awoke','woken'},
'awry':	{'airy','away'},
'ax':	{'a','ab','ac','ad','af','ag','ai','ak','al','am','an','ar','as','at','au','aux','av','axe','az','ex','fax','ix','lax','max','ox','px','sax','tax','tx','wax','x','xx'},
'axe':	{'ace','ade','age','ale','ape','are','ate','ave','awe','ax','axed','axel','axes','axle','aye','xe'},
'axed':	{'aged','axe','axel','axes','faxed','taxed','waxed'},
'axel':	{'abel','axe','axed','axes'},
'axes':	{'aces','ages','ales','apes','ares','axe','axed','axel','axis','axles','ayes','faxes','taxes','waxes'},
'axing':	{'aging','faxing','taxing','waxing'},
'axiom':	{'axioms'},
'axioms':	{'axiom'},
'axis':	{'axes','taxis'},
'axle':	{'able','ale','axe','axles'},
'axles':	{'ales','axes','axle'},
'aye':	{'ace','ade','age','ale','ape','are','ate','ave','awe','axe','ayes','bye','dye','eye','rye','wye','ye'},
'ayes':	{'aces','ages','ales','apes','ares','axes','aye','bayes','dyes','eyes','hayes','yes'},
'az':	{'a','ab','ac','ad','af','ag','ai','ak','al','am','an','ar','as','at','au','av','ax','cz','hz','z'},
'azerbaijan':	{'azerbaijani'},
'azerbaijani':	{'azerbaijan'},
'b':	{'a','ab','ba','bb','bc','be','bi','bk','bl','bm','br','bs','by','c','d','db','e','eb','f','g','gb','h','i','j','k','kb','l','lb','mb','nb','o','ob','p','pb','q','r','rb','sb','t','tb','u','v','w','x','y','yb','z'},
'ba':	{'a','aba','b','baa','bad','bag','bai','ban','bar','bat','bay','bb','bc','be','bi','bk','bl','bm','boa','br','bra','bs','by','ca','da','ea','fa','ga','ha','ia','ka','la','ma','mba','na','pa','ra','sa','sba','ta','va','wa','ya','za'},
'baa':	{'ba','baal','baba','bad','bag','bai','ban','bar','bat','bay','boa','bra','faa'},
'baal':	{'baa','bail','ball','basal'},
'baba':	{'aba','baa','babe','baby','saba'},
'babble':	{'bobble','bubble','rabble'},
'babe':	{'baba','babel','babes','baby','bade','bake','bale','bane','bare','base'},
'babel':	{'abel','babe','babes','bagel','basel','label'},
'babes':	{'babe','babel','babies','bakes','bales','bares','bases','bayes'},
'babies':	{'babes','rabies'},
'baby':	{'baba','babe','bay'},
'bach':	{'back','bash','batch','bath','beach','each','mach'},
'bachelor':	{'bachelors'},
'bachelors':	{'bachelor'},
'back':	{'bach','backs','bank','bark','beck','black','bock','buck','hack','jack','lack','mack','pack','rack','sack','tack'},
'backed':	{'baked','banked','hacked','lacked','packed','sacked'},
'backers':	{'bakers','bankers','hackers'},
'background':	{'backgrounds'},
'backgrounds':	{'background'},
'backing':	{'baking','banking','barking','hacking','jacking','lacking','packing','racking'},
'backlash':	{'backslash'},
'backpack':	{'backpacks'},
'backpacker':	{'backpackers'},
'backpackers':	{'backpacker'},
'backpacks':	{'backpack'},
'backs':	{'back','banks','blacks','bucks','hacks','jacks','lacks','packs','racks','sacks'},
'backslash':	{'backlash'},
'backup':	{'backups'},
'backups':	{'backup'},
'backward':	{'backwards','backyard'},
'backwards':	{'backward'},
'backyard':	{'backward'},
'bacon':	{'baron','baton','beacon','macon'},
'bacteria':	{'bacterial'},
'bacterial':	{'bacteria'},
'bad':	{'ad','ba','baa','bade','bag','bai','bald','ban','band','bar','bard','bat','baud','bay','bead','bed','bid','bod','brad','bud','cad','dad','fad','had','lad','mad','pad','rad','sad','tad','wad'},
'bade':	{'ade','babe','bad','badge','bake','bale','bane','bare','base','blade','bode','fade','jade','made','sade','wade'},
'badge':	{'bade','badger','badges','barge'},
'badger':	{'badge','badges'},
'badges':	{'badge','badger','barges'},
'badly':	{'bally','madly','sadly'},
'badness':	{'baldness','madness','sadness'},
'bag':	{'ag','ba','baa','bad','bags','bai','ban','bang','bar','bat','bay','beg','big','bog','brag','bug','dag','fag','gag','jag','lag','mag','nag','rag','sag','tag'},
'bagel':	{'babel','bagels','basel'},
'bagels':	{'bagel'},
'bagged':	{'banged','begged','bogged','gagged','jagged','lagged','ragged','tagged'},
'bagging':	{'banging','begging','bragging','gagging','lagging','nagging','tagging'},
'bags':	{'bag','bangs','bans','bars','bass','bats','bays','begs','bugs','gags','lags','rags','tags'},
'baht':	{'bait','bart','bat'},
'bai':	{'ai','ba','baa','bad','bag','bail','bait','bali','ban','bar','bari','bat','bay','bi','sai','tai','wai'},
'bail':	{'baal','bai','bait','ball','basil','boil','dail','fail','hail','jail','mail','nail','rail','sail','tail'},
'bailey':	{'barley'},
'bait':	{'baht','bai','bail','baits','bart','bat','bit','brit','gait','wait'},
'baits':	{'bait','bats','bits','brits','waits'},
'bake':	{'babe','bade','baked','baker','bakes','baku','bale','bane','bare','base','bike','blake','brake','cake','fake','lake','make','rake','sake','take','wake'},
'baked':	{'backed','bake','baker','bakes','banked','bared','based','beaked','faked','naked','raked'},
'baker':	{'bake','baked','bakers','bakery','bakes','banker','barker','bayer','biker','maker','taker'},
'bakers':	{'backers','baker','bakery','bakes','bankers','bikers','makers','takers'},
'bakery':	{'baker','bakers'},
'bakes':	{'babes','bake','baked','baker','bakers','bales','bares','bases','bayes','bikes','brakes','cakes','fakes','lakes','makes','rakes','sakes','takes','wakes'},
'baking':	{'backing','banking','baring','barking','basing','biking','braking','making','raking','taking','waking'},
'baku':	{'bake'},
'balance':	{'balanced','balances','valance'},
'balanced':	{'balance','balances'},
'balances':	{'balance','balanced'},
'bald':	{'bad','bale','bali','ball','balm','band','bard','baud','bold'},
'baldness':	{'badness','boldness'},
'bale':	{'ale','babe','bade','bake','bald','bales','bali','ball','balm','bane','bare','base','bile','dale','gale','hale','male','pale','sale','tale','vale','yale'},
'bales':	{'ales','babes','bakes','bale','balls','bares','bases','bayes','males','pales','sales','tales','wales'},
'bali':	{'ali','bai','bald','bale','ball','balm','bari','cali','dali','kali','mali'},
'balkan':	{'balkans'},
'balkans':	{'balkan'},
'ball':	{'all','baal','bail','bald','bale','bali','balls','bally','balm','bell','bill','boll','bull','call','fall','gall','hall','mall','pall','tall','wall'},
'ballad':	{'ballads'},
'ballads':	{'ballad'},
'ballet':	{'ballot','billet','bullet','mallet','pallet','wallet'},
'balloon':	{'balloons'},
'balloons':	{'balloon'},
'ballot':	{'ballet','ballots'},
'ballots':	{'ballot'},
'balls':	{'bales','ball','bally','bells','bills','calls','falls','halls','malls','walls'},
'bally':	{'ally','badly','ball','balls','belly','billy','bully','cally','rally','sally','tally','wally'},
'balm':	{'bald','bale','bali','ball','baum','calm','palm'},
'ban':	{'an','ba','baa','bad','bag','bai','band','bane','bang','bank','bans','bar','barn','bat','bay','bean','ben','bin','bran','bun','can','fan','han','jan','lan','man','nan','pan','ran','tan','van','wan'},
'banana':	{'bananas'},
'bananas':	{'banana'},
'band':	{'and','bad','bald','ban','bands','bane','bang','bank','bans','bard','baud','bend','bind','bland','bond','brand','hand','land','rand','sand','wand'},
'bandage':	{'bandages','bondage'},
'bandages':	{'bandage'},
'banded':	{'banged','banked','banned','bonded','branded','handed','landed'},
'banding':	{'banging','banking','banning','bending','binding','bonding','branding','handing','landing','sanding'},
'bandit':	{'bandits'},
'bandits':	{'bandit'},
'bands':	{'band','bangs','banks','bans','bends','binds','bonds','brands','hands','lands','sands','wands'},
'bane':	{'babe','bade','bake','bale','ban','band','bang','bank','bans','bare','base','bone','cane','dane','lane','mane','pane','sane'},
'bang':	{'ang','bag','ban','band','bane','bangs','bank','bans','bong','dang','fang','gang','hang','pang','rang','sang','tang','yang'},
'banged':	{'bagged','banded','banked','banned','hanged','ranged'},
'bangers':	{'angers','bankers','banners','dangers','hangers'},
'banging':	{'bagging','banding','banking','banning','hanging','ranging'},
'bangladesh':	{'bangladeshi'},
'bangladeshi':	{'bangladesh'},
'bangle':	{'angle','bangles','dangle','tangle'},
'bangles':	{'angles','bangle'},
'bangs':	{'bags','bands','bang','banks','bans','bongs','gangs','hangs'},
'banished':	{'vanished'},
'bank':	{'back','ban','band','bane','bang','banks','bans','bark','blank','bunk','hank','rank','sank','tank','wank','yank'},
'banked':	{'backed','baked','banded','banged','banker','banned','ranked'},
'banker':	{'baker','banked','bankers','banner','banter','barker','bunker','tanker'},
'bankers':	{'backers','bakers','bangers','banker','banners','bunkers','tankers'},
'banking':	{'backing','baking','banding','banging','banning','barking','ranking'},
'banks':	{'backs','bands','bangs','bank','bans','blanks','hanks','ranks','tanks'},
'banned':	{'banded','banged','banked','banner','canned','fanned','manned','tanned'},
'banner':	{'banker','banned','banners','banter','manner','tanner'},
'banners':	{'bangers','bankers','banner','manners'},
'banning':	{'banding','banging','banking','canning','fanning','tanning'},
'bans':	{'ans','bags','ban','band','bands','bane','bang','bangs','bank','banks','barns','bars','bass','bats','bays','beans','bins','buns','cans','dans','fans','mans','pans','sans','vans'},
'banter':	{'banker','banner','barter','batter'},
'baptism':	{'baptist'},
'baptist':	{'baptism','baptists'},
'baptists':	{'baptist'},
'bar':	{'ar','ba','baa','bad','bag','bai','ban','barb','bard','bare','bari','bark','barn','bars','bart','bat','bay','bear','ber','boar','br','bur','car','dar','ear','far','gar','jar','mar','oar','par','tar','var','war'},
'barb':	{'bar','bard','bare','bari','bark','barn','bars','bart','garb'},
'barbecue':	{'barbecues'},
'barbecues':	{'barbecue'},
'barbed':	{'barber','bared','barred'},
'barber':	{'barbed','barbers','barker','barter'},
'barbers':	{'barber'},
'bard':	{'bad','bald','band','bar','barb','bare','bared','bari','bark','barn','bars','bart','baud','beard','bird','board','byrd','card','hard','ward','yard'},
'bare':	{'are','babe','bade','bake','bale','bane','bar','barb','bard','bared','bares','barge','bari','bark','barn','bars','bart','base','bore','care','dare','fare','hare','mare','rare','ware'},
'bared':	{'baked','barbed','bard','bare','bares','barred','based','bored','bred','cared','dared','eared','fared','pared'},
'barely':	{'rarely'},
'bares':	{'ares','babes','bakes','bales','bare','bared','barges','barns','bars','bases','bayes','cares','dares','fares','mares','wares'},
'bargain':	{'bargains'},
'bargains':	{'bargain'},
'barge':	{'badge','bare','barges','large','marge'},
'barges':	{'badges','bares','barge','borges'},
'bari':	{'bai','bali','bar','barb','bard','bare','bark','barn','bars','bart','dari','mari','sari'},
'baring':	{'baking','barking','barring','basing','bearing','bering','boring','bring','caring','daring'},
'barium':	{'barnum'},
'bark':	{'ark','back','bank','bar','barb','bard','bare','bari','barn','bars','bart','dark','lark','mark','park'},
'barker':	{'baker','banker','barber','barter','darker','marker','parker'},
'barking':	{'backing','baking','banking','baring','barring','marking','parking'},
'barkley':	{'barley'},
'barley':	{'bailey','barkley','marley'},
'barn':	{'ban','bar','barb','bard','bare','bari','bark','barns','baron','bars','bart','bern','born','burn','darn','earn','warn','yarn'},
'barns':	{'bans','bares','barn','bars','burns','earns','warns','yarns'},
'barnum':	{'barium'},
'baron':	{'aaron','bacon','barn','baton','boron','byron'},
'barred':	{'barbed','bared','barrel','barren','marred','warred'},
'barrel':	{'barred','barrels','barren'},
'barrels':	{'barrel'},
'barren':	{'barred','barrel','warren'},
'barrie':	{'barrier'},
'barrier':	{'barrie','barriers','carrier','harrier'},
'barriers':	{'barrier','carriers'},
'barring':	{'baring','barking','earring','warring'},
'barrow':	{'arrow','borrow','harrow','marrow','narrow'},
'bars':	{'bags','bans','bar','barb','bard','bare','bares','bari','bark','barn','barns','bart','bass','bats','bays','bears','cars','ears','jars','mars','oars','wars'},
'bart':	{'art','baht','bait','bar','barb','bard','bare','bari','bark','barn','bars','barth','bat','burt','cart','dart','fart','hart','kart','mart','part','tart'},
'barter':	{'banter','barber','barker','batter','carter','garter'},
'barth':	{'bart','bath','berth','birth','earth'},
'basal':	{'baal','basalt','basel','basil','nasal'},
'basalt':	{'basal'},
'base':	{'babe','bade','bake','bale','bane','bare','based','basel','bases','bash','bass','bose','case','ease','vase'},
'based':	{'baked','bared','base','basel','bases','biased','eased'},
'basel':	{'babel','bagel','basal','base','based','bases','basil','easel'},
'basement':	{'easement'},
'bases':	{'babes','bakes','bales','bares','base','based','basel','basis','bass','basses','bayes','biases','buses','cases','eases','gases','vases'},
'bash':	{'ash','bach','base','bass','bath','bush','cash','dash','hash','lash','mash','nash','rash','sash','wash'},
'bashing':	{'basing','bathing','cashing','dashing','hashing','washing'},
'basic':	{'basics','basil','basin','basis'},
'basics':	{'basic','basins','basis'},
'basil':	{'bail','basal','basel','basic','basin','basis'},
'basin':	{'basic','basil','basing','basins','basis'},
'basing':	{'baking','baring','bashing','basin','basins','biasing','casing','easing'},
'basins':	{'basics','basin','basing','basis'},
'basis':	{'bases','basic','basics','basil','basin','basins','bass','oasis'},
'basket':	{'baskets','basset','casket','gasket'},
'baskets':	{'basket','gaskets'},
'basque':	{'bisque','masque'},
'bass':	{'ass','bags','bans','bars','base','bases','bash','basis','bats','bays','boss','brass','lass','mass','pass'},
'basses':	{'asses','bases','basset','bosses','masses','passes'},
'basset':	{'asset','basket','basses'},
'bassist':	{'assist'},
'bastard':	{'bastards'},
'bastards':	{'bastard'},
'bat':	{'at','ba','baa','bad','bag','baht','bai','bait','ban','bar','bart','bath','bats','bay','beat','bet','bit','blt','boat','bot','brat','but','cat','dat','eat','fat','hat','kat','lat','mat','oat','pat','rat','sat','tat','vat','wat'},
'batch':	{'bach','bath','bitch','butch','catch','hatch','latch','match','patch','watch'},
'batches':	{'bathes','bitches','catches','latches','matches','patches','watches'},
'bath':	{'bach','barth','bash','bat','batch','bathe','baths','bats','beth','both','hath','math','oath','path'},
'bathe':	{'bath','bathed','bathes','baths','lathe'},
'bathed':	{'bathe','bathes'},
'bathes':	{'batches','bathe','bathed','baths'},
'bathing':	{'bashing','batting'},
'bathroom':	{'bathrooms'},
'bathrooms':	{'bathroom'},
'baths':	{'bath','bathe','bathes','bats','maths','oaths','paths'},
'baton':	{'bacon','baron','paton'},
'bats':	{'bags','baits','bans','bars','bass','bat','bath','baths','bays','beats','bets','bits','boats','bots','cats','eats','fats','hats','lats','mats','oats','rats'},
'battalion':	{'battalions'},
'battalions':	{'battalion'},
'batter':	{'banter','barter','batters','battery','better','bitter','butter','latter','matter'},
'battered':	{'buttered','mattered'},
'batters':	{'batter','battery','butters','matters'},
'battery':	{'batter','batters'},
'batting':	{'bathing','battling','betting'},
'battle':	{'battled','battles','bottle','cattle','rattle'},
'battled':	{'battle','battles','bottled'},
'battles':	{'battle','battled','bottles'},
'battling':	{'batting','bottling','rattling'},
'baud':	{'bad','bald','band','bard','baum','bud'},
'baum':	{'balm','baud','bum'},
'bavaria':	{'bavarian'},
'bavarian':	{'bavaria'},
'bay':	{'ba','baa','baby','bad','bag','bai','ban','bar','bat','bays','boy','bray','buy','by','cay','day','fay','gay','hay','jay','lay','may','nay','pay','ray','say','way'},
'bayer':	{'baker','bayes','buyer','gayer','layer','mayer','payer'},
'bayes':	{'ayes','babes','bakes','bales','bares','bases','bayer','bays','hayes'},
'bays':	{'bags','bans','bars','bass','bats','bay','bayes','boys','buys','days','gays','hays','lays','mays','nays','pays','rays','says','ways'},
'bb':	{'ab','b','ba','bbl','bbs','bc','be','bi','bib','bk','bl','bm','bob','br','bs','by','db','eb','ebb','gb','kb','lb','mb','nb','ob','pb','rb','sb','tb','yb'},
'bbl':	{'bb','bbs','bel','bl'},
'bbs':	{'abs','bb','bbl','bibs','bobs','bps','bs','bus','pbs'},
'bc':	{'abc','ac','b','ba','bb','be','bi','bk','bl','bm','br','bs','by','c','cbc','cc','dc','ec','kc','mc','nc','pc','sc','tc'},
'be':	{'b','ba','bb','bc','bed','bee','beg','bel','ben','ber','bet','bi','bk','bl','bm','br','bs','by','bye','ce','de','e','ee','fe','ge','he','ie','le','me','ne','pe','se','te','ve','we','xe','ye'},
'beach':	{'bach','beech','bench','bleach','breach','each','leach','peach','reach','teach'},
'beaches':	{'benches','breaches','peaches','reaches','teaches'},
'beacon':	{'bacon','deacon'},
'bead':	{'bad','beads','beak','beam','bean','bear','beard','beat','beau','bed','bend','brad','bread','dead','head','lead','mead','read'},
'beaded':	{'beaked','beamed','bearded','bedded','headed','leaded'},
'beading':	{'beaming','bearing','beating','bedding','bending','heading','leading','reading'},
'beads':	{'bead','beaks','beams','beans','beards','bears','beats','beds','bends','breads','heads','leads','reads'},
'beagle':	{'eagle'},
'beak':	{'bead','beaks','beam','bean','bear','beat','beau','beck','bleak','break','leak','peak','teak','weak'},
'beaked':	{'baked','beaded','beamed','leaked','peaked'},
'beaks':	{'beads','beak','beams','beans','bears','beats','breaks','leaks','peaks'},
'beam':	{'bead','beak','beams','bean','bear','beat','beau','seam','team'},
'beamed':	{'beaded','beaked','blamed','teamed'},
'beaming':	{'beading','bearing','beating','blaming','teaming'},
'beams':	{'beads','beaks','beam','beans','bears','beats','seams','teams'},
'bean':	{'ban','bead','beak','beam','beans','bear','beat','beau','been','began','ben','bern','bran','dean','jean','kean','lean','mean'},
'beans':	{'bans','beads','beaks','beams','bean','bears','beats','deans','jeans','leans','means'},
'bear':	{'bar','bead','beak','beam','bean','beard','bears','beat','beau','beer','ber','boar','dear','ear','fear','gear','hear','lear','near','pear','rear','tear','wear','year'},
'beard':	{'bard','bead','bear','beards','bears','board','heard'},
'bearded':	{'beaded','boarded'},
'beards':	{'beads','beard','bears','boards'},
'bearer':	{'bearers','beaver','hearer','nearer','wearer'},
'bearers':	{'bearer'},
'bearing':	{'baring','beading','beaming','bearings','beating','bering','fearing','gearing','hearing','nearing','rearing','tearing','wearing'},
'bearings':	{'bearing','beatings','hearings'},
'bears':	{'bars','beads','beaks','beams','beans','bear','beard','beards','beats','beers','dears','ears','fears','gears','hears','nears','pears','tears','wears','years'},
'beast':	{'beasts','beat','best','blast','boast','breast','east','feast','least','yeast'},
'beasts':	{'beast','beats','blasts','boasts','breasts','feasts'},
'beat':	{'bat','bead','beak','beam','bean','bear','beast','beats','beau','beet','belt','bent','best','bet','boat','brat','eat','feat','heat','meat','neat','peat','seat'},
'beaten':	{'eaten'},
'beating':	{'beading','beaming','bearing','beatings','belting','betting','boating','eating','heating','seating'},
'beatings':	{'bearings','beating'},
'beatles':	{'beetles'},
'beats':	{'bats','beads','beaks','beams','beans','bears','beasts','beat','belts','bets','boats','eats','feats','heats','keats','meats','seats','yeats'},
'beau':	{'bead','beak','beam','bean','bear','beat'},
'beaver':	{'bearer','weaver'},
'became':	{'become'},
'beck':	{'back','beak','bock','buck','deck','heck','neck','peck'},
'become':	{'became','becomes'},
'becomes':	{'become'},
'bed':	{'bad','be','bead','beds','bee','beg','bel','ben','bend','ber','bet','bid','bled','bod','bred','bud','ed','fed','led','med','qed','red','ted','wed','zed'},
'bedded':	{'beaded'},
'bedding':	{'beading','bending','bidding','budding','wedding'},
'bedroom':	{'bedrooms'},
'bedrooms':	{'bedroom'},
'beds':	{'beads','bed','bees','begs','bends','bets','bids','buds','eds','feds'},
'bedside':	{'beside'},
'bee':	{'be','bed','beef','been','beep','beer','bees','beet','beg','bel','ben','ber','bet','bye','ee','fee','gee','lee','nee','pee','see','tee','wee'},
'beech':	{'beach','bench','leech'},
'beef':	{'bee','been','beep','beer','bees','beet','reef'},
'been':	{'bean','bee','beef','beep','beer','bees','beet','ben','bern','keen','seen','teen'},
'beep':	{'bee','beef','been','beer','bees','beet','deep','jeep','keep','peep','weep'},
'beer':	{'bear','bee','beef','been','beep','beers','bees','beet','ber','boer','deer','peer','seer'},
'beers':	{'bears','beer','bees','peers'},
'bees':	{'beds','bee','beef','been','beep','beer','beers','beet','begs','bets','fees','lees','sees','tees'},
'beet':	{'beat','bee','beef','been','beep','beer','bees','belt','bent','beset','best','bet','feet','meet'},
'beetle':	{'beetles'},
'beetles':	{'beatles','beetle'},
'beg':	{'bag','be','bed','bee','begs','bel','ben','ber','berg','bet','big','bog','bug','eeg','leg','meg','peg','veg'},
'began':	{'bean','begin','begun','vegan'},
'beggar':	{'beggars'},
'beggars':	{'beggar'},
'begged':	{'bagged','bogged','legged','pegged'},
'begging':	{'bagging'},
'begin':	{'began','begins','begun','benin'},
'beginner':	{'beginners'},
'beginners':	{'beginner'},
'beginning':	{'beginnings'},
'beginnings':	{'beginning'},
'begins':	{'begin'},
'begs':	{'bags','beds','bees','beg','bets','bugs','legs','megs','pegs','regs'},
'begun':	{'began','begin'},
'behave':	{'behaved','behaves'},
'behaved':	{'behave','behaves'},
'behaves':	{'behave','behaved'},
'behavior':	{'behaviors','behaviour'},
'behavioral':	{'behavioural'},
'behaviors':	{'behavior','behaviours'},
'behaviour':	{'behavior','behaviours'},
'behavioural':	{'behavioral'},
'behaviours':	{'behaviors','behaviour'},
'beheld':	{'behold'},
'behold':	{'beheld'},
'being':	{'beings','bering','bring'},
'beings':	{'being','brings'},
'bel':	{'abel','bbl','be','bed','bee','beg','bell','belt','ben','ber','bet','bl','del','eel','el','gel'},
'belated':	{'belted','related'},
'belief':	{'beliefs','relief'},
'beliefs':	{'belief'},
'believe':	{'believed','believer','believes','relieve'},
'believed':	{'believe','believer','believes','relieved'},
'believer':	{'believe','believed','believers','believes','reliever'},
'believers':	{'believer','believes'},
'believes':	{'believe','believed','believer','believers','relieves'},
'believing':	{'relieving'},
'bell':	{'ball','bel','belle','bells','belly','belt','bill','boll','bull','cell','dell','ell','fell','hell','sell','tell','well','yell'},
'belle':	{'bell','bells','belly'},
'bellied':	{'bellies','bullied'},
'bellies':	{'bellied','bullies'},
'belling':	{'belting','billing','selling','telling','yelling'},
'bellows':	{'fellows'},
'bells':	{'balls','bell','belle','belly','belts','bills','cells','hells','sells','tells','wells','yells'},
'belly':	{'bally','bell','belle','bells','billy','bully','jelly','kelly'},
'belong':	{'belongs'},
'belonging':	{'belongings'},
'belongings':	{'belonging'},
'belongs':	{'belong'},
'below':	{'blow'},
'belt':	{'beat','beet','bel','bell','belts','bent','best','bet','blt','bolt','felt','melt','welt'},
'belted':	{'belated','bolted','melted'},
'belting':	{'beating','belling','betting','melting'},
'belts':	{'beats','bells','belt','bets','bolts','melts'},
'ben':	{'ban','be','bean','bed','bee','been','beg','bel','bend','bent','ber','bern','bet','bin','bun','den','en','fen','gen','hen','ken','men','pen','sen','ten','wen','yen','zen'},
'bench':	{'beach','beech','bunch'},
'benches':	{'beaches','bunches'},
'benchmark':	{'benchmarks'},
'benchmarks':	{'benchmark'},
'bend':	{'band','bead','bed','ben','bends','bent','bind','blend','bond','end','fend','lend','mend','send','tend'},
'bender':	{'binder','blender','fender','gender','lender','render','sender','tender'},
'bending':	{'banding','beading','bedding','binding','blending','bonding','ending','lending','mending','pending','sending','tending','vending'},
'bends':	{'bands','beads','beds','bend','binds','blends','bonds','ends','lends','mends','sends','tends'},
'benefit':	{'benefits'},
'benefits':	{'benefit'},
'bengal':	{'bengali'},
'bengali':	{'bengal'},
'benign':	{'benin'},
'benin':	{'begin','benign','lenin'},
'benny':	{'bonny','bunny','jenny','penny'},
'bent':	{'beat','beet','belt','ben','bend','best','bet','brent','cent','dent','gent','kent','lent','rent','sent','tent','vent','went'},
'bequest':	{'request'},
'ber':	{'aer','bar','be','bear','bed','bee','beer','beg','bel','ben','berg','bern','bet','boer','br','bur','der','er','fer','ger','her','ker','per','uber','yer'},
'berg':	{'beg','ber','bern','burg'},
'bering':	{'baring','bearing','being','boring','bring'},
'berkshire':	{'berkshires'},
'berkshires':	{'berkshire'},
'berlin':	{'merlin'},
'bern':	{'barn','bean','been','ben','ber','berg','born','burn','fern','kern','tern'},
'berries':	{'ferries'},
'berry':	{'ferry','jerry','merry','perry','terry'},
'berth':	{'barth','beth','birth','perth'},
'beset':	{'beet','best','reset'},
'beside':	{'bedside','besides','reside'},
'besides':	{'beside','resides'},
'best':	{'beast','beat','beet','belt','bent','beset','bet','brest','bust','est','fest','jest','lest','nest','pest','rest','test','vest','west','zest'},
'bet':	{'bat','be','beat','bed','bee','beet','beg','bel','belt','ben','bent','ber','best','beta','beth','bets','bit','blt','bot','but','et','get','jet','let','met','net','pet','set','tet','vet','wet','yet'},
'beta':	{'bet','beth','bets','eta','meta','zeta'},
'beth':	{'bath','berth','bet','beta','bets','both','seth'},
'bets':	{'bats','beats','beds','bees','begs','belts','bet','beta','beth','bits','bots','gets','lets','nets','pets','sets','vets','wets'},
'better':	{'batter','bitter','butter','letter','setter'},
'betting':	{'batting','beating','belting','getting','letting','netting','setting','wetting'},
'beverage':	{'beverages','leverage'},
'beverages':	{'beverage','leverages'},
'bi':	{'ai','b','ba','bai','bb','bc','be','bib','bid','big','bin','bio','bit','biz','bk','bl','bm','br','bs','by','ci','di','fbi','gi','hi','i','ii','ji','ki','li','mi','ni','obi','pi','qi','rbi','ri','si','ti','vi','wi','xi','yi'},
'bias':	{'bibs','bids','bins','bits','bras','dias'},
'biased':	{'based','biases'},
'biases':	{'bases','biased'},
'biasing':	{'basing'},
'bib':	{'bb','bi','bibs','bid','big','bin','bio','bit','biz','bob','lib','nib','rib','sib'},
'bible':	{'bile'},
'bibs':	{'bbs','bias','bib','bids','bins','bits','bobs','libs','ribs'},
'bicycle':	{'bicycled','bicycles'},
'bicycled':	{'bicycle','bicycles'},
'bicycles':	{'bicycle','bicycled'},
'bid':	{'aid','bad','bed','bi','bib','bids','big','bin','bind','bio','bird','bit','biz','bod','bud','cid','did','hid','ibid','id','kid','lid','mid','rid'},
'bidder':	{'bidders','binder'},
'bidders':	{'bidder','binders'},
'bidding':	{'bedding','binding','birding','budding','kidding','ridding'},
'bids':	{'aids','beds','bias','bibs','bid','binds','bins','birds','bits','buds','kids','lids','rids','sids'},
'big':	{'bag','beg','bi','bib','bid','bin','bio','bit','biz','bog','brig','bug','dig','fig','gig','jig','pig','rig','sig','wig'},
'bigger':	{'digger','nigger'},
'bike':	{'bake','biker','bikes','bile','bite','hike','ike','like','mike','nike','pike'},
'biker':	{'baker','bike','bikers','bikes','hiker'},
'bikers':	{'bakers','biker','bikes','hikers'},
'bikes':	{'bakes','bike','biker','bikers','bites','dikes','hikes','likes','mikes','pikes'},
'biking':	{'baking','bikini','biting','hiking','liking','viking'},
'bikini':	{'biking','bikinis'},
'bikinis':	{'bikini'},
'bile':	{'bale','bible','bike','bill','bite','file','mile','nile','pile','tile','vile'},
'bill':	{'ball','bell','bile','bills','billy','boll','brill','bull','dill','fill','gill','hill','ill','kill','mill','pill','sill','till','will'},
'billboard':	{'billboards'},
'billboards':	{'billboard'},
'billed':	{'billet','filled','killed','milled','willed'},
'billet':	{'ballet','billed','bullet','fillet','millet'},
'billiard':	{'billiards'},
'billiards':	{'billiard'},
'billing':	{'belling','billings','filling','killing','milling','willing'},
'billings':	{'billing','fillings','killings'},
'billion':	{'billions','bullion','million','zillion'},
'billionaire':	{'millionaire'},
'billions':	{'billion','millions'},
'bills':	{'balls','bells','bill','billy','fills','hills','ills','kills','mills','pills','wills'},
'billy':	{'bally','belly','bill','bills','bully','hilly','silly'},
'bimbo':	{'limbo'},
'bin':	{'ban','ben','bi','bib','bid','big','bind','bins','bio','bit','biz','bun','din','fin','gin','in','kin','lin','min','pin','qin','sin','tin','win','yin'},
'bind':	{'band','bend','bid','bin','binds','bins','bird','blind','bond','find','hind','kind','lind','mind','wind'},
'binder':	{'bender','bidder','binders','finder','hinder','kinder','winder'},
'binders':	{'bidders','binder','finders','hinders'},
'binding':	{'banding','bending','bidding','bindings','birding','blinding','bonding','finding','minding','winding'},
'bindings':	{'binding','findings'},
'binds':	{'bands','bends','bids','bind','bins','birds','blinds','bonds','finds','kinds','minds','winds'},
'binge':	{'bingo','hinge','inge'},
'bingo':	{'binge','bongo','lingo'},
'binocular':	{'binoculars'},
'binoculars':	{'binocular'},
'bins':	{'bans','bias','bibs','bids','bin','bind','binds','bits','buns','fins','ins','pins','sins','tins','wins'},
'bio':	{'bi','bib','bid','big','bin','bit','biz','boo','brio','bro','io','rio'},
'biologist':	{'biologists'},
'biologists':	{'biologist'},
'biometric':	{'biometrics'},
'biometrics':	{'biometric'},
'bionic':	{'ionic'},
'birch':	{'birth','bitch'},
'bird':	{'bard','bid','bind','birds','byrd'},
'birding':	{'bidding','binding'},
'birds':	{'bids','binds','bird'},
'birth':	{'barth','berth','birch','births','firth','girth'},
'birthday':	{'birthdays'},
'birthdays':	{'birthday'},
'births':	{'birth'},
'biscuit':	{'biscuits'},
'biscuits':	{'biscuit'},
'bisexual':	{'bisexuals'},
'bisexuals':	{'bisexual'},
'bishop':	{'bishops'},
'bishops':	{'bishop'},
'bison':	{'boson'},
'bisque':	{'basque','risque'},
'bit':	{'bait','bat','bet','bi','bib','bid','big','bin','bio','bite','bits','biz','blt','bot','brit','but','fit','git','hit','it','kit','lit','mit','nit','obit','pit','sit','tit','wit'},
'bitch':	{'batch','birch','butch','ditch','fitch','hitch','itch','pitch','witch'},
'bitches':	{'batches','ditches','pitches','witches'},
'bitching':	{'ditching','itching','pitching'},
'bite':	{'bike','bile','bit','bites','bits','byte','cite','kite','lite','mite','rite','site'},
'bites':	{'bikes','bite','bits','bytes','cites','kites','mites','rites','sites'},
'biting':	{'biking','citing','siting'},
'bitmap':	{'bitmaps'},
'bitmaps':	{'bitmap'},
'bits':	{'baits','bats','bets','bias','bibs','bids','bins','bit','bite','bites','bots','brits','fits','hits','its','kits','obits','pits','sits','tits','wits'},
'bitten':	{'bitter','britten','kitten'},
'bitter':	{'batter','better','bitten','butter','fitter','hitter','jitter','litter','sitter'},
'biz':	{'bi','bib','bid','big','bin','bio','bit'},
'bk':	{'ak','b','ba','bb','bc','be','bi','bl','bm','br','bs','by','k','ok','uk'},
'bl':	{'al','b','ba','bb','bbl','bc','be','bel','bi','bk','blt','bm','br','bs','by','cl','el','fl','il','l','ll','ml','tl','xl'},
'black':	{'back','blacks','blank','block','lack','slack'},
'blacken':	{'blacker','bracken'},
'blacker':	{'blacken','blocker'},
'blacks':	{'backs','black','blanks','blocks','lacks'},
'bladder':	{'gladder','ladder'},
'blade':	{'bade','blades','blake','blame','blaze','glade'},
'blades':	{'blade','blames'},
'blair':	{'flair','lair'},
'blake':	{'bake','blade','blame','blaze','bloke','brake','flake','lake'},
'blame':	{'blade','blake','blamed','blames','blaze','flame','lame'},
'blamed':	{'beamed','blame','blames'},
'blames':	{'blades','blame','blamed','flames'},
'blaming':	{'beaming','blazing','flaming'},
'bland':	{'band','blank','blend','blind','blond','brand','gland','land'},
'blank':	{'bank','black','bland','blanks','blink','flank','plank'},
'blanket':	{'blankets'},
'blankets':	{'blanket'},
'blanks':	{'banks','blacks','blank','planks'},
'blast':	{'beast','blasts','boast','last'},
'blasted':	{'blaster','boasted','lasted'},
'blaster':	{'blasted','blister','plaster'},
'blasting':	{'boasting','lasting'},
'blasts':	{'beasts','blast','boasts','lasts'},
'blaze':	{'blade','blake','blame','blazer','glaze'},
'blazer':	{'blaze'},
'blazing':	{'blaming','glazing'},
'bleach':	{'beach','breach','leach'},
'bleached':	{'breached'},
'bleaching':	{'leaching'},
'bleak':	{'beak','break','leak'},
'bled':	{'bed','bleed','blend','blew','bred','fled','led','sled'},
'bleed':	{'bled','bleeds','blend','breed'},
'bleeding':	{'blending','breeding'},
'bleeds':	{'bleed','blends','breeds','leeds'},
'blend':	{'bend','bland','bled','bleed','blends','blind','blond','lend'},
'blended':	{'blender','blinded'},
'blender':	{'bender','blended','blenders','lender','slender'},
'blenders':	{'blender','lenders'},
'blending':	{'bending','bleeding','blinding','lending'},
'blends':	{'bends','bleeds','blend','blinds','lends'},
'bless':	{'bliss','less'},
'blessed':	{'blesses'},
'blesses':	{'blessed'},
'blessing':	{'blessings'},
'blessings':	{'blessing'},
'blew':	{'bled','blow','brew','flew','slew'},
'blight':	{'bright','flight','light','plight','slight'},
'blind':	{'bind','bland','blend','blinds','blink','blond','lind'},
'blinded':	{'blended','blinked'},
'blinding':	{'binding','blending','blinking'},
'blinds':	{'binds','blends','blind'},
'blink':	{'blank','blind','brink','link'},
'blinked':	{'blinded','linked'},
'blinking':	{'blinding','linking'},
'bliss':	{'bless'},
'blister':	{'blaster','blisters','lister'},
'blisters':	{'blister'},
'bloated':	{'floated'},
'blob':	{'bloc','blog','blot','blow','bob','boob','lob'},
'bloc':	{'blob','bloch','block','blog','blot','blow'},
'bloch':	{'bloc','block','loch'},
'block':	{'black','bloc','bloch','blocks','bock','clock','flock','lock'},
'blockade':	{'blockage'},
'blockage':	{'blockade'},
'blocked':	{'blocker','clocked','locked'},
'blocker':	{'blacker','blocked','blockers','locker'},
'blockers':	{'blocker','lockers'},
'blocking':	{'locking'},
'blocks':	{'blacks','block','clocks','flocks','locks'},
'blog':	{'blob','bloc','blogs','blot','blow','bog','clog','log'},
'blogger':	{'logger'},
'blogs':	{'blog','blows','clogs','logs'},
'bloke':	{'blake','broke'},
'blond':	{'bland','blend','blind','blood','bond'},
'blood':	{'blond','bloody','bloom','brood','flood'},
'blooded':	{'flooded'},
'bloody':	{'blood'},
'bloom':	{'blood','blooms','boom','broom','gloom','loom'},
'blooming':	{'booming','looming'},
'blooms':	{'bloom','booms','looms'},
'blossom':	{'blossoms'},
'blossoms':	{'blossom'},
'blot':	{'blob','bloc','blog','blow','blt','boot','bot','clot','lot','plot','slot'},
'blotting':	{'clotting','plotting'},
'blouse':	{'blouses'},
'blouses':	{'blouse'},
'blow':	{'below','blew','blob','bloc','blog','blot','blown','blows','bow','brow','flow','glow','low','plow','slow'},
'blower':	{'bower','flower','lower','slower'},
'blowing':	{'bowing','flowing','glowing','lowing','slowing'},
'blown':	{'blow','blows','brown','clown','flown'},
'blows':	{'blogs','blow','blown','bows','brows','flows','lows','slows'},
'blt':	{'alt','bat','belt','bet','bit','bl','blot','bolt','bot','but'},
'blue':	{'bluer','blues','blur','clue','flue','glue'},
'blueprint':	{'blueprints'},
'blueprints':	{'blueprint'},
'bluer':	{'blue','blues','blur'},
'blues':	{'blue','bluer','bluest','clues'},
'bluest':	{'blues'},
'bluff':	{'bluffs','buff','fluff'},
'bluffs':	{'bluff','buffs'},
'blur':	{'blue','bluer','blurb','bur'},
'blurb':	{'blur','blurbs'},
'blurbs':	{'blurb'},
'blurry':	{'flurry','slurry'},
'blush':	{'brush','bush','flush','lush','plush'},
'bm':	{'abm','am','b','ba','bb','bc','be','bi','bk','bl','br','bs','bum','by','cm','em','fm','gm','hm','km','mm','nm','pm','rm','sm','tm','um','wm'},
'boa':	{'ba','baa','boar','boat','bob','bod','bog','bola','boo','bop','bot','bow','box','boy','bra','goa'},
'boar':	{'bar','bear','boa','board','boat','boer','bohr','oar','roar','soar'},
'board':	{'aboard','bard','beard','boar','boards'},
'boarded':	{'bearded'},
'boards':	{'beards','board'},
'boast':	{'beast','blast','boasts','boat','boost','coast','roast','toast'},
'boasted':	{'blasted','boosted','roasted','toasted'},
'boasting':	{'blasting','boating','boosting','roasting'},
'boasts':	{'beasts','blasts','boast','boats','boosts','coasts','roasts'},
'boat':	{'bat','beat','boa','boar','boast','boats','bolt','boot','bot','bout','brat','coat','goat','oat'},
'boating':	{'beating','boasting','booting','coating'},
'boats':	{'bats','beats','boasts','boat','bolts','boots','bots','bouts','coats','goats','oats'},
'bob':	{'bb','bib','blob','boa','bobs','bod','bog','bomb','boo','boob','bop','bot','bow','box','boy','cob','fob','hob','job','lob','mob','nob','ob','rob','sob'},
'bobble':	{'babble','bubble'},
'bobby':	{'hobby','lobby'},
'bobs':	{'bbs','bibs','bob','bombs','boobs','boss','bots','bows','boys','jobs','mobs','robs'},
'bock':	{'back','beck','block','book','buck','cock','dock','jock','lock','mock','rock','sock'},
'bod':	{'bad','bed','bid','boa','bob','bode','body','bog','bold','bond','boo','bop','bot','bow','box','boy','bud','cod','dod','god','mod','nod','od','pod','rod','sod','tod'},
'bode':	{'abode','bade','bod','body','bone','bore','bose','code','mode','node','ode','rode'},
'bodied':	{'bodies'},
'bodies':	{'bodied'},
'body':	{'bod','bode','bony','boy','cody'},
'bodybuilder':	{'bodybuilders'},
'bodybuilders':	{'bodybuilder'},
'boer':	{'beer','ber','boar','bohr','bower','boxer'},
'bog':	{'bag','beg','big','blog','boa','bob','bod','bong','boo','bop','bot','bow','box','boy','bug','cog','dog','fog','hog','jog','log'},
'bogged':	{'bagged','begged','dogged','logged'},
'bogus':	{'bonus'},
'bohemia':	{'bohemian'},
'bohemian':	{'bohemia'},
'bohr':	{'boar','boer'},
'boil':	{'bail','boils','boll','bowl','broil','coil','foil','oil','soil','toil'},
'boiled':	{'boiler','bowled','coiled','oiled','soiled'},
'boiler':	{'boiled','boilers','bowler'},
'boilers':	{'boiler','bowlers'},
'boiling':	{'bowling','soiling'},
'boils':	{'boil','bowls','coils','foils','oils','soils'},
'boise':	{'bose','noise'},
'bola':	{'boa','bold','boll','bolt','cola','ola'},
'bold':	{'bald','bod','bola','boll','bolt','bond','cold','fold','gold','hold','mold','old','sold','told'},
'bolder':	{'border','boulder','colder','folder','holder','older','solder'},
'boldest':	{'coldest','oldest'},
'boldly':	{'coldly'},
'boldness':	{'baldness','coldness'},
'bolivia':	{'bolivian'},
'bolivian':	{'bolivia'},
'boll':	{'ball','bell','bill','boil','bola','bold','bolt','bowl','bull','doll','moll','poll','roll','toll'},
'bolster':	{'booster','holster'},
'bolt':	{'belt','blt','boat','bola','bold','boll','bolts','boot','bot','bout','colt','jolt','volt'},
'bolted':	{'belted','booted'},
'bolts':	{'belts','boats','bolt','boots','bots','bouts','volts'},
'bomb':	{'bob','bombs','boob','comb','omb','tomb','womb'},
'bombed':	{'bomber','combed'},
'bomber':	{'bombed','bombers'},
'bombers':	{'bomber'},
'bombing':	{'bombings','combing'},
'bombings':	{'bombing'},
'bombs':	{'bobs','bomb','boobs','combs','tombs'},
'bond':	{'band','bend','bind','blond','bod','bold','bonds','bone','boned','bong','bonn','bony','bound','fond','pond'},
'bondage':	{'bandage'},
'bonded':	{'banded','boned','bounded'},
'bonding':	{'banding','bending','binding','boning','bounding'},
'bonds':	{'bands','bends','binds','bond','bones','bongs','bonus','bounds','ponds'},
'bone':	{'bane','bode','bond','boned','bones','bong','bonn','bony','boone','bore','borne','bose','cone','done','gone','hone','lone','none','one','tone','zone'},
'boned':	{'bond','bonded','bone','bones','bored','bowed','boxed','honed','toned','zoned'},
'bones':	{'bonds','bone','boned','bongs','bonus','boxes','cones','jones','ones','tones','zones'},
'bong':	{'bang','bog','bond','bone','bongo','bongs','bonn','bony','dong','gong','long','pong','song'},
'bongo':	{'bingo','bong','bongs','congo'},
'bongs':	{'bangs','bonds','bones','bong','bongo','bonus','longs','songs'},
'boning':	{'bonding','boring','bowing','boxing','toning','zoning'},
'bonn':	{'bond','bone','bong','bonny','bony','boon','born','conn'},
'bonnet':	{'sonnet'},
'bonny':	{'benny','bonn','bony','bunny','sonny'},
'bonus':	{'bogus','bonds','bones','bongs','onus'},
'bony':	{'body','bond','bone','bong','bonn','bonny','boy','ebony','pony'},
'boo':	{'bio','boa','bob','bod','bog','boob','book','boom','boon','boot','bop','bot','bow','box','boy','bro','coo','goo','loo','moo','poo','too','woo','zoo'},
'boob':	{'blob','bob','bomb','boo','boobs','book','boom','boon','boot'},
'boobies':	{'booties'},
'boobs':	{'bobs','bombs','boob','books','booms','boots'},
'book':	{'bock','boo','boob','books','boom','boon','boot','brook','cook','hook','look','nook','rook','took'},
'bookcase':	{'bookcases'},
'bookcases':	{'bookcase'},
'booked':	{'booker','booted','cooked','hooked','looked'},
'booker':	{'booked','boomer','broker','cooker','hooker'},
'booking':	{'bookings','booming','booting','cooking','hooking','looking'},
'bookings':	{'booking'},
'booklet':	{'booklets'},
'booklets':	{'booklet'},
'bookmaker':	{'bookmakers'},
'bookmakers':	{'bookmaker'},
'bookmark':	{'bookmarks'},
'bookmarks':	{'bookmark'},
'books':	{'boobs','book','booms','boots','brooks','cooks','hooks','looks'},
'bookseller':	{'booksellers'},
'booksellers':	{'bookseller'},
'bookstore':	{'bookstores'},
'bookstores':	{'bookstore'},
'boom':	{'bloom','boo','boob','book','booms','boon','boot','bosom','broom','doom','loom','room','zoom'},
'boomer':	{'booker','boomers'},
'boomers':	{'boomer'},
'booming':	{'blooming','booking','booting','looming','zooming'},
'booms':	{'blooms','boobs','books','boom','boots','looms','rooms'},
'boon':	{'bonn','boo','boob','book','boom','boone','boot','born','boron','boson','coon','loon','moon','noon','soon'},
'boone':	{'bone','boon','booze','borne','noone'},
'boost':	{'boast','boosts','boot','roost'},
'boosted':	{'boasted','booster','booted'},
'booster':	{'bolster','boosted','boosters','rooster'},
'boosters':	{'booster'},
'boosting':	{'boasting','booting'},
'boosts':	{'boasts','boost','boots'},
'boot':	{'blot','boat','bolt','boo','boob','book','boom','boon','boost','booth','boots','booty','bot','bout','foot','hoot','loot','moot','root','soot'},
'booted':	{'bolted','booked','boosted','footed','looted','rooted'},
'booth':	{'boot','booths','boots','booty','both','broth','tooth'},
'booths':	{'booth','boots'},
'booties':	{'boobies'},
'booting':	{'boating','booking','booming','boosting','footing','looting','rooting'},
'boots':	{'boats','bolts','boobs','books','booms','boosts','boot','booth','booths','booty','bots','bouts','roots'},
'booty':	{'boot','booth','boots'},
'booze':	{'boone','ooze'},
'bop':	{'boa','bob','bod','bog','boo','bot','bow','box','boy','cop','gop','hop','mop','op','pop','sop','top','wop'},
'border':	{'bolder','borders','order'},
'bordered':	{'ordered'},
'bordering':	{'ordering'},
'borders':	{'border','orders'},
'bore':	{'bare','bode','bone','bored','born','borne','bose','core','fore','gore','lore','more','ore','pore','sore','tore','wore'},
'bored':	{'bared','boned','bore','bowed','boxed','bred','cored'},
'borges':	{'barges'},
'boring':	{'baring','bering','boning','bowing','boxing','bring','coring'},
'born':	{'barn','bern','bonn','boon','bore','borne','boron','burn','corn','horn','morn','porn','torn','worn'},
'borne':	{'bone','boone','bore','born','borneo','horne'},
'borneo':	{'borne'},
'boron':	{'baron','boon','born','boson','byron','moron'},
'borough':	{'boroughs'},
'boroughs':	{'borough'},
'borrow':	{'barrow','borrows','morrow','sorrow'},
'borrowed':	{'borrower'},
'borrower':	{'borrowed','borrowers'},
'borrowers':	{'borrower'},
'borrowing':	{'borrowings'},
'borrowings':	{'borrowing'},
'borrows':	{'borrow','sorrows'},
'bose':	{'base','bode','boise','bone','bore','boss','dose','hose','lose','nose','pose','rose'},
'bosnia':	{'bosnian'},
'bosnian':	{'bosnia'},
'bosom':	{'boom','boson'},
'boson':	{'bison','boon','boron','bosom','boston'},
'boss':	{'bass','bobs','bose','bots','bows','boys','loss','moss','ross','toss'},
'bosses':	{'basses','losses'},
'boston':	{'boson'},
'boswell':	{'roswell'},
'bot':	{'bat','bet','bit','blot','blt','boa','boat','bob','bod','bog','bolt','boo','boot','bop','both','bots','bout','bow','box','boy','but','cot','dot','got','hot','lot','mot','not','pot','rot','sot','tot','wot'},
'both':	{'bath','beth','booth','bot','bots','broth','doth','goth','moth','roth'},
'bother':	{'bothers','brother','mother','other'},
'bothers':	{'bother','brothers','mothers','others'},
'bots':	{'bats','bets','bits','boats','bobs','bolts','boots','boss','bot','both','bouts','bows','boys','cots','dots','lots','pots','rots','tots'},
'bottle':	{'battle','bottled','bottles'},
'bottled':	{'battled','bottle','bottles'},
'bottleneck':	{'bottlenecks'},
'bottlenecks':	{'bottleneck'},
'bottles':	{'battles','bottle','bottled'},
'bottling':	{'battling'},
'bottom':	{'bottoms'},
'bottoms':	{'bottom'},
'bough':	{'bought','cough','dough','lough','rough','tough'},
'bought':	{'bough','brought','fought','ought','sought'},
'boulder':	{'bolder','boulders'},
'boulders':	{'boulder'},
'bounce':	{'bounced','bounces','bouncy','ounce'},
'bounced':	{'bounce','bounces','bounded'},
'bounces':	{'bounce','bounced','ounces'},
'bouncing':	{'bounding'},
'bouncy':	{'bounce','bounty'},
'bound':	{'abound','bond','bounds','found','hound','mound','pound','round','sound','wound'},
'bounded':	{'bonded','bounced','founded','pounded','rounded','sounded','wounded'},
'bounding':	{'bonding','bouncing','founding','pounding','rounding','sounding','wounding'},
'bounds':	{'bonds','bound','hounds','mounds','pounds','rounds','sounds','wounds'},
'bounty':	{'bouncy','county'},
'bouquet':	{'bouquets'},
'bouquets':	{'bouquet'},
'bout':	{'about','boat','bolt','boot','bot','bouts','brut','but','gout','out','rout','tout'},
'boutique':	{'boutiques'},
'boutiques':	{'boutique'},
'bouts':	{'boats','bolts','boots','bots','bout','outs','touts'},
'bow':	{'blow','boa','bob','bod','bog','boo','bop','bot','bowl','bows','box','boy','brow','cow','how','low','now','ow','pow','row','sow','tow','vow','wow'},
'bowed':	{'boned','bored','bowel','bower','bowled','boxed','owed','rowed','sowed','towed','vowed'},
'bowel':	{'bowed','bowels','bower','bowl','towel','vowel'},
'bowels':	{'bowel','bowls','towels','vowels'},
'bower':	{'blower','boer','bowed','bowel','bowler','boxer','lower','mower','power','tower'},
'bowing':	{'blowing','boning','boring','bowling','boxing','lowing','mowing','owing','rowing','sowing','towing'},
'bowl':	{'boil','boll','bow','bowel','bowls','bows','fowl','howl','owl'},
'bowled':	{'boiled','bowed','bowler'},
'bowler':	{'boiler','bower','bowled','bowlers','fowler'},
'bowlers':	{'boilers','bowler'},
'bowling':	{'boiling','bowing','howling'},
'bowls':	{'boils','bowels','bowl','bows'},
'bows':	{'blows','bobs','boss','bots','bow','bowl','bowls','boys','brows','cows','hows','lows','rows','sows','vows'},
'box':	{'boa','bob','bod','bog','boo','bop','bot','bow','boy','cox','fox','ox','pox'},
'boxed':	{'boned','bored','bowed','boxer','boxes'},
'boxer':	{'boer','bower','boxed','boxers','boxes'},
'boxers':	{'boxer','boxes'},
'boxes':	{'bones','boxed','boxer','boxers','foxes'},
'boxing':	{'boning','boring','bowing'},
'boy':	{'bay','boa','bob','bod','body','bog','bony','boo','bop','bot','bow','box','boys','buoy','buy','by','coy','joy','soy','toy'},
'boyfriend':	{'boyfriends'},
'boyfriends':	{'boyfriend'},
'boyle':	{'hoyle'},
'boys':	{'bays','bobs','boss','bots','bows','boy','buoys','buys','joys','toys'},
'bps':	{'bbs','bs','bus','cps','fps','ops','ps'},
'br':	{'ar','b','ba','bar','bb','bc','be','ber','bi','bk','bl','bm','bra','bro','bs','bur','by','cr','dr','er','fr','hr','ir','jr','kr','lr','mr','or','pr','qr','r','sr','ur','yr','zr'},
'bra':	{'ara','ba','baa','boa','br','brad','brag','bran','bras','brat','bray','bro','era','ira','nra','ra'},
'brace':	{'braces','brake','brave','bruce','grace','race','trace'},
'bracelet':	{'bracelets'},
'bracelets':	{'bracelet'},
'braces':	{'brace','brakes','braves','graces','races','traces'},
'bracing':	{'braking','braving','gracing','racing','tracing'},
'bracken':	{'blacken','bracket'},
'bracket':	{'bracken','brackets','racket'},
'brackets':	{'bracket'},
'brad':	{'bad','bead','bra','brady','brag','braid','bran','brand','bras','brat','bray','bread','bred','broad','grad','rad','trad'},
'brady':	{'brad','brandy','bray'},
'brag':	{'bag','bra','brad','bragg','bran','bras','brat','bray','brig','drag','rag'},
'bragg':	{'brag'},
'bragging':	{'bagging','dragging'},
'brahma':	{'brahms'},
'brahms':	{'brahma'},
'braid':	{'brad','brain','brand','raid'},
'braided':	{'branded','raided'},
'brain':	{'braid','brains','bran','bruin','drain','grain','rain','train'},
'brains':	{'brain','drains','grains','rains','trains'},
'brake':	{'bake','blake','brace','brakes','brave','broke','drake','rake'},
'brakes':	{'bakes','braces','brake','braves','rakes'},
'braking':	{'baking','bracing','braving','breaking','raking'},
'bran':	{'ban','bean','bra','brad','brag','brain','brand','brant','bras','brat','bray','bryan','gran','iran','ran'},
'branch':	{'brunch','ranch'},
'branched':	{'branches'},
'branches':	{'branched','ranches'},
'brand':	{'band','bland','brad','braid','bran','brands','brandt','brandy','brant','grand','rand'},
'branded':	{'banded','braided'},
'branding':	{'banding'},
'brands':	{'bands','brand','brandt','brandy'},
'brandt':	{'brand','brands','brandy','brant'},
'brandy':	{'brady','brand','brands','brandt','randy'},
'brant':	{'bran','brand','brandt','brat','brent','grant','rant'},
'bras':	{'bias','bra','brad','brag','bran','brass','brat','bray','bros','eras'},
'brass':	{'bass','bras','grass'},
'brat':	{'bat','beat','boat','bra','brad','brag','bran','brant','bras','bray','brit','brut','frat','rat'},
'brave':	{'brace','brake','braved','braves','bravo','crave','grave','rave'},
'braved':	{'brave','braves'},
'bravely':	{'bravery','gravely'},
'bravery':	{'bravely'},
'braves':	{'braces','brakes','brave','braved','graves','raves'},
'braving':	{'bracing','braking','craving','raving'},
'bravo':	{'brave'},
'bray':	{'bay','bra','brad','brady','brag','bran','bras','brat','fray','gray','pray','ray','tray'},
'breach':	{'beach','bleach','breath','preach','reach'},
'breached':	{'bleached','breaches','breathed','preached','reached'},
'breaches':	{'beaches','breached','breathes','preaches','reaches'},
'bread':	{'bead','brad','breads','break','bred','breed','broad','dread','read','tread'},
'breads':	{'beads','bread','breaks','breeds','reads'},
'breadth':	{'breath'},
'break':	{'beak','bleak','bread','breaks','freak'},
'breakdown':	{'breakdowns'},
'breakdowns':	{'breakdown'},
'breaker':	{'breakers'},
'breakers':	{'breaker'},
'breakfast':	{'breakfasts'},
'breakfasts':	{'breakfast'},
'breaking':	{'braking','freaking'},
'breaks':	{'beaks','breads','break','freaks'},
'breakthrough':	{'breakthroughs'},
'breakthroughs':	{'breakthrough'},
'breast':	{'abreast','beast','breasts','brest'},
'breasts':	{'beasts','breast'},
'breath':	{'breach','breadth','breathe','breaths','wreath'},
'breathe':	{'breath','breathed','breathes','breaths'},
'breathed':	{'breached','breathe','breathes'},
'breathes':	{'breaches','breathe','breathed','breaths'},
'breaths':	{'breath','breathe','breathes','wreaths'},
'bred':	{'bared','bed','bled','bored','brad','bread','breed','brew','cred','red'},
'breed':	{'bleed','bread','bred','breeds','brewed','creed','freed','greed','reed'},
'breeding':	{'bleeding'},
'breeds':	{'bleeds','breads','breed','reeds'},
'breeze':	{'breezes','breezy','freeze'},
'breezes':	{'breeze','freezes'},
'breezy':	{'breeze'},
'brent':	{'bent','brant','brest','rent','trent'},
'brest':	{'best','breast','brent','crest','rest'},
'breton':	{'briton'},
'brew':	{'blew','bred','brow','crew','drew','grew'},
'brewed':	{'breed','brewer'},
'brewer':	{'brewed','brewery'},
'brewery':	{'brewer'},
'bribe':	{'bribed','bribes','bride','brie','brine','tribe'},
'bribed':	{'bribe','bribes'},
'bribes':	{'bribe','bribed','brides','tribes'},
'brick':	{'bricks','brink','brisk','prick','rick','trick'},
'bricks':	{'brick','tricks'},
'bride':	{'bribe','brides','bridge','brie','brine','pride','ride'},
'brides':	{'bribes','bride','bridges','prides','rides'},
'bridge':	{'bride','bridged','bridges','bridget','fridge','ridge'},
'bridged':	{'abridged','bridge','bridges','bridget'},
'bridges':	{'brides','bridge','bridged','bridget','fridges','ridges'},
'bridget':	{'bridge','bridged','bridges'},
'bridging':	{'bringing'},
'brie':	{'bribe','bride','brief','brig','brim','brine','brio','brit','erie'},
'brief':	{'brie','briefs','grief'},
'briefcase':	{'briefcases'},
'briefcases':	{'briefcase'},
'briefing':	{'briefings'},
'briefings':	{'briefing'},
'briefs':	{'brief'},
'brig':	{'big','brag','brie','brim','bring','brio','brit','orig','rig','trig'},
'brigade':	{'brigades'},
'brigades':	{'brigade'},
'bright':	{'blight','fright','right','wright'},
'brighten':	{'brightens','brighter','brighton','frighten'},
'brightened':	{'frightened'},
'brightening':	{'frightening'},
'brightens':	{'brighten','frightens'},
'brighter':	{'brighten'},
'brightly':	{'rightly'},
'brighton':	{'brighten'},
'brill':	{'bill','drill','grill'},
'brim':	{'brie','brig','brio','brit','grim','rim','trim'},
'brine':	{'bribe','bride','brie','bring','brink','urine'},
'bring':	{'baring','being','bering','boring','brig','brine','brings','brink','ring'},
'bringing':	{'bridging','ringing'},
'brings':	{'beings','bring','rings'},
'brink':	{'blink','brick','brine','bring','brisk','drink','rink'},
'brio':	{'bio','brie','brig','brim','brit','brno','bro','rio','trio'},
'brisk':	{'brick','brink','risk'},
'brit':	{'bait','bit','brat','brie','brig','brim','brio','brits','britt','brut','grit','writ'},
'briton':	{'breton','triton'},
'brits':	{'baits','bits','brit','britt'},
'britt':	{'brit','brits'},
'britten':	{'bitten','written'},
'brno':	{'arno','brio','bro','bruno'},
'bro':	{'bio','boo','br','bra','brio','brno','bros','brow','fro','pro'},
'broad':	{'abroad','brad','bread','brood','road'},
'broadcast':	{'broadcasts'},
'broadcasted':	{'broadcaster'},
'broadcaster':	{'broadcasted','broadcasters'},
'broadcasters':	{'broadcaster'},
'broadcasts':	{'broadcast'},
'broaden':	{'broader'},
'broader':	{'broaden'},
'broadway':	{'roadway'},
'brochure':	{'brochures'},
'brochures':	{'brochure'},
'broil':	{'boil'},
'broke':	{'bloke','brake','broken','broker','brooke'},
'broken':	{'broke','broker'},
'broker':	{'booker','broke','broken','brokers'},
'brokers':	{'broker'},
'bronte':	{'bronze'},
'bronze':	{'bronte'},
'brood':	{'blood','broad','brook','broom'},
'brook':	{'book','brood','brooke','brooks','broom','crook','rook'},
'brooke':	{'broke','brook','brooks'},
'brooks':	{'books','brook','brooke','crooks'},
'broom':	{'bloom','boom','brood','brook','groom','room'},
'bros':	{'bras','bro','brow','brows','eros','pros'},
'broth':	{'booth','both','roth'},
'brother':	{'bother','brothers'},
'brothers':	{'bothers','brother'},
'brought':	{'bought','drought','wrought'},
'brow':	{'blow','bow','brew','bro','bros','brown','brows','crow','grow','row'},
'brown':	{'blown','brow','browne','browns','brows','crown','drown','frown','grown'},
'browne':	{'brown','browned','brownie','browns','browse'},
'browned':	{'browne','browsed','crowned','drowned','frowned'},
'brownie':	{'browne','brownies'},
'brownies':	{'brownie'},
'browning':	{'browsing','crowning','drowning'},
'browns':	{'brown','browne','brows','crowns','drowns'},
'brows':	{'blows','bows','bros','brow','brown','browns','browse','crows','grows','rows'},
'browse':	{'browne','brows','browsed','browser'},
'browsed':	{'browned','browse','browser'},
'browser':	{'browse','browsed','browsers'},
'browsers':	{'browser'},
'browsing':	{'browning'},
'bruce':	{'brace','brute','truce'},
'bruin':	{'brain','ruin'},
'bruised':	{'bruises'},
'bruises':	{'bruised','cruises'},
'bruising':	{'cruising'},
'brunch':	{'branch','bunch','crunch'},
'brunette':	{'brunettes'},
'brunettes':	{'brunette'},
'bruno':	{'brno'},
'brush':	{'blush','bush','crush','rush'},
'brushed':	{'brushes','crushed','rushed'},
'brushes':	{'brushed','bushes','crushes','rushes'},
'brushing':	{'crushing','rushing'},
'brut':	{'bout','brat','brit','brute','but','rut'},
'brute':	{'bruce','brut'},
'bryan':	{'aryan','bran'},
'bs':	{'abs','as','b','ba','bb','bbs','bc','be','bi','bk','bl','bm','bps','br','bus','by','cs','es','hs','is','ks','ms','os','pbs','ps','ss','ts','us','vs'},
'bubble':	{'babble','bobble','bubbles','bubbly','bumble','hubble','rubble'},
'bubbles':	{'bubble'},
'bubbly':	{'bubble'},
'buck':	{'back','beck','bock','bucks','bulk','bunk','duck','fuck','huck','luck','muck','puck','suck','tuck'},
'bucket':	{'buckets'},
'buckets':	{'bucket'},
'buckle':	{'buckles'},
'buckles':	{'buckle'},
'bucks':	{'backs','buck','ducks','sucks'},
'bud':	{'bad','baud','bed','bid','bod','buds','bug','bum','bun','bur','bus','but','buy','hud','mud','pud'},
'buddhism':	{'buddhist'},
'buddhist':	{'buddhism'},
'budding':	{'bedding','bidding','pudding'},
'buddy':	{'muddy'},
'budget':	{'budgets'},
'budgets':	{'budget'},
'buds':	{'beds','bids','bud','bugs','buns','bus','buys'},
'buff':	{'bluff','buffs','cuff','duff','huff','puff','ruff'},
'buffer':	{'buffers','buffet','suffer'},
'buffered':	{'suffered'},
'buffering':	{'suffering'},
'buffers':	{'buffer','suffers'},
'buffet':	{'buffer'},
'buffs':	{'bluffs','buff','cuffs','puffs'},
'bug':	{'aug','bag','beg','big','bog','bud','bugs','bum','bun','bur','burg','bus','but','buy','dug','hug','jug','lug','mug','pug','rug','tug'},
'bugs':	{'bags','begs','buds','bug','buns','bus','buys','hugs','jugs','mugs','rugs'},
'build':	{'builds','built','guild'},
'build-up':	{'buildup'},
'builder':	{'builders','guilder'},
'builders':	{'builder','guilders'},
'building':	{'buildings'},
'buildings':	{'building'},
'builds':	{'build','guilds'},
'buildup':	{'build-up'},
'built':	{'build','guilt','quilt'},
'bulb':	{'bulbs','bulk','bull'},
'bulbs':	{'bulb'},
'bulgaria':	{'bulgarian'},
'bulgarian':	{'bulgaria'},
'bulk':	{'buck','bulb','bulky','bull','bunk','hulk'},
'bulky':	{'bulk','bully'},
'bull':	{'ball','bell','bill','boll','bulb','bulk','bully','dull','full','gull','hull','mull','null','pull'},
'bullet':	{'ballet','billet','bullets','mullet'},
'bulletin':	{'bulletins'},
'bulletins':	{'bulletin'},
'bullets':	{'bullet'},
'bullied':	{'bellied','bullies'},
'bullies':	{'bellies','bullied'},
'bullion':	{'billion'},
'bully':	{'bally','belly','billy','bulky','bull','fully','gully','sully','tully'},
'bum':	{'baum','bm','bud','bug','bump','bun','bur','bus','but','buy','cum','gum','hum','mum','rum','sum','um','yum'},
'bumble':	{'bubble','fumble','humble','jumble','rumble','tumble'},
'bump':	{'bum','bumps','bumpy','dump','hump','jump','lump','pump','sump'},
'bumped':	{'bumper','dumped','jumped','pumped'},
'bumper':	{'bumped','bumpers','jumper'},
'bumpers':	{'bumper','jumpers'},
'bumping':	{'dumping','humping','jumping','pumping'},
'bumps':	{'bump','bumpy','dumps','humps','jumps','lumps','pumps'},
'bumpy':	{'bump','bumps'},
'bun':	{'ban','ben','bin','bud','bug','bum','bunk','buns','bur','burn','bus','but','buy','dun','fun','gun','hun','nun','pun','run','sun','un'},
'bunch':	{'bench','brunch','butch','lunch','munch','punch'},
'bunches':	{'benches','lunches','punches'},
'bundle':	{'bundled','bundles'},
'bundled':	{'bundle','bundles'},
'bundles':	{'bundle','bundled'},
'bungalow':	{'bungalows'},
'bungalows':	{'bungalow'},
'bunk':	{'bank','buck','bulk','bun','buns','dunk','funk','hunk','junk','punk','sunk'},
'bunker':	{'banker','bunkers'},
'bunkers':	{'bankers','bunker'},
'bunnies':	{'funnies'},
'bunny':	{'benny','bonny','funny','runny','sunny'},
'buns':	{'bans','bins','buds','bugs','bun','bunk','burns','bus','buys','guns','nuns','runs','suns'},
'bunting':	{'busting','hunting'},
'buoy':	{'boy','buoys','bury','busy','buy'},
'buoys':	{'boys','buoy','buys'},
'bur':	{'bar','ber','blur','br','bud','bug','bum','bun','burg','burn','burr','burt','bury','bus','but','buy','cur','dur','fur','our','ur'},
'burden':	{'burdens'},
'burdens':	{'burden'},
'bureau':	{'bureaus'},
'bureaus':	{'bureau'},
'burg':	{'berg','bug','bur','burn','burr','burt','bury'},
'burger':	{'burgers','burner'},
'burgers':	{'burger','burgess','burners'},
'burgess':	{'burgers'},
'burglar':	{'burglary'},
'burglary':	{'burglar'},
'burial':	{'burials'},
'burials':	{'burial'},
'buried':	{'buries','burned'},
'buries':	{'buried','juries'},
'burn':	{'barn','bern','born','bun','bur','burg','burns','burnt','burr','burt','bury','turn','urn'},
'burned':	{'buried','burner','turned'},
'burner':	{'burger','burned','burners','turner'},
'burners':	{'burgers','burner'},
'burning':	{'burying','turning'},
'burnout':	{'turnout'},
'burns':	{'barns','buns','burn','burnt','turns','urns'},
'burnt':	{'burn','burns','burst','burt'},
'burr':	{'bur','burg','burn','burt','bury'},
'burst':	{'burnt','bursts','burt','bust'},
'bursting':	{'busting'},
'bursts':	{'burst'},
'burt':	{'bart','bur','burg','burn','burnt','burr','burst','bury','bust','but','butt','curt','hurt'},
'burton':	{'button'},
'bury':	{'buoy','bur','burg','burn','burr','burt','busy','buy','fury','jury'},
'burying':	{'burning','buying'},
'bus':	{'bbs','bps','bs','bud','buds','bug','bugs','bum','bun','buns','bur','bush','busi','bust','busy','but','buy','buys','mus','pus','us'},
'busby':	{'bushy','busty','busy'},
'buses':	{'abuses','bases','bushes','fuses','uses'},
'bush':	{'bash','blush','brush','bus','bushy','busi','bust','busy','hush','lush','push','rush'},
'bushels':	{'bushes'},
'bushes':	{'brushes','buses','bushels','pushes','rushes'},
'bushy':	{'busby','bush','busty','busy'},
'busi':	{'bus','bush','bust','busy'},
'busier':	{'buster'},
'businessman':	{'businessmen'},
'businessmen':	{'businessman'},
'businesswoman':	{'businesswomen'},
'businesswomen':	{'businesswoman'},
'bussed':	{'busted'},
'bussing':	{'busting'},
'bust':	{'best','burst','burt','bus','bush','busi','busty','busy','but','butt','dust','gust','just','lust','must','rust'},
'busted':	{'bussed','buster','dusted','ousted','rusted'},
'buster':	{'busier','busted','busters','butter','custer','duster','luster','muster'},
'busters':	{'buster','butters','dusters'},
'busting':	{'bunting','bursting','bussing','bustling','dusting','rusting'},
'bustle':	{'hustle'},
'bustling':	{'busting'},
'busty':	{'busby','bushy','bust','busy','dusty','lusty','rusty'},
'busy':	{'buoy','bury','bus','busby','bush','bushy','busi','bust','busty','buy'},
'but':	{'bat','bet','bit','blt','bot','bout','brut','bud','bug','bum','bun','bur','burt','bus','bust','butt','buy','cut','gut','hut','nut','out','put','rut','tut','ut'},
'butch':	{'batch','bitch','bunch','dutch','hutch'},
'butcher':	{'butchers'},
'butchers':	{'butcher'},
'butler':	{'butter','cutler'},
'butt':	{'burt','bust','but','butte','butts','mutt','putt'},
'butte':	{'butt','butter','butts'},
'butter':	{'batter','better','bitter','buster','butler','butte','butters','cutter','gutter','putter','utter'},
'buttered':	{'battered','muttered','uttered'},
'butters':	{'batters','busters','butter','cutters','gutters','putters'},
'button':	{'burton','buttons','hutton'},
'buttons':	{'button'},
'butts':	{'butt','butte'},
'buy':	{'bay','boy','bud','bug','bum','bun','buoy','bur','bury','bus','busy','but','buys','by','guy'},
'buyer':	{'bayer','buyers'},
'buyers':	{'buyer'},
'buying':	{'burying'},
'buys':	{'bays','boys','buds','bugs','buns','buoys','bus','buy','guys'},
'by':	{'b','ba','bay','bb','bc','be','bi','bk','bl','bm','boy','br','bs','buy','bye','dy','ky','ly','my','ny','wy','y'},
'bye':	{'aye','be','bee','by','byte','dye','eye','rye','wye','ye'},
'bylaw':	{'bylaws'},
'bylaws':	{'bylaw'},
'byrd':	{'bard','bird'},
'byron':	{'baron','boron'},
'byte':	{'bite','bye','bytes'},
'bytes':	{'bites','byte'},
'c':	{'a','ac','b','bc','ca','cc','cd','ce','cf','ci','cl','cm','co','cr','cs','ct','cu','cv','cz','d','dc','e','ec','f','g','h','i','j','k','kc','l','mc','nc','o','p','pc','q','r','sc','t','tc','u','v','w','x','y','z'},
'ca':	{'a','ba','c','cab','cad','cam','can','cap','car','cat','cay','cc','cd','ce','cf','cha','ci','cia','cl','cm','co','cpa','cr','cs','ct','cu','cv','cz','da','ea','fa','ga','ha','ia','ka','la','ma','na','pa','ra','sa','ta','va','wa','ya','za'},
'cab':	{'ab','ca','cabs','cad','cam','can','cap','car','cat','cay','cob','crab','cub','dab','fab','gab','jab','lab','nab','tab'},
'cabin':	{'cabins','cain','sabin'},
'cabinet':	{'cabinets'},
'cabinets':	{'cabinet'},
'cabins':	{'cabin'},
'cable':	{'able','cables','fable','gable','sable','table'},
'cables':	{'cable','fables','gables','tables'},
'cabling':	{'calling'},
'cabs':	{'abs','cab','cams','cans','caps','cars','cats','crabs','labs','tabs'},
'cache':	{'ache','cached','caches'},
'cached':	{'ached','cache','caches','coached'},
'caches':	{'aches','cache','cached','catches','coaches'},
'caching':	{'aching','cashing','catching','coaching'},
'cad':	{'ad','bad','ca','cab','cam','can','cap','car','card','cat','cay','cd','chad','cid','clad','cod','dad','fad','had','lad','mad','pad','rad','sad','tad','wad'},
'caddy':	{'candy','daddy','paddy'},
'cadet':	{'cadets'},
'cadets':	{'cadet'},
'cadre':	{'care','padre'},
'cafe':	{'cafes','cage','cake','came','cane','cape','care','case','cave','safe'},
'cafes':	{'cafe','cages','cakes','canes','capes','cares','cases','caves','safes'},
'cage':	{'age','cafe','caged','cages','cake','came','cane','cape','care','case','cave','gage','page','rage','sage','wage'},
'caged':	{'aged','cage','cages','caped','cared','caved','waged'},
'cages':	{'ages','cafes','cage','caged','cakes','canes','capes','cares','cases','caves','pages','sages','wages'},
'caging':	{'aging','caring','casing','caving','paging','raging','waging'},
'cain':	{'cabin','cairn','can','chain','chin','coin','gain','jain','lain','main','pain','rain','vain'},
'cairn':	{'cain','cairo'},
'cairo':	{'cairn'},
'cake':	{'bake','cafe','cage','cakes','came','cane','cape','care','case','cave','coke','fake','lake','make','rake','sake','take','wake'},
'cakes':	{'bakes','cafes','cages','cake','canes','capes','cares','cases','caves','fakes','lakes','makes','rakes','sakes','takes','wakes'},
'calculate':	{'calculated','calculates'},
'calculated':	{'calculate','calculates'},
'calculates':	{'calculate','calculated'},
'calculation':	{'calculations'},
'calculations':	{'calculation'},
'calculator':	{'calculators'},
'calculators':	{'calculator'},
'calder':	{'alder','caldera','caller','colder'},
'caldera':	{'calder'},
'calendar':	{'calendars','calender'},
'calendars':	{'calendar'},
'calender':	{'calendar'},
'calf':	{'cali','calif','call','calm','half'},
'calgary':	{'calvary'},
'cali':	{'ali','bali','calf','calif','call','calm','dali','kali','mali'},
'caliber':	{'caliper'},
'calibrate':	{'calibrated'},
'calibrated':	{'calibrate'},
'calibration':	{'calibrations'},
'calibrations':	{'calibration'},
'calif':	{'calf','cali'},
'california':	{'californian'},
'californian':	{'california'},
'caliper':	{'caliber'},
'call':	{'all','ball','calf','cali','calla','calls','cally','calm','cell','fall','gall','hall','mall','pall','tall','wall'},
'calla':	{'alla','call','calls','cally'},
'callback':	{'callbacks','fallback'},
'callbacks':	{'callback'},
'called':	{'caller','calmed','culled','walled'},
'caller':	{'calder','called','callers','taller','waller'},
'callers':	{'caller'},
'calling':	{'cabling','calming','falling'},
'calls':	{'balls','call','calla','cally','calms','cells','falls','halls','malls','walls'},
'cally':	{'ally','bally','call','calla','calls','calmly','rally','sally','tally','wally'},
'calm':	{'balm','calf','cali','call','calms','cam','palm'},
'calmed':	{'called'},
'calming':	{'calling'},
'calmly':	{'cally'},
'calms':	{'calls','calm','cams','palms'},
'caloric':	{'calorie'},
'calorie':	{'caloric','calories'},
'calories':	{'calorie'},
'calvary':	{'calgary'},
'calves':	{'caves','halves','valves'},
'cam':	{'am','ca','cab','cad','calm','came','camp','cams','can','cap','car','cat','cay','clam','cm','com','cram','cum','dam','ham','jam','lam','ram','sam','scam','tam','yam'},
'cambodia':	{'cambodian'},
'cambodian':	{'cambodia'},
'camcorder':	{'camcorders'},
'camcorders':	{'camcorder'},
'came':	{'cafe','cage','cake','cam','camel','cameo','camp','cams','cane','cape','care','case','cave','come','dame','fame','game','lame','name','same','tame'},
'camel':	{'came','camels','cameo'},
'camels':	{'camel'},
'cameo':	{'came','camel'},
'camera':	{'cameras'},
'cameras':	{'camera'},
'camp':	{'amp','cam','came','camps','cams','cap','carp','champ','clamp','comp','damp','lamp','ramp','scamp'},
'campaign':	{'campaigns'},
'campaigns':	{'campaign'},
'camped':	{'camper','caped','capped','clamped','cramped'},
'camper':	{'camped','campers','casper','damper','hamper','pamper','tamper'},
'campers':	{'camper','capers','hampers'},
'campground':	{'campgrounds'},
'campgrounds':	{'campground'},
'camping':	{'capping','clamping','damping'},
'camps':	{'amps','camp','campus','cams','camus','caps','champs','clamps','comps','cramps','lamps','ramps'},
'campsite':	{'campsites'},
'campsites':	{'campsite'},
'campus':	{'camps','camus'},
'cams':	{'cabs','calms','cam','came','camp','camps','camus','cans','caps','cars','cats','clams','dams','jams','scams'},
'camus':	{'camps','campus','cams'},
'can':	{'an','ban','ca','cab','cad','cain','cam','cane','cans','cant','cap','car','cat','cay','clan','con','cyan','fan','han','jan','lan','man','nan','pan','ran','scan','tan','van','wan'},
'canal':	{'anal','canals','carnal'},
'canals':	{'canal'},
'cancel':	{'cancels','cancer'},
'canceled':	{'cancelled'},
'canceling':	{'cancelling'},
'cancellation':	{'cancellations'},
'cancellations':	{'cancellation'},
'cancelled':	{'canceled'},
'cancelling':	{'canceling'},
'cancels':	{'cancel','cancers'},
'cancer':	{'cancel','cancers','dancer','lancer'},
'cancers':	{'cancels','cancer','dancers'},
'candid':	{'candida'},
'candida':	{'candid'},
'candidate':	{'candidates'},
'candidates':	{'candidate'},
'candies':	{'candles'},
'candle':	{'candles','handle'},
'candles':	{'candies','candle','handles'},
'candy':	{'caddy','dandy','handy','randy','sandy','tandy'},
'cane':	{'bane','cafe','cage','cake','came','can','canes','canoe','cans','cant','cape','care','case','cave','cine','cone','crane','dane','lane','mane','pane','sane'},
'canes':	{'cafes','cages','cakes','cane','cannes','canoes','cans','capes','cares','cases','caves','cones','cranes','lanes','panes'},
'canned':	{'banned','cannes','fanned','manned','scanned','tanned'},
'cannes':	{'canes','canned','canoes'},
'cannibal':	{'hannibal'},
'canning':	{'banning','cunning','fanning','scanning','tanning'},
'cannon':	{'cannons','cannot','canon','canton','canyon'},
'cannons':	{'cannon','canyons'},
'cannot':	{'cannon'},
'canoe':	{'cane','canoes','canon'},
'canoes':	{'canes','cannes','canoe'},
'canon':	{'anon','cannon','canoe','canton','canyon'},
'cans':	{'ans','bans','cabs','cams','can','cane','canes','cant','caps','cars','cats','clans','cns','cons','dans','fans','mans','pans','sans','scans','vans'},
'cant':	{'ant','can','cane','cans','canto','capt','cart','cast','cat','cent','chant','cont','cunt','kant','pant','rant','scant','want'},
'canto':	{'cant','canton','cantor'},
'canton':	{'cannon','canon','canto','cantor','canyon','carton','wanton'},
'cantor':	{'canto','canton','castor'},
'canyon':	{'cannon','canon','canton','canyons'},
'canyons':	{'cannons','canyon'},
'cap':	{'ca','cab','cad','cam','camp','can','cape','capo','caps','capt','car','carp','cat','cay','chap','clap','cop','crap','cup','gap','hap','lap','map','nap','pap','rap','sap','tap','yap','zap'},
'capacitor':	{'capacitors'},
'capacitors':	{'capacitor'},
'cape':	{'ape','cafe','cage','cake','came','cane','cap','caped','capes','capo','caps','capt','care','case','cave','cope','rape','tape'},
'caped':	{'caged','camped','cape','capes','capped','cared','caved','raped','taped'},
'capers':	{'campers','capes','carers','caters','papers'},
'capes':	{'apes','cafes','cages','cakes','canes','cape','caped','capers','caps','cares','cases','caves','rapes','tapes'},
'capital':	{'capitals','capitol'},
'capitalism':	{'capitalist'},
'capitalist':	{'capitalism','capitalists'},
'capitalists':	{'capitalist'},
'capitalize':	{'capitalized'},
'capitalized':	{'capitalize'},
'capitals':	{'capital'},
'capitol':	{'capital'},
'capo':	{'apo','cap','cape','caps','capt'},
'capone':	{'capote'},
'capote':	{'capone'},
'capped':	{'camped','caped','mapped','tapped'},
'capping':	{'camping','cappings','clapping','mapping','tapping'},
'cappings':	{'capping','mappings'},
'caps':	{'cabs','camps','cams','cans','cap','cape','capes','capo','capt','cars','cats','chaps','cops','cps','craps','cups','gaps','laps','maps','taps'},
'capsule':	{'capsules'},
'capsules':	{'capsule'},
'capt':	{'apt','cant','cap','cape','capo','caps','cart','cast','cat'},
'captain':	{'captains'},
'captains':	{'captain'},
'caption':	{'captions','cation','caution'},
'captioned':	{'cautioned'},
'captions':	{'caption','cations','cautions'},
'captive':	{'captives'},
'captives':	{'captive'},
'capture':	{'captured','captures','rapture'},
'captured':	{'capture','captures'},
'captures':	{'capture','captured'},
'car':	{'ar','bar','ca','cab','cad','cam','can','cap','card','care','carp','cars','cart','cat','cay','char','cpr','cr','cur','dar','ear','far','gar','jar','mar','oar','par','scar','tar','var','war'},
'carat':	{'carats','cart','karat'},
'carats':	{'carat','carts'},
'caravan':	{'caravans'},
'caravans':	{'caravan'},
'carbohydrate':	{'carbohydrates'},
'carbohydrates':	{'carbohydrate'},
'carbon':	{'carson','carton'},
'carcinogen':	{'carcinogens'},
'carcinogens':	{'carcinogen'},
'carcinoma':	{'carcinomas'},
'carcinomas':	{'carcinoma'},
'card':	{'bard','cad','car','cards','care','cared','carp','cars','cart','chard','cord','hard','ward','yard'},
'cardigan':	{'cardigans'},
'cardigans':	{'cardigan'},
'cards':	{'card','cares','cars','carts','cords','wards','yards'},
'care':	{'are','bare','cadre','cafe','cage','cake','came','cane','cape','car','card','cared','carer','cares','carp','cars','cart','carve','case','cave','core','cure','dare','fare','hare','mare','rare','scare','ware'},
'cared':	{'bared','caged','caped','card','care','carer','cares','carted','carved','caved','cored','cred','cured','dared','eared','fared','pared','scared'},
'career':	{'careers','carer','carter','carver'},
'careers':	{'career','carers'},
'caregiver':	{'caregivers'},
'caregivers':	{'caregiver'},
'carer':	{'care','cared','career','carers','cares','carter','carver','cater','rarer'},
'carers':	{'capers','careers','carer','cares','caress','caters'},
'cares':	{'ares','bares','cafes','cages','cakes','canes','capes','cards','care','cared','carer','carers','caress','caries','cars','carts','cases','caves','ceres','cores','cures','dares','fares','mares','scares','wares'},
'caress':	{'carers','cares'},
'cargo':	{'argo','fargo','largo'},
'caries':	{'aries','cares','carries','cries','varies'},
'carina':	{'caring','marina'},
'caring':	{'baring','caging','carina','carting','carving','casing','caving','coring','curing','daring','scaring'},
'carnal':	{'canal','carpal'},
'carol':	{'carols'},
'carolina':	{'caroline'},
'caroline':	{'carolina'},
'carols':	{'carol'},
'carp':	{'camp','cap','car','card','care','cars','cart','corp','harp','warp'},
'carpal':	{'carnal'},
'carpenter':	{'carpenters'},
'carpenters':	{'carpenter'},
'carpet':	{'carpets'},
'carpets':	{'carpet'},
'carriage':	{'carriages','marriage'},
'carriages':	{'carriage','marriages'},
'carried':	{'carrier','carries','married'},
'carrier':	{'barrier','carried','carriers','carries','cartier','harrier'},
'carriers':	{'barriers','carrier','carries'},
'carries':	{'caries','carried','carrier','carriers','marries'},
'carrot':	{'carrots','parrot'},
'carrots':	{'carrot','parrots'},
'carry':	{'curry','harry','marry','parry'},
'carrying':	{'marrying'},
'cars':	{'bars','cabs','cams','cans','caps','car','card','cards','care','cares','carp','cart','carts','cats','chars','ears','jars','mars','oars','scars','wars'},
'carson':	{'arson','carbon','carton','parson'},
'cart':	{'art','bart','cant','capt','car','carat','card','care','carp','cars','carts','cast','cat','cert','chart','crt','curt','dart','fart','hart','kart','mart','part','tart'},
'carted':	{'cared','cartel','carter','carved','charted','parted'},
'cartel':	{'carted','carter'},
'carter':	{'barter','career','carer','carted','cartel','cartier','carver','caster','cater','charter','garter'},
'cartier':	{'carrier','carter'},
'carting':	{'caring','carving','casting','charting','parting'},
'carton':	{'canton','carbon','carson','cartons','cartoon'},
'cartons':	{'carton','cartoons'},
'cartoon':	{'carton','cartoons'},
'cartoons':	{'cartons','cartoon'},
'cartridge':	{'cartridges','partridge'},
'cartridges':	{'cartridge'},
'carts':	{'arts','carats','cards','cares','cars','cart','casts','cats','charts','darts','karts','parts','tarts','warts'},
'carve':	{'care','carved','carver','cave','curve'},
'carved':	{'cared','carted','carve','carver','caved','curved'},
'carver':	{'career','carer','carter','carve','carved'},
'carving':	{'caring','carting','carvings','caving','curving'},
'carvings':	{'carving'},
'cascade':	{'cascades'},
'cascades':	{'cascade'},
'case':	{'base','cafe','cage','cake','came','cane','cape','care','cases','cash','cast','caste','cause','cave','cease','chase','ease','vase'},
'cases':	{'bases','cafes','cages','cakes','canes','capes','cares','case','casts','causes','caves','ceases','chases','eases','gases','vases'},
'cash':	{'ash','bash','case','cast','clash','crash','dash','hash','lash','mash','nash','rash','sash','wash'},
'cashier':	{'cashiers'},
'cashiers':	{'cashier'},
'cashing':	{'bashing','caching','casing','casting','crashing','dashing','hashing','washing'},
'casing':	{'basing','caging','caring','cashing','casino','casting','causing','caving','ceasing','chasing','easing'},
'casino':	{'casing','casinos'},
'casinos':	{'casino'},
'casket':	{'basket','gasket'},
'casper':	{'camper','caster','jasper'},
'casserole':	{'casseroles'},
'casseroles':	{'casserole'},
'cassette':	{'cassettes'},
'cassettes':	{'cassette'},
'cast':	{'cant','capt','cart','case','cash','caste','casts','cat','coast','cost','cst','cyst','east','fast','hast','last','mast','past','vast'},
'caste':	{'case','cast','caster','castle','casts','haste','paste','taste','waste'},
'caster':	{'aster','carter','casper','caste','casters','castor','cater','coaster','custer','easter','faster','master','raster'},
'casters':	{'caster','caters','coasters','masters'},
'casting':	{'carting','cashing','casing','castings','costing','fasting','lasting','pasting','tasting','wasting'},
'castings':	{'casting','hastings'},
'castle':	{'caste','castles','cattle'},
'castles':	{'castle'},
'castor':	{'astor','cantor','caster','pastor'},
'casts':	{'carts','cases','cast','caste','cats','coasts','costs','cysts','lasts'},
'casually':	{'casualty'},
'casualty':	{'casually'},
'cat':	{'at','bat','ca','cab','cad','cam','can','cant','cap','capt','car','cart','cast','cats','cay','chat','coat','cot','crt','cst','ct','cut','dat','eat','fat','hat','kat','lat','mat','oat','pat','rat','sat','scat','tat','vat','wat'},
'catalog':	{'catalogs'},
'catalogs':	{'catalog'},
'catalogue':	{'catalogues'},
'catalogues':	{'catalogue'},
'catalyst':	{'catalysts'},
'catalysts':	{'catalyst'},
'catch':	{'batch','catchy','hatch','latch','match','patch','watch'},
'catcher':	{'catches','watcher'},
'catches':	{'batches','caches','catcher','latches','matches','patches','watches'},
'catching':	{'caching','hatching','matching','patching','watching'},
'catchy':	{'catch','patchy'},
'categories':	{'categorises','categorizes'},
'categorisation':	{'categorization'},
'categorise':	{'categorised','categorises','categorize'},
'categorised':	{'categorise','categorises','categorized'},
'categorises':	{'categories','categorise','categorised','categorizes'},
'categorising':	{'categorizing'},
'categorization':	{'categorisation'},
'categorize':	{'categorise','categorized','categorizes'},
'categorized':	{'categorised','categorize','categorizes'},
'categorizes':	{'categories','categorises','categorize','categorized'},
'categorizing':	{'categorising'},
'cater':	{'carer','carter','caster','caters','crater','eater','later','mater','water'},
'catered':	{'caterer','watered'},
'caterer':	{'catered','caterers'},
'caterers':	{'caterer'},
'catering':	{'watering'},
'caters':	{'capers','carers','casters','cater','craters','eaters','haters','waters'},
'cation':	{'caption','cations','caution','nation','ration'},
'cations':	{'captions','cation','cautions','nations','rations'},
'cats':	{'bats','cabs','cams','cans','caps','cars','carts','casts','cat','chats','coats','cots','cuts','eats','fats','hats','lats','mats','oats','rats'},
'cattle':	{'battle','castle','rattle'},
'caught':	{'taught'},
'cause':	{'case','caused','causes','clause','pause'},
'caused':	{'cause','causes','paused'},
'causes':	{'cases','cause','caused','clauses','pauses'},
'causing':	{'casing','pausing'},
'caution':	{'caption','cation','cautions'},
'cautioned':	{'captioned'},
'cautions':	{'captions','cations','caution','cautious'},
'cautious':	{'cautions'},
'cave':	{'ave','cafe','cage','cake','came','cane','cape','care','carve','case','caved','caves','cove','crave','fave','gave','have','pave','rave','save','wave'},
'caveat':	{'caveats'},
'caveats':	{'caveat'},
'caved':	{'caged','caped','cared','carved','cave','caves','paved','saved','waved'},
'cavern':	{'caverns','tavern'},
'caverns':	{'cavern'},
'caves':	{'cafes','cages','cakes','calves','canes','capes','cares','cases','cave','caved','haves','raves','saves','waves'},
'caving':	{'caging','caring','carving','casing','craving','having','paving','raving','saving','waving'},
'cay':	{'bay','ca','cab','cad','cam','can','cap','car','cat','clay','coy','cry','day','fay','gay','hay','jay','lay','may','nay','pay','ray','say','way'},
'cayman':	{'layman'},
'cbc':	{'abc','bc','cc','cdc','cfc'},
'cc':	{'ac','bc','c','ca','cbc','cd','cdc','ce','cf','cfc','ci','cl','cm','co','cr','cs','ct','cu','cv','cz','dc','ec','fcc','icc','kc','mc','nc','pc','sc','tc'},
'cd':	{'ad','c','ca','cad','cc','cdc','ce','cf','ci','cid','cl','cm','co','cod','cr','cs','ct','cu','cv','cz','d','dd','ed','gd','id','lcd','md','nd','od','pd','sd','vd'},
'cdc':	{'cbc','cc','cd','cfc','dc'},
'ce':	{'ace','be','c','ca','cc','cd','ceo','cf','ci','cl','cm','co','cr','cs','ct','cu','cue','cv','cz','de','e','ee','fe','ge','he','ice','ie','le','me','ne','pe','se','te','ve','we','xe','ye'},
'cease':	{'case','ceased','ceases','chase','crease','ease','lease','tease'},
'ceased':	{'cease','ceases','chased','creased','eased','leased','teased'},
'ceases':	{'cases','cease','ceased','chases','creases','eases','leases'},
'ceasing':	{'casing','chasing','easing','leasing','teasing'},
'ceiling':	{'ceilings','veiling'},
'ceilings':	{'ceiling'},
'celeb':	{'celebs'},
'celebrate':	{'celebrated','celebrates'},
'celebrated':	{'celebrate','celebrates'},
'celebrates':	{'celebrate','celebrated'},
'celebration':	{'celebrations'},
'celebrations':	{'celebration'},
'celebs':	{'celeb'},
'cell':	{'bell','call','cello','cells','dell','ell','fell','hell','sell','tell','well','yell'},
'cellar':	{'cellars','collar'},
'cellars':	{'cellar','collars'},
'cello':	{'cell','cells','hello','jello'},
'cellphone':	{'cellphones'},
'cellphones':	{'cellphone'},
'cells':	{'bells','calls','cell','cello','hells','sells','tells','wells','yells'},
'cement':	{'clement'},
'cemented':	{'demented'},
'censor':	{'sensor','tensor'},
'censure':	{'ensure'},
'cent':	{'bent','cant','cents','cert','cont','cunt','dent','gent','kent','lent','rent','scent','sent','tent','vent','went'},
'center':	{'centers','enter','renter'},
'centered':	{'centred','entered'},
'centering':	{'entering'},
'centerist':	{'centerists','centrist'},
'centerists':	{'centerist','centrists'},
'centers':	{'center','enters','renters'},
'centimeter':	{'centimeters'},
'centimeters':	{'centimeter'},
'centimetre':	{'centimetres'},
'centimetres':	{'centimetre'},
'central':	{'ventral'},
'centralised':	{'centralized'},
'centralized':	{'centralised'},
'centre':	{'centred','centres'},
'centred':	{'centered','centre','centres'},
'centres':	{'centre','centred'},
'centrist':	{'centerist','centrists'},
'centrists':	{'centerists','centrist'},
'cents':	{'cent','dents','gents','rents','scents','tents','vents'},
'ceo':	{'ce','cfo','co','coo','leo'},
'ceramic':	{'ceramics'},
'ceramics':	{'ceramic'},
'cereal':	{'cereals'},
'cereals':	{'cereal'},
'ceres':	{'cares','cores','cures'},
'cert':	{'cart','cent','crt','curt'},
'certain':	{'curtain','pertain'},
'certainly':	{'certainty'},
'certainty':	{'certainly'},
'certificate':	{'certificated','certificates'},
'certificated':	{'certificate','certificates'},
'certificates':	{'certificate','certificated'},
'certification':	{'certifications'},
'certifications':	{'certification'},
'certified':	{'certifies'},
'certifies':	{'certified'},
'cf':	{'af','c','ca','cc','cd','ce','cfc','cfo','ci','cl','cm','co','cr','cs','ct','cu','cv','cz','f','ff','gf','hf','if','of','rf'},
'cfc':	{'cbc','cc','cdc','cf','cfo','pfc'},
'cfo':	{'ceo','cf','cfc','co','coo','fo','ufo'},
'cha':	{'ca','chad','chap','char','chat','chg','chi','cia','cpa','fha','ha'},
'chad':	{'cad','cha','chap','char','chard','chat','clad','had','shad'},
'chain':	{'cain','chains','chair','chin'},
'chained':	{'chaired'},
'chains':	{'chain','chairs'},
'chair':	{'chain','chairs','char','choir','hair'},
'chaired':	{'chained','haired'},
'chairman':	{'chairmen'},
'chairmen':	{'chairman'},
'chairs':	{'chains','chair','chars','choirs','hairs'},
'chalet':	{'chalets'},
'chalets':	{'chalet'},
'chalk':	{'chalks'},
'chalks':	{'chalk'},
'challenge':	{'challenged','challenger','challenges'},
'challenged':	{'challenge','challenger','challenges'},
'challenger':	{'challenge','challenged','challengers','challenges'},
'challengers':	{'challenger','challenges'},
'challenges':	{'challenge','challenged','challenger','challengers'},
'chamber':	{'chambers'},
'chambers':	{'chamber'},
'champ':	{'camp','champs','chap','chimp','clamp'},
'champion':	{'champions'},
'champions':	{'champion'},
'championship':	{'championships'},
'championships':	{'championship'},
'champlain':	{'chaplain'},
'champs':	{'camps','champ','chaps','clamps','cramps'},
'chance':	{'chanced','chances','change'},
'chanced':	{'chance','chances','changed'},
'chances':	{'chance','chanced','changes'},
'chancing':	{'changing','chanting'},
'chandelier':	{'chandeliers'},
'chandeliers':	{'chandelier'},
'chandler':	{'handler'},
'chang':	{'change','chant','hang','shang','thang'},
'change':	{'chance','chang','changed','changer','changes','charge'},
'changeable':	{'chargeable'},
'changed':	{'chanced','change','changer','changes','charged','hanged'},
'changer':	{'change','changed','changers','changes','charger','hanger'},
'changers':	{'changer','changes','hangers'},
'changes':	{'chances','change','changed','changer','changers','charges'},
'changing':	{'chancing','chanting','charging','hanging'},
'channel':	{'channels'},
'channeled':	{'channelled'},
'channeling':	{'channelling'},
'channelled':	{'channeled'},
'channelling':	{'channeling'},
'channels':	{'channel'},
'chant':	{'cant','chang','chants','chart','chat'},
'chanting':	{'chancing','changing','charting','chatting'},
'chants':	{'chant','charts','chats'},
'chaos':	{'chaps','chars','chats'},
'chap':	{'cap','cha','chad','champ','chaps','char','chat','cheap','chip','chop','clap','crap','hap'},
'chaplain':	{'champlain','chaplin'},
'chaplin':	{'chaplain'},
'chaps':	{'caps','champs','chaos','chap','chars','chats','chips','chops','craps'},
'chapter':	{'chapters','charter','chatter'},
'chapters':	{'chapter','charters'},
'char':	{'car','cha','chad','chair','chap','chard','charm','chars','chart','chat'},
'character':	{'characters'},
'characterisation':	{'characterization'},
'characterise':	{'characterised','characterises','characterize'},
'characterised':	{'characterise','characterises','characterized'},
'characterises':	{'characterise','characterised','characterizes'},
'characteristic':	{'characteristics'},
'characteristics':	{'characteristic'},
'characterization':	{'characterisation'},
'characterize':	{'characterise','characterized','characterizes'},
'characterized':	{'characterised','characterize','characterizes'},
'characterizes':	{'characterises','characterize','characterized'},
'characters':	{'character'},
'chard':	{'card','chad','char','charm','chars','chart','chord','hard'},
'charge':	{'change','charged','charger','charges'},
'chargeable':	{'changeable'},
'charged':	{'changed','charge','charger','charges','charmed','charted'},
'charger':	{'changer','charge','charged','charges','charter'},
'charges':	{'changes','charge','charged','charger','charles'},
'charging':	{'changing','charming','charting'},
'charity':	{'clarity'},
'charles':	{'charges'},
'charm':	{'char','chard','charms','chars','chart','harm'},
'charmed':	{'charged','charted','harmed'},
'charming':	{'charging','charting','harming'},
'charms':	{'charm','chars','charts','harms'},
'chars':	{'cars','chairs','chaos','chaps','char','chard','charm','charms','chart','charts','chats'},
'chart':	{'cart','chant','char','chard','charm','chars','charts','chat','hart'},
'charted':	{'carted','charged','charmed','charter','chatted'},
'charter':	{'carter','chapter','charger','charted','charters','chatter'},
'charters':	{'chapters','charter'},
'charting':	{'carting','chanting','charging','charming','chatting'},
'charts':	{'carts','chants','charms','chars','chart','chats'},
'chase':	{'case','cease','chased','chaser','chases','chose','phase'},
'chased':	{'ceased','chase','chaser','chases','phased'},
'chaser':	{'chase','chased','chases'},
'chases':	{'cases','ceases','chase','chased','chaser','phases'},
'chasing':	{'casing','ceasing','phasing'},
'chat':	{'cat','cha','chad','chant','chap','char','chart','chats','cheat','chit','coat','hat','phat','that','what'},
'chats':	{'cats','chants','chaos','chaps','chars','charts','chat','cheats','coats','hats','whats'},
'chatted':	{'charted','chatter'},
'chatter':	{'chapter','charter','chatted','shatter'},
'chatting':	{'chanting','charting'},
'cheap':	{'chap','cheat','heap'},
'cheat':	{'chat','cheap','cheats','chest','heat','wheat'},
'cheated':	{'chested','created','heated'},
'cheating':	{'creating','heating'},
'cheats':	{'chats','cheat','chests','cleats','heats','wheats'},
'check':	{'checks','cheek','chick','chock','chuck','heck'},
'checked':	{'checker'},
'checker':	{'checked','checkers'},
'checkers':	{'checker'},
'checklist':	{'checklists'},
'checklists':	{'checklist'},
'checkpoint':	{'checkpoints'},
'checkpoints':	{'checkpoint'},
'checks':	{'check','cheeks','chicks'},
'cheek':	{'check','cheeks','cheeky','cheer','creek'},
'cheeks':	{'checks','cheek','cheeky','cheers','creeks'},
'cheeky':	{'cheek','cheeks','cheery','cheesy'},
'cheer':	{'cheek','cheers','cheery','sheer'},
'cheerleader':	{'cheerleaders'},
'cheerleaders':	{'cheerleader'},
'cheers':	{'cheeks','cheer','cheery'},
'cheery':	{'cheeky','cheer','cheers','cheesy','cherry'},
'cheese':	{'cheeses','cheesy'},
'cheeses':	{'cheese'},
'cheesy':	{'cheeky','cheery','cheese'},
'chef':	{'chefs','chem','chen','chew','chief'},
'chefs':	{'chef','chess','chews','chiefs'},
'chem':	{'ahem','chef','chemo','chen','chew','hem','them'},
'chemical':	{'chemicals'},
'chemicals':	{'chemical'},
'chemist':	{'chemists'},
'chemists':	{'chemist'},
'chemo':	{'chem'},
'chen':	{'chef','chem','chew','chin','hen','then','when'},
'cheque':	{'cheques'},
'cheques':	{'cheque'},
'cherry':	{'cheery','sherry'},
'chess':	{'chefs','chest','chests','chews','hess'},
'chest':	{'cheat','chess','chests','crest'},
'chested':	{'cheated','chester','crested'},
'chester':	{'chested'},
'chests':	{'cheats','chess','chest'},
'chew':	{'chef','chem','chen','chews','chow','crew','shew'},
'chews':	{'chefs','chess','chew','crews'},
'chg':	{'cha','chi','cog','hg'},
'chi':	{'cha','chg','chic','chin','chip','chit','ci','cpi','hi','phi','zhi'},
'chic':	{'chi','chick','chico','chin','chip','chit'},
'chicago':	{'chicano'},
'chicano':	{'chicago'},
'chick':	{'check','chic','chicks','chico','chock','chuck','click','thick'},
'chicken':	{'chickens'},
'chickens':	{'chicken'},
'chicks':	{'checks','chick','clicks'},
'chico':	{'chic','chick','chino'},
'chief':	{'chef','chiefs','thief'},
'chiefs':	{'chefs','chief'},
'child':	{'chile','chili','chill'},
'chile':	{'child','chili','chill','chime','while'},
'chili':	{'child','chile','chill'},
'chill':	{'child','chile','chili','chills','chilly','hill'},
'chilled':	{'chiller'},
'chiller':	{'chilled','schiller'},
'chilling':	{'schilling','shilling'},
'chills':	{'chill','chilly','hills'},
'chilly':	{'chill','chills','hilly'},
'chime':	{'chile','chimes','chimp','crime'},
'chimes':	{'chime','crimes'},
'chimney':	{'chimneys'},
'chimneys':	{'chimney'},
'chimp':	{'champ','chime','chip'},
'chin':	{'cain','chain','chen','chi','chic','china','chino','chip','chit','coin','shin','thin'},
'china':	{'chin','chino'},
'chino':	{'chico','chin','china','rhino'},
'chip':	{'chap','chi','chic','chimp','chin','chips','chit','chop','clip','hip','ship','whip'},
'chipped':	{'chopped','clipped','shipped','whipped'},
'chipping':	{'chopping','clipping','shipping','whipping'},
'chips':	{'chaps','chip','chops','clips','hips','ships','whips'},
'chiral':	{'choral'},
'chiropractor':	{'chiropractors'},
'chiropractors':	{'chiropractor'},
'chit':	{'chat','chi','chic','chin','chip','hit','shit','whit'},
'chloride':	{'chlorine'},
'chlorine':	{'chloride'},
'chock':	{'check','chick','chuck','clock','cock','crock','shock'},
'chocolate':	{'chocolates'},
'chocolates':	{'chocolate'},
'choice':	{'choices'},
'choices':	{'choice'},
'choir':	{'chair','choirs'},
'choirs':	{'chairs','choir'},
'choke':	{'choked','choker','chore','chose','coke','cooke'},
'choked':	{'choke','choker','cooked'},
'choker':	{'choke','choked','cooker'},
'choking':	{'cooking'},
'choose':	{'chooses','chose'},
'chooses':	{'choose'},
'chop':	{'chap','chip','chops','chou','chow','coop','cop','crop','hop','shop'},
'chopped':	{'chipped','chopper','cropped','hopped','shopped'},
'chopper':	{'chopped','choppers','copper','hopper','shopper'},
'choppers':	{'chopper','shoppers'},
'chopping':	{'chipping','cropping','hopping','shopping','whopping'},
'chops':	{'chaps','chips','chop','cops','crops','hops','shops'},
'choral':	{'chiral','chorale','coral'},
'chorale':	{'choral'},
'chord':	{'chard','chords','chore','cord'},
'chords':	{'chord','chores','chorus','cords'},
'chore':	{'choke','chord','chores','chose','core','shore','whore'},
'chores':	{'chords','chore','chorus','cores','shores','whores'},
'chorus':	{'chords','chores'},
'chose':	{'chase','choke','choose','chore','chosen','close','hose','those','whose'},
'chosen':	{'chose'},
'chou':	{'chop','chow','cou','thou','zhou'},
'chow':	{'chew','chop','chou','cow','crow','how','show'},
'chromatic':	{'chromatin'},
'chromatin':	{'chromatic'},
'chromosome':	{'chromosomes'},
'chromosomes':	{'chromosome'},
'chronicle':	{'chronicles'},
'chronicles':	{'chronicle'},
'chubby':	{'hubby'},
'chuck':	{'check','chick','chock','chunk','huck'},
'chuckle':	{'chuckled'},
'chuckled':	{'chuckle'},
'chunk':	{'chuck','chunks','chunky','hunk'},
'chunks':	{'chunk','chunky','hunks'},
'chunky':	{'chunk','chunks'},
'chute':	{'cute'},
'ci':	{'ai','bi','c','ca','cc','cd','ce','cf','chi','cia','cid','cl','cm','co','cpi','cr','cs','ct','cu','cv','cz','di','gi','hi','i','ii','ji','ki','li','mi','ni','pi','qi','ri','si','ti','vi','wi','xi','yi'},
'cia':	{'ca','cha','ci','ciao','cid','cpa','ia','pia','tia','via'},
'ciao':	{'cia'},
'cid':	{'acid','aid','bid','cad','cd','ci','cia','cod','did','hid','id','kid','lid','mid','rid'},
'cider':	{'coder','rider','wider'},
'cigar':	{'cigars'},
'cigarette':	{'cigarettes'},
'cigarettes':	{'cigarette'},
'cigars':	{'cigar'},
'cine':	{'cane','cite','cline','cone','dine','fine','line','mine','nine','pine','sine','vine','wine','zine'},
'cinema':	{'cinemas'},
'cinemas':	{'cinema'},
'cinematic':	{'kinematic'},
'circle':	{'circled','circles'},
'circled':	{'circle','circles'},
'circles':	{'circle','circled'},
'circuit':	{'circuits'},
'circuits':	{'circuit'},
'circular':	{'circulars'},
'circulars':	{'circular'},
'circulate':	{'circulated'},
'circulated':	{'circulate'},
'circumstance':	{'circumstances'},
'circumstances':	{'circumstance'},
'circus':	{'cirrus'},
'cirrus':	{'circus','citrus'},
'cisco':	{'disco'},
'citation':	{'citations'},
'citations':	{'citation'},
'cite':	{'bite','cine','cited','cites','city','cote','cute','kite','lite','mite','rite','site'},
'cited':	{'cite','cites','sited'},
'cites':	{'bites','cite','cited','cities','kites','mites','rites','sites'},
'cities':	{'cites','cuties','pities'},
'citing':	{'biting','siting'},
'citizen':	{'citizens'},
'citizens':	{'citizen'},
'citrate':	{'nitrate'},
'citrus':	{'cirrus'},
'city':	{'cite','pity'},
'civic':	{'civil'},
'civil':	{'civic'},
'civilian':	{'civilians'},
'civilians':	{'civilian'},
'civilisation':	{'civilisations','civilization'},
'civilisations':	{'civilisation','civilizations'},
'civilise':	{'civilised','civilises','civilize'},
'civilised':	{'civilise','civilises','civilized'},
'civilises':	{'civilise','civilised','civilizes'},
'civilising':	{'civilizing'},
'civilization':	{'civilisation','civilizations'},
'civilizations':	{'civilisations','civilization'},
'civilize':	{'civilise','civilized','civilizes'},
'civilized':	{'civilised','civilize','civilizes'},
'civilizes':	{'civilises','civilize','civilized'},
'civilizing':	{'civilising'},
'cl':	{'al','bl','c','ca','cc','cd','ce','cf','ci','cm','co','col','cr','cs','ct','cu','cv','cz','el','fl','il','l','ll','ml','tl','xl'},
'clad':	{'cad','chad','clam','clan','clap','claw','clay','glad','lad'},
'claim':	{'claims','clam'},
'claimant':	{'claimants'},
'claimants':	{'claimant'},
'claims':	{'claim','clams'},
'clam':	{'cam','clad','claim','clamp','clams','clan','clap','claw','clay','cram','glam','lam','slam'},
'clamp':	{'camp','champ','clam','clamps','clams','clap','clasp','lamp'},
'clamped':	{'camped','cramped'},
'clamping':	{'camping','clapping'},
'clamps':	{'camps','champs','clamp','clams','clasps','clumps','cramps','lamps'},
'clams':	{'cams','claims','clam','clamp','clamps','clans','class','claws','clays','slams'},
'clan':	{'can','clad','clam','clans','clap','claw','clay','clean','cyan','elan','klan','lan','plan'},
'clans':	{'cans','clams','clan','class','claws','clays','cleans','plans'},
'clap':	{'cap','chap','clad','clam','clamp','clan','clasp','claw','clay','clip','crap','flap','lap','slap'},
'clapping':	{'capping','clamping','clipping','slapping'},
'clarification':	{'clarifications'},
'clarifications':	{'clarification'},
'clarified':	{'clarifies'},
'clarifies':	{'clarified'},
'clarify':	{'clarity'},
'clarity':	{'charity','clarify'},
'clark':	{'clerk','lark'},
'clash':	{'cash','clasp','class','crash','flash','lash','slash'},
'clashes':	{'classes','crashes','flashes','lashes','slashes'},
'clasp':	{'clamp','clap','clash','clasps','class'},
'clasps':	{'clamps','clasp','class'},
'class':	{'clams','clans','clash','clasp','clasps','classy','claws','clays','glass','lass'},
'classed':	{'classes'},
'classes':	{'clashes','classed','clauses','glasses'},
'classic':	{'classics'},
'classics':	{'classic'},
'classification':	{'classifications'},
'classifications':	{'classification'},
'classified':	{'classifieds','classifier','classifies'},
'classifieds':	{'classified','classifies'},
'classifier':	{'classified','classifies'},
'classifies':	{'classified','classifieds','classifier'},
'classmate':	{'classmates'},
'classmates':	{'classmate'},
'classroom':	{'classrooms'},
'classrooms':	{'classroom'},
'classy':	{'class'},
'clause':	{'cause','clauses'},
'clauses':	{'causes','classes','clause'},
'claw':	{'clad','clam','clan','clap','claws','clay','flaw','law'},
'claws':	{'clams','clans','class','claw','clays','flaws','laws'},
'clay':	{'cay','clad','clam','clan','clap','claw','clays','lay','play','slay'},
'clays':	{'clams','clans','class','claws','clay','lays','plays'},
'clean':	{'clan','cleans','clear','lean'},
'cleaned':	{'cleaner','cleansed','cleared','gleaned','leaned'},
'cleaner':	{'cleaned','cleaners','cleanser','clearer','cleaver'},
'cleaners':	{'cleaner','cleansers'},
'cleanest':	{'clearest'},
'cleaning':	{'cleansing','clearing','leaning'},
'cleanly':	{'clearly'},
'cleanness':	{'clearness'},
'cleans':	{'clans','clean','cleanse','clears','cleats','leans'},
'cleanse':	{'cleans','cleansed','cleanser'},
'cleansed':	{'cleaned','cleanse','cleanser'},
'cleanser':	{'cleaner','cleanse','cleansed','cleansers'},
'cleansers':	{'cleaners','cleanser'},
'cleansing':	{'cleaning'},
'cleanup':	{'cleanups'},
'cleanups':	{'cleanup'},
'clear':	{'clean','clears','lear'},
'clearance':	{'clearances'},
'clearances':	{'clearance'},
'cleared':	{'cleaned','clearer'},
'clearer':	{'cleaner','cleared','cleaver'},
'clearest':	{'cleanest'},
'clearing':	{'cleaning','clearings'},
'clearings':	{'clearing'},
'clearly':	{'cleanly'},
'clearness':	{'cleanness'},
'clears':	{'cleans','clear','cleats'},
'cleats':	{'cheats','cleans','clears'},
'cleaver':	{'cleaner','clearer','clever'},
'cleft':	{'left'},
'clemens':	{'clement'},
'clement':	{'cement','clemens','element'},
'cleric':	{'clerics'},
'clerics':	{'cleric'},
'clerk':	{'clark','clerks'},
'clerks':	{'clerk'},
'clever':	{'cleaver','clover','lever'},
'click':	{'chick','clicks','clock','flick','lick','slick'},
'clicked':	{'clocked','licked'},
'clicking':	{'licking'},
'clicks':	{'chicks','click','clocks','flicks','licks'},
'client':	{'clients'},
'clients':	{'client'},
'cliff':	{'cliffs'},
'cliffs':	{'cliff'},
'climate':	{'climates'},
'climates':	{'climate'},
'climb':	{'climbs','limb'},
'climbed':	{'climber'},
'climber':	{'climbed','climbers'},
'climbers':	{'climber'},
'climbs':	{'climb','limbs'},
'cline':	{'cine','cling','clive','clone','kline','line'},
'cling':	{'cline','clung','fling','ling','sling'},
'clinic':	{'clinics'},
'clinician':	{'clinicians'},
'clinicians':	{'clinician'},
'clinics':	{'clinic'},
'clio':	{'clip'},
'clip':	{'chip','clap','clio','clips','flip','lip','slip'},
'clipped':	{'chipped','clipper','flipped','slipped'},
'clipper':	{'clipped','flipper','slipper'},
'clipping':	{'chipping','clapping','clippings','flipping','slipping'},
'clippings':	{'clipping'},
'clips':	{'chips','clip','flips','lips','slips'},
'clive':	{'alive','cline','clove','live','olive'},
'cloak':	{'clock'},
'clock':	{'block','chock','click','cloak','clocks','cock','crock','flock','lock'},
'clocked':	{'blocked','clicked','locked'},
'clocks':	{'blocks','clicks','clock','cocks','flocks','locks'},
'clog':	{'blog','clogs','clot','cog','log'},
'clogged':	{'logged'},
'clogging':	{'logging'},
'clogs':	{'blogs','clog','clots','logs'},
'clone':	{'alone','cline','cloned','clones','close','clove','cone','lone'},
'cloned':	{'clone','clones','closed'},
'clones':	{'clone','cloned','closes','cloves','cones'},
'cloning':	{'closing'},
'close':	{'chose','clone','closed','closer','closes','closet','clove','lose'},
'closed':	{'cloned','close','closer','closes','closet'},
'closeout':	{'closeouts'},
'closeouts':	{'closeout'},
'closer':	{'close','closed','closes','closet','clover','loser'},
'closes':	{'clones','close','closed','closer','closest','closet','closets','cloves','loses'},
'closest':	{'closes','closet'},
'closet':	{'close','closed','closer','closes','closest','closets'},
'closets':	{'closes','closet'},
'closeup':	{'closeups'},
'closeups':	{'closeup'},
'closing':	{'cloning','closings','losing'},
'closings':	{'closing'},
'closure':	{'closures'},
'closures':	{'closure'},
'clot':	{'blot','clog','cloth','clots','clout','cot','lot','plot','slot'},
'cloth':	{'clot','cloths','clots'},
'clothed':	{'clothes'},
'clothes':	{'clothed','cloths'},
'clothing':	{'clotting'},
'cloths':	{'cloth','clothes','clots'},
'clots':	{'clogs','clot','cloth','cloths','cots','lots','plots','slots'},
'clotting':	{'blotting','clothing','plotting'},
'cloud':	{'aloud','clouds','cloudy','clout','loud'},
'clouds':	{'cloud','cloudy'},
'cloudy':	{'cloud','clouds'},
'clout':	{'clot','cloud'},
'clove':	{'clive','clone','close','clover','cloves','cove','glove','love'},
'clover':	{'clever','closer','clove','cloves','cover','lover','plover'},
'cloves':	{'clones','closes','clove','clover','clovis','gloves','loves'},
'clovis':	{'cloves'},
'clown':	{'blown','clowns','crown','flown'},
'clowns':	{'clown','crowns'},
'club':	{'clubs','clue','cub'},
'clubs':	{'club','clues'},
'clue':	{'blue','club','clues','cue','flue','glue'},
'clues':	{'blues','clubs','clue','cues'},
'clumps':	{'clamps','lumps'},
'clung':	{'cling','flung','lung'},
'cluster':	{'clusters','clutter','custer','luster'},
'clustered':	{'cluttered'},
'clusters':	{'cluster'},
'clutter':	{'cluster','cutter','flutter'},
'cluttered':	{'clustered'},
'cm':	{'am','bm','c','ca','cam','cc','cd','ce','cf','ci','cl','co','com','cr','cs','ct','cu','cum','cv','cz','em','fm','gm','hm','km','lcm','mm','nm','pm','rm','sm','tm','um','wm'},
'cns':	{'ans','cans','cons','cos','cps','cs','ens','ins'},
'co':	{'c','ca','cc','cd','ce','ceo','cf','cfo','ci','cl','cm','cob','cod','cog','col','com','con','coo','cop','cos','cot','cou','cow','cox','coy','cr','cs','ct','cu','cv','cz','do','fo','go','ho','io','ko','lo','mo','no','o','po','so','to','wo'},
'co-operate':	{'co-operated','co-operates','cooperate'},
'co-operated':	{'co-operate','co-operates','cooperated'},
'co-operates':	{'co-operate','co-operated','cooperates'},
'co-operation':	{'cooperation'},
'co-operative':	{'cooperative'},
'co-operatively':	{'cooperatively'},
'co-ordinate':	{'co-ordinated','co-ordinates','coordinate'},
'co-ordinated':	{'co-ordinate','co-ordinates','coordinated'},
'co-ordinates':	{'co-ordinate','co-ordinated','coordinates'},
'co-ordinating':	{'coordinating'},
'co-ordination':	{'coordination'},
'co-ordinator':	{'co-ordinators','coordinator'},
'co-ordinators':	{'co-ordinator','coordinators'},
'coach':	{'couch','roach'},
'coached':	{'cached','coaches'},
'coaches':	{'caches','coached','couches'},
'coaching':	{'caching'},
'coal':	{'coals','coat','coax','coil','col','cool','coral','foal','goal'},
'coalition':	{'coalitions'},
'coalitions':	{'coalition'},
'coals':	{'coal','coats','coils','cols','cools','corals','goals'},
'coarse':	{'coarser','course'},
'coarser':	{'coarse'},
'coast':	{'boast','cast','coasts','coat','cost','roast','toast'},
'coaster':	{'caster','coasters','toaster'},
'coasters':	{'casters','coaster','toasters'},
'coasts':	{'boasts','casts','coast','coats','costs','roasts'},
'coat':	{'boat','cat','chat','coal','coast','coats','coax','colt','cont','cost','cot','goat','oat'},
'coating':	{'boating','coatings','costing'},
'coatings':	{'coating'},
'coats':	{'boats','cats','chats','coals','coasts','coat','costs','cots','goats','oats'},
'coax':	{'coal','coat','cox','hoax'},
'cob':	{'bob','cab','co','cod','cog','col','com','comb','con','coo','cop','cos','cot','cou','cow','cox','coy','cub','fob','hob','job','lob','mob','nob','ob','rob','sob'},
'cobol':	{'cool'},
'cobra':	{'cora'},
'coca':	{'cock','coco','cocoa','coda','cola','coma','cora'},
'cock':	{'bock','chock','clock','coca','cocks','coco','cook','cork','crock','dock','jock','lock','mock','rock','sock'},
'cocks':	{'clocks','cock','cocos','cooks','corks','docks','jocks','locks','rocks','socks'},
'cocktail':	{'cocktails'},
'cocktails':	{'cocktail'},
'coco':	{'coca','cock','cocoa','cocos','como','coo','loco'},
'cocoa':	{'coca','coco','cocos'},
'cocos':	{'cocks','coco','cocoa','coos'},
'cod':	{'bod','cad','cd','cid','co','cob','coda','code','cody','coed','cog','col','cold','com','con','coo','cop','cord','cos','cot','cou','cow','cox','coy','dod','god','mod','nod','od','pod','rod','sod','tod'},
'coda':	{'coca','cod','code','cody','cola','coma','cora','moda','soda'},
'code':	{'bode','cod','coda','coded','coder','codes','codex','cody','coke','cole','come','cone','cope','core','cote','cove','mode','node','ode','rode'},
'coded':	{'code','coder','codes','codex','coed','corded','cored'},
'coder':	{'cider','code','coded','coders','codes','codex','colder','comer','cover','oder'},
'coders':	{'coder','codes','covers'},
'codes':	{'code','coded','coder','coders','codex','comes','cones','cores','modes','nodes'},
'codex':	{'code','coded','coder','codes'},
'codified':	{'modified'},
'coding':	{'coming','coping','coring'},
'cody':	{'body','cod','coda','code','copy','cosy','coy','cozy'},
'coed':	{'cod','coded','cold','cord','cored','cred'},
'coefficient':	{'coefficients'},
'coefficients':	{'coefficient'},
'coerce':	{'coerced'},
'coerced':	{'coerce'},
'coffee':	{'coffees'},
'coffees':	{'coffee','coffers'},
'coffers':	{'coffees','confers','offers'},
'cog':	{'bog','chg','clog','co','cob','cod','col','com','con','coo','cop','cos','cot','cou','cow','cox','coy','dog','fog','hog','jog','log'},
'cohort':	{'cohorts'},
'cohorts':	{'cohort'},
'coil':	{'boil','coal','coils','coin','col','cool','foil','oil','soil','toil'},
'coiled':	{'boiled','coined','cooled','oiled','soiled'},
'coils':	{'boils','coals','coil','coins','cols','cools','foils','oils','soils'},
'coin':	{'cain','chin','coil','coins','con','conn','coon','corn','join','loin'},
'coincide':	{'coincided','coincides'},
'coincided':	{'coincide','coincides'},
'coincidence':	{'coincidences'},
'coincidences':	{'coincidence'},
'coincides':	{'coincide','coincided'},
'coined':	{'coiled','joined'},
'coins':	{'coils','coin','cons','joins'},
'coke':	{'cake','choke','code','cole','come','cone','cooke','cope','core','cote','cove','joke','poke','woke','yoke'},
'col':	{'cl','co','coal','cob','cod','cog','coil','cola','cold','cole','cols','colt','com','con','coo','cool','cop','cos','cot','cou','cow','cox','coy','fol','pol','sol','vol'},
'cola':	{'bola','coca','coda','col','cold','cole','cols','colt','coma','cora','ola'},
'cold':	{'bold','cod','coed','col','cola','colds','cole','cols','colt','cord','could','fold','gold','hold','mold','old','scold','sold','told'},
'colder':	{'bolder','calder','coder','folder','holder','older','solder'},
'coldest':	{'boldest','oldest'},
'coldly':	{'boldly'},
'coldness':	{'boldness'},
'colds':	{'cold','cols','cords','folds','holds','molds','scolds'},
'cole':	{'code','coke','col','cola','cold','cols','colt','come','cone','cope','core','cote','cove','dole','hole','mole','ole','pole','role','sole'},
'collaborate':	{'collaborated'},
'collaborated':	{'collaborate'},
'collaboration':	{'collaborations'},
'collaborations':	{'collaboration'},
'collaborator':	{'collaborators'},
'collaborators':	{'collaborator'},
'collage':	{'collagen','college'},
'collagen':	{'collage'},
'collapse':	{'collapsed','collapses'},
'collapsed':	{'collapse','collapses'},
'collapses':	{'collapse','collapsed'},
'collar':	{'cellar','collars','dollar'},
'collars':	{'cellars','collar','dollars'},
'colleague':	{'colleagues'},
'colleagues':	{'colleague'},
'collect':	{'collects'},
'collectible':	{'collectibles'},
'collectibles':	{'collectible'},
'collection':	{'collections'},
'collections':	{'collection'},
'collector':	{'collectors'},
'collectors':	{'collector'},
'collects':	{'collect'},
'college':	{'collage','colleges'},
'colleges':	{'college'},
'collide':	{'collie'},
'collie':	{'collide','collier','mollie'},
'collier':	{'collie'},
'collision':	{'collisions','collusion'},
'collisions':	{'collision'},
'collusion':	{'collision'},
'cologne':	{'colognes'},
'colognes':	{'cologne'},
'colombia':	{'colombian','columbia'},
'colombian':	{'colombia'},
'colon':	{'colony','color','coon','solon'},
'colonial':	{'colonials'},
'colonials':	{'colonial'},
'colonist':	{'colonists'},
'colonists':	{'colonist'},
'colonize':	{'colonized'},
'colonized':	{'colonize'},
'colony':	{'colon'},
'color':	{'colon','colors','colour','dolor'},
'colored':	{'coloured'},
'colorful':	{'colourful'},
'coloring':	{'colouring'},
'colorless':	{'colourless'},
'colors':	{'color','colours'},
'colour':	{'color','colours'},
'coloured':	{'colored'},
'colourful':	{'colorful'},
'colouring':	{'coloring'},
'colourless':	{'colorless'},
'colours':	{'colors','colour'},
'cols':	{'coals','coils','col','cola','cold','colds','cole','colt','cons','cools','coos','cops','cos','cots','cows'},
'colt':	{'bolt','coat','col','cola','cold','cole','cols','cont','cost','cot','cult','jolt','volt'},
'columbia':	{'colombia'},
'column':	{'columns'},
'columnist':	{'columnists'},
'columnists':	{'columnist'},
'columns':	{'column'},
'com':	{'cam','cm','co','cob','cod','cog','col','coma','comb','come','como','comp','con','coo','cop','cos','cot','cou','cow','cox','coy','cum','mom','pom','rom','tom'},
'coma':	{'coca','coda','cola','com','comb','come','comma','como','comp','cora','roma'},
'comb':	{'bomb','cob','com','coma','combo','combs','come','como','comp','omb','tomb','womb'},
'combatant':	{'combatants'},
'combatants':	{'combatant'},
'combed':	{'bombed'},
'combination':	{'combinations'},
'combinations':	{'combination'},
'combine':	{'combined','combines','combing'},
'combined':	{'combine','combines'},
'combines':	{'combine','combined'},
'combing':	{'bombing','combine','coming'},
'combo':	{'comb','combos','combs','como'},
'combos':	{'combo','combs'},
'combs':	{'bombs','comb','combo','combos','comes','comps','tombs'},
'come':	{'came','code','coke','cole','com','coma','comb','comer','comes','comet','como','comp','comte','cone','cope','core','cote','cove','dome','home','nome','rome','some','tome'},
'comedian':	{'comedians'},
'comedians':	{'comedian'},
'comer':	{'coder','come','comes','comet','cover','homer'},
'comes':	{'codes','combs','come','comer','comet','comps','cones','cores','domes','homes'},
'comet':	{'come','comer','comes'},
'comfort':	{'comforts'},
'comfortable':	{'comfortably'},
'comfortably':	{'comfortable'},
'comforted':	{'comforter'},
'comforter':	{'comforted','comforters'},
'comforters':	{'comforter'},
'comforts':	{'comfort'},
'comic':	{'comics','cosmic'},
'comical':	{'conical'},
'comics':	{'comic'},
'coming':	{'coding','combing','coping','coring'},
'comma':	{'coma','commas','momma'},
'command':	{'commando','commands','commend'},
'commanded':	{'commander','commended'},
'commander':	{'commanded','commanders'},
'commanders':	{'commander'},
'commandment':	{'commandments'},
'commandments':	{'commandment'},
'commando':	{'command','commandos','commands'},
'commandos':	{'commando','commands'},
'commands':	{'command','commando','commandos'},
'commas':	{'comma'},
'commence':	{'commenced','commences','commerce'},
'commenced':	{'commence','commences','commended','commented'},
'commences':	{'commence','commenced'},
'commencing':	{'commenting'},
'commend':	{'command','comment'},
'commended':	{'commanded','commenced','commented'},
'comment':	{'commend','comments'},
'commentator':	{'commentators'},
'commentators':	{'commentator'},
'commented':	{'commenced','commended'},
'commenting':	{'commencing'},
'comments':	{'comment'},
'commerce':	{'commence'},
'commercial':	{'commercials'},
'commercialisation':	{'commercialization'},
'commercialization':	{'commercialisation'},
'commercials':	{'commercial'},
'commission':	{'commissions'},
'commissioned':	{'commissioner'},
'commissioner':	{'commissioned','commissioners'},
'commissioners':	{'commissioner'},
'commissions':	{'commission'},
'commit':	{'commits'},
'commitment':	{'commitments'},
'commitments':	{'commitment'},
'commits':	{'commit'},
'committed':	{'committee'},
'committee':	{'committed','committees'},
'committees':	{'committee'},
'common':	{'commons'},
'commons':	{'common'},
'commune':	{'commute'},
'communicate':	{'communicated','communicates'},
'communicated':	{'communicate','communicates'},
'communicates':	{'communicate','communicated'},
'communication':	{'communications'},
'communications':	{'communication'},
'communicator':	{'communicators'},
'communicators':	{'communicator'},
'communism':	{'communist'},
'communist':	{'communism'},
'commute':	{'commune','commuter','compute'},
'commuter':	{'commute','commuters','computer'},
'commuters':	{'commuter','computers'},
'commuting':	{'computing'},
'como':	{'coco','com','coma','comb','combo','come','comp','coo','homo'},
'comp':	{'camp','com','coma','comb','come','como','comps','coop','cop','corp','coup','romp'},
'companion':	{'companions'},
'companions':	{'companion'},
'compare':	{'compared','compares'},
'compared':	{'compare','compares'},
'compares':	{'compare','compared'},
'comparison':	{'comparisons'},
'comparisons':	{'comparison'},
'compartment':	{'compartments'},
'compartments':	{'compartment'},
'compensate':	{'compensated','compensates'},
'compensated':	{'compensate','compensates'},
'compensates':	{'compensate','compensated'},
'compensation':	{'compensations'},
'compensations':	{'compensation'},
'compete':	{'competed','competes','complete','compute'},
'competed':	{'compete','competes','completed','computed'},
'competence':	{'competences','competency'},
'competences':	{'competence','competencies'},
'competencies':	{'competences'},
'competency':	{'competence'},
'competes':	{'compete','competed','completes','computes'},
'competing':	{'completing','computing'},
'competition':	{'competitions'},
'competitions':	{'competition'},
'competitor':	{'competitors'},
'competitors':	{'competitor'},
'compilation':	{'compilations'},
'compilations':	{'compilation'},
'compile':	{'compiled','compiler','compiles'},
'compiled':	{'compile','compiler','compiles'},
'compiler':	{'compile','compiled','compilers','compiles'},
'compilers':	{'compiler','compiles'},
'compiles':	{'compile','compiled','compiler','compilers'},
'complain':	{'complains','complaint'},
'complainant':	{'complainants'},
'complainants':	{'complainant'},
'complains':	{'complain','complaint','complaints'},
'complaint':	{'complain','complains','complaints'},
'complaints':	{'complains','complaint'},
'complement':	{'complements','compliment'},
'complementary':	{'complimentary'},
'complemented':	{'complimented'},
'complements':	{'complement','compliments'},
'complete':	{'compete','completed','completes'},
'completed':	{'competed','complete','completes'},
'completes':	{'competes','complete','completed','complexes'},
'completing':	{'competing'},
'completion':	{'completions','complexion'},
'completions':	{'completion'},
'complexes':	{'completes'},
'complexion':	{'completion'},
'complicate':	{'complicated','complicates'},
'complicated':	{'complicate','complicates'},
'complicates':	{'complicate','complicated'},
'complication':	{'complications'},
'complications':	{'complication'},
'complied':	{'complies'},
'complies':	{'complied'},
'compliment':	{'complement','compliments'},
'complimentary':	{'complementary'},
'complimented':	{'complemented'},
'compliments':	{'complements','compliment'},
'component':	{'components'},
'components':	{'component'},
'compose':	{'composed','composer','composes','compost'},
'composed':	{'compose','composer','composes'},
'composer':	{'compose','composed','composers','composes'},
'composers':	{'composer','composes'},
'composes':	{'compose','composed','composer','composers'},
'composing':	{'composting'},
'composite':	{'composites'},
'composites':	{'composite'},
'composition':	{'compositions'},
'compositions':	{'composition'},
'compost':	{'compose'},
'composting':	{'composing'},
'compound':	{'compounds'},
'compounds':	{'compound'},
'compressor':	{'compressors'},
'compressors':	{'compressor'},
'comprise':	{'comprised','comprises'},
'comprised':	{'comprise','comprises'},
'comprises':	{'comprise','comprised'},
'compromise':	{'compromised','compromises'},
'compromised':	{'compromise','compromises'},
'compromises':	{'compromise','compromised'},
'comps':	{'camps','combs','comes','comp','cops','corps'},
'computation':	{'computations'},
'computations':	{'computation'},
'compute':	{'commute','compete','computed','computer','computes'},
'computed':	{'competed','compute','computer','computes'},
'computer':	{'commuter','compute','computed','computers','computes'},
'computerised':	{'computerized'},
'computerized':	{'computerised'},
'computers':	{'commuters','computer','computes'},
'computes':	{'competes','compute','computed','computer','computers'},
'computing':	{'commuting','competing'},
'comrade':	{'comrades'},
'comrades':	{'comrade'},
'comte':	{'come','cote'},
'con':	{'can','co','cob','cod','cog','coin','col','com','cone','conn','cons','cont','coo','coon','cop','corn','cos','cot','cou','cow','cox','coy','don','hon','icon','ion','mon','non','on','ron','son','ton','von','won','yon'},
'concede':	{'conceded','concedes'},
'conceded':	{'concede','concedes'},
'concedes':	{'concede','conceded'},
'conceivable':	{'conceivably'},
'conceivably':	{'conceivable'},
'conceive':	{'conceived','conceives'},
'conceived':	{'conceive','conceives'},
'conceives':	{'conceive','conceived'},
'concentrate':	{'concentrated','concentrates'},
'concentrated':	{'concentrate','concentrates'},
'concentrates':	{'concentrate','concentrated'},
'concentration':	{'concentrations'},
'concentrations':	{'concentration'},
'concept':	{'concepts','concert'},
'conception':	{'conceptions'},
'conceptions':	{'conception'},
'concepts':	{'concept','concerts'},
'conceptualise':	{'conceptualised','conceptualises'},
'conceptualised':	{'conceptualise','conceptualises'},
'conceptualises':	{'conceptualise','conceptualised'},
'concern':	{'concerns','concert'},
'concerned':	{'concerted'},
'concerns':	{'concern','concerts'},
'concert':	{'concept','concern','concerto','concerts','convert'},
'concerted':	{'concerned','converted'},
'concerto':	{'concert','concertos','concerts'},
'concertos':	{'concerto','concerts'},
'concerts':	{'concepts','concerns','concert','concerto','concertos','converts'},
'concession':	{'concessions','confession'},
'concessions':	{'concession','confessions'},
'conclude':	{'concluded','concludes'},
'concluded':	{'conclude','concludes'},
'concludes':	{'conclude','concluded'},
'conclusion':	{'conclusions'},
'conclusions':	{'conclusion'},
'concurrence':	{'concurrency'},
'concurrency':	{'concurrence'},
'condemn':	{'condemns'},
'condemns':	{'condemn'},
'condensed':	{'condenser'},
'condenser':	{'condensed'},
'condition':	{'conditions'},
'conditioned':	{'conditioner'},
'conditioner':	{'conditioned','conditioners'},
'conditioners':	{'conditioner'},
'conditions':	{'condition'},
'condo':	{'condom','condor','condos','congo'},
'condom':	{'condo','condoms','condor','condos'},
'condominium':	{'condominiums'},
'condominiums':	{'condominium'},
'condoms':	{'condom','condos'},
'condor':	{'condo','condom','condos'},
'condos':	{'condo','condom','condoms','condor'},
'conducive':	{'conductive'},
'conduct':	{'conducts','conduit'},
'conductive':	{'conducive'},
'conductor':	{'conductors'},
'conductors':	{'conductor'},
'conducts':	{'conduct','conduits'},
'conduit':	{'conduct','conduits'},
'conduits':	{'conducts','conduit'},
'cone':	{'bone','cane','cine','clone','code','coke','cole','come','con','cones','conn','cons','cont','cope','core','cote','cove','done','gone','hone','lone','none','one','tone','zone'},
'cones':	{'bones','canes','clones','codes','comes','cone','cons','cores','jones','ones','tones','zones'},
'confer':	{'confers'},
'conference':	{'conferences'},
'conferences':	{'conference'},
'confers':	{'coffers','confer','confess'},
'confess':	{'confers'},
'confessed':	{'confesses'},
'confesses':	{'confessed'},
'confession':	{'concession','confessions'},
'confessions':	{'concessions','confession'},
'confidence':	{'confidences'},
'confidences':	{'confidence'},
'configuration':	{'configurations'},
'configurations':	{'configuration'},
'configure':	{'configured','configures'},
'configured':	{'configure','configures'},
'configures':	{'configure','configured'},
'confine':	{'confined','confines'},
'confined':	{'confine','confines'},
'confines':	{'confine','confined'},
'confirm':	{'confirms','conform'},
'confirmation':	{'conformation'},
'confirmed':	{'conformed'},
'confirming':	{'conforming'},
'confirms':	{'confirm','conforms'},
'conflict':	{'conflicts'},
'conflicts':	{'conflict'},
'conform':	{'confirm','conforms'},
'conformation':	{'confirmation'},
'conformed':	{'confirmed'},
'conforming':	{'confirming'},
'conformist':	{'conformists'},
'conformists':	{'conformist'},
'conforms':	{'confirms','conform'},
'confront':	{'confronts'},
'confronts':	{'confront'},
'confuse':	{'confused','confuses'},
'confused':	{'confuse','confuses'},
'confuses':	{'confuse','confused'},
'congested':	{'contested'},
'congo':	{'bongo','condo'},
'congratulate':	{'congratulated','congratulates'},
'congratulated':	{'congratulate','congratulates'},
'congratulates':	{'congratulate','congratulated'},
'congregation':	{'congregations'},
'congregations':	{'congregation'},
'congressman':	{'congressmen'},
'congressmen':	{'congressman'},
'conical':	{'comical','cynical'},
'conjugate':	{'conjugated'},
'conjugated':	{'conjugate'},
'conn':	{'bonn','coin','con','cone','cons','cont','coon','corn'},
'connect':	{'connects'},
'connection':	{'connections','convection'},
'connections':	{'connection'},
'connective':	{'convective'},
'connector':	{'connectors'},
'connectors':	{'connector'},
'connects':	{'connect'},
'conquer':	{'conquers'},
'conqueror':	{'conquerors'},
'conquerors':	{'conqueror'},
'conquers':	{'conquer'},
'conquest':	{'conquests'},
'conquests':	{'conquest'},
'cons':	{'cans','cns','coins','cols','con','cone','cones','conn','cont','coos','cops','cos','cots','cows','icons','ions','sons','tons'},
'conscience':	{'consciences'},
'consciences':	{'conscience'},
'consent':	{'consents','content','convent'},
'consented':	{'contented'},
'consenting':	{'contenting'},
'consents':	{'consent','contents'},
'consequence':	{'consequences'},
'consequences':	{'consequence'},
'conservative':	{'conservatives'},
'conservatives':	{'conservative'},
'conserve':	{'conserved'},
'conserved':	{'conserve'},
'consider':	{'considers'},
'considerable':	{'considerably'},
'considerably':	{'considerable'},
'consideration':	{'considerations'},
'considerations':	{'consideration'},
'considers':	{'consider'},
'consist':	{'consists'},
'consists':	{'consist'},
'console':	{'consoles'},
'consoles':	{'console'},
'consolidate':	{'consolidated'},
'consolidated':	{'consolidate'},
'constance':	{'constancy'},
'constancy':	{'constance'},
'constant':	{'constants'},
'constants':	{'constant'},
'constellation':	{'constellations'},
'constellations':	{'constellation'},
'constituent':	{'constituents'},
'constituents':	{'constituent'},
'constitute':	{'constituted','constitutes'},
'constituted':	{'constitute','constitutes'},
'constitutes':	{'constitute','constituted'},
'constitution':	{'constitutions'},
'constitutions':	{'constitution'},
'constrain':	{'constrains','constraint'},
'constrains':	{'constrain','constraint','constraints'},
'constraint':	{'constrain','constrains','constraints'},
'constraints':	{'constrains','constraint'},
'construct':	{'constructs'},
'construction':	{'constructions'},
'constructions':	{'construction'},
'constructs':	{'construct'},
'consul':	{'consult'},
'consulate':	{'consulates'},
'consulates':	{'consulate'},
'consult':	{'consul','consults'},
'consultant':	{'consultants'},
'consultants':	{'consultant'},
'consultation':	{'consultations'},
'consultations':	{'consultation'},
'consults':	{'consult'},
'consumable':	{'consumables'},
'consumables':	{'consumable'},
'consume':	{'consumed','consumer','consumes'},
'consumed':	{'consume','consumer','consumes'},
'consumer':	{'consume','consumed','consumers','consumes'},
'consumers':	{'consumer','consumes'},
'consumes':	{'consume','consumed','consumer','consumers'},
'cont':	{'cant','cent','coat','colt','con','cone','conn','cons','cost','cot','count','cunt','dont','font','ont','wont'},
'contact':	{'contacts','contract'},
'contacted':	{'contracted'},
'contacting':	{'contracting'},
'contacts':	{'contact','contracts'},
'contain':	{'contains'},
'contained':	{'container'},
'container':	{'contained','containers'},
'containers':	{'container'},
'contains':	{'contain'},
'contaminant':	{'contaminants'},
'contaminants':	{'contaminant'},
'contaminate':	{'contaminated'},
'contaminated':	{'contaminate'},
'contemplate':	{'contemplated'},
'contemplated':	{'contemplate'},
'contend':	{'contends','content'},
'contended':	{'contender','contented'},
'contender':	{'contended','contenders'},
'contenders':	{'contender'},
'contending':	{'contenting'},
'contends':	{'contend','contents'},
'content':	{'consent','contend','contents','contest','context','convent'},
'contented':	{'consented','contended','contested'},
'contenting':	{'consenting','contending'},
'contention':	{'convention'},
'contents':	{'consents','contends','content','contests','contexts'},
'contest':	{'content','contests','context'},
'contestant':	{'contestants'},
'contestants':	{'contestant'},
'contested':	{'congested','contented'},
'contests':	{'contents','contest','contexts'},
'context':	{'content','contest','contexts'},
'contexts':	{'contents','contests','context'},
'contextualise':	{'contextualised','contextualize'},
'contextualised':	{'contextualise','contextualized'},
'contextualising':	{'contextualizing'},
'contextualize':	{'contextualise','contextualized'},
'contextualized':	{'contextualised','contextualize'},
'contextualizing':	{'contextualising'},
'contiguous':	{'continuous'},
'continent':	{'continents','contingent'},
'continents':	{'continent'},
'contingent':	{'continent'},
'continue':	{'continued','continues'},
'continued':	{'continue','continues'},
'continues':	{'continue','continued'},
'continuous':	{'contiguous'},
'contour':	{'contours'},
'contours':	{'contour'},
'contraceptive':	{'contraceptives'},
'contraceptives':	{'contraceptive'},
'contract':	{'contact','contracts','contrast'},
'contracted':	{'contacted','contrasted'},
'contracting':	{'contacting','contrasting'},
'contraction':	{'contractions'},
'contractions':	{'contraction'},
'contractor':	{'contractors'},
'contractors':	{'contractor'},
'contracts':	{'contacts','contract','contrasts'},
'contradict':	{'contradicts'},
'contradiction':	{'contradictions'},
'contradictions':	{'contradiction'},
'contradicts':	{'contradict'},
'contrast':	{'contract','contrasts'},
'contrasted':	{'contracted'},
'contrasting':	{'contracting'},
'contrasts':	{'contracts','contrast'},
'contribute':	{'contributed','contributes'},
'contributed':	{'contribute','contributes'},
'contributes':	{'contribute','contributed'},
'contribution':	{'contributions'},
'contributions':	{'contribution'},
'contributor':	{'contributors','contributory'},
'contributors':	{'contributor','contributory'},
'contributory':	{'contributor','contributors'},
'control':	{'controls'},
'controlled':	{'controller'},
'controller':	{'controlled','controllers'},
'controllers':	{'controller'},
'controls':	{'control'},
'convection':	{'connection','convention','conviction'},
'convective':	{'connective'},
'convene':	{'convened','convener','convenes','convent'},
'convened':	{'convene','convener','convenes','conveyed'},
'convener':	{'convene','convened','convenes'},
'convenes':	{'convene','convened','convener'},
'convenience':	{'conveniences'},
'conveniences':	{'convenience'},
'convening':	{'conveying'},
'convent':	{'consent','content','convene','convert'},
'convention':	{'contention','convection','conventions'},
'conventions':	{'convention'},
'converge':	{'converged','converges','converse'},
'converged':	{'converge','converges','converted'},
'converges':	{'converge','converged'},
'converging':	{'converting'},
'conversation':	{'conversations'},
'conversations':	{'conversation'},
'converse':	{'converge'},
'conversion':	{'conversions'},
'conversions':	{'conversion'},
'convert':	{'concert','convent','converts','covert'},
'converted':	{'concerted','converged','converter'},
'converter':	{'converted','converters'},
'converters':	{'converter'},
'convertible':	{'convertibles'},
'convertibles':	{'convertible'},
'converting':	{'converging'},
'converts':	{'concerts','convert'},
'convex':	{'convey'},
'convey':	{'convex','conveys','convoy','covey'},
'conveyed':	{'convened'},
'conveying':	{'convening'},
'conveyor':	{'conveyors'},
'conveyors':	{'conveyor'},
'conveys':	{'convey'},
'convict':	{'convicts'},
'conviction':	{'convection','convictions'},
'convictions':	{'conviction'},
'convicts':	{'convict'},
'convince':	{'convinced','convinces'},
'convinced':	{'convince','convinces'},
'convinces':	{'convince','convinced'},
'convoy':	{'convey'},
'coo':	{'boo','ceo','cfo','co','cob','coco','cod','cog','col','com','como','con','cook','cool','coon','coop','coos','cop','cos','cot','cou','cow','cox','coy','goo','loo','moo','poo','too','woo','zoo'},
'cook':	{'book','cock','coo','cooke','cooks','cool','coon','coop','coos','cork','crook','hook','look','nook','rook','took'},
'cookbook':	{'cookbooks'},
'cookbooks':	{'cookbook'},
'cooke':	{'choke','coke','cook','cooked','cooker','cookie','cooks'},
'cooked':	{'booked','choked','cooke','cooker','cooled','corked','crooked','hooked','looked'},
'cooker':	{'booker','choker','cooke','cooked','cookers','cookery','cooler','cooper','hooker'},
'cookers':	{'cooker','cookery','coolers'},
'cookery':	{'cooker','cookers'},
'cookie':	{'cooke','cookies','rookie'},
'cookies':	{'cookie','rookies'},
'cooking':	{'booking','choking','cooling','corking','hooking','looking'},
'cooks':	{'books','cocks','cook','cooke','cools','coos','corks','crooks','hooks','looks'},
'cool':	{'coal','cobol','coil','col','coo','cook','cools','coon','coop','coos','fool','pool','tool','wool'},
'cooled':	{'coiled','cooked','cooler','fooled','pooled','tooled'},
'cooler':	{'cooker','cooled','coolers','cooper'},
'coolers':	{'cookers','cooler'},
'cooling':	{'cooking','fooling','pooling','tooling'},
'coolly':	{'woolly'},
'cools':	{'coals','coils','cols','cooks','cool','coos','fools','pools','tools','wools'},
'coon':	{'boon','coin','colon','con','conn','coo','cook','cool','coop','coos','corn','loon','moon','noon','soon'},
'coop':	{'chop','comp','coo','cook','cool','coon','coos','cop','corp','coup','crop','hoop','loop','poop','scoop'},
'cooper':	{'cooker','cooler','copper'},
'cooperate':	{'co-operate','cooperated','cooperates'},
'cooperated':	{'co-operated','cooperate','cooperates'},
'cooperates':	{'co-operates','cooperate','cooperated'},
'cooperation':	{'co-operation'},
'cooperative':	{'co-operative','cooperatives'},
'cooperatively':	{'co-operatively'},
'cooperatives':	{'cooperative'},
'coordinate':	{'co-ordinate','coordinated','coordinates'},
'coordinated':	{'co-ordinated','coordinate','coordinates'},
'coordinates':	{'co-ordinates','coordinate','coordinated'},
'coordinating':	{'co-ordinating'},
'coordination':	{'co-ordination'},
'coordinator':	{'co-ordinator','coordinators'},
'coordinators':	{'co-ordinators','coordinator'},
'coos':	{'cocos','cols','cons','coo','cook','cooks','cool','cools','coon','coop','cops','cos','cots','cows','zoos'},
'cop':	{'bop','cap','chop','co','cob','cod','cog','col','com','comp','con','coo','coop','cope','cops','copy','corp','cos','cot','cou','coup','cow','cox','coy','crop','cup','gop','hop','mop','op','pop','sop','top','wop'},
'cope':	{'cape','code','coke','cole','come','cone','cop','cops','copy','core','cote','coupe','cove','dope','hope','pope','rope','scope'},
'copied':	{'copier','copies'},
'copier':	{'copied','copiers','copies','copper'},
'copiers':	{'copier','copies'},
'copies':	{'copied','copier','copiers'},
'coping':	{'coding','coming','copying','coring','doping','hoping','scoping'},
'copper':	{'chopper','cooper','copier','hopper','popper','topper'},
'cops':	{'caps','chops','cols','comps','cons','coos','cop','cope','copy','corps','cos','cots','cows','cps','crops','cups','hops','ops','pops','tops'},
'coptic':	{'optic'},
'copy':	{'cody','cop','cope','cops','cosy','coy','cozy'},
'copying':	{'coping'},
'copyright':	{'copyrights'},
'copyrights':	{'copyright'},
'cora':	{'cobra','coca','coda','cola','coma','coral','cord','core','cork','corn','corp','fora','hora'},
'coral':	{'choral','coal','cora','corals','corral','moral','oral'},
'corals':	{'coals','coral','morals'},
'cord':	{'card','chord','cod','coed','cold','cora','cords','core','cored','cork','corn','corp','ford','lord','word'},
'corded':	{'coded','cored','corked','worded'},
'cords':	{'cards','chords','colds','cord','cores','corks','corps','lords','words'},
'core':	{'bore','care','chore','code','coke','cole','come','cone','cope','cora','cord','cored','cores','cork','corn','corp','cote','cove','cure','fore','gore','lore','more','ore','pore','score','sore','tore','wore'},
'cored':	{'bored','cared','coded','coed','cord','corded','core','cores','corked','cred','cured','scored'},
'cores':	{'cares','ceres','chores','codes','comes','cones','cords','core','cored','corks','corps','cortes','cures','ores','pores','scores','sores'},
'coring':	{'boring','caring','coding','coming','coping','corking','curing','scoring'},
'cork':	{'cock','cook','cora','cord','core','corks','corn','corp','dork','fork','pork','work','york'},
'corked':	{'cooked','corded','cored','worked'},
'corking':	{'cooking','coring','working'},
'corks':	{'cocks','cooks','cords','cores','cork','corps','forks','works'},
'corn':	{'acorn','born','coin','con','conn','coon','cora','cord','core','cork','corp','horn','morn','porn','scorn','torn','worn'},
'cornea':	{'corneal','corner'},
'corneal':	{'cornea','cornell'},
'cornell':	{'corneal'},
'corner':	{'cornea','corners','coroner'},
'corners':	{'corner'},
'corona':	{'coronal'},
'coronal':	{'corona'},
'coroner':	{'corner'},
'corp':	{'carp','comp','coop','cop','cora','cord','core','cork','corn','corps','coup'},
'corporate':	{'corporates'},
'corporates':	{'corporate'},
'corporation':	{'corporations'},
'corporations':	{'corporation'},
'corps':	{'comps','cops','cords','cores','corks','corp','corpse','corpus'},
'corpse':	{'corps','corpses'},
'corpses':	{'corpse'},
'corpus':	{'corps'},
'corral':	{'coral'},
'correct':	{'corrects'},
'correction':	{'corrections'},
'corrections':	{'correction'},
'corrects':	{'correct'},
'correlate':	{'correlated','correlates'},
'correlated':	{'correlate','correlates'},
'correlates':	{'correlate','correlated'},
'correlation':	{'correlations'},
'correlations':	{'correlation'},
'correspond':	{'corresponds'},
'correspondent':	{'correspondents'},
'correspondents':	{'correspondent'},
'corresponds':	{'correspond'},
'corridor':	{'corridors'},
'corridors':	{'corridor'},
'corset':	{'corsets'},
'corsets':	{'corset'},
'cortes':	{'cores','cortex'},
'cortex':	{'cortes','vortex'},
'cortland':	{'portland'},
'cos':	{'cns','co','cob','cod','cog','col','cols','com','con','cons','coo','coos','cop','cops','cost','cosy','cot','cots','cou','cow','cows','cox','coy','cps','cs','dos','hos','nos','os','sos'},
'cosmetic':	{'cosmetics'},
'cosmetics':	{'cosmetic'},
'cosmic':	{'comic'},
'cost':	{'cast','coast','coat','colt','cont','cos','costa','costs','cosy','cot','cst','cyst','host','lost','most','post'},
'costa':	{'cost','costs'},
'costing':	{'casting','coating','hosting','posting'},
'costly':	{'mostly'},
'costs':	{'casts','coasts','coats','cost','costa','cots','cysts','hosts','posts'},
'costume':	{'costumes'},
'costumes':	{'costume'},
'cosy':	{'cody','copy','cos','cost','coy','cozy','rosy'},
'cot':	{'bot','cat','clot','co','coat','cob','cod','cog','col','colt','com','con','cont','coo','cop','cos','cost','cote','cots','cou','cow','cox','coy','crt','cst','ct','cut','dot','got','hot','lot','mot','not','pot','rot','scot','sot','tot','wot'},
'cote':	{'cite','code','coke','cole','come','comte','cone','cope','core','cot','cots','cove','cute','note','tote','vote'},
'cots':	{'bots','cats','clots','coats','cols','cons','coos','cops','cos','costs','cot','cote','cows','cuts','dots','lots','pots','rots','scots','tots'},
'cottage':	{'cottages'},
'cottages':	{'cottage'},
'cotter':	{'cutter','hotter','otter','potter'},
'cou':	{'chou','co','cob','cod','cog','col','com','con','coo','cop','cos','cot','coup','cow','cox','coy','cpu','cu','tou','you'},
'couch':	{'coach','cough','crouch','pouch','touch','vouch'},
'couches':	{'coaches','pouches','touches'},
'cough':	{'bough','couch','coughs','dough','lough','rough','tough'},
'coughs':	{'cough'},
'could':	{'cold','couldn','gould','mould','would'},
'couldn':	{'could','wouldn'},
'council':	{'councils'},
'councillor':	{'councillors','councilor'},
'councillors':	{'councillor'},
'councilor':	{'councillor'},
'councils':	{'council'},
'counsel':	{'counsels'},
'counseling':	{'counselling'},
'counselling':	{'counseling'},
'counsellor':	{'counsellors','counselor'},
'counsellors':	{'counsellor','counselors'},
'counselor':	{'counsellor','counselors'},
'counselors':	{'counsellors','counselor'},
'counsels':	{'counsel'},
'count':	{'cont','counts','county','court','cunt','mount'},
'countable':	{'mountable'},
'counted':	{'counter','mounted'},
'counter':	{'counted','counters'},
'counterpart':	{'counterparts'},
'counterparts':	{'counterpart'},
'counters':	{'counter','countess'},
'countess':	{'counters','countless'},
'counties':	{'countries'},
'counting':	{'mounting'},
'countless':	{'countess'},
'countries':	{'counties'},
'country':	{'county'},
'countryside':	{'countrywide'},
'countrywide':	{'countryside'},
'counts':	{'count','county','courts','mounts'},
'county':	{'bounty','count','country','counts'},
'coup':	{'comp','coop','cop','corp','cou','coupe','cup','soup'},
'coupe':	{'cope','coup','couple'},
'couple':	{'coupe','coupled','coupler','couples'},
'coupled':	{'couple','coupler','couples'},
'coupler':	{'couple','coupled','couples'},
'couples':	{'couple','coupled','coupler'},
'coupling':	{'couplings'},
'couplings':	{'coupling'},
'coupon':	{'coupons'},
'coupons':	{'coupon'},
'courier':	{'fourier'},
'course':	{'coarse','courses','curse'},
'courses':	{'course','curses'},
'court':	{'count','courts','curt'},
'courts':	{'counts','court'},
'cousin':	{'cousins'},
'cousins':	{'cousin'},
'cove':	{'cave','clove','code','coke','cole','come','cone','cope','core','cote','cover','covey','dove','love','move','rove','wove'},
'covenant':	{'covenants'},
'covenants':	{'covenant'},
'cover':	{'clover','coder','comer','cove','covers','covert','covey','dover','hover','lover','mover','over','rover'},
'coverage':	{'coverages'},
'coverages':	{'coverage'},
'covered':	{'coveted'},
'covering':	{'coverings','hovering'},
'coverings':	{'covering'},
'covers':	{'coders','cover','covert','lovers','movers','overs','rovers'},
'covert':	{'convert','cover','covers','overt'},
'coveted':	{'covered'},
'covey':	{'convey','cove','cover'},
'cow':	{'bow','chow','co','cob','cod','cog','col','com','con','coo','cop','cos','cot','cou','cows','cox','coy','crow','how','low','now','ow','pow','row','sow','tow','vow','wow'},
'coward':	{'cowards','howard','toward'},
'cowards':	{'coward','towards'},
'cows':	{'bows','cols','cons','coos','cops','cos','cots','cow','crows','hows','lows','rows','sows','vows'},
'cox':	{'box','co','coax','cob','cod','cog','col','com','con','coo','cop','cos','cot','cou','cow','coy','fox','ox','pox'},
'coy':	{'boy','cay','co','cob','cod','cody','cog','col','com','con','coo','cop','copy','cos','cosy','cot','cou','cow','cox','cozy','cry','joy','soy','toy'},
'cozy':	{'cody','copy','cosy','coy'},
'cpa':	{'ca','cha','cia','cpi','cpr','cps','cpu','epa','gpa','pa','spa'},
'cpi':	{'chi','ci','cpa','cpr','cps','cpu','epi','pi'},
'cpr':	{'apr','car','cpa','cpi','cps','cpu','cr','cur','pr'},
'cps':	{'bps','caps','cns','cops','cos','cpa','cpi','cpr','cpu','cs','cups','fps','ops','ps'},
'cpu':	{'cou','cpa','cpi','cpr','cps','cu','pu'},
'cr':	{'ar','br','c','ca','car','cc','cd','ce','cf','ci','cl','cm','co','cpr','crt','cry','cs','ct','cu','cur','cv','cz','dr','er','fr','hr','ir','jr','kr','lr','mr','or','pr','qr','r','sr','ur','vcr','yr','zr'},
'crab':	{'arab','cab','crabs','cram','crap','crib','grab'},
'crabs':	{'cabs','crab','craps','cribs','grabs'},
'crack':	{'cracks','crank','crock','rack','track'},
'cracked':	{'cracker','tracked'},
'cracker':	{'cracked','crackers','tracker'},
'crackers':	{'cracker'},
'cracking':	{'racking','tracking'},
'cracks':	{'crack','racks','tracks'},
'cradle':	{'cradles'},
'cradles':	{'cradle'},
'craft':	{'crafts','crafty','croft','draft','graft','kraft','raft'},
'crafted':	{'drafted'},
'crafting':	{'drafting','grafting','rafting'},
'crafts':	{'craft','crafty','drafts','grafts'},
'craftsman':	{'craftsmen'},
'craftsmen':	{'craftsman'},
'crafty':	{'craft','crafts'},
'cram':	{'cam','clam','crab','crap','cream','dram','gram','ram','tram'},
'crammed':	{'cramped','rammed'},
'cramped':	{'camped','clamped','crammed'},
'cramps':	{'camps','champs','clamps','craps','ramps'},
'crane':	{'cane','cranes','crank','crate','crave','craze'},
'cranes':	{'canes','crane','crates'},
'crank':	{'crack','crane','cranky','drank','frank','prank','rank'},
'cranky':	{'crank'},
'crap':	{'cap','chap','clap','crab','cram','craps','crop','rap','scrap','trap','wrap'},
'craps':	{'caps','chaps','crabs','cramps','crap','crops','scraps','traps','wraps'},
'crash':	{'cash','clash','crush','rash','trash'},
'crashed':	{'crashes','crushed','trashed'},
'crashers':	{'crashes'},
'crashes':	{'clashes','crashed','crashers','crushes'},
'crashing':	{'cashing','crushing'},
'crate':	{'crane','crater','crates','crave','craze','create','crete','grate','rate'},
'crater':	{'cater','crate','craters','crates'},
'craters':	{'caters','crater','crates'},
'crates':	{'cranes','crate','crater','craters','creates','rates'},
'crave':	{'brave','cave','crane','crate','craven','craze','grave','rave'},
'craven':	{'crave','raven'},
'craving':	{'braving','caving','cravings','raving'},
'cravings':	{'craving'},
'crawl':	{'trawl'},
'crawled':	{'crawler'},
'crawler':	{'crawled'},
'craze':	{'crane','crate','crave','crazed','crazy'},
'crazed':	{'craze'},
'crazy':	{'craze'},
'cream':	{'cram','creams','creamy','dream','scream'},
'creamed':	{'creamer','creased','created','dreamed','screamed'},
'creamer':	{'creamed','dreamer'},
'creaming':	{'creating','dreaming','screaming'},
'creams':	{'cream','creamy','dreams','screams'},
'creamy':	{'cream','creams','dreamy'},
'crease':	{'cease','creased','creases','create','grease'},
'creased':	{'ceased','creamed','crease','creases','created','greased'},
'creases':	{'ceases','crease','creased','creates','greases'},
'create':	{'crate','crease','created','creates','crete'},
'created':	{'cheated','creamed','creased','create','creates','crested','treated'},
'creates':	{'crates','creases','create','created'},
'creating':	{'cheating','creaming','treating'},
'creation':	{'creations','cremation'},
'creations':	{'creation'},
'creator':	{'creators'},
'creators':	{'creator'},
'creature':	{'creatures'},
'creatures':	{'creature'},
'cred':	{'bred','cared','coed','cored','cree','creed','crew','cried','cured','red'},
'credential':	{'credentials'},
'credentials':	{'credential'},
'credit':	{'credits'},
'creditor':	{'creditors'},
'creditors':	{'creditor'},
'credits':	{'credit'},
'cree':	{'cred','creed','creek','creep','creme','crepe','crete','crew','free','tree'},
'creed':	{'breed','cred','cree','creek','creep','cried','freed','greed','reed'},
'creek':	{'cheek','cree','creed','creeks','creep','greek'},
'creeks':	{'cheeks','creek','creeps'},
'creep':	{'cree','creed','creek','creeps','creepy'},
'creeps':	{'creeks','creep','creepy'},
'creepy':	{'creep','creeps'},
'cremation':	{'creation'},
'creme':	{'cree','crepe','crete','crime'},
'crepe':	{'cree','creme','crept','crete'},
'crept':	{'crepe','crest','crypt'},
'crest':	{'brest','chest','crept','crust','rest'},
'crested':	{'chested','created','rested'},
'crete':	{'crate','create','cree','creme','crepe'},
'crew':	{'brew','chew','cred','cree','crews','crow','drew','grew','screw'},
'crews':	{'chews','crew','crows','screws'},
'crib':	{'crab','cribs','rib'},
'cribs':	{'crabs','crib','cries','ribs'},
'cried':	{'cred','creed','cries','dried','fried','tried'},
'cries':	{'aries','caries','cribs','cried','crimes','crises','dries','fries','tries'},
'crime':	{'chime','creme','crimea','crimes','prime'},
'crimea':	{'crime','crimes'},
'crimes':	{'chimes','cries','crime','crimea','crises','primes'},
'criminal':	{'criminals'},
'criminals':	{'criminal'},
'cringe':	{'fringe'},
'cripple':	{'crippled','ripple'},
'crippled':	{'cripple'},
'crises':	{'arises','cries','crimes','crisis','cruises','rises'},
'crisis':	{'crises'},
'crisp':	{'crispy'},
'crispy':	{'crisp'},
'critic':	{'critica','critics'},
'critica':	{'critic','critical','critics'},
'critical':	{'critica'},
'criticise':	{'criticised','criticism','criticize'},
'criticised':	{'criticise','criticized'},
'criticism':	{'criticise','criticisms'},
'criticisms':	{'criticism'},
'criticize':	{'criticise','criticized','criticizes'},
'criticized':	{'criticised','criticize','criticizes'},
'criticizes':	{'criticize','criticized'},
'critics':	{'critic','critica'},
'critique':	{'critiques'},
'critiques':	{'critique'},
'critter':	{'critters'},
'critters':	{'critter'},
'croatia':	{'croatian'},
'croatian':	{'croatia'},
'crock':	{'chock','clock','cock','crack','crook','rock'},
'croft':	{'craft'},
'crook':	{'brook','cook','crock','crooks','rook'},
'crooked':	{'cooked'},
'crooks':	{'brooks','cooks','crook'},
'crop':	{'chop','coop','cop','crap','crops','crow','drop','prop'},
'cropped':	{'chopped','dropped'},
'cropping':	{'chopping','dropping'},
'crops':	{'chops','cops','craps','crop','cross','crows','drops','props'},
'cross':	{'across','crops','crows','gross','ross'},
'crossed':	{'crosses'},
'crosses':	{'crossed'},
'crossing':	{'crossings'},
'crossings':	{'crossing'},
'crossword':	{'crosswords'},
'crosswords':	{'crossword'},
'crotch':	{'crouch'},
'crouch':	{'couch','crotch'},
'crow':	{'brow','chow','cow','crew','crop','crowd','crown','crows','grow','row'},
'crowd':	{'crow','crowds','crown','crows'},
'crowded':	{'crowned'},
'crowding':	{'crowning'},
'crowds':	{'crowd','crowns','crows'},
'crown':	{'brown','clown','crow','crowd','crowns','crows','drown','frown','grown'},
'crowned':	{'browned','crowded','drowned','frowned'},
'crowning':	{'browning','crowding','drowning'},
'crowns':	{'browns','clowns','crowds','crown','crows','drowns'},
'crows':	{'brows','cows','crews','crops','cross','crow','crowd','crowds','crown','crowns','grows','rows'},
'crt':	{'art','cart','cat','cert','cot','cr','cry','cst','ct','curt','cut'},
'crude':	{'rude'},
'cruelly':	{'cruelty'},
'cruelty':	{'cruelly'},
'cruise':	{'cruiser','cruises'},
'cruiser':	{'cruise','cruisers','cruises'},
'cruisers':	{'cruiser','cruises'},
'cruises':	{'bruises','crises','cruise','cruiser','cruisers'},
'cruising':	{'bruising'},
'crumb':	{'crumbs'},
'crumble':	{'crumbled','rumble'},
'crumbled':	{'crumble'},
'crumbs':	{'crumb'},
'crunch':	{'brunch','crunchy'},
'crunchy':	{'crunch'},
'crusade':	{'crusader','crusades'},
'crusader':	{'crusade','crusades'},
'crusades':	{'crusade','crusader'},
'crush':	{'brush','crash','crust','rush'},
'crushed':	{'brushed','crashed','crusher','crushes','rushed'},
'crusher':	{'crushed','crushes'},
'crushes':	{'brushes','crashes','crushed','crusher','rushes'},
'crushing':	{'brushing','crashing','rushing'},
'crust':	{'crest','crush','crusty','rust','trust'},
'crusty':	{'crust','rusty','trusty'},
'cry':	{'cay','coy','cr','crt','dry','fry','try'},
'crying':	{'drying','frying','trying'},
'crypt':	{'crept'},
'crystal':	{'crystals'},
'crystals':	{'crystal'},
'cs':	{'as','bs','c','ca','cc','cd','ce','cf','ci','cl','cm','cns','co','cos','cps','cr','cst','ct','cu','cv','cz','es','hs','is','ks','ms','os','ps','ss','ts','us','vs'},
'cst':	{'cast','cat','cost','cot','crt','cs','ct','cut','cyst','est','mst','pst'},
'ct':	{'act','at','c','ca','cat','cc','cd','ce','cf','ci','cl','cm','co','cot','cr','crt','cs','cst','cu','cut','cv','cz','et','ft','ht','it','kt','mt','nt','oct','pct','pt','t','ut','vt'},
'cu':	{'au','c','ca','cc','cd','ce','cf','ci','cl','cm','co','cou','cpu','cr','cs','ct','cub','cue','cum','cup','cur','cut','cv','cz','du','eu','gu','icu','ju','lu','mu','nu','pu','ru','su','u','wu','zu'},
'cub':	{'cab','club','cob','cu','cuba','cube','cue','cum','cup','cur','curb','cut','dub','hub','pub','rub','sub','tub'},
'cuba':	{'cub','cuban','cube','scuba','tuba'},
'cuban':	{'cuba'},
'cube':	{'cub','cuba','cubes','cue','cure','cute','lube','tube'},
'cubes':	{'cube','cues','cures','lubes','tubes'},
'cubic':	{'pubic'},
'cue':	{'ce','clue','cu','cub','cube','cues','cum','cup','cur','cure','cut','cute','due','hue','que','rue','sue'},
'cues':	{'clues','cubes','cue','cups','cures','cuts','dues','hues','tues'},
'cuff':	{'buff','cuffs','duff','huff','puff','ruff'},
'cuffs':	{'buffs','cuff','puffs'},
'cuisine':	{'cuisines'},
'cuisines':	{'cuisine'},
'culled':	{'called','curled','pulled'},
'cult':	{'colt','cults','cunt','curt','cut'},
'cultivate':	{'cultivated','cultivates'},
'cultivated':	{'cultivate','cultivates'},
'cultivates':	{'cultivate','cultivated'},
'cults':	{'cult','cuts'},
'culture':	{'cultured','cultures','vulture'},
'cultured':	{'culture','cultures'},
'cultures':	{'culture','cultured'},
'cum':	{'bum','cam','cm','com','cu','cub','cue','cup','cur','cut','gum','hum','mum','rum','scum','sum','um','yum'},
'cunning':	{'canning','running'},
'cunt':	{'aunt','cant','cent','cont','count','cult','curt','cut','hunt','punt'},
'cup':	{'cap','cop','coup','cu','cub','cue','cum','cups','cur','cusp','cut','pup','sup','up'},
'cupboard':	{'cupboards'},
'cupboards':	{'cupboard'},
'cups':	{'caps','cops','cps','cues','cup','cuts','pups'},
'cur':	{'bur','car','cpr','cr','cu','cub','cue','cum','cup','curb','cure','curl','curt','cut','dur','fur','our','ur'},
'curable':	{'durable'},
'curator':	{'curators'},
'curators':	{'curator'},
'curb':	{'cub','cur','curbs','cure','curl','curt'},
'curbs':	{'curb','cures','curls'},
'cure':	{'care','core','cube','cue','cur','curb','cured','cures','curie','curl','curse','curt','curve','cute','lure','pure','sure'},
'cured':	{'cared','cored','cred','cure','cures','curled','cursed','curved','lured'},
'cures':	{'cares','ceres','cores','cubes','cues','curbs','cure','cured','curls','curses','curves','lures'},
'curie':	{'cure','curio','curse','curve','cutie'},
'curing':	{'caring','coring','curling','cursing','curving','during','turing'},
'curio':	{'curie'},
'curious':	{'furious'},
'curiously':	{'furiously'},
'curl':	{'cur','curb','cure','curls','curly','curt','furl','url'},
'curled':	{'culled','cured','cursed','curved','hurled'},
'curling':	{'curing','cursing','curving'},
'curls':	{'curbs','cures','curl','curly'},
'curly':	{'curl','curls','curry'},
'current':	{'currents'},
'currents':	{'current'},
'curricula':	{'curricular'},
'curricular':	{'curricula'},
'curry':	{'carry','curly','furry','hurry'},
'curse':	{'course','cure','curie','cursed','curses','curve','nurse','purse'},
'cursed':	{'cured','curled','curse','curses','curved','nursed'},
'curses':	{'courses','cures','curse','cursed','curves','nurses','purses'},
'cursing':	{'curing','curling','curving','nursing'},
'cursor':	{'cursors','cursory'},
'cursors':	{'cursor','cursory'},
'cursory':	{'cursor','cursors'},
'curt':	{'burt','cart','cert','court','crt','cult','cunt','cur','curb','cure','curl','cut','hurt'},
'curtail':	{'curtain'},
'curtain':	{'certain','curtail','curtains'},
'curtains':	{'curtain'},
'curve':	{'carve','cure','curie','curse','curved','curves'},
'curved':	{'carved','cured','curled','cursed','curve','curves'},
'curves':	{'cures','curses','curve','curved'},
'curving':	{'carving','curing','curling','cursing'},
'cushion':	{'cushions'},
'cushions':	{'cushion'},
'cusp':	{'cup'},
'custard':	{'mustard'},
'custer':	{'buster','caster','cluster','cutter','duster','luster','muster'},
'custodial':	{'custodian'},
'custodian':	{'custodial'},
'custom':	{'customs'},
'customer':	{'customers'},
'customers':	{'customer'},
'customise':	{'customize'},
'customize':	{'customise','customized'},
'customized':	{'customize'},
'customs':	{'custom'},
'cut':	{'but','cat','cot','crt','cst','ct','cu','cub','cue','cult','cum','cunt','cup','cur','curt','cute','cuts','gut','hut','nut','out','put','rut','tut','ut'},
'cute':	{'acute','chute','cite','cote','cube','cue','cure','cut','cutie','cuts','jute','mute','ute'},
'cutie':	{'curie','cute','cuties'},
'cuties':	{'cities','cutie','duties'},
'cutler':	{'butler','cutlery','cutter'},
'cutlery':	{'cutler'},
'cuts':	{'cats','cots','cues','cults','cups','cut','cute','guts','huts','nuts','outs','puts'},
'cutter':	{'butter','clutter','cotter','custer','cutler','cutters','gutter','putter','utter'},
'cutters':	{'butters','cutter','gutters','putters'},
'cutting':	{'cuttings','putting'},
'cuttings':	{'cutting'},
'cv':	{'av','c','ca','cc','cd','ce','cf','ci','cl','cm','co','cr','cs','ct','cu','cz','ev','iv','jv','lv','nv','rv','tv','uv','v','wv','xv'},
'cyan':	{'can','clan'},
'cycle':	{'cycled','cycles'},
'cycled':	{'cycle','cycles'},
'cycles':	{'cycle','cycled'},
'cyclist':	{'cyclists'},
'cyclists':	{'cyclist'},
'cylinder':	{'cylinders'},
'cylinders':	{'cylinder'},
'cymbal':	{'cymbals'},
'cymbals':	{'cymbal'},
'cynical':	{'conical'},
'cyprus':	{'cyrus'},
'cyrus':	{'cyprus'},
'cyst':	{'cast','cost','cst','cysts'},
'cystic':	{'mystic'},
'cysts':	{'casts','costs','cyst'},
'cz':	{'az','c','ca','cc','cd','ce','cf','ci','cl','cm','co','cr','cs','ct','cu','cv','hz','z'},
'd':	{'a','ad','b','c','cd','da','db','dc','dd','de','di','dj','do','dp','dr','du','dy','e','ed','f','g','gd','h','i','id','j','k','l','md','nd','o','od','p','pd','q','r','sd','t','u','v','vd','w','x','y','z'},
'da':	{'a','ada','ba','ca','d','dab','dad','dag','dal','dam','dar','dat','day','db','dc','dd','de','dea','di','dj','dna','do','dp','dr','du','dy','ea','eda','fa','fda','ga','ha','ia','ida','ka','la','ma','na','pa','pda','ra','sa','ta','va','wa','ya','za'},
'dab':	{'ab','cab','da','dad','dag','dal','dam','dar','dat','day','db','deb','dub','fab','gab','jab','lab','nab','tab'},
'dad':	{'ad','bad','cad','da','dab','dada','dads','dag','dal','dam','dar','dat','day','dd','dead','did','dmd','dod','dvd','fad','had','lad','mad','pad','rad','sad','tad','wad'},
'dada':	{'ada','dad','dads','dana','data','nada'},
'daddy':	{'caddy','dandy','paddy'},
'dads':	{'ads','dad','dada','dams','dans','days','dds','lads','pads'},
'daemon':	{'damon','demon'},
'daft':	{'aft','dart','dat','draft','raft','taft'},
'dag':	{'ag','bag','da','dab','dad','dal','dam','dang','dar','dat','day','dig','dog','drag','dug','fag','gag','jag','lag','mag','nag','rag','sag','tag'},
'dagger':	{'daggers','danger','digger','jagger'},
'daggers':	{'dagger','dangers'},
'dail':	{'bail','daily','dal','fail','hail','jail','mail','nail','rail','sail','tail'},
'daily':	{'dail','dairy','daisy','gaily'},
'dairy':	{'airy','daily','daisy','fairy','hairy'},
'daisy':	{'daily','dairy'},
'dal':	{'al','da','dab','dad','dag','dail','dale','dali','dam','dar','dat','day','deal','del','dial','dual','gal','mal','pal'},
'dale':	{'ale','bale','dal','dali','dame','dane','dare','date','daze','dole','gale','hale','male','pale','sale','tale','vale','yale'},
'dali':	{'ali','bali','cali','dal','dale','dari','deli','kali','mali'},
'dalton':	{'dayton','walton'},
'dam':	{'adam','am','cam','da','dab','dad','dag','dal','dame','damn','damp','dams','dar','dat','day','diam','dim','dram','ham','jam','lam','ram','sam','tam','yam'},
'damage':	{'damaged','damages'},
'damaged':	{'damage','damages'},
'damages':	{'damage','damaged'},
'dame':	{'came','dale','dam','damn','damp','dams','dane','dare','date','daze','dime','dome','fame','game','lame','name','same','tame'},
'damn':	{'dam','dame','damon','damp','dams','darn','dawn'},
'damned':	{'dawned'},
'damon':	{'daemon','damn','demon'},
'damp':	{'amp','camp','dam','dame','damn','dams','dump','lamp','ramp'},
'damper':	{'camper','hamper','pamper','tamper'},
'damping':	{'camping','dumping'},
'dams':	{'adams','cams','dads','dam','dame','damn','damp','dans','days','dbms','jams'},
'dana':	{'ana','dada','dane','dang','dans','data','diana','dna','dona','rana'},
'dance':	{'danced','dancer','dances','dane','dante','lance','nance','tance'},
'danced':	{'dance','dancer','dances'},
'dancer':	{'cancer','dance','danced','dancers','dances','danger','lancer'},
'dancers':	{'cancers','dancer','dances','dangers'},
'dances':	{'dance','danced','dancer','dancers'},
'dandy':	{'candy','daddy','handy','randy','sandy','tandy'},
'dane':	{'bane','cane','dale','dame','dana','dance','dang','dans','dante','dare','date','daze','dine','done','dune','lane','mane','pane','sane'},
'dang':	{'ang','bang','dag','dana','dane','dans','ding','dong','dung','fang','gang','hang','pang','rang','sang','tang','yang'},
'danger':	{'anger','dagger','dancer','dangers','hanger','manger','ranger','sanger'},
'dangers':	{'angers','bangers','daggers','dancers','danger','hangers'},
'dangle':	{'angle','bangle','dongle','tangle'},
'dangling':	{'angling'},
'danish':	{'vanish'},
'dans':	{'ans','bans','cans','dads','dams','dana','dane','dang','days','deans','fans','mans','pans','sans','vans'},
'dante':	{'ante','dance','dane','date'},
'dar':	{'ar','bar','car','da','dab','dad','dag','dal','dam','dare','dari','dark','darn','dart','dat','day','dear','der','dr','dur','ear','far','gar','jar','mar','oar','par','tar','var','war'},
'dare':	{'are','bare','care','dale','dame','dane','dar','dared','dares','dari','dark','darn','dart','date','daze','dire','fare','hare','mare','rare','ware'},
'dared':	{'bared','cared','dare','dares','dated','eared','fared','pared'},
'dares':	{'ares','bares','cares','dare','dared','darts','dates','dawes','fares','mares','wares'},
'dari':	{'bari','dali','dar','dare','dark','darn','dart','mari','sari'},
'daring':	{'baring','caring','darling','dating','during'},
'dark':	{'ark','bark','dar','dare','dari','darn','dart','dirk','dork','lark','mark','park'},
'darker':	{'barker','marker','parker'},
'darling':	{'daring'},
'darn':	{'barn','damn','dar','dare','dari','dark','dart','dawn','earn','warn','yarn'},
'dart':	{'art','bart','cart','daft','dar','dare','dari','dark','darn','darts','dat','dirt','fart','hart','kart','mart','part','tart'},
'darts':	{'arts','carts','dares','dart','karts','parts','tarts','warts'},
'dash':	{'ash','bash','cash','dish','hash','lash','mash','nash','rash','sash','wash'},
'dashed':	{'dashes','mashed','washed'},
'dashes':	{'ashes','dashed','dishes','hashes','lashes','washes'},
'dashing':	{'bashing','cashing','hashing','washing'},
'dat':	{'at','bat','cat','da','dab','dad','daft','dag','dal','dam','dar','dart','data','date','day','ddt','dot','eat','fat','hat','kat','lat','mat','oat','pat','rat','sat','tat','vat','wat'},
'data':	{'dada','dana','dat','date','kata'},
'database':	{'databases'},
'databases':	{'database'},
'date':	{'ate','dale','dame','dane','dante','dare','dat','data','dated','dates','daze','fate','gate','hate','late','mate','pate','rate','tate'},
'dated':	{'dared','date','dates','fated','gated','hated','mated','rated'},
'dates':	{'dares','date','dated','dawes','fates','gates','hates','mates','oates','rates'},
'dating':	{'daring','eating','hating','mating','rating'},
'datum':	{'tatum'},
'daughter':	{'daughters','laughter'},
'daughters':	{'daughter'},
'daunting':	{'haunting'},
'david':	{'avid','davis'},
'davis':	{'david','mavis'},
'davy':	{'day','navy','wavy'},
'dawes':	{'dares','dates'},
'dawn':	{'damn','darn','down','drawn','fawn','lawn','pawn','yawn'},
'dawned':	{'damned','downed'},
'day':	{'bay','cay','da','dab','dad','dag','dal','dam','dar','dat','davy','days','dry','dy','fay','gay','hay','jay','lay','may','nay','pay','ray','say','way'},
'days':	{'bays','dads','dams','dans','day','gays','hays','lays','mays','nays','pays','rays','says','ways'},
'dayton':	{'dalton'},
'daze':	{'dale','dame','dane','dare','date','gaze','haze','maze'},
'db':	{'ab','b','bb','d','da','dab','dc','dd','de','deb','di','dj','do','dp','dr','du','dub','dy','eb','gb','kb','lb','mb','nb','ob','pb','rb','sb','tb','yb'},
'dbms':	{'dams'},
'dc':	{'ac','bc','c','cc','cdc','d','da','db','dd','de','dec','di','dj','do','doc','dp','dr','du','dy','ec','kc','mc','nc','pc','sc','tc'},
'dd':	{'ad','add','cd','d','da','dad','db','dc','dds','ddt','de','di','did','dj','dmd','do','dod','dp','dr','du','dvd','dy','ed','gd','id','md','nd','od','odd','pd','sd','vd'},
'dds':	{'adds','ads','dads','dd','ddt','des','dis','dos','eds','odds'},
'ddt':	{'dat','dd','dds','dot'},
'de':	{'ade','be','ce','d','da','db','dc','dd','dea','deb','dec','del','den','der','des','dew','di','die','dj','do','doe','dp','dr','du','due','dy','dye','e','ee','fe','ge','he','ie','le','me','ne','ode','pe','se','te','ve','we','xe','ye'},
'dea':	{'da','de','dead','deaf','deal','dean','dear','deb','dec','del','den','der','des','dew','dna','ea','idea','lea','pea','sea','tea','yea'},
'deacon':	{'beacon','deacons'},
'deacons':	{'deacon'},
'deactivate':	{'deactivated','reactivate'},
'deactivated':	{'deactivate'},
'dead':	{'bead','dad','dea','deaf','deal','dean','dear','deed','dread','head','lead','mead','read'},
'deadline':	{'deadlines','headline'},
'deadlines':	{'deadline','headlines'},
'deadly':	{'dearly'},
'deaf':	{'dea','dead','deal','dean','dear','leaf'},
'deafer':	{'dealer','defer'},
'deafest':	{'dearest'},
'deal':	{'dal','dea','dead','deaf','deals','dealt','dean','dear','decal','del','dell','dial','dual','heal','ideal','meal','real','seal','teal','veal','zeal'},
'dealer':	{'deafer','dealers','dialer','healer'},
'dealers':	{'dealer','healers'},
'dealership':	{'dealerships'},
'dealerships':	{'dealership'},
'dealing':	{'dealings','dialing','healing','sealing'},
'dealings':	{'dealing'},
'deals':	{'deal','dealt','deans','dears','decals','dials','heals','ideals','meals','seals'},
'dealt':	{'deal','deals'},
'dean':	{'bean','dea','dead','deaf','deal','deans','dear','den','jean','kean','lean','mean'},
'deans':	{'beans','dans','deals','dean','dears','jeans','leans','means'},
'dear':	{'bear','dar','dea','dead','deaf','deal','dean','dears','deer','der','dewar','ear','fear','gear','hear','lear','near','pear','rear','tear','wear','year'},
'dearest':	{'deafest','nearest'},
'dearly':	{'deadly','early','nearly','yearly'},
'dears':	{'bears','deals','deans','dear','ears','fears','gears','hears','nears','pears','tears','wears','years'},
'death':	{'deaths','depth','heath','neath'},
'deaths':	{'death','depths'},
'deb':	{'dab','db','de','dea','debt','dec','del','den','der','des','dew','dub','eb','feb','web'},
'debate':	{'debated','debates','rebate'},
'debated':	{'debate','debates','debuted'},
'debates':	{'debate','debated','rebates'},
'debit':	{'debt','debut'},
'debt':	{'deb','debit','debts','debut','dent'},
'debtor':	{'debtors'},
'debtors':	{'debtor'},
'debts':	{'debt','debuts','dents'},
'debug':	{'debut'},
'debut':	{'debit','debt','debug','debuts'},
'debuted':	{'debated'},
'debuts':	{'debts','debut'},
'dec':	{'dc','de','dea','deb','deck','deco','del','den','der','des','dew','doc','ec','eec','rec','sec'},
'decade':	{'decades','decide','decode'},
'decadent':	{'decedent'},
'decades':	{'decade','decides'},
'decal':	{'deal','decals','decay','fecal'},
'decals':	{'deals','decal','decays'},
'decay':	{'decal','decays','delay'},
'decayed':	{'delayed'},
'decaying':	{'delaying'},
'decays':	{'decals','decay','delays'},
'deceased':	{'decreased'},
'decedent':	{'decadent'},
'deceit':	{'decent'},
'deceive':	{'deceived','deceives','receive'},
'deceived':	{'deceive','deceives','received'},
'deceives':	{'deceive','deceived','receives'},
'deceiving':	{'receiving'},
'decent':	{'deceit','descent','recent'},
'deception':	{'reception'},
'deceptive':	{'receptive'},
'decide':	{'decade','decided','decides','decode'},
'decided':	{'decide','decides','decoded'},
'decides':	{'decades','decide','decided'},
'deciding':	{'decoding'},
'decimal':	{'decimals'},
'decimals':	{'decimal'},
'decision':	{'decisions'},
'decisions':	{'decision'},
'deck':	{'beck','dec','decks','deco','desk','dick','dock','duck','heck','neck','peck'},
'decking':	{'docking','ducking'},
'decks':	{'deck','desks','docks','ducks','necks'},
'declaration':	{'declarations'},
'declarations':	{'declaration'},
'declare':	{'declared','declares'},
'declared':	{'declare','declares'},
'declares':	{'declare','declared'},
'decline':	{'declined','declines'},
'declined':	{'decline','declines'},
'declines':	{'decline','declined'},
'declining':	{'reclining'},
'deco':	{'dec','deck','decor','demo'},
'decode':	{'decade','decide','decoded','decoder'},
'decoded':	{'decided','decode','decoder'},
'decoder':	{'decode','decoded'},
'decoding':	{'deciding'},
'decompose':	{'decomposed'},
'decomposed':	{'decompose'},
'decor':	{'deco','decors'},
'decorate':	{'decorated'},
'decorated':	{'decorate'},
'decoration':	{'decorations'},
'decorations':	{'decoration'},
'decorator':	{'decorators'},
'decorators':	{'decorator'},
'decors':	{'decor'},
'decrease':	{'decreased','decreases'},
'decreased':	{'deceased','decrease','decreases'},
'decreases':	{'decrease','decreased'},
'decree':	{'decreed','decrees','degree'},
'decreed':	{'decree','decrees'},
'decrees':	{'decree','decreed','degrees'},
'dedicate':	{'dedicated','delicate'},
'dedicated':	{'dedicate'},
'dedication':	{'medication'},
'deduce':	{'deduced','deduces','deduct','deuce','reduce','seduce'},
'deduced':	{'deduce','deduces','deducted','reduced','seduced'},
'deduces':	{'deduce','deduced','reduces'},
'deducing':	{'reducing'},
'deduct':	{'deduce'},
'deducted':	{'deduced'},
'deduction':	{'deductions','reduction','seduction'},
'deductions':	{'deduction','reductions'},
'deed':	{'dead','deeds','deem','deep','deer','died','dyed','feed','heed','need','reed','seed','weed'},
'deeds':	{'deed','deems','feeds','leeds','needs','reeds','seeds','weeds'},
'deem':	{'deed','deems','deep','deer','seem'},
'deemed':	{'seemed'},
'deems':	{'deeds','deem','seems'},
'deep':	{'beep','deed','deem','deer','jeep','keep','peep','weep'},
'deepen':	{'deeper'},
'deeper':	{'deepen','keeper'},
'deer':	{'beer','dear','deed','deem','deep','deere','defer','der','deter','dyer','peer','seer'},
'deere':	{'deer'},
'default':	{'defaults'},
'defaults':	{'default'},
'defeat':	{'defeats','defect'},
'defeats':	{'defeat','defects'},
'defect':	{'defeat','defects','detect'},
'defective':	{'detective'},
'defects':	{'defeats','defect','detects'},
'defence':	{'defences','defense'},
'defences':	{'defence','defenses'},
'defend':	{'defends','depend'},
'defendant':	{'defendants','dependant'},
'defendants':	{'defendant','dependants'},
'defended':	{'defender','depended'},
'defender':	{'defended','defenders'},
'defenders':	{'defender'},
'defending':	{'depending'},
'defends':	{'defend','depends'},
'defense':	{'defence','defenses'},
'defenses':	{'defences','defense'},
'defer':	{'deafer','deer','deter','refer'},
'deference':	{'reference'},
'deferral':	{'referral'},
'deferred':	{'referred'},
'defiant':	{'deviant'},
'deficit':	{'deficits'},
'deficits':	{'deficit'},
'defied':	{'defies','defined','denied'},
'defies':	{'defied','defines','denies'},
'define':	{'defined','defines','refine'},
'defined':	{'defied','define','defines','refined'},
'defines':	{'defies','define','defined','refines'},
'defining':	{'refining'},
'definition':	{'definitions'},
'definitions':	{'definition'},
'deflection':	{'reflection'},
'deformation':	{'reformation'},
'deformed':	{'reformed'},
'defy':	{'deny'},
'defying':	{'denying'},
'degenerate':	{'regenerate'},
'degeneration':	{'regeneration'},
'degrade':	{'degraded'},
'degraded':	{'degrade'},
'degree':	{'decree','degrees'},
'degrees':	{'decrees','degree'},
'del':	{'bel','dal','de','dea','deal','deb','dec','deli','dell','den','der','des','dew','duel','eel','el','gel'},
'delay':	{'decay','delays','relay'},
'delayed':	{'decayed','relayed'},
'delaying':	{'decaying','relaying'},
'delays':	{'decays','delay','relays'},
'delectable':	{'detectable','selectable'},
'delegate':	{'delegated','delegates'},
'delegated':	{'delegate','delegates','relegated'},
'delegates':	{'delegate','delegated'},
'delegation':	{'delegations'},
'delegations':	{'delegation'},
'delete':	{'deleted'},
'deleted':	{'delete','depleted'},
'deletion':	{'deletions','depletion'},
'deletions':	{'deletion'},
'delhi':	{'deli','delphi'},
'deli':	{'dali','del','delhi','dell','devi','heli'},
'deliberation':	{'deliberations'},
'deliberations':	{'deliberation'},
'delicate':	{'dedicate'},
'delicatessen':	{'delicatessens'},
'delicatessens':	{'delicatessen'},
'delight':	{'delights'},
'delights':	{'delight'},
'delineate':	{'delineated'},
'delineated':	{'delineate'},
'deliver':	{'delivers','delivery'},
'delivers':	{'deliver','delivery'},
'delivery':	{'deliver','delivers'},
'dell':	{'bell','cell','deal','del','deli','dill','doll','dull','dwell','ell','fell','hell','sell','tell','well','yell'},
'delphi':	{'delhi'},
'delusion':	{'delusions'},
'delusions':	{'delusion'},
'demand':	{'demands','remand'},
'demanded':	{'remanded'},
'demands':	{'demand'},
'demented':	{'cemented'},
'demise':	{'devise'},
'demo':	{'deco','demon','demos','emo','memo'},
'demographic':	{'demographics'},
'demographics':	{'demographic'},
'demon':	{'daemon','damon','demo','demons','demos','devon','lemon'},
'demons':	{'demon','demos','lemons'},
'demonstrable':	{'demonstrably'},
'demonstrably':	{'demonstrable'},
'demonstrate':	{'demonstrated','demonstrates'},
'demonstrated':	{'demonstrate','demonstrates'},
'demonstrates':	{'demonstrate','demonstrated'},
'demonstration':	{'demonstrations'},
'demonstrations':	{'demonstration'},
'demonstrator':	{'demonstrators'},
'demonstrators':	{'demonstrator'},
'demos':	{'demo','demon','demons','memos'},
'den':	{'aden','ben','de','dea','dean','deb','dec','del','dent','deny','der','des','dew','din','don','dun','eden','en','fen','gen','hen','ken','men','pen','sen','ten','wen','yen','zen'},
'denial':	{'denials','dental'},
'denials':	{'denial'},
'denied':	{'defied','denier','denies'},
'denier':	{'denied','denies','denver'},
'denies':	{'defies','denied','denier'},
'denomination':	{'denominations'},
'denominations':	{'denomination'},
'denotation':	{'denotations'},
'denotations':	{'denotation'},
'denote':	{'denoted','denotes','devote'},
'denoted':	{'denote','denotes','devoted'},
'denotes':	{'denote','denoted','devotes'},
'denoting':	{'devoting'},
'denounce':	{'denounced','renounce'},
'denounced':	{'denounce'},
'dense':	{'sense','tense'},
'densely':	{'tensely'},
'dent':	{'bent','cent','debt','den','dents','deny','dont','gent','kent','lent','rent','sent','tent','vent','went'},
'dental':	{'denial','mental','rental'},
'dentist':	{'dentists'},
'dentists':	{'dentist'},
'dents':	{'cents','debts','dent','gents','rents','tents','vents'},
'denver':	{'denier'},
'deny':	{'defy','den','dent'},
'denying':	{'defying'},
'deodorant':	{'deodorants'},
'deodorants':	{'deodorant'},
'depart':	{'departs'},
'departed':	{'deported'},
'department':	{'departments'},
'departments':	{'department'},
'departs':	{'depart'},
'departure':	{'departures'},
'departures':	{'departure'},
'depend':	{'defend','depends'},
'dependant':	{'defendant','dependants','dependent'},
'dependants':	{'defendants','dependant','dependents'},
'depended':	{'defended'},
'dependence':	{'dependency'},
'dependency':	{'dependence'},
'dependent':	{'dependant','dependents'},
'dependents':	{'dependants','dependent'},
'depending':	{'defending'},
'depends':	{'defends','depend'},
'depict':	{'depicts'},
'depiction':	{'depictions'},
'depictions':	{'depiction'},
'depicts':	{'depict'},
'depleted':	{'deleted'},
'depletion':	{'deletion'},
'deployment':	{'deployments'},
'deployments':	{'deployment'},
'deported':	{'departed','reported'},
'deposit':	{'deposits'},
'deposition':	{'depositions'},
'depositions':	{'deposition'},
'depository':	{'repository'},
'deposits':	{'deposit'},
'depot':	{'depots'},
'depots':	{'depot'},
'deprecated':	{'depreciated'},
'depreciated':	{'deprecated'},
'depressed':	{'depresses','repressed'},
'depresses':	{'depressed'},
'depression':	{'repression'},
'depressive':	{'repressive'},
'deprivation':	{'derivation'},
'deprive':	{'deprived','derive'},
'deprived':	{'deprive','derived'},
'depriving':	{'deriving'},
'depth':	{'death','depths'},
'depths':	{'deaths','depth'},
'der':	{'aer','ber','dar','de','dea','dear','deb','dec','deer','del','den','des','dew','dr','dur','dyer','er','fer','ger','her','ker','oder','per','yer'},
'deregister':	{'deregisters'},
'deregisters':	{'deregister'},
'deregulated':	{'deregulates'},
'deregulates':	{'deregulated'},
'derivation':	{'deprivation','derivations'},
'derivations':	{'derivation'},
'derivative':	{'derivatives'},
'derivatives':	{'derivative'},
'derive':	{'deprive','derived','derives','drive'},
'derived':	{'deprived','derive','derives'},
'derives':	{'derive','derived','drives'},
'deriving':	{'depriving','driving'},
'derrick':	{'herrick'},
'des':	{'dds','de','dea','deb','dec','del','den','der','desk','dew','dies','dis','does','dos','dues','dyes','es','les','mes','res','yes'},
'descend':	{'descends','descent'},
'descendant':	{'descendants'},
'descendants':	{'descendant'},
'descends':	{'descend'},
'descent':	{'decent','descend'},
'describe':	{'described','describes'},
'described':	{'describe','describes'},
'describes':	{'describe','described'},
'description':	{'descriptions'},
'descriptions':	{'description'},
'descriptor':	{'descriptors'},
'descriptors':	{'descriptor'},
'desert':	{'deserts','dessert'},
'deserted':	{'deserved'},
'deserting':	{'deserving'},
'deserts':	{'desert','desserts'},
'deserve':	{'deserved','deserves','reserve'},
'deserved':	{'deserted','deserve','deserves','reserved'},
'deserves':	{'deserve','deserved','reserves'},
'deserving':	{'deserting','reserving'},
'design':	{'designs','resign'},
'designate':	{'designated','designates'},
'designated':	{'designate','designates'},
'designates':	{'designate','designated'},
'designation':	{'designations','resignation'},
'designations':	{'designation','resignations'},
'designed':	{'designer','resigned'},
'designer':	{'designed','designers'},
'designers':	{'designer'},
'designing':	{'resigning'},
'designs':	{'design','resigns'},
'desire':	{'desired','desires'},
'desired':	{'desire','desires'},
'desires':	{'desire','desired'},
'desist':	{'resist'},
'desk':	{'deck','des','desks','disk','dusk'},
'desks':	{'decks','desk','disks'},
'desktop':	{'desktops'},
'desktops':	{'desktop'},
'despair':	{'despairs'},
'despairs':	{'despair'},
'despise':	{'despised','despite'},
'despised':	{'despise'},
'despite':	{'despise','respite'},
'dessert':	{'desert','desserts'},
'desserts':	{'deserts','dessert'},
'destination':	{'destinations'},
'destinations':	{'destination'},
'destroy':	{'destroys'},
'destroyed':	{'destroyer'},
'destroyer':	{'destroyed'},
'destroys':	{'destroy'},
'detail':	{'details','detain','retail'},
'detailed':	{'detained'},
'detailing':	{'retailing'},
'details':	{'detail'},
'detain':	{'detail','retain'},
'detained':	{'detailed','detainee','retained'},
'detainee':	{'detained','detainees'},
'detainees':	{'detainee'},
'detect':	{'defect','detects'},
'detectable':	{'delectable'},
'detection':	{'detention'},
'detective':	{'defective','detectives'},
'detectives':	{'detective'},
'detector':	{'detectors'},
'detectors':	{'detector'},
'detects':	{'defects','detect'},
'detention':	{'detection','retention'},
'deter':	{'deer','defer','dexter','dieter','meter','peter'},
'detergent':	{'detergents','deterrent'},
'detergents':	{'detergent'},
'deteriorate':	{'deteriorated'},
'deteriorated':	{'deteriorate'},
'determinant':	{'determinants'},
'determinants':	{'determinant'},
'determination':	{'determinations'},
'determinations':	{'determination'},
'determine':	{'determined','determines'},
'determined':	{'determine','determines'},
'determines':	{'determine','determined'},
'deterrent':	{'detergent'},
'detour':	{'devour'},
'detract':	{'retract'},
'deuce':	{'deduce'},
'devaluation':	{'evaluation','revaluation'},
'develop':	{'develops'},
'developed':	{'developer'},
'developer':	{'developed','developers'},
'developers':	{'developer'},
'development':	{'developments'},
'developments':	{'development'},
'develops':	{'develop'},
'devi':	{'deli','devil','levi'},
'deviant':	{'defiant'},
'deviate':	{'deviated','deviates'},
'deviated':	{'deviate','deviates'},
'deviates':	{'deviate','deviated'},
'deviation':	{'deviations'},
'deviations':	{'deviation'},
'device':	{'devices','devise'},
'devices':	{'device'},
'devil':	{'devi','devils','evil'},
'devils':	{'devil','evils'},
'devise':	{'demise','device','devised','revise'},
'devised':	{'devise','revised'},
'devising':	{'revising'},
'devolution':	{'evolution','revolution'},
'devolved':	{'evolved'},
'devon':	{'demon'},
'devote':	{'denote','devoted','devotes'},
'devoted':	{'denoted','devote','devotes'},
'devotees':	{'devotes'},
'devotes':	{'denotes','devote','devoted','devotees'},
'devoting':	{'denoting'},
'devotion':	{'devotions'},
'devotions':	{'devotion'},
'devour':	{'detour','devout'},
'devout':	{'devour'},
'dew':	{'de','dea','deb','dec','del','den','der','des','drew','few','jew','mew','new','pew','sew','yew'},
'dewar':	{'dear'},
'dexter':	{'deter'},
'di':	{'ai','bi','ci','d','da','db','dc','dd','de','did','die','dig','dim','din','dip','dis','dix','dj','do','dp','dr','du','dy','gi','hi','i','ii','ji','ki','li','mi','ni','pi','qi','ri','si','ti','vi','wi','xi','yi'},
'diabetic':	{'diabetics'},
'diabetics':	{'diabetic'},
'diagnose':	{'diagnosed','diagnoses'},
'diagnosed':	{'diagnose','diagnoses'},
'diagnoses':	{'diagnose','diagnosed','diagnosis'},
'diagnosis':	{'diagnoses'},
'diagnostic':	{'diagnostics'},
'diagnostics':	{'diagnostic'},
'diagram':	{'diagrams'},
'diagrams':	{'diagram'},
'dial':	{'dal','deal','dials','diam','dias','dill','dual','rial','vial'},
'dialect':	{'dialects'},
'dialects':	{'dialect'},
'dialed':	{'dialer'},
'dialer':	{'dealer','dialed','diaper'},
'dialing':	{'dealing'},
'dialog':	{'dialogs'},
'dialogs':	{'dialog'},
'dialogue':	{'dialogues'},
'dialogues':	{'dialogue'},
'dials':	{'deals','dial','dias','vials'},
'diam':	{'dam','dial','dias','dim','dram','siam'},
'diameter':	{'diameters'},
'diameters':	{'diameter'},
'diamond':	{'diamonds'},
'diamonds':	{'diamond'},
'diana':	{'dana'},
'diaper':	{'dialer','diapers','draper'},
'diapers':	{'diaper'},
'diarrhea':	{'diarrhoea'},
'diarrhoea':	{'diarrhea'},
'dias':	{'bias','dial','dials','diam','dies','digs','dips','dis','divas'},
'dice':	{'diced','dick','dict','die','dime','dine','dire','dive','ice','lice','mice','nice','rice','vice'},
'diced':	{'dice','died','dined','dived','iced'},
'dick':	{'deck','dice','dict','dirk','disk','dock','duck','kick','lick','mick','nick','pick','rick','sick','tick','wick'},
'dickey':	{'hickey','mickey'},
'dict':	{'dice','dick','diet','dirt','duct'},
'dictate':	{'dictated','dictates'},
'dictated':	{'dictate','dictates'},
'dictates':	{'dictate','dictated'},
'dictator':	{'dictators'},
'dictators':	{'dictator'},
'did':	{'aid','bid','cid','dad','dd','di','didn','dido','die','died','dig','dim','din','dip','dis','dix','dmd','dod','dvd','hid','id','kid','lid','mid','rid'},
'didn':	{'did','dido','din'},
'dido':	{'did','didn','dildo','lido'},
'die':	{'de','di','dice','did','died','dies','diet','dig','dim','dime','din','dine','dip','dire','dis','dive','dix','doe','due','dye','ie','lie','pie','tie','vie'},
'died':	{'deed','diced','did','die','dies','diet','dined','dived','dried','dyed','lied','pied','tied'},
'dies':	{'des','dias','die','died','diet','diets','digs','dikes','dimes','dines','dips','dis','dives','does','dries','dues','dyes','lies','pies','ties'},
'diet':	{'dict','die','died','dies','diets','dirt','duet'},
'dieter':	{'deter'},
'diets':	{'dies','diet','duets'},
'diff':	{'duff','riff','tiff'},
'differ':	{'differs'},
'difference':	{'differences'},
'differences':	{'difference'},
'differential':	{'differentials'},
'differentials':	{'differential'},
'differentiate':	{'differentiated','differentiates'},
'differentiated':	{'differentiate','differentiates'},
'differentiates':	{'differentiate','differentiated'},
'differs':	{'differ'},
'difficult':	{'difficulty'},
'difficulty':	{'difficult'},
'diffuse':	{'diffused'},
'diffused':	{'diffuse'},
'dig':	{'big','dag','di','did','die','digs','dim','din','ding','dip','dis','dix','dog','dug','fig','gig','jig','pig','rig','sig','wig'},
'digest':	{'digests'},
'digests':	{'digest'},
'digger':	{'bigger','dagger','nigger'},
'digging':	{'rigging'},
'digit':	{'digits'},
'digits':	{'digit'},
'dignified':	{'signified'},
'digs':	{'dias','dies','dig','dips','dis','dogs','figs','gigs','pigs','rigs','wigs'},
'dikes':	{'bikes','dies','dimes','dines','dives','hikes','likes','mikes','pikes'},
'dilated':	{'diluted'},
'dilation':	{'dilution'},
'dildo':	{'dido','dildos'},
'dildos':	{'dildo'},
'dilemma':	{'dilemmas'},
'dilemmas':	{'dilemma'},
'dill':	{'bill','dell','dial','doll','drill','dull','fill','gill','hill','ill','kill','mill','pill','sill','till','will'},
'dilute':	{'diluted'},
'diluted':	{'dilated','dilute'},
'dilution':	{'dilation'},
'dim':	{'aim','dam','di','diam','did','die','dig','dime','din','dip','dis','dix','him','rim','vim'},
'dime':	{'dame','dice','die','dim','dimer','dimes','dine','dire','dive','dome','lime','mime','time'},
'dimension':	{'dimensions'},
'dimensions':	{'dimension'},
'dimer':	{'dime','dimes','diner','diver','timer'},
'dimes':	{'dies','dikes','dime','dimer','dines','dives','domes','times'},
'diminished':	{'diminishes'},
'diminishes':	{'diminished'},
'din':	{'bin','den','di','did','didn','die','dig','dim','dine','ding','dip','dis','dix','don','dun','fin','gin','in','kin','lin','min','odin','pin','qin','sin','tin','win','yin'},
'dinar':	{'dinars','diner'},
'dinars':	{'dinar','diners'},
'dine':	{'cine','dane','dice','die','dime','din','dined','diner','dines','ding','dire','dive','done','dune','fine','line','mine','nine','pine','sine','vine','wine','zine'},
'dined':	{'diced','died','dine','diner','dines','dived','fined','lined','mined','wined'},
'diner':	{'dimer','dinar','dine','dined','diners','dines','dinner','diver','finer','liner','miner'},
'diners':	{'dinars','diner','dines','dinners','divers','liners','miners'},
'dines':	{'dies','dikes','dimes','dine','dined','diner','diners','dives','dunes','fines','lines','mines','nines','pines','vines','wines','zines'},
'ding':	{'dang','dig','din','dine','doing','dong','dung','dying','king','ling','ming','ning','ping','qing','ring','sing','ting','wing','ying'},
'dining':	{'diving','lining','mining','wining'},
'dinner':	{'diner','dinners','inner','sinner','winner'},
'dinners':	{'diners','dinner','sinners','winners'},
'dinosaur':	{'dinosaurs'},
'dinosaurs':	{'dinosaur'},
'diode':	{'diodes'},
'diodes':	{'diode'},
'dior':	{'door'},
'dip':	{'di','did','die','dig','dim','din','dips','dis','dix','dp','drip','hip','ip','kip','lip','nip','pip','rip','sip','tip','vip','yip','zip'},
'diploma':	{'diplomas','diplomat'},
'diplomas':	{'diploma','diplomat','diplomats'},
'diplomat':	{'diploma','diplomas','diplomats'},
'diplomats':	{'diplomas','diplomat'},
'dipped':	{'ripped','tipped','zipped'},
'dipping':	{'dripping','ripping','sipping','tipping'},
'dips':	{'dias','dies','digs','dip','dis','hips','lips','mips','rips','sips','tips','zips'},
'dire':	{'dare','dice','die','dime','dine','dirk','dirt','dive','eire','fire','hire','ire','lire','sire','tire','wire'},
'direct':	{'directs'},
'direction':	{'directions'},
'directions':	{'direction'},
'directive':	{'directives'},
'directives':	{'directive'},
'director':	{'directors','directory'},
'directors':	{'director','directory'},
'directory':	{'director','directors'},
'directs':	{'direct'},
'dirk':	{'dark','dick','dire','dirt','disk','dork','kirk'},
'dirt':	{'dart','dict','diet','dire','dirk','dirty'},
'dirty':	{'dirt'},
'dis':	{'dds','des','di','dias','did','die','dies','dig','digs','dim','din','dip','dips','disc','dish','disk','dix','dos','his','is','sis'},
'disable':	{'disabled','disables'},
'disabled':	{'disable','disables'},
'disables':	{'disable','disabled'},
'disadvantage':	{'disadvantaged','disadvantages'},
'disadvantaged':	{'disadvantage','disadvantages'},
'disadvantages':	{'disadvantage','disadvantaged'},
'disagree':	{'disagreed','disagrees'},
'disagreed':	{'disagree','disagrees'},
'disagreement':	{'disagreements'},
'disagreements':	{'disagreement'},
'disagrees':	{'disagree','disagreed'},
'disappear':	{'disappears'},
'disappearance':	{'disappearances'},
'disappearances':	{'disappearance'},
'disappears':	{'disappear'},
'disappoint':	{'disappoints'},
'disappointment':	{'disappointments'},
'disappointments':	{'disappointment'},
'disappoints':	{'disappoint'},
'disapprove':	{'disapproved','disapproves'},
'disapproved':	{'disapprove','disapproves'},
'disapproves':	{'disapprove','disapproved'},
'disassociate':	{'disassociated'},
'disassociated':	{'disassociate'},
'disaster':	{'disasters'},
'disasters':	{'disaster'},
'disbursement':	{'disbursements'},
'disbursements':	{'disbursement'},
'disc':	{'dis','disco','discs','dish','disk'},
'discard':	{'discards','discord'},
'discards':	{'discard'},
'discharge':	{'discharged','discharges'},
'discharged':	{'discharge','discharges'},
'discharges':	{'discharge','discharged'},
'disciple':	{'disciples'},
'disciples':	{'disciple'},
'discipline':	{'disciplined','disciplines'},
'disciplined':	{'discipline','disciplines'},
'disciplines':	{'discipline','disciplined'},
'disclaim':	{'disclaims'},
'disclaimer':	{'disclaimers'},
'disclaimers':	{'disclaimer'},
'disclaims':	{'disclaim'},
'disclose':	{'disclosed','discloses'},
'disclosed':	{'disclose','discloses'},
'discloses':	{'disclose','disclosed'},
'disclosure':	{'disclosures'},
'disclosures':	{'disclosure'},
'disco':	{'cisco','disc','discos','discs'},
'discontinue':	{'discontinued'},
'discontinued':	{'discontinue'},
'discord':	{'discard'},
'discos':	{'disco','discs','discus'},
'discount':	{'discounts','viscount'},
'discounts':	{'discount'},
'discourage':	{'discouraged'},
'discouraged':	{'discourage'},
'discourse':	{'discourses'},
'discourses':	{'discourse'},
'discover':	{'discovers','discovery'},
'discovers':	{'discover','discovery'},
'discovery':	{'discover','discovers'},
'discriminate':	{'discriminated','discriminates'},
'discriminated':	{'discriminate','discriminates'},
'discriminates':	{'discriminate','discriminated'},
'discs':	{'disc','disco','discos','discus','disks'},
'discus':	{'discos','discs','discuss'},
'discuss':	{'discus'},
'discussed':	{'discusses'},
'discusses':	{'discussed'},
'discussion':	{'discussions'},
'discussions':	{'discussion'},
'disease':	{'diseased','diseases'},
'diseased':	{'disease','diseases'},
'diseases':	{'disease','diseased'},
'disestablished':	{'disestablishes'},
'disestablishes':	{'disestablished'},
'disguise':	{'disguised'},
'disguised':	{'disguise'},
'disgust':	{'disgusts'},
'disgusts':	{'disgust'},
'dish':	{'dash','dis','disc','disk','fish','wish'},
'dishes':	{'dashes','fishes','wishes'},
'dishonest':	{'dishonesty'},
'dishonesty':	{'dishonest'},
'dishwasher':	{'dishwashers'},
'dishwashers':	{'dishwasher'},
'disk':	{'desk','dick','dirk','dis','disc','dish','disks','dusk','risk'},
'disks':	{'desks','discs','disk','risks'},
'dislike':	{'disliked','dislikes'},
'disliked':	{'dislike','dislikes'},
'dislikes':	{'dislike','disliked'},
'dismal':	{'dismay','distal'},
'dismantle':	{'dismantled'},
'dismantled':	{'dismantle'},
'dismay':	{'dismal'},
'dismissed':	{'dismisses'},
'dismisses':	{'dismissed'},
'disorder':	{'disorders'},
'disorders':	{'disorder'},
'dispatched':	{'dispatcher','dispatches'},
'dispatcher':	{'dispatched','dispatches'},
'dispatches':	{'dispatched','dispatcher'},
'dispense':	{'dispensed','dispenser','disperse'},
'dispensed':	{'dispense','dispenser','dispersed'},
'dispenser':	{'dispense','dispensed','dispensers'},
'dispensers':	{'dispenser'},
'disperse':	{'dispense','dispersed'},
'dispersed':	{'dispensed','disperse'},
'displace':	{'displaced','displaces','misplace'},
'displaced':	{'displace','displaces','displayed','misplaced'},
'displacement':	{'displacements'},
'displacements':	{'displacement'},
'displaces':	{'displace','displaced'},
'displacing':	{'displaying'},
'display':	{'displays'},
'displayed':	{'displaced'},
'displaying':	{'displacing'},
'displays':	{'display'},
'displease':	{'displeased'},
'displeased':	{'displease'},
'disposable':	{'disposables'},
'disposables':	{'disposable'},
'dispose':	{'disposed','disposes'},
'disposed':	{'dispose','disposes'},
'disposes':	{'dispose','disposed'},
'disposition':	{'dispositions'},
'dispositions':	{'disposition'},
'dispute':	{'disputed','disputes'},
'disputed':	{'dispute','disputes'},
'disputes':	{'dispute','disputed'},
'disregard':	{'disregards'},
'disregards':	{'disregard'},
'disruption':	{'disruptions'},
'disruptions':	{'disruption'},
'dissatisfied':	{'dissatisfies'},
'dissatisfies':	{'dissatisfied'},
'disseminate':	{'disseminated'},
'disseminated':	{'disseminate'},
'dissertation':	{'dissertations'},
'dissertations':	{'dissertation'},
'dissident':	{'dissidents'},
'dissidents':	{'dissident'},
'dissolve':	{'dissolved','dissolves'},
'dissolved':	{'dissolve','dissolves'},
'dissolves':	{'dissolve','dissolved'},
'distal':	{'dismal'},
'distance':	{'distanced','distances'},
'distanced':	{'distance','distances'},
'distances':	{'distance','distanced'},
'distinction':	{'distinctions'},
'distinctions':	{'distinction'},
'distinguished':	{'distinguishes'},
'distinguishes':	{'distinguished'},
'distort':	{'distorts'},
'distortion':	{'distortions'},
'distortions':	{'distortion'},
'distorts':	{'distort'},
'distract':	{'district'},
'distraction':	{'distractions'},
'distractions':	{'distraction'},
'distress':	{'mistress'},
'distribute':	{'distributed','distributes'},
'distributed':	{'distribute','distributes'},
'distributes':	{'distribute','distributed'},
'distribution':	{'distributions'},
'distributions':	{'distribution'},
'distributor':	{'distributors'},
'distributors':	{'distributor'},
'district':	{'distract','districts'},
'districts':	{'district'},
'distrust':	{'mistrust'},
'disturb':	{'disturbs'},
'disturbance':	{'disturbances'},
'disturbances':	{'disturbance'},
'disturbs':	{'disturb'},
'ditch':	{'bitch','dutch','fitch','hitch','itch','pitch','witch'},
'ditched':	{'ditches','pitched'},
'ditches':	{'bitches','ditched','pitches','witches'},
'ditching':	{'bitching','itching','pitching'},
'diva':	{'divas','dive','iva','viva'},
'divas':	{'dias','diva','dives'},
'dive':	{'dice','die','dime','dine','dire','diva','dived','diver','dives','dove','drive','five','give','hive','jive','live'},
'dived':	{'diced','died','dined','dive','diver','dives','lived'},
'diver':	{'dimer','diner','dive','dived','divers','divert','dives','dover','driver','giver','liver','river'},
'divers':	{'diners','diver','diverse','divert','dives','drivers','rivers'},
'diverse':	{'divers'},
'diversified':	{'diversifies'},
'diversifies':	{'diversified'},
'diversify':	{'diversity'},
'diversion':	{'diversions'},
'diversions':	{'diversion'},
'diversity':	{'diversify'},
'divert':	{'diver','divers'},
'dives':	{'dies','dikes','dimes','dines','divas','dive','dived','diver','divers','doves','drives','fives','gives','hives','ives','lives','wives'},
'divide':	{'divided','divider','divides','divine'},
'divided':	{'divide','dividend','divider','divides'},
'dividend':	{'divided','dividends'},
'dividends':	{'dividend'},
'divider':	{'divide','divided','dividers','divides'},
'dividers':	{'divider','divides'},
'divides':	{'divide','divided','divider','dividers'},
'divine':	{'divide','diving'},
'diving':	{'dining','divine','driving','giving','living'},
'division':	{'divisions'},
'divisions':	{'division'},
'divorce':	{'divorced','divorces'},
'divorced':	{'divorce','divorces'},
'divorces':	{'divorce','divorced'},
'dix':	{'di','did','die','dig','dim','din','dip','dis','fix','ix','mix','nix','pix','six','xix'},
'dixie':	{'pixie'},
'dj':	{'adj','d','da','db','dc','dd','de','di','do','dp','dr','du','dy','j','nj'},
'dmd':	{'dad','dd','did','dmz','dod','dvd','md'},
'dmz':	{'dmd'},
'dna':	{'ana','da','dana','dea','dona','na','rna','una'},
'do':	{'ado','co','d','da','db','dc','dd','de','di','dj','doc','dod','doe','dog','don','dos','dot','dp','dr','du','duo','dy','fo','go','ho','io','ko','lo','mo','no','o','po','so','to','wo'},
'doc':	{'dc','dec','do','dock','docs','dod','doe','dog','don','dos','dot'},
'dock':	{'bock','cock','deck','dick','doc','docks','docs','dork','duck','jock','lock','mock','rock','sock'},
'docked':	{'docket','ducked','locked','mocked','rocked'},
'docket':	{'docked','pocket','rocket','socket'},
'docking':	{'decking','ducking','locking','mocking','rocking'},
'docks':	{'cocks','decks','dock','docs','ducks','jocks','locks','rocks','socks'},
'docs':	{'doc','dock','docks','does','dogs','dos','dots'},
'doctor':	{'doctors'},
'doctors':	{'doctor'},
'doctrine':	{'doctrines'},
'doctrines':	{'doctrine'},
'document':	{'documents'},
'documents':	{'document'},
'dod':	{'bod','cod','dad','dd','did','dmd','do','doc','doe','dog','don','dos','dot','dvd','god','mod','nod','od','pod','rod','sod','tod'},
'dodge':	{'dodger','dodgy','lodge'},
'dodger':	{'dodge'},
'dodging':	{'lodging'},
'dodgy':	{'dodge','doggy'},
'doe':	{'de','die','do','doc','dod','does','dog','dole','dome','don','done','dope','dos','dose','dot','dove','due','dye','foe','hoe','poe','roe','toe','woe'},
'does':	{'des','dies','docs','doe','doesn','dogs','domes','dos','doses','dots','doves','dues','dyes','foes','goes','hoes','toes','woes'},
'doesn':	{'does'},
'dog':	{'bog','cog','dag','dig','do','doc','dod','doe','dogs','don','dong','dos','dot','dug','fog','hog','jog','log'},
'dogged':	{'bogged','logged'},
'doggy':	{'dodgy','foggy'},
'dogs':	{'digs','docs','does','dog','dos','dots','hogs','logs'},
'doha':	{'dona'},
'doing':	{'ding','dong','doping','dosing','dying','going'},
'dolby':	{'dolly'},
'dole':	{'cole','dale','doe','doll','dome','done','dope','dose','dove','hole','mole','ole','pole','role','sole'},
'doll':	{'boll','dell','dill','dole','dolls','dolly','dull','moll','poll','roll','toll'},
'dollar':	{'collar','dollars'},
'dollars':	{'collars','dollar'},
'dolls':	{'doll','dolly','polls','rolls','tolls'},
'dolly':	{'dolby','doll','dolls','folly','holly','jolly','molly'},
'dolor':	{'color','donor','door'},
'domain':	{'domains'},
'domains':	{'domain'},
'dome':	{'come','dame','dime','doe','dole','domes','done','dope','dose','dove','home','nome','rome','some','tome'},
'domes':	{'comes','dimes','does','dome','doses','doves','homes'},
'domestic':	{'domestics'},
'domesticate':	{'domesticated'},
'domesticated':	{'domesticate'},
'domestics':	{'domestic'},
'dominate':	{'dominated','dominates','nominate'},
'dominated':	{'dominate','dominates','nominated'},
'dominates':	{'dominate','dominated'},
'dominating':	{'nominating'},
'domination':	{'nomination'},
'domingo':	{'domino'},
'dominic':	{'dominica','dominick'},
'dominica':	{'dominic','dominican','dominick'},
'dominican':	{'dominica'},
'dominick':	{'dominic','dominica'},
'domino':	{'domingo'},
'don':	{'con','den','din','do','doc','dod','doe','dog','dona','done','dong','dont','dos','dot','down','dun','hon','ion','mon','non','on','ron','son','ton','von','won','yon'},
'dona':	{'dana','dna','doha','don','done','dong','donna','dont','mona'},
'donate':	{'donated','donates'},
'donated':	{'donate','donates'},
'donates':	{'donate','donated'},
'donation':	{'donations'},
'donations':	{'donation'},
'done':	{'bone','cone','dane','dine','doe','dole','dome','don','dona','dong','donne','dont','dope','dose','dove','drone','dune','gone','hone','lone','none','one','tone','zone'},
'dong':	{'bong','dang','ding','dog','doing','don','dona','done','dont','dung','gong','long','pong','song'},
'dongle':	{'dangle'},
'donkey':	{'donkeys','monkey'},
'donkeys':	{'donkey','monkeys'},
'donna':	{'dona','donne','gonna'},
'donne':	{'done','donna','tonne'},
'donor':	{'dolor','donors','door','honor'},
'donors':	{'donor','doors','honors'},
'dont':	{'cont','dent','don','dona','done','dong','donut','dot','font','ont','wont'},
'donut':	{'dont','donuts'},
'donuts':	{'donut'},
'doodle':	{'noodle','poodle'},
'doom':	{'boom','door','dorm','loom','room','zoom'},
'door':	{'dior','dolor','donor','doom','doors','moor','poor'},
'doors':	{'donors','door','moors'},
'dope':	{'cope','doe','dole','dome','done','doped','dose','dove','hope','pope','rope'},
'doped':	{'dope','hoped'},
'doping':	{'coping','doing','dosing','hoping'},
'doris':	{'dorms'},
'dork':	{'cork','dark','dirk','dock','dorm','fork','pork','work','york'},
'dorm':	{'doom','dork','dorms','form','norm','worm'},
'dorms':	{'doris','dorm','forms','norms','worms'},
'dos':	{'cos','dds','des','dis','do','doc','docs','dod','doe','does','dog','dogs','don','dose','dot','dots','hos','nos','os','sos'},
'dosage':	{'dosages','osage'},
'dosages':	{'dosage'},
'dose':	{'bose','doe','dole','dome','done','dope','dos','doses','dove','hose','lose','nose','pose','rose'},
'doses':	{'does','domes','dose','doves','hoses','loses','moses','noses','poses','roses'},
'dosing':	{'doing','doping','losing','posing'},
'dot':	{'bot','cot','dat','ddt','do','doc','dod','doe','dog','don','dont','dos','doth','dots','got','hot','lot','mot','not','pot','rot','sot','tot','wot'},
'doth':	{'both','dot','dots','goth','moth','roth'},
'dots':	{'bots','cots','docs','does','dogs','dos','dot','doth','lots','pots','rots','tots'},
'dotted':	{'potted','rotted'},
'double':	{'doubled','doubles','doubly','rouble'},
'doubled':	{'double','doubles','doubted'},
'doubles':	{'double','doubled'},
'doubling':	{'doubting'},
'doubly':	{'double'},
'doubt':	{'doubts'},
'doubted':	{'doubled'},
'doubting':	{'doubling'},
'doubts':	{'doubt'},
'dough':	{'bough','cough','lough','rough','tough'},
'douglas':	{'douglass'},
'douglass':	{'douglas'},
'dove':	{'cove','dive','doe','dole','dome','done','dope','dose','dover','doves','drove','love','move','rove','wove'},
'dover':	{'cover','diver','dove','doves','hover','lover','mover','over','rover'},
'doves':	{'dives','does','domes','doses','dove','dover','loves','moves'},
'down':	{'dawn','don','downs','drown','gown','own','sown','town'},
'downed':	{'dawned','downer','drowned','owned'},
'downer':	{'downed','downers','owner'},
'downers':	{'downer','owners'},
'downgrade':	{'downgraded'},
'downgraded':	{'downgrade'},
'downing':	{'drowning','owning'},
'download':	{'downloads'},
'downloads':	{'download'},
'downs':	{'down','drowns','gowns','owns','towns'},
'downward':	{'downwards'},
'downwards':	{'downward'},
'dozen':	{'dozens'},
'dozens':	{'dozen'},
'dp':	{'adp','d','da','db','dc','dd','de','di','dip','dj','do','dr','du','dy','edp','gdp','gp','hp','ip','kp','lp','mp','np','op','p','up'},
'dr':	{'ar','br','cr','d','da','dar','db','dc','dd','de','der','di','dj','do','dp','dry','du','dur','dy','er','fdr','fr','hr','ir','jr','kr','lr','mr','or','pr','qr','r','sr','ur','yr','zr'},
'draft':	{'craft','daft','drafts','drift','graft','kraft','raft'},
'drafted':	{'crafted','drifted'},
'drafting':	{'crafting','drifting','grafting','rafting'},
'drafts':	{'crafts','draft','drifts','grafts'},
'drag':	{'brag','dag','drags','dram','draw','drug','rag'},
'dragged':	{'ragged'},
'dragging':	{'bragging'},
'dragon':	{'dragons'},
'dragons':	{'dragon'},
'drags':	{'drag','draws','drugs','rags'},
'drain':	{'brain','drains','drawn','grain','rain','train'},
'drained':	{'grained','rained','trained'},
'draining':	{'raining','training'},
'drains':	{'brains','drain','grains','rains','trains'},
'drake':	{'brake','rake'},
'dram':	{'cram','dam','diam','drag','drama','draw','dream','drum','gram','ram','tram'},
'drama':	{'dram','dramas','rama'},
'dramas':	{'drama'},
'dramatisation':	{'dramatisations','dramatization'},
'dramatisations':	{'dramatisation','dramatizations'},
'dramatise':	{'dramatised','dramatises','dramatist','dramatize'},
'dramatised':	{'dramatise','dramatises','dramatized'},
'dramatises':	{'dramatise','dramatised','dramatists','dramatizes'},
'dramatising':	{'dramatizing'},
'dramatist':	{'dramatise','dramatists'},
'dramatists':	{'dramatises','dramatist'},
'dramatization':	{'dramatisation','dramatizations'},
'dramatizations':	{'dramatisations','dramatization'},
'dramatize':	{'dramatise','dramatized','dramatizes'},
'dramatized':	{'dramatised','dramatize','dramatizes'},
'dramatizes':	{'dramatises','dramatize','dramatized'},
'dramatizing':	{'dramatising'},
'drank':	{'crank','drink','drunk','frank','prank','rank'},
'draped':	{'draper','drapes','raped'},
'draper':	{'diaper','draped','drapery','drapes','drawer'},
'drapery':	{'draper'},
'drapes':	{'draped','draper','grapes','rapes'},
'draught':	{'drought','fraught'},
'draw':	{'drag','dram','drawn','draws','drew','raw'},
'drawback':	{'drawbacks'},
'drawbacks':	{'drawback'},
'drawer':	{'draper','drawers','rawer'},
'drawers':	{'drawer'},
'drawing':	{'drawings'},
'drawings':	{'drawing'},
'drawn':	{'dawn','drain','draw','draws','drown'},
'draws':	{'drags','draw','drawn'},
'dread':	{'bread','dead','dream','read','tread'},
'dreaded':	{'dreamed'},
'dream':	{'cream','dram','dread','dreams','dreamt','dreamy'},
'dreamed':	{'creamed','dreaded','dreamer'},
'dreamer':	{'creamer','dreamed','dreamers'},
'dreamers':	{'dreamer'},
'dreaming':	{'creaming'},
'dreams':	{'creams','dream','dreamt','dreamy'},
'dreamt':	{'dream','dreams','dreamy'},
'dreamy':	{'creamy','dream','dreams','dreamt','dreary'},
'dreary':	{'dreamy'},
'dredge':	{'drudge'},
'dress':	{'press'},
'dressed':	{'dresser','dresses','pressed'},
'dresser':	{'dressed','dressers','dresses'},
'dressers':	{'dresser','dresses'},
'dresses':	{'dressed','dresser','dressers','presses'},
'dressing':	{'dressings','pressing'},
'dressings':	{'dressing'},
'drew':	{'brew','crew','dew','draw','grew'},
'dried':	{'cried','died','drier','dries','fried','tried'},
'drier':	{'dried','dries','driver','dryer','trier'},
'dries':	{'aries','cries','dies','dried','drier','driest','drives','fries','tries'},
'driest':	{'dries','priest'},
'drift':	{'draft','drifts','rift'},
'drifted':	{'drafted'},
'drifting':	{'drafting'},
'drifts':	{'drafts','drift'},
'drill':	{'brill','dill','drills','grill'},
'drilled':	{'grilled'},
'drilling':	{'grilling'},
'drills':	{'drill','frills','grills'},
'drink':	{'brink','drank','drinks','drunk','rink'},
'drinker':	{'drinkers'},
'drinkers':	{'drinker'},
'drinks':	{'drink'},
'drip':	{'dip','drop','grip','rip','trip'},
'dripping':	{'dipping','dropping','gripping','ripping','tripping'},
'drive':	{'derive','dive','driven','driver','drives','drove'},
'driven':	{'drive','driver','drives'},
'driver':	{'diver','drier','drive','driven','drivers','drives','river'},
'drivers':	{'divers','driver','drives','rivers'},
'drives':	{'derives','dives','dries','drive','driven','driver','drivers'},
'driveway':	{'driveways'},
'driveways':	{'driveway'},
'driving':	{'deriving','diving'},
'drone':	{'done','drove','krone','prone'},
'drop':	{'crop','drip','drops','prop'},
'droplet':	{'droplets'},
'droplets':	{'droplet'},
'dropout':	{'dropouts'},
'dropouts':	{'dropout'},
'dropped':	{'cropped'},
'dropping':	{'cropping','dripping'},
'drops':	{'crops','drop','props'},
'drought':	{'brought','draught','droughts','wrought'},
'droughts':	{'drought'},
'drove':	{'dove','drive','drone','grove','prove','rove','trove'},
'drown':	{'brown','crown','down','drawn','drowns','frown','grown'},
'drowned':	{'browned','crowned','downed','frowned'},
'drowning':	{'browning','crowning','downing'},
'drowns':	{'browns','crowns','downs','drown'},
'drudge':	{'dredge','grudge'},
'drug':	{'drag','drugs','drum','dug','rug'},
'drugs':	{'drags','drug','drums','rugs'},
'drum':	{'dram','drug','drums','rum'},
'drummed':	{'drummer'},
'drummer':	{'drummed','drummers'},
'drummers':	{'drummer'},
'drums':	{'drugs','drum'},
'drunk':	{'drank','drink','dunk','trunk'},
'dry':	{'cry','day','dr','dy','fry','try'},
'dryer':	{'drier','dryers','dyer','fryer'},
'dryers':	{'dryer','fryers'},
'drying':	{'crying','dying','frying','trying'},
'du':	{'au','cu','d','da','db','dc','dd','de','di','dj','do','dp','dr','dub','due','dug','duh','dun','duo','dur','dy','edu','eu','gu','ju','lu','mu','nu','pu','ru','su','u','wu','zu'},
'dual':	{'dal','deal','dial','duel','dull'},
'duality':	{'quality'},
'dub':	{'cub','dab','db','deb','du','due','dug','duh','dumb','dun','duo','dur','hub','pub','rub','sub','tub'},
'dubbed':	{'rubbed'},
'duck':	{'buck','deck','dick','dock','ducks','ducky','duct','dunk','dusk','fuck','huck','luck','muck','puck','suck','tuck'},
'ducked':	{'docked','sucked','tucked'},
'ducking':	{'decking','docking','fucking','sucking'},
'ducks':	{'bucks','decks','docks','duck','ducky','ducts','sucks'},
'ducky':	{'duck','ducks','lucky'},
'duct':	{'dict','duck','ducts','duet','dust'},
'ducts':	{'ducks','duct','duets','dusts'},
'dude':	{'dudes','due','duke','dune','jude','nude','rude'},
'dudes':	{'dude','dues','dunes','nudes'},
'due':	{'cue','de','die','doe','du','dub','dude','duel','dues','duet','dug','duh','duke','dun','dune','duo','dur','dye','hue','que','rue','sue'},
'duel':	{'del','dual','due','dues','duet','dull','fuel'},
'dues':	{'cues','des','dies','does','dudes','due','duel','duet','duets','dunes','dyes','hues','tues'},
'duet':	{'diet','duct','due','duel','dues','duets','dust','duvet'},
'duets':	{'diets','ducts','dues','duet','dusts'},
'duff':	{'buff','cuff','diff','huff','puff','ruff'},
'dug':	{'aug','bug','dag','dig','dog','drug','du','dub','due','duh','dun','dung','duo','dur','hug','jug','lug','mug','pug','rug','tug'},
'duh':	{'du','dub','due','dug','dun','duo','dur','huh','uh'},
'duke':	{'dude','due','dune','luke','nuke','puke'},
'dull':	{'bull','dell','dill','doll','dual','duel','duly','full','gull','hull','mull','null','pull'},
'duller':	{'dulles','fuller','muller'},
'dulles':	{'duller','dullest'},
'dullest':	{'dulles','fullest'},
'dullness':	{'fullness'},
'duly':	{'dull','duty','july'},
'dumas':	{'dumps'},
'dumb':	{'dub','dump','numb'},
'dummy':	{'mummy','tummy','yummy'},
'dump':	{'bump','damp','dumb','dumps','hump','jump','lump','pump','sump'},
'dumped':	{'bumped','jumped','pumped'},
'dumping':	{'bumping','damping','humping','jumping','pumping'},
'dumps':	{'bumps','dumas','dump','humps','jumps','lumps','pumps'},
'dun':	{'bun','den','din','don','du','dub','due','dug','duh','dune','dung','dunk','duo','dur','fun','gun','hun','nun','pun','run','sun','un'},
'dune':	{'dane','dine','done','dude','due','duke','dun','dunes','dung','dunk','june','rune','tune'},
'dunes':	{'dines','dudes','dues','dune','runes','tunes'},
'dung':	{'dang','ding','dong','dug','dun','dune','dunk','hung','jung','lung','rung','sung'},
'dungeon':	{'dungeons'},
'dungeons':	{'dungeon'},
'dunk':	{'bunk','drunk','duck','dun','dune','dung','dusk','funk','hunk','junk','punk','sunk'},
'duo':	{'do','du','dub','due','dug','duh','dun','dur','luo'},
'duplicate':	{'duplicated','duplicates'},
'duplicated':	{'duplicate','duplicates'},
'duplicates':	{'duplicate','duplicated'},
'duplicator':	{'duplicators'},
'duplicators':	{'duplicator'},
'dur':	{'bur','cur','dar','der','dr','du','dub','due','dug','duh','dun','duo','fur','our','ur'},
'durable':	{'curable'},
'duration':	{'durations'},
'durations':	{'duration'},
'durban':	{'urban'},
'during':	{'curing','daring','turing'},
'dusk':	{'desk','disk','duck','dunk','dust','musk','rusk'},
'dust':	{'bust','duct','duet','dusk','dusts','dusty','gust','just','lust','must','rust'},
'dusted':	{'busted','duster','ousted','rusted'},
'duster':	{'buster','custer','dusted','dusters','luster','muster'},
'dusters':	{'busters','duster'},
'dusting':	{'busting','rusting'},
'dusts':	{'ducts','duets','dust','dusty','gusts','rusts'},
'dusty':	{'busty','dust','dusts','duty','lusty','rusty'},
'dutch':	{'butch','ditch','hutch'},
'duties':	{'cuties'},
'duty':	{'duly','dusty'},
'duvet':	{'duet'},
'dvd':	{'dad','dd','did','dmd','dod','vd'},
'dwarf':	{'dwarfs'},
'dwarfs':	{'dwarf'},
'dwell':	{'dell','dwells','dwelt','swell','well'},
'dwelling':	{'dwellings','swelling'},
'dwellings':	{'dwelling'},
'dwells':	{'dwell','swells','wells'},
'dwelt':	{'dwell','welt'},
'dy':	{'by','d','da','day','db','dc','dd','de','di','dj','do','dp','dr','dry','du','dye','ky','ly','my','ny','wy','y'},
'dye':	{'aye','bye','de','die','doe','due','dy','dyed','dyer','dyes','eye','rye','wye','ye'},
'dyed':	{'deed','died','dye','dyer','dyes','eyed'},
'dyeing':	{'dying','eyeing'},
'dyer':	{'deer','der','dryer','dye','dyed','dyes','yer'},
'dyes':	{'ayes','des','dies','does','dues','dye','dyed','dyer','eyes','yes'},
'dying':	{'ding','doing','drying','dyeing','lying','tying','vying','ying'},
'dynamic':	{'dynamics'},
'dynamics':	{'dynamic'},
'e':	{'a','b','be','c','ce','d','de','ea','eb','ec','ed','ee','eh','el','em','en','er','es','et','eu','ev','ex','f','fe','g','ge','h','he','i','ie','j','k','l','le','me','ne','o','p','pe','q','r','se','t','te','u','v','ve','w','we','x','xe','y','ye','z'},
'ea':	{'a','ba','ca','da','dea','e','ear','eat','eb','ec','ed','eda','ee','eh','el','em','en','epa','er','era','es','et','eta','eu','ev','ex','fa','ga','ha','ia','ka','la','lea','ma','na','pa','pea','ra','sa','sea','ta','tea','va','wa','ya','yea','za'},
'each':	{'bach','beach','etch','leach','mach','peach','reach','teach'},
'eager':	{'eater','lager','meager','pager','wager'},
'eagle':	{'beagle'},
'ear':	{'ar','bar','bear','car','dar','dear','ea','earl','earn','ears','eat','er','err','far','fear','gar','gear','hear','jar','lear','mar','near','oar','par','pear','rear','tar','tear','var','war','wear','year'},
'eared':	{'bared','cared','dared','earned','eased','erred','fared','feared','geared','pared','reared'},
'earl':	{'ear','early','earn','ears','pearl'},
'early':	{'dearly','earl','nearly','yearly'},
'earn':	{'barn','darn','ear','earl','earns','ears','learn','warn','yarn'},
'earned':	{'eared','learned','warned'},
'earners':	{'learners'},
'earning':	{'earnings','earring','learning','warning','yearning'},
'earnings':	{'earning','earrings','warnings'},
'earns':	{'barns','earn','ears','learns','warns','yarns'},
'earring':	{'barring','earning','earrings','warring'},
'earrings':	{'earnings','earring'},
'ears':	{'bars','bears','cars','dears','ear','earl','earn','earns','eats','fears','gears','hears','jars','mars','nears','oars','pears','tears','wars','wears','years'},
'earth':	{'barth','earthy','hearth'},
'earthly':	{'earthy'},
'earthquake':	{'earthquakes'},
'earthquakes':	{'earthquake'},
'earthy':	{'earth','earthly'},
'ease':	{'base','case','cease','eased','easel','eases','east','easy','else','erase','ese','lease','tease','vase'},
'eased':	{'based','ceased','eared','ease','easel','eases','erased','leased','teased'},
'easel':	{'basel','ease','eased','eases','weasel'},
'easement':	{'basement','easements'},
'easements':	{'easement'},
'eases':	{'bases','cases','ceases','ease','eased','easel','gases','leases','vases'},
'easier':	{'easter'},
'easing':	{'basing','casing','ceasing','eating','erasing','leasing','teasing'},
'east':	{'beast','cast','ease','easy','eat','est','fast','feast','hast','last','least','mast','past','vast','yeast'},
'easter':	{'aster','caster','easier','eastern','eater','ester','faster','master','raster'},
'eastern':	{'easter'},
'easy':	{'ease','east'},
'eat':	{'at','bat','beat','cat','dat','ea','ear','east','eats','eft','est','et','fat','feat','hat','heat','kat','lat','mat','meat','neat','oat','pat','peat','rat','sat','seat','tat','vat','wat'},
'eaten':	{'beaten','eater'},
'eater':	{'cater','eager','easter','eaten','eaters','enter','ester','heater','later','mater','neater','water'},
'eaters':	{'caters','eater','enters','esters','haters','heaters','waters'},
'eating':	{'beating','dating','easing','hating','heating','mating','rating','seating'},
'eats':	{'bats','beats','cats','ears','eat','fats','feats','hats','heats','keats','lats','mats','meats','oats','rats','seats','yeats'},
'eb':	{'ab','b','bb','db','deb','e','ea','ebb','ec','ed','ee','eh','el','em','en','er','es','et','eu','ev','ex','feb','gb','kb','lb','mb','nb','ob','pb','rb','sb','tb','web','yb'},
'ebb':	{'bb','eb','webb'},
'ebony':	{'bony'},
'ec':	{'ac','bc','c','cc','dc','dec','e','ea','eb','ecg','ed','ee','eec','eh','el','em','en','er','es','et','etc','eu','ev','ex','kc','mc','nc','pc','rec','sc','sec','tc'},
'ecg':	{'ec','eeg','egg'},
'echoed':	{'echoes'},
'echoes':	{'echoed'},
'eclipse':	{'ellipse'},
'econometric':	{'econometrics'},
'econometrics':	{'econometric'},
'economic':	{'economics'},
'economics':	{'economic','economies'},
'economies':	{'economics'},
'economist':	{'economists'},
'economists':	{'economist'},
'ecosystem':	{'ecosystems'},
'ecosystems':	{'ecosystem'},
'ed':	{'ad','bed','cd','d','dd','e','ea','eb','ec','eda','edp','eds','edu','ee','eh','el','em','en','end','er','es','et','eu','ev','ex','fed','gd','id','led','md','med','nd','od','pd','qed','red','sd','ted','vd','wed','zed'},
'eda':	{'ada','da','ea','ed','edp','eds','edu','epa','era','eta','fda','ida','pda'},
'eddy':	{'edgy','teddy'},
'edema':	{'enema'},
'eden':	{'aden','den','even'},
'edgar':	{'elgar'},
'edge':	{'edged','edges','edgy','hedge','ledge','wedge'},
'edged':	{'edge','edges'},
'edges':	{'edge','edged','hedges','wedges'},
'edging':	{'hedging'},
'edgy':	{'eddy','edge'},
'edit':	{'edits','emit','exit'},
'edited':	{'exited'},
'editing':	{'exiting'},
'edition':	{'editions'},
'editions':	{'edition'},
'editor':	{'editors'},
'editorial':	{'editorials'},
'editorials':	{'editorial'},
'editors':	{'editor'},
'edits':	{'edit','emits','exits'},
'edp':	{'adp','dp','ed','eda','eds','edu','esp','gdp'},
'eds':	{'ads','beds','dds','ed','eda','edp','edu','ends','ens','es','feds'},
'edu':	{'du','ed','eda','edp','eds','emu','eu'},
'educate':	{'educated','educates'},
'educated':	{'educate','educates'},
'educates':	{'educate','educated'},
'educator':	{'educators'},
'educators':	{'educator'},
'edward':	{'edwards'},
'edwards':	{'edward'},
'ee':	{'be','bee','ce','de','e','ea','eb','ec','ed','eec','eeg','eek','eel','eh','el','em','en','ene','er','ere','es','ese','et','eu','ev','eve','ex','eye','fe','fee','ge','gee','he','ie','le','lee','me','ne','nee','pe','pee','se','see','te','tee','ve','we','wee','xe','ye'},
'eec':	{'dec','ec','ee','eeg','eek','eel','etc','exec','rec','sec'},
'eeg':	{'beg','ecg','ee','eec','eek','eel','egg','leg','meg','peg','veg'},
'eek':	{'ee','eec','eeg','eel','elk','geek','leek','lek','meek','peek','seek','week'},
'eel':	{'bel','del','ee','eec','eeg','eek','eels','el','ell','feel','gel','heel','keel','peel','reel'},
'eels':	{'eel','feels','gels','heels','reels'},
'eerie':	{'erie'},
'eff':	{'eft','elf','emf','ff','off'},
'effect':	{'affect','effects'},
'effected':	{'affected'},
'effecting':	{'affecting'},
'effective':	{'affective'},
'effectively':	{'affectively'},
'effects':	{'affects','effect'},
'effluent':	{'affluent'},
'effort':	{'efforts'},
'efforts':	{'effort'},
'eft':	{'aft','eat','eff','est','et','ft','left','oft'},
'egg':	{'ecg','eeg','eggs','ego'},
'eggs':	{'egg','egos'},
'ego':	{'ago','egg','egos','emo','ergo','go','lego'},
'egos':	{'eggs','ego','eros'},
'egress':	{'regress'},
'eh':	{'e','ea','eb','ec','ed','ee','el','em','en','er','es','et','eu','ev','ex','h','nh','oh','ph','rh','sh','th','uh'},
'eight':	{'eighth','eights','eighty','fight','height','light','might','night','right','sight','tight','weight','wight'},
'eighth':	{'eight','eights','eighty'},
'eights':	{'eight','eighth','eighty','fights','heights','lights','nights','rights','sights','tights','weights'},
'eighty':	{'eight','eighth','eights','mighty'},
'eire':	{'dire','ere','eyre','fire','hire','ire','lire','sire','tire','wire'},
'either':	{'esther','ether','hither','neither'},
'eject':	{'elect','erect','reject'},
'ejected':	{'elected','erected','rejected'},
'ejection':	{'election','erection','rejection'},
'el':	{'al','bel','bl','cl','del','e','ea','eb','ec','ed','ee','eel','eh','elf','elk','ell','elm','em','en','er','es','et','eu','ev','ex','fl','gel','il','l','ll','ml','tl','xl'},
'elaborate':	{'elaborated'},
'elaborated':	{'elaborate'},
'elan':	{'clan','klan','lan','plan'},
'elapsed':	{'lapsed'},
'elastic':	{'elastics','plastic'},
'elasticity':	{'plasticity'},
'elastics':	{'elastic','plastics'},
'elbow':	{'elbows'},
'elbows':	{'elbow'},
'elder':	{'alder','elders','older','welder'},
'elders':	{'elder','welders'},
'eldest':	{'oldest'},
'elect':	{'eject','elects','erect','select'},
'elected':	{'ejected','erected','selected'},
'electing':	{'selecting'},
'election':	{'ejection','elections','electron','erection','selection'},
'elections':	{'election','electrons','erections','selections'},
'elective':	{'electives','selective'},
'electives':	{'elective'},
'elector':	{'electors','selector'},
'electors':	{'elector','selectors'},
'electric':	{'electrics'},
'electrician':	{'electricians'},
'electricians':	{'electrician'},
'electrics':	{'electric'},
'electrode':	{'electrodes'},
'electrodes':	{'electrode'},
'electron':	{'election','electrons'},
'electronic':	{'electronics'},
'electronics':	{'electronic'},
'electrons':	{'elections','electron'},
'elects':	{'elect','selects'},
'element':	{'clement','elements'},
'elements':	{'element'},
'elephant':	{'elephants'},
'elephants':	{'elephant'},
'elevate':	{'elevated'},
'elevated':	{'elevate'},
'elevation':	{'elevations'},
'elevations':	{'elevation'},
'elevator':	{'elevators'},
'elevators':	{'elevator'},
'eleven':	{'elevens','elven'},
'elevens':	{'eleven'},
'elf':	{'eff','el','elk','ell','elm','emf','self'},
'elgar':	{'edgar'},
'eliminate':	{'eliminated','eliminates'},
'eliminated':	{'eliminate','eliminates'},
'eliminates':	{'eliminate','eliminated'},
'elite':	{'elites','lite'},
'elites':	{'elite'},
'elk':	{'eek','el','elf','ell','elm','ilk'},
'ell':	{'all','bell','cell','dell','eel','el','elf','elk','elm','fell','hell','ill','ll','sell','tell','well','yell'},
'ellington':	{'wellington'},
'ellipse':	{'eclipse'},
'elm':	{'el','elf','elk','ell','em','helm'},
'else':	{'ease','ese'},
'elven':	{'eleven','elves','even'},
'elves':	{'elven','elvis','selves'},
'elvis':	{'elves','pelvis'},
'em':	{'am','bm','cm','e','ea','eb','ec','ed','ee','eh','el','elm','emf','emo','emu','en','er','es','et','eu','ev','ex','fem','fm','gem','gm','hem','hm','km','mm','nm','pm','rem','rm','sm','tm','um','wm'},
'email':	{'emails','mail'},
'emailed':	{'mailed'},
'emailing':	{'mailing'},
'emails':	{'email','mails'},
'embed':	{'ember'},
'ember':	{'amber','embed','member'},
'emblem':	{'emblems'},
'emblems':	{'emblem'},
'embodied':	{'embodies'},
'embodies':	{'embodied'},
'embodiment':	{'embodiments'},
'embodiments':	{'embodiment'},
'embrace':	{'embraced','embraces'},
'embraced':	{'embrace','embraces'},
'embraces':	{'embrace','embraced'},
'embryo':	{'embryos'},
'embryos':	{'embryo'},
'emerge':	{'emerged','emerges','merge'},
'emerged':	{'emerge','emerges','merged'},
'emergence':	{'emergency'},
'emergency':	{'emergence'},
'emerges':	{'emerge','emerged','merges'},
'emerging':	{'merging'},
'emery':	{'every'},
'emf':	{'eff','elf','em','emo','emu','imf'},
'emigrated':	{'migrated'},
'emigration':	{'migration'},
'emile':	{'exile','mile','smile'},
'emir':	{'emit'},
'emission':	{'emissions','mission','omission','remission'},
'emissions':	{'emission','missions','omissions'},
'emit':	{'edit','emir','emits','exit','mit','omit','remit'},
'emits':	{'edits','emit','exits','omits'},
'emitted':	{'emitter','omitted','remitted'},
'emitter':	{'emitted'},
'emitting':	{'omitting'},
'emo':	{'demo','ego','em','emf','emu','hmo','imo','memo','mo'},
'emoticons':	{'emotions'},
'emotion':	{'emotions','motion'},
'emotions':	{'emoticons','emotion','motions'},
'emphasis':	{'emphasise'},
'emphasise':	{'emphasis','emphasised','emphasises','emphasize'},
'emphasised':	{'emphasise','emphasises','emphasized'},
'emphasises':	{'emphasise','emphasised','emphasizes'},
'emphasising':	{'emphasizing'},
'emphasize':	{'emphasise','emphasized','emphasizes'},
'emphasized':	{'emphasised','emphasize','emphasizes'},
'emphasizes':	{'emphasises','emphasize','emphasized'},
'emphasizing':	{'emphasising'},
'empire':	{'empires','expire','umpire'},
'empires':	{'empire','expires','umpires'},
'employ':	{'employs'},
'employed':	{'employee','employer'},
'employee':	{'employed','employees','employer'},
'employees':	{'employee','employers'},
'employer':	{'employed','employee','employers'},
'employers':	{'employees','employer'},
'employs':	{'employ'},
'empower':	{'empowers'},
'empowers':	{'empower'},
'empress':	{'express','impress'},
'emptied':	{'empties'},
'empties':	{'emptied'},
'emu':	{'edu','em','emf','emo','eu','mu'},
'emulate':	{'emulated'},
'emulated':	{'emulate'},
'emulator':	{'emulators'},
'emulators':	{'emulator'},
'en':	{'an','ben','den','e','ea','eb','ec','ed','ee','eh','el','em','end','ene','ens','er','es','et','eu','ev','ex','fen','gen','hen','in','ken','men','mn','on','pen','rn','sen','sn','ten','tn','un','wen','yen','zen','zn'},
'enable':	{'enabled','enables','unable'},
'enabled':	{'enable','enables'},
'enables':	{'enable','enabled'},
'enact':	{'exact'},
'enacting':	{'exacting'},
'enclose':	{'enclosed','encloses'},
'enclosed':	{'enclose','encloses'},
'encloses':	{'enclose','enclosed'},
'enclosure':	{'enclosures'},
'enclosures':	{'enclosure'},
'encode':	{'encoded','encoder','encodes','encore'},
'encoded':	{'encode','encoder','encodes'},
'encoder':	{'encode','encoded','encoders','encodes'},
'encoders':	{'encoder','encodes'},
'encodes':	{'encode','encoded','encoder','encoders'},
'encompassed':	{'encompasses'},
'encompasses':	{'encompassed'},
'encore':	{'encode'},
'encounter':	{'encounters'},
'encounters':	{'encounter'},
'encourage':	{'encouraged','encourages','entourage'},
'encouraged':	{'encourage','encourages'},
'encourages':	{'encourage','encouraged'},
'encyclopedia':	{'encyclopedias'},
'encyclopedias':	{'encyclopedia'},
'end':	{'and','bend','ed','en','ends','ene','enid','ens','fend','lend','mend','nd','send','tend'},
'endeavor':	{'endeavors','endeavour'},
'endeavors':	{'endeavor','endeavours'},
'endeavour':	{'endeavor','endeavours'},
'endeavours':	{'endeavors','endeavour'},
'ended':	{'mended','tended'},
'ending':	{'bending','endings','lending','mending','pending','sending','tending','vending'},
'endings':	{'ending'},
'endorse':	{'endorsed','endorses'},
'endorsed':	{'endorse','endorses'},
'endorsement':	{'endorsements'},
'endorsements':	{'endorsement'},
'endorses':	{'endorse','endorsed'},
'endowment':	{'endowments'},
'endowments':	{'endowment'},
'endpoint':	{'endpoints'},
'endpoints':	{'endpoint'},
'ends':	{'bends','eds','end','ens','lends','mends','sends','tends'},
'endure':	{'endured','ensure'},
'endured':	{'endure','ensured'},
'enduring':	{'ensuring'},
'ene':	{'ee','en','end','ens','ere','ese','eve','eye','gene','ne','one'},
'enema':	{'edema','enemy'},
'enemy':	{'enema'},
'energized':	{'energizer'},
'energizer':	{'energized'},
'enforce':	{'enforced','enforces'},
'enforced':	{'enforce','enforces'},
'enforces':	{'enforce','enforced'},
'engage':	{'engaged','engages'},
'engaged':	{'engage','engages','enraged'},
'engagement':	{'engagements'},
'engagements':	{'engagement'},
'engages':	{'engage','engaged'},
'engine':	{'engines'},
'engineer':	{'engineers'},
'engineers':	{'engineer'},
'engines':	{'engine'},
'engraving':	{'engravings'},
'engravings':	{'engraving'},
'enhance':	{'enhanced','enhancer','enhances'},
'enhanced':	{'enhance','enhancer','enhances'},
'enhancement':	{'enhancements'},
'enhancements':	{'enhancement'},
'enhancer':	{'enhance','enhanced','enhancers','enhances'},
'enhancers':	{'enhancer','enhances'},
'enhances':	{'enhance','enhanced','enhancer','enhancers'},
'enid':	{'end'},
'enjoy':	{'enjoys','envoy'},
'enjoys':	{'enjoy'},
'enlarge':	{'enlarged'},
'enlarged':	{'enlarge'},
'enlisted':	{'unlisted'},
'enquire':	{'enquirer','enquiry','esquire','inquire'},
'enquirer':	{'enquire','inquirer'},
'enquiries':	{'inquiries'},
'enquiring':	{'inquiring'},
'enquiry':	{'enquire','inquiry'},
'enraged':	{'engaged'},
'enrol':	{'enroll'},
'enroll':	{'enrol'},
'enrollment':	{'enrollments','enrolment'},
'enrollments':	{'enrollment'},
'enrolment':	{'enrollment'},
'ens':	{'ans','cns','eds','en','end','ends','ene','es','hens','ins','lens','pens','sens','tens'},
'ensemble':	{'ensembles'},
'ensembles':	{'ensemble'},
'ensue':	{'ensued','ensues','ensure'},
'ensued':	{'ensue','ensues','ensured'},
'ensues':	{'ensue','ensued','ensures'},
'ensuing':	{'ensuring'},
'ensure':	{'censure','endure','ensue','ensured','ensures','insure','unsure'},
'ensured':	{'endured','ensued','ensure','ensures','insured'},
'ensures':	{'ensues','ensure','ensured','insures'},
'ensuring':	{'enduring','ensuing','insuring'},
'entail':	{'entails'},
'entails':	{'entail'},
'enter':	{'center','eater','enters','ester','inter','renter'},
'entered':	{'centered'},
'entering':	{'centering'},
'enterprise':	{'enterprises'},
'enterprises':	{'enterprise'},
'enters':	{'centers','eaters','enter','esters','renters'},
'entertain':	{'entertains'},
'entertained':	{'entertainer'},
'entertainer':	{'entertained','entertainers'},
'entertainers':	{'entertainer'},
'entertains':	{'entertain'},
'enthusiasm':	{'enthusiast'},
'enthusiast':	{'enthusiasm','enthusiasts'},
'enthusiasts':	{'enthusiast'},
'entice':	{'entire'},
'entire':	{'entice'},
'entirely':	{'entirety'},
'entirety':	{'entirely'},
'entities':	{'entitles'},
'entitle':	{'entitled','entitles'},
'entitled':	{'entitle','entitles','untitled'},
'entitlement':	{'entitlements'},
'entitlements':	{'entitlement'},
'entitles':	{'entities','entitle','entitled'},
'entourage':	{'encourage'},
'entrance':	{'entrances'},
'entrances':	{'entrance'},
'entrant':	{'entrants'},
'entrants':	{'entrant'},
'entrees':	{'entries'},
'entrepreneur':	{'entrepreneurs'},
'entrepreneurs':	{'entrepreneur'},
'entries':	{'entrees'},
'entry':	{'gentry','sentry'},
'enumerate':	{'enumerated'},
'enumerated':	{'enumerate'},
'envelope':	{'enveloped','envelopes'},
'enveloped':	{'envelope','envelopes'},
'envelopes':	{'envelope','enveloped'},
'envied':	{'envies'},
'envies':	{'envied'},
'environ':	{'environs'},
'environment':	{'environments'},
'environmentalist':	{'environmentalists'},
'environmentalists':	{'environmentalist'},
'environments':	{'environment'},
'environs':	{'environ'},
'envisage':	{'envisaged'},
'envisaged':	{'envisage'},
'envoy':	{'enjoy','envy'},
'envy':	{'envoy'},
'enzyme':	{'enzymes'},
'enzymes':	{'enzyme'},
'epa':	{'cpa','ea','eda','epi','era','eta','gpa','pa','spa'},
'ephemera':	{'ephemeral'},
'ephemeral':	{'ephemera'},
'epi':	{'cpi','epa','epic','pi'},
'epic':	{'epi','pic'},
'epidemic':	{'epidemics'},
'epidemics':	{'epidemic'},
'episode':	{'episodes'},
'episodes':	{'episode'},
'epsilon':	{'upsilon'},
'equal':	{'equals'},
'equaled':	{'equalled','equated'},
'equaling':	{'equalling','equating'},
'equality':	{'quality'},
'equalled':	{'equaled'},
'equalling':	{'equaling'},
'equals':	{'equal'},
'equate':	{'equated','equates'},
'equated':	{'equaled','equate','equates'},
'equates':	{'equate','equated'},
'equating':	{'equaling'},
'equation':	{'equations'},
'equations':	{'equation'},
'equip':	{'equips'},
'equipment':	{'equipments'},
'equipments':	{'equipment'},
'equips':	{'equip'},
'equivalence':	{'equivalency'},
'equivalency':	{'equivalence'},
'equivalent':	{'equivalents'},
'equivalents':	{'equivalent'},
'er':	{'aer','ar','ber','br','cr','der','dr','e','ea','ear','eb','ec','ed','ee','eh','el','em','en','era','ere','err','es','et','eu','ev','ex','fer','fr','ger','her','hr','ir','jr','ker','kr','lr','mr','or','per','pr','qr','r','sr','ur','yer','yr','zr'},
'era':	{'ara','bra','ea','eda','epa','er','eras','ere','err','eta','ezra','ira','nra','ra','tera'},
'eradicate':	{'eradicated'},
'eradicated':	{'eradicate'},
'eras':	{'bras','era','erase','eros'},
'erase':	{'ease','eras','erased','eraser'},
'erased':	{'eased','erase','eraser'},
'eraser':	{'erase','erased'},
'erasing':	{'easing'},
'ere':	{'are','ee','eire','ene','er','era','erie','err','ese','eve','eye','eyre','here','ire','mere','ore','pre','were'},
'erect':	{'eject','elect'},
'erected':	{'ejected','elected'},
'erection':	{'ejection','election','erections'},
'erections':	{'elections','erection'},
'ergo':	{'argo','ego'},
'ergonomic':	{'ergonomics'},
'ergonomics':	{'ergonomic'},
'erica':	{'rica'},
'erie':	{'brie','eerie','ere','erin'},
'erin':	{'erie','grin'},
'erode':	{'eroded','erodes','rode'},
'eroded':	{'erode','erodes'},
'erodes':	{'erode','eroded'},
'eros':	{'bros','egos','eras','euros','pros','zeros'},
'erotic':	{'erotica','exotic'},
'erotica':	{'erotic'},
'err':	{'ear','er','era','ere','herr','orr'},
'erred':	{'eared'},
'error':	{'errors','terror'},
'errors':	{'error'},
'eruption':	{'eruptions'},
'eruptions':	{'eruption'},
'es':	{'as','bs','cs','des','e','ea','eb','ec','ed','eds','ee','eh','el','em','en','ens','er','ese','esp','esq','est','et','eu','ev','ex','hs','is','ks','les','mes','ms','os','ps','res','ss','ts','us','vs','yes'},
'escalate':	{'escalated'},
'escalated':	{'escalate'},
'escape':	{'escaped','escapes'},
'escaped':	{'escape','escapes'},
'escapes':	{'escape','escaped'},
'escort':	{'escorts'},
'escorts':	{'escort'},
'ese':	{'ease','ee','else','ene','ere','es','esp','esq','est','eve','eye','se','sse','use'},
'esp':	{'asp','edp','es','ese','esq','est'},
'especial':	{'special'},
'especially':	{'specially'},
'esq':	{'es','ese','esp','est'},
'esquire':	{'enquire','squire'},
'essay':	{'assay','essays'},
'essays':	{'assays','essay'},
'essen':	{'essex','lessen'},
'essence':	{'essences'},
'essences':	{'essence'},
'essential':	{'essentials'},
'essentials':	{'essential'},
'essex':	{'essen','wessex'},
'est':	{'best','cst','east','eat','eft','es','ese','esp','esq','esta','et','fest','jest','lest','mst','nest','pest','pst','rest','test','vest','west','zest'},
'esta':	{'est','eta','vesta'},
'established':	{'establishes'},
'establishes':	{'established'},
'establishment':	{'establishments'},
'establishments':	{'establishment'},
'estate':	{'estates','state'},
'estates':	{'estate','states'},
'ester':	{'aster','easter','eater','enter','esters','esther','jester','tester'},
'esters':	{'eaters','enters','ester','testers'},
'esther':	{'either','ester','ether'},
'estimate':	{'estimated','estimates'},
'estimated':	{'estimate','estimates'},
'estimates':	{'estimate','estimated'},
'estimation':	{'estimations'},
'estimations':	{'estimation'},
'estimator':	{'estimators'},
'estimators':	{'estimator'},
'estonia':	{'estonian'},
'estonian':	{'estonia'},
'et':	{'at','bet','ct','e','ea','eat','eb','ec','ed','ee','eft','eh','el','em','en','er','es','est','eta','etc','eu','ev','ex','ft','get','ht','it','jet','kt','let','met','mt','net','nt','pet','pt','set','t','tet','ut','vet','vt','wet','yet'},
'eta':	{'beta','ea','eda','epa','era','esta','et','etc','etna','meta','ta','uta','zeta'},
'etc':	{'ec','eec','et','eta','etch','ftc','otc','tc'},
'etch':	{'each','etc','fetch','itch'},
'etched':	{'fetched'},
'etching':	{'fetching','itching'},
'eternal':	{'external'},
'eternally':	{'externally'},
'ethanol':	{'methanol'},
'ether':	{'either','esther','nether','other'},
'ethic':	{'ethics','ethnic'},
'ethically':	{'ethnically'},
'ethics':	{'ethic'},
'ethiopia':	{'ethiopian'},
'ethiopian':	{'ethiopia'},
'ethnic':	{'ethic'},
'ethnically':	{'ethically'},
'ethyl':	{'methyl'},
'etna':	{'eta'},
'eu':	{'au','cu','du','e','ea','eb','ec','ed','edu','ee','eh','el','em','emu','en','er','es','et','ev','ex','gu','ju','lu','mu','nu','pu','ru','su','u','wu','zu'},
'euler':	{'ruler'},
'eurasia':	{'eurasian'},
'eurasian':	{'eurasia'},
'euro':	{'euros'},
'europa':	{'europe'},
'europe':	{'europa'},
'euros':	{'eros','euro'},
'ev':	{'av','cv','e','ea','eb','ec','ed','ee','eh','el','em','en','er','es','et','eu','eve','ex','iv','jv','lev','lv','nv','rev','rv','tv','uv','v','wv','xv'},
'evacuate':	{'evacuated','evaluate'},
'evacuated':	{'evacuate','evaluated'},
'evacuation':	{'evaluation'},
'evaluate':	{'evacuate','evaluated','evaluates'},
'evaluated':	{'evacuated','evaluate','evaluates'},
'evaluates':	{'evaluate','evaluated'},
'evaluation':	{'devaluation','evacuation','evaluations','revaluation','valuation'},
'evaluations':	{'evaluation','valuations'},
'evaluator':	{'evaluators'},
'evaluators':	{'evaluator'},
'evangelism':	{'evangelist'},
'evangelist':	{'evangelism'},
'evans':	{'vans'},
'evaporate':	{'evaporated'},
'evaporated':	{'evaporate'},
'eve':	{'ave','ee','ene','ere','ese','ev','even','ever','eye','ve'},
'even':	{'eden','elven','eve','event','ever','oven','seven'},
'evening':	{'evenings'},
'evenings':	{'evening'},
'event':	{'even','events','vent'},
'events':	{'event','vents'},
'ever':	{'eve','even','every','fever','lever','never','over','sever'},
'everest':	{'severest'},
'every':	{'emery','ever','very'},
'evidence':	{'evidenced','evidences'},
'evidenced':	{'evidence','evidences'},
'evidences':	{'evidence','evidenced'},
'evil':	{'devil','evils'},
'evils':	{'devils','evil'},
'evoke':	{'evoked','evokes','revoke'},
'evoked':	{'evoke','evokes','revoked'},
'evokes':	{'evoke','evoked'},
'evolution':	{'devolution','revolution'},
'evolutionary':	{'revolutionary'},
'evolutionist':	{'evolutionists','revolutionist'},
'evolutionists':	{'evolutionist','revolutionists'},
'evolve':	{'evolved','evolves','revolve'},
'evolved':	{'devolved','evolve','evolves'},
'evolves':	{'evolve','evolved','revolves'},
'evolving':	{'revolving'},
'ex':	{'ax','e','ea','eb','ec','ed','ee','eh','el','em','en','er','es','et','eu','ev','hex','ix','ox','px','rex','sex','tx','x','xx'},
'exacerbate':	{'exacerbated'},
'exacerbated':	{'exacerbate'},
'exact':	{'enact'},
'exacting':	{'enacting'},
'exam':	{'exams'},
'examination':	{'examinations'},
'examinations':	{'examination'},
'examine':	{'examined','examiner','examines'},
'examined':	{'examine','examiner','examines'},
'examiner':	{'examine','examined','examiners','examines'},
'examiners':	{'examiner','examines'},
'examines':	{'examine','examined','examiner','examiners'},
'example':	{'examples'},
'examples':	{'example'},
'exams':	{'exam'},
'excavation':	{'excavations'},
'excavations':	{'excavation'},
'exceed':	{'exceeds'},
'exceeds':	{'exceed'},
'excel':	{'excels','expel'},
'excelled':	{'expelled'},
'excellence':	{'excellency'},
'excellency':	{'excellence'},
'excels':	{'excel','excess'},
'except':	{'excerpt'},
'excepted':	{'excerpted'},
'exception':	{'exceptions'},
'exceptions':	{'exception'},
'excerpt':	{'except','excerpts'},
'excerpted':	{'excepted'},
'excerpts':	{'excerpt'},
'excess':	{'excels'},
'exchange':	{'exchanged','exchanger','exchanges'},
'exchanged':	{'exchange','exchanger','exchanges'},
'exchanger':	{'exchange','exchanged','exchanges'},
'exchanges':	{'exchange','exchanged','exchanger'},
'excise':	{'excite','excuse'},
'excite':	{'excise','excited','excites'},
'excited':	{'excite','excites','exited'},
'excites':	{'excite','excited'},
'exciting':	{'exiting'},
'exclude':	{'excluded','excludes'},
'excluded':	{'exclude','excludes'},
'excludes':	{'exclude','excluded'},
'exclusion':	{'exclusions'},
'exclusions':	{'exclusion'},
'exclusive':	{'exclusives'},
'exclusives':	{'exclusive'},
'excursion':	{'excursions'},
'excursions':	{'excursion'},
'excuse':	{'excise','excused','excuses'},
'excused':	{'excuse','excuses'},
'excuses':	{'excuse','excused'},
'exec':	{'eec','execs'},
'execs':	{'exec'},
'execute':	{'executed','executes'},
'executed':	{'execute','executes'},
'executes':	{'execute','executed'},
'execution':	{'executions'},
'executions':	{'execution'},
'executive':	{'executives'},
'executives':	{'executive'},
'exemplified':	{'exemplifies'},
'exemplifies':	{'exemplified'},
'exemption':	{'exemptions'},
'exemptions':	{'exemption'},
'exercise':	{'exercised','exercises'},
'exercised':	{'exercise','exercises'},
'exercises':	{'exercise','exercised'},
'exert':	{'exerts','expert'},
'exerts':	{'exert','experts'},
'exhibit':	{'exhibits'},
'exhibition':	{'exhibitions'},
'exhibitionism':	{'exhibitionist'},
'exhibitionist':	{'exhibitionism'},
'exhibitions':	{'exhibition'},
'exhibitor':	{'exhibitors'},
'exhibitors':	{'exhibitor'},
'exhibits':	{'exhibit'},
'exile':	{'emile','exiled'},
'exiled':	{'exile','exited'},
'exist':	{'exists','exit','sexist'},
'existed':	{'exited'},
'existing':	{'exiting'},
'exists':	{'exist','exits'},
'exit':	{'edit','emit','exist','exits'},
'exited':	{'edited','excited','exiled','existed'},
'exiting':	{'editing','exciting','existing'},
'exits':	{'edits','emits','exists','exit'},
'exorcism':	{'exorcist'},
'exorcist':	{'exorcism'},
'exotic':	{'erotic'},
'expand':	{'expands','expend'},
'expanded':	{'expander','expended'},
'expander':	{'expanded'},
'expands':	{'expand'},
'expanse':	{'expense'},
'expansion':	{'expansions'},
'expansions':	{'expansion'},
'expansive':	{'expensive'},
'expat':	{'expats'},
'expatriate':	{'expatriates'},
'expatriates':	{'expatriate'},
'expats':	{'expat'},
'expect':	{'expects','expert'},
'expectation':	{'expectations'},
'expectations':	{'expectation'},
'expects':	{'expect','experts'},
'expedite':	{'expedited'},
'expedited':	{'expedite'},
'expedition':	{'expeditions'},
'expeditions':	{'expedition'},
'expel':	{'excel'},
'expelled':	{'excelled'},
'expend':	{'expand','extend'},
'expended':	{'expanded','extended'},
'expenditure':	{'expenditures'},
'expenditures':	{'expenditure'},
'expense':	{'expanse','expenses'},
'expenses':	{'expense'},
'expensive':	{'expansive','extensive'},
'experience':	{'experienced','experiences'},
'experienced':	{'experience','experiences'},
'experiences':	{'experience','experienced'},
'experiment':	{'experiments'},
'experiments':	{'experiment'},
'expert':	{'exert','expect','experts','export'},
'experts':	{'exerts','expects','expert','exports'},
'expire':	{'empire','expired','expires','expiry'},
'expired':	{'expire','expires'},
'expires':	{'empires','expire','expired'},
'expiry':	{'expire'},
'explain':	{'explains'},
'explains':	{'explain'},
'explanation':	{'explanations'},
'explanations':	{'explanation'},
'explode':	{'exploded','explodes','explore'},
'exploded':	{'explode','explodes','explored'},
'explodes':	{'explode','exploded','explores'},
'exploding':	{'exploring'},
'exploit':	{'exploits'},
'exploits':	{'exploit'},
'exploration':	{'explorations'},
'explorations':	{'exploration'},
'explore':	{'explode','explored','explorer','explores'},
'explored':	{'exploded','explore','explorer','explores'},
'explorer':	{'explore','explored','explorers','explores'},
'explorers':	{'explorer','explores'},
'explores':	{'explodes','explore','explored','explorer','explorers'},
'exploring':	{'exploding'},
'explosion':	{'explosions'},
'explosions':	{'explosion'},
'explosive':	{'explosives'},
'explosives':	{'explosive'},
'exponent':	{'exponents'},
'exponents':	{'exponent'},
'export':	{'expert','exports'},
'exported':	{'exporter'},
'exporter':	{'exported','exporters'},
'exporters':	{'exporter'},
'exports':	{'experts','export'},
'expose':	{'exposed','exposes'},
'exposed':	{'expose','exposes'},
'exposes':	{'expose','exposed'},
'exposure':	{'exposures'},
'exposures':	{'exposure'},
'express':	{'empress'},
'expressed':	{'expresses'},
'expresses':	{'expressed'},
'expression':	{'expressions'},
'expressions':	{'expression'},
'extant':	{'extent'},
'extend':	{'expend','extends','extent'},
'extended':	{'expended','extender'},
'extender':	{'extended'},
'extends':	{'extend'},
'extension':	{'extensions'},
'extensions':	{'extension'},
'extensive':	{'expensive'},
'extent':	{'extant','extend'},
'external':	{'eternal'},
'externalisation':	{'externalization'},
'externalise':	{'externalised','externalises','externalize'},
'externalised':	{'externalise','externalises','externalized'},
'externalises':	{'externalise','externalised','externalizes'},
'externalising':	{'externalizing'},
'externalization':	{'externalisation'},
'externalize':	{'externalise','externalized','externalizes'},
'externalized':	{'externalised','externalize','externalizes'},
'externalizes':	{'externalises','externalize','externalized'},
'externalizing':	{'externalising'},
'externally':	{'eternally'},
'extinguished':	{'extinguisher'},
'extinguisher':	{'extinguished','extinguishers'},
'extinguishers':	{'extinguisher'},
'extra':	{'extras'},
'extract':	{'extracts'},
'extracts':	{'extract'},
'extras':	{'extra'},
'extreme':	{'extremes'},
'extremes':	{'extreme'},
'extremism':	{'extremist'},
'extremist':	{'extremism','extremists'},
'extremists':	{'extremist'},
'eye':	{'aye','bye','dye','ee','ene','ere','ese','eve','eyed','eyes','eyre','rye','wye','ye'},
'eyebrow':	{'eyebrows'},
'eyebrows':	{'eyebrow'},
'eyed':	{'dyed','eye','eyes','keyed'},
'eyeing':	{'dyeing'},
'eyelid':	{'eyelids'},
'eyelids':	{'eyelid'},
'eyes':	{'ayes','dyes','eye','eyed','reyes','yes'},
'eyre':	{'eire','ere','eye','tyre'},
'ezra':	{'era'},
'f':	{'a','af','b','c','cf','d','e','fa','fe','ff','fl','fm','fo','fr','ft','g','gf','h','hf','i','if','j','k','l','o','of','p','q','r','rf','t','u','v','w','x','y','z'},
'fa':	{'a','ba','ca','da','ea','f','faa','fab','fad','fag','fan','faq','far','fat','fax','fay','fda','fe','ff','fha','fl','fm','fo','fr','ft','ga','ha','ia','ka','la','ma','mfa','na','pa','ra','sa','ta','va','wa','ya','za'},
'faa':	{'baa','fa','fab','fad','fag','fan','faq','far','fat','fax','fay','fda','fha'},
'fab':	{'ab','cab','dab','fa','faa','fad','fag','fan','faq','far','fat','fax','fay','feb','fob','gab','jab','lab','nab','tab'},
'fable':	{'able','cable','fables','gable','sable','table'},
'fables':	{'cables','fable','gables','tables'},
'fabric':	{'fabrics'},
'fabricate':	{'fabricated'},
'fabricated':	{'fabricate'},
'fabrics':	{'fabric'},
'face':	{'ace','faced','faces','facet','fact','fade','fake','fame','farce','fare','fate','fave','lace','mace','pace','race'},
'faced':	{'face','faces','facet','faded','faked','famed','fared','fated','faxed','laced','paced','raced'},
'faces':	{'aces','face','faced','facet','facets','facts','fades','fakes','fares','fates','faxes','feces','laces','paces','races'},
'facet':	{'face','faced','faces','facets','fact','faucet'},
'facets':	{'faces','facet','facts','faucets'},
'facial':	{'facials','racial'},
'facials':	{'facial'},
'facilitate':	{'facilitated','facilitates'},
'facilitated':	{'facilitate','facilitates'},
'facilitates':	{'facilitate','facilitated'},
'facilitator':	{'facilitators'},
'facilitators':	{'facilitator'},
'facing':	{'fading','faxing','pacing','racing'},
'fact':	{'act','face','facet','facts','fart','fast','fat','pact','tact'},
'faction':	{'action','factions','fiction','fraction'},
'factions':	{'actions','faction','fractions'},
'factor':	{'actor','factors','factory'},
'factors':	{'actors','factor','factory'},
'factory':	{'factor','factors'},
'facts':	{'acts','faces','facets','fact','fats'},
'factual':	{'actual'},
'faculty':	{'faulty'},
'fad':	{'ad','bad','cad','dad','fa','faa','fab','fade','fag','fan','faq','far','fat','fax','fay','fed','had','lad','mad','pad','rad','sad','tad','wad'},
'fade':	{'ade','bade','face','fad','faded','fades','fake','fame','fare','fate','fave','jade','made','sade','wade'},
'faded':	{'faced','fade','fades','faked','famed','fared','fated','faxed','jaded'},
'fades':	{'faces','fade','faded','fakes','fares','fates','faxes','hades'},
'fading':	{'facing','faxing','wading'},
'fag':	{'ag','bag','dag','fa','faa','fab','fad','fan','fang','faq','far','fat','fax','fay','fig','flag','fog','gag','jag','lag','mag','nag','rag','sag','tag'},
'fail':	{'bail','dail','fails','fair','fall','foil','frail','hail','jail','mail','nail','rail','sail','tail'},
'failed':	{'filed','hailed','jailed','mailed','nailed','sailed','tailed'},
'failing':	{'ailing','failings','falling','filing','mailing','nailing','railing','sailing','wailing'},
'failings':	{'failing','filings','mailings','railings','sailings'},
'fails':	{'fail','fairs','falls','foils','hails','jails','mails','nails','rails','sails','tails'},
'failure':	{'failures'},
'failures':	{'failure'},
'faint':	{'faints','flint','paint','saint'},
'fainted':	{'fainter','painted','tainted'},
'fainter':	{'fainted','painter'},
'fainting':	{'painting'},
'faints':	{'faint','paints'},
'fair':	{'air','fail','fairs','fairy','far','fir','flair','hair','lair','pair'},
'fairly':	{'fairy'},
'fairs':	{'airs','fails','fair','fairy','hairs','pairs'},
'fairway':	{'airway'},
'fairy':	{'airy','dairy','fair','fairly','fairs','hairy'},
'faith':	{'faiths','saith'},
'faiths':	{'faith'},
'fake':	{'bake','cake','face','fade','faked','fakes','fame','fare','fate','fave','flake','lake','make','rake','sake','take','wake'},
'faked':	{'baked','faced','faded','fake','fakes','famed','fared','fated','faxed','naked','raked'},
'fakes':	{'bakes','cakes','faces','fades','fake','faked','fares','fates','faxes','flakes','lakes','makes','rakes','sakes','takes','wakes'},
'fall':	{'all','ball','call','fail','falls','fell','fill','full','gall','hall','mall','pall','tall','wall'},
'fallback':	{'callback'},
'fallen':	{'allen'},
'falling':	{'calling','failing','filling'},
'falls':	{'balls','calls','fails','fall','fills','halls','malls','walls'},
'fame':	{'came','dame','face','fade','fake','famed','fare','fate','fave','flame','frame','fume','game','lame','name','same','tame'},
'famed':	{'faced','faded','faked','fame','fared','farmed','fated','faxed','framed','named','tamed'},
'familial':	{'familiar'},
'familiar':	{'familial'},
'famine':	{'amine'},
'fan':	{'an','ban','can','fa','faa','fab','fad','fag','fang','fans','faq','far','fat','fawn','fax','fay','fen','fin','fun','han','jan','lan','man','nan','pan','ran','tan','van','wan'},
'fanatic':	{'fanatics'},
'fanatics':	{'fanatic'},
'fancied':	{'fancier','fancies'},
'fancier':	{'fancied','fancies'},
'fancies':	{'fancied','fancier','fanciest'},
'fanciest':	{'fancies'},
'fancy':	{'fanny','nancy'},
'fang':	{'ang','bang','dang','fag','fan','fans','feng','gang','hang','pang','rang','sang','tang','yang'},
'fanned':	{'banned','canned','manned','tanned'},
'fanning':	{'banning','canning','tanning'},
'fanny':	{'fancy','funny','nanny'},
'fans':	{'ans','bans','cans','dans','fan','fang','fats','fins','mans','pans','sans','vans'},
'faq':	{'fa','faa','fab','fad','fag','fan','far','fat','fax','fay'},
'far':	{'afar','ar','bar','car','dar','ear','fa','faa','fab','fad','fag','fair','fan','faq','fare','farm','faro','fart','fat','fax','fay','fdr','fear','fer','fir','for','fr','fur','gar','jar','mar','oar','par','tar','var','war'},
'farce':	{'face','fare','force'},
'fare':	{'are','bare','care','dare','face','fade','fake','fame','far','farce','fared','fares','farm','faro','fart','fate','fave','fire','flare','fore','hare','mare','rare','ware'},
'fared':	{'bared','cared','dared','eared','faced','faded','faked','famed','fare','fares','farmed','fated','faxed','feared','fired','flared','pared'},
'fares':	{'ares','bares','cares','dares','faces','fades','fakes','fare','fared','farms','fates','faxes','fires','flares','mares','wares'},
'fargo':	{'argo','cargo','faro','largo'},
'farm':	{'arm','far','fare','farms','faro','fart','firm','form','harm','warm'},
'farmed':	{'armed','famed','fared','farmer','formed','harmed','warmed'},
'farmer':	{'farmed','farmers','firmer','former','warmer'},
'farmers':	{'farmer','warmers'},
'farming':	{'forming','harming','warming'},
'farms':	{'arms','fares','farm','firms','forms','harms','warms'},
'faro':	{'far','fare','fargo','farm','fart','fro'},
'fart':	{'art','bart','cart','dart','fact','far','fare','farm','faro','fast','fat','fort','hart','kart','mart','part','tart'},
'farther':	{'father','further'},
'farthest':	{'furthest'},
'fascism':	{'fascist'},
'fascist':	{'fascism'},
'fashion':	{'fashions'},
'fashions':	{'fashion'},
'fast':	{'cast','east','fact','fart','fat','faust','feast','fest','fist','hast','last','mast','past','vast'},
'fasten':	{'fastens','faster','fatten','hasten'},
'fastened':	{'fastener','hastened'},
'fastener':	{'fastened','fasteners'},
'fasteners':	{'fastener'},
'fastening':	{'hastening'},
'fastens':	{'fasten','hastens'},
'faster':	{'aster','caster','easter','fasten','foster','master','raster'},
'fasting':	{'casting','feasting','lasting','pasting','tasting','wasting'},
'fat':	{'at','bat','cat','dat','eat','fa','faa','fab','fact','fad','fag','fan','faq','far','fart','fast','fate','fats','fax','fay','feat','fiat','fit','flat','frat','ft','hat','kat','lat','mat','oat','pat','rat','sat','tat','vat','wat'},
'fatah':	{'fatal'},
'fatal':	{'fatah','fetal','natal'},
'fate':	{'ate','date','face','fade','fake','fame','fare','fat','fated','fates','fats','fave','gate','hate','late','mate','pate','rate','tate'},
'fated':	{'dated','faced','faded','faked','famed','fared','fate','fates','faxed','gated','hated','mated','rated'},
'fateful':	{'hateful'},
'fates':	{'dates','faces','fades','fakes','fares','fate','fated','fats','faxes','gates','hates','mates','oates','rates'},
'father':	{'farther','fathers','feather','gather','rather'},
'fathers':	{'father','feathers','gathers'},
'fats':	{'bats','cats','eats','facts','fans','fat','fate','fates','feats','fits','flats','hats','lats','mats','oats','rats'},
'fatten':	{'fasten','flatten','patten'},
'fatty':	{'patty'},
'faucet':	{'facet','faucets'},
'faucets':	{'facets','faucet'},
'fault':	{'faults','faulty','faust','vault'},
'faults':	{'fault','faulty','vaults'},
'faulty':	{'faculty','fault','faults'},
'fauna':	{'sauna'},
'faust':	{'fast','fault'},
'fave':	{'ave','cave','face','fade','fake','fame','fare','fate','five','gave','have','pave','rave','save','wave'},
'favor':	{'favors','favour','flavor','savor'},
'favorable':	{'favorably','favourable'},
'favorably':	{'favorable','favourably'},
'favored':	{'favoured','flavored'},
'favoring':	{'favouring','flavoring'},
'favorite':	{'favorites','favourite'},
'favorites':	{'favorite','favourites'},
'favors':	{'favor','favours','flavors'},
'favour':	{'favor','favours','flavour'},
'favourable':	{'favorable','favourably'},
'favourably':	{'favorably','favourable'},
'favoured':	{'favored','flavoured'},
'favouring':	{'favoring','flavouring'},
'favourite':	{'favorite','favourites'},
'favourites':	{'favorites','favourite'},
'favours':	{'favors','favour','flavours'},
'fawn':	{'dawn','fan','lawn','pawn','yawn'},
'fax':	{'ax','fa','faa','fab','fad','fag','fan','faq','far','fat','fay','fix','flax','fox','lax','max','sax','tax','wax'},
'faxed':	{'axed','faced','faded','faked','famed','fared','fated','faxes','fixed','taxed','waxed'},
'faxes':	{'axes','faces','fades','fakes','fares','fates','faxed','fixes','foxes','taxes','waxes'},
'faxing':	{'axing','facing','fading','fixing','taxing','waxing'},
'fay':	{'bay','cay','day','fa','faa','fab','fad','fag','fan','faq','far','fat','fax','fey','fly','fray','fry','gay','hay','jay','lay','may','nay','pay','ray','say','way'},
'fbi':	{'bi','fri','obi','rbi'},
'fcc':	{'cc','ftc','icc'},
'fda':	{'ada','da','eda','fa','faa','fdr','fha','ida','pda'},
'fdr':	{'dr','far','fda','fer','fir','for','fr','fur'},
'fe':	{'be','ce','de','e','ee','f','fa','feb','fed','fee','fem','fen','fer','few','fey','ff','fl','fm','fo','foe','fr','ft','ge','he','ie','le','me','ne','pe','se','te','ve','we','xe','ye'},
'fear':	{'bear','dear','ear','far','fears','feat','fer','gear','hear','lear','near','pear','rear','tear','wear','year'},
'feared':	{'eared','fared','flared','geared','reared'},
'fearing':	{'bearing','gearing','hearing','nearing','rearing','tearing','wearing'},
'fears':	{'bears','dears','ears','fear','feats','gears','hears','nears','pears','tears','wears','years'},
'feast':	{'beast','east','fast','feasts','feat','fest','least','yeast'},
'feasting':	{'fasting'},
'feasts':	{'beasts','feast','feats'},
'feat':	{'beat','eat','fat','fear','feast','feats','feet','felt','fest','fiat','flat','frat','heat','meat','neat','peat','seat'},
'feather':	{'father','feathers','heather','leather','weather'},
'feathered':	{'weathered'},
'feathering':	{'weathering'},
'feathers':	{'fathers','feather','leathers','weathers'},
'feats':	{'beats','eats','fats','fears','feasts','feat','flats','heats','keats','meats','seats','yeats'},
'feature':	{'featured','features'},
'featured':	{'feature','features'},
'features':	{'feature','featured'},
'feb':	{'deb','eb','fab','fe','fed','fee','fem','fen','fer','few','fey','fob','web'},
'fecal':	{'decal','feral','fetal','focal'},
'feces':	{'faces','fees','fences'},
'fed':	{'bed','ed','fad','fe','feb','feds','fee','feed','fem','fen','fend','fer','feud','few','fey','fled','led','med','qed','red','ted','wed','zed'},
'federalism':	{'federalist'},
'federalist':	{'federalism'},
'federation':	{'federations'},
'federations':	{'federation'},
'feds':	{'beds','eds','fed','feeds','fees'},
'fee':	{'bee','ee','fe','feb','fed','feed','feel','fees','feet','fem','fen','fer','few','fey','flee','foe','free','gee','lee','nee','pee','see','tee','wee'},
'feed':	{'deed','fed','fee','feeds','feel','fees','feet','fend','feud','fled','freed','heed','need','reed','seed','weed'},
'feeder':	{'feeders','fender'},
'feeders':	{'feeder','fenders'},
'feeding':	{'feeling','needing','seeding','weeding'},
'feeds':	{'deeds','feds','feed','feels','fees','leeds','needs','reeds','seeds','weeds'},
'feel':	{'eel','fee','feed','feels','fees','feet','fell','fuel','heel','keel','peel','reel'},
'feeling':	{'feeding','feelings','fueling','peeling','reeling'},
'feelings':	{'feeling'},
'feels':	{'eels','feeds','feel','fees','fuels','heels','reels'},
'fees':	{'bees','feces','feds','fee','feed','feeds','feel','feels','feet','foes','frees','lees','sees','tees'},
'feet':	{'beet','feat','fee','feed','feel','fees','felt','fest','fleet','fret','meet'},
'fell':	{'bell','cell','dell','ell','fall','feel','fella','felt','fill','full','hell','sell','tell','well','yell'},
'fella':	{'fell'},
'fellow':	{'fellows','follow','mellow','yellow'},
'fellows':	{'bellows','fellow','follows'},
'fellowship':	{'fellowships'},
'fellowships':	{'fellowship'},
'felt':	{'belt','feat','feet','fell','fest','melt','welt'},
'fem':	{'em','fe','feb','fed','fee','fen','fer','few','fey','fm','gem','hem','rem'},
'female':	{'females'},
'females':	{'female'},
'feminism':	{'feminist'},
'feminist':	{'feminism','feminists'},
'feminists':	{'feminist'},
'fen':	{'ben','den','en','fan','fe','feb','fed','fee','fem','fend','feng','fer','fern','few','fey','fin','fun','gen','hen','ken','men','pen','sen','ten','wen','yen','zen'},
'fence':	{'fenced','fences','hence','pence'},
'fenced':	{'fence','fences'},
'fences':	{'feces','fence','fenced'},
'fend':	{'bend','end','fed','feed','fen','feng','feud','fiend','find','fond','fund','lend','mend','send','tend'},
'fender':	{'bender','feeder','fenders','finder','fonder','funder','gender','lender','render','sender','tender'},
'fenders':	{'feeders','fender','finders','funders','genders','lenders','renders','senders','tenders'},
'feng':	{'fang','fen','fend'},
'fer':	{'aer','ber','der','er','far','fdr','fe','fear','feb','fed','fee','fem','fen','fern','few','fey','fir','for','fr','fur','ger','her','ker','per','yer'},
'feral':	{'fecal','fetal'},
'fern':	{'bern','fen','fer','ferns','kern','tern'},
'ferns':	{'fern'},
'ferries':	{'berries'},
'ferry':	{'berry','furry','jerry','merry','perry','terry'},
'fertiliser':	{'fertilizer'},
'fertilized':	{'fertilizer'},
'fertilizer':	{'fertiliser','fertilized','fertilizers'},
'fertilizers':	{'fertilizer'},
'fest':	{'best','est','fast','feast','feat','feet','felt','fist','jest','lest','nest','pest','rest','test','vest','west','zest'},
'festival':	{'festivals'},
'festivals':	{'festival'},
'fetal':	{'fatal','fecal','feral','metal','petal'},
'fetch':	{'etch','fitch'},
'fetched':	{'etched'},
'fetching':	{'etching'},
'feud':	{'fed','feed','fend','freud'},
'fever':	{'ever','fevers','fewer','lever','never','sever'},
'fevers':	{'fever','levers'},
'few':	{'dew','fe','feb','fed','fee','fem','fen','fer','fey','flew','jew','mew','new','pew','sew','yew'},
'fewer':	{'fever','newer','sewer'},
'fewest':	{'newest'},
'fey':	{'fay','fe','feb','fed','fee','fem','fen','fer','few','fly','frey','fry','hey','key'},
'ff':	{'af','cf','eff','f','fa','fe','fl','fm','fo','fr','ft','gf','hf','if','of','off','rf'},
'fha':	{'cha','fa','faa','fda','ha'},
'fiance':	{'fiancee','finance','france'},
'fiancee':	{'fiance'},
'fiat':	{'fat','feat','fist','fit','flat','frat'},
'fiber':	{'fibers','filer','finer'},
'fibers':	{'fiber'},
'fibre':	{'fibres','fire'},
'fibres':	{'fibre','fires'},
'fibroblast':	{'fibroblasts'},
'fibroblasts':	{'fibroblast'},
'fiction':	{'faction','friction'},
'fiddle':	{'fiddler','middle','riddle'},
'fiddler':	{'fiddle'},
'field':	{'afield','fields','fiend','wield','yield'},
'fielded':	{'fielder','yielded'},
'fielder':	{'fielded'},
'fielding':	{'wielding','yielding'},
'fields':	{'field','yields'},
'fiend':	{'fend','field','find','friend'},
'fierce':	{'fiercer','pierce'},
'fiercer':	{'fierce'},
'fiesta':	{'siesta'},
'fife':	{'fifo','file','fine','fire','five','life','rife','wife'},
'fifo':	{'fife'},
'fifth':	{'fifths','fifty','filth','firth'},
'fifths':	{'fifth'},
'fifty':	{'fifth','nifty'},
'fig':	{'big','dig','fag','figs','fin','fir','fit','fix','fog','gig','jig','pig','rig','sig','wig'},
'fight':	{'eight','fights','flight','fright','light','might','night','right','sight','tight','wight'},
'fighter':	{'fighters','lighter','tighter'},
'fighters':	{'fighter','lighters'},
'fighting':	{'lighting','sighting'},
'fights':	{'eights','fight','flights','frights','lights','nights','rights','sights','tights'},
'figs':	{'digs','fig','fins','fits','gigs','pigs','rigs','wigs'},
'figure':	{'figured','figures'},
'figured':	{'figure','figures'},
'figures':	{'figure','figured'},
'figurine':	{'figurines','figuring'},
'figurines':	{'figurine'},
'figuring':	{'figurine'},
'fiji':	{'fuji'},
'filament':	{'filaments'},
'filaments':	{'filament'},
'file':	{'bile','fife','filed','filer','files','fill','film','fine','fire','five','mile','nile','pile','tile','vile'},
'filed':	{'failed','file','filer','files','filled','filmed','fined','fired','fixed','fled','oiled','piled','tiled'},
'filer':	{'fiber','file','filed','files','filler','filter','finer'},
'files':	{'file','filed','filer','fills','films','fines','fires','fives','fixes','miles','piles','tiles'},
'filing':	{'ailing','failing','filings','filling','filming','firing','fixing','fling','piling','tiling'},
'filings':	{'failings','filing','fillings'},
'fill':	{'bill','dill','fall','fell','file','fills','film','full','gill','hill','ill','kill','mill','pill','sill','till','will'},
'filled':	{'billed','filed','filler','fillet','filmed','killed','milled','willed'},
'filler':	{'filer','filled','fillers','fillet','filter','fuller','killer','miller'},
'fillers':	{'filler','fillets','filters','killers'},
'fillet':	{'billet','filled','filler','fillets','millet'},
'fillets':	{'fillers','fillet'},
'filling':	{'billing','falling','filing','fillings','filming','killing','milling','willing'},
'fillings':	{'billings','filings','filling','killings'},
'fills':	{'bills','falls','files','fill','films','frills','hills','ills','kills','mills','pills','wills'},
'film':	{'file','fill','films','filmy','firm'},
'filmed':	{'filed','filled'},
'filming':	{'filing','filling'},
'filmmaker':	{'filmmakers'},
'filmmakers':	{'filmmaker'},
'films':	{'files','fills','film','filmy','firms'},
'filmy':	{'film','films'},
'filter':	{'filer','filler','filters','fitter'},
'filters':	{'fillers','filter'},
'filth':	{'fifth','filthy','firth'},
'filthy':	{'filth'},
'fin':	{'bin','din','fan','fen','fig','find','fine','fink','finn','fins','fir','fit','fix','fun','gin','in','kin','lin','min','pin','qin','sin','tin','win','yin'},
'final':	{'finale','finals'},
'finale':	{'final','finals'},
'finalise':	{'finalised','finalises','finalist','finalize'},
'finalised':	{'finalise','finalises','finalized'},
'finalises':	{'finalise','finalised','finalists','finalizes'},
'finalising':	{'finalizing'},
'finalist':	{'finalise','finalists'},
'finalists':	{'finalises','finalist'},
'finalize':	{'finalise','finalized','finalizes'},
'finalized':	{'finalised','finalize','finalizes'},
'finalizes':	{'finalises','finalize','finalized'},
'finalizing':	{'finalising'},
'finals':	{'final','finale'},
'finance':	{'fiance','financed','finances'},
'financed':	{'finance','finances'},
'finances':	{'finance','financed'},
'financier':	{'financiers'},
'financiers':	{'financier'},
'finch':	{'fitch','inch','pinch','winch'},
'find':	{'bind','fend','fiend','fin','finds','fine','fined','fink','finn','fins','fond','fund','hind','kind','lind','mind','wind'},
'finder':	{'binder','fender','finders','finer','finger','fonder','funder','hinder','kinder','winder'},
'finders':	{'binders','fenders','finder','fingers','funders','hinders'},
'finding':	{'binding','findings','funding','minding','winding'},
'findings':	{'bindings','finding'},
'finds':	{'binds','find','fines','fins','funds','kinds','minds','winds'},
'fine':	{'cine','dine','fife','file','fin','find','fined','finer','fines','fink','finn','fins','fire','five','line','mine','nine','pine','sine','vine','wine','zine'},
'fined':	{'dined','filed','find','fine','finer','fines','fired','fixed','lined','mined','wined'},
'finer':	{'diner','fiber','filer','finder','fine','fined','fines','finger','liner','miner'},
'fines':	{'dines','files','finds','fine','fined','finer','finest','fins','fires','fives','fixes','lines','mines','nines','pines','vines','wines','zines'},
'finest':	{'fines'},
'finger':	{'finder','finer','fingers','ginger','linger','ringer','singer','winger'},
'fingering':	{'lingering'},
'fingerprint':	{'fingerprints'},
'fingerprints':	{'fingerprint'},
'fingers':	{'finders','finger','ringers','singers'},
'finish':	{'finnish'},
'finished':	{'finishes'},
'finishers':	{'finishes'},
'finishes':	{'finished','finishers'},
'fink':	{'fin','find','fine','finn','fins','funk','ink','link','mink','pink','rink','sink','wink'},
'finland':	{'inland'},
'finn':	{'fin','find','fine','fink','fins','inn'},
'finnish':	{'finish'},
'fins':	{'bins','fans','figs','fin','find','finds','fine','fines','fink','finn','fits','ins','pins','sins','tins','wins'},
'fir':	{'air','fair','far','fdr','fer','fig','fin','fire','firm','fit','fix','for','fr','fur','ir','sir'},
'fire':	{'dire','eire','fare','fibre','fife','file','fine','fir','fired','fires','firm','five','fore','hire','ire','lire','sire','tire','wire'},
'firearm':	{'firearms','forearm'},
'firearms':	{'firearm'},
'fireball':	{'firewall'},
'fired':	{'aired','fared','filed','fined','fire','fires','fixed','hired','tired','wired'},
'firefighter':	{'firefighters'},
'firefighters':	{'firefighter'},
'fireman':	{'foreman'},
'fireplace':	{'fireplaces'},
'fireplaces':	{'fireplace'},
'fires':	{'fares','fibres','files','fines','fire','fired','firms','fives','fixes','hires','tires','wires'},
'firewall':	{'fireball','firewalls'},
'firewalls':	{'firewall'},
'firing':	{'airing','filing','fixing','hiring','tiring','wiring'},
'firm':	{'farm','film','fir','fire','firms','form'},
'firmer':	{'farmer','former'},
'firms':	{'farms','films','fires','firm','forms'},
'first':	{'fist'},
'firth':	{'birth','fifth','filth','forth','girth'},
'fischer':	{'fisher'},
'fish':	{'dish','fishy','fist','wish'},
'fished':	{'fisher','fishes','wished'},
'fisher':	{'fischer','fished','fishers','fishery','fishes'},
'fisherman':	{'fishermen'},
'fishermen':	{'fisherman'},
'fishers':	{'fisher','fishery','fishes'},
'fishery':	{'fisher','fishers'},
'fishes':	{'dishes','fished','fisher','fishers','wishes'},
'fishing':	{'wishing'},
'fishy':	{'fish'},
'fission':	{'mission'},
'fist':	{'fast','fest','fiat','first','fish','fists','fit','gist','hist','list','mist'},
'fists':	{'fist','fits','lists'},
'fit':	{'bit','fat','fiat','fig','fin','fir','fist','fits','fix','ft','git','hit','it','kit','lit','mit','nit','pit','sit','tit','wit'},
'fitch':	{'bitch','ditch','fetch','finch','hitch','itch','pitch','witch'},
'fitness':	{'witness'},
'fits':	{'bits','fats','figs','fins','fists','fit','hits','its','kits','pits','sits','tits','wits'},
'fitted':	{'fitter','pitted'},
'fitter':	{'bitter','filter','fitted','hitter','jitter','litter','sitter'},
'fitting':	{'fittings','hitting','sitting'},
'fittings':	{'fitting'},
'five':	{'dive','fave','fife','file','fine','fire','fives','give','hive','jive','live'},
'fives':	{'dives','files','fines','fires','five','fixes','gives','hives','ives','lives','wives'},
'fix':	{'dix','fax','fig','fin','fir','fit','fox','ix','mix','nix','pix','six','xix'},
'fixed':	{'faxed','filed','fined','fired','fixes','mixed'},
'fixes':	{'faxes','files','fines','fires','fives','fixed','foxes','mixes','sixes'},
'fixing':	{'faxing','filing','firing','mixing'},
'fixture':	{'fixtures','mixture'},
'fixtures':	{'fixture','mixtures'},
'fl':	{'al','bl','cl','el','f','fa','fe','ff','flu','fly','fm','fo','fol','fr','ft','il','l','ll','ml','tl','xl'},
'flag':	{'fag','flags','flap','flat','flaw','flax','lag','slag'},
'flagged':	{'lagged'},
'flagging':	{'lagging'},
'flags':	{'flag','flaps','flats','flaws','lags'},
'flair':	{'blair','fair','lair'},
'flake':	{'blake','fake','flakes','flaky','flame','flare','fluke','lake'},
'flakes':	{'fakes','flake','flames','flares','lakes'},
'flaky':	{'flake'},
'flame':	{'blame','fame','flake','flames','flare','frame','lame'},
'flames':	{'blames','flakes','flame','flares','frames'},
'flaming':	{'blaming','flamingo','fleming','framing'},
'flamingo':	{'flaming'},
'flange':	{'flanges'},
'flanges':	{'flange'},
'flank':	{'blank','flask','frank','plank'},
'flap':	{'clap','flag','flaps','flat','flaw','flax','flip','flop','lap','slap'},
'flaps':	{'flags','flap','flats','flaws','flips','flops','laps'},
'flare':	{'fare','flake','flame','flared','flares','glare'},
'flared':	{'fared','feared','flare','flares','flawed'},
'flares':	{'fares','flakes','flames','flare','flared'},
'flash':	{'clash','flashy','flask','flesh','flush','lash','slash'},
'flashback':	{'flashbacks'},
'flashbacks':	{'flashback'},
'flashed':	{'flasher','flashes','flushed','slashed'},
'flasher':	{'flashed','flashers','flashes'},
'flashers':	{'flasher','flashes'},
'flashes':	{'clashes','flashed','flasher','flashers','lashes','slashes'},
'flashing':	{'slashing'},
'flashlight':	{'flashlights'},
'flashlights':	{'flashlight'},
'flashy':	{'flash','fleshy'},
'flask':	{'flank','flash'},
'flat':	{'fat','feat','fiat','flag','flap','flats','flaw','flax','float','frat','lat','plat'},
'flats':	{'fats','feats','flags','flaps','flat','flaws','floats','lats'},
'flatten':	{'fatten','flatter'},
'flattening':	{'flattering'},
'flatter':	{'flatten','flutter','latter','platter'},
'flattering':	{'flattening'},
'flavor':	{'favor','flavors','flavour'},
'flavored':	{'favored','flavoured'},
'flavoring':	{'favoring','flavouring'},
'flavors':	{'favors','flavor','flavours'},
'flavour':	{'favour','flavor','flavours'},
'flavoured':	{'favoured','flavored'},
'flavouring':	{'favouring','flavoring'},
'flavours':	{'favours','flavors','flavour'},
'flaw':	{'claw','flag','flap','flat','flaws','flax','flew','flow','law'},
'flawed':	{'flared','flowed'},
'flawless':	{'lawless'},
'flaws':	{'claws','flags','flaps','flats','flaw','flows','laws'},
'flax':	{'fax','flag','flap','flat','flaw','flex','flux','lax'},
'flea':	{'fleas','fled','flee','flew','flex','lea','plea'},
'fleas':	{'flea','pleas'},
'fleck':	{'flick','flock'},
'fled':	{'bled','fed','feed','filed','flea','flee','flew','flex','flied','led','sled'},
'fledged':	{'pledged'},
'flee':	{'fee','flea','fled','fleet','flew','flex','flue','free','glee','klee','lee'},
'fleeing':	{'fleeting','fleming','freeing'},
'fleet':	{'feet','flee','fleets'},
'fleeting':	{'fleeing'},
'fleets':	{'fleet'},
'fleming':	{'flaming','fleeing'},
'flesh':	{'flash','fleshy','flush','fresh'},
'fleshy':	{'flashy','flesh'},
'fleur':	{'flour'},
'flew':	{'blew','few','flaw','flea','fled','flee','flex','flow','slew'},
'flex':	{'flax','flea','fled','flee','flew','flux'},
'flick':	{'click','fleck','flicks','flock','lick','slick'},
'flicks':	{'clicks','flick','flocks','licks'},
'flied':	{'fled','flies','fried','lied'},
'fliers':	{'flies','pliers'},
'flies':	{'flied','fliers','flips','fries','lies'},
'flight':	{'blight','fight','flights','fright','light','plight','slight'},
'flights':	{'fights','flight','frights','lights','slights'},
'fling':	{'cling','filing','flint','flung','flying','ling','sling'},
'flint':	{'faint','fling','flirt','lint'},
'flip':	{'clip','flap','flips','flop','lip','slip'},
'flipped':	{'clipped','flipper','slipped'},
'flipper':	{'clipper','flipped','slipper'},
'flipping':	{'clipping','slipping'},
'flips':	{'clips','flaps','flies','flip','flops','lips','slips'},
'flirt':	{'flint'},
'float':	{'afloat','flat','floats'},
'floated':	{'bloated'},
'floats':	{'flats','float'},
'flock':	{'block','clock','fleck','flick','flocks','lock'},
'flocks':	{'blocks','clocks','flicks','flock','locks'},
'flood':	{'blood','floods','floor','food'},
'flooded':	{'blooded'},
'flooding':	{'flooring'},
'floods':	{'flood','floors','foods'},
'floor':	{'flood','floors','flour'},
'flooring':	{'flooding'},
'floors':	{'floods','floor'},
'flop':	{'flap','flip','flops','flow'},
'floppy':	{'sloppy'},
'flops':	{'flaps','flips','flop','floss','flows'},
'flora':	{'floral','fora'},
'floral':	{'flora'},
'florist':	{'florists'},
'florists':	{'florist'},
'floss':	{'flops','flows','gloss','loss'},
'flounder':	{'founder'},
'flour':	{'fleur','floor','four'},
'flow':	{'blow','flaw','flew','flop','flown','flows','glow','low','plow','slow'},
'flowed':	{'flawed','flower','slowed'},
'flower':	{'blower','flowed','flowers','lower','slower'},
'flowered':	{'lowered'},
'flowering':	{'lowering'},
'flowers':	{'flower','lowers'},
'flowing':	{'blowing','glowing','lowing','slowing'},
'flown':	{'blown','clown','flow','flows','frown'},
'flows':	{'blows','flaws','flops','floss','flow','flown','lows','slows'},
'flu':	{'fl','flue','flux','fly','lu'},
'fluctuate':	{'fluctuated','fluctuates'},
'fluctuated':	{'fluctuate','fluctuates'},
'fluctuates':	{'fluctuate','fluctuated'},
'fluctuation':	{'fluctuations'},
'fluctuations':	{'fluctuation'},
'flue':	{'blue','clue','flee','flu','fluke','flute','flux','glue'},
'fluff':	{'bluff','fluffy'},
'fluffy':	{'fluff'},
'fluid':	{'fluids'},
'fluids':	{'fluid'},
'fluke':	{'flake','flue','flute','luke'},
'flung':	{'clung','fling','lung'},
'flurry':	{'blurry','furry','slurry'},
'flush':	{'blush','flash','flesh','lush','plush'},
'flushed':	{'flashed'},
'flute':	{'flue','fluke','flutes'},
'flutes':	{'flute','fluxes'},
'flutter':	{'clutter','flatter'},
'flux':	{'flax','flex','flu','flue'},
'fluxes':	{'flutes'},
'fly':	{'fay','fey','fl','flu','fry','ly','ply','sly'},
'flying':	{'fling','frying','lying'},
'fm':	{'am','bm','cm','em','f','fa','fe','fem','ff','fl','fo','fr','ft','gm','hm','km','mm','nm','pm','rm','sm','tm','um','wm'},
'fo':	{'cfo','co','do','f','fa','fe','ff','fl','fm','fob','foe','fog','fol','for','fox','fr','fro','ft','go','ho','io','ko','lo','mo','no','o','po','so','to','ufo','wo'},
'foal':	{'coal','foam','focal','foil','fol','fool','foul','fowl','goal'},
'foam':	{'foal','form','loam','roam'},
'fob':	{'bob','cob','fab','feb','fo','foe','fog','fol','for','fox','hob','job','lob','mob','nob','ob','rob','sob'},
'focal':	{'fecal','foal','local','vocal'},
'focus':	{'locus'},
'focused':	{'focuses','focussed'},
'focuses':	{'focused'},
'focusing':	{'focussing'},
'focussed':	{'focused'},
'focussing':	{'focusing'},
'fodder':	{'folder','fonder'},
'foe':	{'doe','fe','fee','fo','fob','foes','fog','fol','for','fore','fox','hoe','poe','roe','toe','woe'},
'foes':	{'does','fees','foe','foxes','goes','hoes','toes','woes'},
'fog':	{'bog','cog','dog','fag','fig','fo','fob','foe','fol','for','fox','frog','hog','jog','log'},
'foggy':	{'doggy'},
'foil':	{'boil','coil','fail','foal','foils','fol','fool','foul','fowl','oil','soil','toil'},
'foils':	{'boils','coils','fails','foil','fools','fouls','oils','soils'},
'fol':	{'col','fl','fo','foal','fob','foe','fog','foil','fold','folk','fool','for','foul','fowl','fox','pol','sol','vol'},
'fold':	{'bold','cold','fol','folds','folk','fond','food','ford','gold','hold','mold','old','sold','told'},
'folded':	{'folder','molded'},
'folder':	{'bolder','colder','fodder','folded','folders','fonder','holder','older','solder'},
'folders':	{'folder','holders'},
'folding':	{'golding','holding','molding'},
'folds':	{'colds','fold','folks','foods','holds','molds'},
'folio':	{'polio'},
'folk':	{'fol','fold','folks','fork','polk','yolk'},
'folks':	{'folds','folk','forks'},
'follicle':	{'follicles'},
'follicles':	{'follicle'},
'follow':	{'fellow','follows','hollow'},
'followed':	{'follower','hollowed'},
'follower':	{'followed','followers'},
'followers':	{'follower'},
'following':	{'followings','hollowing'},
'followings':	{'following'},
'follows':	{'fellows','follow','hollows'},
'folly':	{'dolly','fully','holly','jolly','molly'},
'fond':	{'bond','fend','find','fold','fonda','font','food','ford','found','fund','pond'},
'fonda':	{'fond'},
'fonder':	{'fender','finder','fodder','folder','founder','funder','ponder','wonder','yonder'},
'font':	{'cont','dont','fond','fonts','foot','fort','front','ont','wont'},
'fonts':	{'font','forts','fronts'},
'food':	{'flood','fold','fond','foods','fool','foot','ford','good','hood','mood','wood'},
'foods':	{'floods','folds','food','fools','goods','hoods','moods','woods'},
'fool':	{'cool','foal','foil','fol','food','fools','foot','foul','fowl','pool','tool','wool'},
'fooled':	{'cooled','footed','fouled','pooled','tooled'},
'fooling':	{'cooling','footing','pooling','tooling'},
'fools':	{'cools','foils','foods','fool','fouls','pools','tools','wools'},
'foot':	{'boot','font','food','fool','fort','hoot','loot','moot','root','soot'},
'football':	{'footballs'},
'footballs':	{'football'},
'footed':	{'booted','fooled','footer','looted','rooted'},
'footer':	{'footed','foster'},
'foothill':	{'foothills'},
'foothills':	{'foothill'},
'footing':	{'booting','fooling','looting','rooting'},
'footnote':	{'footnotes'},
'footnotes':	{'footnote'},
'footprint':	{'footprints'},
'footprints':	{'footprint'},
'for':	{'far','fdr','fer','fir','fo','fob','foe','fog','fol','fora','ford','fore','fork','form','fort','four','fox','fr','fur','nor','or','tor'},
'fora':	{'cora','flora','for','foray','ford','fore','fork','form','fort','hora'},
'forage':	{'forge'},
'foraging':	{'forging'},
'foray':	{'fora','forty','fray','moray'},
'forbid':	{'forbids','morbid'},
'forbids':	{'forbid'},
'force':	{'farce','forced','forces','fore','forge','forte'},
'forced':	{'force','forces','forged','formed'},
'forces':	{'force','forced'},
'forcing':	{'forging','forming'},
'ford':	{'cord','fold','fond','food','for','fora','fore','fork','form','fort','lord','word'},
'fore':	{'bore','core','fare','fire','foe','for','fora','force','ford','forge','fork','form','fort','forte','gore','lore','more','ore','pore','sore','tore','wore'},
'forearm':	{'firearm'},
'forecast':	{'forecasts'},
'forecasts':	{'forecast'},
'foreclosure':	{'foreclosures'},
'foreclosures':	{'foreclosure'},
'foreigner':	{'foreigners'},
'foreigners':	{'foreigner'},
'foreman':	{'fireman'},
'forensic':	{'forensics'},
'forensics':	{'forensic'},
'foresee':	{'foreseen'},
'foreseen':	{'foresee'},
'forest':	{'forests'},
'forested':	{'forester'},
'forester':	{'forested'},
'forests':	{'forest'},
'forgave':	{'forgive'},
'forge':	{'forage','force','fore','forged','forget','forte','gorge'},
'forged':	{'forced','forge','forget','formed'},
'forget':	{'forge','forged','forgets','forgot'},
'forgets':	{'forget'},
'forging':	{'foraging','forcing','forming'},
'forgive':	{'forgave','forgiven','forgives'},
'forgiven':	{'forgive','forgives'},
'forgives':	{'forgive','forgiven'},
'forgot':	{'forget'},
'fork':	{'cork','dork','folk','for','fora','ford','fore','forks','form','fort','pork','work','york'},
'forks':	{'corks','folks','fork','forms','forts','works'},
'form':	{'dorm','farm','firm','foam','for','fora','ford','fore','fork','forms','fort','forum','norm','worm'},
'formal':	{'format','normal'},
'formality':	{'normality'},
'formalized':	{'normalized'},
'formally':	{'normally'},
'format':	{'formal','formats'},
'formation':	{'formations'},
'formations':	{'formation'},
'formative':	{'normative'},
'formats':	{'format'},
'formed':	{'farmed','forced','forged','former','wormed'},
'former':	{'farmer','firmer','formed'},
'forming':	{'farming','forcing','forging','worming'},
'forms':	{'dorms','farms','firms','forks','form','forts','forums','norms','worms'},
'formula':	{'formulae','formulas'},
'formulae':	{'formula','formulas','formulate'},
'formulas':	{'formula','formulae'},
'formulate':	{'formulae','formulated'},
'formulated':	{'formulate'},
'formulation':	{'formulations'},
'formulations':	{'formulation'},
'forsake':	{'forsaken'},
'forsaken':	{'forsake'},
'fort':	{'fart','font','foot','for','fora','ford','fore','fork','form','forte','forth','forts','forty','hort','port','sort','tort','wort'},
'forte':	{'force','fore','forge','fort','forth','forts','forty'},
'forth':	{'firth','fort','forte','forts','forty','fourth','north','worth'},
'forts':	{'fonts','forks','forms','fort','forte','forth','forty','ports','sorts','torts'},
'fortune':	{'fortunes'},
'fortunes':	{'fortune'},
'forty':	{'foray','fort','forte','forth','forts'},
'forum':	{'form','forums'},
'forums':	{'forms','forum'},
'forward':	{'forwards'},
'forwards':	{'forward'},
'fossil':	{'fossils'},
'fossils':	{'fossil'},
'foster':	{'faster','footer','fosters','poster','roster'},
'fosters':	{'foster','posters','rosters'},
'fought':	{'bought','ought','sought'},
'foul':	{'foal','foil','fol','fool','fouls','four','fowl','soul'},
'fouled':	{'fooled'},
'fouls':	{'foils','fools','foul','fours','souls'},
'found':	{'bound','fond','fund','hound','mound','pound','round','sound','wound'},
'foundation':	{'foundations'},
'foundations':	{'foundation'},
'founded':	{'bounded','founder','funded','pounded','rounded','sounded','wounded'},
'founder':	{'flounder','fonder','founded','founders','funder','rounder'},
'founders':	{'founder','funders'},
'founding':	{'bounding','funding','pounding','rounding','sounding','wounding'},
'fountain':	{'fountains','mountain'},
'fountains':	{'fountain','mountains'},
'four':	{'flour','for','foul','fours','fur','hour','our','pour','sour','tour','your'},
'fourier':	{'courier'},
'fours':	{'fouls','four','furs','hours','ours','pours','sours','tours','yours'},
'fourth':	{'forth','fourths'},
'fourths':	{'fourth'},
'fowl':	{'bowl','foal','foil','fol','fool','foul','howl','owl'},
'fowler':	{'bowler'},
'fox':	{'box','cox','fax','fix','fo','fob','foe','fog','fol','for','foxy','ox','pox'},
'foxes':	{'boxes','faxes','fixes','foes'},
'foxy':	{'fox'},
'foyer':	{'fryer'},
'fps':	{'bps','cps','ops','ps'},
'fr':	{'ar','br','cr','dr','er','f','fa','far','fdr','fe','fer','ff','fir','fl','fm','fo','for','fri','fro','fry','ft','fur','hr','ir','jr','kr','lr','mr','or','pr','qr','r','sr','ur','yr','zr'},
'fraction':	{'faction','fractions','friction','traction'},
'fractions':	{'factions','fraction'},
'fracture':	{'fractured','fractures'},
'fractured':	{'fracture','fractures'},
'fractures':	{'fracture','fractured'},
'fragment':	{'fragments'},
'fragments':	{'fragment'},
'fragrance':	{'fragrances'},
'fragrances':	{'fragrance'},
'frail':	{'fail','grail','rail','trail'},
'frame':	{'fame','flame','framed','frames'},
'framed':	{'famed','frame','frames'},
'frames':	{'flames','frame','framed'},
'framework':	{'frameworks'},
'frameworks':	{'framework'},
'framing':	{'flaming'},
'franc':	{'france','franck','franco','francs','frank'},
'france':	{'fiance','franc','franck','franco','francs','trance'},
'franchise':	{'franchisee','franchises'},
'franchisee':	{'franchise','franchisees','franchises'},
'franchisees':	{'franchisee','franchises'},
'franchises':	{'franchise','franchisee','franchisees'},
'franck':	{'franc','france','franco','francs','frank'},
'franco':	{'franc','france','franck','francs'},
'francs':	{'franc','france','franck','franco'},
'frank':	{'crank','drank','flank','franc','franck','prank','rank'},
'frankfort':	{'frankfurt'},
'frankfurt':	{'frankfort'},
'frat':	{'brat','fat','feat','fiat','flat','frau','fray','fret','rat'},
'frau':	{'frat','fraud','fray'},
'fraud':	{'frau','frauds','freud'},
'frauds':	{'fraud'},
'fraught':	{'draught'},
'fray':	{'bray','fay','foray','frat','frau','frey','fry','gray','pray','ray','tray'},
'freak':	{'break','freaks','freaky'},
'freaking':	{'breaking'},
'freaks':	{'breaks','freak','freaky'},
'freaky':	{'freak','freaks'},
'free':	{'cree','fee','flee','freed','freer','frees','freq','fret','frey','frye','tree'},
'freed':	{'breed','creed','feed','free','freer','frees','freud','fried','greed','reed'},
'freedman':	{'freeman','friedman'},
'freedom':	{'freedoms'},
'freedoms':	{'freedom'},
'freeing':	{'fleeing','freezing'},
'freeman':	{'freedman'},
'freer':	{'free','freed','frees','fryer'},
'frees':	{'fees','free','freed','freer','freest','fries','trees'},
'freest':	{'frees'},
'freeze':	{'breeze','freezer','freezes'},
'freezer':	{'freeze','freezers','freezes'},
'freezers':	{'freezer','freezes'},
'freezes':	{'breezes','freeze','freezer','freezers'},
'freezing':	{'freeing'},
'freight':	{'fright'},
'french':	{'trench','wrench'},
'freq':	{'free','fret','frey'},
'frequent':	{'frequents'},
'frequents':	{'frequent'},
'fresco':	{'fresno'},
'fresh':	{'flesh'},
'freshman':	{'freshmen'},
'freshmen':	{'freshman'},
'fresno':	{'fresco'},
'fret':	{'feet','frat','free','freq','frey'},
'freud':	{'feud','fraud','freed'},
'frey':	{'fey','fray','free','freq','fret','freya','fry','grey','prey','trey'},
'freya':	{'frey'},
'fri':	{'fbi','fr','fro','fry','mri','ri'},
'friction':	{'fiction','fraction'},
'friday':	{'fridays'},
'fridays':	{'friday'},
'fridge':	{'bridge','fridges','fringe','ridge'},
'fridges':	{'bridges','fridge','fringes','ridges'},
'fried':	{'cried','dried','flied','freed','friend','fries','tried'},
'friedman':	{'freedman'},
'friend':	{'fiend','fried','friends'},
'friends':	{'friend'},
'friendship':	{'friendships'},
'friendships':	{'friendship'},
'fries':	{'aries','cries','dries','flies','frees','fried','tries'},
'fright':	{'bright','fight','flight','freight','frights','right','wright'},
'frighten':	{'brighten','frightens'},
'frightened':	{'brightened'},
'frightening':	{'brightening'},
'frightens':	{'brightens','frighten'},
'frightful':	{'rightful'},
'frights':	{'fights','flights','fright','rights'},
'frills':	{'drills','fills','grills'},
'fringe':	{'cringe','fridge','fringes'},
'fringes':	{'fridges','fringe'},
'fro':	{'afro','bro','faro','fo','fr','fri','frog','from','fry','pro'},
'frog':	{'fog','fro','from'},
'from':	{'fro','frog','prom','rom'},
'front':	{'font','fronts','frost'},
'fronted':	{'frosted'},
'frontier':	{'frontiers'},
'frontiers':	{'frontier'},
'fronts':	{'fonts','front'},
'frost':	{'front','frosty'},
'frosted':	{'fronted'},
'frosty':	{'frost'},
'frown':	{'brown','crown','drown','flown','grown'},
'frowned':	{'browned','crowned','drowned'},
'froze':	{'frozen'},
'frozen':	{'froze'},
'fruit':	{'fruits','fruity'},
'fruits':	{'fruit','fruity'},
'fruity':	{'fruit','fruits'},
'frustrate':	{'frustrated'},
'frustrated':	{'frustrate'},
'frustration':	{'frustrations'},
'frustrations':	{'frustration'},
'fry':	{'cry','dry','fay','fey','fly','fr','fray','frey','fri','fro','frye','fury','try'},
'frye':	{'free','fry','fryer','rye'},
'fryer':	{'dryer','foyer','freer','frye','fryers'},
'fryers':	{'dryers','fryer'},
'frying':	{'crying','drying','flying','trying'},
'ft':	{'aft','at','ct','eft','et','f','fa','fat','fe','ff','fit','fl','fm','fo','fr','ftc','ftp','ht','it','kt','mt','nt','oft','pt','t','ut','vt'},
'ftc':	{'etc','fcc','ft','ftp','otc','tc'},
'ftp':	{'atp','ft','ftc'},
'fuck':	{'buck','duck','funk','huck','luck','muck','puck','suck','tuck'},
'fucker':	{'sucker','tucker'},
'fucking':	{'ducking','sucking'},
'fudge':	{'judge','nudge'},
'fuel':	{'duel','feel','fuels','full','furl'},
'fueled':	{'fuelled'},
'fueling':	{'feeling'},
'fuelled':	{'fueled'},
'fuels':	{'feels','fuel'},
'fugitive':	{'fugitives'},
'fugitives':	{'fugitive'},
'fuji':	{'fiji'},
'fulfil':	{'fulfill'},
'fulfill':	{'fulfil','fulfills'},
'fulfillment':	{'fulfilment'},
'fulfills':	{'fulfill'},
'fulfilment':	{'fulfillment'},
'full':	{'bull','dull','fall','fell','fill','fuel','fully','furl','gull','hull','mull','null','pull'},
'fuller':	{'duller','filler','muller'},
'fullest':	{'dullest'},
'fullness':	{'dullness'},
'fully':	{'bully','folly','full','gully','sully','tully'},
'fulton':	{'futon'},
'fumble':	{'bumble','humble','jumble','rumble','tumble'},
'fume':	{'fame','fumes','fuse','hume'},
'fumes':	{'fume','fuses'},
'fun':	{'bun','dun','fan','fen','fin','fund','funk','fur','gun','hun','nun','pun','run','sun','un'},
'function':	{'functions','junction'},
'functions':	{'function','junctions'},
'fund':	{'fend','find','fond','found','fun','funds','funk'},
'fundamental':	{'fundamentals'},
'fundamentalism':	{'fundamentalist'},
'fundamentalist':	{'fundamentalism','fundamentalists'},
'fundamentalists':	{'fundamentalist'},
'fundamentals':	{'fundamental'},
'funded':	{'founded','funder'},
'funder':	{'fender','finder','fonder','founder','funded','funders','under'},
'funders':	{'fenders','finders','founders','funder'},
'funding':	{'finding','founding'},
'fundraiser':	{'fundraisers'},
'fundraisers':	{'fundraiser'},
'funds':	{'finds','fund'},
'funeral':	{'funerals'},
'funerals':	{'funeral'},
'funk':	{'bunk','dunk','fink','fuck','fun','fund','funky','hunk','junk','punk','sunk'},
'funky':	{'funk','funny'},
'funnel':	{'tunnel'},
'funnier':	{'funnies'},
'funnies':	{'bunnies','funnier','funniest'},
'funniest':	{'funnies'},
'funny':	{'bunny','fanny','funky','runny','sunny'},
'fur':	{'bur','cur','dur','far','fdr','fer','fir','for','four','fr','fun','furl','furs','fury','our','ur'},
'furious':	{'curious'},
'furiously':	{'curiously'},
'furl':	{'curl','fuel','full','fur','furs','fury','url'},
'furnace':	{'furnaces'},
'furnaces':	{'furnace'},
'furnished':	{'furnishes'},
'furnishes':	{'furnished'},
'furnishing':	{'furnishings'},
'furnishings':	{'furnishing'},
'furry':	{'curry','ferry','flurry','fury','hurry'},
'furs':	{'fours','fur','furl','fury','fuss','ours'},
'further':	{'farther'},
'furthest':	{'farthest'},
'fury':	{'bury','fry','fur','furl','furry','furs','jury'},
'fuse':	{'fume','fused','fuses','fuss','muse','use'},
'fused':	{'fuse','fuses','used'},
'fuses':	{'buses','fumes','fuse','fused','fuss','uses'},
'fuss':	{'furs','fuse','fuses','muss'},
'futility':	{'utility'},
'futon':	{'fulton','futons'},
'futons':	{'futon'},
'future':	{'futures','suture'},
'futures':	{'future'},
'g':	{'a','ag','b','c','d','e','f','ga','gb','gd','ge','gf','gi','gm','go','gp','gu','h','hg','i','j','k','kg','l','mg','o','p','q','r','t','u','v','w','x','y','z'},
'ga':	{'a','ba','ca','da','ea','fa','g','gab','gag','gal','gao','gap','gar','gas','gay','gb','gd','ge','gf','gi','gm','go','goa','gp','gpa','gsa','gu','ha','ia','ka','la','ma','na','pa','ra','sa','ta','va','wa','ya','za'},
'gab':	{'ab','cab','dab','fab','ga','gag','gal','gao','gap','gar','garb','gas','gay','gb','grab','jab','lab','nab','tab'},
'gable':	{'able','cable','fable','gables','gale','gamble','sable','table'},
'gables':	{'cables','fables','gable','tables'},
'gadget':	{'gadgets'},
'gadgets':	{'gadget'},
'gael':	{'gal','gall','gaul','gel'},
'gaelic':	{'garlic'},
'gag':	{'ag','bag','dag','fag','ga','gab','gage','gags','gal','gang','gao','gap','gar','gas','gay','gig','jag','lag','mag','nag','rag','sag','tag'},
'gage':	{'age','cage','gag','gags','gale','game','gate','gauge','gave','gaze','page','rage','sage','wage'},
'gagged':	{'bagged','jagged','lagged','ragged','tagged'},
'gagging':	{'bagging','lagging','nagging','tagging'},
'gags':	{'bags','gag','gage','gals','gangs','gaps','gas','gays','gigs','lags','rags','tags'},
'gaily':	{'daily'},
'gain':	{'again','cain','gains','gait','gin','grain','grin','jain','lain','main','pain','rain','vain'},
'gained':	{'grained','rained'},
'gaining':	{'raining'},
'gains':	{'gain','grains','grins','mains','pains','rains'},
'gait':	{'bait','gain','gatt','git','grit','wait'},
'gal':	{'al','dal','ga','gab','gael','gag','gala','gale','gall','gals','gao','gap','gar','gas','gaul','gay','gel','goal','mal','pal'},
'gala':	{'ala','gal','gale','gall','gals','gaza','gila','mala','tala'},
'gale':	{'ale','bale','dale','gable','gage','gal','gala','galen','gall','gals','game','gate','gave','gaze','hale','male','pale','sale','tale','vale','yale'},
'galen':	{'gale','galena','glen'},
'galena':	{'galen'},
'galilee':	{'galileo'},
'galileo':	{'galilee'},
'gall':	{'all','ball','call','fall','gael','gal','gala','gale','gals','gaul','gill','gull','hall','mall','pall','tall','wall'},
'gallery':	{'galley'},
'galley':	{'alley','gallery','halley','valley'},
'gallon':	{'gallons'},
'gallons':	{'gallon'},
'gals':	{'gags','gal','gala','gale','gall','gaps','gas','gays','gels','goals','pals'},
'gambia':	{'gambian','gambit','zambia'},
'gambian':	{'gambia','zambian'},
'gambit':	{'gambia'},
'gamble':	{'gable','gambler'},
'gambler':	{'ambler','gamble','gamblers','rambler'},
'gamblers':	{'gambler'},
'gambling':	{'rambling'},
'game':	{'came','dame','fame','gage','gale','gamer','games','gate','gave','gaze','lame','name','same','tame'},
'gamer':	{'game','gamers','games','gayer'},
'gamers':	{'gamer','games'},
'games':	{'game','gamer','gamers','gases','gates','james','names','tames'},
'gaming':	{'gaping','gazing','naming','taming'},
'gang':	{'ang','bang','dang','fang','gag','gangs','gong','hang','pang','rang','sang','tang','yang'},
'ganglia':	{'anglia'},
'gangs':	{'bangs','gags','gang','hangs'},
'gao':	{'ga','gab','gag','gal','gap','gar','gas','gay','go','goo','gpo','hao','lao','mao','tao'},
'gap':	{'cap','ga','gab','gag','gal','gao','gaps','gar','gas','gasp','gay','gdp','gnp','gop','gp','hap','lap','map','nap','pap','rap','sap','tap','yap','zap'},
'gaping':	{'gaming','gazing','raping','taping'},
'gaps':	{'caps','gags','gals','gap','gas','gays','laps','maps','taps'},
'gar':	{'agar','ar','bar','car','dar','ear','far','ga','gab','gag','gal','gao','gap','garb','gary','gas','gay','gear','ger','jar','mar','oar','par','tar','var','war'},
'garage':	{'garages','garbage'},
'garages':	{'garage'},
'garb':	{'barb','gab','gar','gary'},
'garbage':	{'garage'},
'garden':	{'gardens','harden','warden'},
'gardener':	{'gardeners','gardiner','gardner'},
'gardeners':	{'gardener'},
'gardening':	{'hardening'},
'gardens':	{'garden','hardens'},
'gardiner':	{'gardener','gardner'},
'gardner':	{'gardener','gardiner','garner'},
'garlic':	{'gaelic'},
'garment':	{'garments'},
'garments':	{'garment'},
'garner':	{'gardner','garnet','garter','warner'},
'garnet':	{'garner'},
'garnish':	{'varnish'},
'garrison':	{'harrison'},
'garter':	{'barter','carter','garner'},
'gary':	{'gar','garb','gay','gory','mary','vary','wary'},
'gas':	{'as','ga','gab','gag','gags','gal','gals','gao','gap','gaps','gar','gasp','gay','gays','has','mas','oas','pas','was'},
'gases':	{'bases','cases','eases','games','gates','vases'},
'gasket':	{'basket','casket','gaskets'},
'gaskets':	{'baskets','gasket'},
'gasp':	{'asp','gap','gas','grasp','wasp'},
'gasped':	{'grasped'},
'gate':	{'agate','ate','date','fate','gage','gale','game','gated','gates','gatt','gave','gaze','grate','hate','late','mate','pate','rate','tate'},
'gated':	{'dated','fated','gate','gates','gazed','grated','hated','mated','rated'},
'gates':	{'dates','fates','games','gases','gate','gated','hates','mates','oates','rates'},
'gateway':	{'gateways'},
'gateways':	{'gateway'},
'gather':	{'father','gathers','rather'},
'gathering':	{'gatherings'},
'gatherings':	{'gathering'},
'gathers':	{'fathers','gather'},
'gatt':	{'gait','gate','matt','watt'},
'gauge':	{'gage','gauges'},
'gauges':	{'gauge'},
'gaul':	{'gael','gal','gall','haul','paul','saul'},
'gave':	{'ave','cave','fave','gage','gale','game','gate','gaze','give','grave','have','pave','rave','save','wave'},
'gawk':	{'hawk'},
'gay':	{'bay','cay','day','fay','ga','gab','gag','gal','gao','gap','gar','gary','gas','gays','gray','guy','hay','jay','lay','may','nay','ngay','pay','ray','say','way'},
'gayer':	{'bayer','gamer','layer','mayer','payer'},
'gays':	{'bays','days','gags','gals','gaps','gas','gay','grays','guys','hays','lays','mays','nays','pays','rays','says','ways'},
'gaza':	{'gala','gaze'},
'gaze':	{'daze','gage','gale','game','gate','gave','gaza','gazed','glaze','haze','maze'},
'gazed':	{'gated','gaze','glazed'},
'gazing':	{'gaming','gaping','glazing','grazing'},
'gb':	{'ab','b','bb','db','eb','g','ga','gab','gd','ge','gf','gi','gm','go','gp','gu','kb','kgb','lb','mb','nb','ob','pb','rb','sb','tb','yb'},
'gd':	{'ad','cd','d','dd','ed','g','ga','gb','gdp','ge','gf','gi','gm','go','god','gp','gu','id','md','nd','od','pd','sd','vd'},
'gdp':	{'adp','dp','edp','gap','gd','gnp','gop','gp'},
'ge':	{'age','be','ce','de','e','ee','fe','g','ga','gb','gd','gee','gel','gem','gen','ger','get','gf','gi','gm','go','gp','gu','he','ie','le','me','ne','pe','se','te','ve','we','xe','ye'},
'gear':	{'bear','dear','ear','fear','gar','gears','ger','hear','lear','near','pear','rear','tear','wear','year'},
'geared':	{'eared','feared','reared'},
'gearing':	{'bearing','fearing','glaring','hearing','nearing','rearing','tearing','wearing'},
'gears':	{'bears','dears','ears','fears','gear','hears','nears','pears','tears','wears','years'},
'gee':	{'bee','ee','fee','ge','geek','gel','gem','gen','gene','ger','get','glee','lee','nee','pee','see','tee','wee'},
'geek':	{'eek','gee','geeks','geeky','greek','leek','meek','peek','seek','week'},
'geeks':	{'geek','geeky','seeks','weeks'},
'geeky':	{'geek','geeks'},
'gel':	{'bel','del','eel','el','gael','gal','ge','gee','geld','gels','gem','gen','ger','get'},
'geld':	{'gel','gels','gold','held','weld'},
'gels':	{'eels','gals','gel','geld','gems','gets'},
'gem':	{'em','fem','ge','gee','gel','gems','gen','ger','germ','get','gm','gum','gym','hem','rem'},
'gems':	{'gels','gem','germs','gets','gums','gyms'},
'gemstone':	{'gemstones'},
'gemstones':	{'gemstone'},
'gen':	{'ben','den','en','fen','ge','gee','gel','gem','gene','gent','ger','get','gin','glen','gun','hen','ken','men','pen','sen','ten','wen','yen','zen'},
'gender':	{'bender','fender','genders','lender','render','sender','tender'},
'genders':	{'fenders','gender','lenders','renders','senders','tenders'},
'gene':	{'ene','gee','gen','genes','genet','genie','genre','gent','gente','gone'},
'genera':	{'general','geneva'},
'general':	{'genera','generals'},
'generalisation':	{'generalisations','generalization'},
'generalisations':	{'generalisation','generalizations'},
'generalise':	{'generalised','generalize'},
'generalised':	{'generalise','generalized'},
'generalization':	{'generalisation','generalizations'},
'generalizations':	{'generalisations','generalization'},
'generalize':	{'generalise','generalized'},
'generalized':	{'generalised','generalize'},
'generals':	{'general'},
'generate':	{'generated','generates'},
'generated':	{'generate','generates'},
'generates':	{'generate','generated'},
'generation':	{'generations'},
'generations':	{'generation'},
'generator':	{'generators'},
'generators':	{'generator'},
'generic':	{'generics','genetic'},
'generics':	{'generic','genetics'},
'genes':	{'gene','genet','genres','gents','genus'},
'genet':	{'gene','genes','gent','tenet'},
'genetic':	{'generic','genetics'},
'genetics':	{'generics','genetic'},
'geneva':	{'genera'},
'genie':	{'gene','genre','gente'},
'genital':	{'genitals'},
'genitals':	{'genital'},
'genius':	{'genus'},
'genome':	{'genomes','gnome'},
'genomes':	{'genome'},
'genotype':	{'genotypes'},
'genotypes':	{'genotype'},
'genre':	{'gene','genie','genres','gente'},
'genres':	{'genes','genre'},
'gent':	{'agent','bent','cent','dent','gen','gene','genet','gente','gents','get','ghent','kent','lent','rent','sent','tent','vent','went'},
'gente':	{'gene','genie','genre','gent','gentle','gents'},
'gentile':	{'gentiles','gentle'},
'gentiles':	{'gentile'},
'gentle':	{'gente','gentile','gently'},
'gentleman':	{'gentlemen'},
'gentlemen':	{'gentleman'},
'gently':	{'gentle','gentry'},
'gentry':	{'entry','gently','sentry'},
'gents':	{'agents','cents','dents','genes','gent','gente','genus','gets','rents','tents','vents'},
'genus':	{'genes','genius','gents','gnus','menus','venus'},
'george':	{'gorge'},
'georgia':	{'georgian'},
'georgian':	{'georgia'},
'ger':	{'aer','ber','der','er','fer','gar','ge','gear','gee','gel','gem','gen','germ','get','her','ker','per','yer'},
'geriatric':	{'geriatrics'},
'geriatrics':	{'geriatric'},
'germ':	{'gem','ger','germs','perm','term'},
'german':	{'germany','herman'},
'germany':	{'german'},
'germination':	{'termination'},
'germs':	{'gems','germ','terms'},
'gesture':	{'gestures'},
'gestures':	{'gesture'},
'get':	{'bet','et','ge','gee','gel','gem','gen','gent','ger','gets','git','gmt','got','gut','jet','let','met','net','pet','set','tet','vet','wet','yet'},
'getaway':	{'getaways'},
'getaways':	{'getaway'},
'gets':	{'bets','gels','gems','gents','get','guts','lets','nets','pets','sets','vets','wets'},
'getting':	{'betting','letting','netting','setting','wetting'},
'gf':	{'af','cf','f','ff','g','ga','gb','gd','ge','gi','gm','go','gp','gu','hf','if','of','rf'},
'ghent':	{'gent'},
'ghost':	{'ghosts','host'},
'ghosts':	{'ghost','hosts'},
'gi':	{'ai','bi','ci','di','g','ga','gb','gd','ge','gf','gig','gin','git','gm','go','gp','gu','gui','hi','i','ii','ji','ki','li','mi','ni','pi','qi','ri','si','ti','vi','wi','xi','yi'},
'gian':	{'giant','gin','gran','xian'},
'giant':	{'gian','grant'},
'gibbon':	{'gibson','ribbon'},
'gibson':	{'gibbon'},
'gift':	{'gifts','gilt','gist','git','lift','rift','sift'},
'gifted':	{'lifted'},
'gifts':	{'gift','lifts'},
'gig':	{'big','dig','fig','gag','gi','gigs','gin','git','jig','pig','rig','sig','wig'},
'giggle':	{'giggles','goggle','wiggle'},
'giggles':	{'giggle','goggles','wiggles'},
'gigs':	{'digs','figs','gags','gig','pigs','rigs','wigs'},
'gila':	{'gala','gill','gilt','vila'},
'gilbert':	{'hilbert'},
'gill':	{'bill','dill','fill','gall','gila','gilt','girl','grill','gull','hill','ill','kill','mill','pill','sill','till','will'},
'gilt':	{'gift','gila','gill','gist','git','guilt','kilt','milt','silt','tilt','wilt'},
'gimmick':	{'gimmicks'},
'gimmicks':	{'gimmick'},
'gimp':	{'imp','limp','pimp'},
'gin':	{'bin','din','fin','gain','gen','gi','gian','gig','git','grin','gun','in','kin','lin','min','pin','qin','sin','tin','win','yin'},
'ginger':	{'finger','linger','ringer','singer','winger'},
'girl':	{'gill','girls','giro'},
'girlfriend':	{'girlfriends'},
'girlfriends':	{'girlfriend'},
'girls':	{'girl'},
'giro':	{'girl','miro'},
'girth':	{'birth','firth'},
'gist':	{'fist','gift','gilt','git','grist','gust','hist','list','mist'},
'git':	{'bit','fit','gait','get','gi','gift','gig','gilt','gin','gist','gmt','got','grit','gut','hit','it','kit','lit','mit','nit','pit','sit','tit','wit'},
'give':	{'dive','five','gave','given','giver','gives','hive','jive','live'},
'giveaway':	{'giveaways'},
'giveaways':	{'giveaway'},
'given':	{'give','giver','gives'},
'giver':	{'diver','give','given','gives','liver','river'},
'gives':	{'dives','fives','give','given','giver','hives','ives','lives','wives'},
'giving':	{'diving','living'},
'glacier':	{'glaciers'},
'glaciers':	{'glacier'},
'glad':	{'clad','glade','glam','gland','grad','lad'},
'gladder':	{'bladder','ladder'},
'glade':	{'blade','glad','glare','glaze','glide','grade'},
'glam':	{'clam','glad','gram','guam','lam','slam'},
'glance':	{'glanced','glances','lance'},
'glanced':	{'glance','glances'},
'glances':	{'glance','glanced'},
'gland':	{'bland','glad','glands','grand','land'},
'glands':	{'gland','lands'},
'glare':	{'flare','glade','glaze'},
'glaring':	{'gearing','glazing'},
'glaser':	{'laser'},
'glass':	{'class','gloss','grass','lass'},
'glasses':	{'classes','grasses'},
'glaze':	{'blaze','gaze','glade','glare','glazed'},
'glazed':	{'gazed','glaze'},
'glazing':	{'blazing','gazing','glaring','grazing'},
'gleaned':	{'cleaned','leaned'},
'glee':	{'flee','gee','glen','glue','klee','lee'},
'glen':	{'galen','gen','glee','glenn','glens'},
'glenn':	{'glen','glens'},
'glens':	{'glen','glenn','lens'},
'glib':	{'lib'},
'glide':	{'glade','glider','guide','slide'},
'glider':	{'glide','gliders','slider'},
'gliders':	{'glider','sliders'},
'gliding':	{'guiding','sliding'},
'glimpse':	{'glimpses'},
'glimpses':	{'glimpse'},
'glistening':	{'listening'},
'glitter':	{'litter'},
'globalisation':	{'globalization'},
'globalization':	{'globalisation'},
'globe':	{'globes','glove','lobe'},
'globes':	{'globe','gloves','lobes'},
'gloom':	{'bloom','gloomy','groom','loom'},
'gloomy':	{'gloom'},
'glory':	{'gory'},
'gloss':	{'floss','glass','glossy','gross','loss'},
'glossy':	{'gloss'},
'glove':	{'clove','globe','gloves','grove','love'},
'gloves':	{'cloves','globes','glove','groves','loves'},
'glow':	{'blow','flow','grow','low','plow','slow'},
'glowing':	{'blowing','flowing','growing','lowing','slowing'},
'glue':	{'blue','clue','flue','glee','glued','glut'},
'glued':	{'glue'},
'glut':	{'glue','gout','gut','slut'},
'gm':	{'am','bm','cm','em','fm','g','ga','gb','gd','ge','gem','gf','gi','gmt','go','gp','gu','gum','gym','hm','km','mm','nm','pm','rm','sm','tm','um','wm'},
'gmt':	{'get','git','gm','got','gut','mt'},
'gnats':	{'goats'},
'gnome':	{'genome','nome'},
'gnp':	{'gap','gdp','gnu','gop','gp','np'},
'gnu':	{'gnp','gnus','gu','nu'},
'gnus':	{'anus','genus','gnu','onus'},
'go':	{'ago','co','do','ego','fo','g','ga','gao','gb','gd','ge','gf','gi','gm','goa','god','goo','gop','got','gp','gpo','gu','ho','io','ko','lo','mo','no','o','po','so','to','wo'},
'goa':	{'boa','ga','go','goal','goat','god','goo','gop','got','goya','gpa','gsa'},
'goal':	{'coal','foal','gal','goa','goals','goat'},
'goals':	{'coals','gals','goal','goats'},
'goat':	{'boat','coat','goa','goal','goats','got','gout','govt','oat'},
'goats':	{'boats','coats','gnats','goals','goat','oats'},
'god':	{'bod','cod','dod','gd','go','goa','gods','gold','goo','good','gop','got','mod','nod','od','pod','rod','sod','tod'},
'gods':	{'god','goes','goods','mods','nods','pods','rods'},
'goers':	{'goes'},
'goes':	{'does','foes','gods','goers','hoes','toes','woes'},
'goggle':	{'giggle','goggles','google','toggle'},
'goggles':	{'giggles','goggle'},
'going':	{'doing','goings','gong'},
'goings':	{'going'},
'gold':	{'bold','cold','fold','geld','god','golf','good','gould','hold','mold','old','sold','told'},
'golding':	{'folding','golfing','holding','molding'},
'goldman':	{'goodman'},
'golf':	{'gold','gulf','rolf','wolf'},
'golfer':	{'golfers'},
'golfers':	{'golfer'},
'golfing':	{'golding'},
'gone':	{'bone','cone','done','gene','gong','gore','hone','lone','none','one','tone','zone'},
'gong':	{'bong','dong','gang','going','gone','long','pong','song'},
'gonna':	{'donna'},
'goo':	{'boo','coo','gao','go','goa','god','good','gop','got','gpo','loo','moo','poo','too','woo','zoo'},
'good':	{'food','god','gold','goo','goods','goody','hood','mood','wood'},
'goodbye':	{'goodbyes'},
'goodbyes':	{'goodbye'},
'goodman':	{'goldman','woodman'},
'goods':	{'foods','gods','good','goody','goofs','hoods','moods','woods'},
'goody':	{'good','goods','goofy','moody','woody'},
'goofs':	{'goods','goofy','roofs'},
'goofy':	{'goody','goofs'},
'google':	{'goggle'},
'goose':	{'loose','moose'},
'gop':	{'bop','cop','gap','gdp','gnp','go','goa','god','goo','got','gp','hop','mop','op','pop','sop','top','wop'},
'gore':	{'bore','core','fore','gone','gorge','gory','lore','more','ore','pore','sore','tore','wore'},
'gorge':	{'forge','george','gore'},
'gory':	{'gary','glory','gore','tory'},
'gosh':	{'goth','josh','posh'},
'gospel':	{'gospels'},
'gospels':	{'gospel'},
'got':	{'bot','cot','dot','get','git','gmt','go','goa','goat','god','goo','gop','goth','gout','govt','gut','hot','lot','mot','not','pot','rot','sot','tot','wot'},
'goth':	{'both','doth','gosh','got','moth','roth'},
'gotten':	{'rotten'},
'gould':	{'could','gold','mould','would'},
'gout':	{'bout','glut','goat','got','govt','grout','gut','out','rout','tout'},
'govern':	{'governs'},
'government':	{'governments'},
'governments':	{'government'},
'governor':	{'governors'},
'governors':	{'governor'},
'governs':	{'govern'},
'govt':	{'goat','got','gout'},
'gown':	{'down','gowns','grown','own','sown','town'},
'gowns':	{'downs','gown','owns','towns'},
'goya':	{'goa'},
'gp':	{'dp','g','ga','gap','gb','gd','gdp','ge','gf','gi','gm','gnp','go','gop','gpa','gpo','gu','hp','ip','kp','lp','mp','np','op','p','up'},
'gpa':	{'cpa','epa','ga','goa','gp','gpo','gsa','pa','spa'},
'gpo':	{'apo','gao','go','goo','gp','gpa','po'},
'grab':	{'arab','crab','gab','grabs','grad','gram','gran','gray','grub'},
'grabbed':	{'grabber'},
'grabber':	{'grabbed'},
'grabs':	{'crabs','grab','grads','grams','grass','grays'},
'grace':	{'brace','graced','graces','gracie','grade','grape','grate','grave','race','trace'},
'graced':	{'grace','graces','graded','grated','raced','traced'},
'graceful':	{'grateful'},
'gracefully':	{'gratefully'},
'graces':	{'braces','grace','graced','grades','grapes','graves','races','traces'},
'gracie':	{'grace'},
'gracing':	{'bracing','grading','grating','grazing','racing','tracing'},
'grad':	{'brad','glad','grab','grade','grads','gram','gran','grand','gray','grid','rad','trad'},
'grade':	{'glade','grace','grad','graded','grader','grades','grads','grape','grate','grave','trade'},
'graded':	{'graced','grade','grader','grades','grated','traded'},
'grader':	{'grade','graded','graders','grades','trader'},
'graders':	{'grader','grades','traders'},
'grades':	{'graces','grade','graded','grader','graders','grads','grapes','graves','trades'},
'gradient':	{'gradients'},
'gradients':	{'gradient'},
'grading':	{'gracing','grating','grazing','trading'},
'grads':	{'grabs','grad','grade','grades','grams','grass','grays','grids'},
'graduate':	{'graduated','graduates'},
'graduated':	{'graduate','graduates'},
'graduates':	{'graduate','graduated'},
'graft':	{'craft','draft','grafts','grant','kraft','raft'},
'grafting':	{'crafting','drafting','granting','grating','rafting'},
'grafts':	{'crafts','drafts','graft','grants'},
'grail':	{'frail','grain','rail','trail'},
'grain':	{'brain','drain','gain','grail','grains','gran','grin','groin','rain','train'},
'grained':	{'drained','gained','rained','trained'},
'grains':	{'brains','drains','gains','grain','grins','rains','trains'},
'gram':	{'cram','dram','glam','grab','grad','grams','gran','gray','grim','guam','ram','tram'},
'grammar':	{'grammars'},
'grammars':	{'grammar'},
'grams':	{'grabs','grads','gram','grass','grays'},
'gran':	{'bran','gian','grab','grad','grain','gram','grand','grant','gray','grin','groan','iran','ran'},
'granada':	{'grenada'},
'grand':	{'brand','gland','grad','gran','grant','grind','rand'},
'granddaughter':	{'granddaughters'},
'granddaughters':	{'granddaughter'},
'grandma':	{'grandpa'},
'grandpa':	{'grandma'},
'grandparent':	{'grandparents'},
'grandparents':	{'grandparent'},
'grandson':	{'grandsons'},
'grandsons':	{'grandson'},
'grange':	{'granger','grunge','orange','range'},
'granger':	{'grange','ranger'},
'grant':	{'brant','giant','graft','gran','grand','grants','grunt','rant'},
'granted':	{'grantee','grated'},
'grantee':	{'granted','grantees'},
'grantees':	{'grantee'},
'granting':	{'grafting','grating','ranting'},
'grants':	{'grafts','grant','rants'},
'grape':	{'grace','grade','grapes','graph','grate','grave','gripe','rape'},
'grapes':	{'drapes','graces','grades','grape','graphs','graves','rapes'},
'graph':	{'grape','graphs'},
'graphic':	{'graphics'},
'graphics':	{'graphic'},
'graphs':	{'grapes','graph'},
'grasp':	{'gasp','grass'},
'grasped':	{'gasped'},
'grass':	{'brass','glass','grabs','grads','grams','grasp','grassy','grays','gross'},
'grasses':	{'glasses'},
'grassland':	{'grasslands'},
'grasslands':	{'grassland'},
'grassy':	{'grass'},
'grate':	{'crate','gate','grace','grade','grape','grated','grave','rate'},
'grated':	{'gated','graced','graded','granted','grate','rated'},
'grateful':	{'graceful'},
'gratefully':	{'gracefully'},
'gratification':	{'ratification'},
'grating':	{'gracing','grading','grafting','granting','grazing','rating'},
'grave':	{'brave','crave','gave','grace','grade','grape','grate','gravel','graves','gravy','grove','rave'},
'gravel':	{'grave','gravely','graves','ravel','travel'},
'gravely':	{'bravely','gravel'},
'graves':	{'braves','graces','grades','grapes','grave','gravel','groves','raves'},
'gravy':	{'grave','gray'},
'gray':	{'bray','fray','gay','grab','grad','gram','gran','gravy','grays','grey','pray','ray','tray'},
'grays':	{'gays','grabs','grads','grams','grass','gray','prays','rays','trays'},
'grazing':	{'gazing','glazing','gracing','grading','grating'},
'grease':	{'crease','greased','greases','greasy'},
'greased':	{'creased','grease','greases'},
'greases':	{'creases','grease','greased'},
'greasy':	{'grease'},
'great':	{'greats','greet','treat'},
'greats':	{'great','greets','treats'},
'greece':	{'greene'},
'greed':	{'agreed','breed','creed','freed','greedy','greek','green','greet','reed'},
'greedy':	{'greed'},
'greek':	{'creek','geek','greed','green','greet'},
'green':	{'greed','greek','greene','greens','greet'},
'greene':	{'greece','green','greener','greens'},
'greener':	{'greene','greenery'},
'greenery':	{'greener'},
'greenhouse':	{'greenhouses'},
'greenhouses':	{'greenhouse'},
'greening':	{'greeting'},
'greens':	{'green','greene','greets'},
'greet':	{'great','greed','greek','green','greets'},
'greeting':	{'greening','greetings'},
'greetings':	{'greeting'},
'greets':	{'greats','greens','greet'},
'grenada':	{'granada','grenade'},
'grenade':	{'grenada','grenades'},
'grenades':	{'grenade'},
'grep':	{'grew','grey','grip','prep','rep'},
'grew':	{'brew','crew','drew','grep','grey','grow'},
'grey':	{'frey','gray','grep','grew','prey','trey'},
'greyhound':	{'greyhounds'},
'greyhounds':	{'greyhound'},
'grid':	{'arid','grad','grids','grim','grin','grind','grip','gris','grit','rid'},
'grids':	{'grads','grid','grinds','grins','grips','gris','rids'},
'grief':	{'brief'},
'grievance':	{'grievances'},
'grievances':	{'grievance'},
'grill':	{'brill','drill','gill','grille','grills'},
'grille':	{'grill','grilled','grilles','grills'},
'grilled':	{'drilled','grille','grilles'},
'grilles':	{'grille','grilled','grills'},
'grilling':	{'drilling'},
'grills':	{'drills','frills','grill','grille','grilles'},
'grim':	{'brim','gram','grid','grimm','grin','grip','gris','grit','rim','trim'},
'grimm':	{'grim'},
'grin':	{'erin','gain','gin','grain','gran','grid','grim','grind','grins','grip','gris','grit','groin'},
'grind':	{'grand','grid','grin','grinds','grins'},
'grinder':	{'grinders'},
'grinders':	{'grinder'},
'grinding':	{'grinning'},
'grinds':	{'grids','grind','grins'},
'grinning':	{'grinding'},
'grins':	{'gains','grains','grids','grin','grind','grinds','grips','gris'},
'grip':	{'drip','grep','grid','grim','grin','gripe','grips','gris','grit','rip','trip'},
'gripe':	{'grape','grip','grips','ripe'},
'gripped':	{'ripped','tripped'},
'gripping':	{'dripping','ripping','tripping'},
'grips':	{'grids','grins','grip','gripe','gris','rips','trips'},
'gris':	{'grid','grids','grim','grin','grins','grip','grips','grist','grit','iris','kris'},
'grist':	{'gist','gris','grit','wrist'},
'grit':	{'brit','gait','git','grid','grim','grin','grip','gris','grist','writ'},
'groan':	{'gran','groin','grown'},
'grocers':	{'grocery','growers'},
'grocery':	{'grocers'},
'groin':	{'grain','grin','groan','grown'},
'groom':	{'broom','gloom','room'},
'groove':	{'grooves','groovy','grove'},
'grooves':	{'groove','groves'},
'groovy':	{'groove'},
'gross':	{'cross','gloss','grass','grows','ross'},
'ground':	{'around','grounds','round'},
'grounded':	{'rounded'},
'grounding':	{'rounding'},
'grounds':	{'ground','rounds'},
'group':	{'groups','grout'},
'grouping':	{'groupings'},
'groupings':	{'grouping'},
'groups':	{'group'},
'grouse':	{'arouse','rouse'},
'grout':	{'gout','group','rout','trout'},
'grove':	{'drove','glove','grave','groove','groves','prove','rove','trove'},
'groves':	{'gloves','graves','grooves','grove','proves'},
'grow':	{'brow','crow','glow','grew','grown','grows','row'},
'grower':	{'growers'},
'growers':	{'grocers','grower'},
'growing':	{'glowing','rowing'},
'grown':	{'brown','crown','drown','frown','gown','groan','groin','grow','grows'},
'grows':	{'brows','crows','gross','grow','grown','rows'},
'grub':	{'grab','rub'},
'grudge':	{'drudge','grunge'},
'grunge':	{'grange','grudge'},
'grunt':	{'grant'},
'gsa':	{'ga','goa','gpa','sa','ssa','usa'},
'gu':	{'au','cu','du','eu','g','ga','gb','gd','ge','gf','gi','gm','gnu','go','gp','gui','gum','gun','gut','guy','ju','lu','mu','nu','pu','ru','su','u','wu','zu'},
'guam':	{'glam','gram','gum'},
'guarantee':	{'guaranteed','guarantees'},
'guaranteed':	{'guarantee','guarantees'},
'guarantees':	{'guarantee','guaranteed'},
'guard':	{'guards'},
'guardian':	{'guardians'},
'guardians':	{'guardian'},
'guards':	{'guard'},
'guatemala':	{'guatemalan'},
'guatemalan':	{'guatemala'},
'guerrilla':	{'guerrillas'},
'guerrillas':	{'guerrilla'},
'guess':	{'guest','guests'},
'guessed':	{'guesses'},
'guesses':	{'guessed'},
'guest':	{'guess','guests','gust','quest'},
'guesthouse':	{'guesthouses'},
'guesthouses':	{'guesthouse'},
'guests':	{'guess','guest','gusts','quests'},
'gui':	{'gi','gu','gum','gun','gut','guy','hui'},
'guiana':	{'guyana'},
'guide':	{'glide','guided','guides','guile','guise'},
'guidebook':	{'guidebooks'},
'guidebooks':	{'guidebook'},
'guided':	{'guide','guides'},
'guideline':	{'guidelines'},
'guidelines':	{'guideline'},
'guides':	{'guide','guided'},
'guiding':	{'gliding'},
'guild':	{'build','guilds','guile','guilt'},
'guilder':	{'builder','guilders'},
'guilders':	{'builders','guilder'},
'guilds':	{'builds','guild'},
'guile':	{'guide','guild','guilt','guise'},
'guilt':	{'built','gilt','guild','guile','guilty','quilt'},
'guilty':	{'guilt'},
'guise':	{'guide','guile'},
'guitar':	{'guitars'},
'guitarist':	{'guitarists'},
'guitarists':	{'guitarist'},
'guitars':	{'guitar'},
'gujarat':	{'gujarati'},
'gujarati':	{'gujarat'},
'gulch':	{'mulch'},
'gulf':	{'golf','gull'},
'gull':	{'bull','dull','full','gall','gill','gulf','gully','hull','mull','null','pull'},
'gully':	{'bully','fully','gull','sully','tully'},
'gum':	{'bum','cum','gem','gm','gu','guam','gui','gums','gun','gut','guy','gym','hum','mum','rum','sum','um','yum'},
'gums':	{'gems','gum','guns','guts','guys','gyms','mums','sums'},
'gun':	{'bun','dun','fun','gen','gin','gu','gui','gum','guns','gut','guy','hun','nun','pun','run','sun','un'},
'gunner':	{'runner'},
'guns':	{'buns','gums','gun','guts','guys','nuns','runs','suns'},
'guru':	{'gurus'},
'gurus':	{'guru'},
'gushing':	{'pushing','rushing'},
'gust':	{'bust','dust','gist','guest','gusts','gut','just','lust','must','rust'},
'gusts':	{'dusts','guests','gust','guts','rusts'},
'gut':	{'but','cut','get','git','glut','gmt','got','gout','gu','gui','gum','gun','gust','guts','guy','hut','nut','out','put','rut','tut','ut'},
'guts':	{'cuts','gets','gums','guns','gusts','gut','guys','huts','nuts','outs','puts'},
'gutted':	{'gutter'},
'gutter':	{'butter','cutter','gutted','gutters','putter','utter'},
'gutters':	{'butters','cutters','gutter','putters'},
'guy':	{'buy','gay','gu','gui','gum','gun','gut','guys'},
'guyana':	{'guiana'},
'guys':	{'buys','gays','gums','guns','guts','guy'},
'gym':	{'gem','gm','gum','gyms'},
'gyms':	{'gems','gums','gym'},
'h':	{'a','b','c','d','e','eh','f','g','ha','he','hf','hg','hi','hm','ho','hp','hq','hr','hs','ht','hz','i','j','k','l','nh','o','oh','p','ph','q','r','rh','sh','t','th','u','uh','v','w','x','y','z'},
'ha':	{'a','ba','ca','cha','da','ea','fa','fha','ga','h','had','ham','han','hao','hap','has','hat','haw','hay','he','hf','hg','hi','hm','ho','hp','hq','hr','hs','ht','hua','hz','ia','ka','la','ma','na','pa','ra','sa','ta','va','wa','ya','za'},
'habit':	{'habits'},
'habitat':	{'habitats'},
'habitats':	{'habitat'},
'habits':	{'habit'},
'hack':	{'back','hacks','hank','hawk','heck','huck','jack','lack','mack','pack','rack','sack','shack','tack','whack'},
'hacked':	{'backed','hacker','lacked','packed','sacked'},
'hacker':	{'hacked','hackers','hawker','packer'},
'hackers':	{'backers','hacker'},
'hacking':	{'backing','hawking','jacking','lacking','packing','racking'},
'hacks':	{'backs','hack','hanks','jacks','lacks','packs','racks','sacks'},
'had':	{'ad','bad','cad','chad','dad','fad','ha','hadn','ham','han','hand','hao','hap','hard','has','hat','haw','hay','head','hid','hud','lad','mad','pad','rad','sad','shad','tad','wad'},
'hades':	{'fades','hates','haves','hayes','hides','shades'},
'hadn':	{'had','hahn','han','hasn','haydn'},
'haha':	{'hahn'},
'hahn':	{'hadn','haha','han','hasn'},
'hail':	{'bail','dail','fail','hails','hair','hall','haul','jail','mail','nail','rail','sail','tail'},
'hailed':	{'failed','haired','hauled','jailed','mailed','nailed','sailed','tailed'},
'hails':	{'fails','hail','hairs','halls','jails','mails','nails','rails','sails','tails'},
'hair':	{'air','chair','fair','hail','hairs','hairy','heir','lair','pair'},
'haired':	{'aired','chaired','hailed','hatred','hired','paired'},
'hairs':	{'airs','chairs','fairs','hails','hair','hairy','heirs','pairs'},
'hairy':	{'airy','dairy','fairy','hair','hairs','harry'},
'hale':	{'ale','bale','dale','gale','haley','half','hall','halo','halt','hare','hate','have','haze','hole','male','pale','sale','shale','tale','vale','whale','yale'},
'haley':	{'hale','halley'},
'half':	{'calf','hale','hall','halo','halt'},
'halfway':	{'hallway'},
'hall':	{'all','ball','call','fall','gall','hail','hale','half','hallo','halls','halo','halt','haul','hell','hill','hull','mall','pall','shall','tall','wall'},
'halley':	{'alley','galley','haley','valley'},
'hallmark':	{'hallmarks'},
'hallmarks':	{'hallmark'},
'hallo':	{'hall','halls','halo','hello','hullo'},
'halls':	{'balls','calls','falls','hails','hall','hallo','halts','hells','hills','malls','walls'},
'hallway':	{'halfway','hallways'},
'hallways':	{'hallway'},
'halo':	{'hale','half','hall','hallo','halt','hao'},
'halt':	{'alt','hale','half','hall','halo','halts','hart','hast','hat','malt','salt','shalt'},
'halted':	{'halter','halved','hated','salted'},
'halter':	{'alter','halted','salter','walter'},
'halting':	{'hating'},
'halts':	{'halls','halt','hats','salts'},
'halved':	{'halted','halves'},
'halves':	{'calves','halved','haves','valves'},
'ham':	{'am','cam','dam','ha','had','han','hao','hap','harm','has','hat','haw','hay','hem','him','hm','hum','jam','lam','ram','sam','sham','tam','yam'},
'hamburger':	{'hamburgers'},
'hamburgers':	{'hamburger'},
'hamlet':	{'hamlets'},
'hamlets':	{'hamlet'},
'hammer':	{'hammers','hamper','hummer'},
'hammered':	{'hampered'},
'hammers':	{'hammer','hampers'},
'hammock':	{'hammocks'},
'hammocks':	{'hammock'},
'hamper':	{'camper','damper','hammer','hampers','harper','pamper','tamper'},
'hampered':	{'hammered','pampered'},
'hampers':	{'campers','hammers','hamper'},
'hamster':	{'hamsters'},
'hamsters':	{'hamster'},
'han':	{'an','ban','can','fan','ha','had','hadn','hahn','ham','hand','hang','hank','hao','hap','has','hasn','hat','haw','hay','hen','hon','hun','jan','khan','lan','man','nan','pan','ran','shan','tan','than','van','wan'},
'hand':	{'and','band','had','han','hands','handy','hang','hank','hard','hind','land','rand','sand','wand'},
'handbag':	{'handbags'},
'handbags':	{'handbag'},
'handball':	{'hardball'},
'handbook':	{'handbooks'},
'handbooks':	{'handbook'},
'handed':	{'banded','handel','handled','hanged','landed'},
'handel':	{'handed'},
'handful':	{'handfuls'},
'handfuls':	{'handful'},
'handgun':	{'handguns'},
'handguns':	{'handgun'},
'handicraft':	{'handicrafts'},
'handicrafts':	{'handicraft'},
'handing':	{'banding','handling','hanging','harding','landing','sanding'},
'handkerchief':	{'handkerchiefs'},
'handkerchiefs':	{'handkerchief'},
'handle':	{'candle','handled','handler','handles'},
'handled':	{'handed','handle','handler','handles'},
'handler':	{'chandler','handle','handled','handlers','handles'},
'handlers':	{'handler','handles'},
'handles':	{'candles','handle','handled','handler','handlers'},
'handling':	{'handing'},
'handout':	{'handouts','hangout'},
'handouts':	{'handout'},
'handover':	{'hangover','hanover'},
'hands':	{'bands','hand','handy','hangs','hanks','lands','sands','wands'},
'handset':	{'handsets'},
'handsets':	{'handset'},
'handy':	{'candy','dandy','hand','hands','hardy','randy','sandy','tandy'},
'hang':	{'ang','bang','chang','dang','fang','gang','han','hand','hangs','hank','hung','pang','rang','sang','shang','tang','thang','yang'},
'hangar':	{'hanger'},
'hanged':	{'banged','changed','handed','hanger','hinged','ranged'},
'hanger':	{'anger','changer','danger','hangar','hanged','hangers','hunger','manger','ranger','sanger'},
'hangers':	{'angers','bangers','changers','dangers','hanger','hungers'},
'hanging':	{'banging','changing','handing','hangings','ranging'},
'hangings':	{'hanging'},
'hangout':	{'handout'},
'hangover':	{'handover','hanover'},
'hangs':	{'bangs','gangs','hands','hang','hanks'},
'hank':	{'bank','hack','han','hand','hang','hanks','hawk','hunk','rank','sank','shank','tank','thank','wank','yank'},
'hanks':	{'banks','hacks','hands','hangs','hank','hunks','ranks','shanks','tanks','thanks'},
'hannibal':	{'cannibal'},
'hanover':	{'handover','hangover'},
'hao':	{'gao','ha','had','halo','ham','han','hap','has','hat','haw','hay','hmo','ho','lao','mao','tao'},
'hap':	{'cap','chap','gap','ha','had','ham','han','hao','harp','has','hat','haw','hay','heap','hep','hip','hop','hp','lap','map','nap','pap','rap','sap','tap','yap','zap'},
'happen':	{'happens'},
'happening':	{'happenings'},
'happenings':	{'happening'},
'happens':	{'happen'},
'happy':	{'nappy'},
'harbor':	{'arbor','harbors','harbour'},
'harbors':	{'harbor','harbours'},
'harbour':	{'harbor','harbours'},
'harbours':	{'harbors','harbour'},
'hard':	{'bard','card','chard','had','hand','hardy','hare','harm','harp','hart','heard','herd','ward','yard'},
'hardball':	{'handball'},
'harden':	{'garden','hardens','harder','warden'},
'hardening':	{'gardening'},
'hardens':	{'gardens','harden'},
'harder':	{'harden','harper'},
'hardest':	{'harvest'},
'harding':	{'handing','harming'},
'hardly':	{'hardy'},
'hardness':	{'harness'},
'hardship':	{'hardships'},
'hardships':	{'hardship'},
'hardwood':	{'hardwoods'},
'hardwoods':	{'hardwood'},
'hardy':	{'handy','hard','hardly','harry'},
'hare':	{'are','bare','care','dare','fare','hale','hard','harm','harp','hart','harte','hate','have','haze','here','hire','mare','rare','share','ware'},
'harlow':	{'harrow'},
'harm':	{'arm','charm','farm','ham','hard','hare','harms','harp','hart','warm'},
'harmed':	{'armed','charmed','farmed','warmed'},
'harming':	{'charming','farming','harding','warming'},
'harmonic':	{'harmonica','harmonics'},
'harmonica':	{'harmonic','harmonics'},
'harmonics':	{'harmonic','harmonica','harmonies'},
'harmonies':	{'harmonics'},
'harmonisation':	{'harmonization'},
'harmonization':	{'harmonisation'},
'harms':	{'arms','charms','farms','harm','warms'},
'harness':	{'hardness'},
'harp':	{'carp','hap','hard','hare','harm','hart','sharp','warp'},
'harper':	{'hamper','harder','sharper'},
'harrier':	{'barrier','carrier'},
'harrison':	{'garrison'},
'harrow':	{'arrow','barrow','harlow','marrow','narrow'},
'harrowing':	{'narrowing'},
'harry':	{'carry','hairy','hardy','hurry','marry','parry'},
'harsh':	{'hash','marsh'},
'hart':	{'art','bart','cart','chart','dart','fart','halt','hard','hare','harm','harp','harte','hast','hat','heart','hort','hurt','kart','mart','part','tart'},
'harte':	{'arte','hare','hart','haste','hate'},
'harvest':	{'hardest','harvests'},
'harvested':	{'harvester'},
'harvester':	{'harvested'},
'harvests':	{'harvest'},
'has':	{'as','gas','ha','had','ham','han','hao','hap','hash','hasn','hast','hat','hats','haw','hay','hays','hhs','his','hos','hs','mas','oas','pas','was'},
'hash':	{'ash','bash','cash','dash','harsh','has','hasn','hast','hath','hush','lash','mash','nash','rash','sash','wash'},
'hashes':	{'ashes','dashes','lashes','washes'},
'hashing':	{'bashing','cashing','dashing','washing'},
'hasn':	{'hadn','hahn','han','has','hash','hast','wasn'},
'hassle':	{'hassles'},
'hassles':	{'hassle'},
'hast':	{'cast','east','fast','halt','hart','has','hash','hasn','haste','hasty','hat','hist','host','last','mast','past','vast'},
'haste':	{'caste','harte','hast','hasten','hasty','hate','paste','taste','waste'},
'hasten':	{'fasten','haste','hastens'},
'hastened':	{'fastened'},
'hastening':	{'fastening'},
'hastens':	{'fastens','hasten'},
'hastings':	{'castings'},
'hasty':	{'hast','haste','nasty','tasty'},
'hat':	{'at','bat','cat','chat','dat','eat','fat','ha','had','halt','ham','han','hao','hap','hart','has','hast','hate','hath','hats','haw','hay','heat','hit','hot','ht','hut','kat','lat','mat','oat','pat','phat','rat','sat','tat','that','vat','wat','what'},
'hatch':	{'batch','catch','hath','hitch','hutch','latch','match','patch','watch'},
'hatched':	{'hatchet','matched','patched','watched'},
'hatchet':	{'hatched','ratchet'},
'hatching':	{'catching','matching','patching','watching'},
'hate':	{'ate','date','fate','gate','hale','hare','harte','haste','hat','hated','hates','hath','hats','have','haze','late','mate','pate','rate','tate'},
'hated':	{'dated','fated','gated','halted','hate','hates','hatred','heated','mated','rated'},
'hateful':	{'fateful'},
'haters':	{'caters','eaters','hates','heaters','waters'},
'hates':	{'dates','fates','gates','hades','hate','hated','haters','hats','haves','hayes','mates','oates','rates'},
'hath':	{'bath','hash','hat','hatch','hate','hats','heath','math','oath','path'},
'hating':	{'dating','eating','halting','having','heating','mating','rating'},
'hatred':	{'haired','hated'},
'hats':	{'bats','cats','chats','eats','fats','halts','has','hat','hate','hates','hath','hays','heats','hits','huts','lats','mats','oats','rats','whats'},
'haul':	{'gaul','hail','hall','paul','saul'},
'hauled':	{'hailed'},
'haunt':	{'aunt','haunts','hunt'},
'haunted':	{'hunted'},
'haunting':	{'daunting','hunting'},
'haunts':	{'aunts','haunt','hunts'},
'have':	{'ave','cave','fave','gave','hale','hare','hate','haven','haves','haze','hive','pave','rave','save','shave','wave'},
'haven':	{'have','havens','haves','heaven','maven','raven'},
'havens':	{'haven','haves','heavens'},
'haves':	{'caves','hades','halves','hates','have','haven','havens','hayes','hives','raves','saves','shaves','waves'},
'having':	{'caving','hating','paving','raving','saving','shaving','waving'},
'haw':	{'ha','had','ham','han','hao','hap','has','hat','hawk','hay','how','jaw','law','paw','raw','saw','shaw','thaw'},
'hawk':	{'gawk','hack','hank','haw'},
'hawker':	{'hacker'},
'hawking':	{'hacking','hawkins'},
'hawkins':	{'hawking'},
'hawthorn':	{'hawthorne'},
'hawthorne':	{'hawthorn'},
'hay':	{'bay','cay','day','fay','gay','ha','had','ham','han','hao','hap','has','hat','haw','hays','hazy','hey','jay','lay','may','nay','pay','ray','say','shay','way'},
'haydn':	{'hadn'},
'hayes':	{'ayes','bayes','hades','hates','haves','hays'},
'hays':	{'bays','days','gays','has','hats','hay','hayes','lays','mays','nays','pays','rays','says','ways'},
'hazard':	{'hazards'},
'hazards':	{'hazard'},
'haze':	{'daze','gaze','hale','hare','hate','have','hazel','hazy','maze'},
'hazel':	{'haze'},
'hazy':	{'hay','haze','lazy'},
'he':	{'be','ce','de','e','ee','fe','ge','h','ha','hem','hen','hep','her','hex','hey','hf','hg','hi','hm','ho','hoe','hp','hq','hr','hs','ht','hue','hz','ie','le','me','ne','pe','se','she','te','the','ve','we','xe','ye'},
'head':	{'ahead','bead','dead','had','heads','heady','heal','heap','hear','heard','heat','heed','held','herd','lead','mead','read'},
'headache':	{'headaches'},
'headaches':	{'headache'},
'headed':	{'beaded','header','healed','heaped','heated','leaded'},
'header':	{'headed','headers','healer','hearer','heater','leader','reader'},
'headers':	{'header','healers','heaters','leaders','readers'},
'heading':	{'beading','headings','healing','heaping','hearing','heating','leading','reading'},
'headings':	{'heading','hearings','readings'},
'headlight':	{'headlights'},
'headlights':	{'headlight'},
'headline':	{'deadline','headlines'},
'headlines':	{'deadlines','headline'},
'headphone':	{'headphones'},
'headphones':	{'headphone'},
'heads':	{'beads','head','heady','heals','heaps','hears','heats','herds','leads','reads'},
'headset':	{'headsets'},
'headsets':	{'headset'},
'heady':	{'head','heads','heavy','ready'},
'heal':	{'deal','head','heals','heap','hear','heat','heel','hell','meal','real','seal','teal','veal','zeal'},
'healed':	{'headed','healer','heaped','heated','sealed'},
'healer':	{'dealer','header','healed','healers','hearer','heater','heller'},
'healers':	{'dealers','headers','healer','heaters'},
'healing':	{'dealing','heading','heaping','hearing','heating','sealing'},
'heals':	{'deals','heads','heal','heaps','hears','heats','heels','hells','meals','seals'},
'health':	{'healthy','hearth','heath','wealth'},
'healthiest':	{'wealthiest'},
'healthy':	{'health','wealthy'},
'heap':	{'cheap','hap','head','heal','heaps','hear','heat','help','hemp','hep','leap','reap'},
'heaped':	{'headed','healed','heated','helped','leaped'},
'heaping':	{'heading','healing','hearing','heating','helping','leaping'},
'heaps':	{'heads','heals','heap','hears','heats','helps','leaps'},
'hear':	{'bear','dear','ear','fear','gear','head','heal','heap','heard','hears','heart','heat','heir','her','herr','lear','near','pear','rear','shear','tear','wear','year'},
'heard':	{'beard','hard','head','hear','hears','heart','herd'},
'hearer':	{'bearer','header','healer','heater','nearer','shearer','wearer'},
'hearing':	{'bearing','fearing','gearing','heading','healing','heaping','hearings','heating','herring','nearing','rearing','shearing','tearing','wearing'},
'hearings':	{'bearings','headings','hearing'},
'hears':	{'bears','dears','ears','fears','gears','heads','heals','heaps','hear','heard','hearst','heart','hearts','heats','heirs','hers','nears','pears','shears','tears','wears','years'},
'hearst':	{'hears','heart'},
'heart':	{'hart','hear','heard','hears','hearst','hearth','hearts','hearty','heat'},
'hearted':	{'heated'},
'hearth':	{'earth','health','heart','hearts','hearty','heath'},
'hearts':	{'hears','heart','hearth','hearty','heats'},
'hearty':	{'heart','hearth','hearts'},
'heat':	{'beat','cheat','eat','feat','hat','head','heal','heap','hear','heart','heath','heats','meat','neat','peat','seat','wheat'},
'heated':	{'cheated','hated','headed','healed','heaped','hearted','heater','seated'},
'heater':	{'eater','header','healer','hearer','heated','heaters','heather','neater','theater'},
'heaters':	{'eaters','haters','headers','healers','heater','theaters'},
'heath':	{'death','hath','health','hearth','heat','heats','neath','sheath'},
'heathen':	{'heather'},
'heather':	{'feather','heater','heathen','leather','weather'},
'heating':	{'beating','cheating','eating','hating','heading','healing','heaping','hearing','seating'},
'heats':	{'beats','cheats','eats','feats','hats','heads','heals','heaps','hears','hearts','heat','heath','keats','meats','seats','wheats','yeats'},
'heaven':	{'haven','heavens'},
'heavens':	{'havens','heaven'},
'heavy':	{'heady'},
'hebrew':	{'hebrews'},
'hebrews':	{'hebrew'},
'heck':	{'beck','check','deck','hack','huck','neck','peck'},
'hectare':	{'hectares'},
'hectares':	{'hectare'},
'hector':	{'rector','sector','vector'},
'hedge':	{'edge','hedges','ledge','wedge'},
'hedges':	{'edges','hedge','wedges'},
'hedging':	{'edging'},
'heed':	{'deed','feed','head','heel','held','herd','need','reed','seed','weed'},
'heel':	{'eel','feel','heal','heed','heels','hegel','hell','keel','peel','reel','wheel'},
'heels':	{'eels','feels','heals','heel','hells','reels','wheels'},
'hefty':	{'lefty'},
'hegel':	{'heel'},
'height':	{'eight','heights','weight'},
'heights':	{'eights','height','weights'},
'heir':	{'hair','hear','heirs','her','herr','meir','their','weir'},
'heirs':	{'hairs','hears','heir','hers','theirs'},
'held':	{'geld','head','heed','heli','hell','helm','help','herd','hold','weld'},
'helen':	{'helena'},
'helena':	{'helen'},
'heli':	{'deli','held','helix','hell','helm','help'},
'helicopter':	{'helicopters'},
'helicopters':	{'helicopter'},
'helix':	{'heli'},
'hell':	{'bell','cell','dell','ell','fell','hall','heal','heel','held','heli','hello','hells','helm','help','hill','hull','sell','shell','tell','well','yell'},
'heller':	{'healer','helper','keller','seller','teller'},
'hello':	{'cello','hallo','hell','hells','hullo','jello'},
'hells':	{'bells','cells','halls','heals','heels','hell','hello','helps','hills','sells','shells','tells','wells','yells'},
'helm':	{'elm','held','heli','hell','help','hem'},
'helmet':	{'helmets'},
'helmets':	{'helmet'},
'help':	{'heap','held','heli','hell','helm','helps','hemp','hep'},
'helped':	{'heaped','helper'},
'helper':	{'heller','helped','helpers'},
'helpers':	{'helper'},
'helping':	{'heaping'},
'helps':	{'heaps','hells','help'},
'hem':	{'ahem','chem','em','fem','gem','ham','he','helm','hemp','hen','hep','her','hex','hey','him','hm','hum','rem','them'},
'hemp':	{'heap','help','hem','hep','hump','temp'},
'hen':	{'ben','chen','den','en','fen','gen','han','he','hem','hens','hep','her','hex','hey','hon','hun','ken','men','pen','sen','ten','then','wen','when','yen','zen'},
'hence':	{'fence','pence','thence','whence'},
'henna':	{'senna'},
'hens':	{'ens','hen','hers','hess','lens','pens','sens','tens'},
'hep':	{'hap','he','heap','help','hem','hemp','hen','her','hex','hey','hip','hop','hp','pep','rep','sep'},
'her':	{'aer','ber','der','er','fer','ger','he','hear','heir','hem','hen','hep','herb','herd','here','hero','herr','hers','hex','hey','hr','ker','per','yer'},
'herb':	{'her','herbs','herd','here','hero','herr','hers','serb','verb'},
'herbal':	{'verbal'},
'herbicide':	{'herbicides'},
'herbicides':	{'herbicide'},
'herbs':	{'herb','herds','hers','verbs'},
'herd':	{'hard','head','heard','heed','held','her','herb','herds','here','hero','herod','herr','hers','nerd'},
'herds':	{'heads','herbs','herd','hers','nerds'},
'here':	{'ere','hare','her','herb','herd','hero','herr','hers','hire','mere','there','were','where'},
'hereafter':	{'thereafter'},
'hereby':	{'heresy','thereby','whereby'},
'herein':	{'heroin','therein','wherein'},
'hereof':	{'thereof','whereof'},
'heresy':	{'hereby'},
'hereto':	{'thereto'},
'hereunder':	{'thereunder'},
'herewith':	{'therewith'},
'heritage':	{'hermitage'},
'herman':	{'german','hermann','sherman'},
'hermann':	{'herman'},
'hermes':	{'heroes','herpes'},
'hermit':	{'permit'},
'hermitage':	{'heritage'},
'hero':	{'her','herb','herd','here','herod','heron','herr','hers','nero','zero'},
'herod':	{'herd','hero','heron'},
'heroes':	{'hermes','herpes'},
'heroic':	{'heroin'},
'heroin':	{'herein','heroic','heroine','heron'},
'heroine':	{'heroin'},
'heron':	{'hero','herod','heroin','huron'},
'herpes':	{'hermes','heroes'},
'herr':	{'err','hear','heir','her','herb','herd','here','hero','hers'},
'herrick':	{'derrick'},
'herring':	{'hearing'},
'hers':	{'hears','heirs','hens','her','herb','herbs','herd','herds','here','hero','herr','hess'},
'hesitate':	{'hesitated','hesitates'},
'hesitated':	{'hesitate','hesitates'},
'hesitates':	{'hesitate','hesitated'},
'hesitation':	{'hesitations'},
'hesitations':	{'hesitation'},
'hess':	{'chess','hens','hers','hesse','less','mess'},
'hesse':	{'hess'},
'heuristic':	{'heuristics'},
'heuristics':	{'heuristic'},
'hex':	{'ex','he','hem','hen','hep','her','hey','rex','sex'},
'hey':	{'fey','hay','he','hem','hen','hep','her','hex','key','they','whey'},
'hf':	{'af','cf','f','ff','gf','h','ha','he','hg','hi','hm','ho','hp','hq','hr','hs','ht','hz','if','of','rf','uhf','vhf'},
'hg':	{'ag','chg','g','h','ha','he','hf','hi','hm','ho','hog','hp','hq','hr','hs','ht','hug','hz','kg','mg'},
'hhs':	{'has','his','hos','hs'},
'hi':	{'ai','bi','chi','ci','di','gi','h','ha','he','hf','hg','hid','him','hip','his','hit','hiv','hm','ho','hp','hq','hr','hs','ht','hui','hz','i','ii','ji','ki','li','mi','ni','phi','pi','qi','ri','si','ti','vi','wi','xi','yi','zhi'},
'hickey':	{'dickey','hockey','mickey'},
'hid':	{'aid','bid','cid','did','had','hi','hide','him','hind','hip','his','hit','hiv','hud','id','kid','lid','mid','rid'},
'hidden':	{'ridden'},
'hide':	{'aide','hid','hides','hike','hire','hive','ride','side','tide','wide'},
'hides':	{'aides','hades','hide','hikes','hires','hives','rides','sides','tides'},
'hiding':	{'aiding','hiking','hiring','riding','siding'},
'high':	{'highs','nigh','sigh','thigh'},
'higher':	{'hither'},
'highland':	{'highlands'},
'highlands':	{'highland'},
'highlight':	{'highlights'},
'highlights':	{'highlight'},
'highs':	{'high','sighs','thighs'},
'highway':	{'highways'},
'highways':	{'highway'},
'hike':	{'bike','hide','hiker','hikes','hire','hive','ike','like','mike','nike','pike'},
'hiker':	{'biker','hike','hikers','hikes'},
'hikers':	{'bikers','hiker','hikes'},
'hikes':	{'bikes','dikes','hides','hike','hiker','hikers','hires','hives','likes','mikes','pikes'},
'hiking':	{'biking','hiding','hiring','liking','viking'},
'hilbert':	{'gilbert'},
'hill':	{'bill','chill','dill','fill','gill','hall','hell','hills','hilly','hull','ill','kill','mill','pill','sill','till','will'},
'hills':	{'bills','chills','fills','halls','hells','hill','hilly','ills','kills','mills','pills','wills'},
'hilly':	{'billy','chilly','hill','hills','holly','silly'},
'him':	{'aim','dim','ham','hem','hi','hid','hip','his','hit','hiv','hm','hum','rim','vim','whim'},
'himalaya':	{'himalayan','himalayas'},
'himalayan':	{'himalaya','himalayas'},
'himalayas':	{'himalaya','himalayan'},
'hind':	{'bind','find','hand','hid','hindi','hindu','hint','kind','lind','mind','wind'},
'hinder':	{'binder','finder','hinders','kinder','winder'},
'hinders':	{'binders','finders','hinder'},
'hindi':	{'hind','hindu'},
'hindu':	{'hind','hindi'},
'hinge':	{'binge','hinged','hinges','inge'},
'hinged':	{'hanged','hinge','hinges','hinted','ringed','tinged','winged'},
'hinges':	{'hinge','hinged'},
'hint':	{'hind','hints','hist','hit','hunt','int','lint','mint','pint','tint'},
'hinted':	{'hinged','hunted','tinted'},
'hints':	{'hint','hits','hunts','mints','pints'},
'hip':	{'chip','dip','hap','hep','hi','hid','him','hips','his','hit','hiv','hop','hp','ip','kip','lip','nip','pip','rip','ship','sip','tip','vip','whip','yip','zip'},
'hippie':	{'hippies'},
'hippies':	{'hippie'},
'hips':	{'chips','dips','hip','his','hits','hops','lips','mips','rips','ships','sips','tips','whips','zips'},
'hire':	{'dire','eire','fire','hare','here','hide','hike','hired','hires','hive','ire','lire','shire','sire','tire','wire'},
'hired':	{'aired','fired','haired','hire','hires','tired','wired'},
'hires':	{'fires','hides','hikes','hire','hired','hives','tires','wires'},
'hiring':	{'airing','firing','hiding','hiking','tiring','wiring'},
'his':	{'dis','has','hhs','hi','hid','him','hip','hips','hist','hit','hits','hiv','hos','hs','is','sis','this'},
'hist':	{'fist','gist','hast','hint','his','hit','hoist','host','list','mist'},
'historian':	{'historians'},
'historians':	{'historian'},
'hit':	{'bit','chit','fit','git','hat','hi','hid','him','hint','hip','his','hist','hits','hiv','hot','ht','hut','it','kit','lit','mit','nit','pit','shit','sit','tit','whit','wit'},
'hitch':	{'bitch','ditch','fitch','hatch','hutch','itch','pitch','witch'},
'hither':	{'either','higher','hitler','hitter','thither','whither'},
'hitler':	{'hither','hitter'},
'hits':	{'bits','fits','hats','hints','hips','his','hit','huts','its','kits','pits','sits','tits','wits'},
'hitter':	{'bitter','fitter','hither','hitler','hitters','hotter','jitter','litter','sitter'},
'hitters':	{'hitter'},
'hitting':	{'fitting','shitting','sitting'},
'hiv':	{'hi','hid','him','hip','his','hit','hive','iv','liv','xiv'},
'hive':	{'dive','five','give','have','hide','hike','hire','hiv','hives','jive','live'},
'hives':	{'dives','fives','gives','haves','hides','hikes','hires','hive','ives','lives','wives'},
'hm':	{'am','bm','cm','em','fm','gm','h','ha','ham','he','hem','hf','hg','hi','him','hmo','ho','hp','hq','hr','hs','ht','hum','hz','km','mm','nm','ohm','pm','rm','sm','tm','um','wm'},
'hmo':	{'emo','hao','hm','ho','homo','imo','mo'},
'hmong':	{'among'},
'ho':	{'co','do','fo','go','h','ha','hao','he','hf','hg','hi','hm','hmo','hob','hoe','hog','hon','hop','hos','hot','how','hp','hq','hr','hs','ht','hz','io','ko','lo','mo','no','o','po','rho','so','tho','to','who','wo'},
'hoax':	{'coax'},
'hob':	{'bob','cob','fob','ho','hobo','hoe','hog','hon','hop','hos','hot','how','hub','job','lob','mob','nob','ob','rob','sob'},
'hobbes':	{'hobbies','hobbs'},
'hobbies':	{'hobbes','lobbies'},
'hobbs':	{'hobbes','hobby'},
'hobby':	{'bobby','hobbs','hubby','lobby'},
'hobo':	{'hob','homo'},
'hockey':	{'hickey','jockey'},
'hoe':	{'doe','foe','he','ho','hob','hoes','hog','hole','home','hon','hone','hop','hope','hos','hose','hot','how','howe','hue','poe','roe','shoe','toe','woe'},
'hoes':	{'does','foes','goes','hoe','hogs','holes','homes','hopes','hops','hos','hoses','hows','hues','shoes','toes','woes'},
'hog':	{'bog','cog','dog','fog','hg','ho','hob','hoe','hogs','hon','hop','hos','hot','how','hug','jog','log'},
'hogan':	{'logan'},
'hogs':	{'dogs','hoes','hog','hops','hos','hows','hugs','logs'},
'hoist':	{'hist','horst','host','moist'},
'hold':	{'bold','cold','fold','gold','held','holds','hole','holy','hood','mold','old','sold','told'},
'holder':	{'bolder','colder','folder','holders','holier','older','solder'},
'holders':	{'folders','holder'},
'holding':	{'folding','golding','holdings','molding'},
'holdings':	{'holding'},
'holds':	{'colds','folds','hold','holes','hoods','molds'},
'hole':	{'cole','dole','hale','hoe','hold','holes','holy','home','hone','hope','hose','howe','hoyle','mole','ole','pole','role','sole','whole'},
'holes':	{'hoes','holds','hole','holmes','homes','hopes','hoses','moles','poles','roles','soles'},
'holiday':	{'holidays'},
'holidays':	{'holiday'},
'holier':	{'holder'},
'holland':	{'hollands'},
'hollands':	{'holland'},
'hollow':	{'follow','hollows'},
'hollowed':	{'followed'},
'hollowing':	{'following'},
'hollows':	{'follows','hollow'},
'holly':	{'dolly','folly','hilly','holy','hotly','jolly','molly','wholly'},
'holmes':	{'holes','homes'},
'holster':	{'bolster','holsters'},
'holsters':	{'holster'},
'holy':	{'hold','hole','holly','hotly'},
'hombre':	{'hombres'},
'hombres':	{'hombre'},
'home':	{'come','dome','hoe','hole','homer','homes','homo','hone','hope','hose','howe','hume','nome','rome','some','tome'},
'homeless':	{'hopeless'},
'homelessness':	{'hopelessness'},
'homeowner':	{'homeowners'},
'homeowners':	{'homeowner'},
'homepage':	{'homepages'},
'homepages':	{'homepage'},
'homer':	{'comer','home','homes','hover'},
'homes':	{'comes','domes','hoes','holes','holmes','home','homer','hopes','hoses'},
'homo':	{'como','hmo','hobo','home'},
'homosexual':	{'homosexuals'},
'homosexuals':	{'homosexual'},
'hon':	{'con','don','han','hen','ho','hob','hoe','hog','hone','hop','horn','hos','hot','how','hun','ion','mon','non','on','ron','son','ton','von','won','yon'},
'honduran':	{'honduras'},
'honduras':	{'honduran'},
'hone':	{'bone','cone','done','gone','hoe','hole','home','hon','honed','honey','hope','horne','hose','howe','lone','none','one','phone','rhone','shone','tone','zone'},
'honed':	{'boned','hone','honey','hoped','horned','phoned','toned','zoned'},
'honest':	{'honesty'},
'honestly':	{'honesty'},
'honesty':	{'honest','honestly'},
'honey':	{'hone','honed','honky','money'},
'honeymoon':	{'honeymoons'},
'honeymoons':	{'honeymoon'},
'honky':	{'honey'},
'honor':	{'donor','honors','honour'},
'honorable':	{'honorably','honourable'},
'honorably':	{'honorable','honourably'},
'honored':	{'honoured'},
'honors':	{'donors','honor','honours'},
'honour':	{'honor','honours'},
'honourable':	{'honorable','honourably'},
'honourably':	{'honorably','honourable'},
'honoured':	{'honored'},
'honours':	{'honors','honour'},
'hood':	{'food','good','hold','hoods','hook','hoop','hoot','mood','wood'},
'hooded':	{'hooked','wooded'},
'hoods':	{'foods','goods','holds','hood','hooks','hoops','moods','woods'},
'hook':	{'book','cook','hood','hooks','hoop','hoot','look','nook','rook','shook','took'},
'hooked':	{'booked','cooked','hooded','hooker','looked'},
'hooker':	{'booker','cooker','hooked','hoover'},
'hooking':	{'booking','cooking','looking'},
'hooks':	{'books','cooks','hoods','hook','hoops','looks'},
'hoop':	{'coop','hood','hook','hoops','hoot','hop','loop','poop'},
'hoops':	{'hoods','hooks','hoop','hops','loops'},
'hoot':	{'boot','foot','hood','hook','hoop','hort','host','hot','loot','moot','root','shoot','soot'},
'hoover':	{'hooker','hover'},
'hop':	{'bop','chop','cop','gop','hap','hep','hip','ho','hob','hoe','hog','hon','hoop','hope','hopi','hops','hos','hot','how','hp','mop','op','pop','shop','sop','top','wop'},
'hope':	{'cope','dope','hoe','hole','home','hone','hop','hoped','hopes','hopi','hops','hose','howe','hype','pope','rope'},
'hoped':	{'doped','honed','hope','hopes','hopped','hyped'},
'hopeless':	{'homeless'},
'hopelessness':	{'homelessness'},
'hopes':	{'hoes','holes','homes','hope','hoped','hops','hoses','ropes'},
'hopi':	{'hop','hope','hops'},
'hoping':	{'coping','doping','hopping'},
'hopped':	{'chopped','hoped','hopper','popped','shopped','topped'},
'hopper':	{'chopper','copper','hopped','popper','shopper','topper'},
'hopping':	{'chopping','hoping','popping','shopping','topping','whopping'},
'hops':	{'chops','cops','hips','hoes','hogs','hoops','hop','hope','hopes','hopi','hos','hows','ops','pops','shops','tops'},
'hora':	{'cora','fora','horn','hort'},
'horde':	{'hordes','horne','horse'},
'hordes':	{'horde','horses'},
'horizon':	{'horizons'},
'horizons':	{'horizon'},
'hormone':	{'hormones'},
'hormones':	{'hormone'},
'horn':	{'born','corn','hon','hora','horne','horns','horny','hort','morn','porn','thorn','torn','worn'},
'horne':	{'borne','hone','horde','horn','horned','hornet','horns','horny','horse'},
'horned':	{'honed','horne','hornet'},
'hornet':	{'horne','horned'},
'horns':	{'horn','horne','horny','thorns'},
'horny':	{'horn','horne','horns'},
'horoscope':	{'horoscopes'},
'horoscopes':	{'horoscope'},
'horrible':	{'horribly'},
'horribly':	{'horrible'},
'horror':	{'horrors'},
'horrors':	{'horror'},
'horse':	{'horde','horne','horses','horst','hose','house','morse','norse','worse'},
'horses':	{'hordes','horse','hoses','houses'},
'horst':	{'hoist','horse','hort','host','worst'},
'hort':	{'fort','hart','hoot','hora','horn','horst','host','hot','hurt','port','short','sort','tort','wort'},
'hos':	{'cos','dos','has','hhs','his','ho','hob','hoe','hoes','hog','hogs','hon','hop','hops','hose','host','hot','how','hows','hs','nos','os','sos'},
'hose':	{'bose','chose','dose','hoe','hole','home','hone','hope','horse','hos','hosea','hoses','host','house','howe','lose','nose','pose','rose','those','whose'},
'hosea':	{'hose','hoses'},
'hoses':	{'doses','hoes','holes','homes','hopes','horses','hose','hosea','hosts','houses','loses','moses','noses','poses','roses'},
'hospital':	{'hospitals'},
'hospitals':	{'hospital'},
'host':	{'cost','ghost','hast','hist','hoist','hoot','horst','hort','hos','hose','hosts','hot','lost','most','post'},
'hostage':	{'hostages','postage'},
'hostages':	{'hostage'},
'hosted':	{'hostel','posted'},
'hostel':	{'hosted','hostels','hotel'},
'hostels':	{'hostel','hostess','hotels'},
'hostess':	{'hostels'},
'hosting':	{'costing','posting'},
'hosts':	{'costs','ghosts','hoses','host','posts'},
'hot':	{'bot','cot','dot','got','hat','hit','ho','hob','hoe','hog','hon','hoot','hop','hort','hos','host','how','ht','hut','lot','mot','not','pot','rot','shot','sot','tot','wot'},
'hotel':	{'hostel','hotels','motel'},
'hotels':	{'hostels','hotel','motels'},
'hotly':	{'holly','holy'},
'hotter':	{'cotter','hitter','otter','potter'},
'hound':	{'bound','found','hounds','mound','pound','round','sound','wound'},
'hounds':	{'bounds','hound','mounds','pounds','rounds','sounds','wounds'},
'hour':	{'four','hours','our','pour','sour','tour','your'},
'hourly':	{'sourly'},
'hours':	{'fours','hour','ours','pours','sours','tours','yours'},
'house':	{'horse','hose','housed','houses','mouse','rouse'},
'housed':	{'house','houses'},
'household':	{'households'},
'householder':	{'householders'},
'householders':	{'householder'},
'households':	{'household'},
'houses':	{'horses','hoses','house','housed'},
'housing':	{'housings','rousing'},
'housings':	{'housing'},
'houston':	{'huston'},
'hover':	{'cover','dover','homer','hoover','lover','mover','over','rover'},
'hovering':	{'covering'},
'how':	{'bow','chow','cow','haw','ho','hob','hoe','hog','hon','hop','hos','hot','howe','howl','hows','low','now','ow','pow','row','show','sow','tow','vow','wow'},
'howard':	{'coward','toward'},
'howe':	{'hoe','hole','home','hone','hope','hose','how','howl','hows','owe'},
'howl':	{'bowl','fowl','how','howe','hows','owl'},
'howling':	{'bowling'},
'hows':	{'bows','cows','hoes','hogs','hops','hos','how','howe','howl','lows','rows','shows','sows','vows'},
'hoyle':	{'boyle','hole'},
'hp':	{'dp','gp','h','ha','hap','he','hep','hf','hg','hi','hip','hm','ho','hop','hq','hr','hs','ht','hz','ip','kp','lp','mp','np','op','p','up'},
'hq':	{'h','ha','he','hf','hg','hi','hm','ho','hp','hr','hs','ht','hz','iq','q'},
'hr':	{'ar','br','cr','dr','er','fr','h','ha','he','her','hf','hg','hi','hm','ho','hp','hq','hs','ht','hz','ir','jr','kr','lr','mr','or','pr','qr','r','sr','ur','yr','zr'},
'hs':	{'as','bs','cs','es','h','ha','has','he','hf','hg','hhs','hi','his','hm','ho','hos','hp','hq','hr','ht','hz','is','ks','ms','os','ps','ss','ts','us','vs'},
'ht':	{'at','ct','et','ft','h','ha','hat','he','hf','hg','hi','hit','hm','ho','hot','hp','hq','hr','hs','hut','hz','it','kt','mt','nt','pt','t','ut','vt'},
'hua':	{'ha','hub','hud','hue','hug','huh','hui','hula','hum','hun','hut','qua'},
'hub':	{'cub','dub','hob','hua','hubs','hud','hue','hug','huh','hui','hum','hun','hut','pub','rub','sub','tub'},
'hubble':	{'bubble','humble','rubble'},
'hubby':	{'chubby','hobby'},
'hubs':	{'hub','hues','hugs','huts','pubs','rubs','subs','tubs'},
'huck':	{'buck','chuck','duck','fuck','hack','heck','hulk','hunk','luck','muck','puck','suck','tuck'},
'hud':	{'bud','had','hid','hua','hub','hue','hug','huh','hui','hum','hun','hut','mud','pud'},
'hue':	{'cue','due','he','hoe','hua','hub','hud','hues','hug','huge','huh','hui','hum','hume','hun','hut','que','rue','sue'},
'hues':	{'cues','dues','hoes','hubs','hue','hugs','huts','tues'},
'huff':	{'buff','cuff','duff','puff','ruff'},
'hug':	{'aug','bug','dug','hg','hog','hua','hub','hud','hue','huge','hugo','hugs','huh','hui','hum','hun','hung','hut','jug','lug','mug','pug','rug','thug','tug'},
'huge':	{'hue','hug','hugo','hugs','hume','luge'},
'hugged':	{'rugged'},
'hugging':	{'huggins'},
'huggins':	{'hugging'},
'hugo':	{'hug','huge','hugs'},
'hugs':	{'bugs','hogs','hubs','hues','hug','huge','hugo','huts','jugs','mugs','rugs','thugs'},
'huh':	{'duh','hua','hub','hud','hue','hug','hui','hum','hun','hush','hut','uh'},
'hui':	{'gui','hi','hua','hub','hud','hue','hug','huh','hum','hun','hut','shui'},
'hula':	{'hua','hulk','hull','pula'},
'hulk':	{'bulk','huck','hula','hull','hunk'},
'hull':	{'bull','dull','full','gull','hall','hell','hill','hula','hulk','hullo','mull','null','pull'},
'hullo':	{'hallo','hello','hull'},
'hum':	{'bum','cum','gum','ham','hem','him','hm','hua','hub','hud','hue','hug','huh','hui','hume','hump','hun','hut','mum','rum','sum','um','yum'},
'human':	{'humane','humans','hunan'},
'humane':	{'human','humans'},
'humans':	{'human','humane'},
'humble':	{'bumble','fumble','hubble','humbled','humbles','humbly','jumble','rumble','tumble'},
'humbled':	{'humble','humbles','tumbled'},
'humbles':	{'humble','humbled'},
'humbling':	{'tumbling'},
'humbly':	{'humble'},
'hume':	{'fume','home','hue','huge','hum','hump'},
'humidifier':	{'humidifiers'},
'humidifiers':	{'humidifier'},
'humidity':	{'humility'},
'humility':	{'humidity'},
'hummer':	{'hammer','summer'},
'humming':	{'humping','summing'},
'humor':	{'humour','rumor','tumor'},
'humour':	{'humor','rumour','tumour'},
'hump':	{'bump','dump','hemp','hum','hume','humps','jump','lump','pump','sump'},
'humping':	{'bumping','dumping','humming','jumping','pumping'},
'humps':	{'bumps','dumps','hump','jumps','lumps','pumps'},
'hun':	{'bun','dun','fun','gun','han','hen','hon','hua','hub','hud','hue','hug','huh','hui','hum','hung','hunk','hunt','hut','nun','pun','run','shun','sun','un'},
'hunan':	{'human'},
'hundred':	{'hundreds'},
'hundreds':	{'hundred'},
'hung':	{'dung','hang','hug','hun','hunk','hunt','jung','lung','rung','sung'},
'hungary':	{'hungry'},
'hunger':	{'hanger','hungers','hunter'},
'hungers':	{'hangers','hunger','hunters'},
'hungry':	{'hungary'},
'hunk':	{'bunk','chunk','dunk','funk','hank','huck','hulk','hun','hung','hunks','hunt','junk','punk','sunk'},
'hunks':	{'chunks','hanks','hunk','hunts','punks'},
'hunt':	{'aunt','cunt','haunt','hint','hun','hung','hunk','hunts','hurt','hut','punt','shunt'},
'hunted':	{'haunted','hinted','hunter'},
'hunter':	{'hunger','hunted','hunters'},
'hunters':	{'hungers','hunter'},
'hunting':	{'bunting','haunting','hurting'},
'hunts':	{'aunts','haunts','hints','hunks','hunt','hurts','huts'},
'hurdle':	{'hurdles'},
'hurdles':	{'hurdle'},
'hurled':	{'curled'},
'huron':	{'heron'},
'hurried':	{'hurries'},
'hurries':	{'hurried'},
'hurry':	{'curry','furry','harry'},
'hurt':	{'burt','curt','hart','hort','hunt','hurts','hut'},
'hurting':	{'hunting'},
'hurts':	{'hunts','hurt','huts'},
'husband':	{'husbands'},
'husbands':	{'husband'},
'hush':	{'bush','hash','huh','lush','push','rush'},
'hustle':	{'bustle','hustler'},
'hustler':	{'hustle'},
'huston':	{'houston','hutton'},
'hut':	{'but','cut','gut','hat','hit','hot','ht','hua','hub','hud','hue','hug','huh','hui','hum','hun','hunt','hurt','huts','nut','out','put','rut','shut','tut','ut'},
'hutch':	{'butch','dutch','hatch','hitch'},
'huts':	{'cuts','guts','hats','hits','hubs','hues','hugs','hunts','hurts','hut','nuts','outs','puts','shuts'},
'hutton':	{'button','huston'},
'hybrid':	{'hybrids'},
'hybrids':	{'hybrid'},
'hydra':	{'hydro'},
'hydraulic':	{'hydraulics'},
'hydraulics':	{'hydraulic'},
'hydro':	{'hydra'},
'hydrocarbon':	{'hydrocarbons'},
'hydrocarbons':	{'hydrocarbon'},
'hymn':	{'hymns'},
'hymns':	{'hymn'},
'hype':	{'hope','hyped','hyper','type'},
'hyped':	{'hoped','hype','hyper','typed'},
'hyper':	{'hype','hyped'},
'hyperlink':	{'hyperlinks'},
'hyperlinks':	{'hyperlink'},
'hypotheses':	{'hypothesis'},
'hypothesis':	{'hypotheses','hypothesise'},
'hypothesise':	{'hypothesis','hypothesised','hypothesises','hypothesize'},
'hypothesised':	{'hypothesise','hypothesises','hypothesized'},
'hypothesises':	{'hypothesise','hypothesised','hypothesizes'},
'hypothesising':	{'hypothesizing'},
'hypothesize':	{'hypothesise','hypothesized','hypothesizes'},
'hypothesized':	{'hypothesised','hypothesize','hypothesizes'},
'hypothesizes':	{'hypothesises','hypothesize','hypothesized'},
'hypothesizing':	{'hypothesising'},
'hz':	{'az','cz','h','ha','he','hf','hg','hi','hm','ho','hp','hq','hr','hs','ht','khz','mhz','z'},
'i':	{'a','ai','b','bi','c','ci','d','di','e','f','g','gi','h','hi','ia','id','ie','if','ii','il','in','io','ip','iq','ir','is','it','iv','ix','j','ji','k','ki','l','li','mi','ni','o','p','pi','q','qi','r','ri','si','t','ti','u','v','vi','w','wi','x','xi','y','yi','z'},
'ia':	{'a','ba','ca','cia','da','ea','fa','ga','ha','i','id','ida','ie','if','ii','il','in','io','ip','iq','ir','ira','is','it','iv','iva','ix','ka','la','ma','na','pa','pia','ra','sa','ta','tia','va','via','wa','ya','za'},
'iberia':	{'iberian','liberia','siberia'},
'iberian':	{'iberia','liberian','siberian'},
'ibid':	{'bid','ibis'},
'ibis':	{'ibid','iris','isis'},
'icc':	{'cc','fcc','ice','icu','icy','inc'},
'ice':	{'ace','ce','dice','icc','iced','icu','icy','ie','ike','ire','lice','mice','nice','rice','vice'},
'iced':	{'diced','ice'},
'iceland':	{'ireland'},
'icon':	{'con','icons','ion','iron'},
'iconic':	{'ionic','ironic'},
'icons':	{'cons','icon','ions','irons'},
'icu':	{'cu','icc','ice','icy'},
'icy':	{'icc','ice','icu','ivy'},
'id':	{'ad','aid','bid','cd','cid','d','dd','did','ed','gd','hid','i','ia','ida','ie','if','ii','il','in','io','ip','iq','ir','is','it','iv','ix','kid','lid','md','mid','nd','od','pd','rid','sd','vd'},
'ida':	{'ada','da','eda','fda','ia','id','idea','ira','iva','pda','vida'},
'idea':	{'dea','ida','ideal','ideas'},
'ideal':	{'deal','idea','ideals','ideas'},
'ideals':	{'deals','ideal','ideas'},
'ideas':	{'idea','ideal','ideals'},
'identified':	{'identifier','identifies'},
'identifier':	{'identified','identifiers','identifies'},
'identifiers':	{'identifier','identifies'},
'identifies':	{'identified','identifier','identifiers','identities'},
'identify':	{'identity'},
'identities':	{'identifies'},
'identity':	{'identify'},
'idiom':	{'idioms','idiot'},
'idioms':	{'idiom','idiots'},
'idiot':	{'idiom','idiots'},
'idiots':	{'idioms','idiot'},
'idle':	{'idled','idles','idly','isle'},
'idled':	{'idle','idles'},
'idles':	{'idle','idled'},
'idly':	{'idle'},
'idol':	{'idols'},
'idols':	{'idol'},
'ie':	{'be','ce','de','die','e','ee','fe','ge','he','i','ia','ice','id','if','ii','ike','il','in','io','ip','iq','ir','ire','is','it','iv','ix','le','lie','me','ne','pe','pie','se','te','tie','ve','vie','we','xe','ye'},
'if':	{'af','cf','f','ff','gf','hf','i','ia','id','ie','ifs','ii','il','imf','in','io','ip','iq','ir','is','it','iv','ix','of','rf'},
'ifs':	{'if','ins','irs','is','its'},
'ignite':	{'ignited'},
'ignited':	{'ignite'},
'ignore':	{'ignored','ignores'},
'ignored':	{'ignore','ignores'},
'ignores':	{'ignore','ignored'},
'ii':	{'ai','bi','ci','di','gi','hi','i','ia','id','ie','if','iii','il','in','io','ip','iq','ir','is','it','iv','ix','ji','ki','li','lii','mi','ni','pi','qi','ri','si','ti','vi','vii','wi','xi','xii','yi'},
'iii':	{'ii','lii','vii','viii','xii','xiii'},
'ike':	{'bike','hike','ice','ie','ire','like','mike','nike','pike'},
'il':	{'al','bl','cl','el','fl','i','ia','id','ie','if','ii','ilk','ill','in','io','ip','iq','ir','is','it','iv','ix','l','ll','mil','ml','nil','oil','til','tl','xl'},
'ilk':	{'elk','il','ill','ink','milk','silk'},
'ill':	{'all','bill','dill','ell','fill','gill','hill','il','ilk','ills','kill','ll','mill','pill','sill','till','will'},
'ills':	{'bills','fills','hills','ill','illus','kills','mills','pills','wills'},
'illuminate':	{'illuminated','illuminates'},
'illuminated':	{'illuminate','illuminates'},
'illuminates':	{'illuminate','illuminated'},
'illus':	{'ills'},
'illusion':	{'illusions'},
'illusions':	{'illusion'},
'illustrate':	{'illustrated','illustrates'},
'illustrated':	{'illustrate','illustrates'},
'illustrates':	{'illustrate','illustrated'},
'illustration':	{'illustrations'},
'illustrations':	{'illustration'},
'illustrator':	{'illustrators'},
'illustrators':	{'illustrator'},
'image':	{'imaged','images'},
'imaged':	{'image','images'},
'images':	{'image','imaged'},
'imagination':	{'imaginations'},
'imaginations':	{'imagination'},
'imagine':	{'imagined','imagines','imaging'},
'imagined':	{'imagine','imagines'},
'imagines':	{'imagine','imagined'},
'imaging':	{'imagine'},
'imbalance':	{'imbalances'},
'imbalances':	{'imbalance'},
'imf':	{'emf','if','imo','imp'},
'imitate':	{'imitated','imitates'},
'imitated':	{'imitate','imitates'},
'imitates':	{'imitate','imitated'},
'imitation':	{'imitations','limitation'},
'imitations':	{'imitation','limitations'},
'immense':	{'immerse'},
'immerse':	{'immense','immersed'},
'immersed':	{'immerse'},
'immigrant':	{'immigrants'},
'immigrants':	{'immigrant'},
'immigrate':	{'immigrated','immigrates'},
'immigrated':	{'immigrate','immigrates'},
'immigrates':	{'immigrate','immigrated'},
'immoral':	{'immortal'},
'immortal':	{'immoral'},
'immunity':	{'impunity'},
'immunization':	{'immunizations'},
'immunizations':	{'immunization'},
'imo':	{'emo','hmo','imf','imp','io','limo','mo'},
'imp':	{'amp','gimp','imf','imo','ip','limp','mp','pimp'},
'impact':	{'impacts','impart'},
'impacts':	{'impact'},
'impairment':	{'impairments'},
'impairments':	{'impairment'},
'impart':	{'impact','import'},
'impatient':	{'inpatient'},
'impediment':	{'impediments'},
'impediments':	{'impediment'},
'imperative':	{'imperatives'},
'imperatives':	{'imperative'},
'imperialism':	{'imperialist'},
'imperialist':	{'imperialism'},
'implant':	{'implants'},
'implants':	{'implant'},
'implement':	{'implements'},
'implementation':	{'implementations'},
'implementations':	{'implementation'},
'implements':	{'implement'},
'implicate':	{'implicated','implicates'},
'implicated':	{'implicate','implicates'},
'implicates':	{'implicate','implicated'},
'implication':	{'implications'},
'implications':	{'implication'},
'implied':	{'implies'},
'implies':	{'implied'},
'imply':	{'simply'},
'import':	{'impart','imports'},
'imported':	{'importer'},
'importer':	{'imported','importers'},
'importers':	{'importer'},
'imports':	{'import'},
'impose':	{'imposed','imposes'},
'imposed':	{'impose','imposes'},
'imposes':	{'impose','imposed'},
'impossible':	{'impossibly'},
'impossibly':	{'impossible'},
'impress':	{'empress'},
'impression':	{'impressions'},
'impressionism':	{'impressionist'},
'impressionist':	{'impressionism'},
'impressions':	{'impression'},
'improve':	{'improved','improves'},
'improved':	{'improve','improves'},
'improvement':	{'improvements'},
'improvements':	{'improvement'},
'improves':	{'improve','improved'},
'impulse':	{'impulses'},
'impulses':	{'impulse'},
'impunity':	{'immunity','impurity'},
'impurity':	{'impunity'},
'in':	{'an','bin','din','en','fin','gin','i','ia','id','ie','if','ii','il','inc','ink','inn','ins','int','io','ion','ip','iq','ir','is','isn','it','iv','ix','kin','lin','min','mn','on','pin','qin','rn','sin','sn','tin','tn','un','win','yin','zn'},
'inbound':	{'unbound'},
'inc':	{'icc','in','inca','inch','incl','ink','inn','ins','int','nc','zinc'},
'inca':	{'inc','inch','incl'},
'incapacitate':	{'incapacitated'},
'incapacitated':	{'incapacitate'},
'incense':	{'intense'},
'incentive':	{'incentives','inventive'},
'incentives':	{'incentive'},
'incest':	{'invest'},
'inch':	{'finch','inc','inca','incl','itch','pinch','winch'},
'inches':	{'pinches'},
'incident':	{'incidents'},
'incidents':	{'incident'},
'incl':	{'inc','inca','inch'},
'inclement':	{'increment'},
'inclination':	{'inclinations'},
'inclinations':	{'inclination'},
'incline':	{'inclined','inclines'},
'inclined':	{'incline','inclines'},
'inclines':	{'incline','inclined'},
'include':	{'included','includes'},
'included':	{'include','includes'},
'includes':	{'include','included'},
'inclusion':	{'inclusions'},
'inclusions':	{'inclusion'},
'income':	{'incomes'},
'incomes':	{'income'},
'inconceivable':	{'inconceivably'},
'inconceivably':	{'inconceivable'},
'incorporate':	{'incorporated','incorporates'},
'incorporated':	{'incorporate','incorporates'},
'incorporates':	{'incorporate','incorporated'},
'increase':	{'increased','increases'},
'increased':	{'increase','increases'},
'increases':	{'increase','increased'},
'incredible':	{'incredibly'},
'incredibly':	{'incredible'},
'increment':	{'inclement','increments'},
'increments':	{'increment'},
'incumbent':	{'incumbents'},
'incumbents':	{'incumbent'},
'incur':	{'incurs'},
'incurs':	{'incur'},
'indebted':	{'indented'},
'indeed':	{'indexed'},
'indemnify':	{'indemnity'},
'indemnity':	{'indemnify'},
'indent':	{'intent','invent'},
'indented':	{'indebted','invented'},
'independent':	{'independents'},
'independents':	{'independent'},
'indexed':	{'indeed','indexes'},
'indexes':	{'indexed'},
'india':	{'indian','indie','indra'},
'indian':	{'india','indiana'},
'indiana':	{'indian'},
'indicate':	{'indicated','indicates'},
'indicated':	{'indicate','indicates','indicted'},
'indicates':	{'indicate','indicated'},
'indication':	{'indications'},
'indications':	{'indication'},
'indicator':	{'indicators'},
'indicators':	{'indicator'},
'indicted':	{'indicated','inducted'},
'indictment':	{'indictments'},
'indictments':	{'indictment'},
'indie':	{'india','indies'},
'indies':	{'indie','undies'},
'individual':	{'individuals'},
'individualised':	{'individualized'},
'individualism':	{'individualist'},
'individualist':	{'individualism','individualists'},
'individualists':	{'individualist'},
'individualized':	{'individualised'},
'individuals':	{'individual'},
'indonesia':	{'indonesian'},
'indonesian':	{'indonesia'},
'indoor':	{'indoors'},
'indoors':	{'indoor'},
'indra':	{'india','infra'},
'induce':	{'induced','induces'},
'induced':	{'induce','induces','inducted'},
'induces':	{'induce','induced'},
'inducted':	{'indicted','induced'},
'inept':	{'inert'},
'inert':	{'inept','insert','invert'},
'inertia':	{'inertial'},
'inertial':	{'inertia'},
'inevitable':	{'inevitably'},
'inevitably':	{'inevitable'},
'infant':	{'infants'},
'infants':	{'infant'},
'infect':	{'inject','insect'},
'infected':	{'infested','injected'},
'infecting':	{'injecting'},
'infection':	{'infections','injection'},
'infections':	{'infection','infectious','injections'},
'infectious':	{'infections'},
'infer':	{'infers','inner','inter'},
'inference':	{'inferences'},
'inferences':	{'inference'},
'inferior':	{'interior'},
'infernal':	{'internal'},
'infers':	{'infer'},
'infested':	{'infected','ingested','invested'},
'infinite':	{'infinity'},
'infinity':	{'infinite'},
'inflamed':	{'inflated'},
'inflatable':	{'inflatables'},
'inflatables':	{'inflatable'},
'inflate':	{'inflated'},
'inflated':	{'inflamed','inflate'},
'inflow':	{'inflows'},
'inflows':	{'inflow'},
'influence':	{'influenced','influences'},
'influenced':	{'influence','influences'},
'influences':	{'influence','influenced'},
'info':	{'into'},
'inform':	{'informs'},
'informacion':	{'information'},
'informant':	{'informants'},
'informants':	{'informant'},
'information':	{'informacion'},
'informed':	{'informer'},
'informer':	{'informed'},
'informs':	{'inform'},
'infra':	{'indra'},
'infrastructure':	{'infrastructures'},
'infrastructures':	{'infrastructure'},
'infringe':	{'infringed'},
'infringed':	{'infringe'},
'infringement':	{'infringements'},
'infringements':	{'infringement'},
'inge':	{'binge','hinge'},
'ingested':	{'infested','invested'},
'ingredient':	{'ingredients'},
'ingredients':	{'ingredient'},
'inhabit':	{'inhibit'},
'inhabited':	{'inhibited'},
'inhale':	{'inhaled','inhaler'},
'inhaled':	{'inhale','inhaler'},
'inhaler':	{'inhale','inhaled'},
'inherit':	{'inherits'},
'inherits':	{'inherit'},
'inhibit':	{'inhabit','inhibits'},
'inhibited':	{'inhabited'},
'inhibition':	{'inhibitions'},
'inhibitions':	{'inhibition'},
'inhibitor':	{'inhibitors','inhibitory'},
'inhibitors':	{'inhibitor','inhibitory'},
'inhibitory':	{'inhibitor','inhibitors'},
'inhibits':	{'inhibit'},
'initial':	{'initials'},
'initialize':	{'initialized'},
'initialized':	{'initialize'},
'initials':	{'initial'},
'initiate':	{'initiated','initiates'},
'initiated':	{'initiate','initiates'},
'initiates':	{'initiate','initiated'},
'initiation':	{'initiations'},
'initiations':	{'initiation'},
'initiative':	{'initiatives'},
'initiatives':	{'initiative'},
'initiator':	{'initiators'},
'initiators':	{'initiator'},
'inject':	{'infect','insect'},
'injected':	{'infected'},
'injecting':	{'infecting'},
'injection':	{'infection','injections'},
'injections':	{'infections','injection'},
'injure':	{'injured','injures','injury','insure'},
'injured':	{'injure','injures','insured'},
'injures':	{'injure','injured','injuries','insures'},
'injuries':	{'injures'},
'injuring':	{'insuring'},
'injury':	{'injure'},
'injustice':	{'injustices'},
'injustices':	{'injustice'},
'ink':	{'fink','ilk','in','inc','inks','inky','inn','ins','int','link','mink','pink','rink','sink','wink'},
'inks':	{'ink','inky','inns','ins','kinks','links','sinks'},
'inky':	{'ink','inks','kinky'},
'inland':	{'finland','island'},
'inlet':	{'inset'},
'inmate':	{'inmates','innate'},
'inmates':	{'inmate'},
'inn':	{'finn','in','inc','ink','inns','ins','int','ion','isn'},
'innate':	{'inmate'},
'inner':	{'dinner','infer','inter','sinner','winner'},
'inning':	{'innings','pinning','winning'},
'innings':	{'inning','winnings'},
'innocent':	{'innocents'},
'innocents':	{'innocent'},
'innovate':	{'innovated','innovates'},
'innovated':	{'innovate','innovates'},
'innovates':	{'innovate','innovated'},
'innovation':	{'innovations'},
'innovations':	{'innovation'},
'innovator':	{'innovators'},
'innovators':	{'innovator'},
'inns':	{'inks','inn','ins','ions'},
'inpatient':	{'impatient'},
'input':	{'inputs'},
'inputs':	{'input'},
'inquire':	{'enquire','inquired','inquirer','inquires','inquiry'},
'inquired':	{'inquire','inquirer','inquires'},
'inquirer':	{'enquirer','inquire','inquired','inquires'},
'inquires':	{'inquire','inquired','inquirer','inquiries'},
'inquiries':	{'enquiries','inquires'},
'inquiring':	{'enquiring'},
'inquiry':	{'enquiry','inquire'},
'ins':	{'ans','bins','cns','ens','fins','ifs','in','inc','ink','inks','inn','inns','inst','int','ions','irs','is','its','pins','sins','tins','wins'},
'inscription':	{'inscriptions'},
'inscriptions':	{'inscription'},
'insect':	{'infect','inject','insects','insert','inset','inspect'},
'insecticide':	{'insecticides'},
'insecticides':	{'insecticide'},
'insects':	{'insect','inserts','inspects'},
'insert':	{'inert','insect','inserts','inset','invert'},
'inserted':	{'inverted'},
'insertion':	{'insertions'},
'insertions':	{'insertion'},
'inserts':	{'insects','insert'},
'inset':	{'inlet','insect','insert','inst','onset','unset'},
'inside':	{'insider'},
'insider':	{'inside','insiders'},
'insiders':	{'insider'},
'insight':	{'insights'},
'insights':	{'insight'},
'insist':	{'insists'},
'insists':	{'insist'},
'inspect':	{'insect','inspects'},
'inspection':	{'inspections'},
'inspections':	{'inspection'},
'inspector':	{'inspectors'},
'inspectors':	{'inspector'},
'inspects':	{'insects','inspect'},
'inspiration':	{'inspirations'},
'inspirations':	{'inspiration'},
'inspire':	{'inspired','inspires'},
'inspired':	{'inspire','inspires'},
'inspires':	{'inspire','inspired'},
'inst':	{'ins','inset','int'},
'install':	{'installs','instill'},
'installation':	{'installations'},
'installations':	{'installation'},
'installed':	{'installer'},
'installer':	{'installed','installers'},
'installers':	{'installer'},
'installment':	{'installments','instalment'},
'installments':	{'installment','instalments'},
'installs':	{'install'},
'instalment':	{'installment','instalments'},
'instalments':	{'installments','instalment'},
'instance':	{'instances'},
'instances':	{'instance'},
'instill':	{'install'},
'instinct':	{'instincts'},
'instincts':	{'instinct'},
'institute':	{'instituted','institutes'},
'instituted':	{'institute','institutes'},
'institutes':	{'institute','instituted'},
'institution':	{'institutions'},
'institutionalise':	{'institutionalised','institutionalises'},
'institutionalised':	{'institutionalise','institutionalises','institutionalized'},
'institutionalises':	{'institutionalise','institutionalised','institutionalizes'},
'institutionalising':	{'institutionalizing'},
'institutionalized':	{'institutionalised','institutionalizes'},
'institutionalizes':	{'institutionalises','institutionalized'},
'institutionalizing':	{'institutionalising'},
'institutions':	{'institution'},
'instruct':	{'instructs'},
'instruction':	{'instructions'},
'instructions':	{'instruction'},
'instructor':	{'instructors'},
'instructors':	{'instructor'},
'instructs':	{'instruct'},
'instrument':	{'instruments'},
'instrumental':	{'instrumentals'},
'instrumentals':	{'instrumental'},
'instruments':	{'instrument'},
'insulated':	{'insulted'},
'insulating':	{'insulting'},
'insult':	{'insults'},
'insulted':	{'insulated'},
'insulting':	{'insulating'},
'insults':	{'insult'},
'insure':	{'ensure','injure','insured','insurer','insures','unsure'},
'insured':	{'ensured','injured','insure','insurer','insures'},
'insurer':	{'insure','insured','insurers','insures'},
'insurers':	{'insurer','insures'},
'insures':	{'ensures','injures','insure','insured','insurer','insurers'},
'insurgent':	{'insurgents'},
'insurgents':	{'insurgent'},
'insuring':	{'ensuring','injuring'},
'int':	{'ant','hint','in','inc','ink','inn','ins','inst','into','it','lint','mint','nt','ont','pint','tint','tnt'},
'intake':	{'intakes'},
'intakes':	{'intake'},
'intangible':	{'intangibles'},
'intangibles':	{'intangible'},
'integer':	{'integers'},
'integers':	{'integer'},
'integrate':	{'integrated','integrates'},
'integrated':	{'integrate','integrates'},
'integrates':	{'integrate','integrated'},
'integrator':	{'integrators'},
'integrators':	{'integrator'},
'intellectual':	{'intellectuals'},
'intellectuals':	{'intellectual'},
'intend':	{'intends','intent'},
'intends':	{'intend'},
'intense':	{'incense'},
'intensified':	{'intensifies'},
'intensifies':	{'intensified','intensities'},
'intensify':	{'intensity'},
'intension':	{'intention'},
'intensities':	{'intensifies'},
'intensity':	{'intensify'},
'intent':	{'indent','intend','invent'},
'intention':	{'intension','intentions','invention'},
'intentions':	{'intention','inventions'},
'inter':	{'enter','infer','inner','intern','winter'},
'interact':	{'interacts'},
'interaction':	{'interactions'},
'interactions':	{'interaction'},
'interacts':	{'interact'},
'interception':	{'interceptions'},
'interceptions':	{'interception'},
'interchangeable':	{'interchangeably'},
'interchangeably':	{'interchangeable'},
'interconnect':	{'interconnects'},
'interconnects':	{'interconnect'},
'interest':	{'interests'},
'interests':	{'interest'},
'interface':	{'interfaces'},
'interfaces':	{'interface'},
'interfere':	{'interfered','interferes'},
'interfered':	{'interfere','interferes'},
'interferes':	{'interfere','interfered'},
'interior':	{'anterior','inferior','interiors'},
'interiors':	{'interior'},
'intermediate':	{'intermediates'},
'intermediates':	{'intermediate'},
'intern':	{'inter','interns'},
'internal':	{'infernal','internals','interval'},
'internalise':	{'internalised','internalises','internalize'},
'internalised':	{'internalise','internalises','internalized'},
'internalises':	{'internalise','internalised','internalizes'},
'internalising':	{'internalizing'},
'internalize':	{'internalise','internalized','internalizes'},
'internalized':	{'internalised','internalize','internalizes'},
'internalizes':	{'internalises','internalize','internalized'},
'internalizing':	{'internalising'},
'internals':	{'internal','intervals'},
'international':	{'internationale','internationals'},
'internationale':	{'international','internationals'},
'internationals':	{'international','internationale'},
'interns':	{'intern'},
'internship':	{'internships'},
'internships':	{'internship'},
'interpret':	{'interprets'},
'interpretation':	{'interpretations'},
'interpretations':	{'interpretation'},
'interpreted':	{'interpreter'},
'interpreter':	{'interpreted','interpreters'},
'interpreters':	{'interpreter'},
'interprets':	{'interpret'},
'interrupt':	{'interrupts'},
'interruption':	{'interruptions'},
'interruptions':	{'interruption'},
'interrupts':	{'interrupt'},
'intersect':	{'intersects'},
'intersection':	{'intersections'},
'intersections':	{'intersection'},
'intersects':	{'intersect'},
'interval':	{'internal','intervals'},
'intervals':	{'internals','interval'},
'intervene':	{'intervened','intervenes'},
'intervened':	{'intervene','intervenes'},
'intervenes':	{'intervene','intervened'},
'intervention':	{'interventions'},
'interventions':	{'intervention'},
'interview':	{'interviews'},
'interviewed':	{'interviewer'},
'interviewees':	{'interviewers'},
'interviewer':	{'interviewed','interviewers'},
'interviewers':	{'interviewees','interviewer'},
'interviews':	{'interview'},
'intestine':	{'intestines'},
'intestines':	{'intestine'},
'intimate':	{'intimates'},
'intimates':	{'intimate'},
'intimidate':	{'intimidated'},
'intimidated':	{'intimidate'},
'into':	{'info','int','intro','onto','pinto','unto'},
'intranet':	{'intranets'},
'intranets':	{'intranet'},
'intrigue':	{'intrigued'},
'intrigued':	{'intrigue'},
'intro':	{'into'},
'introduce':	{'introduced','introduces'},
'introduced':	{'introduce','introduces'},
'introduces':	{'introduce','introduced'},
'introduction':	{'introductions'},
'introductions':	{'introduction'},
'intruder':	{'intruders'},
'intruders':	{'intruder'},
'intrusion':	{'intrusions'},
'intrusions':	{'intrusion'},
'intuit':	{'inuit'},
'inuit':	{'intuit'},
'invade':	{'invaded','invader'},
'invaded':	{'invade','invader'},
'invader':	{'invade','invaded','invaders'},
'invaders':	{'invader'},
'invalidate':	{'invalidated'},
'invalidated':	{'invalidate'},
'invaluable':	{'invaluably'},
'invaluably':	{'invaluable'},
'invariable':	{'invariably'},
'invariably':	{'invariable'},
'invasion':	{'invasions'},
'invasions':	{'invasion'},
'invent':	{'indent','intent','invents','invert','invest'},
'invented':	{'indented','inverted','invested'},
'inventing':	{'investing'},
'invention':	{'intention','inventions'},
'inventions':	{'intentions','invention'},
'inventive':	{'incentive'},
'inventor':	{'inventors','inventory','investor'},
'inventors':	{'inventor','inventory','investors'},
'inventory':	{'inventor','inventors'},
'invents':	{'invent','invests'},
'invert':	{'inert','insert','invent','invest'},
'invertebrate':	{'invertebrates'},
'invertebrates':	{'invertebrate'},
'inverted':	{'inserted','invented','inverter','invested'},
'inverter':	{'inverted','inverters'},
'inverters':	{'inverter'},
'invest':	{'incest','invent','invert','invests'},
'invested':	{'infested','ingested','invented','inverted'},
'investigate':	{'investigated','investigates'},
'investigated':	{'investigate','investigates'},
'investigates':	{'investigate','investigated'},
'investigation':	{'investigations'},
'investigations':	{'investigation'},
'investigator':	{'investigators'},
'investigators':	{'investigator'},
'investing':	{'inventing'},
'investment':	{'investments'},
'investments':	{'investment'},
'investor':	{'inventor','investors'},
'investors':	{'inventors','investor'},
'invests':	{'invents','invest'},
'invitation':	{'invitations'},
'invitations':	{'invitation'},
'invite':	{'invited','invites'},
'invited':	{'invite','invites'},
'invites':	{'invite','invited'},
'invoice':	{'invoiced','invoices'},
'invoiced':	{'invoice','invoices'},
'invoices':	{'invoice','invoiced'},
'invoke':	{'invoked','invokes'},
'invoked':	{'invoke','invokes'},
'invokes':	{'invoke','invoked'},
'involve':	{'involved','involves'},
'involved':	{'involve','involves'},
'involves':	{'involve','involved'},
'inward':	{'onward'},
'io':	{'bio','co','do','fo','go','ho','i','ia','id','ie','if','ii','il','imo','in','ion','ip','iq','ir','is','it','iv','ix','ko','lo','mo','no','o','po','rio','so','to','wo'},
'ion':	{'con','don','hon','icon','in','inn','io','ions','iron','isn','lion','mon','non','on','ron','son','ton','von','won','yon','zion'},
'ionic':	{'bionic','iconic','ironic','sonic','tonic'},
'ions':	{'cons','icons','inns','ins','ion','irons','sons','tons'},
'iowa':	{'kiowa'},
'ip':	{'dip','dp','gp','hip','hp','i','ia','id','ie','if','ii','il','imp','in','io','iq','ir','is','it','iv','ix','kip','kp','lip','lp','mp','nip','np','op','p','pip','rip','sip','tip','up','vip','yip','zip'},
'ipod':	{'pod'},
'iq':	{'hq','i','ia','id','ie','if','ii','il','in','io','ip','ir','is','it','iv','ix','q'},
'ir':	{'air','ar','br','cr','dr','er','fir','fr','hr','i','ia','id','ie','if','ii','il','in','io','ip','iq','ira','ire','irs','is','it','iv','ix','jr','kr','lr','mr','or','pr','qr','r','sir','sr','ur','yr','zr'},
'ira':	{'ara','bra','era','ia','ida','ir','iran','iraq','ire','irs','iva','lira','nra','ra'},
'iran':	{'bran','gran','ira','iraq','iron','ran'},
'iraq':	{'ira','iran','iraqi'},
'iraqi':	{'iraq'},
'ire':	{'are','dire','eire','ere','fire','hire','ice','ie','ike','ir','ira','irs','lire','ore','pre','sire','tire','wire'},
'ireland':	{'iceland'},
'iris':	{'gris','ibis','irish','irs','isis','kris'},
'irish':	{'iris'},
'iron':	{'icon','ion','iran','irons','irony','ron'},
'ironic':	{'iconic','ionic'},
'irons':	{'icons','ions','iron','irony'},
'irony':	{'iron','irons'},
'irrevocable':	{'irrevocably'},
'irrevocably':	{'irrevocable'},
'irrigated':	{'irritated'},
'irrigation':	{'irritation'},
'irritate':	{'irritated'},
'irritated':	{'irrigated','irritate'},
'irritation':	{'irrigation'},
'irs':	{'airs','ifs','ins','ir','ira','ire','iris','is','its','mrs'},
'is':	{'as','bs','cs','dis','es','his','hs','i','ia','id','ie','if','ifs','ii','il','in','ins','io','ip','iq','ir','irs','ism','isn','it','its','iv','ix','ks','ms','os','ps','sis','ss','ts','us','vs'},
'isis':	{'ibis','iris','sis'},
'islam':	{'slam'},
'island':	{'inland','islands'},
'islander':	{'slander'},
'islands':	{'island'},
'isle':	{'aisle','idle','lisle'},
'ism':	{'is','isn','sm'},
'isn':	{'in','inn','ion','is','ism','sn','usn'},
'isolate':	{'isolated','isolates'},
'isolated':	{'isolate','isolates'},
'isolates':	{'isolate','isolated'},
'isotope':	{'isotopes'},
'isotopes':	{'isotope'},
'isotopic':	{'isotropic'},
'isotropic':	{'isotopic'},
'israel':	{'israeli'},
'israeli':	{'israel'},
'issue':	{'issued','issuer','issues','tissue'},
'issued':	{'issue','issuer','issues'},
'issuer':	{'issue','issued','issuers','issues'},
'issuers':	{'issuer','issues'},
'issues':	{'issue','issued','issuer','issuers','tissues'},
'it':	{'at','bit','ct','et','fit','ft','git','hit','ht','i','ia','id','ie','if','ii','il','in','int','io','ip','iq','ir','is','its','iv','ix','kit','kt','lit','mit','mt','nit','nt','pit','pt','sit','t','tit','ut','vt','wit'},
'italic':	{'italics'},
'italics':	{'italic'},
'itch':	{'bitch','ditch','etch','fitch','hitch','inch','itchy','pitch','witch'},
'itching':	{'bitching','ditching','etching','pitching'},
'itchy':	{'itch'},
'item':	{'items','stem'},
'itemise':	{'itemised','itemises'},
'itemised':	{'itemise','itemises','itemized'},
'itemises':	{'itemise','itemised'},
'itemized':	{'itemised'},
'items':	{'item','stems'},
'iterate':	{'literate'},
'iteration':	{'iterations'},
'iterations':	{'iteration'},
'its':	{'bits','fits','hits','ifs','ins','irs','is','it','kits','pits','sits','tits','ts','wits'},
'iv':	{'av','cv','ev','hiv','i','ia','id','ie','if','ii','il','in','io','ip','iq','ir','is','it','iva','ivy','ix','jv','liv','lv','nv','rv','tv','uv','v','wv','xiv','xv'},
'iva':	{'diva','ia','ida','ira','iv','ivy','va','viva'},
'ives':	{'dives','fives','gives','hives','lives','wives'},
'ivy':	{'icy','iv','iva'},
'ix':	{'ax','dix','ex','fix','i','ia','id','ie','if','ii','il','in','io','ip','iq','ir','is','it','iv','mix','nix','ox','pix','px','six','tx','x','xix','xx'},
'j':	{'a','b','c','d','dj','e','f','g','h','i','ji','jr','ju','jv','k','l','nj','o','p','q','r','t','u','v','w','x','y','z'},
'jab':	{'ab','cab','dab','fab','gab','jag','jam','jan','jar','jaw','jay','job','lab','nab','tab'},
'jack':	{'back','hack','jacks','jock','lack','mack','pack','rack','sack','tack'},
'jacket':	{'jackets','packet','racket'},
'jackets':	{'jacket','packets'},
'jacking':	{'backing','hacking','lacking','packing','racking'},
'jackpot':	{'jackpots'},
'jackpots':	{'jackpot'},
'jacks':	{'backs','hacks','jack','jocks','lacks','packs','racks','sacks'},
'jacob':	{'jacobi','jacobs'},
'jacobi':	{'jacob','jacobs'},
'jacobs':	{'jacob','jacobi'},
'jade':	{'ade','bade','fade','jaded','jude','made','sade','wade'},
'jaded':	{'faded','jade'},
'jag':	{'ag','bag','dag','fag','gag','jab','jam','jan','jar','jaw','jay','jig','jog','jug','lag','mag','nag','rag','sag','tag'},
'jagged':	{'bagged','gagged','jagger','lagged','ragged','tagged'},
'jagger':	{'dagger','jagged','jogger'},
'jail':	{'bail','dail','fail','hail','jails','jain','mail','nail','rail','sail','tail'},
'jailed':	{'failed','hailed','mailed','nailed','sailed','tailed'},
'jails':	{'fails','hails','jail','mails','nails','rails','sails','tails'},
'jain':	{'cain','gain','jail','jan','join','lain','main','pain','rain','vain'},
'jam':	{'am','cam','dam','ham','jab','jag','jams','jan','jar','jaw','jay','lam','ram','sam','tam','yam'},
'jamaica':	{'jamaican'},
'jamaican':	{'jamaica'},
'james':	{'games','jams','names','tames'},
'jammed':	{'rammed'},
'jams':	{'cams','dams','jam','james','jars','jaws'},
'jan':	{'an','ban','can','fan','han','jab','jag','jain','jam','jar','jaw','jay','jean','lan','man','nan','pan','ran','tan','van','wan'},
'jansen':	{'jensen'},
'janus':	{'anus'},
'jar':	{'ar','bar','car','dar','ear','far','gar','jab','jag','jam','jan','jars','jaw','jay','jr','mar','oar','par','tar','var','war'},
'jargon':	{'argon'},
'jars':	{'bars','cars','ears','jams','jar','jaws','mars','oars','wars'},
'jason':	{'mason'},
'jasper':	{'casper'},
'java':	{'lava'},
'jaw':	{'haw','jab','jag','jam','jan','jar','jaws','jay','jew','law','paw','raw','saw'},
'jaws':	{'jams','jars','jaw','laws','paws','saws'},
'jay':	{'bay','cay','day','fay','gay','hay','jab','jag','jam','jan','jar','jaw','joy','lay','may','nay','pay','ray','say','way'},
'jazz':	{'jazzy'},
'jazzy':	{'jazz'},
'jealous':	{'jealousy','zealous'},
'jealously':	{'jealousy'},
'jealousy':	{'jealous','jealously'},
'jean':	{'bean','dean','jan','jeans','kean','lean','mean'},
'jeans':	{'beans','deans','jean','leans','means'},
'jeep':	{'beep','deep','keep','peep','weep'},
'jello':	{'cello','hello','jelly'},
'jelly':	{'belly','jello','jolly','kelly'},
'jena':	{'lena'},
'jenny':	{'benny','penny'},
'jensen':	{'jansen'},
'jerk':	{'jerks','jerky'},
'jerks':	{'jerk','jerky','perks'},
'jerky':	{'jerk','jerks','jerry','perky'},
'jerry':	{'berry','ferry','jerky','jewry','merry','perry','terry'},
'jersey':	{'jerseys'},
'jerseys':	{'jersey'},
'jest':	{'best','est','fest','jet','just','lest','nest','pest','rest','test','vest','west','zest'},
'jester':	{'ester','tester'},
'jet':	{'bet','et','get','jest','jew','let','met','net','pet','set','tet','vet','wet','yet'},
'jetty':	{'petty'},
'jew':	{'dew','few','jaw','jet','mew','new','pew','sew','yew'},
'jewel':	{'jewels'},
'jeweler':	{'jewelers','jeweller'},
'jewelers':	{'jeweler','jewellers'},
'jeweller':	{'jeweler','jewellers','jewellery'},
'jewellers':	{'jewelers','jeweller','jewellery'},
'jewellery':	{'jeweller','jewellers'},
'jewels':	{'jewel'},
'jewry':	{'jerry'},
'ji':	{'ai','bi','ci','di','gi','hi','i','ii','j','jig','jr','ju','jv','ki','li','mi','ni','pi','qi','ri','si','ti','vi','wi','xi','yi'},
'jig':	{'big','dig','fig','gig','jag','ji','jog','jug','pig','rig','sig','wig'},
'jingle':	{'jungle','mingle','single'},
'jitter':	{'bitter','fitter','hitter','litter','sitter'},
'jive':	{'dive','five','give','hive','live'},
'job':	{'bob','cob','fob','hob','jab','jobs','jog','joy','lob','mob','nob','ob','rob','sob'},
'jobs':	{'bobs','job','joys','mobs','robs'},
'jock':	{'bock','cock','dock','jack','jocks','lock','mock','rock','sock'},
'jockey':	{'hockey','jockeys'},
'jockeys':	{'jockey'},
'jocks':	{'cocks','docks','jacks','jock','locks','rocks','socks'},
'joel':	{'noel'},
'jog':	{'bog','cog','dog','fog','hog','jag','jig','job','joy','jug','log'},
'jogger':	{'jagger','logger'},
'jogging':	{'logging'},
'john':	{'johns','join'},
'johns':	{'john','joins'},
'johnson':	{'johnston'},
'johnston':	{'johnson'},
'join':	{'coin','jain','john','joins','joint','loin'},
'joined':	{'coined','joiner','jointed'},
'joiner':	{'joined'},
'joins':	{'coins','johns','join','joint','joints'},
'joint':	{'join','joins','joints','point'},
'jointed':	{'joined','pointed'},
'joints':	{'joins','joint','points'},
'joke':	{'coke','joked','joker','jokes','poke','woke','yoke'},
'joked':	{'joke','joker','jokes','poked'},
'joker':	{'joke','joked','jokers','jokes','poker'},
'jokers':	{'joker','jokes'},
'jokes':	{'joke','joked','joker','jokers','jones'},
'joking':	{'poking'},
'jolly':	{'dolly','folly','holly','jelly','molly'},
'jolt':	{'bolt','colt','volt'},
'jones':	{'bones','cones','jokes','ones','tones','zones'},
'josh':	{'gosh','posh'},
'journal':	{'journals'},
'journalism':	{'journalist'},
'journalist':	{'journalism','journalists'},
'journalists':	{'journalist'},
'journals':	{'journal'},
'journey':	{'journeys','tourney'},
'journeys':	{'journey'},
'joy':	{'boy','coy','jay','job','jog','joys','soy','toy'},
'joys':	{'boys','jobs','joy','toys'},
'joystick':	{'joysticks'},
'joysticks':	{'joystick'},
'jr':	{'ar','br','cr','dr','er','fr','hr','ir','j','jar','ji','ju','jv','kr','lr','mr','or','pr','qr','r','sr','ur','yr','zr'},
'ju':	{'au','cu','du','eu','gu','j','ji','jr','jug','jv','lu','mu','nu','pu','ru','su','u','wu','zu'},
'judah':	{'judas'},
'judas':	{'judah'},
'jude':	{'dude','jade','judea','judge','judo','june','jute','nude','rude'},
'judea':	{'jude'},
'judge':	{'fudge','jude','judged','judges','nudge'},
'judged':	{'judge','judges'},
'judgement':	{'judgements','judgment'},
'judgements':	{'judgement','judgments'},
'judges':	{'judge','judged'},
'judgment':	{'judgement','judgments'},
'judgments':	{'judgements','judgment'},
'judo':	{'jude','juno'},
'jug':	{'aug','bug','dug','hug','jag','jig','jog','ju','jugs','jung','lug','mug','pug','rug','tug'},
'jugs':	{'bugs','hugs','jug','mugs','rugs'},
'juice':	{'juicer','juices','juicy'},
'juicer':	{'juice','juicers','juices'},
'juicers':	{'juicer','juices'},
'juices':	{'juice','juicer','juicers'},
'juicy':	{'juice'},
'july':	{'duly','jury'},
'jumble':	{'bumble','fumble','humble','rumble','tumble'},
'jump':	{'bump','dump','hump','jumps','lump','pump','sump'},
'jumped':	{'bumped','dumped','jumper','pumped'},
'jumper':	{'bumper','jumped','jumpers'},
'jumpers':	{'bumpers','jumper'},
'jumping':	{'bumping','dumping','humping','pumping'},
'jumps':	{'bumps','dumps','humps','jump','lumps','pumps'},
'junction':	{'function','junctions'},
'junctions':	{'functions','junction'},
'juncture':	{'puncture'},
'june':	{'dune','jude','jung','junk','juno','jute','rune','tune'},
'jung':	{'dung','hung','jug','june','junk','juno','lung','rung','sung'},
'jungle':	{'jingle'},
'junior':	{'juniors'},
'juniors':	{'junior'},
'junk':	{'bunk','dunk','funk','hunk','june','jung','juno','punk','sunk'},
'junkie':	{'junkies'},
'junkies':	{'junkie'},
'juno':	{'judo','june','jung','junk'},
'juries':	{'buries'},
'jurisdiction':	{'jurisdictions'},
'jurisdictions':	{'jurisdiction'},
'juror':	{'jurors'},
'jurors':	{'juror'},
'jury':	{'bury','fury','july'},
'just':	{'bust','dust','gust','jest','lust','must','rust'},
'justice':	{'justices'},
'justices':	{'justice'},
'justifiable':	{'justifiably'},
'justifiably':	{'justifiable'},
'justification':	{'justifications'},
'justifications':	{'justification'},
'justified':	{'justifies'},
'justifies':	{'justified'},
'jute':	{'cute','jude','june','mute','ute'},
'juvenile':	{'juveniles'},
'juveniles':	{'juvenile'},
'jv':	{'av','cv','ev','iv','j','ji','jr','ju','lv','nv','rv','tv','uv','v','wv','xv'},
'k':	{'a','ak','b','bk','c','d','e','f','g','h','i','j','ka','kb','kc','kg','ki','km','ko','kp','kr','ks','kt','kw','ky','l','o','ok','p','q','r','t','u','uk','v','w','x','y','z'},
'ka':	{'a','aka','ba','ca','da','ea','fa','ga','ha','ia','k','kat','kb','kc','kg','ki','km','ko','kp','kr','ks','kt','kw','ky','la','ma','na','pa','ra','sa','ska','ta','va','wa','ya','za'},
'kaiser':	{'raiser'},
'kali':	{'ali','bali','cali','dali','mali'},
'kama':	{'karma','kata','lama','mama','rama'},
'kant':	{'ant','cant','kart','kat','kent','pant','rant','want'},
'karat':	{'carat','karate','kart'},
'karate':	{'karat'},
'karen':	{'aren'},
'karma':	{'kama'},
'kart':	{'art','bart','cart','dart','fart','hart','kant','karat','karts','kat','mart','part','tart'},
'karts':	{'arts','carts','darts','kart','parts','tarts','warts'},
'kat':	{'at','bat','cat','dat','eat','fat','hat','ka','kant','kart','kata','kit','kt','lat','mat','oat','pat','rat','sat','tat','vat','wat'},
'kata':	{'data','kama','kat'},
'kayak':	{'kayaks'},
'kayaks':	{'kayak'},
'kb':	{'ab','b','bb','db','eb','gb','k','ka','kc','kg','kgb','ki','km','ko','kp','kr','ks','kt','kw','ky','lb','mb','nb','ob','pb','rb','sb','tb','yb'},
'kc':	{'ac','bc','c','cc','dc','ec','k','ka','kb','kg','ki','km','ko','kp','kr','ks','kt','kw','ky','mc','nc','pc','sc','tc'},
'kean':	{'bean','dean','jean','keen','ken','kern','khan','klan','lean','mean'},
'keats':	{'beats','eats','feats','heats','meats','seats','yeats'},
'keel':	{'eel','feel','heel','keen','keep','kneel','peel','reel'},
'keen':	{'been','kean','keel','keep','ken','kern','seen','teen'},
'keep':	{'beep','deep','jeep','keel','keen','keeps','peep','weep'},
'keeper':	{'deeper','keepers'},
'keepers':	{'keeper'},
'keeping':	{'peeping','weeping'},
'keeps':	{'keep'},
'keepsake':	{'keepsakes'},
'keepsakes':	{'keepsake'},
'keller':	{'heller','kepler','killer','seller','teller'},
'kelly':	{'belly','jelly'},
'ken':	{'ben','den','en','fen','gen','hen','kean','keen','keno','kent','ker','kern','key','kin','men','pen','sen','ten','wen','yen','zen'},
'kendal':	{'kendall'},
'kendall':	{'kendal'},
'kennel':	{'kennels','kernel'},
'kennels':	{'kennel','kernels'},
'keno':	{'ken','kent','reno'},
'kent':	{'bent','cent','dent','gent','kant','ken','keno','kept','lent','rent','sent','tent','vent','went'},
'kenya':	{'kenyan'},
'kenyan':	{'kenya'},
'kepler':	{'keller'},
'kept':	{'kent','sept','wept'},
'ker':	{'aer','ber','der','er','fer','ger','her','ken','kern','key','kr','per','yer'},
'kern':	{'bern','fern','kean','keen','ken','ker','tern'},
'kernel':	{'kennel','kernels'},
'kernels':	{'kennels','kernel'},
'kettering':	{'lettering'},
'kettle':	{'kettles','settle'},
'kettles':	{'kettle','settles'},
'key':	{'fey','hey','ken','ker','keys','ky'},
'keyboard':	{'keyboards'},
'keyboards':	{'keyboard'},
'keyed':	{'eyed'},
'keying':	{'keyring'},
'keyring':	{'keying'},
'keys':	{'key'},
'keystroke':	{'keystrokes'},
'keystrokes':	{'keystroke'},
'keyword':	{'keywords'},
'keywords':	{'keyword'},
'kg':	{'ag','g','hg','k','ka','kb','kc','kgb','ki','km','ko','kp','kr','ks','kt','kw','ky','mg'},
'kgb':	{'gb','kb','kg'},
'khan':	{'han','kean','klan','shan','than'},
'khz':	{'hz','mhz'},
'ki':	{'ai','bi','ci','di','gi','hi','i','ii','ji','k','ka','kb','kc','kg','kid','kin','kip','kit','km','ko','kp','kr','ks','kt','kw','ky','li','mi','ni','pi','qi','ri','si','ski','ti','vi','wi','xi','yi'},
'kick':	{'dick','kicks','kirk','lick','mick','nick','pick','rick','sick','tick','wick'},
'kicked':	{'kicker','licked','picked','ticked','wicked'},
'kicker':	{'kicked','picker','sicker','ticker','wicker'},
'kicking':	{'licking','picking','ticking'},
'kicks':	{'kick','kinks','licks','picks','ticks'},
'kid':	{'aid','bid','cid','did','hid','id','ki','kidd','kids','kin','kind','kip','kit','lid','mid','rid','skid'},
'kidd':	{'kid','kids','kind'},
'kidding':	{'bidding','ridding'},
'kidney':	{'kidneys','sidney'},
'kidneys':	{'kidney'},
'kids':	{'aids','bids','kid','kidd','kinds','kiss','kits','lids','rids','sids'},
'kiley':	{'riley'},
'kill':	{'bill','dill','fill','gill','hill','ill','kills','kiln','kilo','kilt','mill','pill','sill','skill','till','will'},
'killed':	{'billed','filled','killer','milled','skilled','willed'},
'killer':	{'filler','keller','killed','killers','miller'},
'killers':	{'fillers','killer'},
'killing':	{'billing','filling','killings','kipling','milling','willing'},
'killings':	{'billings','fillings','killing'},
'kills':	{'bills','fills','hills','ills','kill','mills','pills','skills','wills'},
'kiln':	{'kill','kilo','kilt','kin'},
'kilo':	{'kill','kiln','kilt','lilo','milo','silo'},
'kilogram':	{'kilograms'},
'kilograms':	{'kilogram'},
'kilometer':	{'kilometers'},
'kilometers':	{'kilometer'},
'kilometre':	{'kilometres'},
'kilometres':	{'kilometre'},
'kilt':	{'gilt','kill','kiln','kilo','kit','milt','silt','tilt','wilt'},
'kin':	{'akin','bin','din','fin','gin','in','ken','ki','kid','kiln','kind','king','kip','kit','lin','min','pin','qin','sin','skin','tin','win','yin'},
'kind':	{'bind','find','hind','kid','kidd','kin','kinda','kinds','king','lind','mind','wind'},
'kinda':	{'kind','kinds'},
'kinder':	{'binder','finder','hinder','winder'},
'kinds':	{'binds','finds','kids','kind','kinda','kings','kinks','minds','winds'},
'kinematic':	{'cinematic','kinematics'},
'kinematics':	{'kinematic'},
'kinetic':	{'kinetics'},
'kinetics':	{'kinetic'},
'king':	{'ding','kin','kind','kings','ling','ming','ning','ping','qing','ring','sing','ting','wing','ying'},
'kingdom':	{'kingdoms'},
'kingdoms':	{'kingdom'},
'kings':	{'kinds','king','kinks','pings','rings','sings','wings'},
'kinks':	{'inks','kicks','kinds','kings','kinky','links','sinks'},
'kinky':	{'inky','kinks'},
'kiosk':	{'kiosks'},
'kiosks':	{'kiosk'},
'kiowa':	{'iowa'},
'kip':	{'dip','hip','ip','ki','kid','kin','kit','kp','lip','nip','pip','rip','sip','skip','tip','vip','yip','zip'},
'kipling':	{'killing'},
'kirk':	{'dirk','kick'},
'kiss':	{'kids','kits','miss','piss'},
'kissed':	{'kisses','missed','pissed'},
'kisses':	{'kissed','misses'},
'kissing':	{'missing','pissing'},
'kit':	{'bit','fit','git','hit','it','kat','ki','kid','kilt','kin','kip','kite','kits','knit','kt','lit','mit','nit','pit','sit','skit','tit','wit'},
'kitchen':	{'kitchens'},
'kitchens':	{'kitchen'},
'kite':	{'bite','cite','kit','kites','kits','lite','mite','rite','site'},
'kites':	{'bites','cites','kite','kits','mites','rites','sites'},
'kits':	{'bits','fits','hits','its','kids','kiss','kit','kite','kites','knits','pits','sits','tits','wits'},
'kitten':	{'bitten','kittens'},
'kittens':	{'kitten','mittens'},
'kitty':	{'titty','witty'},
'klan':	{'clan','elan','kean','khan','lan','plan'},
'klee':	{'flee','glee','knee','lee'},
'kline':	{'cline','line'},
'km':	{'am','bm','cm','em','fm','gm','hm','k','ka','kb','kc','kg','ki','ko','kp','kr','ks','kt','kw','ky','mm','nm','pm','rm','sm','tm','um','wm'},
'knack':	{'knock','snack'},
'knee':	{'klee','kneel','knees','knew','nee'},
'kneel':	{'keel','knee','kneels','knees'},
'kneels':	{'kneel','knees'},
'knees':	{'knee','kneel','kneels'},
'knew':	{'anew','knee','know','new'},
'knight':	{'knights','night'},
'knights':	{'knight','nights'},
'knit':	{'kit','knits','knot','nit','unit'},
'knits':	{'kits','knit','knots','units'},
'knitted':	{'knotted'},
'knitting':	{'knotting'},
'knob':	{'knobs','knot','know','knox','nob'},
'knobs':	{'knob','knots','knows'},
'knock':	{'knack','knocks'},
'knocks':	{'knock'},
'knot':	{'knit','knob','knots','know','knox','not'},
'knots':	{'knits','knobs','knot','knows'},
'knotted':	{'knitted'},
'knotting':	{'knitting'},
'know':	{'knew','knob','knot','known','knows','knox','now','snow'},
'knowing':	{'snowing'},
'known':	{'know','knows'},
'knows':	{'knobs','knots','know','known','snows'},
'knox':	{'knob','knot','know'},
'knuckle':	{'knuckles'},
'knuckles':	{'knuckle'},
'ko':	{'co','do','fo','go','ho','io','k','ka','kb','kc','kg','ki','km','kp','kr','ks','kt','kw','ky','lo','mo','no','o','po','so','tko','to','wo'},
'kobe':	{'lobe','robe'},
'koch':	{'loch','och'},
'koran':	{'korean'},
'korea':	{'korean'},
'korean':	{'koran','korea'},
'kp':	{'dp','gp','hp','ip','k','ka','kb','kc','kg','ki','kip','km','ko','kph','kr','ks','kt','kw','ky','lp','mp','np','op','p','up'},
'kph':	{'kp','mph','ph'},
'kr':	{'ar','br','cr','dr','er','fr','hr','ir','jr','k','ka','kb','kc','ker','kg','ki','km','ko','kp','ks','kt','kw','ky','lr','mr','or','pr','qr','r','sr','ur','yr','zr'},
'kraft':	{'craft','draft','graft','raft'},
'kris':	{'gris','iris'},
'krona':	{'krone'},
'krone':	{'drone','krona','kroner','prone'},
'kroner':	{'krone'},
'ks':	{'as','bs','cs','es','hs','is','k','ka','kb','kc','kg','ki','km','ko','kp','kr','kt','kw','ky','ms','os','ps','ss','ts','us','vs'},
'kt':	{'at','ct','et','ft','ht','it','k','ka','kat','kb','kc','kg','ki','kit','km','ko','kp','kr','ks','kw','ky','mt','nt','pt','t','ut','vt'},
'kuwait':	{'kuwaiti'},
'kuwaiti':	{'kuwait'},
'kw':	{'k','ka','kb','kc','kg','ki','km','ko','kp','kr','ks','kt','ky','nw','ow','sw','w'},
'ky':	{'by','dy','k','ka','kb','kc','key','kg','ki','km','ko','kp','kr','ks','kt','kw','ly','my','ny','sky','wy','y'},
'kylie':	{'wylie'},
'l':	{'a','al','b','bl','c','cl','d','e','el','f','fl','g','h','i','il','j','k','la','lb','le','li','ll','lo','lp','lr','lu','lv','ly','ml','o','p','q','r','t','tl','u','v','w','x','xl','y','z'},
'la':	{'a','ala','ba','ca','da','ea','fa','ga','ha','ia','ka','l','lab','lac','lad','lag','lam','lan','lao','lap','lat','law','lax','lay','lb','le','lea','li','ll','lo','lp','lr','lu','lv','ly','ma','na','ola','pa','ra','sa','ta','va','wa','ya','za'},
'lab':	{'ab','cab','dab','fab','gab','jab','la','labs','lac','lad','lag','lam','lamb','lan','lao','lap','lat','law','lax','lay','lb','lib','llb','lob','nab','slab','tab'},
'label':	{'abel','babel','labels','lapel','libel'},
'labeled':	{'labelled'},
'labeling':	{'labelling'},
'labelled':	{'labeled'},
'labelling':	{'labeling'},
'labels':	{'label'},
'labor':	{'labors','labour','tabor'},
'labored':	{'laborer','laboured'},
'laborer':	{'labored','laborers','labourer'},
'laborers':	{'laborer','labourers'},
'labors':	{'labor','labours'},
'labour':	{'labor','labours'},
'laboured':	{'labored','labourer'},
'labourer':	{'laborer','laboured','labourers'},
'labourers':	{'laborers','labourer'},
'labours':	{'labors','labour'},
'labs':	{'abs','cabs','lab','lads','lags','laos','laps','lass','lats','laws','lays','libs','slabs','tabs'},
'lac':	{'ac','la','lab','lace','lack','lacy','lad','lag','lam','lan','lao','lap','lat','law','lax','lay','mac','pac','sac','vac','wac'},
'lace':	{'ace','face','lac','laced','laces','lack','lacy','lake','lame','lance','lane','late','lice','luce','mace','pace','place','race'},
'laced':	{'faced','lace','laces','lacked','paced','placed','raced'},
'laces':	{'aces','faces','lace','laced','lacks','lakes','lanes','paces','places','races'},
'lack':	{'back','black','hack','jack','lac','lace','lacks','lacy','lark','lick','lock','luck','mack','pack','rack','sack','slack','tack'},
'lacked':	{'backed','hacked','laced','licked','locked','packed','sacked'},
'lacking':	{'backing','hacking','jacking','licking','locking','packing','racking'},
'lacks':	{'backs','blacks','hacks','jacks','laces','lack','licks','locks','packs','racks','sacks'},
'lactic':	{'tactic'},
'lacy':	{'lac','lace','lack','lady','lay','lazy','lucy'},
'lad':	{'ad','bad','cad','clad','dad','fad','glad','had','la','lab','lac','lads','lady','lag','laid','lam','lan','land','lao','lap','lat','law','lax','lay','lcd','lead','led','lid','load','lsd','mad','pad','rad','sad','tad','wad'},
'ladder':	{'adder','bladder','gladder','ladders','lander','lauder','madder','sadder'},
'ladders':	{'ladder'},
'laden':	{'aden'},
'lads':	{'ads','dads','labs','lad','lady','lags','lands','laos','laps','lass','lats','laws','lays','leads','lids','loads','pads'},
'lady':	{'lacy','lad','lads','lay','lazy'},
'lag':	{'ag','bag','dag','fag','flag','gag','jag','la','lab','lac','lad','lags','lam','lan','lao','lap','lat','law','lax','lay','leg','log','lug','mag','nag','rag','sag','slag','tag'},
'lager':	{'eager','larger','laser','later','layer','leger','pager','wager'},
'lagged':	{'bagged','flagged','gagged','jagged','legged','logged','ragged','tagged'},
'lagging':	{'bagging','flagging','gagging','logging','nagging','tagging'},
'lagoon':	{'lagoons'},
'lagoons':	{'lagoon'},
'lagos':	{'lags','laos','logos'},
'lags':	{'bags','flags','gags','labs','lads','lag','lagos','laos','laps','lass','lats','laws','lays','legs','logs','rags','tags'},
'laid':	{'aid','lad','lain','lair','laird','land','lid','maid','paid','plaid','raid','said'},
'lain':	{'cain','gain','jain','laid','lair','lan','latin','lawn','lin','loin','main','pain','plain','rain','slain','vain'},
'lair':	{'air','blair','fair','flair','hair','laid','lain','laird','pair'},
'laird':	{'laid','lair'},
'lake':	{'bake','blake','cake','fake','flake','lace','lakes','lame','lane','late','like','luke','make','rake','sake','take','wake'},
'lakes':	{'bakes','cakes','fakes','flakes','laces','lake','lanes','likes','makes','rakes','sakes','takes','wakes'},
'lam':	{'am','cam','clam','dam','glam','ham','jam','la','lab','lac','lad','lag','lama','lamb','lame','lamp','lan','lao','lap','lat','law','lax','lay','lcm','loam','ram','sam','slam','tam','yam'},
'lama':	{'kama','lam','lamb','lame','lamp','lava','lima','llama','mama','rama'},
'lamb':	{'lab','lam','lama','lame','lamp','limb'},
'lame':	{'blame','came','dame','fame','flame','game','lace','lake','lam','lama','lamb','lamp','lane','late','lime','name','same','tame'},
'lament':	{'latent'},
'laminate':	{'laminated'},
'laminated':	{'laminate'},
'lamp':	{'amp','camp','clamp','damp','lam','lama','lamb','lame','lamps','lap','limp','lump','ramp'},
'lamps':	{'amps','camps','clamps','lamp','laps','lumps','ramps'},
'lan':	{'an','ban','can','clan','elan','fan','han','jan','klan','la','lab','lac','lad','lag','lain','lam','land','lane','lao','lap','lat','law','lawn','lax','lay','lean','lin','loan','lpn','man','nan','pan','plan','ran','tan','van','wan'},
'lance':	{'dance','glance','lace','lancer','lancet','lane','nance','tance'},
'lancer':	{'cancer','dancer','lance','lancet','lander'},
'lancet':	{'lance','lancer'},
'land':	{'and','band','bland','gland','hand','lad','laid','lan','lands','lane','lend','lind','rand','sand','wand'},
'landed':	{'banded','handed','lander','lauded'},
'lander':	{'ladder','lancer','landed','lauder','leander','lender','sander','slander','wander'},
'landfill':	{'landfills'},
'landfills':	{'landfill'},
'landing':	{'banding','handing','landings','lansing','lending','sanding'},
'landings':	{'landing'},
'landlord':	{'landlords'},
'landlords':	{'landlord'},
'landmark':	{'landmarks'},
'landmarks':	{'landmark'},
'landowner':	{'landowners'},
'landowners':	{'landowner'},
'lands':	{'bands','glands','hands','lads','land','lanes','lends','sands','wands'},
'landscape':	{'landscaped','landscapes'},
'landscaped':	{'landscape','landscapes'},
'landscapes':	{'landscape','landscaped'},
'landslide':	{'landslides'},
'landslides':	{'landslide'},
'lane':	{'bane','cane','dane','lace','lake','lame','lan','lance','land','lanes','late','line','lone','mane','pane','plane','sane'},
'lanes':	{'canes','laces','lakes','lands','lane','lines','panes','planes'},
'language':	{'languages'},
'languages':	{'language'},
'lansing':	{'landing'},
'lantern':	{'lanterns'},
'lanterns':	{'lantern'},
'lanyard':	{'lanyards'},
'lanyards':	{'lanyard'},
'lao':	{'gao','hao','la','lab','lac','lad','lag','lam','lan','laos','lap','lat','law','lax','lay','leo','lo','loo','luo','mao','tao'},
'laos':	{'labs','lads','lagos','lags','lao','laps','lass','lats','laws','lays'},
'lap':	{'cap','clap','flap','gap','hap','la','lab','lac','lad','lag','lam','lamp','lan','lao','laps','lat','law','lax','lay','leap','lip','lp','map','nap','pap','rap','sap','slap','tap','yap','zap'},
'lapel':	{'label'},
'laps':	{'caps','flaps','gaps','labs','lads','lags','lamps','laos','lap','lapse','lass','lats','laws','lays','leaps','lips','maps','taps'},
'lapse':	{'laps','lapsed','lapses'},
'lapsed':	{'elapsed','lapse','lapses'},
'lapses':	{'lapse','lapsed'},
'laptop':	{'laptops'},
'laptops':	{'laptop'},
'large':	{'barge','larger','largo','marge'},
'larger':	{'lager','large'},
'largo':	{'argo','cargo','fargo','large'},
'lark':	{'ark','bark','clark','dark','lack','mark','park'},
'larvae':	{'larval'},
'larval':	{'larvae'},
'laser':	{'glaser','lager','lasers','later','layer','loser'},
'lasers':	{'laser','layers','losers'},
'lash':	{'ash','bash','cash','clash','dash','flash','hash','lass','last','leash','lush','mash','nash','rash','sash','slash','wash'},
'lashes':	{'ashes','clashes','dashes','flashes','hashes','leashes','slashes','washes'},
'lass':	{'ass','bass','class','glass','labs','lads','lags','laos','laps','lash','last','lasts','lats','laws','lays','less','loss','mass','pass'},
'last':	{'blast','cast','east','fast','hast','lash','lass','lasts','lat','least','lest','list','lost','lust','mast','past','vast'},
'lasted':	{'blasted','listed','pasted','tasted','wasted'},
'lasting':	{'blasting','casting','fasting','listing','pasting','tasting','wasting'},
'lastly':	{'vastly'},
'lasts':	{'blasts','casts','lass','last','lats','lists'},
'lat':	{'at','bat','cat','dat','eat','fat','flat','hat','kat','la','lab','lac','lad','lag','lam','lan','lao','lap','last','late','lats','law','lax','lay','let','lit','lot','mat','oat','pat','plat','rat','sat','tat','vat','wat'},
'latch':	{'batch','catch','hatch','match','patch','watch'},
'latches':	{'batches','catches','matches','patches','watches'},
'late':	{'ate','date','fate','gate','hate','lace','lake','lame','lane','lat','later','latex','lathe','lats','latte','lite','mate','pate','plate','rate','slate','tate'},
'latent':	{'lament','latest','patent'},
'later':	{'cater','eater','lager','laser','late','latex','latter','layer','liter','mater','slater','water'},
'lateral':	{'literal'},
'laterally':	{'literally'},
'latest':	{'latent'},
'latex':	{'late','later'},
'lathe':	{'bathe','late','latte'},
'latin':	{'lain','latino','satin'},
'latino':	{'latin'},
'latitude':	{'latitudes'},
'latitudes':	{'latitude'},
'lats':	{'bats','cats','eats','fats','flats','hats','labs','lads','lags','laos','laps','lass','lasts','lat','late','laws','lays','lets','lots','mats','oats','rats'},
'latte':	{'late','lathe','latter','matte','platte'},
'latter':	{'batter','flatter','later','latte','letter','litter','matter','platter'},
'lattice':	{'lattices'},
'lattices':	{'lattice'},
'latvia':	{'latvian'},
'latvian':	{'latvia'},
'lauded':	{'landed','lauder'},
'lauder':	{'ladder','lander','lauded','louder'},
'laugh':	{'laughs','lough','waugh'},
'laughs':	{'laugh'},
'laughter':	{'daughter','slaughter'},
'launch':	{'lunch'},
'launched':	{'launcher','launches'},
'launcher':	{'launched','launchers','launches'},
'launchers':	{'launcher','launches'},
'launches':	{'launched','launcher','launchers','lunches'},
'lava':	{'java','lama'},
'law':	{'claw','flaw','haw','jaw','la','lab','lac','lad','lag','lam','lan','lao','lap','lat','lawn','laws','lax','lay','low','paw','raw','saw'},
'lawful':	{'awful'},
'lawfully':	{'awfully'},
'lawless':	{'flawless'},
'lawn':	{'dawn','fawn','lain','lan','law','lawns','laws','pawn','yawn'},
'lawns':	{'lawn','laws'},
'laws':	{'claws','flaws','jaws','labs','lads','lags','laos','laps','lass','lats','law','lawn','lawns','lays','lows','paws','saws'},
'lawsuit':	{'lawsuits'},
'lawsuits':	{'lawsuit'},
'lawyer':	{'lawyers','layer','sawyer'},
'lawyers':	{'lawyer','layers'},
'lax':	{'ax','fax','flax','la','lab','lac','lad','lag','lam','lan','lao','lap','lat','law','lay','max','sax','tax','wax'},
'lay':	{'bay','cay','clay','day','fay','gay','hay','jay','la','lab','lac','lacy','lad','lady','lag','lam','lan','lao','lap','lat','law','lax','lays','lazy','ly','may','nay','pay','play','ray','say','slay','way'},
'layer':	{'bayer','gayer','lager','laser','later','lawyer','layers','mayer','payer','player','slayer'},
'layers':	{'lasers','lawyers','layer','payers','players','sayers'},
'laying':	{'lying','paying','playing','saying','slaying'},
'layman':	{'cayman'},
'layoff':	{'layoffs','payoff','playoff'},
'layoffs':	{'layoff','payoffs','playoffs'},
'layout':	{'layouts','payout'},
'layouts':	{'layout','payouts'},
'lays':	{'bays','clays','days','gays','hays','labs','lads','lags','laos','laps','lass','lats','laws','lay','mays','nays','pays','plays','rays','says','ways'},
'lazy':	{'hazy','lacy','lady','lay'},
'lb':	{'ab','alb','b','bb','db','eb','gb','kb','l','la','lab','lbj','le','li','lib','ll','llb','lo','lob','lp','lr','lu','lv','ly','mb','nb','ob','pb','rb','sb','tb','yb'},
'lbj':	{'lb'},
'lcd':	{'cd','lad','lcm','led','lid','lsd'},
'lcm':	{'cm','lam','lcd'},
'le':	{'ale','be','ce','de','e','ee','fe','ge','he','ie','l','la','lb','lea','led','lee','leg','lei','lek','leo','les','let','lev','li','lie','ll','lo','lp','lr','lu','lv','ly','me','ne','ole','pe','se','te','ve','we','xe','ye'},
'lea':	{'dea','ea','flea','la','le','lead','leaf','leak','lean','leap','lear','led','lee','leg','lei','lek','lena','leo','les','let','lev','pea','plea','sea','tea','yea'},
'leach':	{'beach','bleach','each','leash','leech','peach','reach','teach'},
'leaching':	{'bleaching','reaching','teaching'},
'lead':	{'bead','dead','head','lad','lea','leads','leaf','leak','lean','leap','lear','led','lend','load','mead','plead','read'},
'leaded':	{'beaded','headed','leader','leaked','leaned','leaped','leased','leaved','loaded','pleaded'},
'leader':	{'header','leaded','leaders','leander','lender','loader','reader'},
'leaders':	{'headers','leader','leavers','lenders','loaders','readers'},
'leadership':	{'readership'},
'leading':	{'beading','heading','leaking','leaning','leaping','leasing','leaving','lending','loading','pleading','reading'},
'leads':	{'beads','heads','lads','lead','leaks','leans','leaps','leeds','lends','loads','pleads','reads'},
'leaf':	{'deaf','lea','lead','leafy','leak','lean','leap','lear','loaf'},
'leaflet':	{'leaflets'},
'leaflets':	{'leaflet'},
'leafy':	{'leaf','leaky','leary'},
'league':	{'leagues'},
'leagues':	{'league'},
'leak':	{'beak','bleak','lea','lead','leaf','leaks','leaky','lean','leap','lear','leek','lek','peak','teak','weak'},
'leaked':	{'beaked','leaded','leaned','leaped','leased','leaved','peaked'},
'leaking':	{'leading','leaning','leaping','leasing','leaving','peaking'},
'leaks':	{'beaks','leads','leak','leaky','leans','leaps','peaks'},
'leaky':	{'leafy','leak','leaks','leary'},
'lean':	{'bean','clean','dean','jean','kean','lan','lea','lead','leaf','leak','leans','leap','lear','learn','leon','loan','mean'},
'leander':	{'lander','leader','lender'},
'leaned':	{'cleaned','gleaned','leaded','leaked','leaped','learned','leased','leaved','loaned'},
'leaning':	{'cleaning','leading','leaking','leaping','learning','leasing','leaving','meaning','weaning'},
'leans':	{'beans','cleans','deans','jeans','leads','leaks','lean','leaps','learns','lens','loans','means'},
'leap':	{'heap','lap','lea','lead','leaf','leak','lean','leaps','lear','reap'},
'leaped':	{'heaped','leaded','leaked','leaned','leased','leaved'},
'leaping':	{'heaping','leading','leaking','leaning','leasing','leaving'},
'leaps':	{'heaps','laps','leads','leaks','leans','leap'},
'lear':	{'bear','clear','dear','ear','fear','gear','hear','lea','lead','leaf','leak','lean','leap','learn','leary','liar','near','pear','rear','tear','wear','year'},
'learn':	{'earn','lean','lear','learns','learnt','leary'},
'learned':	{'earned','leaned','learner'},
'learner':	{'learned','learners','lerner'},
'learners':	{'earners','learner'},
'learning':	{'earning','leaning','yearning'},
'learns':	{'earns','leans','learn','learnt'},
'learnt':	{'learn','learns'},
'leary':	{'leafy','leaky','lear','learn','weary'},
'lease':	{'cease','ease','leased','leases','leash','least','leave','please','tease'},
'leased':	{'ceased','eased','leaded','leaked','leaned','leaped','lease','leases','leaved','pleased','teased'},
'leases':	{'ceases','eases','lease','leased','leashes','leaves','lenses','pleases'},
'leash':	{'lash','leach','lease','least'},
'leashes':	{'lashes','leases'},
'leasing':	{'ceasing','easing','leading','leaking','leaning','leaping','leaving','pleasing','teasing'},
'least':	{'beast','east','feast','last','lease','leash','lest','yeast'},
'leather':	{'feather','heather','leathers','weather'},
'leathers':	{'feathers','leather','weathers'},
'leave':	{'lease','leaved','leaves','weave'},
'leaved':	{'leaded','leaked','leaned','leaped','leased','leave','leaves','weaved'},
'leavers':	{'leaders','leaves','levers','weavers'},
'leaves':	{'leases','leave','leaved','leavers','loaves','weaves'},
'leaving':	{'leading','leaking','leaning','leaping','leasing','weaving'},
'lecture':	{'lectured','lecturer','lectures'},
'lectured':	{'lecture','lecturer','lectures'},
'lecturer':	{'lecture','lectured','lecturers','lectures'},
'lecturers':	{'lecturer','lectures'},
'lectures':	{'lecture','lectured','lecturer','lecturers'},
'led':	{'bed','bled','ed','fed','fled','lad','lcd','le','lea','lead','lee','leg','lei','lek','lend','leo','les','let','lev','lid','lied','lsd','med','qed','red','sled','ted','wed','zed'},
'ledge':	{'edge','hedge','ledger','lodge','pledge','sledge','wedge'},
'ledger':	{'ledge','leger'},
'lee':	{'bee','ee','fee','flee','gee','glee','klee','le','lea','led','leek','lees','leg','lei','lek','leo','les','let','lev','lie','nee','pee','see','tee','wee'},
'leech':	{'beech','leach'},
'leeds':	{'bleeds','deeds','feeds','leads','lees','lends','needs','reeds','seeds','weeds'},
'leek':	{'eek','geek','leak','lee','lees','lek','meek','peek','seek','sleek','week'},
'lees':	{'bees','fees','lee','leeds','leek','legs','lens','les','less','lets','lies','sees','tees'},
'left':	{'cleft','eft','lefty','lent','lest','let','lift','loft'},
'leftist':	{'leftists'},
'leftists':	{'leftist'},
'leftover':	{'leftovers'},
'leftovers':	{'leftover'},
'lefty':	{'hefty','left','lofty'},
'leg':	{'beg','eeg','lag','le','lea','led','lee','lego','legs','lei','lek','leo','les','let','lev','log','lug','meg','peg','veg'},
'legal':	{'legals','regal'},
'legals':	{'legal'},
'legend':	{'legends'},
'legends':	{'legend'},
'leger':	{'lager','ledger','lever'},
'legged':	{'begged','lagged','logged','pegged'},
'legion':	{'legions','lesion','region'},
'legions':	{'legion','lesions','regions'},
'legislate':	{'legislated','legislates'},
'legislated':	{'legislate','legislates'},
'legislates':	{'legislate','legislated'},
'legislator':	{'legislators'},
'legislators':	{'legislator'},
'legislature':	{'legislatures'},
'legislatures':	{'legislature'},
'lego':	{'ego','leg','legs','leo','logo'},
'legs':	{'begs','lags','lees','leg','lego','lens','les','less','lets','logs','megs','pegs','regs'},
'lei':	{'le','lea','led','lee','leg','lek','leo','les','let','lev','levi','li','lii','mei','pei','wei'},
'leigh':	{'sleigh','weigh'},
'lek':	{'eek','le','lea','leak','led','lee','leek','leg','lei','leo','les','let','lev'},
'lemon':	{'demon','lemons','lemony','leon'},
'lemons':	{'demons','lemon','lemony'},
'lemony':	{'lemon','lemons'},
'lena':	{'jena','lea','lend','lens','lent','luna'},
'lend':	{'bend','blend','end','fend','land','lead','led','lena','lends','lens','lent','lind','mend','send','tend'},
'lender':	{'bender','blender','fender','gender','lander','leader','leander','lenders','render','sender','slender','tender'},
'lenders':	{'blenders','fenders','genders','leaders','lender','renders','senders','tenders'},
'lending':	{'bending','blending','ending','landing','leading','mending','pending','sending','tending','vending'},
'lends':	{'bends','blends','ends','lands','leads','leeds','lend','lens','mends','sends','tends'},
'length':	{'lengths','lengthy'},
'lengths':	{'length','lengthy'},
'lengthy':	{'length','lengths'},
'lenin':	{'benin'},
'lens':	{'ens','glens','hens','leans','lees','legs','lena','lend','lends','lent','les','less','lets','liens','pens','sens','tens'},
'lenses':	{'leases','senses'},
'lent':	{'bent','cent','dent','gent','kent','left','lena','lend','lens','lest','let','lint','rent','sent','tent','vent','went'},
'leo':	{'ceo','lao','le','lea','led','lee','leg','lego','lei','lek','leon','les','let','lev','lo','loo','luo'},
'leon':	{'lean','lemon','leo','leone','lion','loon','lyon','neon'},
'leonard':	{'leonardo','leopard'},
'leonardo':	{'leonard'},
'leone':	{'leon','lone'},
'leopard':	{'leonard'},
'lerner':	{'learner'},
'les':	{'ales','des','es','le','lea','led','lee','lees','leg','legs','lei','lek','lens','leo','less','lest','let','lets','lev','lies','mes','res','yes'},
'lesbian':	{'lesbians'},
'lesbians':	{'lesbian'},
'lesion':	{'legion','lesions','lesson'},
'lesions':	{'legions','lesion','lessons'},
'less':	{'bless','hess','lass','lees','legs','lens','les','lest','lets','loss','mess'},
'lessee':	{'lessen','lesser'},
'lessen':	{'essen','lessee','lesser','lesson'},
'lesser':	{'lessee','lessen','lessor'},
'lesson':	{'lesion','lessen','lessons','lessor'},
'lessons':	{'lesions','lesson'},
'lessor':	{'lesser','lesson'},
'lest':	{'best','est','fest','jest','last','least','left','lent','les','less','let','list','lost','lust','nest','pest','rest','test','vest','west','zest'},
'let':	{'bet','et','get','jet','lat','le','lea','led','lee','left','leg','lei','lek','lent','leo','les','lest','lets','lev','lit','lot','met','net','pet','set','tet','vet','wet','yet'},
'lets':	{'bets','gets','lats','lees','legs','lens','les','less','let','lots','nets','pets','sets','vets','wets'},
'letter':	{'better','latter','letters','litter','setter'},
'lettering':	{'kettering'},
'letters':	{'letter','setters'},
'letting':	{'betting','getting','lettings','netting','setting','wetting'},
'lettings':	{'letting','settings'},
'lev':	{'ev','le','lea','led','lee','leg','lei','lek','leo','les','let','levi','levy','liv','lv','rev'},
'levee':	{'levees','level','lever'},
'levees':	{'levee','levels','levers','levies'},
'level':	{'levee','levels','lever','revel'},
'leveled':	{'levelled'},
'leveling':	{'levelling'},
'levelled':	{'leveled','leveller'},
'leveller':	{'levelled'},
'levelling':	{'leveling'},
'levels':	{'levees','level','levers'},
'lever':	{'clever','ever','fever','leger','levee','level','levers','liver','lover','never','sever'},
'leverage':	{'beverage','leveraged','leverages'},
'leveraged':	{'leverage','leverages'},
'leverages':	{'beverages','leverage','leveraged'},
'levers':	{'fevers','leavers','levees','levels','lever','lovers'},
'levi':	{'devi','lei','lev','levis','levy'},
'levied':	{'levies'},
'levies':	{'levees','levied','levis'},
'levis':	{'levi','levies','lewis','lexis','nevis'},
'levy':	{'lev','levi'},
'lewis':	{'levis','lexis'},
'lexis':	{'levis','lewis'},
'li':	{'ai','ali','bi','ci','di','gi','hi','i','ii','ji','ki','l','la','lb','le','lei','lib','lid','lie','lii','lin','lip','lit','liv','ll','lo','lp','lr','lu','lv','ly','mi','ni','pi','qi','ri','si','ti','vi','wi','xi','yi'},
'liability':	{'viability'},
'liable':	{'viable'},
'liar':	{'lear','liars'},
'liars':	{'liar'},
'lib':	{'bib','glib','lab','lb','li','libs','lid','lie','lii','limb','lin','lip','lit','liv','llb','lob','nib','rib','sib'},
'libby':	{'lobby'},
'libel':	{'label'},
'liberal':	{'liberals','literal'},
'liberalisation':	{'liberalization'},
'liberalise':	{'liberalised','liberalises','liberalism','liberalize'},
'liberalised':	{'liberalise','liberalises','liberalized'},
'liberalises':	{'liberalise','liberalised','liberalizes'},
'liberalising':	{'liberalizing'},
'liberalism':	{'liberalise'},
'liberalization':	{'liberalisation'},
'liberalize':	{'liberalise','liberalized','liberalizes'},
'liberalized':	{'liberalised','liberalize','liberalizes'},
'liberalizes':	{'liberalises','liberalize','liberalized'},
'liberalizing':	{'liberalising'},
'liberally':	{'literally'},
'liberals':	{'liberal'},
'liberate':	{'liberated','liberates','literate'},
'liberated':	{'liberate','liberates'},
'liberates':	{'liberate','liberated'},
'liberation':	{'liberations'},
'liberations':	{'liberation'},
'liberator':	{'liberators'},
'liberators':	{'liberator'},
'liberia':	{'iberia','liberian','siberia'},
'liberian':	{'iberian','liberia','siberian'},
'libra':	{'libya','lira'},
'librarian':	{'librarians'},
'librarians':	{'librarian'},
'libs':	{'bibs','labs','lib','lids','lies','limbs','lips','ribs'},
'libya':	{'libra','libyan'},
'libyan':	{'libya'},
'lice':	{'dice','ice','lace','lick','lie','life','like','lime','line','lire','lite','live','luce','mice','nice','rice','slice','vice'},
'licence':	{'licences','license'},
'licences':	{'licence','licenses'},
'license':	{'licence','licensed','licensee','licenses'},
'licensed':	{'license','licensee','licenses'},
'licensee':	{'license','licensed','licensees','licenses'},
'licensees':	{'licensee','licenses'},
'licenses':	{'licences','license','licensed','licensee','licensees'},
'lichtenstein':	{'liechtenstein'},
'lick':	{'click','dick','flick','kick','lack','lice','licks','link','lock','luck','mick','nick','pick','rick','sick','slick','tick','wick'},
'licked':	{'clicked','kicked','lacked','liked','linked','locked','picked','ticked','wicked'},
'licking':	{'clicking','kicking','lacking','liking','linking','locking','picking','ticking'},
'licks':	{'clicks','flicks','kicks','lacks','lick','links','locks','picks','ticks'},
'lid':	{'aid','bid','cid','did','hid','id','kid','lad','laid','lcd','led','li','lib','lido','lids','lie','lied','lii','lin','lind','lip','lit','liv','lsd','mid','rid','slid'},
'lido':	{'dido','lid','lids','lilo','limo'},
'lids':	{'aids','bids','kids','lads','libs','lid','lido','lies','lips','rids','sids'},
'lie':	{'die','ie','le','lee','li','lib','lice','lid','lied','lien','lies','lieu','life','lii','like','lime','lin','line','lip','lire','lit','lite','liv','live','pie','tie','vie'},
'liechtenstein':	{'lichtenstein'},
'lied':	{'died','flied','led','lid','lie','lien','lies','lieu','liked','lind','lined','lived','pied','tied'},
'lien':	{'alien','lie','lied','liens','lies','lieu','lin','linen','lion','vien'},
'liens':	{'aliens','lens','lien','lies','linens'},
'lies':	{'dies','flies','lees','les','libs','lids','lie','lied','lien','liens','lieu','likes','lines','lips','lives','pies','ties'},
'lieu':	{'lie','lied','lien','lies','tieu'},
'life':	{'fife','lice','lie','lift','like','lime','line','lire','lite','live','rife','wife'},
'lifelike':	{'lifeline'},
'lifeline':	{'lifelike'},
'lifestyle':	{'lifestyles'},
'lifestyles':	{'lifestyle'},
'lifetime':	{'lifetimes'},
'lifetimes':	{'lifetime'},
'lift':	{'gift','left','life','lifts','lint','list','lit','loft','rift','sift'},
'lifted':	{'gifted','listed'},
'lifting':	{'listing'},
'lifts':	{'gifts','lift','lists','lofts'},
'ligament':	{'ligaments'},
'ligaments':	{'ligament'},
'ligand':	{'ligands'},
'ligands':	{'ligand'},
'light':	{'blight','eight','fight','flight','lights','might','night','plight','right','sight','slight','tight','wight'},
'lighted':	{'lighten','lighter','sighted','slighted'},
'lighten':	{'lighted','lighter','tighten'},
'lightening':	{'lightning','tightening'},
'lighter':	{'fighter','lighted','lighten','lighters','slighter','tighter'},
'lighters':	{'fighters','lighter'},
'lightest':	{'slightest','tightest'},
'lighthouse':	{'lighthouses'},
'lighthouses':	{'lighthouse'},
'lighting':	{'fighting','lightning','sighting','slighting'},
'lightly':	{'nightly','rightly','slightly','tightly'},
'lightness':	{'tightness'},
'lightning':	{'lightening','lighting'},
'lights':	{'eights','fights','flights','light','nights','rights','sights','slights','tights'},
'lii':	{'ii','iii','lei','li','lib','lid','lie','lin','lip','lit','liv','vii','xii'},
'like':	{'alike','bike','hike','ike','lake','lice','lie','life','liked','likes','lime','line','lire','lite','live','luke','mike','nike','pike'},
'liked':	{'licked','lied','like','likes','lined','linked','lived'},
'likeliest':	{'liveliest'},
'likelihood':	{'livelihood'},
'likely':	{'lively'},
'likes':	{'bikes','dikes','hikes','lakes','lies','like','liked','lines','lives','mikes','pikes'},
'liking':	{'biking','hiking','licking','lining','linking','living','viking'},
'lille':	{'lillie','lisle','ville'},
'lillie':	{'lille'},
'lilo':	{'kilo','lido','lily','limo','milo','silo'},
'lily':	{'lilo','oily'},
'lima':	{'lama','limb','lime','limo','limp','lira','liza','sima'},
'limb':	{'climb','lamb','lib','lima','limbo','limbs','lime','limo','limp'},
'limbo':	{'bimbo','limb','limbs','limo'},
'limbs':	{'climbs','libs','limb','limbo','limos'},
'lime':	{'dime','lame','lice','lie','life','like','lima','limb','limo','limp','line','lire','lite','live','mime','slime','time'},
'limit':	{'limits'},
'limitation':	{'imitation','limitations'},
'limitations':	{'imitations','limitation'},
'limited':	{'limiter'},
'limiter':	{'limited'},
'limits':	{'limit'},
'limo':	{'imo','lido','lilo','lima','limb','limbo','lime','limos','limp'},
'limos':	{'limbs','limo'},
'limousine':	{'limousines'},
'limousines':	{'limousine'},
'limp':	{'gimp','imp','lamp','lima','limb','lime','limo','lip','lisp','lump','pimp'},
'lin':	{'bin','din','fin','gin','in','kin','lain','lan','li','lib','lid','lie','lien','lii','lind','line','ling','link','lint','lion','lip','lit','liv','loin','lpn','min','pin','qin','sin','tin','win','yin'},
'lind':	{'bind','blind','find','hind','kind','land','lend','lid','lied','lin','lindy','line','lined','ling','link','lint','mind','wind'},
'linden':	{'linen'},
'lindy':	{'lind','windy'},
'line':	{'cine','cline','dine','fine','kline','lane','lice','lie','life','like','lime','lin','lind','lined','linen','liner','lines','ling','link','lint','lire','lite','live','lone','mine','nine','pine','sine','vine','wine','zine'},
'lineage':	{'linkage'},
'linear':	{'liner'},
'lined':	{'dined','fined','lied','liked','lind','line','linen','liner','lines','linked','lived','mined','wined'},
'linen':	{'lien','linden','line','lined','linens','liner','lines'},
'linens':	{'liens','linen','liners','lines'},
'liner':	{'diner','finer','line','linear','lined','linen','liners','lines','linger','liter','liver','miner'},
'liners':	{'diners','linens','liner','lines','liters','miners'},
'lines':	{'dines','fines','lanes','lies','likes','line','lined','linen','linens','liner','liners','links','lives','mines','nines','pines','vines','wines','zines'},
'ling':	{'cling','ding','fling','king','lin','lind','line','lingo','link','lint','long','lung','lying','ming','ning','ping','qing','ring','sing','sling','ting','wing','ying'},
'linger':	{'finger','ginger','liner','longer','ringer','singer','winger'},
'lingering':	{'fingering'},
'lingo':	{'bingo','ling'},
'linguistic':	{'linguistics'},
'linguistics':	{'linguistic'},
'lining':	{'dining','liking','linking','living','mining','wining'},
'link':	{'blink','fink','ink','lick','lin','lind','line','ling','links','lint','mink','pink','rink','sink','wink'},
'linkage':	{'lineage','linkages'},
'linkages':	{'linkage'},
'linked':	{'blinked','licked','liked','lined'},
'linking':	{'blinking','licking','liking','lining','sinking'},
'links':	{'inks','kinks','licks','lines','link','sinks'},
'lint':	{'flint','hint','int','lent','lift','lin','lind','line','ling','link','list','lit','mint','pint','tint'},
'lion':	{'ion','leon','lien','lin','loon','lyon','zion'},
'lip':	{'clip','dip','flip','hip','ip','kip','lap','li','lib','lid','lie','lii','limp','lin','lips','lisp','lit','liv','lp','nip','pip','rip','sip','slip','tip','vip','yip','zip'},
'lipid':	{'lipids'},
'lipids':	{'lipid'},
'lips':	{'clips','dips','flips','hips','laps','libs','lids','lies','lip','mips','rips','sips','slips','tips','zips'},
'liquid':	{'liquids'},
'liquids':	{'liquid'},
'lira':	{'ira','libra','lima','lire','liza','lyra'},
'lire':	{'dire','eire','fire','hire','ire','lice','lie','life','like','lime','line','lira','lite','litre','live','loire','lore','lure','sire','tire','wire'},
'lisle':	{'aisle','isle','lille'},
'lisp':	{'limp','lip','list','wisp'},
'list':	{'fist','gist','hist','last','lest','lift','lint','lisp','lists','liszt','lit','lost','lust','mist'},
'listed':	{'lasted','lifted','listen','lister'},
'listen':	{'listed','listens','lister'},
'listened':	{'listener'},
'listener':	{'listened','listeners'},
'listeners':	{'listener'},
'listening':	{'glistening'},
'listens':	{'listen'},
'lister':	{'blister','listed','listen','liter','litter','luster','mister','sister'},
'listing':	{'lasting','lifting','listings'},
'listings':	{'listing'},
'lists':	{'fists','lasts','lifts','list'},
'liszt':	{'list'},
'lit':	{'bit','fit','git','hit','it','kit','lat','let','li','lib','lid','lie','lift','lii','lin','lint','lip','list','lite','liv','lot','mit','nit','pit','sit','slit','tit','wit'},
'lite':	{'bite','cite','elite','kite','late','lice','lie','life','like','lime','line','lire','lit','liter','litre','live','mite','rite','site'},
'liter':	{'later','liner','lister','lite','liters','litter','liver'},
'literacy':	{'literary'},
'literal':	{'lateral','liberal'},
'literally':	{'laterally','liberally'},
'literary':	{'literacy'},
'literate':	{'iterate','liberate'},
'liters':	{'liners','liter'},
'lithuania':	{'lithuanian'},
'lithuanian':	{'lithuania'},
'litigation':	{'mitigation'},
'litre':	{'lire','lite','litres','mitre','titre'},
'litres':	{'litre'},
'litter':	{'bitter','fitter','glitter','hitter','jitter','latter','letter','lister','liter','littler','sitter'},
'little':	{'littler'},
'littler':	{'litter','little'},
'liv':	{'hiv','iv','lev','li','lib','lid','lie','lii','lin','lip','lit','live','lv','xiv'},
'live':	{'alive','clive','dive','five','give','hive','jive','lice','lie','life','like','lime','line','lire','lite','liv','lived','liver','lives','love','olive'},
'lived':	{'dived','lied','liked','lined','live','liver','lives','loved'},
'liveliest':	{'likeliest'},
'livelihood':	{'likelihood','livelihoods'},
'livelihoods':	{'livelihood'},
'lively':	{'likely','livery','lovely'},
'liver':	{'diver','giver','lever','liner','liter','live','lived','livery','lives','lover','oliver','river'},
'livery':	{'lively','liver'},
'lives':	{'dives','fives','gives','hives','ives','lies','likes','lines','live','lived','liver','loves','olives','wives'},
'living':	{'diving','giving','liking','lining','loving'},
'livingston':	{'livingstone'},
'livingstone':	{'livingston'},
'liza':	{'lima','lira'},
'lizard':	{'lizards','wizard'},
'lizards':	{'lizard'},
'll':	{'al','all','bl','cl','el','ell','fl','il','ill','l','la','lb','le','li','llb','lo','lp','lr','lu','lv','ly','ml','tl','xl'},
'llama':	{'lama'},
'llb':	{'alb','lab','lb','lib','ll','lob'},
'lo':	{'co','do','fo','go','ho','io','ko','l','la','lao','lb','le','leo','li','ll','lob','log','loo','lot','low','lp','lr','lu','luo','lv','ly','mo','no','o','plo','po','so','to','wo'},
'load':	{'lad','lead','loads','loaf','loam','loan','lord','loud','road','toad'},
'loaded':	{'leaded','loader','loaned'},
'loader':	{'leader','loaded','loaders','louder'},
'loaders':	{'leaders','loader'},
'loading':	{'leading','loadings'},
'loadings':	{'loading'},
'loads':	{'lads','leads','load','loans','lords','roads'},
'loaf':	{'leaf','load','loam','loan'},
'loam':	{'foam','lam','load','loaf','loan','loom','roam'},
'loan':	{'lan','lean','load','loaf','loam','loans','logan','loin','loon','moan'},
'loaned':	{'leaned','loaded','moaned'},
'loans':	{'leans','loads','loan','moans'},
'loaves':	{'leaves','loves'},
'lob':	{'blob','bob','cob','fob','hob','job','lab','lb','lib','llb','lo','lobe','log','loo','lot','low','mob','nob','ob','rob','sob'},
'lobbied':	{'lobbies'},
'lobbies':	{'hobbies','lobbied'},
'lobby':	{'bobby','hobby','libby'},
'lobbyist':	{'lobbyists'},
'lobbyists':	{'lobbyist'},
'lobe':	{'globe','kobe','lob','lobes','lone','lore','lose','love','lube','robe'},
'lobes':	{'globes','lobe','loses','loves','lubes','robes'},
'local':	{'focal','locale','locals','loyal','vocal'},
'locale':	{'local','locales','locals','locate'},
'locales':	{'locale','locals','locates'},
'localisation':	{'localization'},
'localised':	{'localized'},
'localization':	{'localisation'},
'localized':	{'localised'},
'locally':	{'loyally'},
'locals':	{'local','locale','locales','vocals'},
'locate':	{'locale','located','locates'},
'located':	{'locate','locates'},
'locates':	{'locales','locate','located'},
'location':	{'locations','vocation'},
'locations':	{'location'},
'loch':	{'bloch','koch','loci','lock','loco','och'},
'loci':	{'loch','lock','loco','loki'},
'lock':	{'block','bock','clock','cock','dock','flock','jock','lack','lick','loch','loci','locke','locks','loco','look','luck','mock','rock','sock'},
'locke':	{'lock','locked','locker','locks'},
'locked':	{'blocked','clocked','docked','lacked','licked','locke','locker','looked','mocked','rocked'},
'locker':	{'blocker','locke','locked','lockers','rocker'},
'lockers':	{'blockers','locker','rockers'},
'locking':	{'blocking','docking','lacking','licking','looking','mocking','rocking'},
'lockout':	{'lookout'},
'locks':	{'blocks','clocks','cocks','docks','flocks','jocks','lacks','licks','lock','locke','locus','looks','rocks','socks'},
'locksmith':	{'locksmiths'},
'locksmiths':	{'locksmith'},
'loco':	{'coco','loch','loci','lock','logo','loo'},
'locomotive':	{'locomotives'},
'locomotives':	{'locomotive'},
'locus':	{'focus','locks','locust','lotus'},
'locust':	{'locus'},
'lodge':	{'dodge','ledge','lodged','lodges'},
'lodged':	{'lodge','lodges','logged','longed'},
'lodges':	{'lodge','lodged'},
'lodging':	{'dodging','lodgings','logging','longing'},
'lodgings':	{'lodging'},
'loft':	{'aloft','left','lift','lofts','lofty','loot','lost','lot','oft','soft'},
'lofts':	{'lifts','loft','lofty','lots'},
'lofty':	{'lefty','loft','lofts'},
'log':	{'blog','bog','clog','cog','dog','fog','hog','jog','lag','leg','lo','lob','logo','logs','long','loo','lot','low','lug'},
'logan':	{'hogan','loan','login','slogan'},
'logged':	{'bogged','clogged','dogged','lagged','legged','lodged','logger','longed'},
'logger':	{'blogger','jogger','logged','loggers','longer'},
'loggers':	{'logger'},
'logging':	{'clogging','jogging','lagging','lodging','longing'},
'logic':	{'login'},
'logician':	{'logicians'},
'logicians':	{'logician'},
'login':	{'logan','logic','loin'},
'logistic':	{'logistics'},
'logistics':	{'logistic'},
'logo':	{'lego','loco','log','logos','logs','loo','togo'},
'logos':	{'lagos','logo','logs'},
'logs':	{'blogs','clogs','dogs','hogs','lags','legs','log','logo','logos','longs','loss','lots','lows'},
'loin':	{'coin','join','lain','lin','loan','login','loon'},
'loire':	{'lire','lore'},
'loki':	{'loci'},
'lombard':	{'lombardy'},
'lombardy':	{'lombard'},
'lone':	{'alone','bone','clone','cone','done','gone','hone','lane','leone','line','lobe','long','lore','lose','love','none','one','tone','zone'},
'lonely':	{'lovely'},
'long':	{'along','bong','dong','gong','ling','log','lone','longs','lung','pong','song'},
'longed':	{'lodged','logged','longer'},
'longer':	{'linger','logger','longed'},
'longing':	{'lodging','logging'},
'longs':	{'bongs','logs','long','lungs','songs'},
'loo':	{'boo','coo','goo','lao','leo','lo','lob','loco','log','logo','look','loom','loon','loop','loot','lot','low','luo','moo','poo','too','woo','zoo'},
'look':	{'book','cook','hook','lock','loo','looks','loom','loon','loop','loot','nook','rook','took'},
'looked':	{'booked','cooked','hooked','locked','looted'},
'looking':	{'booking','cooking','hooking','locking','looming','looping','loosing','looting'},
'lookout':	{'lockout'},
'looks':	{'books','cooks','hooks','locks','look','looms','loops'},
'loom':	{'bloom','boom','doom','gloom','loam','loo','look','looms','loon','loop','loot','room','zoom'},
'looming':	{'blooming','booming','looking','looping','loosing','looting','zooming'},
'looms':	{'blooms','booms','looks','loom','loops','rooms'},
'loon':	{'boon','coon','leon','lion','loan','loin','loo','look','loom','loop','loot','lyon','moon','noon','soon'},
'loop':	{'coop','hoop','loo','look','loom','loon','loops','loot','poop'},
'loophole':	{'loopholes'},
'loopholes':	{'loophole'},
'looping':	{'looking','looming','loosing','looting'},
'loops':	{'hoops','looks','looms','loop'},
'loose':	{'goose','loosen','looser','lose','moose'},
'loosen':	{'loose','looser'},
'looser':	{'loose','loosen','loser'},
'loosing':	{'looking','looming','looping','looting','losing'},
'loot':	{'boot','foot','hoot','loft','loo','look','loom','loon','loop','lost','lot','moot','root','soot'},
'looted':	{'booted','footed','looked','rooted'},
'looting':	{'booting','footing','looking','looming','looping','loosing','rooting'},
'lord':	{'cord','ford','load','lords','lore','loud','word'},
'lords':	{'cords','loads','lord','words'},
'lordship':	{'lordships'},
'lordships':	{'lordship'},
'lore':	{'bore','core','fore','gore','lire','lobe','loire','lone','lord','loren','lose','love','lure','more','ore','pore','sore','tore','wore'},
'loren':	{'lore','lorenz'},
'lorentz':	{'lorenz'},
'lorenz':	{'loren','lorentz'},
'lose':	{'bose','close','dose','hose','lobe','lone','loose','lore','loser','loses','loss','lost','love','nose','pose','rose'},
'loser':	{'closer','laser','looser','lose','losers','loses','lover','lower','poser'},
'losers':	{'lasers','loser','loses','lovers','lowers'},
'loses':	{'closes','doses','hoses','lobes','lose','loser','losers','loss','losses','loves','moses','noses','poses','roses'},
'losing':	{'closing','dosing','loosing','loving','lowing','posing'},
'loss':	{'boss','floss','gloss','lass','less','logs','lose','loses','lost','lots','lows','moss','ross','toss'},
'losses':	{'bosses','loses'},
'lost':	{'cost','host','last','lest','list','loft','loot','lose','loss','lot','lust','most','post'},
'lot':	{'blot','bot','clot','cot','dot','got','hot','lat','let','lit','lo','lob','loft','log','loo','loot','lost','lots','low','mot','not','plot','pot','rot','slot','sot','tot','wot'},
'lotion':	{'lotions','motion','notion','potion'},
'lotions':	{'lotion','motions','notions','potions'},
'lots':	{'bots','clots','cots','dots','lats','lets','lofts','logs','loss','lot','lotus','lows','plots','pots','rots','slots','tots'},
'lottery':	{'pottery'},
'lotto':	{'motto'},
'lotus':	{'locus','lots'},
'loud':	{'aloud','cloud','load','lord'},
'louder':	{'lauder','loader'},
'loudspeaker':	{'loudspeakers'},
'loudspeakers':	{'loudspeaker'},
'lough':	{'bough','cough','dough','laugh','plough','rough','slough','tough'},
'lounge':	{'lounges'},
'lounges':	{'lounge'},
'lovable':	{'movable'},
'love':	{'clove','cove','dove','glove','live','lobe','lone','lore','lose','loved','lover','loves','move','rove','wove'},
'loved':	{'lived','love','lover','loves','moved'},
'lovell':	{'lovely','lowell'},
'lovely':	{'lively','lonely','lovell'},
'lover':	{'clover','cover','dover','hover','lever','liver','loser','love','loved','lovers','loves','lower','mover','over','plover','rover'},
'lovers':	{'covers','levers','losers','lover','loves','lowers','movers','overs','rovers'},
'loves':	{'cloves','doves','gloves','lives','loaves','lobes','loses','love','loved','lover','lovers','moves'},
'loving':	{'living','losing','lowing','moving','roving'},
'low':	{'blow','bow','cow','flow','glow','how','law','lo','lob','log','loo','lot','lows','now','ow','plow','pow','row','slow','sow','tow','vow','wow'},
'lowdown':	{'slowdown'},
'lowell':	{'lovell','powell'},
'lower':	{'blower','bower','flower','loser','lover','lowers','mower','power','slower','tower'},
'lowered':	{'flowered','powered'},
'lowering':	{'flowering','powering','towering'},
'lowers':	{'flowers','losers','lovers','lower','mowers','powers','towers'},
'lowest':	{'slowest'},
'lowing':	{'blowing','bowing','flowing','glowing','losing','loving','mowing','owing','rowing','slowing','sowing','towing'},
'lowly':	{'slowly'},
'lows':	{'blows','bows','cows','flows','hows','laws','logs','loss','lots','low','rows','slows','sows','vows'},
'loyal':	{'local','royal'},
'loyally':	{'locally','loyalty','royally'},
'loyalty':	{'loyally','royalty'},
'lp':	{'alp','dp','gp','hp','ip','kp','l','la','lap','lb','le','li','lip','ll','lo','lpn','lr','lu','lv','ly','mp','np','op','p','up'},
'lpn':	{'lan','lin','lp'},
'lr':	{'ar','br','cr','dr','er','fr','hr','ir','jr','kr','l','la','lb','le','li','ll','lo','lp','lu','lv','ly','mr','or','pr','qr','r','sr','ur','yr','zr'},
'lsd':	{'lad','lcd','led','lid','sd'},
'lu':	{'au','cu','du','eu','flu','gu','ju','l','la','lb','le','li','ll','lo','lp','lr','lug','luo','lv','ly','mu','nu','pu','ru','su','u','wu','zu'},
'luau':	{'lulu'},
'lube':	{'cube','lobe','lubes','luce','luge','luke','lure','tube'},
'lubes':	{'cubes','lobes','lube','lures','tubes'},
'lubricant':	{'lubricants'},
'lubricants':	{'lubricant'},
'luce':	{'lace','lice','lube','luck','lucy','luge','luke','lure'},
'luck':	{'buck','duck','fuck','huck','lack','lick','lock','luce','lucky','lucy','muck','pluck','puck','suck','tuck'},
'lucky':	{'ducky','luck','lucy'},
'lucy':	{'lacy','luce','luck','lucky'},
'lug':	{'aug','bug','dug','hug','jug','lag','leg','log','lu','luge','lung','luo','mug','plug','pug','rug','slug','tug'},
'luge':	{'huge','lube','luce','lug','luke','lure'},
'luke':	{'duke','fluke','lake','like','lube','luce','luge','lure','nuke','puke'},
'lulu':	{'luau','zulu'},
'lumbar':	{'lumber'},
'lumber':	{'lumbar','number','plumber','slumber'},
'lump':	{'bump','dump','hump','jump','lamp','limp','lumps','plump','pump','slump','sump'},
'lumps':	{'bumps','clumps','dumps','humps','jumps','lamps','lump','pumps'},
'luna':	{'lena','lunar','lung','tuna','una'},
'lunar':	{'luna'},
'lunch':	{'bunch','launch','lynch','munch','punch'},
'lunches':	{'bunches','launches','punches'},
'lung':	{'clung','dung','flung','hung','jung','ling','long','lug','luna','lungs','rung','sung'},
'lungs':	{'longs','lung'},
'luo':	{'duo','lao','leo','lo','loo','lu','lug'},
'lure':	{'cure','lire','lore','lube','luce','luge','luke','lured','lures','pure','sure'},
'lured':	{'cured','lure','lures'},
'lures':	{'cures','lubes','lure','lured'},
'lush':	{'blush','bush','flush','hush','lash','lust','plush','push','rush'},
'lust':	{'bust','dust','gust','just','last','lest','list','lost','lush','lusty','must','rust'},
'luster':	{'buster','cluster','custer','duster','lister','muster'},
'lusty':	{'busty','dusty','lust','rusty'},
'lv':	{'av','cv','ev','iv','jv','l','la','lb','le','lev','li','liv','ll','lo','lp','lr','lu','ly','nv','rv','tv','uv','v','wv','xv'},
'ly':	{'by','dy','fly','ky','l','la','lay','lb','le','li','ll','lo','lp','lr','lu','lv','my','ny','ply','sly','wy','y'},
'lying':	{'dying','flying','laying','ling','tying','vying','ying'},
'lymph':	{'nymph'},
'lymphocyte':	{'lymphocytes'},
'lymphocytes':	{'lymphocyte'},
'lynch':	{'lunch'},
'lyon':	{'leon','lion','loon','lyons','yon'},
'lyons':	{'lyon'},
'lyra':	{'lira'},
'lyric':	{'lyrics'},
'lyrics':	{'lyric'},
'ma':	{'a','ba','ca','da','ea','fa','ga','ha','ia','ka','la','mac','mad','mag','maj','mal','man','mao','map','mar','mas','mat','max','may','mb','mba','mc','md','me','mfa','mg','mi','ml','mm','mn','mo','mp','mr','ms','mt','mu','my','na','pa','ra','sa','ta','va','wa','ya','za'},
'mac':	{'ac','lac','ma','mace','mach','mack','mad','mag','maj','mal','man','mao','map','mar','marc','mas','mat','max','may','mc','pac','sac','vac','wac'},
'macao':	{'macho','macro'},
'mace':	{'ace','face','lace','mac','mach','mack','made','make','male','mane','mare','mate','maze','mice','pace','race'},
'macedonia':	{'macedonian'},
'macedonian':	{'macedonia'},
'mach':	{'bach','each','mac','mace','macho','mack','march','mash','match','math','much'},
'machine':	{'machined','machines'},
'machined':	{'machine','machines'},
'machines':	{'machine','machined'},
'macho':	{'macao','mach','macro'},
'macintosh':	{'mackintosh','mcintosh'},
'mack':	{'back','hack','jack','lack','mac','mace','mach','mark','mask','mick','mock','muck','pack','rack','sack','smack','tack'},
'mackintosh':	{'macintosh'},
'macon':	{'bacon','mason'},
'macro':	{'macao','macho','macros','micro'},
'macroeconomic':	{'macroeconomics'},
'macroeconomics':	{'macroeconomic','microeconomics'},
'macrophage':	{'macrophages'},
'macrophages':	{'macrophage'},
'macros':	{'macro'},
'macroscopic':	{'microscopic'},
'mad':	{'ad','bad','cad','dad','fad','had','lad','ma','mac','made','mag','maid','maj','mal','man','mao','map','mar','mas','mat','max','may','md','mead','med','mid','mod','mud','pad','rad','sad','tad','wad'},
'madam':	{'adam','madame'},
'madame':	{'madam'},
'madden':	{'madder','maiden','sadden'},
'madder':	{'adder','ladder','madden','sadder'},
'maddest':	{'saddest'},
'made':	{'ade','bade','fade','jade','mace','mad','make','male','mane','mare','mate','maze','meade','mode','sade','wade'},
'madly':	{'badly','manly','sadly'},
'madness':	{'badness','sadness'},
'mafia':	{'maia','mania','maria'},
'mag':	{'ag','bag','dag','fag','gag','jag','lag','ma','mac','mad','magi','maj','mal','man','mao','map','mar','mas','mat','max','may','meg','mg','mpg','msg','mug','nag','rag','sag','tag'},
'magazine':	{'magazines'},
'magazines':	{'magazine'},
'magi':	{'mag','magic','mali','mari','maui','maxi'},
'magic':	{'magi','manic'},
'magician':	{'magicians'},
'magicians':	{'magician'},
'magistrate':	{'magistrates'},
'magistrates':	{'magistrate'},
'magma':	{'mama'},
'magnet':	{'magneto','magnets'},
'magnetic':	{'magnetics'},
'magnetics':	{'magnetic'},
'magneto':	{'magnet','magnets'},
'magnets':	{'magnet','magneto'},
'magnified':	{'magnifier'},
'magnifier':	{'magnified'},
'magnitude':	{'magnitudes'},
'magnitudes':	{'magnitude'},
'mahler':	{'mailer'},
'maia':	{'mafia','maid','mail','main','mala','mama','mania','mara','maria','maya'},
'maid':	{'aid','laid','mad','maia','maids','mail','main','mid','paid','raid','said'},
'maiden':	{'madden'},
'maids':	{'aids','maid','mails','mains','raids'},
'mail':	{'bail','dail','email','fail','hail','jail','maia','maid','mails','main','mal','mall','mil','nail','rail','sail','tail'},
'mailed':	{'emailed','failed','hailed','jailed','mailer','nailed','sailed','tailed'},
'mailer':	{'mahler','mailed','mailers'},
'mailers':	{'mailer'},
'mailing':	{'ailing','emailing','failing','mailings','nailing','railing','sailing','wailing'},
'mailings':	{'failings','mailing','railings','sailings'},
'mails':	{'emails','fails','hails','jails','maids','mail','mains','malls','nails','rails','sails','tails'},
'main':	{'cain','gain','jain','lain','maia','maid','mail','maine','mains','man','mann','min','pain','rain','vain'},
'maine':	{'main','mains','maize','mane','marine','mine','paine'},
'mainly':	{'manly','vainly'},
'mains':	{'gains','maids','mails','main','maine','mans','pains','rains'},
'maintain':	{'maintains'},
'maintained':	{'maintainer'},
'maintainer':	{'maintained','maintainers'},
'maintainers':	{'maintainer'},
'maintains':	{'maintain'},
'maize':	{'maine','maze'},
'maj':	{'ma','mac','mad','mag','mal','man','mao','map','mar','mas','mat','max','may','raj'},
'major':	{'majors','manor','mayor'},
'majors':	{'major','mayors'},
'make':	{'bake','cake','fake','lake','mace','made','maker','makes','male','mane','mare','mate','maze','mike','rake','sake','take','wake'},
'makeover':	{'takeover'},
'maker':	{'baker','make','makers','makes','marker','mater','mayer','taker'},
'makers':	{'bakers','maker','makes','markers','takers'},
'makes':	{'bakes','cakes','fakes','lakes','make','maker','makers','males','mares','mates','mikes','rakes','sakes','takes','wakes'},
'making':	{'baking','marking','masking','mating','raking','taking','waking'},
'mal':	{'al','dal','gal','ma','mac','mad','mag','mail','maj','mala','male','mali','mall','malt','man','mao','map','mar','mas','mat','max','may','meal','mil','ml','pal'},
'mala':	{'ala','gala','maia','mal','malay','male','mali','mall','malt','malta','mama','mara','maya','tala'},
'malay':	{'mala','malaya'},
'malaya':	{'malay'},
'malaysia':	{'malaysian'},
'malaysian':	{'malaysia'},
'male':	{'ale','bale','dale','gale','hale','mace','made','make','mal','mala','males','mali','mall','malt','mane','maple','mare','mate','maze','mile','mole','mule','pale','sale','tale','vale','yale'},
'males':	{'ales','bales','makes','male','malls','maples','mares','mates','miles','moles','mules','pales','sales','tales','wales'},
'malfunction':	{'malfunctions'},
'malfunctions':	{'malfunction'},
'mali':	{'ali','bali','cali','dali','kali','magi','mal','mala','male','mall','malt','mari','maui','maxi'},
'mall':	{'all','ball','call','fall','gall','hall','mail','mal','mala','male','mali','malls','malt','mill','moll','mull','pall','small','tall','wall'},
'mallet':	{'ballet','millet','mullet','pallet','wallet'},
'malls':	{'balls','calls','falls','halls','mails','males','mall','mills','walls'},
'malone':	{'alone'},
'malt':	{'alt','halt','mal','mala','male','mali','mall','malta','mart','mast','mat','matt','melt','milt','salt'},
'malta':	{'mala','malt','manta'},
'mama':	{'kama','lama','magma','maia','mala','mamas','mara','maya','rama'},
'mamas':	{'mama'},
'mammal':	{'mammals'},
'mammals':	{'mammal'},
'man':	{'an','ban','can','fan','han','jan','lan','ma','mac','mad','mag','main','maj','mal','mane','mann','mano','mans','manx','many','mao','map','mar','mas','mat','max','may','mean','men','min','mn','moan','mon','nan','oman','pan','ran','tan','van','wan'},
'manage':	{'managed','manager','manages'},
'managed':	{'manage','manager','manages'},
'manager':	{'manage','managed','managers','manages','manger'},
'managers':	{'manager','manages'},
'manages':	{'manage','managed','manager','managers'},
'mandate':	{'mandated','mandates'},
'mandated':	{'mandate','mandates'},
'mandates':	{'mandate','mandated'},
'mane':	{'bane','cane','dane','lane','mace','made','maine','make','male','man','mann','mano','mans','manx','many','mare','mate','maze','mine','pane','sane'},
'maneuver':	{'maneuvers'},
'maneuvers':	{'maneuver'},
'manger':	{'anger','danger','hanger','manager','manner','ranger','sanger'},
'mangled':	{'angled','mingled','tangled'},
'mango':	{'mano','tango'},
'mania':	{'mafia','maia','maniac','manic','manila','manta','maria'},
'maniac':	{'mania','maniacs','manic'},
'maniacs':	{'maniac'},
'manic':	{'magic','mania','maniac','panic'},
'manicure':	{'manicures'},
'manicures':	{'manicure'},
'manifest':	{'manifesto','manifests'},
'manifestation':	{'manifestations'},
'manifestations':	{'manifestation'},
'manifesto':	{'manifest','manifests'},
'manifests':	{'manifest','manifesto'},
'manifold':	{'manifolds'},
'manifolds':	{'manifold'},
'manila':	{'mania'},
'manipulate':	{'manipulated','manipulates'},
'manipulated':	{'manipulate','manipulates'},
'manipulates':	{'manipulate','manipulated'},
'manipulation':	{'manipulations'},
'manipulations':	{'manipulation'},
'manly':	{'madly','mainly','many','meanly'},
'mann':	{'main','man','mane','mano','mans','manx','many'},
'manned':	{'banned','canned','fanned','manner','tanned'},
'manner':	{'banner','manger','manned','manners','tanner'},
'manners':	{'banners','manner'},
'mano':	{'man','mane','mango','mann','manor','mans','manx','many','mao','mayo','mono'},
'manor':	{'major','mano','mayor','minor'},
'mans':	{'ans','bans','cans','dans','fans','mains','man','mane','mann','mano','manx','many','maps','mars','mas','mass','mats','mays','means','moans','pans','sans','vans'},
'mansion':	{'mansions','manson'},
'mansions':	{'mansion'},
'manson':	{'mansion','mason'},
'manta':	{'malta','mania','mantra','santa'},
'mantra':	{'manta','tantra'},
'manual':	{'manuals'},
'manuals':	{'manual'},
'manufacture':	{'manufactured','manufacturer','manufactures'},
'manufactured':	{'manufacture','manufacturer','manufactures'},
'manufacturer':	{'manufacture','manufactured','manufacturers','manufactures'},
'manufacturers':	{'manufacturer','manufactures'},
'manufactures':	{'manufacture','manufactured','manufacturer','manufacturers'},
'manure':	{'mature'},
'manuscript':	{'manuscripts'},
'manuscripts':	{'manuscript'},
'manx':	{'man','mane','mann','mano','mans','many','marx','max'},
'many':	{'any','man','mane','manly','mann','mano','mans','manx','mary','may'},
'mao':	{'gao','hao','lao','ma','mac','mad','mag','maj','mal','man','mano','map','mar','mas','mat','max','may','mayo','mo','moo','tao'},
'maori':	{'mari'},
'map':	{'cap','gap','hap','lap','ma','mac','mad','mag','maj','mal','man','mao','maps','mar','mas','mat','max','may','mop','mp','mvp','nap','pap','rap','sap','tap','yap','zap'},
'maple':	{'male','maples'},
'maples':	{'males','maple','naples'},
'mapped':	{'capped','mapper','tapped'},
'mapper':	{'mapped','rapper'},
'mapping':	{'capping','mappings','tapping'},
'mappings':	{'cappings','mapping'},
'maps':	{'caps','gaps','laps','mans','map','mars','mas','mass','mats','mays','mips','taps'},
'mar':	{'ar','bar','car','dar','ear','far','gar','jar','ma','mac','mad','mag','maj','mal','man','mao','map','mara','marc','mare','mari','mark','mars','mart','marx','mary','mas','mat','max','may','mr','oar','par','tar','var','war'},
'mara':	{'ara','maia','mala','mama','mar','marc','mare','mari','maria','mark','mars','mart','marx','mary','maya','nara','para','tara'},
'marble':	{'marbles'},
'marbles':	{'marble'},
'marc':	{'arc','mac','mar','mara','march','mare','mari','mark','mars','mart','marx','mary'},
'marcel':	{'marvel','parcel'},
'march':	{'arch','mach','marc','marsh','match'},
'marched':	{'arched','marches','matched'},
'marchers':	{'marches'},
'marches':	{'arches','marched','marchers','marshes','matches'},
'marching':	{'arching','matching'},
'mare':	{'are','bare','care','dare','fare','hare','mace','made','make','male','mane','mar','mara','marc','mares','marge','mari','mark','mars','mart','marx','mary','mate','maze','mere','more','rare','ware'},
'mares':	{'ares','bares','cares','dares','fares','makes','males','mare','marks','mars','mates','wares'},
'marge':	{'barge','large','mare','merge'},
'margin':	{'margins','marlin','martin'},
'margins':	{'margin'},
'mari':	{'bari','dari','magi','mali','maori','mar','mara','marc','mare','maria','mark','mars','mart','marti','marx','mary','maui','maxi','mri','sari'},
'maria':	{'aria','mafia','maia','mania','mara','mari','marian','marina'},
'marian':	{'maria','martian'},
'marina':	{'carina','maria','marinas','marine'},
'marinas':	{'marina','marines'},
'marine':	{'maine','marina','mariner','marines','murine'},
'mariner':	{'marine','marines'},
'marines':	{'marinas','marine','mariner'},
'mark':	{'ark','bark','dark','lark','mack','mar','mara','marc','mare','mari','marks','mars','mart','marx','mary','mask','park'},
'marked':	{'marker','market','marred','masked','parked'},
'marker':	{'barker','darker','maker','marked','markers','market','parker'},
'markers':	{'makers','marker','markets'},
'market':	{'marked','marker','markets'},
'marketed':	{'marketer'},
'marketer':	{'marketed','marketers'},
'marketers':	{'marketer'},
'marketplace':	{'marketplaces'},
'marketplaces':	{'marketplace'},
'markets':	{'markers','market'},
'marking':	{'barking','making','markings','masking','parking'},
'markings':	{'marking'},
'marks':	{'mares','mark','mars','masks','parks'},
'marley':	{'barley','morley'},
'marlin':	{'margin','martin','merlin'},
'marque':	{'marquee','masque'},
'marquee':	{'marque'},
'marquis':	{'marquise'},
'marquise':	{'marquis'},
'marred':	{'barred','marked','married','warred'},
'marriage':	{'carriage','marriages'},
'marriages':	{'carriages','marriage'},
'married':	{'carried','marred','marries'},
'marries':	{'carries','married'},
'marrow':	{'arrow','barrow','harrow','morrow','narrow'},
'marry':	{'carry','harry','mary','merry','parry'},
'marrying':	{'carrying'},
'mars':	{'bars','cars','ears','jars','mans','maps','mar','mara','marc','mare','mares','mari','mark','marks','marsh','mart','marx','mary','mas','mass','mats','mays','mrs','oars','wars'},
'marsh':	{'harsh','march','mars','mash'},
'marshal':	{'marshall'},
'marshall':	{'marshal'},
'marshes':	{'marches'},
'mart':	{'art','bart','cart','dart','fart','hart','kart','malt','mar','mara','marc','mare','mari','mark','mars','marti','marx','mary','mast','mat','matt','part','smart','tart'},
'marti':	{'mari','mart','martin'},
'martial':	{'martian','partial'},
'martian':	{'marian','martial','martin'},
'martin':	{'margin','marlin','marti','martian','martini'},
'martini':	{'martin'},
'martyr':	{'martyrs'},
'martyrs':	{'martyr'},
'marvel':	{'marcel'},
'marvellous':	{'marvelous'},
'marvelous':	{'marvellous'},
'marx':	{'manx','mar','mara','marc','mare','mari','mark','mars','mart','mary','max'},
'marxism':	{'marxist'},
'marxist':	{'marxism'},
'mary':	{'gary','many','mar','mara','marc','mare','mari','mark','marry','mars','mart','marx','may','vary','wary'},
'mas':	{'as','gas','has','ma','mac','mad','mag','maj','mal','man','mans','mao','map','maps','mar','mars','mash','mask','mass','mast','mat','mats','max','may','mays','mes','mrs','ms','mus','oas','pas','was','xmas'},
'mascot':	{'ascot'},
'mash':	{'ash','bash','cash','dash','hash','lash','mach','marsh','mas','mask','mass','mast','math','mesh','nash','rash','sash','smash','wash'},
'mashed':	{'dashed','masked','smashed','washed'},
'mask':	{'ask','mack','mark','mas','mash','masks','mass','mast','musk','task'},
'masked':	{'asked','marked','mashed','tasked'},
'masking':	{'asking','making','marking','tasking'},
'masks':	{'asks','marks','mask','mass','tasks'},
'mason':	{'jason','macon','manson'},
'masque':	{'basque','marque','mosque'},
'mass':	{'ass','bass','lass','mans','maps','mars','mas','mash','mask','masks','mast','mats','mays','mess','miss','moss','muss','pass'},
'massacre':	{'massacres'},
'massacres':	{'massacre'},
'massage':	{'massages','message','passage'},
'massages':	{'massage','messages','passages'},
'masses':	{'asses','basses','misses','passes'},
'massive':	{'passive'},
'massively':	{'passively'},
'mast':	{'cast','east','fast','hast','last','malt','mart','mas','mash','mask','mass','mat','matt','mist','most','mst','must','past','vast'},
'master':	{'aster','caster','easter','faster','masters','mastery','mater','matter','mister','muster','raster'},
'mastered':	{'mattered'},
'mastering':	{'mattering'},
'masterpiece':	{'masterpieces'},
'masterpieces':	{'masterpiece'},
'masters':	{'casters','master','mastery','matters'},
'mastery':	{'master','masters','mystery'},
'mat':	{'at','bat','cat','dat','eat','fat','hat','kat','lat','ma','mac','mad','mag','maj','mal','malt','man','mao','map','mar','mart','mas','mast','mate','math','mats','matt','max','may','meat','met','mit','mot','mst','mt','oat','pat','rat','sat','tat','vat','wat'},
'match':	{'batch','catch','hatch','latch','mach','march','math','patch','watch'},
'matched':	{'hatched','marched','matches','patched','watched'},
'matches':	{'batches','catches','latches','marches','matched','patches','watches'},
'matching':	{'catching','hatching','marching','patching','watching'},
'mate':	{'ate','date','fate','gate','hate','late','mace','made','make','male','mane','mare','mat','mated','mater','mates','math','mats','matt','matte','maze','mite','mute','pate','rate','tate'},
'mated':	{'dated','fated','gated','hated','mate','mater','mates','matted','muted','rated'},
'mater':	{'cater','eater','later','maker','master','mate','mated','mates','matter','mayer','meter','water'},
'material':	{'materials','materiel','maternal'},
'materialize':	{'materialized'},
'materialized':	{'materialize'},
'materials':	{'material'},
'materiel':	{'material'},
'maternal':	{'material','paternal'},
'maternity':	{'paternity'},
'mates':	{'dates','fates','gates','hates','makes','males','mares','mate','mated','mater','maths','mats','mites','oates','rates'},
'math':	{'bath','hath','mach','mash','mat','match','mate','maths','mats','matt','moth','myth','oath','path'},
'mathematician':	{'mathematicians'},
'mathematicians':	{'mathematician'},
'maths':	{'baths','mates','math','mats','moths','myths','oaths','paths'},
'mating':	{'dating','eating','hating','making','rating'},
'mats':	{'bats','cats','eats','fats','hats','lats','mans','maps','mars','mas','mass','mat','mate','mates','math','maths','matt','mays','meats','oats','rats'},
'matt':	{'gatt','malt','mart','mast','mat','mate','math','mats','matte','mitt','mott','mutt','watt'},
'matte':	{'latte','mate','matt','matted','matter'},
'matted':	{'mated','matte','matter'},
'matter':	{'batter','latter','master','mater','matte','matted','matters'},
'mattered':	{'battered','mastered','muttered'},
'mattering':	{'mastering'},
'matters':	{'batters','masters','matter'},
'maturation':	{'saturation'},
'mature':	{'manure','matured','matures','nature'},
'matured':	{'mature','matures','natured'},
'matures':	{'mature','matured','natures'},
'maui':	{'magi','mali','mari','maxi'},
'maven':	{'haven','raven'},
'mavis':	{'davis'},
'max':	{'ax','fax','lax','ma','mac','mad','mag','maj','mal','man','manx','mao','map','mar','marx','mas','mat','maxi','may','mix','sax','tax','wax'},
'maxi':	{'magi','mali','mari','maui','max','maxim','taxi'},
'maxim':	{'maxi'},
'maximisation':	{'maximization'},
'maximise':	{'maximised','maximises','maximize'},
'maximised':	{'maximise','maximises','maximized'},
'maximises':	{'maximise','maximised','maximizes'},
'maximising':	{'maximizing'},
'maximization':	{'maximisation'},
'maximize':	{'maximise','maximized','maximizes'},
'maximized':	{'maximised','maximize','maximizes'},
'maximizes':	{'maximises','maximize','maximized'},
'maximizing':	{'maximising'},
'may':	{'bay','cay','day','fay','gay','hay','jay','lay','ma','mac','mad','mag','maj','mal','man','many','mao','map','mar','mary','mas','mat','max','maya','mayo','mays','my','nay','pay','ray','say','way'},
'maya':	{'maia','mala','mama','mara','may','mayan','mayo','mays'},
'mayan':	{'maya'},
'mayer':	{'bayer','gayer','layer','maker','mater','mayor','payer'},
'mayo':	{'mano','mao','may','maya','mayor','mays'},
'mayor':	{'major','manor','mayer','mayo','mayors'},
'mayors':	{'majors','mayor'},
'mays':	{'bays','days','gays','hays','lays','mans','maps','mars','mas','mass','mats','may','maya','mayo','nays','pays','rays','says','ways'},
'maze':	{'amaze','daze','gaze','haze','mace','made','maize','make','male','mane','mare','mate'},
'mb':	{'ab','b','bb','db','eb','gb','kb','lb','ma','mba','mc','md','me','mg','mi','ml','mm','mn','mo','mob','mp','mr','ms','mt','mu','my','nb','ob','omb','pb','rb','sb','tb','yb'},
'mba':	{'aba','ba','ma','mb','mfa','sba'},
'mc':	{'ac','bc','c','cc','dc','ec','kc','ma','mac','mb','md','me','mg','mi','ml','mm','mn','mo','mp','mr','ms','mt','mu','my','nc','pc','sc','tc'},
'mcintosh':	{'macintosh'},
'md':	{'ad','cd','d','dd','dmd','ed','gd','id','ma','mad','mb','mc','me','med','mg','mi','mid','ml','mm','mn','mo','mod','mp','mr','ms','mt','mu','mud','my','nd','od','pd','sd','vd'},
'me':	{'be','ce','de','e','ee','fe','ge','he','ie','le','ma','mb','mc','md','med','meg','mei','men','mes','met','mew','mg','mi','ml','mm','mn','mo','mp','mr','ms','mt','mu','my','ne','pe','se','te','ve','we','xe','ye'},
'mead':	{'bead','dead','head','lead','mad','meade','meal','mean','meat','med','mend','read'},
'meade':	{'made','mead'},
'meadow':	{'meadows'},
'meadows':	{'meadow'},
'meager':	{'eager','meaner','merger'},
'meal':	{'deal','heal','mal','mead','meals','mean','meat','medal','metal','real','seal','teal','veal','zeal'},
'meals':	{'deals','heals','meal','means','meats','medals','metals','seals'},
'mean':	{'bean','dean','jean','kean','lean','man','mead','meal','means','meant','meat','men','moan'},
'meaner':	{'meager'},
'meaning':	{'leaning','meanings','moaning','weaning'},
'meanings':	{'meaning'},
'meanly':	{'manly'},
'means':	{'beans','deans','jeans','leans','mans','meals','mean','meant','meats','moans'},
'meant':	{'mean','means','meat'},
'measurable':	{'measurably'},
'measurably':	{'measurable'},
'measure':	{'measured','measures'},
'measured':	{'measure','measures'},
'measurement':	{'measurements'},
'measurements':	{'measurement'},
'measures':	{'measure','measured'},
'meat':	{'beat','eat','feat','heat','mat','mead','meal','mean','meant','meats','meet','melt','met','neat','peat','seat'},
'meats':	{'beats','eats','feats','heats','keats','mats','meals','means','meat','meets','melts','seats','yeats'},
'mechanic':	{'mechanics'},
'mechanics':	{'mechanic'},
'mechanism':	{'mechanisms'},
'mechanisms':	{'mechanism'},
'med':	{'bed','ed','fed','led','mad','md','me','mead','meg','mei','men','mend','mes','met','mew','mid','mod','mud','qed','red','ted','wed','zed'},
'medal':	{'meal','medals','medial','metal','modal','pedal'},
'medals':	{'meals','medal','metals','pedals'},
'media':	{'medial','median','medic','medina'},
'medial':	{'medal','media','median','medical'},
'median':	{'media','medial'},
'mediate':	{'mediated','mediates','meditate'},
'mediated':	{'mediate','mediates'},
'mediates':	{'mediate','mediated'},
'mediation':	{'medication','meditation'},
'mediator':	{'mediators'},
'mediators':	{'mediator'},
'medic':	{'media','medici'},
'medical':	{'medial'},
'medication':	{'dedication','mediation','medications','meditation'},
'medications':	{'medication','meditations'},
'medici':	{'medic'},
'medicine':	{'medicines'},
'medicines':	{'medicine'},
'medina':	{'media'},
'meditate':	{'mediate'},
'meditation':	{'mediation','medication','meditations'},
'meditations':	{'medications','meditation'},
'medium':	{'mediums'},
'mediums':	{'medium'},
'meek':	{'eek','geek','leek','meet','peek','seek','week'},
'meet':	{'beet','feet','meat','meek','meets','melt','met'},
'meeting':	{'meetings','melting'},
'meetings':	{'meeting'},
'meets':	{'meats','meet','melts'},
'meg':	{'beg','eeg','leg','mag','me','med','mega','megs','mei','men','mes','met','mew','mg','mpg','msg','mug','peg','veg'},
'mega':	{'meg','megs','mesa','meta','omega','vega'},
'megabyte':	{'megabytes'},
'megabytes':	{'megabyte'},
'megs':	{'begs','legs','meg','mega','mes','mess','mews','mugs','pegs','regs'},
'mei':	{'lei','me','med','meg','meir','men','mes','met','mew','mi','mri','pei','wei'},
'meir':	{'heir','mei','muir','weir'},
'mellon':	{'mellow','melon'},
'mellow':	{'fellow','mellon','yellow'},
'melon':	{'mellon','melons'},
'melons':	{'melon'},
'melt':	{'belt','felt','malt','meat','meet','melts','met','milt','smelt','welt'},
'melted':	{'belted'},
'melting':	{'belting','meeting'},
'melts':	{'belts','meats','meets','melt'},
'member':	{'ember','members'},
'members':	{'member'},
'membership':	{'memberships'},
'memberships':	{'membership'},
'membrane':	{'membranes'},
'membranes':	{'membrane'},
'meme':	{'memes','memo','mere','mime'},
'memes':	{'meme','memos'},
'memo':	{'demo','emo','meme','memos'},
'memoir':	{'memoirs'},
'memoirs':	{'memoir'},
'memorial':	{'memorials'},
'memorials':	{'memorial'},
'memories':	{'memorises','memorizes'},
'memorise':	{'memorised','memorises','memorize'},
'memorised':	{'memorise','memorises','memorized'},
'memorises':	{'memories','memorise','memorised','memorizes'},
'memorising':	{'memorizing'},
'memorize':	{'memorise','memorized','memorizes'},
'memorized':	{'memorised','memorize','memorizes'},
'memorizes':	{'memories','memorises','memorize','memorized'},
'memorizing':	{'memorising'},
'memos':	{'demos','memes','memo'},
'men':	{'amen','ben','den','en','fen','gen','hen','ken','man','me','mean','med','meg','mei','mend','menu','mes','met','mew','min','mn','mon','omen','pen','sen','ten','wen','yen','zen'},
'mend':	{'amend','bend','end','fend','lend','mead','med','men','mends','menu','mind','send','tend'},
'mended':	{'amended','ended','mendel','minded','tended'},
'mendel':	{'mended'},
'mending':	{'amending','bending','ending','lending','minding','pending','sending','tending','vending'},
'mends':	{'amends','bends','ends','lends','mend','menus','minds','sends','tends'},
'mental':	{'dental','metal','rental'},
'mention':	{'mentions'},
'mentions':	{'mention'},
'mentor':	{'mentors'},
'mentors':	{'mentor'},
'menu':	{'men','mend','menus'},
'menus':	{'genus','mends','menu','minus','venus'},
'meow':	{'mew'},
'mercer':	{'merger'},
'merchant':	{'merchants'},
'merchants':	{'merchant'},
'mercy':	{'merry','percy'},
'mere':	{'ere','here','mare','meme','merge','merle','metre','more','were'},
'merge':	{'emerge','marge','mere','merged','merger','merges','merle','serge','verge'},
'merged':	{'emerged','merge','merger','merges'},
'merger':	{'meager','mercer','merge','merged','mergers','merges'},
'mergers':	{'merger','merges'},
'merges':	{'emerges','merge','merged','merger','mergers'},
'merging':	{'emerging'},
'merit':	{'merits'},
'merits':	{'merit'},
'merle':	{'mere','merge'},
'merlin':	{'berlin','marlin'},
'merrier':	{'terrier'},
'merry':	{'berry','ferry','jerry','marry','mercy','perry','terry'},
'merton':	{'morton'},
'mes':	{'des','es','les','mas','me','med','meg','megs','mei','men','mesa','mesh','mess','met','mew','mews','mrs','ms','mus','res','yes'},
'mesa':	{'mega','mes','mesh','mess','meta'},
'mesh':	{'mash','mes','mesa','mess'},
'mess':	{'hess','less','mass','megs','mes','mesa','mesh','messy','mews','miss','moss','muss'},
'message':	{'massage','messages'},
'messages':	{'massages','message'},
'messed':	{'missed'},
'messenger':	{'messengers'},
'messengers':	{'messenger'},
'messing':	{'missing'},
'messy':	{'mess','missy'},
'met':	{'bet','et','get','jet','let','mat','me','meat','med','meet','meg','mei','melt','men','mes','meta','mew','mit','mot','mst','mt','net','pet','set','tet','vet','wet','yet'},
'meta':	{'beta','eta','mega','mesa','met','metal','zeta'},
'metabolite':	{'metabolites'},
'metabolites':	{'metabolite'},
'metal':	{'fetal','meal','medal','mental','meta','metals','petal'},
'metals':	{'meals','medals','metal','petals'},
'metaphor':	{'metaphors'},
'metaphors':	{'metaphor'},
'metastases':	{'metastasis'},
'metastasis':	{'metastases'},
'meteor':	{'meter'},
'meter':	{'deter','mater','meteor','meters','peter'},
'meters':	{'meter'},
'methanol':	{'ethanol'},
'method':	{'methods'},
'methods':	{'method'},
'methyl':	{'ethyl'},
'metre':	{'mere','metres','metro','mitre'},
'metres':	{'metre','metros'},
'metric':	{'metrics'},
'metrics':	{'metric'},
'metro':	{'metre','metros','retro'},
'metros':	{'metres','metro'},
'mew':	{'dew','few','jew','me','med','meg','mei','men','meow','mes','met','mews','new','pew','sew','yew'},
'mews':	{'megs','mes','mess','mew','news','sews'},
'mfa':	{'fa','ma','mba'},
'mg':	{'ag','g','hg','kg','ma','mag','mb','mc','md','me','meg','mi','ml','mm','mn','mo','mp','mpg','mr','ms','msg','mt','mu','mug','my'},
'mhz':	{'hz','khz'},
'mi':	{'ai','bi','ci','di','gi','hi','i','ii','ji','ki','li','ma','mb','mc','md','me','mei','mg','mid','mil','min','mit','mix','ml','mm','mn','mo','mp','mr','mri','ms','mt','mu','my','ni','pi','qi','ri','si','ti','vi','wi','xi','yi'},
'mica':	{'micah','mice','mick','mics','mina','rica'},
'micah':	{'mica'},
'mice':	{'dice','ice','lice','mace','mica','mick','mics','mike','mile','mime','mine','mite','nice','rice','vice'},
'mick':	{'dick','kick','lick','mack','mica','mice','mics','milk','mink','mock','muck','nick','pick','rick','sick','tick','wick'},
'mickey':	{'dickey','hickey'},
'micro':	{'macro','micron','miro'},
'microeconomics':	{'macroeconomics'},
'micron':	{'micro','microns'},
'microns':	{'micron'},
'microphone':	{'microphones'},
'microphones':	{'microphone'},
'microprocessor':	{'microprocessors'},
'microprocessors':	{'microprocessor'},
'microscope':	{'microscopes','microscopy'},
'microscopes':	{'microscope'},
'microscopic':	{'macroscopic'},
'microscopy':	{'microscope'},
'microwave':	{'microwaves'},
'microwaves':	{'microwave'},
'mics':	{'mica','mice','mick','mips','miss','pics','tics'},
'mid':	{'aid','amid','bid','cid','did','hid','id','kid','lid','mad','maid','md','med','mi','midi','mil','mild','min','mind','mit','mix','mod','mud','rid'},
'midday':	{'midway'},
'middle':	{'fiddle','riddle'},
'midget':	{'midgets','widget'},
'midgets':	{'midget','widgets'},
'midi':	{'mid','mini'},
'midst':	{'amidst','mist'},
'midway':	{'midday'},
'might':	{'eight','fight','light','mightn','mighty','night','right','sight','tight','wight'},
'mightn':	{'might','mighty'},
'mighty':	{'eighty','might','mightn'},
'migraine':	{'migraines'},
'migraines':	{'migraine'},
'migrant':	{'migrants'},
'migrants':	{'migrant'},
'migrate':	{'migrated','migrates'},
'migrated':	{'emigrated','migrate','migrates'},
'migrates':	{'migrate','migrated'},
'migration':	{'emigration','migrations'},
'migrations':	{'migration'},
'mike':	{'bike','hike','ike','like','make','mice','mikes','mile','mime','mine','mite','nike','pike'},
'mikes':	{'bikes','dikes','hikes','likes','makes','mike','miles','mines','mites','mixes','pikes'},
'mil':	{'il','mail','mal','mi','mid','mild','mile','milk','mill','milo','milt','min','mit','mix','ml','nil','oil','til'},
'mild':	{'mid','mil','mile','milk','mill','milo','milt','mind','mold','wild'},
'milder':	{'mildew','miller','wilder'},
'mildest':	{'wildest'},
'mildew':	{'milder'},
'mildly':	{'wildly'},
'mildness':	{'wildness'},
'mile':	{'bile','emile','file','male','mice','mike','mil','mild','miles','milk','mill','milne','milo','milt','mime','mine','mite','mole','mule','nile','pile','smile','tile','vile'},
'miles':	{'files','males','mikes','mile','milks','mills','mines','mites','mixes','moles','mules','piles','smiles','tiles'},
'milestone':	{'milestones'},
'milestones':	{'milestone'},
'militant':	{'militants'},
'militants':	{'militant'},
'militia':	{'militias'},
'militias':	{'militia'},
'milk':	{'ilk','mick','mil','mild','mile','milks','milky','mill','milo','milt','mink','silk'},
'milked':	{'milled'},
'milking':	{'milling'},
'milks':	{'miles','milk','milky','mills','silks'},
'milky':	{'milk','milks','silky'},
'mill':	{'bill','dill','fill','gill','hill','ill','kill','mall','mil','mild','mile','milk','mills','milo','milt','moll','mull','pill','sill','till','will'},
'milled':	{'billed','filled','killed','milked','miller','millet','misled','willed'},
'miller':	{'filler','killer','milder','milled','millet','muller'},
'millet':	{'billet','fillet','mallet','milled','miller','mullet'},
'milligram':	{'milligrams'},
'milligrams':	{'milligram'},
'millilitre':	{'millilitres'},
'millilitres':	{'millilitre'},
'millimeter':	{'millimeters'},
'millimeters':	{'millimeter'},
'millimetre':	{'millimetres'},
'millimetres':	{'millimetre'},
'milling':	{'billing','filling','killing','milking','willing'},
'million':	{'billion','millions','zillion'},
'millionaire':	{'billionaire','millionaires'},
'millionaires':	{'millionaire'},
'millions':	{'billions','million'},
'mills':	{'bills','fills','hills','ills','kills','malls','miles','milks','mill','pills','wills'},
'milne':	{'mile','mine'},
'milo':	{'kilo','lilo','mil','mild','mile','milk','mill','milt','miro','silo'},
'milt':	{'gilt','kilt','malt','melt','mil','mild','mile','milk','mill','milo','mint','mist','mit','mitt','silt','tilt','wilt'},
'milton':	{'wilton'},
'mime':	{'dime','lime','meme','mice','mike','mile','mine','mite','time'},
'mimic':	{'mimics'},
'mimics':	{'mimic'},
'min':	{'bin','din','fin','gin','in','kin','lin','main','man','men','mi','mid','mil','mina','mind','mine','ming','mini','mink','mint','mit','mix','mn','mon','pin','qin','sin','tin','win','yin'},
'mina':	{'mica','min','mind','mine','ming','mini','mink','mint','mona','nina'},
'minced':	{'minded','mined'},
'mind':	{'bind','find','hind','kind','lind','mend','mid','mild','min','mina','minds','mine','mined','ming','mini','mink','mint','wind'},
'minded':	{'mended','minced','mined','winded'},
'minding':	{'binding','finding','mending','mining','winding'},
'minds':	{'binds','finds','kinds','mends','mind','mines','minis','mints','minus','winds'},
'mine':	{'amine','cine','dine','fine','line','maine','mane','mice','mike','mile','milne','mime','min','mina','mind','mined','miner','mines','ming','mini','mink','mint','mite','nine','pine','sine','vine','wine','zine'},
'mined':	{'dined','fined','lined','minced','mind','minded','mine','miner','mines','mixed','wined'},
'miner':	{'diner','finer','liner','mine','mined','miners','mines','minor','mixer'},
'mineral':	{'minerals'},
'minerals':	{'mineral'},
'miners':	{'diners','liners','miner','mines','minors','mixers'},
'mines':	{'dines','fines','lines','mikes','miles','minds','mine','mined','miner','miners','minis','mints','minus','mites','mixes','nines','pines','vines','wines','zines'},
'ming':	{'ding','king','ling','min','mina','mind','mine','mini','mink','mint','ning','ping','qing','ring','sing','ting','wing','ying'},
'mingle':	{'jingle','mingled','single'},
'mingled':	{'mangled','mingle','singled'},
'mini':	{'midi','min','mina','mind','mine','ming','minis','mink','mint'},
'miniature':	{'miniatures'},
'miniatures':	{'miniature'},
'minimalisation':	{'minimalization'},
'minimalise':	{'minimalised','minimalises','minimalist','minimalize'},
'minimalised':	{'minimalise','minimalises','minimalized'},
'minimalises':	{'minimalise','minimalised','minimalists','minimalizes'},
'minimalising':	{'minimalizing'},
'minimalist':	{'minimalise','minimalists'},
'minimalists':	{'minimalises','minimalist'},
'minimalization':	{'minimalisation'},
'minimalize':	{'minimalise','minimalized','minimalizes'},
'minimalized':	{'minimalised','minimalize','minimalizes'},
'minimalizes':	{'minimalises','minimalize','minimalized'},
'minimalizing':	{'minimalising'},
'minimise':	{'minimised','minimises','minimize'},
'minimised':	{'minimise','minimises','minimized'},
'minimises':	{'minimise','minimised','minimizes'},
'minimising':	{'minimizing'},
'minimize':	{'minimise','minimized','minimizes'},
'minimized':	{'minimised','minimize','minimizes'},
'minimizes':	{'minimises','minimize','minimized'},
'minimizing':	{'minimising'},
'minimum':	{'minimums'},
'minimums':	{'minimum'},
'mining':	{'dining','lining','minding','mixing','wining'},
'minis':	{'minds','mines','mini','mints','minus'},
'minister':	{'ministers','minster','sinister'},
'ministers':	{'minister'},
'mink':	{'fink','ink','link','mick','milk','min','mina','mind','mine','ming','mini','minsk','mint','monk','pink','rink','sink','wink'},
'minor':	{'manor','miner','minors'},
'minors':	{'miners','minor'},
'minsk':	{'mink'},
'minster':	{'minister','mister','monster'},
'mint':	{'hint','int','lint','milt','min','mina','mind','mine','ming','mini','mink','mints','mist','mit','mitt','pint','tint'},
'mints':	{'hints','minds','mines','minis','mint','minus','mitts','pints'},
'minus':	{'menus','minds','mines','minis','mints','sinus'},
'minute':	{'minutes'},
'minutes':	{'minute'},
'mips':	{'dips','hips','lips','maps','mics','miss','rips','sips','tips','zips'},
'miracle':	{'miracles'},
'miracles':	{'miracle'},
'miro':	{'giro','micro','milo','moro'},
'mirror':	{'mirrors'},
'mirrors':	{'mirror'},
'misconception':	{'misconceptions'},
'misconceptions':	{'misconception'},
'miserable':	{'miserably'},
'miserably':	{'miserable'},
'misinterpret':	{'misinterprets'},
'misinterpretation':	{'misinterpretations'},
'misinterpretations':	{'misinterpretation'},
'misinterprets':	{'misinterpret'},
'mislead':	{'misled'},
'misled':	{'milled','mislead','missed'},
'misplace':	{'displace','misplaced'},
'misplaced':	{'displaced','misplace'},
'miss':	{'kiss','mass','mess','mics','mips','missy','mist','moss','muss','piss'},
'missed':	{'kissed','messed','misled','misses','misused','pissed'},
'misses':	{'kisses','masses','missed'},
'missile':	{'missiles'},
'missiles':	{'missile'},
'missing':	{'kissing','messing','pissing'},
'mission':	{'emission','fission','missions','omission'},
'missions':	{'emissions','mission','omissions'},
'missy':	{'messy','miss','misty','sissy'},
'mist':	{'fist','gist','hist','list','mast','midst','milt','mint','miss','misty','mit','mitt','moist','most','mst','must'},
'mistake':	{'mistaken','mistakes'},
'mistaken':	{'mistake','mistakes'},
'mistakes':	{'mistake','mistaken'},
'mister':	{'lister','master','minster','muster','sister'},
'mistress':	{'distress'},
'mistrust':	{'distrust'},
'misty':	{'missy','mist'},
'misunderstanding':	{'misunderstandings'},
'misunderstandings':	{'misunderstanding'},
'misuse':	{'misused'},
'misused':	{'missed','misuse'},
'mit':	{'bit','emit','fit','git','hit','it','kit','lit','mat','met','mi','mid','mil','milt','min','mint','mist','mite','mitt','mix','mot','mst','mt','nit','omit','pit','sit','tit','wit'},
'mite':	{'bite','cite','kite','lite','mate','mice','mike','mile','mime','mine','mit','mites','mitre','mitt','mute','rite','site'},
'mites':	{'bites','cites','kites','mates','mikes','miles','mines','mite','mitts','mixes','rites','sites'},
'mitigate':	{'mitigated'},
'mitigated':	{'mitigate'},
'mitigation':	{'litigation'},
'mitochondria':	{'mitochondrial'},
'mitochondrial':	{'mitochondria'},
'mitre':	{'litre','metre','mite','titre'},
'mitt':	{'matt','milt','mint','mist','mit','mite','mitts','mott','mutt','pitt'},
'mittens':	{'kittens'},
'mitts':	{'mints','mites','mitt'},
'mix':	{'dix','fix','ix','max','mi','mid','mil','min','mit','nix','pix','six','xix'},
'mixed':	{'fixed','mined','mixer','mixes'},
'mixer':	{'miner','mixed','mixers','mixes'},
'mixers':	{'miners','mixer','mixes'},
'mixes':	{'fixes','mikes','miles','mines','mites','mixed','mixer','mixers','sixes'},
'mixing':	{'fixing','mining'},
'mixture':	{'fixture','mixtures'},
'mixtures':	{'fixtures','mixture'},
'ml':	{'al','bl','cl','el','fl','il','l','ll','ma','mal','mb','mc','md','me','mg','mi','mil','mm','mn','mo','mp','mr','ms','mt','mu','my','tl','xl'},
'mm':	{'am','bm','cm','em','fm','gm','hm','km','ma','mb','mc','md','me','mg','mi','ml','mn','mo','mom','mp','mr','ms','mt','mu','mum','my','nm','pm','rm','sm','tm','um','wm'},
'mn':	{'an','en','in','ma','man','mb','mc','md','me','men','mg','mi','min','ml','mm','mo','mon','mp','mr','ms','mt','mu','my','on','rn','sn','tn','un','zn'},
'mo':	{'co','do','emo','fo','go','hmo','ho','imo','io','ko','lo','ma','mao','mb','mc','md','me','mg','mi','ml','mm','mn','mob','mod','mom','mon','moo','mop','mot','mp','mr','ms','mt','mu','my','no','o','po','so','to','wo'},
'moan':	{'loan','man','mean','moans','mon','moon','morn'},
'moaned':	{'loaned'},
'moaning':	{'meaning','morning'},
'moans':	{'loans','mans','means','moan','moons'},
'mob':	{'bob','cob','fob','hob','job','lob','mb','mo','mobs','mod','mom','mon','moo','mop','mot','nob','ob','rob','sob'},
'mobile':	{'mobiles'},
'mobiles':	{'mobile'},
'mobility':	{'motility','nobility'},
'mobilize':	{'mobilized'},
'mobilized':	{'mobilize'},
'mobs':	{'bobs','jobs','mob','mods','moms','moss','robs'},
'mock':	{'bock','cock','dock','jock','lock','mack','mick','monk','muck','rock','sock'},
'mocked':	{'docked','locked','rocked'},
'mocking':	{'docking','locking','rocking'},
'mod':	{'bod','cod','dod','god','mad','md','med','mid','mo','mob','moda','mode','mods','mold','mom','mon','moo','mood','mop','mot','mud','nod','od','pod','rod','sod','tod'},
'moda':	{'coda','mod','modal','mode','mods','mona','soda'},
'modal':	{'medal','moda','model','moral'},
'modality':	{'morality'},
'mode':	{'bode','code','made','mod','moda','model','modem','modes','mods','mole','more','move','node','ode','rode'},
'model':	{'modal','mode','models','modem','modes','morel','motel'},
'modeled':	{'modeler','modelled'},
'modeler':	{'modeled'},
'modeling':	{'modelling'},
'modelled':	{'modeled'},
'modelling':	{'modeling'},
'models':	{'model','modems','modes','motels'},
'modem':	{'mode','model','modems','modes'},
'modems':	{'models','modem','modes'},
'moderate':	{'moderated','moderates'},
'moderated':	{'moderate','moderates'},
'moderates':	{'moderate','moderated'},
'moderator':	{'moderators'},
'moderators':	{'moderator'},
'modernisation':	{'modernization'},
'modernise':	{'modernism','modernist','modernize'},
'modernism':	{'modernise','modernist'},
'modernist':	{'modernise','modernism'},
'modernization':	{'modernisation'},
'modernize':	{'modernise','modernized'},
'modernized':	{'modernize'},
'modes':	{'codes','mode','model','models','modem','modems','modest','mods','moles','moses','moves','nodes'},
'modest':	{'modes','modesty'},
'modestly':	{'modesty'},
'modesty':	{'modest','modestly'},
'modification':	{'modifications'},
'modifications':	{'modification'},
'modified':	{'codified','modifier','modifies'},
'modifier':	{'modified','modifiers','modifies'},
'modifiers':	{'modifier','modifies'},
'modifies':	{'modified','modifier','modifiers'},
'mods':	{'gods','mobs','mod','moda','mode','modes','molds','moms','moods','moss','nods','pods','rods'},
'modulate':	{'modulated'},
'modulated':	{'modulate'},
'module':	{'modules','modulo'},
'modules':	{'module','modulus','nodules'},
'modulo':	{'module'},
'modulus':	{'modules'},
'mogul':	{'mosul'},
'mohammad':	{'muhammad'},
'moist':	{'hoist','mist','most'},
'molar':	{'molnar','mylar','polar','solar'},
'mold':	{'bold','cold','fold','gold','hold','mild','mod','molds','mole','moll','mood','mould','old','sold','told'},
'molded':	{'folded','moulded'},
'molding':	{'folding','golding','holding','moulding'},
'moldova':	{'moldovan'},
'moldovan':	{'moldova'},
'molds':	{'colds','folds','holds','mods','mold','moles','moods'},
'mole':	{'cole','dole','hole','male','mile','mode','mold','moles','moll','more','move','mule','ole','pole','role','sole'},
'molecule':	{'molecules'},
'molecules':	{'molecule'},
'moles':	{'holes','males','miles','modes','molds','mole','moses','moves','mules','poles','roles','soles'},
'moll':	{'boll','doll','mall','mill','mold','mole','molly','mull','poll','roll','toll'},
'mollie':	{'collie'},
'molly':	{'dolly','folly','holly','jolly','moll'},
'molnar':	{'molar'},
'mom':	{'com','mm','mo','mob','mod','moms','mon','moo','mop','mot','mum','pom','rom','tom'},
'moment':	{'moments'},
'moments':	{'moment'},
'momma':	{'comma','mommy'},
'mommy':	{'momma','mummy'},
'moms':	{'mobs','mods','mom','moss','mums'},
'mon':	{'con','don','hon','ion','man','men','min','mn','mo','moan','mob','mod','mom','mona','monk','mono','moo','moon','mop','morn','mot','non','on','ron','son','ton','von','won','yon'},
'mona':	{'dona','mina','moda','mon','monk','mono'},
'monarch':	{'monarchs','monarchy'},
'monarchs':	{'monarch','monarchy'},
'monarchy':	{'monarch','monarchs'},
'monday':	{'mondays'},
'mondays':	{'monday'},
'monet':	{'money'},
'money':	{'honey','monet','moneys','monkey'},
'moneys':	{'money','monkeys'},
'mongolia':	{'mongolian'},
'mongolian':	{'mongolia'},
'monies':	{'movies','ponies'},
'monitor':	{'monitors'},
'monitors':	{'monitor'},
'monk':	{'mink','mock','mon','mona','monks','mono'},
'monkey':	{'donkey','money','monkeys'},
'monkeys':	{'donkeys','moneys','monkey'},
'monks':	{'monk'},
'mono':	{'mano','mon','mona','monk','moo','moro','ono'},
'monograph':	{'monographs'},
'monographs':	{'monograph'},
'monster':	{'minster','monsters'},
'monsters':	{'monster'},
'monte':	{'month'},
'month':	{'monte','months','moth','mouth'},
'months':	{'month','moths','mouths'},
'monument':	{'monuments'},
'monuments':	{'monument'},
'moo':	{'boo','coo','goo','loo','mao','mo','mob','mod','mom','mon','mono','mood','moon','moor','moot','mop','moro','mot','poo','too','woo','zoo'},
'mood':	{'food','good','hood','mod','mold','moo','moods','moody','moon','moor','moot','wood'},
'moods':	{'foods','goods','hoods','mods','molds','mood','moody','moons','moors','woods'},
'moody':	{'goody','mood','moods','woody'},
'moon':	{'boon','coon','loon','moan','mon','moo','mood','moons','moor','moot','morn','moron','noon','soon'},
'moons':	{'moans','moods','moon','moors','morons'},
'moor':	{'door','moo','mood','moon','moore','moors','moot','motor','poor'},
'moore':	{'moor','moors','moose','more'},
'mooring':	{'motoring'},
'moors':	{'doors','moods','moons','moor','moore','motors'},
'moose':	{'goose','loose','moore','morse','mouse'},
'moot':	{'boot','foot','hoot','loot','moo','mood','moon','moor','most','mot','mott','root','soot'},
'mop':	{'bop','cop','gop','hop','map','mo','mob','mod','mom','mon','moo','mot','mp','mvp','op','pop','sop','top','wop'},
'moral':	{'coral','modal','morale','morals','moray','morel','mortal','mural','oral'},
'morale':	{'moral','morals'},
'morality':	{'modality','mortality'},
'morally':	{'orally'},
'morals':	{'corals','moral','morale','mortals','murals'},
'moray':	{'foray','moral'},
'morbid':	{'forbid'},
'more':	{'bore','core','fore','gore','lore','mare','mere','mode','mole','moore','morel','morn','moro','morse','move','ore','pore','sore','tore','wore'},
'morel':	{'model','moral','more','motel'},
'morgan':	{'organ'},
'morley':	{'marley','motley'},
'mormon':	{'mormons','moron','morton'},
'mormons':	{'mormon','morons'},
'morn':	{'born','corn','horn','moan','mon','moon','more','moro','moron','mourn','porn','torn','worn'},
'morning':	{'moaning','mornings','mourning'},
'mornings':	{'morning'},
'moro':	{'miro','mono','moo','more','morn','moron'},
'moron':	{'boron','moon','mormon','morn','moro','morons','morton'},
'morons':	{'moons','mormons','moron'},
'morpheus':	{'orpheus'},
'morris':	{'norris'},
'morrow':	{'borrow','marrow','sorrow'},
'morse':	{'horse','moose','more','mouse','norse','worse'},
'mortal':	{'moral','mortals','mortar','portal'},
'mortality':	{'morality'},
'mortals':	{'morals','mortal','portals'},
'mortar':	{'mortal'},
'mortgage':	{'mortgages'},
'mortgages':	{'mortgage'},
'morton':	{'merton','mormon','moron'},
'mosaic':	{'mosaics'},
'mosaics':	{'mosaic'},
'moses':	{'doses','hoses','loses','modes','moles','moss','moves','noses','poses','roses'},
'mosque':	{'masque','mosques'},
'mosques':	{'mosque'},
'moss':	{'boss','loss','mass','mess','miss','mobs','mods','moms','moses','most','muss','ross','toss'},
'most':	{'cost','host','lost','mast','mist','moist','moot','moss','mot','mott','mst','must','post'},
'mostly':	{'costly'},
'mosul':	{'mogul'},
'mot':	{'bot','cot','dot','got','hot','lot','mat','met','mit','mo','mob','mod','mom','mon','moo','moot','mop','most','moth','mott','mst','mt','not','pot','rot','sot','tot','wot'},
'motel':	{'hotel','model','morel','motels'},
'motels':	{'hotels','models','motel'},
'moth':	{'both','doth','goth','math','month','mot','moths','mott','mouth','myth','roth'},
'mother':	{'bother','mothers','other','smother'},
'motherboard':	{'motherboards'},
'motherboards':	{'motherboard'},
'mothers':	{'bothers','mother','others'},
'moths':	{'maths','months','moth','mouths','myths'},
'motif':	{'motifs'},
'motifs':	{'motif'},
'motility':	{'mobility'},
'motion':	{'emotion','lotion','motions','notion','potion'},
'motions':	{'emotions','lotions','motion','notions','potions'},
'motivate':	{'motivated','motivates'},
'motivated':	{'motivate','motivates'},
'motivates':	{'motivate','motivated'},
'motivation':	{'motivations'},
'motivations':	{'motivation'},
'motive':	{'motives','votive'},
'motives':	{'motive'},
'motley':	{'morley'},
'motor':	{'moor','motors','rotor'},
'motorbike':	{'motorbikes'},
'motorbikes':	{'motorbike'},
'motorcycle':	{'motorcycles'},
'motorcycles':	{'motorcycle'},
'motoring':	{'mooring'},
'motorist':	{'motorists'},
'motorists':	{'motorist'},
'motors':	{'moors','motor','rotors'},
'mott':	{'matt','mitt','moot','most','mot','moth','motto','mutt'},
'motto':	{'lotto','mott'},
'mould':	{'could','gould','mold','mound','would'},
'moulded':	{'molded'},
'moulding':	{'molding'},
'mound':	{'bound','found','hound','mould','mounds','mount','pound','round','sound','wound'},
'mounds':	{'bounds','hounds','mound','mounts','pounds','rounds','sounds','wounds'},
'mount':	{'amount','count','mound','mounts'},
'mountable':	{'countable'},
'mountain':	{'fountain','mountains'},
'mountains':	{'fountains','mountain'},
'mounted':	{'amounted','counted'},
'mounting':	{'amounting','counting'},
'mounts':	{'amounts','counts','mounds','mount'},
'mourn':	{'morn'},
'mourning':	{'morning'},
'mouse':	{'house','moose','morse','mouser','mousse','muse','rouse'},
'mouser':	{'mouse'},
'mousse':	{'mouse'},
'mouth':	{'month','moth','mouths','south','youth'},
'mouthful':	{'youthful'},
'mouths':	{'months','moths','mouth','youths'},
'movable':	{'lovable'},
'move':	{'cove','dove','love','mode','mole','more','moved','mover','moves','movie','rove','wove'},
'moved':	{'loved','move','mover','moves'},
'movement':	{'movements'},
'movements':	{'movement'},
'mover':	{'cover','dover','hover','lover','move','moved','movers','moves','mower','over','rover'},
'movers':	{'covers','lovers','mover','moves','mowers','overs','rovers'},
'moves':	{'doves','loves','modes','moles','moses','move','moved','mover','movers','movies'},
'movie':	{'move','movies'},
'movies':	{'monies','moves','movie'},
'moving':	{'loving','mowing','roving'},
'mower':	{'bower','lower','mover','mowers','power','tower'},
'mowers':	{'lowers','movers','mower','powers','towers'},
'mowing':	{'bowing','lowing','moving','owing','rowing','sowing','towing'},
'mp':	{'amp','dp','gp','hp','imp','ip','kp','lp','ma','map','mb','mc','md','me','mg','mi','ml','mm','mn','mo','mop','mpg','mph','mr','ms','mt','mu','mvp','my','np','op','p','up'},
'mpg':	{'mag','meg','mg','mp','mph','msg','mug'},
'mph':	{'kph','mp','mpg','ph'},
'mr':	{'ar','br','cr','dr','er','fr','hr','ir','jr','kr','lr','ma','mar','mb','mc','md','me','mg','mi','ml','mm','mn','mo','mp','mri','mrs','ms','mt','mu','my','or','pr','qr','r','sr','ur','yr','zr'},
'mri':	{'fri','mari','mei','mi','mr','mrs','ri'},
'mrs':	{'irs','mars','mas','mes','mr','mri','ms','mus'},
'ms':	{'as','bs','cs','es','hs','is','ks','ma','mas','mb','mc','md','me','mes','mg','mi','ml','mm','mn','mo','mp','mr','mrs','msg','mst','mt','mu','mus','my','os','pms','ps','ss','ts','us','vs'},
'msg':	{'mag','meg','mg','mpg','ms','mst','mug'},
'mst':	{'cst','est','mast','mat','met','mist','mit','most','mot','ms','msg','mt','must','pst'},
'mt':	{'at','ct','et','ft','gmt','ht','it','kt','ma','mat','mb','mc','md','me','met','mg','mi','mit','ml','mm','mn','mo','mot','mp','mr','ms','mst','mu','my','nt','pt','t','ut','vt'},
'mu':	{'au','cu','du','emu','eu','gu','ju','lu','ma','mb','mc','md','me','mg','mi','ml','mm','mn','mo','mp','mr','ms','mt','mud','mug','mum','mus','my','nu','pu','ru','su','u','wu','zu'},
'much':	{'mach','muck','mulch','munch','such'},
'muck':	{'buck','duck','fuck','huck','luck','mack','mick','mock','much','musk','puck','suck','tuck'},
'mucous':	{'mucus'},
'mucus':	{'mucous'},
'mud':	{'bud','hud','mad','md','med','mid','mod','mu','mug','mum','mus','pud'},
'muddy':	{'buddy'},
'muffin':	{'muffins','puffin'},
'muffins':	{'muffin'},
'muffled':	{'muffler','ruffled'},
'muffler':	{'muffled','mufflers'},
'mufflers':	{'muffler'},
'mug':	{'aug','bug','dug','hug','jug','lug','mag','meg','mg','mpg','msg','mu','mud','mugs','mum','mus','pug','rug','smug','tug'},
'mugs':	{'bugs','hugs','jugs','megs','mug','mums','mus','muss','rugs'},
'muhammad':	{'mohammad'},
'muir':	{'meir'},
'mulch':	{'gulch','much','munch'},
'mule':	{'male','mile','mole','mules','mull','muse','mute','rule','yule'},
'mules':	{'males','miles','moles','mule','rules'},
'mull':	{'bull','dull','full','gull','hull','mall','mill','moll','mule','null','pull'},
'muller':	{'duller','fuller','miller','mullet'},
'mullet':	{'bullet','mallet','millet','muller'},
'multinational':	{'multinationals'},
'multinationals':	{'multinational'},
'multiple':	{'multiples','multiplex','multiply'},
'multiples':	{'multiple','multiplex','multiplies'},
'multiplex':	{'multiple','multiples'},
'multiplied':	{'multiplier','multiplies'},
'multiplier':	{'multiplied','multipliers','multiplies'},
'multipliers':	{'multiplier','multiplies'},
'multiplies':	{'multiples','multiplied','multiplier','multipliers'},
'multiply':	{'multiple'},
'mum':	{'bum','cum','gum','hum','mm','mom','mu','mud','mug','mums','mus','rum','sum','um','yum'},
'mummy':	{'dummy','mommy','tummy','yummy'},
'mums':	{'gums','moms','mugs','mum','mus','muss','sums'},
'munch':	{'bunch','lunch','much','mulch','munich','punch'},
'munich':	{'munch'},
'mural':	{'aural','moral','murals','rural'},
'murals':	{'morals','mural'},
'murder':	{'murders'},
'murdered':	{'murderer'},
'murderer':	{'murdered','murderers'},
'murderers':	{'murderer'},
'murders':	{'murder'},
'murine':	{'marine','urine'},
'mus':	{'bus','mas','mes','mrs','ms','mu','mud','mug','mugs','mum','mums','muse','musk','muss','must','pus','us'},
'muscle':	{'muscles'},
'muscles':	{'muscle'},
'muse':	{'amuse','fuse','mouse','mule','mus','musk','muss','must','mute','use'},
'museum':	{'museums'},
'museums':	{'museum'},
'mushroom':	{'mushrooms'},
'mushrooms':	{'mushroom'},
'musical':	{'musicals'},
'musicals':	{'musical'},
'musician':	{'musicians'},
'musicians':	{'musician'},
'musk':	{'dusk','mask','muck','mus','muse','muss','must','rusk'},
'muss':	{'fuss','mass','mess','miss','moss','mugs','mums','mus','muse','musk','must'},
'must':	{'bust','dust','gust','just','lust','mast','mist','most','mst','mus','muse','musk','muss','mutt','rust'},
'mustard':	{'custard'},
'muster':	{'buster','custer','duster','luster','master','mister'},
'mutant':	{'mutants'},
'mutants':	{'mutant'},
'mutation':	{'mutations'},
'mutations':	{'mutation'},
'mute':	{'cute','jute','mate','mite','mule','muse','muted','mutt','ute'},
'muted':	{'mated','mute'},
'mutt':	{'butt','matt','mitt','mott','must','mute','putt'},
'muttered':	{'buttered','mattered','uttered'},
'muzzle':	{'puzzle'},
'mvp':	{'map','mop','mp'},
'my':	{'by','dy','ky','ly','ma','may','mb','mc','md','me','mg','mi','ml','mm','mn','mo','mp','mr','ms','mt','mu','ny','wy','y'},
'mylar':	{'molar'},
'mystery':	{'mastery'},
'mystic':	{'cystic'},
'myth':	{'math','moth','myths'},
'myths':	{'maths','moths','myth'},
'na':	{'a','ana','ba','ca','da','dna','ea','fa','ga','ha','ia','ka','la','ma','nab','nae','nag','nan','nap','nay','nb','nc','nd','ne','nh','ni','nj','nm','no','np','nra','nt','nu','nv','nw','ny','pa','ra','rna','sa','ta','una','va','wa','ya','za'},
'nab':	{'ab','cab','dab','fab','gab','jab','lab','na','nae','nag','nan','nap','nay','nb','nib','nob','tab'},
'nada':	{'ada','dada','nara','nasa'},
'nae':	{'na','nab','nag','name','nan','nap','nay','ne','nee'},
'nag':	{'ag','bag','dag','fag','gag','jag','lag','mag','na','nab','nae','nan','nap','nay','rag','sag','snag','tag'},
'nagging':	{'bagging','gagging','lagging','tagging'},
'nail':	{'bail','dail','fail','hail','jail','mail','nails','nil','rail','sail','snail','tail'},
'nailed':	{'failed','hailed','jailed','mailed','sailed','tailed'},
'nailing':	{'ailing','failing','mailing','railing','sailing','wailing'},
'nails':	{'fails','hails','jails','mails','nail','rails','sails','snails','tails'},
'naive':	{'native','waive'},
'naked':	{'baked','faked','named','raked'},
'name':	{'came','dame','fame','game','lame','nae','named','names','nome','same','tame'},
'named':	{'famed','naked','name','names','tamed'},
'names':	{'games','james','name','named','tames'},
'namibia':	{'namibian'},
'namibian':	{'namibia'},
'naming':	{'gaming','taming'},
'nan':	{'an','ban','can','fan','han','jan','lan','man','na','nab','nae','nag','nap','nay','non','nun','pan','ran','tan','van','wan'},
'nance':	{'dance','lance','nancy','tance'},
'nancy':	{'fancy','nance','nanny'},
'nanny':	{'fanny','nancy'},
'nantes':	{'antes'},
'nap':	{'cap','gap','hap','lap','map','na','nab','nae','nag','nan','nay','nip','np','pap','rap','sap','snap','tap','yap','zap'},
'napkin':	{'napkins'},
'napkins':	{'napkin'},
'naples':	{'maples'},
'nappy':	{'happy'},
'nara':	{'ara','mara','nada','nasa','nra','para','tara'},
'narcotic':	{'narcotics'},
'narcotics':	{'narcotic'},
'narrative':	{'narratives'},
'narratives':	{'narrative'},
'narrow':	{'arrow','barrow','harrow','marrow','narrows'},
'narrowed':	{'narrower'},
'narrower':	{'narrowed'},
'narrowing':	{'harrowing'},
'narrows':	{'arrows','narrow'},
'nasa':	{'nada','nara','nasal','nash'},
'nasal':	{'basal','nasa','natal','naval'},
'nascent':	{'ascent'},
'nash':	{'ash','bash','cash','dash','hash','lash','mash','nasa','rash','sash','wash'},
'nasser':	{'passer'},
'nasty':	{'hasty','tasty'},
'natal':	{'fatal','nasal','naval'},
'nation':	{'cation','nations','notion','ration'},
'national':	{'nationals','notional','rational'},
'nationalism':	{'nationalist','rationalism'},
'nationalist':	{'nationalism','nationalists'},
'nationalists':	{'nationalist'},
'nationality':	{'rationality'},
'nationally':	{'rationally'},
'nationals':	{'national'},
'nations':	{'cations','nation','notions','rations'},
'native':	{'naive','natives'},
'natives':	{'native'},
'natural':	{'naturals'},
'naturals':	{'natural'},
'nature':	{'mature','natured','natures'},
'natured':	{'matured','nature','natures'},
'natures':	{'matures','nature','natured'},
'naturist':	{'naturists'},
'naturists':	{'naturist'},
'naval':	{'nasal','natal','navel'},
'navel':	{'naval','novel','ravel'},
'navy':	{'davy','nay','wavy'},
'nay':	{'bay','cay','day','fay','gay','hay','jay','lay','may','na','nab','nae','nag','nan','nap','navy','nays','ngay','ny','pay','ray','say','way'},
'nays':	{'bays','days','gays','hays','lays','mays','nay','pays','rays','says','ways'},
'nb':	{'ab','b','bb','db','eb','gb','kb','lb','mb','na','nab','nc','nd','ne','nh','ni','nib','nj','nm','no','nob','np','nt','nu','nv','nw','ny','ob','pb','rb','sb','tb','yb'},
'nc':	{'ac','bc','c','cc','dc','ec','inc','kc','mc','na','nb','nd','ne','nh','ni','nj','nm','no','np','nrc','nsc','nt','nu','nv','nw','ny','pc','sc','tc'},
'nd':	{'ad','and','cd','d','dd','ed','end','gd','id','md','na','nb','nc','ne','nh','ni','nj','nm','no','nod','np','nt','nu','nv','nw','ny','od','pd','sd','vd'},
'ne':	{'be','ce','de','e','ee','ene','fe','ge','he','ie','le','me','na','nae','nb','nc','nd','nee','net','new','nh','ni','nj','nm','no','np','nt','nu','nv','nw','ny','one','pe','se','te','ve','we','xe','ye'},
'near':	{'bear','dear','ear','fear','gear','hear','lear','nears','neat','pear','rear','tear','wear','year'},
'nearby':	{'nearly'},
'nearer':	{'bearer','hearer','neater','wearer'},
'nearest':	{'dearest','neatest'},
'nearing':	{'bearing','fearing','gearing','hearing','rearing','tearing','wearing'},
'nearly':	{'dearly','early','nearby','neatly','yearly'},
'nearness':	{'neatness'},
'nears':	{'bears','dears','ears','fears','gears','hears','near','pears','tears','wears','years'},
'neat':	{'beat','eat','feat','heat','meat','near','neath','nest','net','newt','next','peat','seat'},
'neater':	{'eater','heater','nearer'},
'neatest':	{'nearest'},
'neath':	{'death','heath','neat'},
'neatly':	{'nearly'},
'neatness':	{'nearness'},
'necessitate':	{'necessitated','necessitates'},
'necessitated':	{'necessitate','necessitates'},
'necessitates':	{'necessitate','necessitated'},
'neck':	{'beck','deck','heck','necks','nick','peck'},
'necklace':	{'necklaces'},
'necklaces':	{'necklace'},
'necks':	{'decks','neck'},
'nee':	{'bee','ee','fee','gee','knee','lee','nae','ne','need','net','new','pee','see','tee','wee'},
'need':	{'deed','feed','heed','nee','needn','needs','needy','nerd','reed','seed','weed'},
'needed':	{'needled','seeded','weeded'},
'needing':	{'feeding','needling','seeding','weeding'},
'needle':	{'needled','needles'},
'needled':	{'needed','needle','needles'},
'needles':	{'needle','needled','needless'},
'needless':	{'needles'},
'needling':	{'needing','seedling'},
'needn':	{'need','needs','needy'},
'needs':	{'deeds','feeds','leeds','need','needn','needy','nerds','reeds','seeds','weeds'},
'needy':	{'need','needn','needs'},
'negate':	{'negated','negates'},
'negated':	{'negate','negates'},
'negates':	{'negate','negated'},
'negative':	{'negatives'},
'negatives':	{'negative'},
'neglect':	{'neglects'},
'neglects':	{'neglect'},
'negotiate':	{'negotiated'},
'negotiated':	{'negotiate'},
'negotiation':	{'negotiations'},
'negotiations':	{'negotiation'},
'negotiator':	{'negotiators'},
'negotiators':	{'negotiator'},
'negro':	{'nero'},
'neighbor':	{'neighbors','neighbour'},
'neighborhood':	{'neighborhoods','neighbourhood'},
'neighborhoods':	{'neighborhood','neighbourhoods'},
'neighboring':	{'neighbouring'},
'neighbors':	{'neighbor','neighbours'},
'neighbour':	{'neighbor','neighbours'},
'neighbourhood':	{'neighborhood','neighbourhoods'},
'neighbourhoods':	{'neighborhoods','neighbourhood'},
'neighbouring':	{'neighboring'},
'neighbours':	{'neighbors','neighbour'},
'neither':	{'either','nether'},
'neon':	{'leon','non','noon'},
'neoplasm':	{'neoplasms'},
'neoplasms':	{'neoplasm'},
'nepal':	{'nepali'},
'nepali':	{'nepal'},
'nephew':	{'nephews'},
'nephews':	{'nephew'},
'nerd':	{'herd','need','nerds','nero'},
'nerds':	{'herds','needs','nerd'},
'nero':	{'hero','negro','nerd','zero'},
'nerve':	{'nerves','serve','verve'},
'nerves':	{'nerve','serves'},
'nest':	{'best','est','fest','jest','lest','neat','nests','net','newt','next','pest','rest','test','vest','west','zest'},
'nested':	{'nestled','netted','rested','tested','vested'},
'nesting':	{'netting','resting','testing','vesting'},
'nestle':	{'nestled'},
'nestled':	{'nested','nestle'},
'nests':	{'nest','nets','pests','rests','tests','vests'},
'net':	{'bet','et','get','jet','let','met','ne','neat','nee','nest','nets','new','newt','next','nit','not','nt','nut','pet','set','tet','vet','wet','yet'},
'nether':	{'ether','neither'},
'nets':	{'bets','gets','lets','nests','net','news','nuts','pets','sets','vets','wets'},
'netted':	{'nested'},
'netting':	{'betting','getting','letting','nesting','setting','wetting'},
'network':	{'networks'},
'networks':	{'network'},
'neural':	{'neutral'},
'neuron':	{'neurons','neutron'},
'neurons':	{'neuron','neutrons'},
'neutral':	{'neural'},
'neutralisation':	{'neutralization'},
'neutralise':	{'neutralised','neutralises','neutralize'},
'neutralised':	{'neutralise','neutralises','neutralized'},
'neutralises':	{'neutralise','neutralised','neutralizes'},
'neutralising':	{'neutralizing'},
'neutralization':	{'neutralisation'},
'neutralize':	{'neutralise','neutralized','neutralizes'},
'neutralized':	{'neutralised','neutralize','neutralizes'},
'neutralizes':	{'neutralises','neutralize','neutralized'},
'neutralizing':	{'neutralising'},
'neutrino':	{'neutrinos'},
'neutrinos':	{'neutrino'},
'neutron':	{'neuron','neutrons'},
'neutrons':	{'neurons','neutron'},
'never':	{'ever','fever','lever','newer','sever'},
'nevis':	{'levis'},
'new':	{'anew','dew','few','jew','knew','mew','ne','nee','net','news','newt','now','nw','pew','sew','yew'},
'newbie':	{'newbies'},
'newbies':	{'newbie'},
'newborn':	{'newborns'},
'newborns':	{'newborn'},
'newcomer':	{'newcomers'},
'newcomers':	{'newcomer'},
'newer':	{'fewer','never','sewer'},
'newest':	{'fewest'},
'news':	{'mews','nets','new','newt','sews'},
'newsgroup':	{'newsgroups'},
'newsgroups':	{'newsgroup'},
'newsletter':	{'newsletters'},
'newsletters':	{'newsletter'},
'newspaper':	{'newspapers'},
'newspapers':	{'newspaper'},
'newt':	{'neat','nest','net','new','news','next'},
'next':	{'neat','nest','net','newt','text'},
'ngay':	{'gay','nay'},
'nh':	{'eh','h','na','nb','nc','nd','ne','ni','nih','nj','nm','no','np','nt','nth','nu','nv','nw','ny','oh','ph','rh','sh','th','uh'},
'ni':	{'ai','bi','ci','di','gi','hi','i','ii','ji','ki','li','mi','na','nb','nc','nd','ne','nh','nib','nih','nil','nip','nit','nix','nj','nm','no','np','nt','nu','nv','nw','ny','pi','qi','ri','si','ti','uni','vi','wi','xi','yi'},
'nib':	{'bib','lib','nab','nb','ni','nih','nil','nip','nit','nix','nob','rib','sib'},
'nicaragua':	{'nicaraguan'},
'nicaraguan':	{'nicaragua'},
'nice':	{'dice','ice','lice','mice','nicer','niche','nick','niece','nike','nile','nine','rice','vice'},
'nicer':	{'nice','niger'},
'niche':	{'nice','niches'},
'niches':	{'niche','riches'},
'nick':	{'dick','kick','lick','mick','neck','nice','pick','rick','sick','tick','wick'},
'nickel':	{'nickels'},
'nickels':	{'nickel'},
'nickname':	{'nicknamed','nicknames'},
'nicknamed':	{'nickname','nicknames'},
'nicknames':	{'nickname','nicknamed'},
'niece':	{'nice','nieces','piece'},
'nieces':	{'niece','pieces'},
'nifty':	{'fifty'},
'niger':	{'nicer','nigger','tiger'},
'nigeria':	{'nigerian'},
'nigerian':	{'nigeria'},
'nigger':	{'bigger','digger','niger'},
'nigh':	{'high','night','nih','sigh'},
'night':	{'eight','fight','knight','light','might','nigh','nights','right','sight','tight','wight'},
'nightclub':	{'nightclubs'},
'nightclubs':	{'nightclub'},
'nightly':	{'lightly','rightly','tightly'},
'nightmare':	{'nightmares'},
'nightmares':	{'nightmare'},
'nights':	{'eights','fights','knights','lights','night','rights','sights','tights'},
'nih':	{'nh','ni','nib','nigh','nil','nip','nit','nix','nth'},
'nike':	{'bike','hike','ike','like','mike','nice','nile','nine','nuke','pike'},
'nil':	{'il','mil','nail','ni','nib','nih','nile','nip','nit','nix','oil','til'},
'nile':	{'bile','file','mile','nice','nike','nil','nine','pile','tile','vile'},
'nina':	{'mina','nine','ning','ninja'},
'nine':	{'cine','dine','fine','line','mine','nice','nike','nile','nina','nines','ning','none','pine','sine','vine','wine','zine'},
'nines':	{'dines','fines','lines','mines','nine','pines','vines','wines','zines'},
'ning':	{'ding','king','ling','ming','nina','nine','ping','qing','ring','sing','ting','wing','ying'},
'ninja':	{'nina'},
'nip':	{'dip','hip','ip','kip','lip','nap','ni','nib','nih','nil','nit','nix','np','pip','rip','sip','snip','tip','vip','yip','zip'},
'nipple':	{'nipples','ripple'},
'nipples':	{'nipple','ripples'},
'nit':	{'bit','fit','git','hit','it','kit','knit','lit','mit','net','ni','nib','nih','nil','nip','nix','not','nt','nut','pit','sit','tit','unit','wit'},
'nitrate':	{'citrate','nitrite'},
'nitrite':	{'nitrate'},
'nix':	{'dix','fix','ix','mix','ni','nib','nih','nil','nip','nit','pix','six','unix','xix'},
'nj':	{'dj','j','na','nb','nc','nd','ne','nh','ni','nm','no','np','nt','nu','nv','nw','ny'},
'nm':	{'am','bm','cm','em','fm','gm','hm','km','mm','na','nb','nc','nd','ne','nh','ni','nj','no','np','nt','nu','nv','nw','ny','pm','rm','sm','tm','um','wm'},
'no':	{'co','do','fo','go','ho','io','ko','lo','mo','na','nb','nc','nd','ne','nh','ni','nj','nm','nob','nod','non','nor','nos','not','nov','now','np','nt','nu','nv','nw','ny','o','ono','po','so','to','wo'},
'nob':	{'bob','cob','fob','hob','job','knob','lob','mob','nab','nb','nib','no','nod','non','nor','nos','not','nov','now','ob','rob','sob'},
'nobel':	{'noel','novel'},
'nobility':	{'mobility'},
'noble':	{'nobler','nobles','nobly'},
'nobler':	{'noble','nobles'},
'nobles':	{'noble','nobler','noblest'},
'noblest':	{'nobles'},
'nobly':	{'noble'},
'nod':	{'bod','cod','dod','god','mod','nd','no','nob','node','nods','non','nor','nos','not','nov','now','od','pod','rod','sod','tod'},
'node':	{'anode','bode','code','mode','nod','nodes','nods','nome','none','nose','note','nude','ode','rode'},
'nodes':	{'codes','modes','node','nods','noses','notes','noyes','nudes'},
'nods':	{'gods','mods','nod','node','nodes','nos','nous','pods','rods'},
'nodules':	{'modules'},
'noel':	{'joel','nobel','novel'},
'noise':	{'boise','noises','noisy','norse','nose'},
'noises':	{'noise','noses'},
'noisy':	{'noise'},
'nome':	{'come','dome','gnome','home','name','node','none','nose','note','rome','some','tome'},
'nominate':	{'dominate','nominated'},
'nominated':	{'dominated','nominate'},
'nominating':	{'dominating'},
'nomination':	{'domination','nominations'},
'nominations':	{'nomination'},
'nominee':	{'nominees'},
'nominees':	{'nominee'},
'non':	{'anon','con','don','hon','ion','mon','nan','neon','no','nob','nod','none','noon','nor','nos','not','noun','nov','now','nun','on','ron','son','ton','von','won','yon'},
'non-conformist':	{'non-conformists','nonconformist'},
'non-conformists':	{'non-conformist','nonconformists'},
'non-conformity':	{'nonconformity'},
'nonconformist':	{'non-conformist','nonconformists'},
'nonconformists':	{'non-conformists','nonconformist'},
'nonconformity':	{'non-conformity'},
'none':	{'bone','cone','done','gone','hone','lone','nine','node','nome','non','noone','nose','note','one','tone','zone'},
'nonprofit':	{'nonprofits'},
'nonprofits':	{'nonprofit'},
'noodle':	{'doodle','noodles','poodle'},
'noodles':	{'noodle'},
'nook':	{'book','cook','hook','look','noon','rook','took'},
'noon':	{'boon','coon','loon','moon','neon','non','nook','noone','noun','soon'},
'noone':	{'boone','none','noon'},
'nor':	{'for','no','nob','nod','non','norm','nos','not','nov','now','or','tor'},
'norm':	{'dorm','form','nor','norma','norms','worm'},
'norma':	{'norm','normal','norman','norms'},
'normal':	{'formal','norma','norman'},
'normalisation':	{'normalization'},
'normalise':	{'normalised','normalises','normalize'},
'normalised':	{'normalise','normalises','normalized'},
'normalises':	{'normalise','normalised','normalizes'},
'normalising':	{'normalizing'},
'normality':	{'formality'},
'normalization':	{'normalisation'},
'normalize':	{'normalise','normalized','normalizes'},
'normalized':	{'formalized','normalised','normalize','normalizes'},
'normalizes':	{'normalises','normalize','normalized'},
'normalizing':	{'normalising'},
'normally':	{'formally'},
'norman':	{'norma','normal'},
'normative':	{'formative'},
'norms':	{'dorms','forms','norm','norma','worms'},
'norris':	{'morris'},
'norse':	{'horse','morse','noise','nose','nurse','worse'},
'north':	{'forth','worth'},
'north-east':	{'northeast'},
'north-west':	{'northwest'},
'northeast':	{'north-east'},
'northward':	{'northwards'},
'northwards':	{'northward'},
'northwest':	{'north-west'},
'nos':	{'cos','dos','hos','no','nob','nod','nods','non','nor','nose','not','nous','nov','now','os','sos'},
'nose':	{'bose','dose','hose','lose','node','noise','nome','none','norse','nos','nosed','noses','note','nyse','pose','rose'},
'nosed':	{'nose','noses','noted','posed'},
'noses':	{'doses','hoses','loses','moses','nodes','noises','nose','nosed','notes','noyes','poses','roses'},
'nostalgia':	{'nostalgic'},
'nostalgic':	{'nostalgia'},
'not':	{'bot','cot','dot','got','hot','knot','lot','mot','net','nit','no','nob','nod','non','nor','nos','note','nov','now','nt','nut','pot','rot','sot','tot','wot'},
'notable':	{'notably','potable'},
'notably':	{'notable'},
'notary':	{'rotary'},
'notation':	{'notations','rotation'},
'notations':	{'notation','rotations'},
'note':	{'cote','node','nome','none','nose','not','noted','notes','tote','vote'},
'notebook':	{'notebooks'},
'notebooks':	{'notebook'},
'noted':	{'nosed','note','notes','voted'},
'notes':	{'nodes','noses','note','noted','noyes','totes','votes'},
'nothing':	{'noting'},
'notice':	{'noticed','notices','novice'},
'noticeable':	{'noticeably'},
'noticeably':	{'noticeable'},
'noticed':	{'notice','notices'},
'notices':	{'notice','noticed','novices'},
'notification':	{'notifications'},
'notifications':	{'notification'},
'notified':	{'notifies'},
'notifies':	{'notified'},
'noting':	{'nothing','voting'},
'notion':	{'lotion','motion','nation','notions','potion'},
'notional':	{'national'},
'notions':	{'lotions','motions','nations','notion','potions'},
'noun':	{'non','noon','nouns','nous','nun'},
'nouns':	{'noun','nous','nuns'},
'nous':	{'nods','nos','noun','nouns','sous'},
'nov':	{'no','nob','nod','non','nor','nos','not','nova','now','nv'},
'nova':	{'nov'},
'novel':	{'navel','nobel','noel','novels'},
'novels':	{'novel'},
'novice':	{'notice','novices'},
'novices':	{'notices','novice'},
'now':	{'bow','cow','how','know','low','new','no','nob','nod','non','nor','nos','not','nov','nw','ow','pow','row','snow','sow','tow','vow','wow'},
'noyes':	{'nodes','noses','notes'},
'nozzle':	{'nozzles'},
'nozzles':	{'nozzle'},
'np':	{'dp','gnp','gp','hp','ip','kp','lp','mp','na','nap','nb','nc','nd','ne','nh','ni','nip','nj','nm','no','nt','nu','nv','nw','ny','op','p','up'},
'nra':	{'ara','bra','era','ira','na','nara','nrc','ra'},
'nrc':	{'arc','nc','nra','nsc','prc'},
'nsc':	{'nc','nrc','nsf','sc'},
'nsf':	{'nsc'},
'nt':	{'ant','at','ct','et','ft','ht','int','it','kt','mt','na','nb','nc','nd','ne','net','nh','ni','nit','nj','nm','no','not','np','nth','nu','nut','nv','nw','ny','ont','pt','t','tnt','ut','vt'},
'nth':	{'nh','nih','nt','th'},
'nu':	{'au','cu','du','eu','gnu','gu','ju','lu','mu','na','nb','nc','nd','ne','nh','ni','nj','nm','no','np','nt','nun','nut','nv','nw','ny','pu','ru','su','u','wu','zu'},
'nuclei':	{'nucleic'},
'nucleic':	{'nuclei'},
'nucleotide':	{'nucleotides'},
'nucleotides':	{'nucleotide'},
'nude':	{'dude','jude','node','nudes','nudge','nuke','rude'},
'nudes':	{'dudes','nodes','nude','nukes'},
'nudge':	{'fudge','judge','nude'},
'nudism':	{'nudist'},
'nudist':	{'nudism','nudists'},
'nudists':	{'nudist'},
'nuisance':	{'nuisances'},
'nuisances':	{'nuisance'},
'nuke':	{'duke','luke','nike','nude','nukes','puke'},
'nukes':	{'nudes','nuke'},
'null':	{'bull','dull','full','gull','hull','mull','pull'},
'numb':	{'dumb'},
'number':	{'lumber','numbers'},
'numbers':	{'number'},
'numeral':	{'numerals'},
'numerals':	{'numeral'},
'nun':	{'bun','dun','fun','gun','hun','nan','non','noun','nu','nuns','nut','pun','run','sun','un'},
'nuns':	{'buns','guns','nouns','nun','nuts','runs','suns'},
'nurse':	{'curse','norse','nursed','nurses','purse'},
'nursed':	{'cursed','nurse','nurses'},
'nurses':	{'curses','nurse','nursed','purses'},
'nursing':	{'cursing'},
'nurture':	{'nurtured'},
'nurtured':	{'nurture'},
'nut':	{'but','cut','gut','hut','net','nit','not','nt','nu','nun','nuts','out','put','rut','tut','ut'},
'nutrient':	{'nutrients'},
'nutrients':	{'nutrient'},
'nuts':	{'cuts','guts','huts','nets','nuns','nut','outs','puts'},
'nutty':	{'putty'},
'nv':	{'av','cv','ev','iv','jv','lv','na','nb','nc','nd','ne','nh','ni','nj','nm','no','nov','np','nt','nu','nw','ny','rv','tv','uv','v','wv','xv'},
'nw':	{'kw','na','nb','nc','nd','ne','new','nh','ni','nj','nm','no','now','np','nt','nu','nv','ny','ow','sw','w','wnw'},
'ny':	{'any','by','dy','ky','ly','my','na','nay','nb','nc','nd','ne','nh','ni','nj','nm','no','np','nt','nu','nv','nw','wy','y'},
'nylon':	{'nylons'},
'nylons':	{'nylon'},
'nymph':	{'lymph'},
'nyse':	{'nose'},
'o':	{'a','b','c','co','d','do','e','f','fo','g','go','h','ho','i','io','j','k','ko','l','lo','mo','no','ob','od','of','oh','ok','on','op','or','os','ow','ox','p','po','q','r','so','t','to','u','v','w','wo','x','y','z'},
'oak':	{'ak','oaks','oar','oas','oat','ok','soak','yak'},
'oaks':	{'oak','oars','oas','oats'},
'oar':	{'ar','bar','boar','car','dar','ear','far','gar','jar','mar','oak','oars','oas','oat','or','orr','our','par','roar','soar','tar','var','war'},
'oars':	{'bars','cars','ears','jars','mars','oaks','oar','oas','oats','ours','roars','soars','wars'},
'oas':	{'as','gas','has','mas','oak','oaks','oar','oars','oat','oats','ops','os','pas','was'},
'oasis':	{'basis'},
'oat':	{'at','bat','boat','cat','coat','dat','eat','fat','goat','hat','kat','lat','mat','oak','oar','oas','oath','oats','oct','oft','ont','opt','out','pat','rat','sat','tat','vat','wat'},
'oates':	{'dates','fates','gates','hates','mates','oaths','oats','rates'},
'oath':	{'bath','hath','math','oat','oaths','oats','path'},
'oaths':	{'baths','maths','oates','oath','oats','paths'},
'oats':	{'bats','boats','cats','coats','eats','fats','goats','hats','lats','mats','oaks','oars','oas','oat','oates','oath','oaths','opts','outs','rats'},
'ob':	{'ab','b','bb','bob','cob','db','eb','fob','gb','hob','job','kb','lb','lob','mb','mob','nb','nob','o','obi','od','of','oh','ok','omb','on','op','or','orb','os','ow','ox','pb','rb','rob','sb','sob','tb','yb'},
'obey':	{'obeys','tobey'},
'obeys':	{'obey'},
'obi':	{'bi','fbi','ob','obit','rbi'},
'obit':	{'bit','obi','obits','omit','orbit'},
'obits':	{'bits','obit','omits','orbits'},
'object':	{'objects'},
'objection':	{'objections'},
'objections':	{'objection'},
'objective':	{'objectives'},
'objectives':	{'objective'},
'objects':	{'object'},
'obligation':	{'obligations'},
'obligations':	{'obligation'},
'oblige':	{'obliged'},
'obliged':	{'oblige'},
'obscure':	{'obscured'},
'obscured':	{'obscure'},
'observation':	{'observations'},
'observations':	{'observation'},
'observe':	{'observed','observer','observes'},
'observed':	{'observe','observer','observes'},
'observer':	{'observe','observed','observers','observes'},
'observers':	{'observer','observes'},
'observes':	{'observe','observed','observer','observers'},
'obstacle':	{'obstacles'},
'obstacles':	{'obstacle'},
'obstruction':	{'obstructions'},
'obstructions':	{'obstruction'},
'obtain':	{'obtains'},
'obtains':	{'obtain'},
'occasion':	{'occasions'},
'occasions':	{'occasion'},
'occidental':	{'accidental'},
'occupant':	{'occupants'},
'occupants':	{'occupant'},
'occupation':	{'occupations'},
'occupations':	{'occupation'},
'occupied':	{'occupier','occupies'},
'occupier':	{'occupied','occupiers','occupies'},
'occupiers':	{'occupier','occupies'},
'occupies':	{'occupied','occupier','occupiers'},
'occur':	{'occurs'},
'occurrence':	{'occurrences'},
'occurrences':	{'occurrence'},
'occurs':	{'occur'},
'ocean':	{'oceans'},
'oceania':	{'oceanic'},
'oceanic':	{'oceania'},
'oceans':	{'ocean'},
'och':	{'koch','loch','oct','oh','ooh'},
'oct':	{'act','ct','oat','och','oft','ont','opt','out','pct'},
'octane':	{'octave'},
'octave':	{'octane'},
'octet':	{'octets'},
'octets':	{'octet'},
'od':	{'ad','bod','cd','cod','d','dd','dod','ed','gd','god','id','md','mod','nd','nod','o','ob','odd','ode','of','oh','ok','old','on','op','or','os','ow','ox','pd','pod','rod','sd','sod','tod','vd'},
'odd':	{'add','dd','od','odds','ode','old','todd'},
'odds':	{'adds','dds','odd'},
'ode':	{'ade','bode','code','de','mode','node','od','odd','oder','ole','one','ore','owe','rode'},
'oder':	{'coder','der','ode','odor','older','order','over'},
'odin':	{'din','rodin'},
'odor':	{'oder','odors','odour'},
'odors':	{'odor'},
'odour':	{'odor'},
'of':	{'af','cf','f','ff','gf','hf','if','o','ob','od','off','oft','oh','ok','on','op','or','os','ow','ox','rf'},
'off':	{'eff','ff','of','offs','oft'},
'offence':	{'offences','offense'},
'offences':	{'offence','offenses'},
'offend':	{'offends'},
'offended':	{'offender'},
'offender':	{'offended','offenders'},
'offenders':	{'offender'},
'offends':	{'offend'},
'offense':	{'offence','offenses'},
'offenses':	{'offences','offense'},
'offer':	{'offers'},
'offering':	{'offerings'},
'offerings':	{'offering'},
'offers':	{'coffers','offer'},
'office':	{'officer','offices'},
'officer':	{'office','officers','offices'},
'officers':	{'officer','offices'},
'offices':	{'office','officer','officers'},
'official':	{'officials'},
'officials':	{'official'},
'offs':	{'off'},
'offset':	{'offsets'},
'offsets':	{'offset'},
'oft':	{'aft','eft','ft','loft','oat','oct','of','off','ont','opt','out','soft'},
'often':	{'soften'},
'ogre':	{'ore'},
'oh':	{'eh','h','nh','o','ob','och','od','of','ohm','ok','on','ooh','op','or','os','ow','ox','ph','rh','sh','th','uh'},
'ohm':	{'hm','oh'},
'oil':	{'boil','coil','foil','il','mil','nil','oils','oily','owl','soil','til','toil'},
'oiled':	{'boiled','coiled','filed','piled','soiled','tiled'},
'oils':	{'boils','coils','foils','oil','oily','soils'},
'oily':	{'lily','oil','oils','only'},
'ok':	{'ak','bk','k','o','oak','ob','od','of','oh','on','op','or','os','ow','ox','uk','wok'},
'ola':	{'ala','bola','cola','la','old','ole'},
'old':	{'bold','cold','fold','gold','hold','mold','od','odd','ola','ole','sold','told'},
'older':	{'alder','bolder','colder','elder','folder','holder','oder','order','solder'},
'oldest':	{'boldest','coldest','eldest'},
'ole':	{'ale','cole','dole','hole','le','mole','ode','ola','old','one','ore','owe','pole','role','sole'},
'olive':	{'alive','clive','live','oliver','olives'},
'oliver':	{'liver','olive','olives','olivier'},
'olives':	{'lives','olive','oliver'},
'olivier':	{'oliver'},
'olympia':	{'olympiad','olympian','olympic'},
'olympiad':	{'olympia','olympian'},
'olympian':	{'olympia','olympiad'},
'olympic':	{'olympia','olympics'},
'olympics':	{'olympic'},
'oman':	{'man','omani','omen','roman','woman'},
'omani':	{'oman'},
'omb':	{'bomb','comb','mb','ob','orb','tomb','womb'},
'omega':	{'mega'},
'omen':	{'amen','men','oman','open','oven','owen','oxen','women'},
'omission':	{'emission','mission','omissions'},
'omissions':	{'emissions','missions','omission'},
'omit':	{'emit','mit','obit','omits','vomit'},
'omits':	{'emits','obits','omit'},
'omitted':	{'emitted'},
'omitting':	{'emitting'},
'on':	{'an','con','don','en','hon','in','ion','mn','mon','non','o','ob','od','of','oh','ok','one','ono','ont','op','or','os','ow','own','ox','rn','ron','sn','son','tn','ton','un','von','won','yon','zn'},
'once':	{'one','ounce','ponce'},
'oncology':	{'ontology'},
'one':	{'bone','cone','done','ene','gone','hone','lone','ne','none','ode','ole','on','once','ones','ono','ont','ore','owe','tone','zone'},
'ones':	{'bones','cones','jones','one','onus','ores','owes','tones','zones'},
'onion':	{'anion','onions','orion','union'},
'onions':	{'onion','unions'},
'only':	{'oily'},
'ono':	{'mono','no','on','one','ont','onto'},
'onset':	{'inset','unset'},
'ont':	{'ant','cont','dont','font','int','nt','oat','oct','oft','on','one','ono','onto','opt','out','tnt','wont'},
'onto':	{'into','ono','ont','unto'},
'ontology':	{'oncology'},
'onus':	{'anus','bonus','gnus','ones','opus'},
'onward':	{'inward','onwards'},
'onwards':	{'onward'},
'ooh':	{'och','oh'},
'ooze':	{'booze'},
'op':	{'bop','cop','dp','gop','gp','hop','hp','ip','kp','lp','mop','mp','np','o','ob','od','of','oh','ok','on','ops','opt','or','os','ow','ox','p','pop','sop','top','up','wop'},
'opal':	{'opel','oral','oval','pal'},
'opec':	{'opel','open','spec'},
'opel':	{'opal','opec','open'},
'open':	{'omen','opec','opel','opens','oven','owen','oxen','pen'},
'opened':	{'opener'},
'opener':	{'opened','openers'},
'openers':	{'opener'},
'opening':	{'openings'},
'openings':	{'opening'},
'opens':	{'open','ovens','owens','pens'},
'opera':	{'operas'},
'operand':	{'operands'},
'operands':	{'operand'},
'operas':	{'opera'},
'operate':	{'operated','operates'},
'operated':	{'operate','operates'},
'operates':	{'operate','operated'},
'operation':	{'operations'},
'operations':	{'operation'},
'operative':	{'operatives'},
'operatives':	{'operative'},
'operator':	{'operators'},
'operators':	{'operator'},
'opinion':	{'opinions'},
'opinions':	{'opinion'},
'opponent':	{'opponents'},
'opponents':	{'opponent'},
'oppose':	{'opposed','opposes'},
'opposed':	{'oppose','opposes'},
'opposes':	{'oppose','opposed'},
'opposite':	{'opposites'},
'opposites':	{'opposite'},
'ops':	{'bps','cops','cps','fps','hops','oas','op','opt','opts','opus','os','pops','ps','tops'},
'opt':	{'apt','oat','oct','oft','ont','op','ops','opts','out','pt'},
'optic':	{'coptic','optics'},
'optical':	{'optimal'},
'optically':	{'optimally'},
'optics':	{'optic'},
'optimal':	{'optical'},
'optimally':	{'optically'},
'optimisation':	{'optimization'},
'optimise':	{'optimism','optimist','optimize'},
'optimism':	{'optimise','optimist'},
'optimist':	{'optimise','optimism'},
'optimization':	{'optimisation','optimizations'},
'optimizations':	{'optimization'},
'optimize':	{'optimise','optimized','optimizer','optimizes'},
'optimized':	{'optimize','optimizer','optimizes'},
'optimizer':	{'optimize','optimized','optimizes'},
'optimizes':	{'optimize','optimized','optimizer'},
'opting':	{'outing'},
'option':	{'options'},
'options':	{'option'},
'opts':	{'oats','ops','opt','opus','outs'},
'opus':	{'onus','ops','opts','pus'},
'or':	{'ar','br','cr','dr','er','for','fr','hr','ir','jr','kr','lr','mr','nor','o','oar','ob','od','of','oh','ok','on','op','orb','ore','org','orr','os','our','ow','ox','pr','qr','r','sr','tor','ur','yr','zr'},
'oral':	{'coral','moral','opal','oval'},
'orally':	{'morally','rally'},
'orange':	{'grange','oranges','range'},
'oranges':	{'orange','ranges'},
'orb':	{'ob','omb','or','ore','org','orr','rb'},
'orbit':	{'obit','orbits'},
'orbits':	{'obits','orbit'},
'orchard':	{'orchards'},
'orchards':	{'orchard'},
'orchestra':	{'orchestral','orchestras'},
'orchestral':	{'orchestra','orchestras'},
'orchestras':	{'orchestra','orchestral'},
'orchid':	{'orchids'},
'orchids':	{'orchid'},
'order':	{'border','oder','older','orders'},
'ordered':	{'bordered'},
'ordering':	{'bordering'},
'orders':	{'borders','order'},
'ordinance':	{'ordinances','ordnance'},
'ordinances':	{'ordinance'},
'ordnance':	{'ordinance'},
'ore':	{'are','bore','core','ere','fore','gore','ire','lore','more','ode','ogre','ole','one','or','orb','ores','org','orr','owe','pore','pre','sore','tore','wore'},
'ores':	{'ares','cores','ones','ore','owes','pores','pres','res','sores'},
'org':	{'or','orb','ore','orgy','orig','orr'},
'organ':	{'morgan','organs'},
'organic':	{'organics'},
'organics':	{'organic'},
'organisation':	{'organisations','organization'},
'organisational':	{'organizational'},
'organisations':	{'organisation','organizations'},
'organise':	{'organised','organiser','organises','organism','organize'},
'organised':	{'organise','organiser','organises','organized'},
'organiser':	{'organise','organised','organisers','organises','organizer'},
'organisers':	{'organiser','organises','organizers'},
'organises':	{'organise','organised','organiser','organisers','organisms','organizes'},
'organising':	{'organizing'},
'organism':	{'organise','organisms'},
'organisms':	{'organises','organism'},
'organization':	{'organisation','organizations'},
'organizational':	{'organisational'},
'organizations':	{'organisations','organization'},
'organize':	{'organise','organized','organizer','organizes'},
'organized':	{'organised','organize','organizer','organizes'},
'organizer':	{'organiser','organize','organized','organizers','organizes'},
'organizers':	{'organisers','organizer','organizes'},
'organizes':	{'organises','organize','organized','organizer','organizers'},
'organizing':	{'organising'},
'organs':	{'organ'},
'orgasm':	{'orgasms'},
'orgasms':	{'orgasm'},
'orgy':	{'org'},
'orient':	{'orients'},
'orientate':	{'orientated','orientates'},
'orientated':	{'orientate','orientates'},
'orientates':	{'orientate','orientated'},
'orientation':	{'orientations'},
'orientations':	{'orientation'},
'orients':	{'orient'},
'orig':	{'brig','org','rig','trig'},
'origin':	{'origins'},
'original':	{'originals'},
'originals':	{'original'},
'originate':	{'originated','originates'},
'originated':	{'originate','originates'},
'originates':	{'originate','originated'},
'origins':	{'origin'},
'orion':	{'onion'},
'ornament':	{'ornaments'},
'ornaments':	{'ornament'},
'orphan':	{'orphans'},
'orphans':	{'orphan'},
'orpheus':	{'morpheus'},
'orr':	{'err','oar','or','orb','ore','org','our'},
'orthodox':	{'orthodoxy'},
'orthodoxy':	{'orthodox'},
'orthopaedic':	{'orthopaedics','orthopedic'},
'orthopaedics':	{'orthopaedic','orthopedics'},
'orthopedic':	{'orthopaedic','orthopedics'},
'orthopedics':	{'orthopaedics','orthopedic'},
'os':	{'as','bs','cos','cs','dos','es','hos','hs','is','ks','ms','nos','o','oas','ob','od','of','oh','ok','on','op','ops','or','ow','ox','ps','sos','ss','ts','us','vs'},
'osage':	{'dosage','sage','usage'},
'oscar':	{'scar'},
'oscillation':	{'oscillations'},
'oscillations':	{'oscillation'},
'oscillator':	{'oscillators'},
'oscillators':	{'oscillator'},
'otc':	{'etc','ftc','rotc','tc'},
'other':	{'bother','ether','mother','others','otter'},
'others':	{'bothers','mothers','other'},
'otter':	{'cotter','hotter','other','outer','potter','utter'},
'ought':	{'bought','fought','oughtn','sought'},
'oughtn':	{'ought'},
'ounce':	{'bounce','once','ounces'},
'ounces':	{'bounces','ounce'},
'our':	{'bur','cur','dur','four','fur','hour','oar','or','orr','ours','out','pour','sour','tour','ur','your'},
'ours':	{'fours','furs','hours','oars','our','outs','pours','sours','tours','yours'},
'ourselves':	{'yourselves'},
'ousted':	{'busted','dusted','rusted'},
'out':	{'bout','but','cut','gout','gut','hut','nut','oat','oct','oft','ont','opt','our','outs','put','rout','rut','tout','tut','ut'},
'outage':	{'outages','outrage'},
'outages':	{'outage'},
'outboard':	{'outboards'},
'outboards':	{'outboard'},
'outbreak':	{'outbreaks'},
'outbreaks':	{'outbreak'},
'outcome':	{'outcomes'},
'outcomes':	{'outcome'},
'outdoor':	{'outdoors'},
'outdoors':	{'outdoor'},
'outer':	{'otter','router'},
'outfit':	{'outfits'},
'outfits':	{'outfit'},
'outfitted':	{'outfitter'},
'outfitter':	{'outfitted','outfitters'},
'outfitters':	{'outfitter'},
'outing':	{'opting','outings','routing'},
'outings':	{'outing'},
'outlaw':	{'outlaws','outlay'},
'outlaws':	{'outlaw','outlays'},
'outlay':	{'outlaw','outlays'},
'outlays':	{'outlaws','outlay'},
'outlet':	{'outlets','outset'},
'outlets':	{'outlet'},
'outline':	{'outlined','outlines'},
'outlined':	{'outline','outlines'},
'outlines':	{'outline','outlined'},
'output':	{'outputs'},
'outputs':	{'output'},
'outrage':	{'outage','outraged'},
'outraged':	{'outrage'},
'outs':	{'bouts','cuts','guts','huts','nuts','oats','opts','ours','out','puts','touts'},
'outset':	{'outlet'},
'outside':	{'outsider'},
'outsider':	{'outside','outsiders'},
'outsiders':	{'outsider'},
'outsource':	{'outsourced'},
'outsourced':	{'outsource'},
'outward':	{'outwards'},
'outwards':	{'outward'},
'oval':	{'opal','oral'},
'ovaries':	{'varies'},
'ovary':	{'vary'},
'oven':	{'even','omen','open','ovens','over','owen','oxen','woven'},
'ovens':	{'opens','oven','overs','owens'},
'over':	{'cover','dover','ever','hover','lover','mover','oder','oven','overs','overt','rover'},
'over-estimate':	{'overestimate'},
'overcame':	{'overcome'},
'overcome':	{'overcame','overcomes'},
'overcomes':	{'overcome'},
'overestimate':	{'over-estimate','overestimated','overestimates'},
'overestimated':	{'overestimate','overestimates'},
'overestimates':	{'overestimate','overestimated'},
'overflow':	{'overflows'},
'overflows':	{'overflow'},
'overhead':	{'overheads','overheard'},
'overheads':	{'overhead'},
'overheard':	{'overhead'},
'overlaid':	{'overland'},
'overland':	{'overlaid'},
'overlap':	{'overlaps','overlay'},
'overlaps':	{'overlap','overlays'},
'overlay':	{'overlap','overlays','overly'},
'overlays':	{'overlaps','overlay'},
'overlook':	{'overlooks'},
'overlooks':	{'overlook'},
'overly':	{'overlay','overtly'},
'overnight':	{'oversight'},
'override':	{'overrides'},
'overrides':	{'override'},
'overs':	{'covers','lovers','movers','ovens','over','overt','rovers'},
'overseas':	{'oversees'},
'oversee':	{'overseen','oversees'},
'overseen':	{'oversee','oversees'},
'oversees':	{'overseas','oversee','overseen'},
'oversight':	{'overnight'},
'overt':	{'avert','covert','over','overs'},
'overtake':	{'overtaken'},
'overtaken':	{'overtake'},
'overtly':	{'overly'},
'overture':	{'overturn'},
'overturn':	{'overture'},
'overview':	{'overviews'},
'overviews':	{'overview'},
'ovid':	{'avid'},
'ow':	{'bow','cow','how','kw','low','now','nw','o','ob','od','of','oh','ok','on','op','or','os','owe','owl','own','ox','pow','row','sow','sw','tow','vow','w','wow'},
'owe':	{'awe','howe','ode','ole','one','ore','ow','owed','owen','owes','owl','own','we'},
'owed':	{'bowed','owe','owen','owes','owned','rowed','sowed','towed','vowed','wed'},
'owen':	{'omen','open','oven','owe','owed','owens','owes','own','oxen','wen'},
'owens':	{'opens','ovens','owen','owes','owns'},
'owes':	{'ones','ores','owe','owed','owen','owens','owns'},
'owing':	{'bowing','lowing','mowing','owning','rowing','sowing','swing','towing','wing'},
'owl':	{'bowl','fowl','howl','oil','ow','owe','own'},
'own':	{'down','gown','on','ow','owe','owen','owl','owns','sown','town'},
'owned':	{'downed','owed','owner'},
'owner':	{'downer','owned','owners'},
'owners':	{'downers','owner'},
'owning':	{'awning','downing','owing'},
'owns':	{'downs','gowns','owens','owes','own','towns'},
'ox':	{'ax','box','cox','ex','fox','ix','o','ob','od','of','oh','ok','on','op','or','os','ow','pox','px','tx','x','xx'},
'oxen':	{'omen','open','oven','owen'},
'oxide':	{'oxides'},
'oxides':	{'oxide'},
'oyster':	{'oysters'},
'oysters':	{'oyster'},
'ozone':	{'zone'},
'p':	{'a','b','c','d','dp','e','f','g','gp','h','hp','i','ip','j','k','kp','l','lp','mp','np','o','op','pa','pb','pc','pd','pe','ph','pi','pm','po','pr','ps','pt','pu','px','q','r','t','u','up','v','w','x','y','z'},
'pa':	{'a','ba','ca','cpa','da','ea','epa','fa','ga','gpa','ha','ia','ka','la','ma','na','p','pac','pad','pah','pal','pan','pap','par','pas','pat','paw','pay','pb','pc','pd','pda','pe','pea','ph','pi','pia','pm','po','pr','ps','pt','pu','px','ra','sa','spa','ta','va','wa','ya','za'},
'pac':	{'ac','lac','mac','pa','pace','pack','pact','pad','pah','pal','pan','pap','par','pas','pat','paw','pay','pc','pfc','pic','prc','pvc','sac','vac','wac'},
'pace':	{'ace','face','lace','mace','pac','paced','paces','pack','pact','page','pale','pane','pate','pave','peace','place','race','space'},
'paced':	{'faced','laced','pace','paces','packed','paled','pared','paved','placed','raced','spaced'},
'paces':	{'aces','faces','laces','pace','paced','packs','pages','pales','panes','places','races','spaces'},
'pacing':	{'facing','packing','paging','paling','paving','paying','placing','racing','spacing'},
'pack':	{'back','hack','jack','lack','mack','pac','pace','packs','pact','park','peck','pick','puck','rack','sack','tack'},
'package':	{'packaged','packager','packages'},
'packaged':	{'package','packager','packages'},
'packager':	{'package','packaged','packages'},
'packages':	{'package','packaged','packager'},
'packed':	{'backed','hacked','lacked','paced','packer','packet','parked','picked','sacked'},
'packer':	{'hacker','packed','packet','parker','picker'},
'packet':	{'jacket','packed','packer','packets','picket','pocket','racket'},
'packets':	{'jackets','packet','pockets'},
'packing':	{'backing','hacking','jacking','lacking','pacing','parking','picking','racking'},
'packs':	{'backs','hacks','jacks','lacks','paces','pack','parks','picks','racks','sacks'},
'pact':	{'act','fact','pac','pace','pack','pant','part','past','pat','pct','tact'},
'pad':	{'ad','bad','cad','dad','fad','had','lad','mad','pa','pac','pads','pah','paid','pal','pan','pap','par','pas','pat','paw','pay','pd','phd','pod','pud','rad','sad','tad','wad'},
'padded':	{'added'},
'padding':	{'adding','paddling','pudding'},
'paddle':	{'paddles','puddle','saddle'},
'paddles':	{'paddle','saddles'},
'paddling':	{'padding','saddling'},
'paddy':	{'caddy','daddy'},
'padre':	{'cadre'},
'pads':	{'ads','dads','lads','pad','pals','pans','pas','pass','paws','pays','pods'},
'paediatric':	{'pediatric'},
'pagan':	{'pagans'},
'pagans':	{'pagan'},
'page':	{'age','cage','gage','pace','pager','pages','paige','pale','pane','pate','pave','phage','rage','sage','wage'},
'pager':	{'eager','lager','page','pagers','pages','paper','payer','wager'},
'pagers':	{'pager','pages','papers','payers'},
'pages':	{'ages','cages','paces','page','pager','pagers','pales','panes','sages','wages'},
'paging':	{'aging','caging','pacing','paling','paving','paying','raging','waging'},
'pah':	{'pa','pac','pad','pal','pan','pap','par','pas','pat','path','paw','pay','ph'},
'paid':	{'aid','laid','maid','pad','pain','pair','plaid','raid','said'},
'paige':	{'page','paine'},
'pain':	{'cain','gain','jain','lain','main','paid','paine','pains','paint','pair','pan','pawn','pin','plain','rain','spain','vain'},
'paine':	{'maine','paige','pain','pains','paint','pane','pine'},
'pains':	{'gains','mains','pain','paine','paint','paints','pairs','pans','pins','plains','rains'},
'paint':	{'faint','pain','paine','pains','paints','pant','pint','point','print','saint'},
'painted':	{'fainted','painter','pointed','printed','tainted'},
'painter':	{'fainter','painted','painters','pointer','printer'},
'painters':	{'painter','pointers','printers'},
'painting':	{'fainting','paintings','pointing','printing'},
'paintings':	{'painting'},
'paints':	{'faints','pains','paint','pants','pints','points','prints'},
'pair':	{'air','fair','hair','lair','paid','pain','pairs','par','parr'},
'paired':	{'aired','haired','pared'},
'pairing':	{'airing','pairings'},
'pairings':	{'pairing'},
'pairs':	{'airs','fairs','hairs','pains','pair'},
'paisley':	{'parsley'},
'pajama':	{'pajamas','panama'},
'pajamas':	{'pajama'},
'pakistan':	{'pakistani'},
'pakistani':	{'pakistan'},
'pal':	{'al','dal','gal','mal','opal','pa','pac','pad','pah','pale','pall','palm','pals','pan','pap','par','pas','pat','paul','paw','pay','pol'},
'palace':	{'palaces','palate','place'},
'palaces':	{'palace','places'},
'palate':	{'palace','pilate','plate'},
'pale':	{'ale','bale','dale','gale','hale','male','pace','page','pal','paled','pales','pall','palm','pals','pane','pate','pave','pile','pole','pyle','sale','tale','vale','yale'},
'paled':	{'paced','pale','pales','pared','paved','piled'},
'pales':	{'ales','bales','males','paces','pages','pale','paled','palms','pals','panes','piles','poles','sales','tales','wales'},
'paling':	{'pacing','paging','paving','paying','piling'},
'pall':	{'all','ball','call','fall','gall','hall','mall','pal','pale','palm','pals','paul','pill','poll','pull','tall','wall'},
'pallet':	{'ballet','mallet','pallets','pellet','wallet'},
'pallets':	{'pallet','pellets','wallets'},
'palm':	{'balm','calm','pal','pale','pall','palms','pals','psalm'},
'palms':	{'calms','pales','palm','pals','psalms'},
'pals':	{'gals','pads','pal','pale','pales','pall','palm','palms','palsy','pans','pas','pass','paws','pays'},
'palsy':	{'pals','patsy'},
'pamper':	{'camper','damper','hamper','paper','tamper'},
'pampered':	{'hampered','papered'},
'pamphlet':	{'pamphlets'},
'pamphlets':	{'pamphlet'},
'pan':	{'an','ban','can','fan','han','jan','lan','man','nan','pa','pac','pad','pah','pain','pal','pane','pang','pans','pant','pap','par','pas','pat','paw','pawn','pay','pen','pin','plan','pun','ran','span','tan','van','wan'},
'panama':	{'pajama'},
'pancake':	{'pancakes'},
'pancakes':	{'pancake'},
'pane':	{'bane','cane','dane','lane','mane','pace','page','paine','pale','pan','panel','panes','pang','pans','pant','pate','pave','pine','plane','sane'},
'panel':	{'pane','panels','panes'},
'panels':	{'panel','panes'},
'panes':	{'canes','lanes','paces','pages','pales','pane','panel','panels','pans','pants','pines','planes'},
'pang':	{'ang','bang','dang','fang','gang','hang','pan','pane','pans','pant','ping','pong','rang','sang','tang','yang'},
'panic':	{'manic'},
'panorama':	{'panoramas'},
'panoramas':	{'panorama'},
'pans':	{'ans','bans','cans','dans','fans','mans','pads','pains','pals','pan','pane','panes','pang','pant','pants','pas','pass','paws','pays','pens','pins','plans','sans','spans','vans'},
'pant':	{'ant','cant','kant','pact','paint','pan','pane','pang','pans','pants','part','past','pat','pint','plant','punt','rant','want'},
'pantie':	{'panties'},
'panties':	{'pantie','parties'},
'pantry':	{'pastry'},
'pants':	{'ants','paints','panes','pans','pant','parts','pints','plants','rants','wants'},
'pap':	{'cap','gap','hap','lap','map','nap','pa','pac','pad','pah','pal','pan','papa','par','pas','pat','paw','pay','pcp','pep','pip','pop','pup','rap','sap','tap','yap','zap'},
'papa':	{'pap','papal','para'},
'papal':	{'papa'},
'paper':	{'pager','pamper','papers','payer','piper','taper'},
'paperback':	{'paperbacks'},
'paperbacks':	{'paperback'},
'papered':	{'pampered','tapered'},
'papers':	{'capers','pagers','paper','payers'},
'par':	{'ar','bar','car','dar','ear','far','gar','jar','mar','oar','pa','pac','pad','pah','pair','pal','pan','pap','para','park','parr','part','pas','pat','paw','pay','pear','per','pr','tar','var','war'},
'para':	{'ara','mara','nara','papa','par','park','parka','parr','part','tara'},
'parable':	{'arable','payable'},
'parade':	{'parades'},
'parades':	{'parade'},
'paradigm':	{'paradigms'},
'paradigms':	{'paradigm'},
'paragraph':	{'paragraphs'},
'paragraphs':	{'paragraph'},
'parallel':	{'parallels'},
'paralleled':	{'parallelled'},
'parallelled':	{'paralleled'},
'parallels':	{'parallel'},
'paramedic':	{'paramedics'},
'paramedics':	{'paramedic'},
'parameter':	{'parameters'},
'parameters':	{'parameter'},
'paranoia':	{'paranoid'},
'paranoid':	{'paranoia'},
'parasite':	{'parasites'},
'parasites':	{'parasite'},
'parcel':	{'marcel','parcels'},
'parcels':	{'parcel'},
'pardon':	{'pardons','parson'},
'pardons':	{'pardon','parsons'},
'pared':	{'bared','cared','dared','eared','fared','paced','paired','paled','parked','parsed','parted','paved','spared'},
'parent':	{'parents','patent'},
'parentheses':	{'parenthesis'},
'parenthesis':	{'parentheses'},
'parenting':	{'patenting'},
'parents':	{'parent','patents'},
'paris':	{'parish','parks','parts'},
'parish':	{'paris','parrish','perish'},
'parity':	{'party','purity','rarity'},
'park':	{'ark','bark','dark','lark','mark','pack','par','para','parka','parks','parr','part','pork','spark'},
'parka':	{'para','park','parks'},
'parked':	{'marked','packed','pared','parker','parsed','parted','sparked'},
'parker':	{'barker','darker','marker','packer','parked','parser'},
'parking':	{'barking','marking','packing','parsing','parting','sparking'},
'parks':	{'marks','packs','paris','park','parka','parts','perks'},
'parliament':	{'parliaments'},
'parliaments':	{'parliament'},
'parlor':	{'parlour'},
'parlour':	{'parlor'},
'parr':	{'pair','par','para','park','parry','part'},
'parrish':	{'parish'},
'parrot':	{'carrot','parrots'},
'parrots':	{'carrots','parrot'},
'parry':	{'carry','harry','marry','parr','party','perry'},
'parse':	{'arse','parsed','parser','passe','pause','purse','sparse'},
'parsed':	{'pared','parked','parse','parser','parted','passed','paused'},
'parser':	{'parker','parse','parsed','passer'},
'parsing':	{'parking','parting','passing','pausing'},
'parsley':	{'paisley'},
'parson':	{'arson','carson','pardon','parsons','person'},
'parsons':	{'pardons','parson','persons'},
'part':	{'apart','art','bart','cart','dart','fart','hart','kart','mart','pact','pant','par','para','park','parr','parts','party','past','pat','port','tart'},
'parted':	{'carted','pared','parked','parsed','pasted','ported'},
'partial':	{'martial'},
'participant':	{'participants'},
'participants':	{'participant'},
'participate':	{'participated','participates'},
'participated':	{'participate','participates'},
'participates':	{'participate','participated'},
'particle':	{'article','particles'},
'particles':	{'articles','particle'},
'particular':	{'particulars'},
'particulars':	{'particular'},
'particulate':	{'articulate'},
'parties':	{'panties'},
'parting':	{'carting','parking','parsing','partying','pasting','porting'},
'partisan':	{'artisan'},
'partition':	{'partitions'},
'partitions':	{'partition'},
'partly':	{'party'},
'partner':	{'partners'},
'partners':	{'partner'},
'partnership':	{'partnerships'},
'partnerships':	{'partnership'},
'partridge':	{'cartridge'},
'parts':	{'arts','carts','darts','karts','pants','paris','parks','part','party','ports','tarts','warts'},
'party':	{'parity','parry','part','partly','parts','patty'},
'partying':	{'parting'},
'pas':	{'as','gas','has','mas','oas','pa','pac','pad','pads','pah','pal','pals','pan','pans','pap','par','pass','past','pat','paw','paws','pay','pays','pbs','peas','pms','ps','pus','spas','was'},
'pascal':	{'rascal'},
'pasha':	{'pasta'},
'pass':	{'ass','bass','lass','mass','pads','pals','pans','pas','passe','past','paws','pays','piss'},
'passage':	{'massage','passages'},
'passages':	{'massages','passage'},
'passe':	{'parse','pass','passed','passer','passes','paste','pause','posse'},
'passed':	{'parsed','passe','passer','passes','pasted','paused','pissed'},
'passenger':	{'passengers'},
'passengers':	{'passenger'},
'passer':	{'nasser','parser','passe','passed','passes'},
'passes':	{'asses','basses','masses','passe','passed','passer','pastes','pauses'},
'passing':	{'parsing','pasting','pausing','pissing'},
'passion':	{'passions'},
'passions':	{'passion'},
'passive':	{'massive'},
'passively':	{'massively'},
'passport':	{'passports'},
'passports':	{'passport'},
'password':	{'passwords'},
'passwords':	{'password'},
'past':	{'cast','east','fast','hast','last','mast','pact','pant','part','pas','pass','pasta','paste','pat','pest','post','pst','vast'},
'pasta':	{'pasha','past','paste'},
'paste':	{'caste','haste','passe','past','pasta','pasted','pastel','pastes','pate','taste','waste'},
'pasted':	{'lasted','parted','passed','paste','pastel','pastes','posted','tasted','wasted'},
'pastel':	{'paste','pasted','pastes'},
'pastes':	{'passes','paste','pasted','pastel','tastes','wastes'},
'pasting':	{'casting','fasting','lasting','parting','passing','posting','tasting','wasting'},
'pastor':	{'astor','castor','pastors'},
'pastors':	{'pastor'},
'pastry':	{'pantry'},
'pasture':	{'pastures','posture'},
'pastures':	{'pasture','postures'},
'pat':	{'at','bat','cat','dat','eat','fat','hat','kat','lat','mat','oat','pa','pac','pact','pad','pah','pal','pan','pant','pap','par','part','pas','past','pate','path','paw','pay','pct','peat','pet','phat','pit','plat','pot','pst','pt','put','rat','sat','spat','tat','vat','wat'},
'patch':	{'batch','catch','hatch','latch','match','patchy','path','pitch','watch'},
'patched':	{'hatched','matched','patches','pitched','watched'},
'patches':	{'batches','catches','latches','matches','patched','pitches','watches'},
'patching':	{'catching','hatching','matching','pitching','watching'},
'patchy':	{'catchy','patch'},
'pate':	{'ate','date','fate','gate','hate','late','mate','pace','page','pale','pane','paste','pat','path','pave','plate','rate','tate'},
'patent':	{'latent','parent','patents','patient','potent'},
'patenting':	{'parenting'},
'patently':	{'patiently'},
'patents':	{'parents','patent','patients'},
'paternal':	{'maternal'},
'paternity':	{'maternity'},
'path':	{'bath','hath','math','oath','pah','pat','patch','pate','paths'},
'pathogen':	{'pathogens'},
'pathogens':	{'pathogen'},
'pathologist':	{'pathologists'},
'pathologists':	{'pathologist'},
'paths':	{'baths','maths','oaths','path'},
'pathway':	{'pathways'},
'pathways':	{'pathway'},
'patient':	{'patent','patients'},
'patiently':	{'patently'},
'patients':	{'patents','patient'},
'patio':	{'patios','ratio'},
'patios':	{'patio','ratios'},
'paton':	{'baton','patron','paxton'},
'patrol':	{'patrols','patron','petrol'},
'patrols':	{'patrol','patrons'},
'patron':	{'paton','patrol','patrons'},
'patrons':	{'patrols','patron'},
'patsy':	{'palsy','patty'},
'patten':	{'fatten','pattern'},
'pattern':	{'patten','patterns'},
'patterns':	{'pattern'},
'patty':	{'fatty','party','patsy','petty','potty','putty'},
'paul':	{'gaul','haul','pal','pall','pauli','saul'},
'pauli':	{'paul'},
'pause':	{'cause','parse','passe','paused','pauses'},
'paused':	{'caused','parsed','passed','pause','pauses'},
'pauses':	{'causes','passes','pause','paused','pluses'},
'pausing':	{'causing','parsing','passing'},
'pave':	{'ave','cave','fave','gave','have','pace','page','pale','pane','pate','paved','rave','save','wave'},
'paved':	{'caved','paced','paled','pared','pave','saved','waved'},
'pavement':	{'pavements'},
'pavements':	{'pavement'},
'paving':	{'caving','having','pacing','paging','paling','paying','raving','saving','waving'},
'paw':	{'haw','jaw','law','pa','pac','pad','pah','pal','pan','pap','par','pas','pat','pawn','paws','pay','pew','pow','raw','saw'},
'pawn':	{'dawn','fawn','lawn','pain','pan','paw','paws','spawn','yawn'},
'paws':	{'jaws','laws','pads','pals','pans','pas','pass','paw','pawn','pays','saws'},
'paxton':	{'paton'},
'pay':	{'bay','cay','day','fay','gay','hay','jay','lay','may','nay','pa','pac','pad','pah','pal','pan','pap','par','pas','pat','paw','pays','play','ply','pray','ray','say','way'},
'payable':	{'parable','playable'},
'payback':	{'playback'},
'payee':	{'payer'},
'payer':	{'bayer','gayer','layer','mayer','pager','paper','payee','payers','player','prayer'},
'payers':	{'layers','pagers','papers','payer','players','prayers','sayers'},
'paying':	{'laying','pacing','paging','paling','paving','playing','praying','saying'},
'payment':	{'payments'},
'payments':	{'payment'},
'payoff':	{'layoff','payoffs','playoff'},
'payoffs':	{'layoffs','payoff','playoffs'},
'payout':	{'layout','payouts'},
'payouts':	{'layouts','payout'},
'pays':	{'bays','days','gays','hays','lays','mays','nays','pads','pals','pans','pas','pass','paws','pay','phys','plays','prays','rays','says','ways'},
'pb':	{'ab','b','bb','db','eb','gb','kb','lb','mb','nb','ob','p','pa','pbs','pc','pd','pe','ph','pi','pm','po','pr','ps','pt','pu','pub','px','rb','sb','tb','yb'},
'pbs':	{'abs','bbs','bs','pas','pb','pms','ps','pubs','pus'},
'pc':	{'ac','bc','c','cc','dc','ec','kc','mc','nc','p','pa','pac','pb','pcp','pct','pd','pe','pfc','ph','pi','pic','pm','po','pr','prc','ps','pt','pu','pvc','px','sc','tc'},
'pcp':	{'pap','pc','pct','pep','pip','pop','pup'},
'pct':	{'act','ct','oct','pact','pat','pc','pcp','pet','pit','pot','pst','pt','put'},
'pd':	{'ad','cd','d','dd','ed','gd','id','md','nd','od','p','pa','pad','pb','pc','pda','pe','ph','phd','pi','pm','po','pod','pr','ps','pt','pu','pud','px','sd','vd'},
'pda':	{'ada','da','eda','fda','ida','pa','pd','pea','pia'},
'pe':	{'ape','be','ce','de','e','ee','fe','ge','he','ie','le','me','ne','p','pa','pb','pc','pd','pea','pee','peg','pei','pen','pep','per','pet','pew','ph','pi','pie','pm','po','poe','pr','pre','ps','pt','pu','px','se','te','ve','we','xe','ye'},
'pea':	{'dea','ea','lea','pa','pda','pe','peak','pear','peas','peat','pee','peg','pei','pen','pep','per','pet','pew','pia','plea','sea','tea','yea'},
'peace':	{'pace','peach','pence','place'},
'peach':	{'beach','each','leach','peace','perch','preach','reach','teach'},
'peaches':	{'beaches','preaches','reaches','teaches'},
'peak':	{'beak','leak','pea','peaks','pear','peas','peat','peck','peek','speak','teak','weak'},
'peaked':	{'beaked','leaked'},
'peaking':	{'leaking','peking','speaking'},
'peaks':	{'beaks','leaks','peak','pears','peas','perks','speaks'},
'peanut':	{'peanuts'},
'peanuts':	{'peanut'},
'pear':	{'bear','dear','ear','fear','gear','hear','lear','near','par','pea','peak','pearl','pears','peas','peat','peer','per','rear','spear','tear','wear','year'},
'pearl':	{'earl','pear','pearls','pears'},
'pearls':	{'pearl','pears'},
'pears':	{'bears','dears','ears','fears','gears','hears','nears','peaks','pear','pearl','pearls','peas','peers','tears','wears','years'},
'peas':	{'pas','pea','peak','peaks','pear','pears','peat','pegs','pens','pets','pleas','seas','teas','yeas'},
'peasant':	{'peasants','pheasant','pleasant'},
'peasants':	{'peasant'},
'peat':	{'beat','eat','feat','heat','meat','neat','pat','pea','peak','pear','peas','pest','pet','phat','plat','seat'},
'pebble':	{'pebbles'},
'pebbles':	{'pebble'},
'pecan':	{'pecans'},
'pecans':	{'pecan'},
'peck':	{'beck','deck','heck','neck','pack','peak','peek','pick','puck','speck'},
'pecos':	{'pesos'},
'pedal':	{'medal','pedals','penal','petal'},
'pedals':	{'medals','pedal','petals'},
'pedestrian':	{'pedestrians'},
'pedestrians':	{'pedestrian'},
'pediatric':	{'paediatric','pediatrics'},
'pediatrics':	{'pediatric'},
'pee':	{'bee','ee','fee','gee','lee','nee','pe','pea','peek','peel','peep','peer','peg','pei','pen','pep','per','pet','pew','pie','poe','pre','see','tee','wee'},
'peeing':	{'peeling','peeping','peering','peking','seeing'},
'peek':	{'eek','geek','leek','meek','peak','peck','pee','peel','peep','peer','seek','week'},
'peel':	{'eel','feel','heel','keel','pee','peek','peep','peer','reel'},
'peeling':	{'feeling','peeing','peeping','peering','reeling'},
'peep':	{'beep','deep','jeep','keep','pee','peek','peel','peer','pep','prep','weep'},
'peeping':	{'keeping','peeing','peeling','peering','weeping'},
'peer':	{'beer','deer','pear','pee','peek','peel','peep','peers','per','peter','pier','seer'},
'peering':	{'peeing','peeling','peeping'},
'peers':	{'beers','pears','peer','piers'},
'peg':	{'beg','eeg','leg','meg','pe','pea','pee','pegs','pei','pen','pep','per','pet','pew','pig','pug','veg'},
'pegged':	{'begged','legged'},
'pegs':	{'begs','legs','megs','peas','peg','pens','pets','pigs','regs'},
'pei':	{'lei','mei','pe','pea','pee','peg','pen','pep','per','peri','pet','pew','phi','pi','poi','psi','wei'},
'peking':	{'peaking','peeing','poking'},
'pellet':	{'pallet','pellets'},
'pellets':	{'pallets','pellet'},
'pelvic':	{'pelvis'},
'pelvis':	{'elvis','pelvic'},
'pen':	{'ben','den','en','fen','gen','hen','ken','men','open','pan','pe','pea','pee','peg','pei','penn','pens','pep','per','pet','pew','pin','pun','sen','ten','wen','yen','zen'},
'penal':	{'pedal','petal','renal'},
'pence':	{'fence','hence','peace','ponce'},
'pencil':	{'pencils'},
'pencils':	{'pencil'},
'pendant':	{'pendants','pennant'},
'pendants':	{'pendant'},
'pending':	{'bending','ending','lending','mending','sending','spending','tending','vending'},
'penetrate':	{'penetrated','penetrates'},
'penetrated':	{'penetrate','penetrates'},
'penetrates':	{'penetrate','penetrated'},
'penis':	{'pens'},
'penn':	{'pen','penny','pens'},
'pennant':	{'pendant'},
'penned':	{'pinned'},
'penny':	{'benny','jenny','penn'},
'pens':	{'ens','hens','lens','opens','pans','peas','pegs','pen','penis','penn','pets','pins','sens','tens'},
'pension':	{'pensions','tension'},
'pensions':	{'pension','tensions'},
'people':	{'peoples'},
'peoples':	{'people'},
'pep':	{'hep','pap','pcp','pe','pea','pee','peep','peg','pei','pen','per','pet','pew','pip','pop','prep','pup','rep','sep'},
'pepper':	{'peppers','popper'},
'peppers':	{'pepper'},
'peptide':	{'peptides'},
'peptides':	{'peptide'},
'per':	{'aer','ber','der','er','fer','ger','her','ker','par','pe','pea','pear','pee','peer','peg','pei','pen','pep','peri','perm','peru','pet','pew','pier','pr','yer'},
'perceive':	{'perceived','perceives'},
'perceived':	{'perceive','perceives'},
'perceives':	{'perceive','perceived'},
'percentage':	{'percentages'},
'percentages':	{'percentage'},
'perception':	{'perceptions'},
'perceptions':	{'perception'},
'perch':	{'peach','percy','perth','porch'},
'percy':	{'mercy','perch','perky','perry'},
'perennial':	{'perennials'},
'perennials':	{'perennial'},
'perfect':	{'perfects'},
'perfects':	{'perfect'},
'perform':	{'performs'},
'performance':	{'performances'},
'performances':	{'performance'},
'performed':	{'performer'},
'performer':	{'performed','performers'},
'performers':	{'performer'},
'performs':	{'perform'},
'perfume':	{'perfumes'},
'perfumes':	{'perfume'},
'peri':	{'pei','per','peril','perm','peru'},
'peril':	{'peri','perils'},
'perils':	{'peril'},
'period':	{'periods'},
'periodical':	{'periodicals'},
'periodicals':	{'periodical'},
'periods':	{'period'},
'peripheral':	{'peripherals'},
'peripherals':	{'peripheral'},
'perish':	{'parish'},
'perks':	{'jerks','parks','peaks','perky'},
'perky':	{'jerky','percy','perks','perry','pesky'},
'perm':	{'germ','per','peri','peru','sperm','term'},
'permian':	{'persian'},
'permission':	{'permissions'},
'permissions':	{'permission'},
'permit':	{'hermit','permits'},
'permits':	{'permit'},
'permutation':	{'permutations'},
'permutations':	{'permutation'},
'perpetrator':	{'perpetrators'},
'perpetrators':	{'perpetrator'},
'perry':	{'berry','ferry','jerry','merry','parry','percy','perky','sperry','terry'},
'persia':	{'persian'},
'persian':	{'permian','persia'},
'persist':	{'persists'},
'persists':	{'persist'},
'person':	{'parson','persona','persons'},
'persona':	{'person','personal','persons'},
'personal':	{'persona'},
'personalised':	{'personalized'},
'personalize':	{'personalized'},
'personalized':	{'personalised','personalize'},
'persons':	{'parsons','person','persona'},
'perspective':	{'perspectives'},
'perspectives':	{'perspective'},
'persuade':	{'persuaded','persuades'},
'persuaded':	{'persuade','persuades'},
'persuades':	{'persuade','persuaded'},
'pertain':	{'certain','pertains'},
'pertains':	{'pertain'},
'perth':	{'berth','perch'},
'perturbation':	{'perturbations'},
'perturbations':	{'perturbation'},
'peru':	{'per','peri','perm'},
'pesky':	{'perky'},
'peso':	{'pesos','pest'},
'pesos':	{'pecos','peso','pests'},
'pest':	{'best','est','fest','jest','lest','nest','past','peat','peso','pests','pet','post','pst','rest','test','vest','west','zest'},
'pesticide':	{'pesticides'},
'pesticides':	{'pesticide'},
'pests':	{'nests','pesos','pest','pets','posts','rests','tests','vests'},
'pet':	{'bet','et','get','jet','let','met','net','pat','pct','pe','pea','peat','pee','peg','pei','pen','pep','per','pest','pets','pew','pit','poet','pot','pst','pt','put','set','tet','vet','wet','yet'},
'petal':	{'fetal','metal','pedal','penal','petals'},
'petals':	{'metals','pedals','petal'},
'peter':	{'deter','meter','peer','pewter'},
'petite':	{'petites'},
'petites':	{'petite'},
'petition':	{'petitions'},
'petitioned':	{'petitioner'},
'petitioner':	{'petitioned','petitioners'},
'petitioners':	{'petitioner'},
'petitions':	{'petition'},
'petrol':	{'patrol'},
'pets':	{'bets','gets','lets','nets','peas','pegs','pens','pests','pet','pits','poets','pots','puts','sets','vets','wets'},
'petty':	{'jetty','patty','potty','pretty','putty'},
'pew':	{'dew','few','jew','mew','new','paw','pe','pea','pee','peg','pei','pen','pep','per','pet','pow','sew','yew'},
'pewter':	{'peter'},
'pfc':	{'cfc','pac','pc','pic','prc','pvc'},
'ph':	{'eh','h','kph','mph','nh','oh','p','pa','pah','pb','pc','pd','pe','phd','phi','pi','pm','po','pr','ps','pt','pu','px','rh','sh','th','uh'},
'phage':	{'page','phase'},
'pharmaceutical':	{'pharmaceuticals'},
'pharmaceuticals':	{'pharmaceutical'},
'pharmacist':	{'pharmacists'},
'pharmacists':	{'pharmacist'},
'phase':	{'chase','phage','phased','phases','phrase'},
'phased':	{'chased','phase','phases'},
'phases':	{'chases','phase','phased','phrases'},
'phasing':	{'chasing','phrasing'},
'phat':	{'chat','hat','pat','peat','plat','that','what'},
'phd':	{'pad','pd','ph','phi','pod','pud'},
'pheasant':	{'peasant','pleasant'},
'phenomena':	{'phenomenal'},
'phenomenal':	{'phenomena'},
'phenotype':	{'phenotypes'},
'phenotypes':	{'phenotype'},
'phi':	{'chi','hi','pei','ph','phd','pi','poi','psi','zhi'},
'philippine':	{'philippines'},
'philippines':	{'philippine'},
'philosopher':	{'philosophers'},
'philosophers':	{'philosopher'},
'philosophies':	{'philosophises','philosophizes'},
'philosophise':	{'philosophised','philosophises','philosophize'},
'philosophised':	{'philosophise','philosophises','philosophized'},
'philosophises':	{'philosophies','philosophise','philosophised','philosophizes'},
'philosophising':	{'philosophizing'},
'philosophize':	{'philosophise','philosophized','philosophizes'},
'philosophized':	{'philosophised','philosophize','philosophizes'},
'philosophizes':	{'philosophies','philosophises','philosophize','philosophized'},
'philosophizing':	{'philosophising'},
'phone':	{'hone','phoned','phones','phony','prone','rhone','shone'},
'phoned':	{'honed','phone','phones'},
'phones':	{'phone','phoned'},
'phony':	{'phone','pony'},
'photo':	{'photon','photos'},
'photograph':	{'photographs','photography'},
'photographed':	{'photographer'},
'photographer':	{'photographed','photographers'},
'photographers':	{'photographer'},
'photographs':	{'photograph','photography'},
'photography':	{'photograph','photographs'},
'photon':	{'photo','photons','photos','proton'},
'photons':	{'photon','photos','protons'},
'photos':	{'photo','photon','photons'},
'phrase':	{'phase','phrases'},
'phrases':	{'phases','phrase'},
'phrasing':	{'phasing'},
'phys':	{'pays'},
'physician':	{'physicians'},
'physicians':	{'physician'},
'physicist':	{'physicists'},
'physicists':	{'physicist'},
'pi':	{'ai','bi','ci','cpi','di','epi','gi','hi','i','ii','ji','ki','li','mi','ni','p','pa','pb','pc','pd','pe','pei','ph','phi','pia','pic','pie','pig','pin','pip','pit','piu','pix','pm','po','poi','pr','ps','psi','pt','pu','px','qi','ri','si','ti','vi','wi','xi','yi'},
'pia':	{'cia','ia','pa','pda','pea','pi','pic','pie','pig','pin','pip','pisa','pit','piu','pix','tia','via'},
'piano':	{'pianos','plano'},
'pianos':	{'piano'},
'piazza':	{'pizza'},
'pic':	{'epic','pac','pc','pfc','pi','pia','pick','pics','pie','pig','pin','pip','pit','piu','pix','prc','pvc','sic','tic'},
'pick':	{'dick','kick','lick','mick','nick','pack','peck','pic','picks','picky','pics','pink','prick','puck','rick','sick','tick','wick'},
'picked':	{'kicked','licked','packed','picker','picket','ticked','wicked'},
'picker':	{'kicker','packer','picked','pickers','picket','pinker','sicker','ticker','wicker'},
'pickers':	{'picker'},
'picket':	{'packet','picked','picker','pickett','pocket','ticket','wicket'},
'pickett':	{'picket'},
'picking':	{'kicking','licking','packing','ticking'},
'pickle':	{'pickles','sickle','tickle'},
'pickles':	{'pickle'},
'picks':	{'kicks','licks','packs','pick','picky','pics','ticks'},
'pickup':	{'pickups'},
'pickups':	{'pickup'},
'picky':	{'pick','picks'},
'picnic':	{'picnics'},
'picnics':	{'picnic'},
'pics':	{'mics','pic','pick','picks','pies','pigs','pins','piss','pits','tics'},
'picture':	{'pictured','pictures'},
'pictured':	{'picture','pictures'},
'pictures':	{'picture','pictured'},
'pie':	{'die','ie','lie','pe','pee','pi','pia','pic','pied','pier','pies','pig','pike','pile','pin','pine','pip','pipe','pit','piu','pix','poe','pre','tie','vie'},
'piece':	{'apiece','niece','pieces','pierce'},
'pieces':	{'nieces','piece','pisces'},
'pied':	{'died','lied','pie','pier','pies','piled','piped','tied'},
'pier':	{'peer','per','pie','pied','piers','pies','piper','tier'},
'pierce':	{'fierce','piece','pierced','pierre'},
'pierced':	{'pierce'},
'piercing':	{'piercings'},
'piercings':	{'piercing'},
'pierre':	{'pierce'},
'piers':	{'peers','pier','pies','pliers','tiers'},
'pies':	{'dies','lies','pics','pie','pied','pier','piers','pigs','pikes','piles','pines','pins','pipes','piss','pits','pres','spies','ties'},
'piety':	{'pity'},
'pig':	{'big','dig','fig','gig','jig','peg','pi','pia','pic','pie','pigs','pin','ping','pip','pit','piu','pix','pug','rig','sig','wig'},
'pigeon':	{'pigeons'},
'pigeons':	{'pigeon'},
'pigment':	{'pigments'},
'pigments':	{'pigment'},
'pigs':	{'digs','figs','gigs','pegs','pics','pies','pig','pings','pins','piss','pits','rigs','wigs'},
'pike':	{'bike','hike','ike','like','mike','nike','pie','pikes','pile','pine','pipe','poke','puke','spike'},
'pikes':	{'bikes','dikes','hikes','likes','mikes','pies','pike','piles','pines','pipes','spikes'},
'pilate':	{'palate','pirate','plate'},
'pile':	{'bile','file','mile','nile','pale','pie','pike','piled','piles','pill','pine','pipe','pole','pyle','tile','vile'},
'piled':	{'filed','oiled','paled','pied','pile','piles','piped','tiled'},
'piles':	{'files','miles','pales','pies','pikes','pile','piled','pills','pines','pipes','poles','tiles'},
'pilgrim':	{'pilgrims'},
'pilgrims':	{'pilgrim'},
'piling':	{'ailing','filing','paling','piping','tiling'},
'pill':	{'bill','dill','fill','gill','hill','ill','kill','mill','pall','pile','pills','poll','pull','sill','spill','till','will'},
'pillar':	{'pillars'},
'pillars':	{'pillar'},
'pillow':	{'pillows','willow'},
'pillows':	{'pillow','willows'},
'pills':	{'bills','fills','hills','ills','kills','mills','piles','pill','polls','pulls','spills','wills'},
'pilot':	{'pilots','pivot','plot'},
'pilots':	{'pilot','plots'},
'pimp':	{'gimp','imp','limp','pip','pump'},
'pin':	{'bin','din','fin','gin','in','kin','lin','min','pain','pan','pen','pi','pia','pic','pie','pig','pine','ping','pink','pins','pint','pip','pit','piu','pix','pun','qin','sin','spin','tin','win','yin'},
'pinch':	{'finch','inch','pitch','punch','winch'},
'pinched':	{'pinches','pitched','punched'},
'pinches':	{'inches','pinched','pitches','punches'},
'pinching':	{'pitching','punching'},
'pine':	{'cine','dine','fine','line','mine','nine','paine','pane','pie','pike','pile','pin','pines','ping','pink','pins','pint','pipe','sine','spine','vine','wine','zine'},
'pines':	{'dines','fines','lines','mines','nines','panes','pies','pikes','piles','pine','pings','pins','pints','pipes','spines','vines','wines','zines'},
'ping':	{'ding','king','ling','ming','ning','pang','pig','pin','pine','pings','pink','pins','pint','pong','qing','ring','sing','ting','wing','ying'},
'pings':	{'kings','pigs','pines','ping','pins','pints','rings','sings','wings'},
'pink':	{'fink','ink','link','mink','pick','pin','pine','ping','pins','pint','punk','rink','sink','wink'},
'pinker':	{'picker','tinker'},
'pinned':	{'penned','sinned'},
'pinning':	{'inning','spinning','winning'},
'pins':	{'bins','fins','ins','pains','pans','pens','pics','pies','pigs','pin','pine','pines','ping','pings','pink','pint','pints','piss','pits','sins','spins','tins','wins'},
'pint':	{'hint','int','lint','mint','paint','pant','pin','pine','ping','pink','pins','pinto','pints','pit','pitt','point','print','punt','tint'},
'pinto':	{'into','pint','pints'},
'pints':	{'hints','mints','paints','pants','pines','pings','pins','pint','pinto','pits','points','prints'},
'pioneer':	{'pioneers'},
'pioneers':	{'pioneer'},
'pip':	{'dip','hip','ip','kip','lip','nip','pap','pcp','pep','pi','pia','pic','pie','pig','pimp','pin','pipe','pit','piu','pix','pop','pup','rip','sip','tip','vip','yip','zip'},
'pipe':	{'pie','pike','pile','pine','pip','piped','piper','pipes','pope','ripe','wipe'},
'piped':	{'pied','piled','pipe','piper','pipes','wiped'},
'pipeline':	{'pipelines'},
'pipelines':	{'pipeline'},
'piper':	{'paper','pier','pipe','piped','pipes','riper','viper','wiper'},
'pipes':	{'pies','pikes','piles','pines','pipe','piped','piper','wipes'},
'piping':	{'piling','wiping'},
'pirate':	{'pilate','pirated'},
'pirated':	{'pirate'},
'pisa':	{'pia','piss','visa'},
'pisces':	{'pieces'},
'piss':	{'kiss','miss','pass','pics','pies','pigs','pins','pisa','pits'},
'pissed':	{'kissed','missed','passed'},
'pissing':	{'kissing','missing','passing'},
'pistol':	{'pistols','piston'},
'pistols':	{'pistol'},
'piston':	{'pistol'},
'pit':	{'bit','fit','git','hit','it','kit','lit','mit','nit','pat','pct','pet','pi','pia','pic','pie','pig','pin','pint','pip','pits','pitt','pity','piu','pix','pot','pst','pt','put','sit','spit','tit','wit'},
'pitch':	{'bitch','ditch','fitch','hitch','itch','patch','pinch','witch'},
'pitched':	{'ditched','patched','pinched','pitcher','pitches'},
'pitcher':	{'pitched','pitchers','pitches'},
'pitchers':	{'pitcher','pitches'},
'pitches':	{'bitches','ditches','patches','pinches','pitched','pitcher','pitchers','witches'},
'pitching':	{'bitching','ditching','itching','patching','pinching'},
'pitied':	{'pities','pitted'},
'pities':	{'cities','pitied'},
'pits':	{'bits','fits','hits','its','kits','pets','pics','pies','pigs','pins','pints','piss','pit','pitt','pity','pots','puts','sits','spits','tits','wits'},
'pitt':	{'mitt','pint','pit','pits','pity','putt'},
'pitted':	{'fitted','pitied','potted'},
'pity':	{'city','piety','pit','pits','pitt'},
'piu':	{'pi','pia','pic','pie','pig','pin','pip','pit','pix','pu'},
'pivot':	{'pilot'},
'pix':	{'dix','fix','ix','mix','nix','pi','pia','pic','pie','pig','pin','pip','pit','piu','pox','px','six','xix'},
'pixel':	{'pixels'},
'pixels':	{'pixel'},
'pixie':	{'dixie'},
'pizza':	{'piazza','pizzas'},
'pizzas':	{'pizza'},
'place':	{'lace','pace','palace','peace','placed','placer','places','plane','plate'},
'placed':	{'laced','paced','place','placer','places','placid','plated','played'},
'placement':	{'placements'},
'placements':	{'placement'},
'placer':	{'place','placed','places','player'},
'places':	{'laces','paces','palaces','place','placed','placer','planes','plates'},
'placid':	{'placed','plaid'},
'placing':	{'pacing','plating','playing'},
'plague':	{'plagued','plagues','plaque','prague'},
'plagued':	{'plague','plagues'},
'plagues':	{'plague','plagued','plaques'},
'plaid':	{'laid','paid','placid','plain'},
'plain':	{'lain','pain','plaid','plains','plan','slain'},
'plains':	{'pains','plain','plans'},
'plaintiff':	{'plaintiffs'},
'plaintiffs':	{'plaintiff'},
'plan':	{'clan','elan','klan','lan','pan','plain','plane','plank','plano','plans','plant','plat','play'},
'planck':	{'plank'},
'plane':	{'lane','pane','place','plan','planes','planet','plank','plano','plans','plant','plate'},
'planes':	{'lanes','panes','places','plane','planet','planets','planks','plans','plants','plates'},
'planet':	{'plane','planes','planets','plant'},
'planets':	{'planes','planet','plants'},
'plank':	{'blank','flank','plan','planck','plane','planks','plano','plans','plant','prank'},
'planks':	{'blanks','planes','plank','plans','plants'},
'planned':	{'planner','planted'},
'planner':	{'planned','planners','planter'},
'planners':	{'planner','planters'},
'planning':	{'planting'},
'plano':	{'piano','plan','plane','plank','plans','plant','plato'},
'plans':	{'clans','pans','plains','plan','plane','planes','plank','planks','plano','plant','plants','plays'},
'plant':	{'pant','plan','plane','planet','plank','plano','plans','plants','plat','slant'},
'plantation':	{'plantations'},
'plantations':	{'plantation'},
'planted':	{'planned','planter','plated'},
'planter':	{'planner','planted','planters','plaster','platter'},
'planters':	{'planners','planter','plasters','platters'},
'planting':	{'planning','plantings','plating'},
'plantings':	{'planting'},
'plants':	{'pants','planes','planets','planks','plans','plant'},
'plaque':	{'plague','plaques'},
'plaques':	{'plagues','plaque'},
'plasma':	{'plasmas'},
'plasmas':	{'plasma'},
'plasmid':	{'plasmids'},
'plasmids':	{'plasmid'},
'plaster':	{'blaster','planter','plasters','platter'},
'plasters':	{'planters','plaster','platters'},
'plastic':	{'elastic','plastics'},
'plasticity':	{'elasticity'},
'plastics':	{'elastics','plastic'},
'plat':	{'flat','lat','pat','peat','phat','plan','plant','plate','plato','play','plot'},
'plate':	{'late','palate','pate','pilate','place','plane','plat','plated','plates','plato','platte','slate'},
'plated':	{'placed','planted','plate','plates','played','pleated','slated'},
'platelet':	{'platelets'},
'platelets':	{'platelet'},
'plates':	{'places','planes','plate','plated'},
'platform':	{'platforms'},
'platforms':	{'platform'},
'plating':	{'placing','planting','playing'},
'plato':	{'plano','plat','plate','pluto'},
'platte':	{'latte','plate','platter'},
'platter':	{'flatter','latter','planter','plaster','platte','platters','plotter'},
'platters':	{'planters','plasters','platter','plotters'},
'play':	{'clay','lay','pay','plan','plat','plays','ploy','ply','pray','slay'},
'playable':	{'payable'},
'playback':	{'payback'},
'played':	{'placed','plated','player','prayed'},
'player':	{'layer','payer','placer','played','players','prayer','slayer'},
'players':	{'layers','payers','player','prayers'},
'playground':	{'playgrounds'},
'playgrounds':	{'playground'},
'playing':	{'laying','paying','placing','plating','praying','slaying'},
'playmate':	{'playmates'},
'playmates':	{'playmate'},
'playoff':	{'layoff','payoff','playoffs'},
'playoffs':	{'layoffs','payoffs','playoff'},
'plays':	{'clays','lays','pays','plans','play','prays'},
'plea':	{'flea','lea','pea','plead','pleas'},
'plead':	{'lead','plea','pleads','pleas'},
'pleaded':	{'leaded','pleased','pleated'},
'pleading':	{'leading','pleadings','pleasing'},
'pleadings':	{'pleading'},
'pleads':	{'leads','plead','pleas'},
'pleas':	{'fleas','peas','plea','plead','pleads','please'},
'pleasant':	{'peasant','pheasant'},
'please':	{'lease','pleas','pleased','pleases'},
'pleased':	{'leased','pleaded','please','pleases','pleated'},
'pleases':	{'leases','please','pleased'},
'pleasing':	{'leasing','pleading'},
'pleasure':	{'pleasures'},
'pleasures':	{'pleasure'},
'pleated':	{'plated','pleaded','pleased'},
'pledge':	{'ledge','pledged','pledges','sledge'},
'pledged':	{'fledged','pledge','pledges'},
'pledges':	{'pledge','pledged'},
'pleural':	{'plural'},
'pliers':	{'fliers','piers'},
'plight':	{'blight','flight','light','slight'},
'plo':	{'lo','plot','plow','ploy','ply','po','polo','poo','pro','pto'},
'plot':	{'blot','clot','lot','pilot','plat','plo','plots','plow','ploy','pot','slot'},
'plots':	{'clots','lots','pilots','plot','pots','slots'},
'plotted':	{'plotter','potted','slotted'},
'plotter':	{'platter','plotted','plotters','potter'},
'plotters':	{'platters','plotter','potters'},
'plotting':	{'blotting','clotting','potting'},
'plough':	{'lough','ploughs','slough'},
'ploughs':	{'plough'},
'plover':	{'clover','lover'},
'plow':	{'blow','flow','glow','low','plo','plot','ploy','pow','slow'},
'ploy':	{'play','plo','plot','plow','ply'},
'pluck':	{'luck','puck'},
'plug':	{'lug','plugs','plum','plus','pug','slug'},
'plugged':	{'plunged'},
'plugging':	{'plunging'},
'plugs':	{'plug','plus'},
'plum':	{'alum','plug','plumb','plume','plump','plus','slum'},
'plumb':	{'plum','plume','plump'},
'plumber':	{'lumber','plumbers','plumper','slumber'},
'plumbers':	{'plumber'},
'plume':	{'plum','plumb','plumes','plump'},
'plumes':	{'plume','pluses'},
'plump':	{'lump','plum','plumb','plume','pump','slump'},
'plumper':	{'plumber'},
'plunge':	{'plunged'},
'plunged':	{'plugged','plunge'},
'plunging':	{'plugging'},
'plural':	{'pleural','plurals'},
'plurals':	{'plural'},
'plus':	{'plug','plugs','plum','plush','pus'},
'pluses':	{'pauses','plumes'},
'plush':	{'blush','flush','lush','plus','push'},
'pluto':	{'plato'},
'ply':	{'fly','ly','pay','play','plo','ploy','sly'},
'pm':	{'am','bm','cm','em','fm','gm','hm','km','mm','nm','p','pa','pb','pc','pd','pe','ph','pi','pms','po','pom','pr','ps','pt','pu','px','rm','rpm','sm','tm','um','wm'},
'pms':	{'ms','pas','pbs','pm','ps','pus'},
'po':	{'apo','co','do','fo','go','gpo','ho','io','ko','lo','mo','no','o','p','pa','pb','pc','pd','pe','ph','pi','plo','pm','pod','poe','poi','pol','pom','poo','pop','pot','pow','pox','pr','pro','ps','pt','pto','pu','px','so','to','wo'},
'pocket':	{'docket','packet','picket','pockets','rocket','socket'},
'pockets':	{'packets','pocket','sockets'},
'pod':	{'bod','cod','dod','god','ipod','mod','nod','od','pad','pd','phd','po','pods','poe','poi','pol','pom','pond','poo','pop','pot','pow','pox','prod','pud','rod','sod','tod'},
'podium':	{'sodium'},
'pods':	{'gods','mods','nods','pads','pod','ponds','pops','pots','rods'},
'poe':	{'doe','foe','hoe','pe','pee','pie','po','pod','poem','poet','poi','poke','pol','pole','pom','poo','pop','pope','pore','pose','pot','pow','pox','pre','roe','toe','woe'},
'poem':	{'poe','poems','poet','pom'},
'poems':	{'poem','poets'},
'poet':	{'pet','poe','poem','poets','port','post','pot'},
'poets':	{'pets','poems','poet','ports','posts','pots'},
'poi':	{'pei','phi','pi','po','pod','poe','pol','pom','poo','pop','posi','pot','pow','pox','psi','roi'},
'point':	{'joint','paint','pint','points','pointy','print'},
'pointed':	{'jointed','painted','pointer','printed'},
'pointer':	{'painter','pointed','pointers','printer'},
'pointers':	{'painters','pointer','printers'},
'pointing':	{'painting','printing'},
'points':	{'joints','paints','pints','point','pointy','prints'},
'pointy':	{'point','points'},
'poised':	{'posed'},
'poison':	{'poisons','prison'},
'poisons':	{'poison','prisons'},
'poke':	{'coke','joke','pike','poe','poked','poker','pole','pope','pore','pose','puke','spoke','woke','yoke'},
'poked':	{'joked','poke','poker','posed'},
'poker':	{'joker','poke','poked','poser','power'},
'poking':	{'joking','peking','posing'},
'pol':	{'col','fol','pal','po','pod','poe','poi','pole','polk','poll','polo','pom','poo','pool','pop','pot','pow','pox','sol','vol'},
'polar':	{'molar','poplar','solar'},
'pole':	{'cole','dole','hole','mole','ole','pale','pile','poe','poke','pol','poles','polk','poll','polo','pope','pore','pose','pyle','role','sole'},
'poles':	{'holes','moles','pales','piles','pole','polls','pores','poses','roles','soles'},
'police':	{'policed','polices','policy','polite'},
'policed':	{'police','polices'},
'policeman':	{'policemen'},
'policemen':	{'policeman'},
'polices':	{'police','policed','policies'},
'policies':	{'polices'},
'policy':	{'police'},
'polio':	{'folio','polo'},
'polished':	{'polishes'},
'polishes':	{'polished'},
'polite':	{'police','politer'},
'politer':	{'polite'},
'politica':	{'political','politics'},
'political':	{'politica'},
'politician':	{'politicians'},
'politicians':	{'politician'},
'politics':	{'politica'},
'polk':	{'folk','pol','pole','polka','poll','polo','pork','yolk'},
'polka':	{'polk'},
'poll':	{'boll','doll','moll','pall','pill','pol','pole','polk','polls','polo','pool','pull','roll','toll'},
'pollack':	{'pollock'},
'polled':	{'pollen','pooled','pulled','rolled'},
'pollen':	{'polled'},
'polling':	{'pooling','pulling','rolling'},
'pollock':	{'pollack'},
'polls':	{'dolls','pills','poles','poll','pools','pulls','rolls','tolls'},
'pollutant':	{'pollutants'},
'pollutants':	{'pollutant'},
'polo':	{'plo','pol','pole','polio','polk','poll','poo','solo'},
'polygon':	{'polygons'},
'polygons':	{'polygon'},
'polymer':	{'polymers'},
'polymers':	{'polymer'},
'polymorphism':	{'polymorphisms'},
'polymorphisms':	{'polymorphism'},
'polynesia':	{'polynesian'},
'polynesian':	{'polynesia'},
'polynomial':	{'polynomials'},
'polynomials':	{'polynomial'},
'pom':	{'com','mom','pm','po','pod','poe','poem','poi','pol','poo','pop','pot','pow','pox','prom','rom','tom'},
'ponce':	{'once','pence'},
'pond':	{'bond','fond','pod','ponds','pong','pony','pound'},
'ponder':	{'fonder','powder','wonder','yonder'},
'pondered':	{'powdered','wondered'},
'pondering':	{'wondering'},
'ponds':	{'bonds','pods','pond','pounds'},
'pong':	{'bong','dong','gong','long','pang','ping','pond','pony','prong','song'},
'ponies':	{'monies'},
'pony':	{'bony','phony','pond','pong','puny'},
'poo':	{'boo','coo','goo','loo','moo','plo','po','pod','poe','poi','pol','polo','pom','pool','poop','poor','pop','pot','pow','pox','pro','pto','too','woo','zoo'},
'poodle':	{'doodle','noodle'},
'pool':	{'cool','fool','pol','poll','poo','pools','poop','poor','spool','tool','wool'},
'pooled':	{'cooled','fooled','polled','tooled'},
'pooling':	{'cooling','fooling','polling','tooling'},
'pools':	{'cools','fools','polls','pool','tools','wools'},
'poop':	{'coop','hoop','loop','poo','pool','poor','pop','prop'},
'poor':	{'door','moor','poo','pool','poop','pour'},
'pop':	{'bop','cop','gop','hop','mop','op','pap','pcp','pep','pip','po','pod','poe','poi','pol','pom','poo','poop','pope','pops','pot','pow','pox','prop','pup','sop','top','wop'},
'pope':	{'cope','dope','hope','pipe','poe','poke','pole','pop','pops','pore','pose','rope'},
'poplar':	{'polar','popular'},
'popped':	{'hopped','popper','topped'},
'popper':	{'copper','hopper','pepper','popped','topper'},
'popping':	{'hopping','topping'},
'poppy':	{'puppy'},
'pops':	{'cops','hops','ops','pods','pop','pope','pots','props','pups','tops'},
'populace':	{'populate'},
'popular':	{'poplar'},
'populate':	{'populace','populated','populates'},
'populated':	{'populate','populates'},
'populates':	{'populate','populated'},
'population':	{'populations'},
'populations':	{'population'},
'porch':	{'perch','pouch','torch'},
'pore':	{'bore','core','fore','gore','lore','more','ore','poe','poke','pole','pope','pores','pork','porn','port','pose','pre','pure','sore','spore','tore','wore'},
'pores':	{'cores','ores','poles','pore','ports','poses','pres','sores','spores'},
'pork':	{'cork','dork','fork','park','polk','pore','porn','port','work','york'},
'porn':	{'born','corn','horn','morn','pore','pork','porno','port','torn','worn'},
'porno':	{'porn','porto'},
'port':	{'fort','hort','part','poet','pore','pork','porn','porto','ports','post','pot','sort','sport','tort','wort'},
'portable':	{'portables','potable'},
'portables':	{'portable'},
'portage':	{'postage'},
'portal':	{'mortal','portals','postal'},
'portals':	{'mortals','portal'},
'ported':	{'parted','porter','posted','potted','sorted'},
'porter':	{'ported','porters','poster','potter','sorter'},
'porters':	{'porter','posters','potters'},
'portfolio':	{'portfolios'},
'portfolios':	{'portfolio'},
'porting':	{'parting','posting','potting','sorting','sporting'},
'portion':	{'portions','potion'},
'portions':	{'portion','potions'},
'portland':	{'cortland'},
'porto':	{'porno','port','ports'},
'portrait':	{'portraits'},
'portraits':	{'portrait'},
'portray':	{'portrays'},
'portrays':	{'portray'},
'ports':	{'forts','parts','poets','pores','port','porto','posts','pots','sorts','sports','torts'},
'portugues':	{'portuguese'},
'portuguese':	{'portugues'},
'pose':	{'bose','dose','hose','lose','nose','poe','poke','pole','pope','pore','posed','poser','poses','posh','posi','posse','post','prose','rose'},
'posed':	{'nosed','poised','poked','pose','poser','poses','posted'},
'poser':	{'loser','poker','pose','posed','poses','poster','power'},
'poses':	{'doses','hoses','loses','moses','noses','poles','pores','pose','posed','poser','posts','roses'},
'posh':	{'gosh','josh','pose','posi','post','push'},
'posi':	{'poi','pose','posh','post','psi'},
'posing':	{'dosing','losing','poking','posting'},
'position':	{'positions','positron'},
'positions':	{'position'},
'positive':	{'positives'},
'positives':	{'positive'},
'positron':	{'position'},
'posse':	{'passe','pose'},
'possessed':	{'possesses'},
'possesses':	{'possessed'},
'possession':	{'possessions'},
'possessions':	{'possession'},
'possible':	{'possibly'},
'possibly':	{'possible'},
'post':	{'cost','host','lost','most','past','pest','poet','port','pose','posh','posi','posts','pot','pst'},
'postage':	{'hostage','portage'},
'postal':	{'portal'},
'postcard':	{'postcards'},
'postcards':	{'postcard'},
'posted':	{'hosted','pasted','ported','posed','poster','potted'},
'poster':	{'foster','porter','poser','posted','posters','potter','roster'},
'posters':	{'fosters','porters','poster','potters','rosters'},
'posting':	{'costing','hosting','pasting','porting','posing','postings','potting'},
'postings':	{'posting'},
'postpone':	{'postponed','postpones'},
'postponed':	{'postpone','postpones'},
'postpones':	{'postpone','postponed'},
'posts':	{'costs','hosts','pests','poets','ports','poses','post','pots'},
'posture':	{'pasture','postures'},
'postures':	{'pastures','posture'},
'pot':	{'bot','cot','dot','got','hot','lot','mot','not','pat','pct','pet','pit','plot','po','pod','poe','poet','poi','pol','pom','poo','pop','port','post','pots','pow','pox','pst','pt','put','rot','sot','spot','tot','wot'},
'potable':	{'notable','portable'},
'potent':	{'patent'},
'potential':	{'potentials'},
'potentials':	{'potential'},
'potion':	{'lotion','motion','notion','portion','potions'},
'potions':	{'lotions','motions','notions','portions','potion'},
'pots':	{'bots','cots','dots','lots','pets','pits','plots','pods','poets','pops','ports','posts','pot','puts','rots','spots','tots'},
'potted':	{'dotted','pitted','plotted','ported','posted','potter','rotted','spotted'},
'potter':	{'cotter','hotter','otter','plotter','porter','poster','potted','potters','pottery','putter'},
'potters':	{'plotters','porters','posters','potter','pottery','putters'},
'pottery':	{'lottery','potter','potters'},
'potting':	{'plotting','porting','posting','putting','rotting','spotting'},
'potty':	{'patty','petty','putty'},
'pouch':	{'couch','porch','touch','vouch'},
'pouches':	{'couches','touches'},
'pound':	{'bound','found','hound','mound','pond','pounds','round','sound','wound'},
'pounded':	{'bounded','founded','rounded','sounded','wounded'},
'pounding':	{'bounding','founding','rounding','sounding','wounding'},
'pounds':	{'bounds','hounds','mounds','ponds','pound','rounds','sounds','wounds'},
'pour':	{'four','hour','our','poor','pours','sour','tour','your'},
'poured':	{'soured','toured'},
'pouring':	{'souring','touring'},
'pours':	{'fours','hours','ours','pour','sours','tours','yours'},
'pow':	{'bow','cow','how','low','now','ow','paw','pew','plow','po','pod','poe','poi','pol','pom','poo','pop','pot','pox','row','sow','tow','vow','wow'},
'powder':	{'ponder','powders','powdery','power'},
'powdered':	{'pondered','powered'},
'powders':	{'powder','powdery','powers'},
'powdery':	{'powder','powders'},
'powell':	{'lowell'},
'power':	{'bower','lower','mower','poker','poser','powder','powers','tower'},
'powered':	{'lowered','powdered'},
'powering':	{'lowering','towering'},
'powers':	{'lowers','mowers','powders','power','towers'},
'pox':	{'box','cox','fox','ox','pix','po','pod','poe','poi','pol','pom','poo','pop','pot','pow','px'},
'pr':	{'apr','ar','br','cpr','cr','dr','er','fr','hr','ir','jr','kr','lr','mr','or','p','pa','par','pb','pc','pd','pe','per','ph','pi','pm','po','prc','pre','pro','ps','pt','pu','px','qr','r','sr','ur','yr','zr'},
'practice':	{'practiced','practices','practise'},
'practiced':	{'practice','practices','practised'},
'practices':	{'practice','practiced','practises'},
'practicing':	{'practising'},
'practise':	{'practice','practised','practises'},
'practised':	{'practiced','practise','practises'},
'practises':	{'practices','practise','practised'},
'practising':	{'practicing'},
'practitioner':	{'practitioners'},
'practitioners':	{'practitioner'},
'prague':	{'plague'},
'prairie':	{'prairies'},
'prairies':	{'prairie'},
'praise':	{'praised','praises','raise'},
'praised':	{'praise','praises','raised'},
'praises':	{'praise','praised','raises'},
'praising':	{'raising'},
'prank':	{'crank','drank','frank','plank','rank'},
'pray':	{'bray','fray','gray','pay','play','prays','prey','ray','spray','tray'},
'prayed':	{'played','prayer','sprayed'},
'prayer':	{'payer','player','prayed','prayers'},
'prayers':	{'payers','players','prayer'},
'praying':	{'paying','playing','spraying'},
'prays':	{'grays','pays','plays','pray','rays','sprays','trays'},
'prc':	{'arc','nrc','pac','pc','pfc','pic','pr','pre','pro','pvc'},
'pre':	{'are','ere','ire','ore','pe','pee','pie','poe','pore','pr','prc','pref','prep','pres','prey','pro','pure'},
'preach':	{'breach','peach','reach'},
'preached':	{'breached','preacher','preaches','reached'},
'preacher':	{'preached','preachers','preaches'},
'preachers':	{'preacher','preaches'},
'preaches':	{'breaches','peaches','preached','preacher','preachers','reaches'},
'preaching':	{'reaching'},
'precaution':	{'precautions'},
'precautions':	{'precaution'},
'precede':	{'preceded','precedes'},
'preceded':	{'precede','precedes'},
'precedent':	{'precedents'},
'precedents':	{'precedent'},
'precedes':	{'precede','preceded'},
'precinct':	{'precincts'},
'precincts':	{'precinct'},
'precious':	{'previous'},
'precipitate':	{'precipitated'},
'precipitated':	{'precipitate'},
'precise':	{'premise'},
'preclude':	{'precluded','precludes','prelude'},
'precluded':	{'preclude','precludes'},
'precludes':	{'preclude','precluded'},
'precondition':	{'preconditions'},
'preconditions':	{'precondition'},
'precursor':	{'precursors'},
'precursors':	{'precursor'},
'predator':	{'predators','predatory'},
'predators':	{'predator','predatory'},
'predatory':	{'predator','predators'},
'predecessor':	{'predecessors'},
'predecessors':	{'predecessor'},
'predefined':	{'redefined'},
'predicate':	{'predicated','predicates'},
'predicated':	{'predicate','predicates','predicted'},
'predicates':	{'predicate','predicated'},
'predict':	{'predicts'},
'predictable':	{'predictably'},
'predictably':	{'predictable'},
'predicted':	{'predicated'},
'prediction':	{'predictions'},
'predictions':	{'prediction'},
'predictor':	{'predictors'},
'predictors':	{'predictor'},
'predicts':	{'predict'},
'predominate':	{'predominated','predominates'},
'predominated':	{'predominate','predominates'},
'predominates':	{'predominate','predominated'},
'pref':	{'pre','prep','pres','prey','prof','ref'},
'prefer':	{'prefers','refer'},
'preferable':	{'preferably'},
'preferably':	{'preferable'},
'preference':	{'preferences','reference'},
'preferences':	{'preference','references'},
'preferential':	{'referential'},
'preferred':	{'referred'},
'preferring':	{'referring'},
'prefers':	{'prefer','refers'},
'prefixed':	{'prefixes'},
'prefixes':	{'prefixed'},
'prejudice':	{'prejudiced','prejudices'},
'prejudiced':	{'prejudice','prejudices'},
'prejudices':	{'prejudice','prejudiced'},
'prelude':	{'preclude'},
'premier':	{'premiere'},
'premiere':	{'premier','premiered','premieres'},
'premiered':	{'premiere','premieres'},
'premieres':	{'premiere','premiered'},
'premise':	{'precise','premises','promise'},
'premises':	{'premise','promises'},
'premium':	{'premiums'},
'premiums':	{'premium'},
'prep':	{'grep','peep','pep','pre','pref','preps','pres','prey','prop','rep'},
'prepaid':	{'repaid'},
'preparation':	{'preparations'},
'preparations':	{'preparation','reparations'},
'prepare':	{'prepared','prepares'},
'prepared':	{'prepare','prepares'},
'prepares':	{'prepare','prepared'},
'prepay':	{'repay'},
'prepayment':	{'repayment'},
'preps':	{'prep','pres','press','props','reps'},
'prerequisite':	{'prerequisites'},
'prerequisites':	{'prerequisite'},
'pres':	{'apres','ares','ores','pies','pores','pre','pref','prep','preps','press','prey','pros','res'},
'preschool':	{'preschools'},
'preschools':	{'preschool'},
'prescribe':	{'prescribed','prescribes'},
'prescribed':	{'prescribe','prescribes'},
'prescribes':	{'prescribe','prescribed'},
'prescription':	{'prescriptions'},
'prescriptions':	{'prescription'},
'presence':	{'pretence'},
'present':	{'presents','preset','prevent','resent'},
'presentation':	{'presentations'},
'presentations':	{'presentation'},
'presented':	{'presenter','prevented'},
'presenter':	{'presented','presenters'},
'presenters':	{'presenter'},
'presenting':	{'preventing'},
'presents':	{'present','presets','prevents'},
'preservation':	{'reservation'},
'preservative':	{'preservatives'},
'preservatives':	{'preservative'},
'preserve':	{'preserved','preserves','reserve'},
'preserved':	{'preserve','preserves','reserved'},
'preserves':	{'preserve','preserved','reserves'},
'preserving':	{'reserving'},
'preset':	{'present','presets','reset'},
'presets':	{'presents','preset','resets'},
'preside':	{'presided','reside'},
'presided':	{'preside','resided'},
'presidency':	{'residency'},
'president':	{'presidents','resident'},
'presidential':	{'residential'},
'presidents':	{'president','residents'},
'presiding':	{'residing'},
'press':	{'dress','preps','pres'},
'pressed':	{'dressed','presses'},
'presses':	{'dresses','pressed'},
'pressing':	{'dressing'},
'pressure':	{'pressured','pressures'},
'pressured':	{'pressure','pressures'},
'pressures':	{'pressure','pressured'},
'presume':	{'presumed','presumes','resume'},
'presumed':	{'presume','presumes','resumed'},
'presumes':	{'presume','presumed','resumes'},
'presuming':	{'resuming'},
'presumption':	{'presumptions','resumption'},
'presumptions':	{'presumption'},
'preteen':	{'preteens'},
'preteens':	{'preteen'},
'pretence':	{'presence','pretense'},
'pretend':	{'pretends'},
'pretends':	{'pretend'},
'pretense':	{'pretence'},
'pretty':	{'petty'},
'prevail':	{'prevails'},
'prevails':	{'prevail'},
'prevent':	{'present','prevents'},
'prevented':	{'presented'},
'preventing':	{'presenting'},
'prevents':	{'presents','prevent'},
'preview':	{'previews','review'},
'previews':	{'preview','reviews'},
'previous':	{'precious'},
'prey':	{'frey','grey','pray','pre','pref','prep','pres','trey'},
'price':	{'priced','prices','pricey','prick','pride','prime','prince','prize','rice'},
'priced':	{'price','prices','pricey','primed','prized'},
'prices':	{'price','priced','pricey','prides','primes','princes','prizes'},
'pricey':	{'price','priced','prices'},
'pricing':	{'priming'},
'prick':	{'brick','pick','price','rick','trick'},
'pride':	{'bride','price','prides','prime','prize','ride'},
'prides':	{'brides','prices','pride','primes','prizes','rides'},
'priest':	{'driest','priests'},
'priests':	{'priest'},
'primacy':	{'primary','privacy'},
'primary':	{'primacy'},
'primate':	{'primates','private'},
'primates':	{'primate'},
'prime':	{'crime','price','pride','primed','primer','primes','prize'},
'primed':	{'priced','prime','primer','primes','prized'},
'primer':	{'prime','primed','primers','primes'},
'primers':	{'primer','primes'},
'primes':	{'crimes','prices','prides','prime','primed','primer','primers','prizes'},
'priming':	{'pricing'},
'primitive':	{'primitives'},
'primitives':	{'primitive'},
'prince':	{'price','princes'},
'princes':	{'prices','prince','princess'},
'princess':	{'princes'},
'principal':	{'principals'},
'principals':	{'principal'},
'principe':	{'principle'},
'principle':	{'principe','principled','principles'},
'principled':	{'principle','principles'},
'principles':	{'principle','principled'},
'print':	{'paint','pint','point','prints','sprint'},
'printed':	{'painted','pointed','printer'},
'printer':	{'painter','pointer','printed','printers'},
'printers':	{'painters','pointers','printer'},
'printing':	{'painting','pointing'},
'printout':	{'printouts'},
'printouts':	{'printout'},
'prints':	{'paints','pints','points','print'},
'prior':	{'priory'},
'priorities':	{'prioritises','prioritizes'},
'prioritisation':	{'prioritization'},
'prioritise':	{'prioritised','prioritises','prioritize'},
'prioritised':	{'prioritise','prioritises','prioritized'},
'prioritises':	{'priorities','prioritise','prioritised','prioritizes'},
'prioritising':	{'prioritizing'},
'prioritization':	{'prioritisation'},
'prioritize':	{'prioritise','prioritized','prioritizes'},
'prioritized':	{'prioritised','prioritize','prioritizes'},
'prioritizes':	{'priorities','prioritises','prioritize','prioritized'},
'prioritizing':	{'prioritising'},
'priory':	{'prior'},
'prison':	{'poison','prisons'},
'prisoner':	{'prisoners'},
'prisoners':	{'prisoner'},
'prisons':	{'poisons','prison'},
'privacy':	{'primacy'},
'private':	{'primate'},
'privatisation':	{'privatization'},
'privatization':	{'privatisation'},
'privilege':	{'privileged','privileges'},
'privileged':	{'privilege','privileges'},
'privileges':	{'privilege','privileged'},
'prize':	{'price','pride','prime','prized','prizes'},
'prized':	{'priced','primed','prize','prizes'},
'prizes':	{'prices','prides','primes','prize','prized'},
'pro':	{'bro','fro','plo','po','poo','pr','prc','pre','prob','prod','prof','prom','prop','pros','pto'},
'prob':	{'pro','probe','prod','prof','prom','prop','pros','rob'},
'probable':	{'probably'},
'probably':	{'probable'},
'probe':	{'prob','probed','probes','prone','prose','prove','robe'},
'probed':	{'probe','probes','proved'},
'probes':	{'probe','probed','proves','robes'},
'probing':	{'proving'},
'problem':	{'problems'},
'problems':	{'problem'},
'procedure':	{'procedures'},
'procedures':	{'procedure'},
'proceed':	{'proceeds'},
'proceeding':	{'proceedings'},
'proceedings':	{'proceeding'},
'proceeds':	{'proceed'},
'process':	{'profess','prowess'},
'processed':	{'processes','professed'},
'processes':	{'processed'},
'procession':	{'processions','profession'},
'processions':	{'procession','professions'},
'processor':	{'processors','professor'},
'processors':	{'processor','professors'},
'proclaim':	{'proclaims'},
'proclaims':	{'proclaim'},
'procure':	{'procured'},
'procured':	{'procure'},
'prod':	{'pod','pro','prob','prof','prom','prop','pros','proud','rod'},
'produce':	{'produced','producer','produces','product'},
'produced':	{'produce','producer','produces'},
'producer':	{'produce','produced','producers','produces'},
'producers':	{'producer','produces'},
'produces':	{'produce','produced','producer','producers','products'},
'product':	{'produce','products'},
'production':	{'productions'},
'productions':	{'production'},
'products':	{'produces','product'},
'prof':	{'pref','pro','prob','prod','prom','proof','prop','pros'},
'profane':	{'propane'},
'profess':	{'process','prowess'},
'professed':	{'processed'},
'profession':	{'procession','professions'},
'professional':	{'professionals'},
'professionals':	{'professional'},
'professions':	{'processions','profession'},
'professor':	{'processor','professors'},
'professors':	{'processors','professor'},
'profile':	{'profiled','profiles'},
'profiled':	{'profile','profiles','profited'},
'profiles':	{'profile','profiled'},
'profiling':	{'profiting'},
'profit':	{'profits'},
'profitable':	{'profitably'},
'profitably':	{'profitable'},
'profited':	{'profiled'},
'profiting':	{'profiling'},
'profits':	{'profit'},
'program':	{'programs'},
'programed':	{'programmed'},
'programing':	{'programming'},
'programme':	{'programmed','programmer','programmes'},
'programmed':	{'programed','programme','programmer','programmes'},
'programmer':	{'programme','programmed','programmers','programmes'},
'programmers':	{'programmer','programmes'},
'programmes':	{'programme','programmed','programmer','programmers'},
'programming':	{'programing'},
'programs':	{'program'},
'progressed':	{'progresses'},
'progresses':	{'progressed'},
'progressive':	{'progressives'},
'progressives':	{'progressive'},
'prohibit':	{'prohibits'},
'prohibition':	{'prohibitions'},
'prohibitions':	{'prohibition'},
'prohibits':	{'prohibit'},
'project':	{'projects','protect'},
'projected':	{'protected'},
'projectile':	{'projective'},
'projecting':	{'protecting'},
'projection':	{'projections','protection'},
'projections':	{'projection','protections'},
'projective':	{'projectile','protective'},
'projector':	{'projectors','protector'},
'projectors':	{'projector','protectors'},
'projects':	{'project','protects'},
'prom':	{'from','pom','pro','prob','prod','prof','promo','prop','pros','rom'},
'promise':	{'premise','promised','promises'},
'promised':	{'promise','promises'},
'promises':	{'premises','promise','promised'},
'promo':	{'prom','promos','provo'},
'promos':	{'promo'},
'promote':	{'promoted','promoter','promotes'},
'promoted':	{'promote','promoter','promotes','prompted'},
'promoter':	{'promote','promoted','promoters','promotes'},
'promoters':	{'promoter','promotes'},
'promotes':	{'promote','promoted','promoter','promoters'},
'promoting':	{'prompting'},
'promotion':	{'promotions'},
'promotions':	{'promotion'},
'prompt':	{'prompts'},
'prompted':	{'promoted'},
'prompting':	{'promoting'},
'prompts':	{'prompt'},
'promulgate':	{'promulgated'},
'promulgated':	{'promulgate'},
'prone':	{'drone','krone','phone','probe','prong','prose','prove','prune'},
'prong':	{'pong','prone','wrong'},
'pronoun':	{'pronouns'},
'pronounce':	{'pronounced','pronounces'},
'pronounced':	{'pronounce','pronounces'},
'pronounces':	{'pronounce','pronounced'},
'pronouns':	{'pronoun'},
'proof':	{'prof','proofs','roof'},
'proofing':	{'roofing'},
'proofs':	{'proof','roofs'},
'prop':	{'crop','drop','poop','pop','prep','pro','prob','prod','prof','prom','props','pros'},
'propagate':	{'propagated'},
'propagated':	{'propagate'},
'propane':	{'profane'},
'propel':	{'proper'},
'propelled':	{'propeller'},
'propeller':	{'propelled'},
'proper':	{'propel','prosper','roper'},
'properly':	{'property'},
'property':	{'properly'},
'prophet':	{'prophets'},
'prophets':	{'prophet'},
'proponent':	{'proponents'},
'proponents':	{'proponent'},
'proportion':	{'proportions'},
'proportions':	{'proportion'},
'proposal':	{'proposals'},
'proposals':	{'proposal'},
'propose':	{'proposed','proposes'},
'proposed':	{'propose','proposes'},
'proposes':	{'propose','proposed'},
'proposition':	{'propositions'},
'propositions':	{'proposition'},
'proprietor':	{'proprietors'},
'proprietors':	{'proprietor'},
'props':	{'crops','drops','pops','preps','prop','pros'},
'pros':	{'bros','eros','pres','pro','prob','prod','prof','prom','prop','props','prose'},
'prose':	{'arose','pose','probe','prone','pros','prove','rose'},
'prosecute':	{'prosecuted'},
'prosecuted':	{'prosecute'},
'prosecution':	{'prosecutions'},
'prosecutions':	{'prosecution'},
'prosecutor':	{'prosecutors'},
'prosecutors':	{'prosecutor'},
'prospect':	{'prospects'},
'prospects':	{'prospect','prospectus'},
'prospectus':	{'prospects'},
'prosper':	{'proper'},
'prostitute':	{'prostitutes'},
'prostitutes':	{'prostitute'},
'protagonist':	{'protagonists'},
'protagonists':	{'protagonist'},
'protect':	{'project','protects','protest'},
'protected':	{'projected','protested'},
'protecting':	{'projecting','protesting'},
'protection':	{'projection','protections'},
'protections':	{'projections','protection'},
'protective':	{'projective'},
'protector':	{'projector','protectors'},
'protectors':	{'projectors','protector'},
'protects':	{'projects','protect','protests'},
'protein':	{'proteins'},
'proteins':	{'protein'},
'protest':	{'protect','protests'},
'protested':	{'protected'},
'protesting':	{'protecting'},
'protests':	{'protects','protest'},
'protocol':	{'protocols'},
'protocols':	{'protocol'},
'proton':	{'photon','protons'},
'protons':	{'photons','proton'},
'prototype':	{'prototypes'},
'prototypes':	{'prototype'},
'proud':	{'prod'},
'prove':	{'drove','grove','probe','prone','prose','proved','proven','proves','provo','rove','trove'},
'proved':	{'probed','prove','proven','proves'},
'proven':	{'prove','proved','proves'},
'provence':	{'province'},
'proverb':	{'proverbs'},
'proverbs':	{'proverb'},
'proves':	{'groves','probes','prove','proved','proven'},
'provide':	{'provided','provider','provides'},
'provided':	{'provide','provider','provides'},
'provider':	{'provide','provided','providers','provides'},
'providers':	{'provider','provides'},
'provides':	{'provide','provided','provider','providers'},
'province':	{'provence','provinces'},
'provinces':	{'province'},
'proving':	{'probing','roving'},
'provision':	{'provisions'},
'provisions':	{'provision'},
'provo':	{'promo','prove'},
'provoke':	{'provoked'},
'provoked':	{'provoke'},
'prowess':	{'process','profess'},
'prune':	{'prone','rune'},
'prussia':	{'prussian','russia'},
'prussian':	{'prussia','russian'},
'ps':	{'as','bps','bs','cps','cs','es','fps','hs','is','ks','ms','ops','os','p','pa','pas','pb','pbs','pc','pd','pe','ph','pi','pm','pms','po','pr','psi','pst','pt','pu','pus','px','ss','ts','us','vs'},
'psalm':	{'palm','psalms'},
'psalms':	{'palms','psalm'},
'psi':	{'pei','phi','pi','poi','posi','ps','pst','si'},
'pst':	{'cst','est','mst','past','pat','pct','pest','pet','pit','post','pot','ps','psi','pt','put'},
'psych':	{'psyche','psycho'},
'psyche':	{'psych','psycho'},
'psychiatrist':	{'psychiatrists'},
'psychiatrists':	{'psychiatrist'},
'psychic':	{'psychics'},
'psychics':	{'psychic'},
'psycho':	{'psych','psyche'},
'psychologist':	{'psychologists'},
'psychologists':	{'psychologist'},
'pt':	{'apt','at','ct','et','ft','ht','it','kt','mt','nt','opt','p','pa','pat','pb','pc','pct','pd','pe','pet','ph','pi','pit','pm','po','pot','pr','ps','pst','pto','pu','put','px','t','ut','vt'},
'pto':	{'plo','po','poo','pro','pt','to'},
'pu':	{'au','cpu','cu','du','eu','gu','ju','lu','mu','nu','p','pa','pb','pc','pd','pe','ph','pi','piu','pm','po','pr','ps','pt','pub','pud','pug','pun','pup','pus','put','px','ru','su','u','wu','zu'},
'pub':	{'cub','dub','hub','pb','pu','pubs','pud','pug','pun','pup','pus','put','rub','sub','tub'},
'pubic':	{'cubic','public'},
'public':	{'pubic'},
'publication':	{'publications'},
'publications':	{'publication'},
'publicize':	{'publicized'},
'publicized':	{'publicize'},
'published':	{'publisher','publishes'},
'publisher':	{'published','publishers','publishes'},
'publishers':	{'publisher','publishes'},
'publishes':	{'published','publisher','publishers'},
'pubs':	{'hubs','pbs','pub','pups','pus','puts','rubs','subs','tubs'},
'puck':	{'buck','duck','fuck','huck','luck','muck','pack','peck','pick','pluck','punk','suck','tuck'},
'pud':	{'bud','hud','mud','pad','pd','phd','pod','pu','pub','pug','pun','pup','pus','put'},
'pudding':	{'budding','padding'},
'puddle':	{'paddle'},
'puebla':	{'pueblo'},
'pueblo':	{'puebla'},
'puff':	{'buff','cuff','duff','huff','puffs','puffy','ruff'},
'puffin':	{'muffin'},
'puffs':	{'buffs','cuffs','puff','puffy'},
'puffy':	{'puff','puffs'},
'pug':	{'aug','bug','dug','hug','jug','lug','mug','peg','pig','plug','pu','pub','pud','pun','pup','pus','put','rug','tug'},
'puke':	{'duke','luke','nuke','pike','poke','pure'},
'pula':	{'hula','pull','pulp','puma'},
'pull':	{'bull','dull','full','gull','hull','mull','null','pall','pill','poll','pula','pulls','pulp'},
'pulled':	{'culled','polled','pulley','pulsed'},
'pulley':	{'pulled'},
'pulling':	{'polling'},
'pulls':	{'pills','polls','pull'},
'pulp':	{'pula','pull','pump','pup'},
'pulse':	{'pulsed','pulses','purse'},
'pulsed':	{'pulled','pulse','pulses'},
'pulses':	{'pulse','pulsed','purses'},
'puma':	{'pula','pump','yuma'},
'pump':	{'bump','dump','hump','jump','lump','pimp','plump','pulp','puma','pumps','pup','sump'},
'pumped':	{'bumped','dumped','jumped'},
'pumping':	{'bumping','dumping','humping','jumping'},
'pumpkin':	{'pumpkins'},
'pumpkins':	{'pumpkin'},
'pumps':	{'bumps','dumps','humps','jumps','lumps','pump','pups'},
'pun':	{'bun','dun','fun','gun','hun','nun','pan','pen','pin','pu','pub','pud','pug','punk','punt','puny','pup','pus','put','run','spun','sun','un'},
'punch':	{'bunch','lunch','munch','pinch'},
'punched':	{'pinched','punches'},
'punches':	{'bunches','lunches','pinches','punched'},
'punching':	{'pinching'},
'puncture':	{'juncture'},
'pundit':	{'pundits'},
'pundits':	{'pundit'},
'punished':	{'punishes'},
'punishes':	{'punished'},
'punishment':	{'punishments'},
'punishments':	{'punishment'},
'punjab':	{'punjabi'},
'punjabi':	{'punjab'},
'punk':	{'bunk','dunk','funk','hunk','junk','pink','puck','pun','punks','punt','puny','sunk'},
'punks':	{'hunks','punk'},
'punt':	{'aunt','cunt','hunt','pant','pint','pun','punk','puny','put','putt'},
'puny':	{'pony','pun','punk','punt'},
'pup':	{'cup','pap','pcp','pep','pip','pop','pu','pub','pud','pug','pulp','pump','pun','pups','pus','put','sup','up'},
'pupil':	{'pupils'},
'pupils':	{'pupil'},
'puppet':	{'puppets'},
'puppets':	{'puppet'},
'puppy':	{'poppy'},
'pups':	{'cups','pops','pubs','pumps','pup','pus','puts'},
'purchase':	{'purchased','purchaser','purchases'},
'purchased':	{'purchase','purchaser','purchases'},
'purchaser':	{'purchase','purchased','purchasers','purchases'},
'purchasers':	{'purchaser','purchases'},
'purchases':	{'purchase','purchased','purchaser','purchasers'},
'pure':	{'cure','lure','pore','pre','puke','purer','purge','purse','sure'},
'purely':	{'surely'},
'pureness':	{'sureness'},
'purer':	{'pure','surer'},
'purest':	{'surest'},
'purge':	{'pure','purged','purse','surge','urge'},
'purged':	{'purge','surged','urged'},
'purified':	{'purifier'},
'purifier':	{'purified','purifiers'},
'purifiers':	{'purifier'},
'purify':	{'purity'},
'purity':	{'parity','purify'},
'purport':	{'purports'},
'purports':	{'purport'},
'purpose':	{'purposes'},
'purposes':	{'purpose'},
'purse':	{'curse','nurse','parse','pulse','pure','purge','purses','pursue'},
'purses':	{'curses','nurses','pulses','purse','pursues'},
'pursue':	{'purse','pursued','pursues'},
'pursued':	{'pursue','pursues'},
'pursues':	{'purses','pursue','pursued'},
'pursuit':	{'pursuits'},
'pursuits':	{'pursuit'},
'pus':	{'bus','mus','opus','pas','pbs','plus','pms','ps','pu','pub','pubs','pud','pug','pun','pup','pups','push','put','puts','us'},
'push':	{'bush','hush','lush','plush','posh','pus','rush'},
'pushed':	{'pushes','rushed'},
'pushes':	{'bushes','pushed','rushes'},
'pushing':	{'gushing','rushing'},
'put':	{'but','cut','gut','hut','nut','out','pat','pct','pet','pit','pot','pst','pt','pu','pub','pud','pug','pun','punt','pup','pus','puts','putt','rut','tut','ut'},
'puts':	{'cuts','guts','huts','nuts','outs','pets','pits','pots','pubs','pups','pus','put','putt'},
'putt':	{'butt','mutt','pitt','punt','put','puts','putty'},
'putter':	{'butter','cutter','gutter','potter','putters','utter'},
'putters':	{'butters','cutters','gutters','potters','putter'},
'putting':	{'cutting','potting'},
'putty':	{'nutty','patty','petty','potty','putt'},
'puzzle':	{'muzzle','puzzled','puzzles'},
'puzzled':	{'puzzle','puzzles'},
'puzzles':	{'puzzle','puzzled'},
'pvc':	{'pac','pc','pfc','pic','prc'},
'px':	{'ax','ex','ix','ox','p','pa','pb','pc','pd','pe','ph','pi','pix','pm','po','pox','pr','ps','pt','pu','tx','x','xx'},
'pyle':	{'pale','pile','pole'},
'pyramid':	{'pyramids'},
'pyramids':	{'pyramid'},
'q':	{'a','b','c','d','e','f','g','h','hq','i','iq','j','k','l','o','p','qi','qr','r','t','u','v','w','x','y','z'},
'qed':	{'bed','ed','fed','led','med','red','ted','wed','zed'},
'qi':	{'ai','bi','ci','di','gi','hi','i','ii','ji','ki','li','mi','ni','pi','q','qin','qr','ri','si','ti','vi','wi','xi','yi'},
'qin':	{'bin','din','fin','gin','in','kin','lin','min','pin','qi','qing','sin','tin','win','yin'},
'qing':	{'ding','king','ling','ming','ning','ping','qin','ring','sing','ting','wing','ying'},
'qr':	{'ar','br','cr','dr','er','fr','hr','ir','jr','kr','lr','mr','or','pr','q','qi','r','sr','ur','yr','zr'},
'qua':	{'aqua','hua','quad','quay','que'},
'quad':	{'qua','quads','quay','quid','squad'},
'quads':	{'quad','squads'},
'quake':	{'quaker'},
'quaker':	{'quake','quakers'},
'quakers':	{'quaker'},
'qualification':	{'qualifications'},
'qualifications':	{'qualification'},
'qualified':	{'qualifier','qualifies'},
'qualifier':	{'qualified','qualifiers','qualifies'},
'qualifiers':	{'qualifier','qualifies'},
'qualifies':	{'qualified','qualifier','qualifiers','qualities'},
'qualify':	{'quality'},
'qualities':	{'qualifies'},
'quality':	{'duality','equality','qualify'},
'quantify':	{'quantity'},
'quantity':	{'quantify'},
'quark':	{'quarks','quart'},
'quarks':	{'quark','quarts','quirks'},
'quarrel':	{'quarrels'},
'quarreled':	{'quarrelled'},
'quarreling':	{'quarrelling'},
'quarrelled':	{'quarreled'},
'quarrelling':	{'quarreling'},
'quarrels':	{'quarrel'},
'quart':	{'quark','quarts','quartz'},
'quarter':	{'quarters','quartet'},
'quarters':	{'quarter'},
'quartet':	{'quarter'},
'quarts':	{'quarks','quart','quartz'},
'quartz':	{'quart','quarts'},
'quay':	{'qua','quad'},
'que':	{'cue','due','hue','qua','rue','sue'},
'queen':	{'queens','queer'},
'queens':	{'queen'},
'queer':	{'queen'},
'queried':	{'queries'},
'queries':	{'queried'},
'quest':	{'guest','quests'},
'question':	{'questions'},
'questionnaire':	{'questionnaires'},
'questionnaires':	{'questionnaire'},
'questions':	{'question'},
'quests':	{'guests','quest'},
'queue':	{'queued'},
'queued':	{'queue'},
'quicken':	{'quicker'},
'quicker':	{'quicken'},
'quid':	{'quad','quit','quiz','squid'},
'quiet':	{'quilt','quit'},
'quill':	{'quilt'},
'quilt':	{'built','guilt','quiet','quill','quilts','quit'},
'quilting':	{'quitting'},
'quilts':	{'quilt','quits'},
'quirks':	{'quarks','quirky'},
'quirky':	{'quirks'},
'quit':	{'quid','quiet','quilt','quite','quito','quits','quiz','suit'},
'quite':	{'quit','quito','quits','quote','suite'},
'quito':	{'quit','quite','quits'},
'quits':	{'quilts','quit','quite','quito','suits'},
'quitting':	{'quilting'},
'quiz':	{'quid','quit'},
'quota':	{'quotas','quote'},
'quotas':	{'quota','quotes'},
'quotation':	{'quotations'},
'quotations':	{'quotation'},
'quote':	{'quite','quota','quoted','quotes'},
'quoted':	{'quote','quotes'},
'quotes':	{'quotas','quote','quoted'},
'r':	{'a','ar','b','br','c','cr','d','dr','e','er','f','fr','g','h','hr','i','ir','j','jr','k','kr','l','lr','mr','o','or','p','pr','q','qr','ra','rb','rf','rh','ri','rm','rn','ru','rv','sr','t','u','ur','v','w','x','y','yr','z','zr'},
'ra':	{'a','ara','ba','bra','ca','da','ea','era','fa','ga','ha','ia','ira','ka','la','ma','na','nra','pa','r','rad','raf','rag','raj','ram','ran','rap','rat','raw','ray','rb','rf','rh','ri','rm','rn','rna','ru','rv','sa','ta','va','wa','ya','za'},
'rabbi':	{'rabbit'},
'rabbit':	{'rabbi','rabbits'},
'rabbits':	{'rabbit'},
'rabble':	{'babble','rubble'},
'rabid':	{'raid','rapid'},
'rabies':	{'babies'},
'race':	{'ace','brace','face','grace','lace','mace','pace','raced','racer','races','rack','rage','rake','rape','rare','rate','rave','rice','trace'},
'raced':	{'faced','graced','laced','paced','race','racer','races','raked','raped','rated','traced'},
'racer':	{'race','raced','racers','races','rarer','rawer','tracer'},
'racers':	{'racer','races'},
'races':	{'aces','braces','faces','graces','laces','paces','race','raced','racer','racers','racks','rakes','rapes','rates','raves','traces'},
'racial':	{'facial','radial'},
'racine':	{'racing'},
'racing':	{'bracing','facing','gracing','pacing','racine','racking','raging','raking','raping','rating','raving','tracing'},
'racism':	{'racist'},
'racist':	{'racism','rapist'},
'rack':	{'back','crack','hack','jack','lack','mack','pack','race','racks','rank','rick','rock','sack','tack','track'},
'racket':	{'bracket','jacket','packet','rocket'},
'racking':	{'backing','cracking','hacking','jacking','lacking','packing','racing','raking','ranking','rocking','tracking'},
'racks':	{'backs','cracks','hacks','jacks','lacks','packs','races','rack','ranks','rocks','sacks','tracks'},
'rad':	{'ad','bad','brad','cad','dad','fad','grad','had','lad','mad','pad','ra','raf','rag','raid','raj','ram','ran','rand','rap','rat','raw','ray','read','red','rid','road','rod','sad','tad','trad','wad'},
'radar':	{'radars'},
'radars':	{'radar'},
'radial':	{'racial','radical'},
'radiator':	{'radiators'},
'radiators':	{'radiator'},
'radical':	{'radial','radicals'},
'radicals':	{'radical'},
'radii':	{'radio'},
'radio':	{'radii','radios','ratio'},
'radios':	{'radio','radius','ratios'},
'radius':	{'radios'},
'radon':	{'rayon'},
'raf':	{'af','ra','rad','raft','rag','raj','ram','ran','rap','rat','raw','ray','ref','rf'},
'raffle':	{'raffles','waffle'},
'raffles':	{'raffle','waffles'},
'raft':	{'aft','craft','daft','draft','graft','kraft','raf','rant','rat','rift','taft'},
'rafting':	{'crafting','drafting','grafting','ranting','rating'},
'rag':	{'ag','bag','brag','dag','drag','fag','gag','jag','lag','mag','nag','ra','rad','raf','rage','rags','raj','ram','ran','rang','rap','rat','raw','ray','rig','rug','sag','tag'},
'rage':	{'age','cage','gage','page','race','rag','rags','rake','range','rape','rare','rate','rave','sage','wage'},
'ragged':	{'bagged','dragged','gagged','jagged','lagged','ranged','rigged','rugged','tagged'},
'raging':	{'aging','caging','paging','racing','raking','ranging','raping','rating','raving','waging'},
'rags':	{'bags','drags','gags','lags','rag','rage','rats','rays','regs','rigs','rugs','tags'},
'raid':	{'aid','braid','laid','maid','paid','rabid','rad','raids','rail','rain','rand','rapid','reid','rid','said'},
'raided':	{'aided','braided','raider','rained','raised'},
'raider':	{'raided','raiser','rider'},
'raids':	{'aids','maids','raid','rails','rains','rapids','rids'},
'rail':	{'bail','dail','fail','frail','grail','hail','jail','mail','nail','raid','rails','rain','sail','tail','trail'},
'railing':	{'ailing','failing','mailing','nailing','railings','raining','raising','sailing','trailing','wailing'},
'railings':	{'failings','mailings','railing','sailings'},
'railroad':	{'railroads'},
'railroads':	{'railroad'},
'rails':	{'fails','hails','jails','mails','nails','raids','rail','rains','sails','tails','trails'},
'railway':	{'railways'},
'railways':	{'railway'},
'rain':	{'brain','cain','drain','gain','grain','jain','lain','main','pain','raid','rail','rains','rainy','ran','rein','ruin','train','vain'},
'rainbow':	{'rainbows'},
'rainbows':	{'rainbow'},
'raindrop':	{'raindrops'},
'raindrops':	{'raindrop'},
'rained':	{'drained','gained','grained','raided','raised','ruined','trained'},
'raining':	{'draining','gaining','railing','raising','ruining','training'},
'rains':	{'brains','drains','gains','grains','mains','pains','raids','rails','rain','rainy','reins','ruins','trains'},
'rainy':	{'rain','rains'},
'raise':	{'praise','raised','raiser','raises','rise'},
'raised':	{'praised','raided','rained','raise','raiser','raises'},
'raiser':	{'kaiser','raider','raise','raised','raises','riser'},
'raises':	{'praises','raise','raised','raiser','rises'},
'raisin':	{'raising','raisins'},
'raising':	{'praising','railing','raining','raisin','raisins','rising'},
'raisins':	{'raisin','raising'},
'raj':	{'maj','ra','rad','raf','rag','ram','ran','rap','rat','raw','ray'},
'rake':	{'bake','brake','cake','drake','fake','lake','make','race','rage','raked','rakes','rape','rare','rate','rave','sake','take','wake'},
'raked':	{'baked','faked','naked','raced','rake','rakes','ranked','raped','rated'},
'rakes':	{'bakes','brakes','cakes','fakes','lakes','makes','races','rake','raked','rapes','rates','raves','sakes','takes','wakes'},
'raking':	{'baking','braking','making','racing','racking','raging','ranking','raping','rating','raving','taking','waking'},
'raleigh':	{'rayleigh'},
'rallied':	{'allied','rallies','tallied'},
'rallies':	{'allies','rallied'},
'rally':	{'ally','bally','cally','orally','really','sally','tally','wally'},
'ram':	{'am','cam','cram','dam','dram','gram','ham','jam','lam','ra','rad','raf','rag','raj','rama','ramp','ran','rap','rat','raw','ray','rem','rim','rm','roam','rom','rpm','rum','sam','tam','tram','yam'},
'rama':	{'drama','kama','lama','mama','ram','ramp','rana','roma'},
'rambler':	{'ambler','gambler'},
'rambling':	{'gambling','ramblings'},
'ramblings':	{'rambling'},
'rammed':	{'crammed','jammed'},
'ramp':	{'amp','camp','damp','lamp','ram','rama','ramps','rap','rcmp','romp','tramp'},
'ramps':	{'amps','camps','cramps','lamps','ramp'},
'ran':	{'an','ban','bran','can','fan','gran','han','iran','jan','lan','man','nan','pan','ra','rad','raf','rag','rain','raj','ram','rana','rand','rang','rank','rant','rap','rat','raw','ray','rn','ron','run','tan','van','wan'},
'rana':	{'ana','dana','rama','ran','rand','rang','rank','rant','rna'},
'ranch':	{'branch'},
'ranchers':	{'ranches'},
'ranches':	{'branches','ranchers'},
'rand':	{'and','band','brand','grand','hand','land','rad','raid','ran','rana','randy','rang','rank','rant','sand','wand'},
'random':	{'ransom'},
'randomised':	{'randomized'},
'randomized':	{'randomised'},
'randy':	{'brandy','candy','dandy','handy','rand','sandy','tandy'},
'rang':	{'ang','bang','dang','fang','gang','hang','pang','rag','ran','rana','rand','range','rank','rant','ring','rung','sang','tang','yang'},
'range':	{'grange','orange','rage','rang','ranged','ranger','ranges'},
'ranged':	{'banged','hanged','ragged','range','ranger','ranges','ranked','ringed'},
'ranger':	{'anger','danger','granger','hanger','manger','range','ranged','ranges','ringer','sanger'},
'ranges':	{'oranges','range','ranged','ranger'},
'ranging':	{'banging','hanging','raging','ranking','ranting','ringing'},
'rank':	{'bank','crank','drank','frank','hank','prank','rack','ran','rana','rand','rang','ranks','rant','rink','sank','tank','wank','yank'},
'ranked':	{'banked','raked','ranged'},
'rankin':	{'ranking'},
'ranking':	{'banking','racking','raking','ranging','rankin','rankings','ranting'},
'rankings':	{'ranking'},
'ranks':	{'banks','hanks','racks','rank','rants','tanks'},
'ransom':	{'random'},
'rant':	{'ant','brant','cant','grant','kant','pant','raft','ran','rana','rand','rang','rank','rants','rat','rent','want'},
'ranting':	{'granting','rafting','ranging','ranking','rating','renting','wanting'},
'rants':	{'ants','grants','pants','ranks','rant','rats','rents','wants'},
'rap':	{'cap','crap','gap','hap','lap','map','nap','pap','ra','rad','raf','rag','raj','ram','ramp','ran','rape','rat','raw','ray','reap','rep','rip','sap','tap','trap','wrap','yap','zap'},
'rape':	{'ape','cape','grape','race','rage','rake','rap','raped','rapes','rare','rate','rave','ripe','rope','tape'},
'raped':	{'caped','draped','raced','raked','rape','rapes','rapid','rated','taped'},
'rapes':	{'apes','capes','drapes','grapes','races','rakes','rape','raped','rates','raves','ropes','tapes'},
'rapid':	{'rabid','raid','raped','rapids'},
'rapids':	{'raids','rapid'},
'raping':	{'gaping','racing','raging','raking','rating','raving','taping'},
'rapist':	{'racist'},
'rapper':	{'mapper','rappers','ripper','wrapper'},
'rappers':	{'rapper','rippers','wrappers'},
'rapture':	{'capture','rupture'},
'rare':	{'are','bare','care','dare','fare','hare','mare','race','rage','rake','rape','rarer','rate','rave','ware'},
'rarely':	{'barely'},
'rarer':	{'carer','racer','rare','rawer'},
'rarest':	{'rawest'},
'rarity':	{'parity'},
'rascal':	{'pascal'},
'rash':	{'ash','bash','cash','crash','dash','hash','lash','mash','nash','rush','sash','trash','wash'},
'raster':	{'aster','caster','easter','faster','master','roster'},
'rat':	{'at','bat','brat','cat','dat','eat','fat','frat','hat','kat','lat','mat','oat','pat','ra','rad','raf','raft','rag','raj','ram','ran','rant','rap','rate','rats','raw','ray','rot','rut','sat','tat','vat','wat'},
'ratchet':	{'hatchet'},
'rate':	{'ate','crate','date','fate','gate','grate','hate','late','mate','pate','race','rage','rake','rape','rare','rat','rated','rates','rats','rave','rite','tate'},
'rated':	{'dated','fated','gated','grated','hated','mated','raced','raked','raped','rate','rates'},
'rates':	{'crates','dates','fates','gates','hates','mates','oates','races','rakes','rapes','rate','rated','rats','raves','rites'},
'rather':	{'father','gather'},
'ratification':	{'gratification'},
'rating':	{'dating','eating','grating','hating','mating','racing','rafting','raging','raking','ranting','raping','ratings','raving'},
'ratings':	{'rating'},
'ratio':	{'patio','radio','ration','ratios'},
'ration':	{'cation','nation','ratio','rations','ratios'},
'rational':	{'national','rationale'},
'rationale':	{'rational'},
'rationalisation':	{'rationalisations','rationalization'},
'rationalisations':	{'rationalisation','rationalizations'},
'rationalise':	{'rationalised','rationalises','rationalism','rationalize'},
'rationalised':	{'rationalise','rationalises','rationalized'},
'rationalises':	{'rationalise','rationalised','rationalizes'},
'rationalism':	{'nationalism','rationalise'},
'rationality':	{'nationality'},
'rationalization':	{'rationalisation','rationalizations'},
'rationalizations':	{'rationalisations','rationalization'},
'rationalize':	{'rationalise','rationalized','rationalizes'},
'rationalized':	{'rationalised','rationalize','rationalizes'},
'rationalizes':	{'rationalises','rationalize','rationalized'},
'rationally':	{'nationally'},
'rations':	{'cations','nations','ration','ratios'},
'ratios':	{'patios','radios','ratio','ration','rations'},
'rats':	{'bats','cats','eats','fats','hats','lats','mats','oats','rags','rants','rat','rate','rates','rays','rots'},
'rattle':	{'battle','cattle'},
'rattling':	{'battling'},
'rave':	{'ave','brave','cave','crave','fave','gave','grave','have','pave','race','rage','rake','rape','rare','rate','ravel','raven','raves','rove','save','wave'},
'ravel':	{'gravel','navel','rave','raven','raves','revel','travel'},
'raven':	{'craven','haven','maven','rave','ravel','raves'},
'raves':	{'braves','caves','graves','haves','races','rakes','rapes','rates','rave','ravel','raven','saves','waves'},
'raving':	{'braving','caving','craving','having','paving','racing','raging','raking','raping','rating','roving','saving','waving'},
'raw':	{'draw','haw','jaw','law','paw','ra','rad','raf','rag','raj','ram','ran','rap','rat','ray','row','saw'},
'rawer':	{'drawer','racer','rarer'},
'rawest':	{'rarest'},
'ray':	{'bay','bray','cay','day','fay','fray','gay','gray','hay','jay','lay','may','nay','pay','pray','ra','rad','raf','rag','raj','ram','ran','rap','rat','raw','rays','say','tray','way'},
'rayleigh':	{'raleigh'},
'rayon':	{'radon'},
'rays':	{'bays','days','gays','grays','hays','lays','mays','nays','pays','prays','rags','rats','ray','says','trays','ways'},
'razor':	{'razors'},
'razors':	{'razor'},
'rb':	{'ab','b','bb','db','eb','gb','kb','lb','mb','nb','ob','orb','pb','r','ra','rbi','rf','rh','ri','rib','rm','rn','rob','ru','rub','rv','sb','tb','yb'},
'rbi':	{'bi','fbi','obi','rb','ri','roi'},
'rcmp':	{'ramp','romp'},
're-evaluate':	{'re-evaluated','re-evaluates'},
're-evaluated':	{'re-evaluate','re-evaluates'},
're-evaluates':	{'re-evaluate','re-evaluated'},
'reach':	{'beach','breach','each','leach','peach','preach','react','reich','roach','teach'},
'reached':	{'breached','preached','reaches','reacted'},
'reaches':	{'beaches','breaches','peaches','preaches','reached','teaches'},
'reaching':	{'leaching','preaching','reacting','teaching'},
'react':	{'reach','reacts'},
'reacted':	{'reached'},
'reacting':	{'reaching'},
'reaction':	{'reactions'},
'reactions':	{'reaction'},
'reactivate':	{'deactivate'},
'reactor':	{'reactors','realtor','rector'},
'reactors':	{'reactor'},
'reacts':	{'react'},
'read':	{'bead','bread','dead','dread','head','lead','mead','rad','reads','ready','real','reap','rear','red','reed','reid','road','tread'},
'reader':	{'header','leader','readers','reaper','redder','render'},
'readers':	{'headers','leaders','reader','renders'},
'readership':	{'leadership'},
'reading':	{'beading','heading','leading','readings','rearing'},
'readings':	{'headings','reading'},
'readjust':	{'readjusts'},
'readjustment':	{'readjustments'},
'readjustments':	{'readjustment'},
'readjusts':	{'readjust'},
'reads':	{'beads','breads','heads','leads','read','ready','reeds','roads'},
'ready':	{'heady','read','reads'},
'reagent':	{'reagents','regent'},
'reagents':	{'reagent','regents'},
'real':	{'deal','heal','meal','read','realm','reap','rear','reel','regal','renal','rial','seal','teal','veal','zeal'},
'realisation':	{'realisations','realization'},
'realisations':	{'realisation'},
'realise':	{'realised','realises','realism','realist','realize'},
'realised':	{'realise','realises','realized'},
'realises':	{'realise','realised','realizes'},
'realising':	{'realizing'},
'realism':	{'realise','realist'},
'realist':	{'realise','realism'},
'reality':	{'realty'},
'realization':	{'realisation'},
'realize':	{'realise','realized','realizes'},
'realized':	{'realised','realize','realizes'},
'realizes':	{'realises','realize','realized'},
'realizing':	{'realising'},
'really':	{'rally','realty'},
'realm':	{'real','realms'},
'realms':	{'realm'},
'realtor':	{'reactor'},
'realty':	{'reality','really'},
'reap':	{'heap','leap','rap','read','real','rear','recap','rep'},
'reaper':	{'reader'},
'rear':	{'bear','dear','ear','fear','gear','hear','lear','near','pear','read','real','reap','roar','tear','wear','year'},
'reared':	{'eared','feared','geared','roared'},
'rearing':	{'bearing','fearing','gearing','hearing','nearing','reading','roaring','tearing','wearing'},
'rearrange':	{'rearranged'},
'rearranged':	{'rearrange'},
'reason':	{'reasons','season','treason'},
'reasonable':	{'reasonably'},
'reasonably':	{'reasonable'},
'reasoned':	{'seasoned'},
'reasoning':	{'seasoning'},
'reasons':	{'reason','seasons'},
'reassign':	{'reassigns'},
'reassigns':	{'reassign'},
'reassure':	{'reassured'},
'reassured':	{'reassure'},
'rebate':	{'debate','rebates','relate'},
'rebates':	{'debates','rebate','relates'},
'rebel':	{'rebels','reel','repel','revel'},
'rebels':	{'rebel','reels'},
'rebound':	{'rebounds'},
'rebounding':	{'resounding'},
'rebounds':	{'rebound'},
'rebuild':	{'rebuilt'},
'rebuilt':	{'rebuild'},
'rec':	{'dec','ec','eec','red','ref','rem','rep','res','rev','rex','sec'},
'recall':	{'recalls'},
'recalls':	{'recall'},
'recap':	{'reap','recaps'},
'recaps':	{'recap'},
'receipt':	{'receipts'},
'receipts':	{'receipt'},
'receivable':	{'receivables'},
'receivables':	{'receivable'},
'receive':	{'deceive','received','receiver','receives'},
'received':	{'deceived','receive','receiver','receives'},
'receiver':	{'receive','received','receivers','receives'},
'receivers':	{'receiver','receives'},
'receives':	{'deceives','receive','received','receiver','receivers'},
'receiving':	{'deceiving'},
'recent':	{'decent','regent','repent','resent'},
'receptacle':	{'receptacles'},
'receptacles':	{'receptacle'},
'reception':	{'deception','receptions'},
'receptions':	{'reception'},
'receptive':	{'deceptive'},
'receptor':	{'receptors'},
'receptors':	{'receptor'},
'recipe':	{'recipes','recite'},
'recipes':	{'recipe'},
'recipient':	{'recipients'},
'recipients':	{'recipient'},
'recital':	{'rectal'},
'recite':	{'recipe','recited'},
'recited':	{'recite'},
'reckon':	{'recon'},
'reclining':	{'declining'},
'recognise':	{'recognised','recognises','recognize'},
'recognised':	{'recognise','recognises','recognized'},
'recognises':	{'recognise','recognised','recognizes'},
'recognising':	{'recognizing'},
'recognize':	{'recognise','recognized','recognizes'},
'recognized':	{'recognised','recognize','recognizes'},
'recognizes':	{'recognises','recognize','recognized'},
'recognizing':	{'recognising'},
'recollection':	{'recollections'},
'recollections':	{'recollection'},
'recommenced':	{'recommences','recommended'},
'recommences':	{'recommenced'},
'recommencing':	{'recommending'},
'recommend':	{'recommends'},
'recommendation':	{'recommendations'},
'recommendations':	{'recommendation'},
'recommended':	{'recommenced'},
'recommending':	{'recommencing'},
'recommends':	{'recommend'},
'recon':	{'reckon'},
'reconcile':	{'reconciled'},
'reconciled':	{'reconcile'},
'reconstruct':	{'reconstructs'},
'reconstructs':	{'reconstruct'},
'record':	{'records'},
'recorded':	{'recorder'},
'recorder':	{'recorded','recorders','reorder'},
'recorders':	{'recorder'},
'recording':	{'recordings'},
'recordings':	{'recording'},
'records':	{'record'},
'recount':	{'recounts'},
'recounts':	{'recount'},
'recover':	{'recovers','recovery','remover'},
'recovers':	{'recover','recovery'},
'recovery':	{'recover','recovers'},
'recreate':	{'recreated','recreates'},
'recreated':	{'recreate','recreates','retreated'},
'recreates':	{'recreate','recreated'},
'recruit':	{'recruits'},
'recruited':	{'recruiter'},
'recruiter':	{'recruited','recruiters'},
'recruiters':	{'recruiter'},
'recruits':	{'recruit'},
'rectal':	{'recital','rental'},
'rectangle':	{'rectangles'},
'rectangles':	{'rectangle'},
'rector':	{'hector','reactor','sector','vector'},
'recycle':	{'recycled'},
'recycled':	{'recycle'},
'red':	{'bed','bred','cred','ed','fed','led','med','qed','rad','read','rec','redo','reed','ref','reid','rem','rep','res','rev','rex','rid','rod','ted','wed','zed'},
'redden':	{'redder','ridden'},
'redder':	{'reader','redden','render','rudder'},
'redeemed':	{'redeemer'},
'redeemer':	{'redeemed'},
'redefine':	{'redefined','redefines'},
'redefined':	{'predefined','redefine','redefines'},
'redefines':	{'redefine','redefined'},
'redhead':	{'redheads'},
'redheads':	{'redhead'},
'redirect':	{'redirects'},
'redirects':	{'redirect'},
'redistribute':	{'redistributed','redistributes'},
'redistributed':	{'redistribute','redistributes'},
'redistributes':	{'redistribute','redistributed'},
'redness':	{'redress'},
'redo':	{'red','reno'},
'redraft':	{'redrafts'},
'redrafts':	{'redraft'},
'redress':	{'redness','regress'},
'reduce':	{'deduce','reduced','reduces','seduce'},
'reduced':	{'deduced','reduce','reduces','seduced'},
'reduces':	{'deduces','reduce','reduced'},
'reducing':	{'deducing'},
'reduction':	{'deduction','reductions','seduction'},
'reductions':	{'deductions','reduction'},
'reed':	{'breed','creed','deed','feed','freed','greed','heed','need','read','red','reeds','reef','reel','reid','seed','weed'},
'reeds':	{'breeds','deeds','feeds','leeds','needs','reads','reed','reefs','reels','seeds','weeds'},
'reef':	{'beef','reed','reefs','reel','ref'},
'reefs':	{'reeds','reef','reels','refs'},
'reel':	{'eel','feel','heel','keel','peel','real','rebel','reed','reef','reels','repel','revel','riel'},
'reelection':	{'reflection'},
'reeling':	{'feeling','peeling'},
'reels':	{'eels','feels','heels','rebels','reeds','reefs','reel'},
'ref':	{'pref','raf','rec','red','reef','refs','rem','rep','res','rev','rex','rf'},
'refer':	{'defer','prefer','refers'},
'referee':	{'refereed','referees'},
'refereed':	{'referee','referees','referred'},
'referees':	{'referee','refereed'},
'reference':	{'deference','preference','referenced','references','reverence'},
'referenced':	{'reference','references'},
'references':	{'preferences','reference','referenced'},
'referential':	{'preferential'},
'referral':	{'deferral','referrals'},
'referrals':	{'referral'},
'referred':	{'deferred','preferred','refereed'},
'referring':	{'preferring'},
'refers':	{'prefers','refer'},
'refill':	{'refills'},
'refills':	{'refill'},
'refine':	{'define','refined','refines'},
'refined':	{'defined','refine','refines'},
'refinement':	{'refinements'},
'refinements':	{'refinement'},
'refines':	{'defines','refine','refined'},
'refining':	{'defining'},
'reflect':	{'reflects'},
'reflection':	{'deflection','reelection','reflections'},
'reflections':	{'reflection'},
'reflects':	{'reflect'},
'reflex':	{'reflux'},
'reflux':	{'reflex'},
'refocused':	{'refocuses','refocussed'},
'refocuses':	{'refocused','refocusses'},
'refocusing':	{'refocussing'},
'refocussed':	{'refocused','refocusses'},
'refocusses':	{'refocuses','refocussed'},
'refocussing':	{'refocusing'},
'reform':	{'reforms'},
'reformation':	{'deformation'},
'reformed':	{'deformed'},
'reforms':	{'reform'},
'reformulate':	{'reformulated'},
'reformulated':	{'reformulate'},
'reformulation':	{'reformulations'},
'reformulations':	{'reformulation'},
'refreshed':	{'refresher','refreshes'},
'refresher':	{'refreshed','refreshes'},
'refreshes':	{'refreshed','refresher'},
'refreshment':	{'refreshments'},
'refreshments':	{'refreshment'},
'refrigerator':	{'refrigerators'},
'refrigerators':	{'refrigerator'},
'refs':	{'reefs','ref','regs','reps','res'},
'refuge':	{'refugee','refuse','refute'},
'refugee':	{'refuge','refugees'},
'refugees':	{'refugee'},
'refund':	{'refunds'},
'refunds':	{'refund'},
'refusal':	{'refusals'},
'refusals':	{'refusal'},
'refuse':	{'refuge','refused','refuses','refute','reuse'},
'refused':	{'refuse','refuses','reused'},
'refuses':	{'refuse','refused'},
'refute':	{'refuge','refuse'},
'regain':	{'remain','retain'},
'regained':	{'remained','retained'},
'regal':	{'legal','real','renal'},
'regard':	{'regards','retard','reward'},
'regarded':	{'retarded','rewarded'},
'regarding':	{'rewarding'},
'regards':	{'regard','rewards'},
'regenerate':	{'degenerate','regenerated'},
'regenerated':	{'regenerate'},
'regeneration':	{'degeneration'},
'regent':	{'reagent','recent','regents','repent','resent'},
'regents':	{'reagents','regent'},
'regime':	{'regimen','regimes'},
'regimen':	{'regime','regimens','regiment','regimes'},
'regimens':	{'regimen','regiment','regiments','regimes'},
'regiment':	{'regimen','regimens','regiments'},
'regiments':	{'regimens','regiment'},
'regimes':	{'regime','regimen','regimens'},
'regina':	{'retina'},
'region':	{'legion','regions'},
'regions':	{'legions','region'},
'register':	{'registers'},
'registers':	{'register'},
'registrant':	{'registrants'},
'registrants':	{'registrant'},
'registrar':	{'registrars'},
'registrars':	{'registrar'},
'registration':	{'registrations'},
'registrations':	{'registration'},
'regress':	{'egress','redress','regrets'},
'regression':	{'regressions','repression'},
'regressions':	{'regression'},
'regret':	{'regrets'},
'regrets':	{'regress','regret'},
'regs':	{'begs','legs','megs','pegs','rags','refs','reps','res','rigs','rugs'},
'regular':	{'regulars'},
'regulars':	{'regular'},
'regulate':	{'regulated','regulates'},
'regulated':	{'regulate','regulates'},
'regulates':	{'regulate','regulated'},
'regulation':	{'regulations'},
'regulations':	{'regulation'},
'regulator':	{'regulators','regulatory'},
'regulators':	{'regulator','regulatory'},
'regulatory':	{'regulator','regulators'},
'rehabilitate':	{'rehabilitated'},
'rehabilitated':	{'rehabilitate'},
'rehearsal':	{'rehearsals'},
'rehearsals':	{'rehearsal'},
'reich':	{'reach','rich'},
'reid':	{'raid','read','red','reed','rein','reit','rid'},
'reign':	{'reigns','rein','resign'},
'reigned':	{'resigned'},
'reigning':	{'resigning'},
'reigns':	{'reign','reins','resigns'},
'reimburse':	{'reimbursed'},
'reimbursed':	{'reimburse'},
'reimbursement':	{'reimbursements'},
'reimbursements':	{'reimbursement'},
'rein':	{'rain','reid','reign','reins','reit','resin','ruin','vein'},
'reinforce':	{'reinforced','reinforces'},
'reinforced':	{'reinforce','reinforces'},
'reinforcement':	{'reinforcements'},
'reinforcements':	{'reinforcement'},
'reinforces':	{'reinforce','reinforced'},
'reins':	{'rains','reigns','rein','resins','ruins','veins'},
'reinstate':	{'reinstated'},
'reinstated':	{'reinstate'},
'reinterpret':	{'reinterprets'},
'reinterpretation':	{'reinterpretations'},
'reinterpretations':	{'reinterpretation'},
'reinterprets':	{'reinterpret'},
'reinvent':	{'reinvest'},
'reinventing':	{'reinvesting'},
'reinvest':	{'reinvent','reinvests'},
'reinvesting':	{'reinventing'},
'reinvests':	{'reinvest'},
'reissue':	{'reissued','reissues'},
'reissued':	{'reissue','reissues'},
'reissues':	{'reissue','reissued'},
'reit':	{'reid','rein','remit','rent','rest'},
'reiterate':	{'reiterated'},
'reiterated':	{'reiterate'},
'reject':	{'eject','rejects'},
'rejected':	{'ejected'},
'rejection':	{'ejection','rejections','resection'},
'rejections':	{'rejection'},
'rejects':	{'reject'},
'rejoice':	{'rejoiced','rejoices'},
'rejoiced':	{'rejoice','rejoices'},
'rejoices':	{'rejoice','rejoiced'},
'relate':	{'rebate','related','relates'},
'related':	{'belated','relate','relates','relaxed','relayed'},
'relates':	{'rebates','relate','related','relaxes'},
'relating':	{'relaxing','relaying'},
'relation':	{'relations'},
'relations':	{'relation'},
'relationship':	{'relationships'},
'relationships':	{'relationship'},
'relative':	{'relatives'},
'relatives':	{'relative'},
'relax':	{'relay'},
'relaxed':	{'related','relaxes','relayed'},
'relaxes':	{'relates','relaxed'},
'relaxing':	{'relating','relaying'},
'relay':	{'delay','relax','relays','rely','repay','replay'},
'relayed':	{'delayed','related','relaxed','replayed'},
'relaying':	{'delaying','relating','relaxing','relying','replaying'},
'relays':	{'delays','relay','replays'},
'release':	{'released','releases'},
'released':	{'release','releases'},
'releases':	{'release','released'},
'relegated':	{'delegated'},
'relevance':	{'relevancy'},
'relevancy':	{'relevance'},
'reliable':	{'reliably'},
'reliably':	{'reliable'},
'relic':	{'relics'},
'relics':	{'relic','relies'},
'relied':	{'relief','relies','replied'},
'relief':	{'belief','relied','relies'},
'relies':	{'relics','relied','relief','replies'},
'relieve':	{'believe','relieved','reliever','relieves','relive'},
'relieved':	{'believed','relieve','reliever','relieves'},
'reliever':	{'believer','relieve','relieved','relieves'},
'relieves':	{'believes','relieve','relieved','reliever'},
'relieving':	{'believing'},
'religion':	{'religions'},
'religions':	{'religion','religious'},
'religious':	{'religions'},
'relive':	{'relieve','revive'},
'relocate':	{'relocated','relocates'},
'relocated':	{'relocate','relocates'},
'relocates':	{'relocate','relocated'},
'relocation':	{'revocation'},
'rely':	{'relay','reply'},
'relying':	{'relaying','replying'},
'rem':	{'em','fem','gem','hem','ram','rec','red','ref','rep','res','rev','rex','rim','rm','rom','rpm','rum'},
'remain':	{'regain','remains','retain'},
'remainder':	{'remainders','reminder'},
'remainders':	{'remainder','reminders'},
'remained':	{'regained','retained'},
'remaining':	{'retaining'},
'remains':	{'remain','retains'},
'remand':	{'demand','remind'},
'remanded':	{'demanded','reminded'},
'remark':	{'remarks'},
'remarkable':	{'remarkably'},
'remarkably':	{'remarkable'},
'remarks':	{'remark'},
'remedied':	{'remedies'},
'remedies':	{'remedied'},
'remember':	{'remembers'},
'remembers':	{'remember'},
'remind':	{'remand','reminds','rewind'},
'reminded':	{'remanded','reminder'},
'reminder':	{'remainder','reminded','reminders'},
'reminders':	{'remainders','reminder'},
'reminds':	{'remind'},
'remission':	{'emission'},
'remit':	{'emit','reit','remix'},
'remittance':	{'remittances'},
'remittances':	{'remittance'},
'remitted':	{'emitted'},
'remix':	{'remit'},
'remnant':	{'remnants'},
'remnants':	{'remnant'},
'remote':	{'remotes','remove'},
'remotes':	{'remote','removes'},
'removal':	{'removals'},
'removals':	{'removal'},
'remove':	{'remote','removed','remover','removes'},
'removed':	{'remove','remover','removes'},
'remover':	{'recover','remove','removed','removes'},
'removes':	{'remotes','remove','removed','remover'},
'renal':	{'penal','real','regal','rental'},
'rename':	{'renamed'},
'renamed':	{'rename'},
'render':	{'bender','fender','gender','lender','reader','redder','renders','renter','sender','tender'},
'rendered':	{'tendered'},
'rendering':	{'tendering'},
'renders':	{'fenders','genders','lenders','readers','render','renters','senders','tenders'},
'renew':	{'renews'},
'renewal':	{'renewals'},
'renewals':	{'renewal'},
'renews':	{'renew'},
'reno':	{'keno','redo','rent'},
'renounce':	{'denounce'},
'renovate':	{'renovated'},
'renovated':	{'renovate'},
'renovation':	{'renovations'},
'renovations':	{'renovation'},
'rent':	{'bent','brent','cent','dent','gent','kent','lent','rant','reit','reno','rents','rest','sent','tent','trent','vent','went'},
'rental':	{'dental','mental','rectal','renal','rentals'},
'rentals':	{'rental'},
'rented':	{'renter','rested','tented','vented'},
'renter':	{'center','enter','render','rented','renters'},
'renters':	{'centers','enters','renders','renter'},
'renting':	{'ranting','resting','venting'},
'rents':	{'cents','dents','gents','rants','rent','rests','tents','vents'},
'reoccur':	{'reoccurs'},
'reoccurs':	{'reoccur'},
'reorder':	{'recorder'},
'rep':	{'grep','hep','pep','prep','rap','reap','rec','red','ref','rem','reps','res','rev','rex','rip','sep'},
'repaid':	{'prepaid','repair'},
'repaint':	{'reprint'},
'repair':	{'repaid','repairs'},
'repairs':	{'repair'},
'reparations':	{'preparations','separations'},
'repay':	{'prepay','relay','replay','reply'},
'repayment':	{'prepayment','repayments'},
'repayments':	{'repayment'},
'repeal':	{'repeat','repel','reseal','reveal'},
'repealed':	{'repeated','revealed'},
'repealing':	{'repeating','revealing'},
'repeat':	{'repeal','repeats','repent'},
'repeated':	{'repealed','repeater'},
'repeater':	{'repeated'},
'repeating':	{'repealing'},
'repeats':	{'repeat'},
'repel':	{'rebel','reel','repeal','revel'},
'repent':	{'recent','regent','repeat','resent'},
'repetition':	{'repetitions'},
'repetitions':	{'repetition'},
'replace':	{'replaced','replaces'},
'replaced':	{'replace','replaces','replayed'},
'replacement':	{'replacements'},
'replacements':	{'replacement'},
'replaces':	{'replace','replaced'},
'replacing':	{'replaying'},
'replay':	{'relay','repay','replays','reply'},
'replayed':	{'relayed','replaced'},
'replaying':	{'relaying','replacing','replying'},
'replays':	{'relays','replay'},
'replica':	{'replicas'},
'replicas':	{'replica'},
'replicate':	{'replicated','replicates'},
'replicated':	{'replicate','replicates'},
'replicates':	{'replicate','replicated'},
'replied':	{'relied','replies'},
'replies':	{'relies','replied'},
'reply':	{'rely','repay','replay'},
'replying':	{'relying','replaying'},
'report':	{'reports','resort'},
'reported':	{'deported','reporter','resorted'},
'reporter':	{'reported','reporters'},
'reporters':	{'reporter'},
'reporting':	{'resorting'},
'reports':	{'report','resorts'},
'repository':	{'depository'},
'represent':	{'represents'},
'representation':	{'representations'},
'representations':	{'representation'},
'representative':	{'representatives'},
'representatives':	{'representative'},
'represents':	{'represent'},
'repressed':	{'depressed'},
'repression':	{'depression','regression'},
'repressive':	{'depressive'},
'reprint':	{'repaint','reprints'},
'reprints':	{'reprint'},
'reproduce':	{'reproduced','reproduces'},
'reproduced':	{'reproduce','reproduces'},
'reproduces':	{'reproduce','reproduced'},
'reproduction':	{'reproductions'},
'reproductions':	{'reproduction'},
'reps':	{'preps','refs','regs','rep','res','rips'},
'reptile':	{'reptiles'},
'reptiles':	{'reptile'},
'republic':	{'republics'},
'republican':	{'republicans'},
'republicans':	{'republican'},
'republics':	{'republic'},
'reputation':	{'reputations'},
'reputations':	{'reputation'},
'request':	{'bequest','requests'},
'requested':	{'requester'},
'requester':	{'requested'},
'requests':	{'request'},
'require':	{'required','requires'},
'required':	{'require','requires'},
'requirement':	{'requirements'},
'requirements':	{'requirement'},
'requires':	{'require','required'},
'requisite':	{'requisites'},
'requisites':	{'requisite'},
'res':	{'ares','des','es','les','mes','ores','pres','rec','red','ref','refs','regs','rem','rep','reps','rest','rev','rex','yes'},
'reschedule':	{'rescheduled','reschedules'},
'rescheduled':	{'reschedule','reschedules'},
'reschedules':	{'reschedule','rescheduled'},
'rescue':	{'rescued','rescues'},
'rescued':	{'rescue','rescues'},
'rescues':	{'rescue','rescued'},
'reseal':	{'repeal','resell','reveal'},
'researched':	{'researcher','researches'},
'researcher':	{'researched','researchers','researches'},
'researchers':	{'researcher','researches'},
'researches':	{'researched','researcher','researchers'},
'resection':	{'rejection'},
'resell':	{'reseal','retell'},
'reseller':	{'resellers'},
'resellers':	{'reseller'},
'reselling':	{'retelling'},
'resemble':	{'resembled','resembles'},
'resembled':	{'resemble','resembles'},
'resembles':	{'resemble','resembled'},
'resent':	{'present','recent','regent','repent','reset'},
'reservation':	{'preservation','reservations'},
'reservations':	{'reservation'},
'reserve':	{'deserve','preserve','reserved','reserves'},
'reserved':	{'deserved','preserved','reserve','reserves'},
'reserves':	{'deserves','preserves','reserve','reserved'},
'reserving':	{'deserving','preserving'},
'reservoir':	{'reservoirs'},
'reservoirs':	{'reservoir'},
'reset':	{'beset','preset','resent','resets','rest'},
'resets':	{'presets','reset','rests'},
'reside':	{'beside','preside','resided','resides','residue'},
'resided':	{'presided','reside','resides'},
'residence':	{'residences','residency'},
'residences':	{'residence'},
'residency':	{'presidency','residence'},
'resident':	{'president','residents'},
'residential':	{'presidential'},
'residents':	{'presidents','resident'},
'resides':	{'besides','reside','resided','residues'},
'residing':	{'presiding','resizing'},
'residual':	{'residuals'},
'residuals':	{'residual'},
'residue':	{'reside','residues'},
'residues':	{'resides','residue'},
'resign':	{'design','reign','resigns','resin'},
'resignation':	{'designation','resignations'},
'resignations':	{'designations','resignation'},
'resigned':	{'designed','reigned'},
'resigning':	{'designing','reigning'},
'resigns':	{'designs','reigns','resign','resins'},
'resin':	{'rein','resign','resins'},
'resins':	{'reins','resigns','resin'},
'resist':	{'desist','resists'},
'resistor':	{'resistors'},
'resistors':	{'resistor'},
'resists':	{'resist'},
'resizing':	{'residing'},
'resolution':	{'resolutions','revolution'},
'resolutions':	{'resolution','revolutions'},
'resolve':	{'resolved','resolver','resolves','revolve'},
'resolved':	{'resolve','resolver','resolves'},
'resolver':	{'resolve','resolved','resolves','revolver'},
'resolves':	{'resolve','resolved','resolver','revolves'},
'resolving':	{'revolving'},
'resonance':	{'resonances'},
'resonances':	{'resonance'},
'resort':	{'report','resorts'},
'resorted':	{'reported'},
'resorting':	{'reporting'},
'resorts':	{'reports','resort'},
'resounding':	{'rebounding'},
'resource':	{'resourced','resources'},
'resourced':	{'resource','resources'},
'resources':	{'resource','resourced'},
'respect':	{'respects'},
'respects':	{'respect'},
'respirator':	{'respiratory'},
'respiratory':	{'respirator'},
'respite':	{'despite'},
'respond':	{'responds'},
'responded':	{'responder'},
'respondent':	{'respondents'},
'respondents':	{'respondent'},
'responder':	{'responded','responders'},
'responders':	{'responder'},
'responds':	{'respond'},
'response':	{'responses'},
'responses':	{'response'},
'responsible':	{'responsibly'},
'responsibly':	{'responsible'},
'rest':	{'best','brest','crest','est','fest','jest','lest','nest','pest','reit','rent','res','reset','rests','rust','test','vest','west','zest'},
'restart':	{'restarts'},
'restarted':	{'restated'},
'restarts':	{'restart'},
'restated':	{'restarted'},
'restaurant':	{'restaurants'},
'restaurants':	{'restaurant'},
'rested':	{'crested','nested','rented','rusted','tested','vested'},
'resting':	{'nesting','renting','rusting','testing','vesting'},
'restore':	{'restored','restores'},
'restored':	{'restore','restores'},
'restores':	{'restore','restored'},
'restrain':	{'restrains','restraint'},
'restraining':	{'retraining'},
'restrains':	{'restrain','restraint','restraints'},
'restraint':	{'restrain','restrains','restraints'},
'restraints':	{'restrains','restraint'},
'restrict':	{'restricts'},
'restriction':	{'restrictions'},
'restrictions':	{'restriction'},
'restricts':	{'restrict'},
'restroom':	{'restrooms'},
'restrooms':	{'restroom'},
'restructure':	{'restructured','restructures'},
'restructured':	{'restructure','restructures'},
'restructures':	{'restructure','restructured'},
'rests':	{'nests','pests','rents','resets','rest','rusts','tests','vests'},
'result':	{'results'},
'results':	{'result'},
'resume':	{'presume','resumed','resumes'},
'resumed':	{'presumed','resume','resumes'},
'resumes':	{'presumes','resume','resumed'},
'resuming':	{'presuming'},
'resumption':	{'presumption'},
'retail':	{'detail','retain'},
'retailer':	{'retailers','retainer'},
'retailers':	{'retailer','retainers'},
'retailing':	{'detailing','retaining'},
'retain':	{'detain','regain','remain','retail','retains'},
'retained':	{'detained','regained','remained','retainer'},
'retainer':	{'retailer','retained','retainers'},
'retainers':	{'retailers','retainer'},
'retaining':	{'remaining','retailing','retraining'},
'retains':	{'remains','retain'},
'retard':	{'regard','reward'},
'retarded':	{'regarded','rewarded'},
'retell':	{'resell'},
'retelling':	{'reselling'},
'retention':	{'detention'},
'retina':	{'regina','retinal'},
'retinal':	{'retina'},
'retire':	{'retired','retiree','retires'},
'retired':	{'retire','retiree','retires'},
'retiree':	{'retire','retired','retirees','retires'},
'retirees':	{'retiree','retires'},
'retires':	{'retire','retired','retiree','retirees'},
'retract':	{'detract'},
'retraining':	{'restraining','retaining'},
'retreat':	{'retreats'},
'retreated':	{'recreated'},
'retreats':	{'retreat'},
'retrieve':	{'retrieved','retriever','retrieves'},
'retrieved':	{'retrieve','retriever','retrieves'},
'retriever':	{'retrieve','retrieved','retrieves'},
'retrieves':	{'retrieve','retrieved','retriever'},
'retro':	{'metro','retry'},
'retry':	{'retro'},
'return':	{'returns'},
'returns':	{'return'},
'reunion':	{'reunions'},
'reunions':	{'reunion'},
'reunite':	{'reunited'},
'reunited':	{'reunite'},
'reuse':	{'refuse','reused','rouse'},
'reused':	{'refused','reuse'},
'rev':	{'ev','lev','rec','red','ref','rem','rep','res','rex','rv'},
'revaluation':	{'devaluation','evaluation'},
'reveal':	{'repeal','reseal','reveals','revel'},
'revealed':	{'repealed'},
'revealing':	{'repealing'},
'reveals':	{'reveal'},
'revel':	{'level','ravel','rebel','reel','repel','reveal'},
'revelation':	{'revelations'},
'revelations':	{'revelation'},
'revenge':	{'revenges','revenue'},
'revenges':	{'revenge','revenues'},
'revenue':	{'revenge','revenues'},
'revenues':	{'revenges','revenue'},
'revere':	{'revered','reverse','revert','severe'},
'revered':	{'revere','reverend','reversed','reverted','severed'},
'reverence':	{'reference'},
'reverend':	{'revered'},
'reversal':	{'reversals'},
'reversals':	{'reversal'},
'reverse':	{'revere','reversed','reverses'},
'reversed':	{'revered','reverse','reverses','reverted'},
'reverses':	{'reverse','reversed'},
'revert':	{'revere'},
'reverted':	{'revered','reversed'},
'review':	{'preview','reviews'},
'reviewed':	{'reviewer'},
'reviewer':	{'reviewed','reviewers'},
'reviewers':	{'reviewer'},
'reviews':	{'previews','review'},
'revise':	{'devise','revised','revises','revive'},
'revised':	{'devised','revise','revises','revived'},
'revises':	{'revise','revised'},
'revising':	{'devising','reviving'},
'revision':	{'revisions'},
'revisions':	{'revision'},
'revive':	{'relive','revise','revived'},
'revived':	{'revised','revive'},
'reviving':	{'revising'},
'revocation':	{'relocation'},
'revoke':	{'evoke','revoked'},
'revoked':	{'evoked','revoke'},
'revolution':	{'devolution','evolution','resolution','revolutions'},
'revolutionary':	{'evolutionary'},
'revolutionise':	{'revolutionised','revolutionises','revolutionist','revolutionize'},
'revolutionised':	{'revolutionise','revolutionises','revolutionized'},
'revolutionises':	{'revolutionise','revolutionised','revolutionists','revolutionizes'},
'revolutionising':	{'revolutionizing'},
'revolutionist':	{'evolutionist','revolutionise','revolutionists'},
'revolutionists':	{'evolutionists','revolutionises','revolutionist'},
'revolutionize':	{'revolutionise','revolutionized','revolutionizes'},
'revolutionized':	{'revolutionised','revolutionize','revolutionizes'},
'revolutionizes':	{'revolutionises','revolutionize','revolutionized'},
'revolutionizing':	{'revolutionising'},
'revolutions':	{'resolutions','revolution'},
'revolve':	{'evolve','resolve','revolver','revolves'},
'revolver':	{'resolver','revolve','revolves'},
'revolves':	{'evolves','resolves','revolve','revolver'},
'revolving':	{'evolving','resolving'},
'reward':	{'regard','retard','rewards','seward'},
'rewarded':	{'regarded','retarded'},
'rewarding':	{'regarding'},
'rewards':	{'regards','reward'},
'rewind':	{'remind'},
'rex':	{'ex','hex','rec','red','ref','rem','rep','res','rev','sex'},
'reyes':	{'eyes'},
'rf':	{'af','cf','f','ff','gf','hf','if','of','r','ra','raf','rb','ref','rh','ri','rm','rn','ru','rv'},
'rh':	{'eh','h','nh','oh','ph','r','ra','rb','rf','rho','ri','rm','rn','ru','rv','sh','th','uh'},
'rhea':	{'thea'},
'rhine':	{'rhino','rhone','shine','thine','whine'},
'rhino':	{'chino','rhine'},
'rho':	{'ho','rh','rio','tho','who'},
'rhone':	{'hone','phone','rhine','shone'},
'rhyme':	{'rhymes','thyme'},
'rhymes':	{'rhyme'},
'rhythm':	{'rhythms'},
'rhythms':	{'rhythm'},
'ri':	{'ai','bi','ci','di','fri','gi','hi','i','ii','ji','ki','li','mi','mri','ni','pi','qi','r','ra','rb','rbi','rf','rh','rib','rid','rig','rim','rio','rip','rm','rn','roi','ru','rv','si','ti','vi','wi','xi','yi'},
'rial':	{'dial','real','riel','rival','riyal','trial','vial'},
'rib':	{'bib','crib','lib','nib','rb','ri','ribs','rid','rig','rim','rio','rip','rob','rub','sib'},
'ribbed':	{'robbed','rubbed'},
'ribbon':	{'gibbon','ribbons'},
'ribbons':	{'ribbon'},
'ribs':	{'bibs','cribs','libs','rib','rids','rigs','rims','rips','robs','rubs'},
'rica':	{'erica','mica','rice','rich','rick','rico','riga'},
'rice':	{'dice','ice','lice','mice','nice','price','race','rica','rich','rick','rico','ride','rife','ripe','rise','rite','vice'},
'rich':	{'reich','rica','rice','rick','rico'},
'richer':	{'riches'},
'riches':	{'niches','richer','richest'},
'richest':	{'riches'},
'rick':	{'brick','dick','kick','lick','mick','nick','pick','prick','rack','rica','rice','rich','rico','rink','risk','rock','sick','tick','trick','wick'},
'rico':	{'rica','rice','rich','rick','rio'},
'rid':	{'aid','arid','bid','cid','did','grid','hid','id','kid','lid','mid','rad','raid','red','reid','ri','rib','ride','rids','rig','rim','rio','rip','rod'},
'ridded':	{'ridden','riddled'},
'ridden':	{'hidden','redden','ridded'},
'ridding':	{'bidding','kidding','riding'},
'riddle':	{'fiddle','middle','riddled','riddles'},
'riddled':	{'ridded','riddle','riddles'},
'riddles':	{'riddle','riddled'},
'ride':	{'aide','bride','hide','pride','rice','rid','rider','rides','ridge','rids','rife','ripe','rise','rite','rode','rude','side','tide','wide'},
'rider':	{'cider','raider','ride','riders','rides','riper','riser','river','ruder','wider'},
'riders':	{'rider','rides','rivers'},
'rides':	{'aides','brides','hides','prides','ride','rider','riders','ridges','rids','rises','rites','sides','tides'},
'ridge':	{'bridge','fridge','ride','ridges'},
'ridges':	{'bridges','fridges','rides','ridge'},
'riding':	{'aiding','hiding','ridding','rising','siding'},
'rids':	{'aids','bids','grids','kids','lids','raids','ribs','rid','ride','rides','rigs','rims','rips','rods','sids'},
'riel':	{'reel','rial'},
'rife':	{'fife','life','rice','ride','riff','rifle','rift','ripe','rise','rite','wife'},
'riff':	{'diff','rife','riffs','rift','ruff','tiff'},
'riffs':	{'riff'},
'rifle':	{'rife','rifles'},
'rifles':	{'rifle'},
'rift':	{'drift','gift','lift','raft','rife','riff','riot','sift'},
'rig':	{'big','brig','dig','fig','gig','jig','orig','pig','rag','ri','rib','rid','riga','rigs','rim','ring','rio','rip','rug','sig','trig','wig'},
'riga':	{'rica','rig','rigs'},
'rigged':	{'ragged','ringed','rugged'},
'rigging':	{'digging','ringing'},
'right':	{'bright','eight','fight','fright','light','might','night','rights','sight','tight','wight','wright'},
'rightful':	{'frightful'},
'rightist':	{'rightists'},
'rightists':	{'rightist'},
'rightly':	{'brightly','lightly','nightly','tightly'},
'rights':	{'eights','fights','frights','lights','nights','right','sights','tights'},
'rigor':	{'vigor'},
'rigorous':	{'vigorous'},
'rigorously':	{'vigorously'},
'rigs':	{'digs','figs','gigs','pigs','rags','regs','ribs','rids','rig','riga','rims','rings','rips','rugs','wigs'},
'riley':	{'kiley'},
'rim':	{'aim','brim','dim','grim','him','ram','rem','ri','rib','rid','rig','rims','rio','rip','rm','rom','rpm','rum','trim','vim'},
'rimming':	{'trimming'},
'rims':	{'aims','ribs','rids','rigs','rim','rips'},
'ring':	{'bring','ding','king','ling','ming','ning','ping','qing','rang','rig','rings','rink','rung','sing','ting','wing','ying'},
'ringed':	{'hinged','ranged','rigged','ringer','rinsed','tinged','winged'},
'ringer':	{'finger','ginger','linger','ranger','ringed','ringers','singer','winger'},
'ringers':	{'fingers','ringer','singers'},
'ringing':	{'bringing','ranging','rigging','singing','winging'},
'rings':	{'brings','kings','pings','rigs','ring','sings','wings'},
'rink':	{'brink','drink','fink','ink','link','mink','pink','rank','rick','ring','risk','sink','wink'},
'rinse':	{'rinsed','rise'},
'rinsed':	{'ringed','rinse'},
'rio':	{'bio','brio','io','rho','ri','rib','rico','rid','rig','rim','riot','rip','trio'},
'riot':	{'rift','rio','riots','root','rot'},
'riots':	{'riot','roots','rots'},
'rip':	{'dip','drip','grip','hip','ip','kip','lip','nip','pip','rap','rep','ri','rib','rid','rig','rim','rio','ripe','rips','sip','tip','trip','vip','yip','zip'},
'ripe':	{'gripe','pipe','rape','rice','ride','rife','rip','riper','rips','rise','rite','rope','wipe'},
'riper':	{'piper','rider','ripe','ripper','riser','river','roper','viper','wiper'},
'ripped':	{'dipped','gripped','ripper','tipped','tripped','zipped'},
'ripper':	{'rapper','riper','ripped','rippers','zipper'},
'rippers':	{'rappers','ripper'},
'ripping':	{'dipping','dripping','gripping','sipping','tipping','tripping'},
'ripple':	{'cripple','nipple','ripples'},
'ripples':	{'nipples','ripple'},
'rips':	{'dips','grips','hips','lips','mips','reps','ribs','rids','rigs','rims','rip','ripe','sips','tips','trips','zips'},
'rise':	{'arise','raise','rice','ride','rife','rinse','ripe','risen','riser','rises','risk','rite','rose','wise'},
'risen':	{'arisen','rise','riser','rises'},
'riser':	{'raiser','rider','riper','rise','risen','rises','river','wiser'},
'rises':	{'arises','crises','raises','rides','rise','risen','riser','risks','rites','roses'},
'rising':	{'arising','raising','riding','risking'},
'risk':	{'brisk','disk','rick','rink','rise','risks','risky','rusk'},
'risking':	{'rising'},
'risks':	{'disks','rises','risk','risky'},
'risky':	{'risk','risks'},
'risque':	{'bisque'},
'rite':	{'bite','cite','kite','lite','mite','rate','rice','ride','rife','ripe','rise','rites','ritz','site','write'},
'rites':	{'bites','cites','kites','mites','rates','rides','rises','rite','sites','writes'},
'ritual':	{'rituals'},
'rituals':	{'ritual'},
'ritz':	{'rite'},
'rival':	{'rial','rivals','riyal'},
'rivals':	{'rival'},
'river':	{'diver','driver','giver','liver','rider','riper','riser','rivera','rivers','rivet','rover'},
'rivera':	{'river','rivers','riviera'},
'rivers':	{'divers','drivers','riders','river','rivera','rivets','rovers'},
'rivet':	{'river','rivets'},
'rivets':	{'rivers','rivet'},
'riviera':	{'rivera'},
'riyal':	{'rial','rival','royal'},
'rm':	{'am','arm','bm','cm','em','fm','gm','hm','km','mm','nm','pm','r','ra','ram','rb','rem','rf','rh','ri','rim','rn','rom','rpm','ru','rum','rv','sm','tm','um','wm'},
'rn':	{'an','en','in','mn','on','r','ra','ran','rb','rf','rh','ri','rm','rna','ron','ru','run','rv','sn','tn','un','urn','zn'},
'rna':	{'ana','dna','na','ra','rana','rn','una'},
'roach':	{'coach','reach'},
'road':	{'broad','load','rad','read','roads','roam','roar','rod','toad'},
'roads':	{'loads','reads','road','roars','rods'},
'roadway':	{'broadway','roadways'},
'roadways':	{'roadway'},
'roam':	{'foam','loam','ram','road','roar','rom','room'},
'roaming':	{'roaring'},
'roar':	{'boar','oar','rear','road','roam','roars','soar'},
'roared':	{'reared','soared'},
'roaring':	{'rearing','roaming','soaring'},
'roars':	{'oars','roads','roar','soars'},
'roast':	{'boast','coast','roasts','roost','toast'},
'roasted':	{'boasted','toasted'},
'roasting':	{'boasting'},
'roasts':	{'boasts','coasts','roast'},
'rob':	{'bob','cob','fob','hob','job','lob','mob','nob','ob','prob','rb','rib','robe','robs','rod','roe','roi','rom','ron','rot','row','rub','sob'},
'robbed':	{'ribbed','robber','rubbed'},
'robber':	{'robbed','robbers','robbery','rubber'},
'robbers':	{'robber','robbery','rubbers'},
'robbery':	{'robber','robbers'},
'robbing':	{'robbins','rubbing'},
'robbins':	{'robbing'},
'robe':	{'kobe','lobe','probe','rob','robes','robs','rode','roe','role','rome','rope','rose','rove'},
'robert':	{'roberts'},
'roberts':	{'robert'},
'robes':	{'lobes','probes','robe','robs','roles','ropes','roses'},
'robin':	{'rodin','tobin'},
'robot':	{'robots','root'},
'robotic':	{'robotics'},
'robotics':	{'robotic'},
'robots':	{'robot','roots'},
'robs':	{'bobs','jobs','mobs','ribs','rob','robe','robes','rods','ross','rots','rows','rubs'},
'rock':	{'bock','cock','crock','dock','jock','lock','mock','rack','rick','rocks','rocky','rook','sock'},
'rocked':	{'docked','locked','mocked','rocker','rocket'},
'rocker':	{'locker','rocked','rockers','rocket'},
'rockers':	{'lockers','rocker'},
'rocket':	{'docket','pocket','racket','rocked','rocker','socket'},
'rockies':	{'rookies'},
'rocking':	{'docking','locking','mocking','racking'},
'rocks':	{'cocks','docks','jocks','locks','racks','rock','rocky','socks'},
'rocky':	{'rock','rocks'},
'rod':	{'bod','cod','dod','god','mod','nod','od','pod','prod','rad','red','rid','road','rob','rode','rods','roe','roi','rom','ron','rot','row','sod','tod'},
'rode':	{'bode','code','erode','mode','node','ode','ride','robe','rod','rodeo','rods','roe','role','rome','rope','rose','rove','rude'},
'rodent':	{'rodents'},
'rodents':	{'rodent'},
'rodeo':	{'rode','romeo'},
'rodgers':	{'rogers'},
'rodin':	{'odin','robin'},
'rods':	{'gods','mods','nods','pods','rids','roads','robs','rod','rode','ross','rots','rows'},
'roe':	{'doe','foe','hoe','poe','rob','robe','rod','rode','roi','role','rom','rome','ron','rope','rose','rot','rove','row','rue','rye','toe','woe'},
'rogers':	{'rodgers','rovers'},
'rogue':	{'vogue'},
'roi':	{'poi','rbi','ri','rob','rod','roe','rom','ron','rot','row'},
'role':	{'cole','dole','hole','mole','ole','pole','robe','rode','roe','roles','rolf','roll','rome','rope','rose','rove','rule','sole'},
'roles':	{'holes','moles','poles','robes','role','rolls','ropes','roses','rules','soles'},
'rolf':	{'golf','role','roll','roof','wolf'},
'roll':	{'boll','doll','moll','poll','role','rolf','rolls','toll','troll'},
'rolled':	{'polled','roller'},
'roller':	{'rolled','rollers'},
'rollers':	{'roller'},
'rolling':	{'polling','trolling'},
'rolls':	{'dolls','polls','roles','roll','tolls','trolls'},
'rom':	{'com','from','mom','pom','prom','ram','rem','rim','rm','roam','rob','rod','roe','roi','roma','rome','romp','ron','room','rot','row','rpm','rum','tom'},
'roma':	{'aroma','coma','rama','rom','roman','rome','romp','rosa','rota'},
'roman':	{'oman','roma','romans','rowan','woman'},
'romance':	{'romances'},
'romances':	{'romance'},
'romania':	{'romanian'},
'romanian':	{'romania'},
'romans':	{'roman'},
'romantic':	{'romantics'},
'romantics':	{'romantic'},
'rome':	{'come','dome','home','nome','robe','rode','roe','role','rom','roma','romeo','romp','rope','rose','rove','some','tome'},
'romeo':	{'rodeo','rome'},
'romp':	{'comp','ramp','rcmp','rom','roma','rome'},
'ron':	{'con','don','hon','ion','iron','mon','non','on','ran','rn','rob','rod','roe','roi','rom','rot','row','run','son','ton','von','won','yon'},
'roof':	{'proof','rolf','roofs','rook','room','root','woof'},
'roofing':	{'proofing','rooting'},
'roofs':	{'goofs','proofs','roof','rooms','roots'},
'rook':	{'book','brook','cook','crook','hook','look','nook','rock','roof','room','root','took'},
'rookie':	{'cookie','rookies'},
'rookies':	{'cookies','rockies','rookie'},
'room':	{'boom','broom','doom','groom','loom','roam','rom','roof','rook','rooms','roomy','root','zoom'},
'roommate':	{'roommates'},
'roommates':	{'roommate'},
'rooms':	{'booms','looms','roofs','room','roomy','roots'},
'roomy':	{'room','rooms'},
'roost':	{'boost','roast','root'},
'rooster':	{'booster','roster'},
'root':	{'boot','foot','hoot','loot','moot','riot','robot','roof','rook','room','roost','roots','rot','rout','soot'},
'rooted':	{'booted','footed','looted','rotted','routed'},
'rooting':	{'booting','footing','looting','roofing','rotting','routing'},
'roots':	{'boots','riots','robots','roofs','rooms','root','rots'},
'rope':	{'cope','dope','hope','pope','rape','ripe','robe','rode','roe','role','rome','roper','ropes','rose','rove'},
'roper':	{'proper','riper','rope','ropes','rover'},
'ropes':	{'hopes','rapes','robes','roles','rope','roper','roses'},
'rosa':	{'roma','rose','ross','rosy','rota'},
'rosary':	{'rotary'},
'rose':	{'arose','bose','dose','hose','lose','nose','pose','prose','rise','robe','rode','roe','role','rome','rope','rosa','roses','ross','rosy','rouse','rove'},
'roses':	{'doses','hoses','loses','moses','noses','poses','rises','robes','roles','ropes','rose','ross'},
'ross':	{'boss','cross','gross','loss','moss','robs','rods','rosa','rose','roses','rosy','rots','rows','toss'},
'roster':	{'foster','poster','raster','rooster','rosters','router'},
'rosters':	{'fosters','posters','roster','routers'},
'roswell':	{'boswell'},
'rosy':	{'cosy','rosa','rose','ross'},
'rot':	{'bot','cot','dot','got','hot','lot','mot','not','pot','rat','riot','rob','rod','roe','roi','rom','ron','root','rota','rotc','roth','rots','rout','row','rut','sot','tot','trot','wot'},
'rota':	{'roma','rosa','rot','rotc','roth','rots'},
'rotary':	{'notary','rosary'},
'rotate':	{'rotated','rotates'},
'rotated':	{'rotate','rotates','rotted'},
'rotates':	{'rotate','rotated'},
'rotating':	{'rotting'},
'rotation':	{'notation','rotations'},
'rotations':	{'notations','rotation'},
'rotc':	{'otc','rot','rota','roth','rots'},
'roth':	{'both','broth','doth','goth','moth','rot','rota','rotc','rots','ruth'},
'rotor':	{'motor','rotors'},
'rotors':	{'motors','rotor'},
'rots':	{'bots','cots','dots','lots','pots','rats','riots','robs','rods','roots','ross','rot','rota','rotc','roth','rows','tots'},
'rotted':	{'dotted','potted','rooted','rotated','rotten','routed'},
'rotten':	{'gotten','rotted'},
'rotting':	{'potting','rooting','rotating','routing'},
'rouble':	{'double','trouble'},
'rouge':	{'rough','rouse','route'},
'rough':	{'bough','cough','dough','lough','rouge','tough','trough'},
'roughness':	{'toughness'},
'round':	{'around','bound','found','ground','hound','mound','pound','rounds','sound','wound'},
'rounded':	{'bounded','founded','grounded','pounded','rounder','sounded','wounded'},
'rounder':	{'founder','rounded'},
'rounding':	{'bounding','founding','grounding','pounding','sounding','wounding'},
'roundly':	{'soundly'},
'roundness':	{'soundness'},
'rounds':	{'bounds','grounds','hounds','mounds','pounds','round','sounds','wounds'},
'roundup':	{'roundups'},
'roundups':	{'roundup'},
'rouse':	{'arouse','grouse','house','mouse','reuse','rose','rouge','route'},
'rousing':	{'housing','routing'},
'rout':	{'bout','gout','grout','out','root','rot','route','roux','rut','tout','trout'},
'route':	{'rouge','rouse','rout','routed','router','routes'},
'routed':	{'rooted','rotted','route','router','routes','touted'},
'router':	{'outer','roster','route','routed','routers','routes'},
'routers':	{'rosters','router','routes'},
'routes':	{'route','routed','router','routers'},
'routine':	{'routines','routing'},
'routines':	{'routine'},
'routing':	{'outing','rooting','rotting','rousing','routine'},
'roux':	{'rout'},
'rove':	{'cove','dove','drove','grove','love','move','prove','rave','robe','rode','roe','role','rome','rope','rose','rover','trove','wove'},
'rover':	{'cover','dover','hover','lover','mover','over','river','roper','rove','rovers'},
'rovers':	{'covers','lovers','movers','overs','rivers','rogers','rover'},
'roving':	{'loving','moving','proving','raving','rowing'},
'row':	{'bow','brow','cow','crow','grow','how','low','now','ow','pow','raw','rob','rod','roe','roi','rom','ron','rot','rows','sow','tow','vow','wow'},
'rowan':	{'roman'},
'rowed':	{'bowed','owed','sowed','towed','vowed'},
'rowing':	{'bowing','growing','lowing','mowing','owing','roving','sowing','towing'},
'rows':	{'bows','brows','cows','crows','grows','hows','lows','robs','rods','ross','rots','row','sows','vows'},
'royal':	{'loyal','riyal'},
'royally':	{'loyally','royalty'},
'royalty':	{'loyalty','royally'},
'rpm':	{'pm','ram','rem','rim','rm','rom','rum'},
'ru':	{'au','cu','du','eu','gu','ju','lu','mu','nu','pu','r','ra','rb','rf','rh','ri','rm','rn','rub','rue','rug','rum','run','rut','rv','su','u','wu','zu'},
'rub':	{'cub','dub','grub','hub','pub','rb','rib','rob','ru','rubs','ruby','rue','rug','rum','run','rut','sub','tub'},
'rubbed':	{'dubbed','ribbed','robbed','rubber'},
'rubber':	{'robber','rubbed','rubbers'},
'rubbers':	{'robbers','rubber'},
'rubbing':	{'robbing'},
'rubble':	{'bubble','hubble','rabble','rumble'},
'rubs':	{'hubs','pubs','ribs','robs','rub','ruby','rugs','runs','subs','tubs'},
'ruby':	{'rub','rubs','rugby'},
'rudd':	{'rude'},
'rudder':	{'redder','ruder'},
'rude':	{'crude','dude','jude','nude','ride','rode','rudd','ruder','rue','rule','rune'},
'ruder':	{'rider','rudder','rude','ruler'},
'rue':	{'cue','due','hue','que','roe','ru','rub','rude','rug','rule','rum','run','rune','rut','rye','sue','true'},
'ruff':	{'buff','cuff','duff','huff','puff','riff'},
'ruffled':	{'muffled'},
'rug':	{'aug','bug','drug','dug','hug','jug','lug','mug','pug','rag','rig','ru','rub','rue','rugs','rum','run','rung','rut','tug'},
'rugby':	{'ruby'},
'rugged':	{'hugged','ragged','rigged'},
'rugs':	{'bugs','drugs','hugs','jugs','mugs','rags','regs','rigs','rubs','rug','runs'},
'ruin':	{'bruin','rain','rein','ruins','run'},
'ruined':	{'rained'},
'ruining':	{'raining','running'},
'ruins':	{'rains','reins','ruin','runs'},
'rule':	{'mule','role','rude','rue','ruled','ruler','rules','rune','yule'},
'ruled':	{'rule','ruler','rules'},
'ruler':	{'euler','ruder','rule','ruled','rulers','rules'},
'rulers':	{'ruler','rules'},
'rules':	{'mules','roles','rule','ruled','ruler','rulers','runes'},
'ruling':	{'rulings'},
'rulings':	{'ruling'},
'rum':	{'bum','cum','drum','gum','hum','mum','ram','rem','rim','rm','rom','rpm','ru','rub','rue','rug','run','rut','sum','um','yum'},
'rumble':	{'bumble','crumble','fumble','humble','jumble','rubble','tumble'},
'rumor':	{'humor','rumors','rumour','tumor'},
'rumors':	{'rumor','tumors'},
'rumour':	{'humour','rumor','tumour'},
'run':	{'bun','dun','fun','gun','hun','nun','pun','ran','rn','ron','ru','rub','rue','rug','ruin','rum','rune','rung','runs','rut','sun','un'},
'runaway':	{'runway'},
'rune':	{'dune','june','prune','rude','rue','rule','run','runes','rung','runs','tune'},
'runes':	{'dunes','rules','rune','runs','tunes'},
'rung':	{'dung','hung','jung','lung','rang','ring','rug','run','rune','runs','sung'},
'runner':	{'gunner','runners'},
'runners':	{'runner'},
'running':	{'cunning','ruining'},
'runny':	{'bunny','funny','sunny'},
'runs':	{'buns','guns','nuns','rubs','rugs','ruins','run','rune','runes','rung','suns'},
'runway':	{'runaway','runways'},
'runways':	{'runway'},
'rupee':	{'rupees'},
'rupees':	{'rupee'},
'rupture':	{'rapture'},
'rural':	{'aural','mural'},
'rush':	{'brush','bush','crush','hush','lush','push','rash','rusk','rust','ruth'},
'rushed':	{'brushed','crushed','pushed','rushes','rusted'},
'rushes':	{'brushes','bushes','crushes','pushes','rushed'},
'rushing':	{'brushing','crushing','gushing','pushing','rusting'},
'rusk':	{'dusk','musk','risk','rush','rust'},
'russia':	{'prussia','russian'},
'russian':	{'prussian','russia'},
'rust':	{'bust','crust','dust','gust','just','lust','must','rest','rush','rusk','rusts','rusty','rut','trust'},
'rusted':	{'busted','dusted','ousted','rested','rushed','trusted'},
'rusting':	{'busting','dusting','resting','rushing','trusting'},
'rusts':	{'dusts','gusts','rests','rust','rusty','trusts'},
'rusty':	{'busty','crusty','dusty','lusty','rust','rusts','trusty'},
'rut':	{'brut','but','cut','gut','hut','nut','out','put','rat','rot','rout','ru','rub','rue','rug','rum','run','rust','ruth','tut','ut'},
'ruth':	{'roth','rush','rut','truth'},
'rv':	{'av','cv','ev','iv','jv','lv','nv','r','ra','rb','rev','rf','rh','ri','rm','rn','ru','tv','uv','v','wv','xv'},
'rwanda':	{'rwandan'},
'rwandan':	{'rwanda'},
'rye':	{'aye','bye','dye','eye','frye','roe','rue','wye','ye'},
'sa':	{'a','ba','ca','da','ea','fa','ga','gsa','ha','ia','ka','la','ma','na','pa','ra','sac','sad','sag','sai','sam','sap','sat','saw','sax','say','sb','sba','sc','sd','se','sea','sh','si','ska','sm','sn','so','spa','sr','ss','ssa','su','sw','ta','usa','va','wa','ya','za'},
'saba':	{'aba','baba','saga','samba','sba'},
'saber':	{'safer','saver','sober'},
'sabin':	{'cabin','sabine','satin'},
'sabine':	{'sabin','saline'},
'sable':	{'able','cable','fable','gable','sabre','sale','stable','table','usable'},
'sabre':	{'sable'},
'sac':	{'ac','lac','mac','pac','sa','sack','sad','sag','sai','sam','sap','sat','saw','sax','say','sc','sec','sic','vac','wac'},
'sack':	{'back','hack','jack','lack','mack','pack','rack','sac','sacks','sank','shack','sick','slack','smack','snack','sock','stack','suck','tack'},
'sacked':	{'backed','hacked','lacked','packed','sacred','stacked','sucked'},
'sacks':	{'backs','hacks','jacks','lacks','packs','racks','sack','snacks','socks','stacks','sucks'},
'sacrament':	{'sacramento'},
'sacramento':	{'sacrament'},
'sacred':	{'sacked'},
'sacrifice':	{'sacrificed','sacrifices'},
'sacrificed':	{'sacrifice','sacrifices'},
'sacrifices':	{'sacrifice','sacrificed'},
'sad':	{'ad','bad','cad','dad','fad','had','lad','mad','pad','rad','sa','sac','sade','sag','sai','said','sam','sand','sap','sat','saw','sax','say','sd','shad','sod','std','tad','wad'},
'sadden':	{'madden','sadder','sudden'},
'sadder':	{'adder','ladder','madder','sadden','sander'},
'saddest':	{'maddest'},
'saddle':	{'paddle','saddled','saddles'},
'saddled':	{'saddle','saddles'},
'saddles':	{'paddles','saddle','saddled'},
'saddling':	{'paddling'},
'sade':	{'ade','bade','fade','jade','made','sad','safe','sage','sake','sale','same','sane','save','shade','side','spade','wade'},
'sadly':	{'badly','madly','sally'},
'sadness':	{'badness','madness'},
'safari':	{'safaris'},
'safaris':	{'safari'},
'safe':	{'cafe','sade','safer','safes','sage','sake','sale','same','sane','save'},
'safeguard':	{'safeguards'},
'safeguards':	{'safeguard'},
'safely':	{'safety'},
'safeness':	{'sameness'},
'safer':	{'saber','safe','safes','saver','wafer'},
'safes':	{'cafes','safe','safer','safest','sages','sakes','sales','saves'},
'safest':	{'safes'},
'safety':	{'safely'},
'sag':	{'ag','bag','dag','fag','gag','jag','lag','mag','nag','rag','sa','sac','sad','saga','sage','sai','sam','sang','sap','sat','saw','sax','say','shag','sig','slag','snag','stag','tag'},
'saga':	{'saba','sag','sage'},
'sage':	{'age','cage','gage','osage','page','rage','sade','safe','sag','saga','sages','sake','sale','same','sane','save','stage','usage','wage'},
'sages':	{'ages','cages','pages','safes','sage','sakes','sales','saves','stages','usages','wages'},
'sahara':	{'saharan','samara'},
'saharan':	{'sahara'},
'sai':	{'ai','bai','sa','sac','sad','sag','said','sail','sam','sap','sari','sat','saw','sax','say','si','ski','tai','wai'},
'said':	{'aid','laid','maid','paid','raid','sad','sai','sail','sand','skid','slid'},
'sail':	{'bail','dail','fail','hail','jail','mail','nail','rail','sai','said','sails','saul','snail','soil','tail'},
'sailed':	{'failed','hailed','jailed','mailed','nailed','smiled','soiled','tailed'},
'sailing':	{'ailing','failing','mailing','nailing','railing','sailings','smiling','soiling','wailing'},
'sailings':	{'failings','mailings','railings','sailing'},
'sailor':	{'sailors','tailor'},
'sailors':	{'sailor','tailors'},
'sails':	{'fails','hails','jails','mails','nails','rails','sail','snails','soils','tails'},
'saint':	{'faint','paint','stint'},
'saith':	{'faith','smith'},
'sake':	{'bake','cake','fake','lake','make','rake','sade','safe','sage','sakes','sale','same','sane','save','shake','snake','spake','stake','take','wake'},
'sakes':	{'bakes','cakes','fakes','lakes','makes','rakes','safes','sages','sake','sales','saves','shakes','snakes','stakes','takes','wakes'},
'salad':	{'salads'},
'salads':	{'salad'},
'salaried':	{'salaries'},
'salaries':	{'salaried'},
'sale':	{'ale','bale','dale','gale','hale','male','pale','sable','sade','safe','sage','sake','salem','sales','salt','same','sane','save','scale','shale','sole','stale','tale','vale','yale'},
'salem':	{'sale','sales','salim'},
'sales':	{'ales','bales','males','pales','safes','sages','sakes','sale','salem','salts','saves','scales','soles','tales','wales'},
'salim':	{'salem','slim'},
'salina':	{'saline','saliva'},
'saline':	{'sabine','salina','spline'},
'saliva':	{'salina'},
'sally':	{'ally','bally','cally','rally','sadly','salty','silly','sully','tally','wally'},
'salmon':	{'salomon','salon','saloon'},
'salomon':	{'salmon','saloon','solomon'},
'salon':	{'salmon','salons','saloon','saxon','solon','talon'},
'salons':	{'salon'},
'saloon':	{'salmon','salomon','salon'},
'salt':	{'alt','halt','malt','sale','salts','salty','sat','shalt','silt'},
'salted':	{'halted','salter'},
'salter':	{'alter','halter','salted','walter'},
'salts':	{'halts','sales','salt','salty'},
'salty':	{'sally','salt','salts'},
'salute':	{'solute'},
'salvage':	{'savage'},
'sam':	{'am','cam','dam','ham','jam','lam','ram','sa','sac','sad','sag','sai','same','sap','sat','saw','sax','say','scam','seam','sham','siam','slam','sm','spam','sum','swam','tam','yam'},
'samara':	{'sahara','samaria'},
'samaria':	{'samara'},
'samba':	{'saba','samoa'},
'same':	{'came','dame','fame','game','lame','name','sade','safe','sage','sake','sale','sam','sane','save','shame','some','tame'},
'sameness':	{'safeness'},
'samoa':	{'samba','samoan'},
'samoan':	{'samoa'},
'sample':	{'ample','sampled','sampler','samples','simple'},
'sampled':	{'sample','sampler','samples'},
'sampler':	{'sample','sampled','samplers','samples','simpler'},
'samplers':	{'sampler','samples'},
'samples':	{'sample','sampled','sampler','samplers'},
'sanction':	{'sanctions'},
'sanctions':	{'sanction'},
'sand':	{'and','band','hand','land','rand','sad','said','sands','sandy','sane','sang','sank','sans','send','stand','wand'},
'sandal':	{'sandals','scandal'},
'sandals':	{'sandal','scandals','vandals'},
'sander':	{'lander','sadder','sanger','sender','slander','wander'},
'sanding':	{'banding','handing','landing','sending','standing'},
'sands':	{'bands','hands','lands','sand','sandy','sans','sends','stands','wands'},
'sandy':	{'candy','dandy','handy','randy','sand','sands','tandy'},
'sane':	{'bane','cane','dane','lane','mane','pane','sade','safe','sage','sake','sale','same','sand','sang','sank','sans','save','sine'},
'sang':	{'ang','bang','dang','fang','gang','hang','pang','rang','sag','sand','sane','sank','sans','shang','sing','slang','song','sung','tang','yang'},
'sanger':	{'anger','danger','hanger','manger','ranger','sander','singer'},
'sanity':	{'vanity'},
'sank':	{'bank','hank','rank','sack','sand','sane','sang','sans','shank','sink','spank','sunk','swank','tank','wank','yank'},
'sans':	{'ans','bans','cans','dans','fans','mans','pans','sand','sands','sane','sang','sank','saws','says','scans','sens','sins','sons','spans','suns','swans','vans'},
'santa':	{'manta'},
'sap':	{'asap','cap','gap','hap','lap','map','nap','pap','rap','sa','sac','sad','sag','sai','sam','sat','saw','sax','say','sep','sip','slap','snap','soap','sop','sup','swap','tap','yap','zap'},
'sargent':	{'argent'},
'sari':	{'bari','dari','mari','sai','shari'},
'sash':	{'ash','bash','cash','dash','hash','lash','mash','nash','rash','slash','smash','stash','wash'},
'sassy':	{'sissy'},
'sat':	{'at','bat','cat','dat','eat','fat','hat','kat','lat','mat','oat','pat','rat','sa','sac','sad','sag','sai','salt','sam','sap','saw','sax','say','scat','seat','set','sit','sot','spat','stat','swat','tat','vat','wat'},
'satan':	{'satin'},
'satellite':	{'satellites'},
'satellites':	{'satellite'},
'satin':	{'latin','sabin','satan'},
'satisfied':	{'satisfies'},
'satisfies':	{'satisfied'},
'saturation':	{'maturation'},
'saturday':	{'saturdays'},
'saturdays':	{'saturday'},
'sauce':	{'saucer','sauces'},
'saucer':	{'sauce','saucers','sauces'},
'saucers':	{'saucer','sauces'},
'sauces':	{'sauce','saucer','saucers'},
'saul':	{'gaul','haul','paul','sail','soul'},
'sauna':	{'fauna','saunas'},
'saunas':	{'sauna'},
'sausage':	{'sausages'},
'sausages':	{'sausage'},
'savage':	{'salvage','savages'},
'savages':	{'savage'},
'savanna':	{'savannah'},
'savannah':	{'savanna'},
'save':	{'ave','cave','fave','gave','have','pave','rave','sade','safe','sage','sake','sale','same','sane','saved','saver','saves','shave','slave','wave'},
'saved':	{'caved','paved','save','saver','saves','sawed','shaved','waved'},
'saver':	{'saber','safer','save','saved','savers','saves','savor','sever','shaver'},
'savers':	{'saver','saves','sayers','shavers'},
'saves':	{'caves','haves','raves','safes','sages','sakes','sales','save','saved','saver','savers','shaves','slaves','waves'},
'saving':	{'caving','having','paving','raving','savings','sawing','saying','shaving','waving'},
'savings':	{'saving','sayings'},
'savior':	{'saviour','savor'},
'saviour':	{'savior'},
'savor':	{'favor','saver','savior','savory','savoy'},
'savory':	{'savor','savoy'},
'savoy':	{'savor','savory','savvy'},
'savvy':	{'savoy'},
'saw':	{'haw','jaw','law','paw','raw','sa','sac','sad','sag','sai','sam','sap','sat','saws','sax','say','sew','shaw','sow','ssw','sw'},
'sawed':	{'saved','sewed','sowed'},
'sawing':	{'saving','saying','sewing','sowing','swing'},
'saws':	{'jaws','laws','paws','sans','saw','says','sews','sows'},
'sawyer':	{'lawyer'},
'sax':	{'ax','fax','lax','max','sa','sac','sad','sag','sai','sam','sap','sat','saw','say','sex','six','tax','wax'},
'saxon':	{'salon','saxony'},
'saxony':	{'saxon'},
'say':	{'bay','cay','day','fay','gay','hay','jay','lay','may','nay','pay','ray','sa','sac','sad','sag','sai','sam','sap','sat','saw','sax','says','shay','shy','sky','slay','sly','soy','spy','stay','sway','way'},
'sayers':	{'layers','payers','savers'},
'saying':	{'laying','paying','saving','sawing','sayings','slaying','spying','staying','swaying'},
'sayings':	{'savings','saying'},
'says':	{'bays','days','gays','hays','lays','mays','nays','pays','rays','sans','saws','say','stays','ways'},
'sb':	{'ab','b','bb','db','eb','gb','kb','lb','mb','nb','ob','pb','rb','sa','sba','sc','sd','se','sh','si','sib','sm','sn','so','sob','sr','ss','su','sub','sw','tb','yb'},
'sba':	{'aba','ba','mba','sa','saba','sb','sea','ska','spa','ssa'},
'sc':	{'ac','bc','c','cc','dc','ec','kc','mc','nc','nsc','pc','sa','sac','sb','sd','se','sec','sh','si','sic','sm','sn','so','sr','ss','su','sw','tc'},
'scale':	{'sale','scaled','scales','scalp','scare','shale','stale'},
'scaled':	{'scale','scales','scared','sealed'},
'scales':	{'sales','scale','scaled','scares'},
'scaling':	{'scaring','sealing'},
'scalp':	{'scale','scamp'},
'scam':	{'cam','sam','scamp','scams','scan','scar','scat','scum','seam','sham','siam','slam','spam','swam'},
'scamp':	{'camp','scalp','scam','scams','stamp','swamp'},
'scams':	{'cams','scam','scamp','scans','scars','seams','shams','slams'},
'scan':	{'can','scam','scans','scant','scar','scat','shan','span','swan'},
'scandal':	{'sandal','scandals'},
'scandals':	{'sandals','scandal'},
'scandinavia':	{'scandinavian'},
'scandinavian':	{'scandinavia'},
'scanned':	{'canned','scanner','spanned'},
'scanner':	{'scanned','scanners'},
'scanners':	{'scanner'},
'scanning':	{'canning','spanning'},
'scans':	{'cans','sans','scams','scan','scant','scars','spans','swans'},
'scant':	{'cant','scan','scans','scat','scent','slant'},
'scar':	{'car','oscar','scam','scan','scare','scarf','scars','scary','scat','soar','star'},
'scarce':	{'scarcer','scare'},
'scarcer':	{'scarce'},
'scare':	{'care','scale','scar','scarce','scared','scares','scarf','scars','scary','score','share','snare','spare','stare'},
'scared':	{'cared','scaled','scare','scares','scarred','scored','shared','soared','spared','stared'},
'scares':	{'cares','scales','scare','scared','scars','scarves','scores','shares','spares','stares'},
'scarf':	{'scar','scare','scars','scary'},
'scaring':	{'caring','scaling','scarring','scoring','sharing','soaring','sparing','staring'},
'scarred':	{'scared','starred'},
'scarring':	{'scaring','starring'},
'scars':	{'cars','scams','scans','scar','scare','scares','scarf','scary','soars','stars'},
'scarves':	{'scares'},
'scary':	{'scar','scare','scarf','scars'},
'scat':	{'cat','sat','scam','scan','scant','scar','scot','seat','spat','stat','swat'},
'scatter':	{'scatters','shatter'},
'scattered':	{'shattered'},
'scattering':	{'shattering'},
'scatters':	{'scatter'},
'scenario':	{'scenarios'},
'scenarios':	{'scenario'},
'scene':	{'scenes','scent'},
'scenes':	{'scene','scents'},
'scent':	{'ascent','cent','scant','scene','scents','sent','spent'},
'scents':	{'cents','scenes','scent'},
'sceptical':	{'skeptical'},
'schedule':	{'scheduled','scheduler','schedules'},
'scheduled':	{'schedule','scheduler','schedules'},
'scheduler':	{'schedule','scheduled','schedules'},
'schedules':	{'schedule','scheduled','scheduler'},
'schema':	{'scheme'},
'schematic':	{'schematics'},
'schematics':	{'schematic'},
'scheme':	{'schema','schemed','schemes'},
'schemed':	{'scheme','schemes'},
'schemes':	{'scheme','schemed'},
'schiller':	{'chiller'},
'schilling':	{'chilling','shilling'},
'schizophrenia':	{'schizophrenic'},
'schizophrenic':	{'schizophrenia'},
'scholar':	{'scholars'},
'scholars':	{'scholar'},
'scholarship':	{'scholarships'},
'scholarships':	{'scholarship'},
'school':	{'schools'},
'schoolgirl':	{'schoolgirls'},
'schoolgirls':	{'schoolgirl'},
'schools':	{'school'},
'science':	{'sciences'},
'sciences':	{'science'},
'scientist':	{'scientists'},
'scientists':	{'scientist'},
'scissor':	{'scissors'},
'scissors':	{'scissor'},
'scold':	{'cold','scolds','sold'},
'scolds':	{'colds','scold'},
'sconce':	{'sconces'},
'sconces':	{'sconce'},
'scoop':	{'coop','scoops','snoop','swoop'},
'scoops':	{'scoop'},
'scooter':	{'scooters','shooter'},
'scooters':	{'scooter','shooters'},
'scope':	{'cope','scopes','score','slope'},
'scopes':	{'scope','scores','slopes'},
'scoping':	{'coping','scoring','sloping'},
'score':	{'core','scare','scope','scored','scorer','scores','scorn','shore','sore','spore','store','swore'},
'scoreboard':	{'scoreboards'},
'scoreboards':	{'scoreboard'},
'scored':	{'cored','scared','score','scorer','scores','scorned','stored'},
'scorer':	{'score','scored','scorers','scores'},
'scorers':	{'scorer','scores'},
'scores':	{'cores','scares','scopes','score','scored','scorer','scorers','scorns','shores','sores','spores','stores'},
'scoring':	{'coring','scaring','scoping','scorning','snoring','storing'},
'scorn':	{'acorn','corn','score','scorns','sworn'},
'scorned':	{'scored'},
'scorning':	{'scoring'},
'scorns':	{'scores','scorn'},
'scorpio':	{'scorpion'},
'scorpion':	{'scorpio','scorpions'},
'scorpions':	{'scorpion'},
'scot':	{'ascot','cot','scat','scots','scott','scout','shot','slot','soot','sot','spot','swot'},
'scots':	{'cots','scot','scott','scouts','shots','slots','spots'},
'scott':	{'scot','scots','scout'},
'scout':	{'scot','scott','scouts','shout','spout','stout'},
'scouting':	{'shouting'},
'scouts':	{'scots','scout','shouts'},
'scrabble':	{'scramble'},
'scramble':	{'scrabble','scrambled'},
'scrambled':	{'scramble'},
'scrap':	{'crap','scrape','scraps','strap'},
'scrapbook':	{'scrapbooks'},
'scrapbooks':	{'scrapbook'},
'scrape':	{'scrap','scraped','scrapes','scraps'},
'scraped':	{'scrape','scrapes','scrapped'},
'scrapes':	{'scrape','scraped','scraps'},
'scrapped':	{'scraped','strapped'},
'scraps':	{'craps','scrap','scrape','scrapes','straps'},
'scratched':	{'scratches'},
'scratches':	{'scratched'},
'scream':	{'cream','screams','stream'},
'screamed':	{'creamed','streamed'},
'screaming':	{'creaming','streaming'},
'screams':	{'creams','scream','streams'},
'screen':	{'screens'},
'screening':	{'screenings'},
'screenings':	{'screening'},
'screens':	{'screen'},
'screw':	{'crew','screws'},
'screwdriver':	{'screwdrivers'},
'screwdrivers':	{'screwdriver'},
'screws':	{'crews','screw'},
'scribe':	{'scribes'},
'scribes':	{'scribe'},
'script':	{'scripts'},
'scripts':	{'script'},
'scroll':	{'scrolls','stroll'},
'scrolling':	{'strolling'},
'scrolls':	{'scroll'},
'scrub':	{'scrubs','shrub'},
'scrubs':	{'scrub','shrubs'},
'scuba':	{'cuba'},
'sculpture':	{'sculptures'},
'sculptures':	{'sculpture'},
'scum':	{'cum','scam','slum','sum','swum'},
'sd':	{'ad','cd','d','dd','ed','gd','id','lsd','md','nd','od','pd','sa','sad','sb','sc','se','sh','si','sm','sn','so','sod','sr','ss','std','su','sw','vd'},
'se':	{'be','ce','de','e','ee','ese','fe','ge','he','ie','le','me','ne','pe','sa','sb','sc','sd','sea','sec','see','sen','sep','seq','set','sew','sex','sh','she','si','sm','sn','so','sr','ss','sse','su','sue','sw','te','use','ve','we','xe','ye'},
'sea':	{'dea','ea','lea','pea','sa','sba','se','seal','seam','seas','seat','sec','see','sen','sep','seq','set','sew','sex','ska','spa','ssa','tea','yea'},
'seal':	{'deal','heal','meal','real','sea','seals','seam','seas','seat','sell','steal','teal','veal','zeal'},
'sealant':	{'sealants'},
'sealants':	{'sealant'},
'sealed':	{'healed','scaled','seated'},
'sealing':	{'dealing','healing','scaling','seating','selling','stealing'},
'seals':	{'deals','heals','meals','seal','seams','seas','seats','sells','steals'},
'seam':	{'beam','sam','scam','sea','seal','seams','seas','seat','seem','sham','siam','slam','spam','steam','swam','team'},
'seaman':	{'seamen','shaman'},
'seamen':	{'seaman','semen'},
'seams':	{'beams','scams','seals','seam','seas','seats','seems','shams','slams','steams','teams'},
'search':	{'starch'},
'searched':	{'searcher','searches'},
'searcher':	{'searched','searchers','searches'},
'searchers':	{'searcher','searches'},
'searches':	{'searched','searcher','searchers'},
'seas':	{'peas','sea','seal','seals','seam','seams','seat','seats','sees','sens','sets','sews','spas','teas','yeas'},
'season':	{'reason','seasons'},
'seasoned':	{'reasoned'},
'seasoning':	{'reasoning','seasonings'},
'seasonings':	{'seasoning'},
'seasons':	{'reasons','season'},
'seat':	{'beat','eat','feat','heat','meat','neat','peat','sat','scat','sea','seal','seam','seas','seats','sect','sent','sept','set','spat','stat','swat','sweat'},
'seated':	{'heated','sealed','slated','stated','sweated'},
'seating':	{'beating','eating','heating','sealing','setting','skating','stating','sweating'},
'seats':	{'beats','eats','feats','heats','keats','meats','seals','seams','seas','seat','sects','sets','stats','sweats','yeats'},
'seattle':	{'settle'},
'sec':	{'dec','ec','eec','rec','sac','sc','se','sea','sect','see','sen','sep','seq','set','sew','sex','sic','spec'},
'second':	{'seconds'},
'seconds':	{'second'},
'secret':	{'secrets'},
'secretarial':	{'secretariat'},
'secretariat':	{'secretarial'},
'secretary':	{'secretory'},
'secretion':	{'secretions'},
'secretions':	{'secretion'},
'secretory':	{'secretary'},
'secrets':	{'secret'},
'sect':	{'seat','sec','sects','sent','sept','set'},
'section':	{'sections','suction'},
'sections':	{'section'},
'sector':	{'hector','rector','sectors','vector'},
'sectors':	{'sector','vectors'},
'sects':	{'seats','sect','sets'},
'secure':	{'secured','secures'},
'secured':	{'secure','secures'},
'secures':	{'secure','secured'},
'sedan':	{'sedans','sudan'},
'sedans':	{'sedan'},
'sediment':	{'sediments'},
'sediments':	{'sediment'},
'seduce':	{'deduce','reduce','seduced'},
'seduced':	{'deduced','reduced','seduce'},
'seduction':	{'deduction','reduction'},
'see':	{'bee','ee','fee','gee','lee','nee','pee','se','sea','sec','seed','seek','seem','seen','seer','sees','sen','sep','seq','set','sew','sex','she','sse','sue','tee','wee'},
'seed':	{'deed','feed','heed','need','reed','see','seeds','seek','seem','seen','seer','sees','send','sewed','shed','sled','sped','speed','steed','sued','weed'},
'seeded':	{'needed','seemed','weeded'},
'seeding':	{'feeding','needing','seedling','seeing','seeking','seeming','sending','speeding','weeding'},
'seedling':	{'needling','seeding','seedlings'},
'seedlings':	{'seedling'},
'seeds':	{'deeds','feeds','leeds','needs','reeds','seed','seeks','seems','sees','sends','sheds','speeds','weeds'},
'seeing':	{'peeing','seeding','seeking','seeming','sewing'},
'seek':	{'eek','geek','leek','meek','peek','see','seed','seeks','seem','seen','seer','sees','sleek','week'},
'seeker':	{'seekers'},
'seekers':	{'seeker'},
'seeking':	{'seeding','seeing','seeming'},
'seeks':	{'geeks','seeds','seek','seems','sees','weeks'},
'seem':	{'deem','seam','see','seed','seek','seems','seen','seer','sees','stem'},
'seemed':	{'deemed','seeded'},
'seeming':	{'seeding','seeing','seeking'},
'seems':	{'deems','seams','seeds','seeks','seem','sees','stems'},
'seen':	{'been','keen','see','seed','seek','seem','seer','sees','semen','sen','seven','sewn','sheen','teen'},
'seer':	{'beer','deer','peer','see','seed','seek','seem','seen','sees','sever','sewer','sheer','steer'},
'sees':	{'bees','fees','lees','seas','see','seed','seeds','seek','seeks','seem','seems','seen','seer','sens','sets','sews','sexes','shes','tees'},
'segment':	{'segments'},
'segments':	{'segment'},
'seine':	{'seize','shine','sine','spine','swine'},
'seize':	{'seine','seized','seizes','size'},
'seized':	{'seize','seizes','sized'},
'seizes':	{'seize','seized','sizes'},
'seizing':	{'sizing'},
'seizure':	{'seizures'},
'seizures':	{'seizure'},
'select':	{'elect','selects'},
'selectable':	{'delectable'},
'selected':	{'elected'},
'selecting':	{'electing'},
'selection':	{'election','selections'},
'selections':	{'elections','selection'},
'selective':	{'elective'},
'selector':	{'elector','selectors'},
'selectors':	{'electors','selector'},
'selects':	{'elects','select'},
'self':	{'elf','sell','shelf'},
'sell':	{'bell','cell','dell','ell','fell','hell','seal','self','sells','shell','sill','smell','spell','swell','tell','well','yell'},
'seller':	{'heller','keller','sellers','teller'},
'sellers':	{'seller'},
'selling':	{'belling','sealing','shelling','smelling','spelling','swelling','telling','yelling'},
'sells':	{'bells','cells','hells','seals','sell','shells','smells','spells','swells','tells','wells','yells'},
'selves':	{'elves','serves','shelves','solves'},
'semantic':	{'semantics'},
'semantics':	{'semantic'},
'semen':	{'seamen','seen','seven','yemen'},
'semester':	{'semesters'},
'semesters':	{'semester'},
'semiconductor':	{'semiconductors'},
'semiconductors':	{'semiconductor'},
'seminal':	{'seminar'},
'seminar':	{'seminal','seminars','seminary'},
'seminars':	{'seminar','seminary'},
'seminary':	{'seminar','seminars'},
'sen':	{'ben','den','en','fen','gen','hen','ken','men','pen','se','sea','sec','see','seen','send','sens','sent','sep','seq','set','sew','sewn','sex','sin','sn','son','sun','ten','wen','yen','zen'},
'senator':	{'senators'},
'senators':	{'senator'},
'send':	{'bend','end','fend','lend','mend','sand','seed','sen','sends','sens','sent','spend','tend'},
'sender':	{'bender','fender','gender','lender','render','sander','senders','slender','tender'},
'senders':	{'fenders','genders','lenders','renders','sender','tenders'},
'sending':	{'bending','ending','lending','mending','pending','sanding','seeding','sensing','spending','tending','vending'},
'sends':	{'bends','ends','lends','mends','sands','seeds','send','sens','spends','tends'},
'senior':	{'seniors','sensor'},
'seniors':	{'senior','sensors'},
'senna':	{'henna','sienna'},
'sens':	{'ens','hens','lens','pens','sans','seas','sees','sen','send','sends','sense','sent','sets','sews','sins','sons','suns','tens'},
'sensation':	{'sensations'},
'sensations':	{'sensation'},
'sense':	{'dense','sens','sensed','senses','tense'},
'sensed':	{'sense','senses'},
'senses':	{'lenses','sense','sensed'},
'sensible':	{'sensibly'},
'sensibly':	{'sensible'},
'sensing':	{'sending'},
'sensor':	{'censor','senior','sensors','sensory','tensor'},
'sensors':	{'seniors','sensor','sensory'},
'sensory':	{'sensor','sensors'},
'sent':	{'bent','cent','dent','gent','kent','lent','rent','scent','seat','sect','sen','send','sens','sept','set','spent','tent','vent','went'},
'sentence':	{'sentenced','sentences'},
'sentenced':	{'sentence','sentences'},
'sentences':	{'sentence','sentenced'},
'sentient':	{'sentiment'},
'sentiment':	{'sentient','sentiments'},
'sentiments':	{'sentiment'},
'sentry':	{'entry','gentry'},
'seoul':	{'soul'},
'sep':	{'hep','pep','rep','sap','se','sea','sec','see','sen','sept','seq','set','sew','sex','sip','sop','step','sup'},
'separate':	{'separated','separates'},
'separated':	{'separate','separates'},
'separates':	{'separate','separated'},
'separation':	{'separations'},
'separations':	{'reparations','separation'},
'separatist':	{'separatists'},
'separatists':	{'separatist'},
'separator':	{'separators'},
'separators':	{'separator'},
'sept':	{'kept','seat','sect','sent','sep','set','slept','swept','wept'},
'septic':	{'skeptic'},
'seq':	{'se','sea','sec','see','sen','sep','set','sew','sex'},
'sequel':	{'sequels'},
'sequels':	{'sequel'},
'sequence':	{'sequenced','sequencer','sequences'},
'sequenced':	{'sequence','sequencer','sequences'},
'sequencer':	{'sequence','sequenced','sequences'},
'sequences':	{'sequence','sequenced','sequencer'},
'serb':	{'herb','verb'},
'serbia':	{'serbian'},
'serbian':	{'serbia'},
'serge':	{'merge','serve','surge','verge'},
'serial':	{'aerial','serials'},
'serials':	{'aerials','serial'},
'series':	{'serves'},
'sermon':	{'sermons'},
'sermons':	{'sermon'},
'serra':	{'sierra'},
'servant':	{'servants'},
'servants':	{'servant'},
'serve':	{'nerve','serge','served','server','serves','servo','verve'},
'served':	{'serve','server','serves'},
'server':	{'serve','served','servers','serves','sever'},
'servers':	{'server','serves'},
'serves':	{'nerves','selves','series','serve','served','server','servers'},
'service':	{'serviced','services'},
'serviced':	{'service','services'},
'services':	{'service','serviced'},
'serving':	{'servings'},
'servings':	{'serving'},
'servo':	{'serve'},
'session':	{'sessions'},
'sessions':	{'session'},
'set':	{'bet','et','get','jet','let','met','net','pet','sat','se','sea','seat','sec','sect','see','sen','sent','sep','sept','seq','seth','sets','sew','sex','sit','sot','tet','vet','wet','yet'},
'setback':	{'setbacks'},
'setbacks':	{'setback'},
'seth':	{'beth','set','sets'},
'seton':	{'sexton'},
'sets':	{'bets','gets','lets','nets','pets','seas','seats','sects','sees','sens','set','seth','sews','sits','vets','wets'},
'setter':	{'better','letter','setters','settler','sitter'},
'setters':	{'letters','setter','settlers'},
'setting':	{'betting','getting','letting','netting','seating','settings','settling','sitting','wetting'},
'settings':	{'lettings','setting'},
'settle':	{'kettle','seattle','settled','settler','settles'},
'settled':	{'settle','settler','settles'},
'settlement':	{'settlements'},
'settlements':	{'settlement'},
'settler':	{'setter','settle','settled','settlers','settles'},
'settlers':	{'setters','settler','settles'},
'settles':	{'kettles','settle','settled','settler','settlers'},
'settling':	{'setting'},
'setup':	{'setups'},
'setups':	{'setup'},
'seven':	{'even','seen','semen','sever','severn'},
'seventh':	{'seventy'},
'seventy':	{'seventh'},
'sever':	{'ever','fever','lever','never','saver','seer','server','seven','severe','severn','sewer'},
'severe':	{'revere','sever','severed','severer','severn'},
'severed':	{'revered','severe','severer'},
'severer':	{'severe','severed'},
'severest':	{'everest'},
'severn':	{'seven','sever','severe'},
'sew':	{'dew','few','jew','mew','new','pew','saw','se','sea','sec','see','sen','sep','seq','set','sewn','sews','sex','shew','skew','slew','sow','ssw','stew','sw','yew'},
'seward':	{'reward','steward'},
'sewed':	{'sawed','seed','sewer','skewed','sowed'},
'sewer':	{'fewer','newer','seer','sever','sewed','sewers'},
'sewers':	{'sewer'},
'sewing':	{'sawing','seeing','sowing','swing'},
'sewn':	{'seen','sen','sew','sews','sown'},
'sews':	{'mews','news','saws','seas','sees','sens','sets','sew','sewn','sows','stews'},
'sex':	{'ex','hex','rex','sax','se','sea','sec','see','sen','sep','seq','set','sew','sexy','six'},
'sexes':	{'sees','sixes'},
'sexiest':	{'sexist'},
'sexism':	{'sexist'},
'sexist':	{'exist','sexiest','sexism'},
'sexton':	{'seton'},
'sexy':	{'sex'},
'sh':	{'ash','eh','h','nh','oh','ph','rh','sa','sb','sc','sd','se','she','shy','si','sm','sn','so','sr','ss','su','sw','th','uh'},
'shack':	{'hack','sack','shank','shark','shock','slack','smack','snack','stack','whack'},
'shad':	{'chad','had','sad','shade','shady','shag','shah','sham','shan','shaw','shay','shed'},
'shade':	{'sade','shad','shaded','shades','shady','shake','shale','shame','shape','share','shave','spade'},
'shaded':	{'shade','shades','shamed','shaped','shared','shaved'},
'shades':	{'hades','shade','shaded','shakes','shames','shapes','shares','shaves','spades'},
'shading':	{'shadings','shaking','shaming','shaping','sharing','shaving'},
'shadings':	{'shading'},
'shadow':	{'shadows','shadowy'},
'shadows':	{'shadow','shadowy'},
'shadowy':	{'shadow','shadows'},
'shady':	{'shad','shade','shaky','shay'},
'shaft':	{'shafts','shalt','shift'},
'shafts':	{'shaft','shifts'},
'shag':	{'sag','shad','shah','sham','shan','shang','shaw','shay','slag','snag','stag'},
'shah':	{'shad','shag','sham','shan','shaw','shay'},
'shake':	{'sake','shade','shaken','shaker','shakes','shaky','shale','shame','shape','share','shave','snake','spake','stake'},
'shaken':	{'shake','shaker','shakes'},
'shaker':	{'shake','shaken','shakers','shakes','shaver'},
'shakers':	{'shaker','shakes','shavers'},
'shakes':	{'sakes','shades','shake','shaken','shaker','shakers','shames','shapes','shares','shaves','snakes','stakes'},
'shaking':	{'shading','shaming','shaping','sharing','shaving','soaking'},
'shaky':	{'shady','shake','shay'},
'shale':	{'hale','sale','scale','shade','shake','shall','shalt','shame','shape','share','shave','stale','whale'},
'shall':	{'hall','shale','shalt','shawl','shell','small','stall'},
'shallow':	{'swallow'},
'shalt':	{'halt','salt','shaft','shale','shall'},
'sham':	{'ham','sam','scam','seam','shad','shag','shah','shame','shams','shan','shaw','shay','siam','slam','spam','swam'},
'shaman':	{'seaman'},
'shame':	{'same','shade','shake','shale','sham','shamed','shames','shams','shape','share','shave'},
'shamed':	{'ashamed','shaded','shame','shames','shaped','shared','shaved'},
'shameless':	{'shapeless'},
'shames':	{'shades','shakes','shame','shamed','shams','shapes','shares','shaves','thames'},
'shaming':	{'shading','shaking','shaping','sharing','shaving'},
'shams':	{'scams','seams','sham','shame','shames','slams'},
'shan':	{'han','khan','scan','shad','shag','shah','sham','shang','shank','shaw','shawn','shay','shin','shun','span','swan','than'},
'shang':	{'chang','hang','sang','shag','shan','shank','slang','thang'},
'shank':	{'hank','sank','shack','shan','shang','shanks','shark','spank','swank','thank'},
'shanks':	{'hanks','shank','thanks'},
'shape':	{'shade','shake','shale','shame','shaped','shapes','share','shave'},
'shaped':	{'shaded','shamed','shape','shapes','shared','shaved'},
'shapeless':	{'shameless'},
'shapes':	{'shades','shakes','shames','shape','shaped','shares','shaves'},
'shaping':	{'shading','shaking','shaming','sharing','shaving'},
'share':	{'hare','scare','shade','shake','shale','shame','shape','shared','shares','shari','shark','sharp','shave','shire','shore','snare','spare','stare'},
'shared':	{'scared','shaded','shamed','shaped','share','shares','shaved','shred','soared','spared','stared'},
'shareholder':	{'shareholders'},
'shareholders':	{'shareholder'},
'shares':	{'scares','shades','shakes','shames','shapes','share','shared','shaves','shores','spares','stares'},
'shari':	{'sari','share','shark','sharp'},
'sharing':	{'scaring','shading','shaking','shaming','shaping','shaving','shearing','soaring','sparing','staring'},
'shark':	{'shack','shank','share','shari','sharp','spark','stark'},
'sharp':	{'harp','share','shari','shark'},
'sharpen':	{'sharpens','sharper'},
'sharpened':	{'sharpener'},
'sharpener':	{'sharpened','sharpeners'},
'sharpeners':	{'sharpener'},
'sharpens':	{'sharpen'},
'sharper':	{'harper','sharpen'},
'shatter':	{'chatter','scatter','shutter'},
'shattered':	{'scattered'},
'shattering':	{'scattering'},
'shave':	{'have','save','shade','shake','shale','shame','shape','share','shaved','shaver','shaves','shove','slave'},
'shaved':	{'saved','shaded','shamed','shaped','shared','shave','shaver','shaves','shoved'},
'shaver':	{'saver','shaker','shave','shaved','shavers','shaves','shiver'},
'shavers':	{'savers','shakers','shaver','shaves'},
'shaves':	{'haves','saves','shades','shakes','shames','shapes','shares','shave','shaved','shaver','shavers','slaves'},
'shaving':	{'having','saving','shading','shaking','shaming','shaping','sharing'},
'shaw':	{'haw','saw','shad','shag','shah','sham','shan','shawl','shawn','shay','shew','show','thaw'},
'shawl':	{'shall','shaw','shawls','shawn'},
'shawls':	{'shawl'},
'shawn':	{'shan','shaw','shawl','shown','spawn'},
'shay':	{'hay','say','shad','shady','shag','shah','shaky','sham','shan','shaw','shy','slay','stay','sway'},
'she':	{'ashe','he','se','see','sh','shed','shes','shew','shoe','shy','sse','sue','the'},
'shear':	{'hear','shears','sheer','smear','spear','swear'},
'shearer':	{'hearer'},
'shearing':	{'hearing','sharing','swearing'},
'shears':	{'hears','shear','smears','swears'},
'sheath':	{'heath'},
'shed':	{'seed','shad','she','sheds','shes','shew','shoed','shred','sled','sped','sued'},
'shedding':	{'shredding','sledding'},
'sheds':	{'seeds','shed','shes'},
'sheen':	{'seen','sheep','sheer','sheet'},
'sheep':	{'sheen','sheer','sheet','sleep','steep','sweep'},
'sheer':	{'cheer','seer','shear','sheen','sheep','sheet','steer'},
'sheet':	{'sheen','sheep','sheer','sheets','sweet'},
'sheets':	{'sheet','sweets'},
'shelf':	{'self','shell'},
'shell':	{'hell','sell','shall','shelf','shells','smell','spell','swell'},
'shelled':	{'shelley','smelled','spelled','swelled'},
'shelley':	{'shelled'},
'shelling':	{'selling','shelving','shilling','smelling','spelling','swelling'},
'shells':	{'hells','sells','shell','smells','spells','swells'},
'shelter':	{'shelters'},
'shelters':	{'shelter'},
'shelves':	{'selves'},
'shelving':	{'shelling'},
'shepherd':	{'shepherds'},
'shepherds':	{'shepherd'},
'sherman':	{'herman'},
'sherry':	{'cherry','sperry'},
'shes':	{'ashes','sees','she','shed','sheds','shew','shoes'},
'shew':	{'chew','sew','shaw','she','shed','shes','show','skew','slew','stew'},
'shield':	{'shields'},
'shields':	{'shield'},
'shift':	{'shaft','shifts','shirt','shit','sift','swift'},
'shifted':	{'shifter'},
'shifter':	{'shifted'},
'shifting':	{'shitting'},
'shifts':	{'shafts','shift','shirts'},
'shilling':	{'chilling','schilling','shelling','shillings','spilling'},
'shillings':	{'shilling'},
'shimmer':	{'simmer','swimmer'},
'shin':	{'chin','shan','shine','shiny','ship','shit','shun','sin','skin','spin','thin'},
'shine':	{'rhine','seine','shin','shined','shines','shiny','shire','shone','shrine','sine','spine','swine','thine','whine'},
'shined':	{'shine','shines'},
'shines':	{'shine','shined','shrines','spines'},
'shingle':	{'shingles','single'},
'shingles':	{'shingle','singles'},
'shining':	{'whining'},
'shiny':	{'shin','shine'},
'ship':	{'chip','hip','shin','ships','shit','shop','sip','skip','slip','snip','whip'},
'shipment':	{'shipments'},
'shipments':	{'shipment'},
'shipped':	{'chipped','shipper','shopped','skipped','slipped','whipped'},
'shipper':	{'shipped','shippers','shopper','skipper','slipper'},
'shippers':	{'shipper','shoppers','slippers'},
'shipping':	{'chipping','shopping','sipping','skipping','slipping','whipping'},
'ships':	{'chips','hips','ship','shops','sips','skips','slips','whips'},
'shire':	{'hire','share','shine','shirt','shore','sire','spire'},
'shirt':	{'shift','shire','shirts','shit','short','skirt'},
'shirts':	{'shifts','shirt','shorts','skirts'},
'shit':	{'chit','hit','shift','shin','ship','shirt','shot','shut','sit','skit','slit','spit','suit','whit'},
'shitting':	{'hitting','shifting','shutting','sitting','spitting'},
'shiver':	{'shaver'},
'shock':	{'chock','shack','shocks','shook','sock','spock','stock'},
'shocked':	{'stocked'},
'shocking':	{'stocking'},
'shocks':	{'shock','socks','stocks'},
'shoe':	{'hoe','she','shoed','shoes','shone','shop','shore','shot','shove','show'},
'shoed':	{'shed','shoe','shoes','shoved','showed','shred'},
'shoeing':	{'showing'},
'shoes':	{'hoes','shes','shoe','shoed','shops','shores','shots','shows'},
'shogun':	{'shotgun'},
'shone':	{'hone','phone','rhone','shine','shoe','shore','shove','stone'},
'shook':	{'hook','shock','shoot'},
'shoot':	{'hoot','shook','shoots','short','shot','shout','soot'},
'shooter':	{'scooter','shooters','shorter'},
'shooters':	{'scooters','shooter'},
'shooting':	{'shootings','shouting'},
'shootings':	{'shooting'},
'shoots':	{'shoot','shorts','shots','shouts'},
'shop':	{'chop','hop','ship','shoe','shops','shot','show','sop','stop'},
'shopped':	{'chopped','hopped','shipped','shopper','stopped'},
'shopper':	{'chopper','hopper','shipper','shopped','shoppers','stopper'},
'shoppers':	{'choppers','shippers','shopper','stoppers'},
'shopping':	{'chopping','hopping','shipping','stopping','whopping'},
'shops':	{'chops','hops','ships','shoes','shop','shots','shows','stops'},
'shore':	{'ashore','chore','score','share','shire','shoe','shone','shores','short','shove','sore','spore','store','swore','whore'},
'shores':	{'chores','scores','shares','shoes','shore','shorts','sores','spores','stores','whores'},
'short':	{'hort','shirt','shoot','shore','shorts','shot','shout','snort','sort','sport'},
'shortage':	{'shortages'},
'shortages':	{'shortage'},
'shortcut':	{'shortcuts'},
'shortcuts':	{'shortcut'},
'shorten':	{'shortens','shorter'},
'shortens':	{'shorten'},
'shorter':	{'shooter','shorten','sorter'},
'shortfall':	{'shortfalls'},
'shortfalls':	{'shortfall'},
'shorts':	{'shirts','shoots','shores','short','shots','shouts','sorts','sports'},
'shot':	{'hot','scot','shit','shoe','shoot','shop','short','shots','shout','show','shut','slot','soot','sot','spot','swot'},
'shotgun':	{'shogun'},
'shots':	{'scots','shoes','shoots','shops','shorts','shot','shouts','shows','shuts','slots','spots'},
'should':	{'shouldn'},
'shoulder':	{'shoulders'},
'shoulders':	{'shoulder'},
'shouldn':	{'should'},
'shout':	{'scout','shoot','short','shot','shouts','shut','spout','stout'},
'shouting':	{'scouting','shooting'},
'shouts':	{'scouts','shoots','shorts','shots','shout','shuts'},
'shove':	{'shave','shoe','shone','shore','shoved','shovel','stove'},
'shoved':	{'shaved','shoed','shove','shovel','showed'},
'shovel':	{'shove','shoved'},
'show':	{'chow','how','shaw','shew','shoe','shop','shot','shown','shows','slow','snow','sow','stow'},
'showcase':	{'showcased','showcases'},
'showcased':	{'showcase','showcases'},
'showcases':	{'showcase','showcased'},
'showdown':	{'slowdown'},
'showed':	{'shoed','shoved','shower','slowed','snowed','sowed'},
'shower':	{'showed','showers','slower'},
'showers':	{'shower'},
'showing':	{'shoeing','slowing','snowing','sowing'},
'shown':	{'shawn','show','shows','sown'},
'showroom':	{'showrooms'},
'showrooms':	{'showroom'},
'shows':	{'hows','shoes','shops','shots','show','shown','slows','snows','sows'},
'shred':	{'shared','shed','shoed','shrewd'},
'shredded':	{'shredder'},
'shredder':	{'shredded','shredders'},
'shredders':	{'shredder'},
'shredding':	{'shedding'},
'shrewd':	{'shred'},
'shrine':	{'shine','shrines','shrink'},
'shrines':	{'shines','shrine','shrinks'},
'shrink':	{'shrine','shrinks','shrunk'},
'shrinks':	{'shrines','shrink'},
'shrub':	{'scrub','shrubs','shrug'},
'shrubs':	{'scrubs','shrub'},
'shrug':	{'shrub'},
'shrunk':	{'shrink'},
'shuffle':	{'shuffled'},
'shuffled':	{'shuffle'},
'shui':	{'hui','shun','shut'},
'shun':	{'hun','shan','shin','shui','shunt','shut','spun','stun','sun'},
'shunt':	{'hunt','shun','shut','stunt'},
'shut':	{'hut','shit','shot','shout','shui','shun','shunt','shuts','slut','smut'},
'shuts':	{'huts','shots','shouts','shut','sluts'},
'shutter':	{'shatter','shutters'},
'shutters':	{'shutter'},
'shutting':	{'shitting'},
'shy':	{'say','sh','shay','she','sky','sly','soy','spy','thy','why'},
'si':	{'ai','bi','ci','di','gi','hi','i','ii','ji','ki','li','mi','ni','pi','psi','qi','ri','sa','sai','sb','sc','sd','se','sh','sib','sic','sig','sin','sip','sir','sis','sit','six','ski','sm','sn','so','sr','ss','su','sw','ti','vi','wi','xi','yi'},
'siam':	{'diam','sam','scam','seam','sham','slam','spam','swam'},
'sib':	{'bib','lib','nib','rib','sb','si','sic','sig','sin','sip','sir','sis','sit','six','sob','sub'},
'siberia':	{'iberia','liberia','siberian'},
'siberian':	{'iberian','liberian','siberia'},
'sibling':	{'siblings'},
'siblings':	{'sibling'},
'sic':	{'pic','sac','sc','sec','si','sib','sick','sig','sin','sip','sir','sis','sit','six','tic'},
'sicily':	{'sickly'},
'sick':	{'dick','kick','lick','mick','nick','pick','rick','sack','sic','silk','sink','slick','sock','stick','suck','tick','wick'},
'sicker':	{'kicker','picker','sticker','sucker','ticker','wicker'},
'sickle':	{'pickle','sickly','tickle'},
'sickly':	{'sicily','sickle'},
'side':	{'aide','aside','hide','ride','sade','sided','sides','sids','sine','sire','site','size','slide','tide','wide'},
'sided':	{'aided','side','sides','sited','sized'},
'sideline':	{'sidelines'},
'sidelines':	{'sideline'},
'sides':	{'aides','hides','rides','side','sided','sids','sites','sixes','sizes','slides','tides'},
'sidewalk':	{'sidewalks'},
'sidewalks':	{'sidewalk'},
'siding':	{'aiding','hiding','riding','siting','sizing','sliding'},
'sidney':	{'kidney','sydney'},
'sids':	{'aids','bids','kids','lids','rids','side','sides','sins','sips','sis','sits'},
'siege':	{'sieve'},
'sienna':	{'senna','vienna'},
'sierra':	{'serra'},
'siesta':	{'fiesta'},
'sieve':	{'siege'},
'sift':	{'gift','lift','rift','shift','silt','sit','soft','swift'},
'sig':	{'big','dig','fig','gig','jig','pig','rig','sag','si','sib','sic','sigh','sign','sin','sing','sip','sir','sis','sit','six','wig'},
'sigh':	{'high','nigh','sig','sighs','sight','sign','sikh'},
'sighed':	{'sighted','signed'},
'sighs':	{'highs','sigh','sight','sights','signs'},
'sight':	{'eight','fight','light','might','night','right','sigh','sighs','sights','slight','tight','wight'},
'sighted':	{'lighted','sighed','slighted'},
'sighting':	{'fighting','lighting','sightings','slighting'},
'sightings':	{'sighting'},
'sights':	{'eights','fights','lights','nights','rights','sighs','sight','slights','tights'},
'sigma':	{'sima','stigma'},
'sign':	{'sig','sigh','signs','sin'},
'signal':	{'signals'},
'signaled':	{'signalled'},
'signaling':	{'signalling'},
'signalled':	{'signaled'},
'signalling':	{'signaling'},
'signals':	{'signal'},
'signature':	{'signatures'},
'signatures':	{'signature'},
'signed':	{'sighed','signer','signet','sinned'},
'signer':	{'signed','signet','sinner'},
'signet':	{'signed','signer'},
'signified':	{'dignified','signifies'},
'signifies':	{'signified'},
'signing':	{'signings'},
'signings':	{'signing'},
'signs':	{'sighs','sign','sins'},
'sikh':	{'sigh'},
'silence':	{'silenced','silences'},
'silenced':	{'silence','silences'},
'silences':	{'silence','silenced'},
'silicon':	{'silicone'},
'silicone':	{'silicon'},
'silk':	{'ilk','milk','sick','silks','silky','sill','silo','silt','sink'},
'silks':	{'milks','silk','silky','silos','sinks'},
'silky':	{'milky','silk','silks','silly'},
'sill':	{'bill','dill','fill','gill','hill','ill','kill','mill','pill','sell','silk','silly','silo','silt','skill','spill','still','till','will'},
'silly':	{'billy','hilly','sally','silky','sill','sully'},
'silo':	{'kilo','lilo','milo','silk','sill','silos','silt','solo'},
'silos':	{'silks','silo','solos'},
'silt':	{'gilt','kilt','milt','salt','sift','silk','sill','silo','sit','tilt','wilt'},
'silva':	{'silvia'},
'silver':	{'silvery','solver'},
'silvery':	{'silver'},
'silvia':	{'silva'},
'sima':	{'lima','sigma'},
'simeon':	{'simon'},
'simmer':	{'shimmer','summer','swimmer'},
'simon':	{'simeon'},
'simple':	{'sample','simpler','simplex','simply'},
'simpler':	{'sampler','simple','simplex'},
'simplex':	{'simple','simpler'},
'simplified':	{'simplifies'},
'simplifies':	{'simplified'},
'simply':	{'imply','simple'},
'simulate':	{'simulated','simulates','stimulate'},
'simulated':	{'simulate','simulates','stimulated'},
'simulates':	{'simulate','simulated','stimulates'},
'simulating':	{'stimulating'},
'simulation':	{'simulations','stimulation'},
'simulations':	{'simulation'},
'simulator':	{'simulators'},
'simulators':	{'simulator'},
'sin':	{'bin','din','fin','gin','in','kin','lin','min','pin','qin','sen','shin','si','sib','sic','sig','sign','sine','sing','sink','sins','sip','sir','sis','sit','six','skin','sn','son','spin','sun','tin','win','yin'},
'since':	{'sine','wince'},
'sine':	{'cine','dine','fine','line','mine','nine','pine','sane','seine','shine','side','sin','since','sing','sink','sins','sire','site','size','spine','swine','vine','wine','zine'},
'sing':	{'ding','king','ling','ming','ning','ping','qing','ring','sang','sig','sin','sine','sings','sink','sins','sling','song','sting','suing','sung','swing','ting','using','wing','ying'},
'singer':	{'finger','ginger','linger','ringer','sanger','singers','sinner','stinger','swinger','winger'},
'singers':	{'fingers','ringers','singer','sinners'},
'singing':	{'ringing','sinking','stinging','swinging','winging'},
'single':	{'jingle','mingle','shingle','singled','singles','singly'},
'singled':	{'mingled','single','singles'},
'singles':	{'shingles','single','singled'},
'singly':	{'single'},
'sings':	{'kings','pings','rings','sing','sinks','sins','sinus','slings','songs','stings','swings','wings'},
'sinister':	{'minister'},
'sink':	{'fink','ink','link','mink','pink','rink','sank','sick','silk','sin','sine','sing','sinks','sins','stink','sunk','wink'},
'sinking':	{'linking','singing'},
'sinks':	{'inks','kinks','links','silks','sings','sink','sins','sinus','stinks'},
'sinned':	{'pinned','signed','sinner','skinned'},
'sinner':	{'dinner','inner','signer','singer','sinned','sinners','skinner','spinner','winner'},
'sinners':	{'dinners','singers','sinner','spinners','winners'},
'sins':	{'bins','fins','ins','pins','sans','sens','sids','signs','sin','sine','sing','sings','sink','sinks','sinus','sips','sis','sits','skins','sons','spins','suns','tins','wins'},
'sinus':	{'minus','sings','sinks','sins'},
'sip':	{'dip','hip','ip','kip','lip','nip','pip','rip','sap','sep','ship','si','sib','sic','sig','sin','sips','sir','sis','sit','six','skip','slip','snip','sop','sup','tip','vip','yip','zip'},
'sipping':	{'dipping','ripping','shipping','skipping','slipping','tipping'},
'sips':	{'dips','hips','lips','mips','rips','ships','sids','sins','sip','sis','sits','skips','slips','tips','zips'},
'sir':	{'air','fir','ir','si','sib','sic','sig','sin','sip','sire','sis','sit','six','sr','stir'},
'sire':	{'dire','eire','fire','hire','ire','lire','shire','side','sine','sir','siren','site','size','sore','spire','sure','tire','wire'},
'siren':	{'sire','sirens'},
'sirens':	{'siren'},
'sis':	{'dis','his','is','isis','si','sib','sic','sids','sig','sin','sins','sip','sips','sir','sit','sits','six','skis','sos','ss','sss'},
'sissy':	{'missy','sassy'},
'sister':	{'lister','mister','sisters','sitter'},
'sisters':	{'sister'},
'sit':	{'bit','fit','git','hit','it','kit','lit','mit','nit','pit','sat','set','shit','si','sib','sic','sift','sig','silt','sin','sip','sir','sis','site','sits','six','skit','slit','sot','spit','suit','tit','wit'},
'site':	{'bite','cite','kite','lite','mite','rite','side','sine','sire','sit','sited','sites','sits','size','spite','suite'},
'sited':	{'cited','sided','site','sites','sized','suited'},
'sites':	{'bites','cites','kites','mites','rites','sides','site','sited','sits','sixes','sizes','suites'},
'siting':	{'biting','citing','siding','sitting','sizing','sting','suiting'},
'sits':	{'bits','fits','hits','its','kits','pits','sets','sids','sins','sips','sis','sit','site','sites','slits','spits','suits','tits','wits'},
'sitter':	{'bitter','fitter','hitter','jitter','litter','setter','sister'},
'sitting':	{'fitting','hitting','setting','shitting','siting','spitting'},
'situate':	{'situated'},
'situated':	{'situate'},
'situation':	{'situations'},
'situations':	{'situation'},
'six':	{'dix','fix','ix','mix','nix','pix','sax','sex','si','sib','sic','sig','sin','sip','sir','sis','sit','xix'},
'sixes':	{'fixes','mixes','sexes','sides','sites','sizes'},
'sixteenth':	{'sixteenths'},
'sixteenths':	{'sixteenth'},
'sixth':	{'sixths','sixty'},
'sixths':	{'sixth'},
'sixtieth':	{'sixtieths'},
'sixtieths':	{'sixtieth'},
'sixty':	{'sixth'},
'size':	{'seize','side','sine','sire','site','sized','sizes'},
'sized':	{'seized','sided','sited','size','sizes'},
'sizes':	{'seizes','sides','sites','sixes','size','sized'},
'sizing':	{'seizing','siding','siting'},
'ska':	{'aka','ka','sa','sba','sea','ski','sky','spa','ssa'},
'skate':	{'skater','skates','slate','state'},
'skateboard':	{'skateboards'},
'skateboards':	{'skateboard'},
'skater':	{'skate','skaters','skates','slater'},
'skaters':	{'skater','skates'},
'skates':	{'skate','skater','skaters','states'},
'skating':	{'seating','stating'},
'skeleton':	{'skeletons'},
'skeletons':	{'skeleton'},
'skeptic':	{'septic','skeptics'},
'skeptical':	{'sceptical'},
'skeptics':	{'skeptic'},
'sketch':	{'sketchy'},
'sketched':	{'sketches'},
'sketches':	{'sketched'},
'sketchy':	{'sketch'},
'skew':	{'askew','sew','shew','slew','stew'},
'skewed':	{'sewed'},
'ski':	{'ki','sai','si','ska','skid','skim','skin','skip','skis','skit','sky'},
'skid':	{'kid','said','ski','skim','skin','skip','skis','skit','slid'},
'skier':	{'skiers','skies'},
'skiers':	{'skier','skies'},
'skies':	{'skier','skiers','skins','skips','skis','spies'},
'skilful':	{'skillful'},
'skilfully':	{'skillfully'},
'skill':	{'kill','sill','skills','skull','spill','still'},
'skilled':	{'killed','skillet','spilled'},
'skillet':	{'skilled'},
'skillful':	{'skilful'},
'skillfully':	{'skilfully'},
'skills':	{'kills','skill','skulls','spills','stills'},
'skim':	{'ski','skid','skin','skip','skis','skit','slim','swim'},
'skin':	{'akin','kin','shin','sin','ski','skid','skim','skins','skip','skis','skit','spin'},
'skinned':	{'sinned','skinner'},
'skinner':	{'sinner','skinned','spinner'},
'skinning':	{'spinning'},
'skins':	{'sins','skies','skin','skips','skis','spins'},
'skip':	{'kip','ship','sip','ski','skid','skim','skin','skips','skis','skit','slip','snip'},
'skipped':	{'shipped','skipper','slipped'},
'skipper':	{'shipper','skipped','slipper'},
'skipping':	{'shipping','sipping','slipping'},
'skips':	{'ships','sips','skies','skins','skip','skis','slips'},
'skirt':	{'shirt','skirts','skit'},
'skirts':	{'shirts','skirt'},
'skis':	{'sis','ski','skid','skies','skim','skin','skins','skip','skips','skit'},
'skit':	{'kit','shit','sit','ski','skid','skim','skin','skip','skirt','skis','slit','spit','suit'},
'skull':	{'skill','skulls'},
'skulls':	{'skills','skull'},
'skunk':	{'sunk'},
'sky':	{'ky','say','shy','ska','ski','sly','soy','spy'},
'slab':	{'lab','slabs','slag','slam','slap','slay','stab'},
'slabs':	{'labs','slab','slams'},
'slack':	{'black','lack','sack','shack','slick','smack','snack','stack'},
'slag':	{'flag','lag','sag','shag','slab','slam','slang','slap','slay','slug','snag','stag'},
'slain':	{'lain','plain','spain','stain','swain'},
'slam':	{'clam','glam','islam','lam','sam','scam','seam','sham','siam','slab','slag','slams','slap','slay','slim','slum','spam','swam'},
'slamming':	{'slimming','spamming'},
'slams':	{'clams','scams','seams','shams','slabs','slam','slums'},
'slander':	{'islander','lander','sander','slender'},
'slang':	{'sang','shang','slag','slant','sling'},
'slant':	{'plant','scant','slang'},
'slap':	{'clap','flap','lap','sap','slab','slag','slam','slay','slip','snap','soap','swap'},
'slapped':	{'slipped','snapped','swapped'},
'slapping':	{'clapping','slipping','snapping','swapping'},
'slash':	{'clash','flash','lash','sash','smash','splash','stash'},
'slashed':	{'flashed','slashes','smashed','splashed'},
'slashes':	{'clashes','flashes','lashes','slashed'},
'slashing':	{'flashing','smashing','splashing'},
'slate':	{'late','plate','skate','slated','slater','slave','state'},
'slated':	{'plated','seated','slate','slater','stated'},
'slater':	{'later','skater','slate','slated','slayer'},
'slaughter':	{'laughter'},
'slave':	{'save','shave','slate','slaves'},
'slaves':	{'saves','shaves','slave'},
'slay':	{'clay','lay','play','say','shay','slab','slag','slam','slap','sly','stay','sway'},
'slayer':	{'layer','player','slater'},
'slaying':	{'laying','playing','saying','staying','swaying'},
'sled':	{'bled','fled','led','seed','shed','slew','slid','sped','sued'},
'sledding':	{'shedding'},
'sledge':	{'ledge','pledge','sludge'},
'sleek':	{'leek','seek','sleep'},
'sleep':	{'asleep','sheep','sleek','sleeps','sleepy','steep','sweep'},
'sleeper':	{'sleepers','steeper','sweeper'},
'sleepers':	{'sleeper'},
'sleeping':	{'sweeping'},
'sleeps':	{'sleep','sleepy','sweeps'},
'sleepy':	{'sleep','sleeps'},
'sleeve':	{'sleeved','sleeves'},
'sleeved':	{'sleeve','sleeves'},
'sleeves':	{'sleeve','sleeved'},
'sleigh':	{'leigh'},
'slender':	{'blender','lender','sender','slander'},
'slept':	{'sept','swept'},
'slew':	{'blew','flew','sew','shew','skew','sled','slow','stew'},
'slice':	{'lice','sliced','slices','slick','slide','slime','spice','splice'},
'sliced':	{'slice','slices','spiced'},
'slices':	{'slice','sliced','slides','spices','splices'},
'slicing':	{'sliding','splicing'},
'slick':	{'click','flick','lick','sick','slack','slice','stick'},
'slid':	{'lid','said','skid','sled','slide','slim','slip','slit','solid'},
'slide':	{'glide','side','slice','slid','slider','slides','slime'},
'slider':	{'glider','slide','sliders','slides','spider'},
'sliders':	{'gliders','slider','slides','spiders'},
'slides':	{'sides','slices','slide','slider','sliders'},
'sliding':	{'gliding','siding','slicing'},
'slight':	{'blight','flight','light','plight','sight','slights'},
'slighted':	{'lighted','sighted','slighter'},
'slighter':	{'lighter','slighted'},
'slightest':	{'lightest'},
'slighting':	{'lighting','sighting'},
'slightly':	{'lightly'},
'slights':	{'flights','lights','sights','slight'},
'slim':	{'salim','skim','slam','slid','slime','slip','slit','slum','swim'},
'slime':	{'lime','slice','slide','slim'},
'slimming':	{'slamming','swimming'},
'sling':	{'cling','fling','ling','sing','slang','slings','sting','suing','swing'},
'slings':	{'sings','sling','stings','swings'},
'slip':	{'clip','flip','lip','ship','sip','skip','slap','slid','slim','slips','slit','snip'},
'slipped':	{'clipped','flipped','shipped','skipped','slapped','slipper'},
'slipper':	{'clipper','flipper','shipper','skipper','slipped','slippers','slippery'},
'slippers':	{'shippers','slipper','slippery'},
'slippery':	{'slipper','slippers'},
'slipping':	{'clipping','flipping','shipping','sipping','skipping','slapping'},
'slips':	{'clips','flips','lips','ships','sips','skips','slip','slits'},
'slit':	{'lit','shit','sit','skit','slid','slim','slip','slits','slot','slut','spit','split','suit'},
'slits':	{'sits','slips','slit','slots','sluts','spits','splits','suits'},
'slogan':	{'logan','slogans'},
'slogans':	{'slogan'},
'slope':	{'scope','sloped','slopes'},
'sloped':	{'slope','slopes','slowed'},
'slopes':	{'scopes','slope','sloped'},
'sloping':	{'scoping','slowing'},
'sloppy':	{'floppy'},
'slot':	{'blot','clot','lot','plot','scot','shot','slit','slots','slow','slut','soot','sot','spot','swot'},
'slots':	{'clots','lots','plots','scots','shots','slits','slot','slows','sluts','spots'},
'slotted':	{'plotted','spotted'},
'slough':	{'lough','plough'},
'slovenia':	{'slovenian'},
'slovenian':	{'slovenia'},
'slow':	{'blow','flow','glow','low','plow','show','slew','slot','slows','snow','sow','stow'},
'slowdown':	{'lowdown','showdown'},
'slowed':	{'flowed','showed','sloped','slower','snowed','sowed'},
'slower':	{'blower','flower','lower','shower','slowed'},
'slowest':	{'lowest'},
'slowing':	{'blowing','flowing','glowing','lowing','showing','sloping','snowing','sowing'},
'slowly':	{'lowly'},
'slows':	{'blows','flows','lows','shows','slots','slow','snows','sows'},
'sludge':	{'sledge'},
'slug':	{'lug','plug','slag','slum','slut','smug','snug'},
'slum':	{'alum','plum','scum','slam','slim','slug','slump','slums','slut','sum','swum'},
'slumber':	{'lumber','plumber'},
'slump':	{'lump','plump','slum','slums','stump','sump'},
'slums':	{'slams','slum','slump','sluts','sums'},
'slurry':	{'blurry','flurry'},
'slut':	{'glut','shut','slit','slot','slug','slum','sluts','smut'},
'sluts':	{'shuts','slits','slots','slums','slut'},
'sly':	{'fly','ly','ply','say','shy','sky','slay','soy','spy'},
'sm':	{'am','bm','cm','em','fm','gm','hm','ism','km','mm','nm','pm','rm','sa','sam','sb','sc','sd','se','sh','si','sn','so','sr','ss','su','sum','sw','tm','um','wm'},
'smack':	{'mack','sack','shack','slack','snack','stack'},
'small':	{'mall','shall','smell','stall'},
'smart':	{'mart','smarts','smarty','start'},
'smarter':	{'starter'},
'smarts':	{'smart','smarty','starts'},
'smarty':	{'smart','smarts'},
'smash':	{'mash','sash','slash','stash'},
'smashed':	{'mashed','slashed'},
'smashing':	{'slashing'},
'smear':	{'shear','smears','spear','swear'},
'smears':	{'shears','smear','swears'},
'smell':	{'sell','shell','small','smells','smelly','smelt','spell','swell'},
'smelled':	{'shelled','spelled','swelled'},
'smelling':	{'selling','shelling','spelling','swelling'},
'smells':	{'sells','shells','smell','smelly','spells','swells'},
'smelly':	{'smell','smells'},
'smelt':	{'melt','smell','spelt'},
'smile':	{'emile','mile','smiled','smiles','smiley'},
'smiled':	{'sailed','smile','smiles','smiley','soiled'},
'smiles':	{'miles','smile','smiled','smiley'},
'smiley':	{'smile','smiled','smiles'},
'smiling':	{'sailing','soiling'},
'smith':	{'saith'},
'smog':	{'smug'},
'smoke':	{'smoked','smoker','smokes','smoky','spoke','stoke'},
'smoked':	{'smoke','smoker','smokes'},
'smoker':	{'smoke','smoked','smokers','smokes','stoker'},
'smokers':	{'smoker','smokes'},
'smokes':	{'smoke','smoked','smoker','smokers','spokes'},
'smoky':	{'smoke'},
'smooth':	{'smooths'},
'smoothed':	{'smoother'},
'smoother':	{'smoothed','smother'},
'smoothing':	{'soothing'},
'smooths':	{'smooth'},
'smother':	{'mother','smoother'},
'smug':	{'mug','slug','smog','smut','snug'},
'smut':	{'shut','slut','smug'},
'sn':	{'an','en','in','isn','mn','on','rn','sa','sb','sc','sd','se','sen','sh','si','sin','sm','so','son','sr','ss','su','sun','sw','tn','un','usn','zn'},
'snack':	{'knack','sack','shack','slack','smack','snacks','stack'},
'snacks':	{'sacks','snack','stacks'},
'snag':	{'nag','sag','shag','slag','snap','snug','stag'},
'snail':	{'nail','sail','snails'},
'snails':	{'nails','sails','snail'},
'snake':	{'sake','shake','snakes','snare','spake','stake'},
'snakes':	{'sakes','shakes','snake','stakes'},
'snap':	{'nap','sap','slap','snag','snaps','snip','soap','swap'},
'snapped':	{'slapped','snapper','swapped'},
'snapper':	{'snapped'},
'snapping':	{'slapping','swapping'},
'snaps':	{'snap','soaps','swaps'},
'snapshot':	{'snapshots'},
'snapshots':	{'snapshot'},
'snare':	{'scare','share','snake','spare','stare'},
'snatch':	{'swatch'},
'sneak':	{'sneaky','speak','steak'},
'sneaker':	{'sneakers','speaker'},
'sneakers':	{'sneaker','speakers'},
'sneaking':	{'speaking'},
'sneaky':	{'sneak'},
'sniff':	{'snuff','stiff'},
'sniffer':	{'stiffer'},
'snip':	{'nip','ship','sip','skip','slip','snap'},
'snippet':	{'snippets'},
'snippets':	{'snippet'},
'snooker':	{'snooper'},
'snoop':	{'scoop','snoopy','swoop'},
'snooper':	{'snooker'},
'snoopy':	{'snoop'},
'snoring':	{'scoring','snorting','snowing','storing'},
'snort':	{'short','sort','sport'},
'snorting':	{'snoring','sorting','sporting'},
'snow':	{'know','now','show','slow','snows','snowy','sow','stow'},
'snowball':	{'snowfall'},
'snowboard':	{'snowboards'},
'snowboards':	{'snowboard'},
'snowed':	{'showed','slowed','sowed'},
'snowfall':	{'snowball'},
'snowing':	{'knowing','showing','slowing','snoring','sowing'},
'snowmobile':	{'snowmobiles'},
'snowmobiles':	{'snowmobile'},
'snows':	{'knows','shows','slows','snow','snowy','sows'},
'snowy':	{'snow','snows'},
'snuff':	{'sniff','stuff'},
'snug':	{'slug','smug','snag'},
'so':	{'co','do','fo','go','ho','io','ko','lo','mo','no','o','po','sa','sb','sc','sd','se','sh','si','sm','sn','sob','sod','sol','son','sop','sos','sot','sow','soy','sr','ss','su','sw','to','wo'},
'soak':	{'oak','soap','soar','sock'},
'soaked':	{'soared'},
'soaking':	{'shaking','soaring'},
'soap':	{'sap','slap','snap','soak','soaps','soar','sop','soup','swap'},
'soaps':	{'snaps','soap','soars','soups','swaps'},
'soar':	{'boar','oar','roar','scar','soak','soap','soars','solar','sonar','sour','star'},
'soared':	{'roared','scared','shared','soaked','soured','spared','stared'},
'soaring':	{'roaring','scaring','sharing','soaking','souring','sparing','staring'},
'soars':	{'oars','roars','scars','soaps','soar','sours','stars'},
'sob':	{'bob','cob','fob','hob','job','lob','mob','nob','ob','rob','sb','sib','so','sod','sol','son','sop','sos','sot','sow','soy','sub'},
'sober':	{'saber'},
'socialism':	{'socialist'},
'socialist':	{'socialism'},
'sock':	{'bock','cock','dock','jock','lock','mock','rock','sack','shock','sick','soak','socks','spock','stock','suck'},
'socket':	{'docket','pocket','rocket','sockets'},
'sockets':	{'pockets','socket'},
'socks':	{'cocks','docks','jocks','locks','rocks','sacks','shocks','sock','stocks','sucks'},
'sod':	{'bod','cod','dod','god','mod','nod','od','pod','rod','sad','sd','so','sob','soda','sol','sold','son','sop','sos','sot','sow','soy','std','tod'},
'soda':	{'coda','moda','sod','sofa'},
'sodium':	{'podium'},
'sodom':	{'sodomy'},
'sodomy':	{'sodom'},
'sofa':	{'soda','sofas','sofia','soft'},
'sofas':	{'sofa'},
'sofia':	{'sofa'},
'soft':	{'loft','oft','sift','sofa','soot','sort','sot'},
'soften':	{'often','softens','softer'},
'softens':	{'soften'},
'softer':	{'soften','sorter'},
'soho':	{'solo'},
'soil':	{'boil','coil','foil','oil','sail','soils','sol','soul','spoil','toil'},
'soiled':	{'boiled','coiled','oiled','sailed','smiled','spoiled'},
'soiling':	{'boiling','sailing','smiling','spoiling'},
'soils':	{'boils','coils','foils','oils','sails','soil','souls','spoils'},
'sol':	{'col','fol','pol','so','sob','sod','soil','sold','sole','solo','son','sop','sos','sot','soul','sow','soy','vol'},
'solar':	{'molar','polar','soar','sonar'},
'sold':	{'bold','cold','fold','gold','hold','mold','old','scold','sod','sol','sole','solid','solo','told'},
'solder':	{'bolder','colder','folder','holder','older','soldier','solver'},
'soldier':	{'solder','soldiers'},
'soldiers':	{'soldier'},
'sole':	{'cole','dole','hole','mole','ole','pole','role','sale','sol','sold','soles','solo','solve','some','sore','stole'},
'solely':	{'sorely'},
'soles':	{'holes','moles','poles','roles','sales','sole','solos','solves','sores'},
'solicitation':	{'solicitations'},
'solicitations':	{'solicitation'},
'solicitor':	{'solicitors'},
'solicitors':	{'solicitor'},
'solid':	{'slid','sold','solids'},
'solids':	{'solid'},
'solo':	{'polo','silo','soho','sol','sold','sole','solon','solos'},
'solomon':	{'salomon'},
'solon':	{'colon','salon','solo','solos','soon'},
'solos':	{'silos','soles','solo','solon'},
'solute':	{'salute'},
'solution':	{'solutions'},
'solutions':	{'solution'},
'solve':	{'sole','solved','solver','solves'},
'solved':	{'solve','solver','solves'},
'solvent':	{'solvents'},
'solvents':	{'solvent'},
'solver':	{'silver','solder','solve','solved','solvers','solves'},
'solvers':	{'solver','solves'},
'solves':	{'selves','soles','solve','solved','solver','solvers','wolves'},
'somali':	{'somalia'},
'somalia':	{'somali'},
'some':	{'come','dome','home','nome','rome','same','sole','sore','tome'},
'sometime':	{'sometimes'},
'sometimes':	{'sometime'},
'son':	{'con','don','hon','ion','mon','non','on','ron','sen','sin','sn','so','sob','sod','sol','song','sons','soon','sop','sos','sot','sow','sown','soy','sun','ton','von','won','yon'},
'sonar':	{'soar','solar'},
'sonata':	{'sonatas'},
'sonatas':	{'sonata'},
'song':	{'bong','dong','gong','long','pong','sang','sing','son','songs','sons','sung'},
'songbook':	{'songbooks'},
'songbooks':	{'songbook'},
'songs':	{'bongs','longs','sings','song','sons'},
'songwriter':	{'songwriters'},
'songwriters':	{'songwriter'},
'sonic':	{'ionic','tonic'},
'sonnet':	{'bonnet'},
'sonny':	{'bonny','sunny'},
'sons':	{'cons','ions','sans','sens','sins','son','song','songs','sos','sous','sows','suns','tons'},
'soon':	{'boon','coon','loon','moon','noon','solon','son','soot','sown','spoon'},
'soot':	{'boot','foot','hoot','loot','moot','root','scot','shoot','shot','slot','soft','soon','sort','sot','spot','swot'},
'soothing':	{'smoothing'},
'sop':	{'bop','cop','gop','hop','mop','op','pop','sap','sep','shop','sip','so','soap','sob','sod','sol','son','sos','sot','soup','sow','soy','stop','sup','top','wop'},
'sore':	{'bore','core','fore','gore','lore','more','ore','pore','score','shore','sire','sole','some','sores','sort','spore','store','sure','swore','tore','wore'},
'sorely':	{'solely','surely'},
'sores':	{'cores','ores','pores','scores','shores','soles','sore','sorts','spores','stores'},
'sorrow':	{'borrow','morrow','sorrows'},
'sorrows':	{'borrows','sorrow'},
'sorry':	{'worry'},
'sort':	{'fort','hort','port','short','snort','soft','soot','sore','sorta','sorts','sot','sport','tort','wort'},
'sorta':	{'aorta','sort','sorts'},
'sorted':	{'ported','sorter'},
'sorter':	{'porter','shorter','softer','sorted'},
'sorting':	{'porting','snorting','sporting'},
'sorts':	{'forts','ports','shorts','sores','sort','sorta','sports','torts'},
'sos':	{'cos','dos','hos','nos','os','sis','so','sob','sod','sol','son','sons','sop','sot','sous','sow','sows','soy','ss','sss'},
'sot':	{'bot','cot','dot','got','hot','lot','mot','not','pot','rot','sat','scot','set','shot','sit','slot','so','sob','sod','soft','sol','son','soot','sop','sort','sos','sow','soy','spot','swot','tot','wot'},
'sought':	{'bought','fought','ought'},
'soul':	{'foul','saul','seoul','soil','sol','souls','soup','sour','sous'},
'souls':	{'fouls','soils','soul','soups','sours','sous'},
'sound':	{'bound','found','hound','mound','pound','round','sounds','wound'},
'sounded':	{'bounded','founded','pounded','rounded','wounded'},
'sounding':	{'bounding','founding','pounding','rounding','wounding'},
'soundly':	{'roundly'},
'soundness':	{'roundness'},
'sounds':	{'bounds','hounds','mounds','pounds','rounds','sound','wounds'},
'soundtrack':	{'soundtracks'},
'soundtracks':	{'soundtrack'},
'soup':	{'coup','soap','sop','soul','soups','sour','sous','sup'},
'soups':	{'soaps','souls','soup','sours','sous'},
'sour':	{'four','hour','our','pour','soar','soul','soup','sours','sous','spur','tour','your'},
'source':	{'sourced','sources'},
'sourced':	{'source','sources','soured'},
'sources':	{'source','sourced'},
'sourcing':	{'souring'},
'soured':	{'poured','soared','sourced','toured'},
'souring':	{'pouring','soaring','sourcing','touring'},
'sourly':	{'hourly'},
'sours':	{'fours','hours','ours','pours','soars','souls','soups','sour','sous','tours','yours'},
'sous':	{'nous','sons','sos','soul','souls','soup','soups','sour','sours','sousa','sows'},
'sousa':	{'sous'},
'south':	{'mouth','youth'},
'southward':	{'southwards'},
'southwards':	{'southward'},
'souvenir':	{'souvenirs'},
'souvenirs':	{'souvenir'},
'soviet':	{'soviets'},
'soviets':	{'soviet'},
'sow':	{'bow','cow','how','low','now','ow','pow','row','saw','sew','show','slow','snow','so','sob','sod','sol','son','sop','sos','sot','sown','sows','soy','ssw','stow','sw','tow','vow','wow'},
'sowed':	{'bowed','owed','rowed','sawed','sewed','showed','slowed','snowed','towed','vowed'},
'sowing':	{'bowing','lowing','mowing','owing','rowing','sawing','sewing','showing','slowing','snowing','swing','towing'},
'sown':	{'down','gown','own','sewn','shown','son','soon','sow','sows','town'},
'sows':	{'bows','cows','hows','lows','rows','saws','sews','shows','slows','snows','sons','sos','sous','sow','sown','vows'},
'soy':	{'boy','coy','joy','say','shy','sky','sly','so','sob','sod','sol','son','sop','sos','sot','sow','spy','toy'},
'soybean':	{'soybeans'},
'soybeans':	{'soybean'},
'spa':	{'cpa','epa','gpa','pa','sa','sba','sea','ska','spam','span','spas','spat','spf','spy','ssa'},
'space':	{'pace','spaced','spacer','spaces','spade','spake','spare','spice'},
'spaced':	{'paced','space','spacer','spaces','spared','spiced'},
'spacer':	{'space','spaced','spacers','spaces'},
'spacers':	{'spacer','spaces'},
'spaces':	{'paces','space','spaced','spacer','spacers','spades','spares','spices'},
'spacing':	{'pacing','sparing'},
'spade':	{'sade','shade','space','spades','spake','spare'},
'spades':	{'shades','spaces','spade','spares'},
'spain':	{'pain','slain','span','spawn','spin','stain','swain'},
'spake':	{'sake','shake','snake','space','spade','spare','spike','spoke','stake'},
'spam':	{'sam','scam','seam','sham','siam','slam','spa','span','spas','spat','swam'},
'spamming':	{'slamming'},
'span':	{'pan','scan','shan','spa','spain','spam','spank','spans','spas','spat','spawn','spin','spun','swan'},
'spank':	{'sank','shank','span','spans','spark','swank'},
'spanked':	{'spanned','sparked'},
'spanking':	{'spankings','spanning','sparking'},
'spankings':	{'spanking'},
'spanned':	{'scanned','spanked','spawned'},
'spanning':	{'scanning','spanking','spawning','spinning'},
'spans':	{'pans','sans','scans','span','spank','spas','spins','swans'},
'spare':	{'scare','share','snare','space','spade','spake','spared','spares','spark','sparse','spire','spore','stare'},
'spared':	{'pared','scared','shared','soared','spaced','spare','spares','sparked','stared'},
'spares':	{'scares','shares','spaces','spades','spare','spared','spires','spores','stares'},
'sparing':	{'scaring','sharing','soaring','spacing','sparking','spring','staring'},
'spark':	{'park','shark','spank','spare','stark'},
'sparked':	{'parked','spanked','spared'},
'sparking':	{'parking','spanking','sparing','sparkling'},
'sparkling':	{'sparking'},
'sparse':	{'parse','spare'},
'sparta':	{'spartan'},
'spartan':	{'sparta'},
'spas':	{'pas','seas','spa','spam','span','spans','spat'},
'spat':	{'pat','sat','scat','seat','spa','spam','span','spas','spit','spot','stat','swat'},
'spawn':	{'pawn','shawn','spain','span'},
'spawned':	{'spanned'},
'spawning':	{'spanning'},
'speak':	{'peak','sneak','speaks','spear','speck','steak'},
'speaker':	{'sneaker','speakers'},
'speakers':	{'sneakers','speaker'},
'speaking':	{'peaking','sneaking'},
'speaks':	{'peaks','speak','steaks'},
'spear':	{'pear','shear','smear','speak','swear'},
'spec':	{'opec','sec','speck','specs','sped'},
'special':	{'especial','specials'},
'specialisation':	{'specialization'},
'specialise':	{'specialised','specialist','specialize'},
'specialised':	{'specialise','specialized'},
'specialist':	{'specialise','specialists'},
'specialists':	{'specialist'},
'specialities':	{'specialties'},
'speciality':	{'specialty'},
'specialization':	{'specialisation','specializations'},
'specializations':	{'specialization'},
'specialize':	{'specialise','specialized','specializes'},
'specialized':	{'specialised','specialize','specializes'},
'specializes':	{'specialize','specialized'},
'specially':	{'especially','specialty'},
'specials':	{'special'},
'specialties':	{'specialities'},
'specialty':	{'speciality','specially'},
'specific':	{'specifics'},
'specification':	{'specifications'},
'specifications':	{'specification'},
'specifics':	{'specific','specifies'},
'specified':	{'specifies'},
'specifies':	{'specifics','specified'},
'specimen':	{'specimens'},
'specimens':	{'specimen'},
'speck':	{'peck','speak','spec','specs','spock'},
'specs':	{'spec','speck'},
'spectacle':	{'spectacles'},
'spectacles':	{'spectacle'},
'spectator':	{'spectators'},
'spectators':	{'spectator'},
'speculate':	{'speculated'},
'speculated':	{'speculate'},
'speculation':	{'speculations'},
'speculations':	{'speculation'},
'sped':	{'seed','shed','sled','spec','speed','spend','sued'},
'speed':	{'seed','sped','speeds','speedy','spend','steed'},
'speeding':	{'seeding','spending'},
'speeds':	{'seeds','speed','speedy','spends'},
'speedy':	{'speed','speeds'},
'spell':	{'sell','shell','smell','spells','spelt','spill','swell'},
'spelled':	{'shelled','smelled','spilled','swelled'},
'spelling':	{'selling','shelling','smelling','spellings','spilling','swelling'},
'spellings':	{'spelling'},
'spells':	{'sells','shells','smells','spell','spills','swells'},
'spelt':	{'smelt','spell','spent'},
'spend':	{'send','sped','speed','spends','spent'},
'spending':	{'pending','sending','speeding'},
'spends':	{'sends','speeds','spend'},
'spent':	{'scent','sent','spelt','spend'},
'sperm':	{'perm'},
'sperry':	{'perry','sherry'},
'spf':	{'spa','spy'},
'sphere':	{'spheres'},
'spheres':	{'sphere'},
'spice':	{'slice','space','spiced','spices','spicy','spike','spine','spire','spite','splice'},
'spiced':	{'sliced','spaced','spice','spices','spiked'},
'spices':	{'slices','spaces','spice','spiced','spies','spikes','spines','spires','splices'},
'spicy':	{'spice'},
'spider':	{'slider','spiders'},
'spiders':	{'sliders','spider'},
'spiel':	{'spies','spill'},
'spies':	{'pies','skies','spices','spiel','spikes','spines','spins','spires','spits'},
'spike':	{'pike','spake','spice','spiked','spikes','spine','spire','spite','spoke'},
'spiked':	{'spiced','spike','spikes'},
'spikes':	{'pikes','spices','spies','spike','spiked','spines','spires','spokes'},
'spill':	{'pill','sill','skill','spell','spiel','spills','still'},
'spilled':	{'skilled','spelled'},
'spilling':	{'shilling','spelling'},
'spills':	{'pills','skills','spells','spill','stills'},
'spin':	{'pin','shin','sin','skin','spain','span','spine','spins','spit','spun'},
'spinal':	{'spiral'},
'spine':	{'pine','seine','shine','sine','spice','spike','spin','spines','spins','spire','spite','spline','swine'},
'spines':	{'pines','shines','spices','spies','spikes','spine','spins','spires'},
'spinner':	{'sinner','skinner','spinners'},
'spinners':	{'sinners','spinner'},
'spinning':	{'pinning','skinning','spanning'},
'spins':	{'pins','sins','skins','spans','spies','spin','spine','spines','spits'},
'spiral':	{'spinal'},
'spire':	{'aspire','shire','sire','spare','spice','spike','spine','spires','spite','spore'},
'spires':	{'spares','spices','spies','spikes','spines','spire','spores'},
'spirit':	{'spirits'},
'spirits':	{'spirit'},
'spit':	{'pit','shit','sit','skit','slit','spat','spin','spite','spits','split','spot','suit'},
'spite':	{'site','spice','spike','spine','spire','spit','spits','sprite','suite'},
'spits':	{'pits','sits','slits','spies','spins','spit','spite','splits','spots','suits'},
'spitting':	{'shitting','sitting','splitting','spotting'},
'splash':	{'slash'},
'splashed':	{'slashed'},
'splashing':	{'slashing'},
'splendor':	{'splendour'},
'splendour':	{'splendor'},
'splice':	{'slice','spice','splices','spline'},
'splices':	{'slices','spices','splice'},
'splicing':	{'slicing'},
'spline':	{'saline','spine','splice'},
'splinter':	{'splitter'},
'split':	{'slit','spit','splits'},
'splits':	{'slits','spits','split'},
'splitter':	{'splinter','splitters'},
'splitters':	{'splitter'},
'splitting':	{'spitting'},
'spock':	{'shock','sock','speck','stock'},
'spoil':	{'soil','spoils','spool'},
'spoiled':	{'soiled','spoiler'},
'spoiler':	{'spoiled','spoilers'},
'spoilers':	{'spoiler'},
'spoiling':	{'soiling'},
'spoils':	{'soils','spoil'},
'spoke':	{'poke','smoke','spake','spike','spoken','spokes','spore','stoke'},
'spoken':	{'spoke','spokes'},
'spokes':	{'smokes','spikes','spoke','spoken','spores'},
'sponge':	{'sponges'},
'sponges':	{'sponge'},
'sponsor':	{'sponsors'},
'sponsors':	{'sponsor'},
'sponsorship':	{'sponsorships'},
'sponsorships':	{'sponsorship'},
'spoof':	{'spool','spoon'},
'spool':	{'pool','spoil','spoof','spoon','stool'},
'spoon':	{'soon','spoof','spool','spoons'},
'spoons':	{'spoon'},
'spore':	{'pore','score','shore','sore','spare','spire','spoke','spores','sport','store','swore'},
'spores':	{'pores','scores','shores','sores','spares','spires','spokes','spore','sports','stores'},
'sport':	{'port','short','snort','sort','spore','sports','sporty','spot','spout'},
'sporting':	{'porting','snorting','sorting','spotting'},
'sports':	{'ports','shorts','sorts','spores','sport','sporty','spots'},
'sporty':	{'sport','sports'},
'spot':	{'pot','scot','shot','slot','soot','sot','spat','spit','sport','spots','spout','swot'},
'spotlight':	{'spotlights'},
'spotlights':	{'spotlight'},
'spots':	{'pots','scots','shots','slots','spits','sports','spot'},
'spotted':	{'potted','slotted'},
'spotting':	{'potting','spitting','sporting'},
'spouse':	{'spouses'},
'spouses':	{'spouse'},
'spout':	{'scout','shout','sport','spot','stout'},
'sprang':	{'spring','sprung'},
'spray':	{'pray','sprays','stray'},
'sprayed':	{'prayed'},
'spraying':	{'praying'},
'sprays':	{'prays','spray'},
'spread':	{'spreads'},
'spreads':	{'spread'},
'spreadsheet':	{'spreadsheets'},
'spreadsheets':	{'spreadsheet'},
'spring':	{'sparing','sprang','springs','sprint','sprung','spying','string'},
'springer':	{'stringer'},
'springing':	{'stringing'},
'springs':	{'spring','strings'},
'sprinkle':	{'sprinkled','sprinkler'},
'sprinkled':	{'sprinkle','sprinkler'},
'sprinkler':	{'sprinkle','sprinkled'},
'sprint':	{'print','spring'},
'sprite':	{'spite'},
'sprung':	{'sprang','spring','strung'},
'spun':	{'pun','shun','span','spin','spur','stun','sun'},
'spur':	{'sour','spun'},
'spy':	{'say','shy','sky','sly','soy','spa','spf'},
'spying':	{'saying','spring'},
'squad':	{'quad','squads','squat','squaw','squid'},
'squads':	{'quads','squad'},
'square':	{'squared','squarer','squares','squire'},
'squared':	{'square','squarer','squares'},
'squarer':	{'square','squared','squares'},
'squares':	{'square','squared','squarer','squarest'},
'squarest':	{'squares'},
'squash':	{'squish'},
'squat':	{'squad','squaw'},
'squaw':	{'squad','squat'},
'squeeze':	{'squeezed'},
'squeezed':	{'squeeze'},
'squid':	{'quid','squad'},
'squire':	{'esquire','square','squirt'},
'squirrel':	{'squirrels'},
'squirrels':	{'squirrel'},
'squirt':	{'squire','squirts'},
'squirts':	{'squirt'},
'squish':	{'squash'},
'sr':	{'ar','br','cr','dr','er','fr','hr','ir','jr','kr','lr','mr','or','pr','qr','r','sa','sb','sc','sd','se','sh','si','sir','sm','sn','so','ss','su','sw','ur','yr','zr'},
'ss':	{'as','ass','bs','cs','es','hs','is','ks','ms','os','ps','sa','sb','sc','sd','se','sh','si','sis','sm','sn','so','sos','sr','ssa','sse','sss','ssw','su','sw','ts','us','vs'},
'ssa':	{'gsa','sa','sba','sea','ska','spa','ss','sse','sss','ssw','usa'},
'sse':	{'ese','se','see','she','ss','ssa','sss','ssw','sue','use'},
'sss':	{'ass','sis','sos','ss','ssa','sse','ssw'},
'ssw':	{'saw','sew','sow','ss','ssa','sse','sss','sw','wsw'},
'stab':	{'slab','stag','star','stat','stay','stub','tab'},
'stabbed':	{'tabbed'},
'stabilisation':	{'stabilization'},
'stabilise':	{'stabilised','stabilises','stabilize'},
'stabilised':	{'stabilise','stabilises','stabilized'},
'stabilises':	{'stabilise','stabilised','stabilizes'},
'stabilising':	{'stabilizing'},
'stabilization':	{'stabilisation'},
'stabilize':	{'stabilise','stabilized','stabilizer','stabilizes'},
'stabilized':	{'stabilised','stabilize','stabilizer','stabilizes'},
'stabilizer':	{'stabilize','stabilized','stabilizes'},
'stabilizes':	{'stabilises','stabilize','stabilized','stabilizer'},
'stabilizing':	{'stabilising'},
'stable':	{'sable','stables','stale','staple','table'},
'stables':	{'stable','tables'},
'stack':	{'sack','shack','slack','smack','snack','stacks','stalk','stark','stick','stock','stuck','tack'},
'stacked':	{'sacked','stacker','stocked'},
'stacker':	{'stacked','stalker','sticker'},
'stacking':	{'stalking','sticking','stocking'},
'stacks':	{'sacks','snacks','stack','stalks','sticks','stocks'},
'stadium':	{'stadiums'},
'stadiums':	{'stadium'},
'staff':	{'staffs','stiff','stuff'},
'staffed':	{'stuffed'},
'staffing':	{'stuffing'},
'staffs':	{'staff','stuffs'},
'stag':	{'sag','shag','slag','snag','stab','stage','star','stat','stay','tag'},
'stage':	{'sage','stag','staged','stages','stake','stale','stare','state'},
'staged':	{'stage','stages','stared','stated','stayed'},
'stages':	{'sages','stage','staged','stakes','stares','states'},
'staging':	{'staring','stating','staying'},
'stain':	{'slain','spain','stains','stair','stalin','stein','strain','swain'},
'stained':	{'strained'},
'staining':	{'straining'},
'stains':	{'stain','stairs','strains'},
'stair':	{'stain','stairs','star','starr','stir'},
'stairs':	{'stains','stair','stars','stirs'},
'stake':	{'sake','shake','snake','spake','stage','stakes','stale','stare','state','stoke','take'},
'stakeholder':	{'stakeholders'},
'stakeholders':	{'stakeholder'},
'stakes':	{'sakes','shakes','snakes','stages','stake','stares','states','takes'},
'stale':	{'sale','scale','shale','stable','stage','stake','stalk','stall','staple','stare','state','stole','style','tale'},
'stalin':	{'stain'},
'stalk':	{'stack','stale','stalks','stall','stark','talk'},
'stalker':	{'stacker'},
'stalking':	{'stacking','talking'},
'stalks':	{'stacks','stalk','stalls','talks'},
'stall':	{'shall','small','stale','stalk','stalls','still','tall'},
'stallion':	{'stallions'},
'stallions':	{'stallion'},
'stalls':	{'stalks','stall','stills'},
'stamp':	{'scamp','stamps','stomp','stump','swamp'},
'stamped':	{'stampede','stumped','swamped'},
'stampede':	{'stamped'},
'stamping':	{'stomping'},
'stamps':	{'stamp','stumps','swamps'},
'stance':	{'stances','tance'},
'stances':	{'stance'},
'stand':	{'sand','stands','strand'},
'standard':	{'standards'},
'standardisation':	{'standardization'},
'standardised':	{'standardized'},
'standardization':	{'standardisation'},
'standardize':	{'standardized'},
'standardized':	{'standardised','standardize'},
'standards':	{'standard'},
'standing':	{'sanding','standings'},
'standings':	{'standing'},
'stands':	{'sands','stand','strands'},
'staple':	{'stable','stale'},
'star':	{'scar','soar','stab','stag','stair','stare','stark','starr','stars','start','stat','stay','stir','tar'},
'starch':	{'search'},
'stare':	{'scare','share','snare','spare','stage','stake','stale','star','stared','stares','stark','starr','stars','start','starve','state','store'},
'stared':	{'scared','shared','soared','spared','staged','stare','stares','starred','started','starved','stated','stayed','stored'},
'stares':	{'scares','shares','spares','stages','stakes','stare','stared','stars','starts','states','stores'},
'staring':	{'scaring','sharing','soaring','sparing','staging','starling','starring','starting','starving','stating','staying','storing','string'},
'stark':	{'shark','spark','stack','stalk','star','stare','starr','stars','start','stork'},
'starling':	{'staring','starring','starting','startling','starving','sterling'},
'starr':	{'stair','star','stare','stark','starry','stars','start'},
'starred':	{'scarred','stared','started','starved','stirred'},
'starring':	{'scarring','staring','starling','starting','starving','stirring'},
'starry':	{'starr'},
'stars':	{'scars','soars','stairs','star','stare','stares','stark','starr','start','starts','stats','stays','stirs'},
'start':	{'smart','star','stare','stark','starr','stars','starts','stat','stuart','tart'},
'started':	{'stared','starred','starter','startled','starved','stated'},
'starter':	{'smarter','started','starters'},
'starters':	{'starter'},
'starting':	{'staring','starling','starring','startling','starving','stating'},
'startled':	{'started'},
'startling':	{'starling','starting'},
'starts':	{'smarts','stares','stars','start','stats','tarts'},
'starve':	{'stare','starved'},
'starved':	{'stared','starred','started','starve'},
'starving':	{'staring','starling','starring','starting'},
'stash':	{'sash','slash','smash'},
'stat':	{'sat','scat','seat','spat','stab','stag','star','start','state','stats','stay','swat','tat'},
'state':	{'estate','skate','slate','stage','stake','stale','stare','stat','stated','states','stats','statue','tate'},
'stated':	{'seated','slated','staged','stared','started','state','states','stayed'},
'statement':	{'statements'},
'statements':	{'statement'},
'states':	{'estates','skates','stages','stakes','stares','state','stated','stats','statues','status'},
'stating':	{'seating','skating','staging','staring','starting','staying'},
'station':	{'stations'},
'stationary':	{'stationery'},
'stationery':	{'stationary'},
'stations':	{'station'},
'statistic':	{'statistics'},
'statistician':	{'statisticians'},
'statisticians':	{'statistician'},
'statistics':	{'statistic'},
'stats':	{'seats','stars','starts','stat','state','states','status','stays'},
'statue':	{'state','statues','stature','status','statute'},
'statues':	{'states','statue','status','statutes'},
'stature':	{'statue','statute'},
'status':	{'states','stats','statue','statues','stratus'},
'statute':	{'statue','stature','statutes'},
'statutes':	{'statues','statute'},
'stay':	{'say','shay','slay','stab','stag','star','stat','stays','stray','sway'},
'stayed':	{'staged','stared','stated','swayed'},
'staying':	{'saying','slaying','staging','staring','stating','swaying'},
'stays':	{'says','stars','stats','stay'},
'std':	{'sad','sd','sod','stud'},
'stead':	{'steady','steak','steal','steam','steed'},
'steadied':	{'steadies'},
'steadies':	{'steadied'},
'steady':	{'stead','steamy'},
'steak':	{'sneak','speak','stead','steaks','steal','steam','streak','teak'},
'steaks':	{'speaks','steak','steals','steams','streaks'},
'steal':	{'seal','stead','steak','steals','steam','steel','teal'},
'stealing':	{'sealing','steaming','sterling'},
'steals':	{'seals','steaks','steal','steams','steels'},
'steam':	{'seam','stead','steak','steal','steams','steamy','stem','stream','team'},
'steamed':	{'steamer','stemmed','streamed','teamed'},
'steamer':	{'steamed','steamers'},
'steamers':	{'steamer'},
'steaming':	{'stealing','stemming','streaming','teaming'},
'steams':	{'seams','steaks','steals','steam','steamy','stems','streams','teams'},
'steamy':	{'steady','steam','steams'},
'steed':	{'seed','speed','stead','steel','steep','steer'},
'steel':	{'steal','steed','steele','steels','steely','steep','steer'},
'steele':	{'steel','steels','steely'},
'steels':	{'steals','steel','steele','steely','steers'},
'steely':	{'steel','steele','steels'},
'steep':	{'sheep','sleep','steed','steel','steer','step','strep','sweep'},
'steeped':	{'steeper','steered','stepped'},
'steeper':	{'sleeper','steeped','sweeper'},
'steer':	{'seer','sheer','steed','steel','steep','steers'},
'steered':	{'steeped'},
'steers':	{'steels','steer'},
'stein':	{'stain','stern'},
'stella':	{'stellar'},
'stellar':	{'stella'},
'stem':	{'item','seem','steam','stems','step','stew'},
'stemmed':	{'steamed'},
'stemming':	{'steaming'},
'stems':	{'items','seems','steams','stem','steps','stews'},
'stencil':	{'stencils'},
'stencils':	{'stencil'},
'step':	{'sep','steep','stem','steps','stew','stop','strep'},
'stepped':	{'steeped','stopped'},
'stepping':	{'stopping'},
'steps':	{'stems','step','stews','stops'},
'stereo':	{'stereos'},
'stereos':	{'stereo'},
'stereotype':	{'stereotypes'},
'stereotypes':	{'stereotype'},
'sterling':	{'starling','stealing'},
'stern':	{'stein','tern'},
'steroid':	{'asteroid','steroids'},
'steroids':	{'asteroids','steroid'},
'stew':	{'sew','shew','skew','slew','stem','step','stews','stow'},
'steward':	{'seward','stewards','stewart'},
'stewards':	{'steward'},
'stewart':	{'steward'},
'stews':	{'sews','stems','steps','stew'},
'stick':	{'sick','slick','stack','sticks','sticky','stink','stock','stuck','tick'},
'sticker':	{'sicker','stacker','stickers','ticker'},
'stickers':	{'sticker'},
'sticking':	{'stacking','stocking','ticking'},
'sticks':	{'stacks','stick','sticky','stinks','stocks','ticks'},
'sticky':	{'stick','sticks'},
'stiff':	{'sniff','staff','stuff','tiff'},
'stiffen':	{'stiffens','stiffer'},
'stiffens':	{'stiffen'},
'stiffer':	{'sniffer','stiffen'},
'stigma':	{'sigma'},
'still':	{'sill','skill','spill','stall','stills','till'},
'stills':	{'skills','spills','stalls','still'},
'stimulant':	{'stimulants'},
'stimulants':	{'stimulant'},
'stimulate':	{'simulate','stimulated','stimulates','stipulate'},
'stimulated':	{'simulated','stimulate','stimulates','stipulated'},
'stimulates':	{'simulates','stimulate','stimulated','stipulates'},
'stimulating':	{'simulating'},
'stimulation':	{'simulation','stipulation'},
'sting':	{'sing','siting','sling','stings','stink','stint','string','stung','suing','swing','ting'},
'stinger':	{'singer','stringer','swinger'},
'stinging':	{'singing','stringing','swinging'},
'stings':	{'sings','slings','sting','stinks','strings','swings'},
'stink':	{'sink','stick','sting','stinks','stint'},
'stinks':	{'sinks','sticks','stings','stink'},
'stint':	{'saint','sting','stink','stunt','tint'},
'stipulate':	{'stimulate','stipulated','stipulates'},
'stipulated':	{'stimulated','stipulate','stipulates'},
'stipulates':	{'stimulates','stipulate','stipulated'},
'stipulation':	{'stimulation','stipulations'},
'stipulations':	{'stipulation'},
'stir':	{'sir','stair','star','stirs'},
'stirred':	{'starred'},
'stirring':	{'starring'},
'stirs':	{'stairs','stars','stir'},
'stitch':	{'switch'},
'stitched':	{'stitches','switched'},
'stitches':	{'stitched','switches'},
'stitching':	{'switching'},
'stock':	{'shock','sock','spock','stack','stick','stocks','stork','stuck'},
'stocked':	{'shocked','stacked'},
'stockholder':	{'stockholders'},
'stockholders':	{'stockholder'},
'stocking':	{'shocking','stacking','sticking','stockings'},
'stockings':	{'stocking'},
'stocks':	{'shocks','socks','stacks','sticks','stock'},
'stoke':	{'smoke','spoke','stake','stoker','stole','stone','store','stove','stowe','stroke'},
'stoker':	{'smoker','stoke'},
'stole':	{'sole','stale','stoke','stolen','stone','store','stove','stowe','style'},
'stolen':	{'stole'},
'stomach':	{'stomachs'},
'stomachs':	{'stomach'},
'stomp':	{'stamp','stop','stump'},
'stomping':	{'stamping','stopping'},
'stone':	{'shone','stoke','stole','stoned','stones','stony','store','stove','stowe','tone'},
'stoned':	{'stone','stones','stored','toned'},
'stones':	{'stone','stoned','stores','stoves','tones'},
'stoning':	{'storing','toning'},
'stony':	{'stone','story'},
'stood':	{'stool'},
'stool':	{'spool','stood','stools','tool'},
'stools':	{'stool','tools'},
'stop':	{'atop','shop','sop','step','stomp','stops','stow','top'},
'stopped':	{'shopped','stepped','stopper','topped'},
'stopper':	{'shopper','stopped','stoppers','topper'},
'stoppers':	{'shoppers','stopper','toppers'},
'stopping':	{'shopping','stepping','stomping','topping'},
'stops':	{'shops','steps','stop','tops'},
'store':	{'score','shore','sore','spore','stare','stoke','stole','stone','stored','stores','storey','stork','storm','story','stove','stowe','swore','tore'},
'stored':	{'scored','stared','stoned','store','stores','storey','stormed'},
'stores':	{'scores','shores','sores','spores','stares','stones','store','stored','storey','stories','storms','stoves'},
'storey':	{'store','stored','stores','stormy','story'},
'stories':	{'stores'},
'storing':	{'scoring','snoring','staring','stoning','storming','string'},
'stork':	{'stark','stock','store','storm','story'},
'storm':	{'store','stork','storms','stormy','story'},
'stormed':	{'stored'},
'storming':	{'storing'},
'storms':	{'stores','storm','stormy'},
'stormy':	{'storey','storm','storms','story'},
'story':	{'stony','store','storey','stork','storm','stormy','tory'},
'stout':	{'scout','shout','spout','strut','tout'},
'stove':	{'shove','stoke','stole','stone','store','stoves','stowe'},
'stoves':	{'stones','stores','stove'},
'stow':	{'show','slow','snow','sow','stew','stop','stowe','tow'},
'stowe':	{'stoke','stole','stone','store','stove','stow'},
'straighten':	{'straightens','straighter'},
'straightens':	{'straighten'},
'straighter':	{'straighten'},
'strain':	{'stain','strains','strait','train'},
'strained':	{'stained','trained'},
'straining':	{'staining','training'},
'strains':	{'stains','strain','straits','trains'},
'strait':	{'strain','straits','trait'},
'straits':	{'strains','strait','traits'},
'strand':	{'stand','strands'},
'strands':	{'stands','strand'},
'strange':	{'stranger'},
'stranger':	{'strange','strangers','stringer','stronger'},
'strangers':	{'stranger'},
'strangest':	{'strongest'},
'strap':	{'scrap','straps','straw','stray','strep','strip','trap'},
'strapped':	{'scrapped','stripped','trapped'},
'strapping':	{'stripping','trapping'},
'straps':	{'scraps','strap','straws','strips','traps'},
'strategist':	{'strategists'},
'strategists':	{'strategist'},
'stratum':	{'stratus'},
'stratus':	{'status','stratum'},
'straw':	{'strap','straws','stray'},
'straws':	{'straps','straw'},
'stray':	{'astray','spray','stay','strap','straw','tray'},
'streak':	{'steak','streaks','stream'},
'streaks':	{'steaks','streak','streams'},
'stream':	{'scream','steam','streak','streams'},
'streamed':	{'screamed','steamed'},
'streaming':	{'screaming','steaming'},
'streamline':	{'streamlined','streamlines'},
'streamlined':	{'streamline','streamlines'},
'streamlines':	{'streamline','streamlined'},
'streams':	{'screams','steams','streaks','stream'},
'street':	{'streets'},
'streets':	{'street'},
'strength':	{'strengths'},
'strengthen':	{'strengthens'},
'strengthens':	{'strengthen'},
'strengths':	{'strength'},
'strep':	{'steep','step','strap','strip'},
'stressed':	{'stresses'},
'stresses':	{'stressed'},
'stretched':	{'stretcher','stretches'},
'stretcher':	{'stretched','stretches'},
'stretches':	{'stretched','stretcher'},
'stride':	{'strider','strides','strife','strike','stripe','strive'},
'strider':	{'stride','strides','striker'},
'strides':	{'stride','strider','strikes','stripes','strives'},
'strife':	{'stride','strike','stripe','strive'},
'strike':	{'stride','strife','striker','strikes','stripe','strive','stroke'},
'striker':	{'strider','strike','strikers','strikes'},
'strikers':	{'striker','strikes'},
'strikes':	{'strides','strike','striker','strikers','stripes','strives','strokes','trikes'},
'striking':	{'striping','striving','stroking'},
'string':	{'spring','staring','sting','storing','strings','strong','strung'},
'stringed':	{'stringer'},
'stringer':	{'springer','stinger','stranger','stringed','stronger'},
'stringing':	{'springing','stinging'},
'strings':	{'springs','stings','string'},
'strip':	{'strap','strep','stripe','strips','trip'},
'stripe':	{'stride','strife','strike','strip','striped','stripes','strips','strive'},
'striped':	{'stripe','stripes','stripped'},
'stripes':	{'strides','strikes','stripe','striped','strips','strives'},
'striping':	{'striking','stripping','striving'},
'stripped':	{'strapped','striped','stripper','tripped'},
'stripper':	{'stripped','strippers'},
'strippers':	{'stripper'},
'stripping':	{'strapping','striping','tripping'},
'strips':	{'straps','strip','stripe','stripes','trips'},
'strive':	{'stride','strife','strike','stripe','strives'},
'strives':	{'strides','strikes','stripes','strive'},
'striving':	{'striking','striping'},
'strobe':	{'stroke'},
'stroke':	{'stoke','strike','strobe','stroked','strokes'},
'stroked':	{'stroke','strokes'},
'strokes':	{'strikes','stroke','stroked'},
'stroking':	{'striking'},
'stroll':	{'scroll','troll'},
'stroller':	{'strollers'},
'strollers':	{'stroller'},
'strolling':	{'scrolling','trolling'},
'strong':	{'string','strung'},
'stronger':	{'stranger','stringer'},
'strongest':	{'strangest'},
'struck':	{'stuck','truck'},
'structure':	{'structured','structures'},
'structured':	{'structure','structures'},
'structures':	{'structure','structured'},
'struggle':	{'struggled','struggles'},
'struggled':	{'struggle','struggles'},
'struggles':	{'struggle','struggled'},
'strung':	{'sprung','string','strong','stung'},
'strut':	{'stout','struts'},
'struts':	{'strut'},
'stuart':	{'start'},
'stub':	{'stab','stubs','stud','stun','sub','tub'},
'stubs':	{'stub','studs','subs','tubs'},
'stuck':	{'stack','stick','stock','struck','suck','tuck'},
'stud':	{'std','stub','studs','study','stun'},
'studded':	{'studied'},
'student':	{'students'},
'students':	{'student'},
'studied':	{'studded','studies'},
'studies':	{'studied','studios'},
'studio':	{'studios'},
'studios':	{'studies','studio'},
'studs':	{'stubs','stud','study'},
'study':	{'stud','studs','sturdy'},
'stuff':	{'snuff','staff','stiff','stuffs'},
'stuffed':	{'staffed'},
'stuffing':	{'staffing'},
'stuffs':	{'staffs','stuff'},
'stumble':	{'stumbled','stumbles','tumble'},
'stumbled':	{'stumble','stumbles','tumbled'},
'stumbles':	{'stumble','stumbled'},
'stumbling':	{'tumbling'},
'stump':	{'slump','stamp','stomp','stumps','sump'},
'stumped':	{'stamped'},
'stumps':	{'stamps','stump'},
'stun':	{'shun','spun','stub','stud','stung','stunt','sun'},
'stung':	{'sting','strung','stun','stunt','sung','swung'},
'stunt':	{'shunt','stint','stun','stung','stunts'},
'stunts':	{'stunt'},
'sturdy':	{'study'},
'sturgeon':	{'surgeon'},
'style':	{'stale','stole','styled','styles'},
'styled':	{'style','styles'},
'styles':	{'style','styled','stylus'},
'stylise':	{'stylised','stylises','stylish','stylist','stylize'},
'stylised':	{'stylise','stylises','stylized'},
'stylises':	{'stylise','stylised','stylizes'},
'stylish':	{'stylise','stylist'},
'stylising':	{'stylizing'},
'stylist':	{'stylise','stylish'},
'stylize':	{'stylise','stylized','stylizes'},
'stylized':	{'stylised','stylize','stylizes'},
'stylizes':	{'stylises','stylize','stylized'},
'stylizing':	{'stylising'},
'stylus':	{'styles'},
'su':	{'au','cu','du','eu','gu','ju','lu','mu','nu','pu','ru','sa','sb','sc','sd','se','sh','si','sm','sn','so','sr','ss','sub','sue','sum','sun','sup','suv','sw','u','wu','zu'},
'sub':	{'cub','dub','hub','pub','rub','sb','sib','sob','stub','su','subs','sue','sum','sun','sup','suv','tub'},
'subcontractor':	{'subcontractors'},
'subcontractors':	{'subcontractor'},
'subdivision':	{'subdivisions'},
'subdivisions':	{'subdivision'},
'subgroup':	{'subgroups'},
'subgroups':	{'subgroup'},
'subject':	{'subjects'},
'subjects':	{'subject'},
'sublets':	{'subsets'},
'submarine':	{'submarines'},
'submarines':	{'submarine'},
'submission':	{'submissions'},
'submissions':	{'submission'},
'submit':	{'submits','summit'},
'submits':	{'submit','summits'},
'submitted':	{'submitter'},
'submitter':	{'submitted'},
'subordinate':	{'subordinated','subordinates'},
'subordinated':	{'subordinate','subordinates'},
'subordinates':	{'subordinate','subordinated'},
'subpoena':	{'subpoenas'},
'subpoenas':	{'subpoena'},
'subroutine':	{'subroutines'},
'subroutines':	{'subroutine'},
'subs':	{'hubs','pubs','rubs','stubs','sub','sums','suns','tubs'},
'subscribe':	{'subscribed','subscriber','subscribes'},
'subscribed':	{'subscribe','subscriber','subscribes'},
'subscriber':	{'subscribe','subscribed','subscribers','subscribes'},
'subscribers':	{'subscriber','subscribes'},
'subscribes':	{'subscribe','subscribed','subscriber','subscribers'},
'subscription':	{'subscriptions'},
'subscriptions':	{'subscription'},
'subsection':	{'subsections'},
'subsections':	{'subsection'},
'subset':	{'subsets','sunset'},
'subsets':	{'sublets','subset','sunsets'},
'subsidies':	{'subsidises','subsidizes'},
'subsidise':	{'subsidised','subsidises','subsidize'},
'subsidised':	{'subsidise','subsidises','subsidized'},
'subsidises':	{'subsidies','subsidise','subsidised','subsidizes'},
'subsidising':	{'subsidizing'},
'subsidize':	{'subsidise','subsidized','subsidizes'},
'subsidized':	{'subsidised','subsidize','subsidizes'},
'subsidizes':	{'subsidies','subsidises','subsidize','subsidized'},
'subsidizing':	{'subsidising'},
'substance':	{'substances'},
'substances':	{'substance'},
'substantiate':	{'substantiated'},
'substantiated':	{'substantiate'},
'substitute':	{'substituted','substitutes'},
'substituted':	{'substitute','substitutes'},
'substitutes':	{'substitute','substituted'},
'substitution':	{'substitutions'},
'substitutions':	{'substitution'},
'substrate':	{'substrates'},
'substrates':	{'substrate'},
'subsystem':	{'subsystems'},
'subsystems':	{'subsystem'},
'subtitle':	{'subtitled','subtitles'},
'subtitled':	{'subtitle','subtitles'},
'subtitles':	{'subtitle','subtitled'},
'subtle':	{'subtly'},
'subtly':	{'subtle'},
'subtype':	{'subtypes'},
'subtypes':	{'subtype'},
'subunit':	{'subunits'},
'subunits':	{'subunit'},
'suburb':	{'suburbs'},
'suburbs':	{'suburb'},
'succeed':	{'succeeds'},
'succeeds':	{'succeed'},
'succession':	{'successions'},
'successions':	{'succession'},
'successor':	{'successors'},
'successors':	{'successor'},
'such':	{'much','suck'},
'suck':	{'buck','duck','fuck','huck','luck','muck','puck','sack','sick','sock','stuck','such','sucks','sunk','tuck'},
'sucked':	{'ducked','sacked','sucker','tucked'},
'sucker':	{'fucker','sicker','sucked','suckers','tucker'},
'suckers':	{'sucker'},
'sucking':	{'ducking','fucking'},
'sucks':	{'bucks','ducks','sacks','socks','suck'},
'sucre':	{'sure'},
'suction':	{'auction','section'},
'sudan':	{'sedan'},
'sudden':	{'sadden'},
'sue':	{'cue','due','hue','que','rue','se','see','she','sse','su','sub','sued','suez','sum','sun','sup','sure','suv'},
'sued':	{'seed','shed','sled','sped','sue','suede','suez'},
'suede':	{'sued'},
'suez':	{'sue','sued'},
'suffer':	{'buffer','suffers','surfer'},
'suffered':	{'buffered'},
'suffering':	{'buffering','sufferings'},
'sufferings':	{'suffering'},
'suffers':	{'buffers','suffer','surfers'},
'suffice':	{'suffices'},
'suffices':	{'suffice','suffixes'},
'suffixes':	{'suffices'},
'sugar':	{'sugars','sugary'},
'sugars':	{'sugar','sugary'},
'sugary':	{'sugar','sugars'},
'suggest':	{'suggests'},
'suggestion':	{'suggestions'},
'suggestions':	{'suggestion'},
'suggests':	{'suggest'},
'suicide':	{'suicides'},
'suicides':	{'suicide'},
'suing':	{'sing','sling','sting','sung','swing'},
'suit':	{'quit','shit','sit','skit','slit','spit','suite','suits'},
'suitable':	{'suitably'},
'suitably':	{'suitable'},
'suite':	{'quite','site','spite','suit','suited','suites','suits'},
'suited':	{'sited','suite','suites'},
'suites':	{'sites','suite','suited','suits'},
'suiting':	{'siting'},
'suits':	{'quits','sits','slits','spits','suit','suite','suites'},
'sulla':	{'sully'},
'sully':	{'bully','fully','gully','sally','silly','sulla','tully'},
'sum':	{'bum','cum','gum','hum','mum','rum','sam','scum','slum','sm','su','sub','sue','sumo','sump','sums','sun','sup','suv','swum','um','yum'},
'summaries':	{'summarises','summarizes'},
'summarisation':	{'summarisations','summarization'},
'summarisations':	{'summarisation','summarizations'},
'summarise':	{'summarised','summarises','summarize'},
'summarised':	{'summarise','summarises','summarized'},
'summarises':	{'summaries','summarise','summarised','summarizes'},
'summarising':	{'summarizing'},
'summarization':	{'summarisation','summarizations'},
'summarizations':	{'summarisations','summarization'},
'summarize':	{'summarise','summarized','summarizes'},
'summarized':	{'summarised','summarize','summarizes'},
'summarizes':	{'summaries','summarises','summarize','summarized'},
'summarizing':	{'summarising'},
'summed':	{'summer'},
'summer':	{'hummer','simmer','summed','summers','sumner'},
'summers':	{'summer'},
'summing':	{'humming'},
'summit':	{'submit','summits'},
'summits':	{'submits','summit'},
'summon':	{'summons'},
'summons':	{'summon'},
'sumner':	{'summer'},
'sumo':	{'sum','sump','sums'},
'sump':	{'bump','dump','hump','jump','lump','pump','slump','stump','sum','sumo','sums','sup'},
'sums':	{'gums','mums','slums','subs','sum','sumo','sump','suns'},
'sun':	{'bun','dun','fun','gun','hun','nun','pun','run','sen','shun','sin','sn','son','spun','stun','su','sub','sue','sum','sung','sunk','suns','sup','suv','un'},
'sunday':	{'sundays','sundry'},
'sundays':	{'sunday'},
'sundry':	{'sunday'},
'sunflower':	{'sunflowers'},
'sunflowers':	{'sunflower'},
'sung':	{'dung','hung','jung','lung','rung','sang','sing','song','stung','suing','sun','sunk','suns','swung'},
'sunk':	{'bunk','dunk','funk','hunk','junk','punk','sank','sink','skunk','suck','sun','sung','suns'},
'sunless':	{'unless'},
'sunni':	{'sunny'},
'sunny':	{'bunny','funny','runny','sonny','sunni'},
'suns':	{'buns','guns','nuns','runs','sans','sens','sins','sons','subs','sums','sun','sung','sunk'},
'sunset':	{'subset','sunsets','unset'},
'sunsets':	{'subsets','sunset'},
'sup':	{'cup','pup','sap','sep','sip','sop','soup','su','sub','sue','sum','sump','sun','suv','up'},
'super':	{'superb','supper','surer'},
'superb':	{'super'},
'superior':	{'superiors'},
'superiors':	{'superior'},
'supermarket':	{'supermarkets'},
'supermarkets':	{'supermarket'},
'supermodel':	{'supermodels'},
'supermodels':	{'supermodel'},
'supersede':	{'superseded','supersedes'},
'superseded':	{'supersede','supersedes'},
'supersedes':	{'supersede','superseded'},
'superstar':	{'superstars'},
'superstars':	{'superstar'},
'supervise':	{'supervised','supervises'},
'supervised':	{'supervise','supervises'},
'supervises':	{'supervise','supervised'},
'supervisor':	{'supervisors','supervisory'},
'supervisors':	{'supervisor','supervisory'},
'supervisory':	{'supervisor','supervisors'},
'supper':	{'super','suppers','upper'},
'suppers':	{'supper','uppers'},
'supple':	{'supply'},
'supplement':	{'supplements'},
'supplements':	{'supplement'},
'supplied':	{'supplier','supplies'},
'supplier':	{'supplied','suppliers','supplies'},
'suppliers':	{'supplier','supplies'},
'supplies':	{'supplied','supplier','suppliers'},
'supply':	{'supple'},
'support':	{'supports'},
'supported':	{'supporter'},
'supporter':	{'supported','supporters'},
'supporters':	{'supporter'},
'supports':	{'support'},
'suppose':	{'supposed','supposes'},
'supposed':	{'suppose','supposes'},
'supposes':	{'suppose','supposed'},
'suppressed':	{'suppresses'},
'suppresses':	{'suppressed'},
'surcharge':	{'surcharges'},
'surcharges':	{'surcharge'},
'sure':	{'cure','lure','pure','sire','sore','sucre','sue','surer','surf','surge'},
'surely':	{'purely','sorely','surety'},
'sureness':	{'pureness'},
'surer':	{'purer','super','sure','surfer'},
'surest':	{'purest'},
'surety':	{'surely'},
'surf':	{'sure','turf'},
'surface':	{'surfaced','surfaces'},
'surfaced':	{'surface','surfaces'},
'surfaces':	{'surface','surfaced'},
'surfer':	{'suffer','surer','surfers'},
'surfers':	{'suffers','surfer'},
'surfing':	{'surging'},
'surge':	{'purge','serge','sure','surged','surges','urge'},
'surged':	{'purged','surge','surges','urged'},
'surgeon':	{'sturgeon','surgeons'},
'surgeons':	{'surgeon'},
'surges':	{'surge','surged','urges'},
'surging':	{'surfing','urging'},
'suriname':	{'surname'},
'surname':	{'suriname','surnames'},
'surnames':	{'surname'},
'surpassed':	{'surpasses'},
'surpasses':	{'surpassed'},
'surprise':	{'surprised','surprises'},
'surprised':	{'surprise','surprises'},
'surprises':	{'surprise','surprised'},
'surrey':	{'survey'},
'surround':	{'surrounds'},
'surrounding':	{'surroundings'},
'surroundings':	{'surrounding'},
'surrounds':	{'surround'},
'survey':	{'surrey','surveys'},
'surveyor':	{'surveyors'},
'surveyors':	{'surveyor'},
'surveys':	{'survey'},
'survive':	{'survived','survives'},
'survived':	{'survive','survives'},
'survives':	{'survive','survived'},
'survivor':	{'survivors'},
'survivors':	{'survivor'},
'suspect':	{'suspects'},
'suspects':	{'suspect'},
'suspend':	{'suspends'},
'suspends':	{'suspend'},
'suspension':	{'suspensions'},
'suspensions':	{'suspension'},
'suspicion':	{'suspicions'},
'suspicions':	{'suspicion','suspicious'},
'suspicious':	{'suspicions'},
'sustain':	{'sustains'},
'sustains':	{'sustain'},
'suture':	{'future'},
'suv':	{'su','sub','sue','sum','sun','sup','uv'},
'sw':	{'kw','nw','ow','sa','saw','sb','sc','sd','se','sew','sh','si','sm','sn','so','sow','sr','ss','ssw','su','w','wsw'},
'swain':	{'slain','spain','stain','swan','twain'},
'swallow':	{'shallow','swallows'},
'swallows':	{'swallow'},
'swam':	{'sam','scam','seam','sham','siam','slam','spam','swami','swamp','swan','swap','swarm','swat','sway','swim','swum'},
'swami':	{'swam','swamp'},
'swamp':	{'scamp','stamp','swam','swami','swamps','swap'},
'swamped':	{'stamped','swapped'},
'swamps':	{'stamps','swamp','swaps'},
'swan':	{'scan','shan','span','swain','swam','swank','swans','swap','swat','sway','wan'},
'swank':	{'sank','shank','spank','swan','swans','wank'},
'swans':	{'sans','scans','spans','swan','swank','swaps'},
'swap':	{'sap','slap','snap','soap','swam','swamp','swan','swaps','swat','sway'},
'swapped':	{'slapped','snapped','swamped'},
'swapping':	{'slapping','snapping'},
'swaps':	{'snaps','soaps','swamps','swans','swap'},
'swarm':	{'swam','warm'},
'swat':	{'sat','scat','seat','spat','stat','swam','swan','swap','swath','sway','sweat','swot','twat','wat'},
'swatch':	{'snatch','swath','switch','watch'},
'swath':	{'swat','swatch'},
'sway':	{'away','say','shay','slay','stay','swam','swan','swap','swat','way'},
'swayed':	{'stayed'},
'swaying':	{'saying','slaying','staying'},
'swear':	{'shear','smear','spear','swears','sweat','wear'},
'swearing':	{'shearing','sweating','wearing'},
'swears':	{'shears','smears','swear','sweats','wears'},
'sweat':	{'seat','swat','swear','sweats','sweaty','sweet','swept'},
'sweated':	{'seated','sweater'},
'sweater':	{'sweated','sweaters','sweeter'},
'sweaters':	{'sweater'},
'sweating':	{'seating','swearing'},
'sweats':	{'seats','swears','sweat','sweaty','sweets'},
'sweatshirt':	{'sweatshirts'},
'sweatshirts':	{'sweatshirt'},
'sweaty':	{'sweat','sweats'},
'sweep':	{'sheep','sleep','steep','sweeps','sweet','weep'},
'sweeper':	{'sleeper','steeper','sweeter'},
'sweeping':	{'sleeping','weeping'},
'sweeps':	{'sleeps','sweep','sweets'},
'sweet':	{'sheet','sweat','sweep','sweets','swept'},
'sweeter':	{'sweater','sweeper','tweeter'},
'sweets':	{'sheets','sweats','sweeps','sweet'},
'swell':	{'dwell','sell','shell','smell','spell','swells','well'},
'swelled':	{'shelled','smelled','spelled'},
'swelling':	{'dwelling','selling','shelling','smelling','spelling'},
'swells':	{'dwells','sells','shells','smells','spells','swell','wells'},
'swept':	{'sept','slept','sweat','sweet','wept'},
'swift':	{'shift','sift'},
'swim':	{'skim','slim','swam','swims','swum'},
'swimmer':	{'shimmer','simmer','swimmers'},
'swimmers':	{'swimmer'},
'swimming':	{'slimming'},
'swims':	{'swim','swiss'},
'swimsuit':	{'swimsuits'},
'swimsuits':	{'swimsuit'},
'swine':	{'seine','shine','sine','spine','swing','swipe','wine'},
'swing':	{'owing','sawing','sewing','sing','sling','sowing','sting','suing','swine','swings','swung','wing'},
'swinger':	{'singer','stinger','winger'},
'swinging':	{'singing','stinging','winging'},
'swings':	{'sings','slings','stings','swing','wings'},
'swipe':	{'swine','wipe'},
'swish':	{'swiss','wish'},
'swiss':	{'swims','swish'},
'switch':	{'stitch','swatch','twitch','witch'},
'switched':	{'stitched','switcher','switches'},
'switcher':	{'switched','switches'},
'switches':	{'stitches','switched','switcher','witches'},
'switching':	{'stitching'},
'swoop':	{'scoop','snoop'},
'sword':	{'swords','swore','sworn','word'},
'swords':	{'sword','words'},
'swore':	{'score','shore','sore','spore','store','sword','sworn','wore'},
'sworn':	{'scorn','sword','swore','worn'},
'swot':	{'scot','shot','slot','soot','sot','spot','swat','wot'},
'swum':	{'scum','slum','sum','swam','swim'},
'swung':	{'stung','sung','swing'},
'sydney':	{'sidney'},
'syllable':	{'syllables'},
'syllables':	{'syllable'},
'symbol':	{'symbols'},
'symbolise':	{'symbolised','symbolises','symbolism','symbolize'},
'symbolised':	{'symbolise','symbolises','symbolized'},
'symbolises':	{'symbolise','symbolised','symbolizes'},
'symbolising':	{'symbolizing'},
'symbolism':	{'symbolise'},
'symbolize':	{'symbolise','symbolized','symbolizes'},
'symbolized':	{'symbolised','symbolize','symbolizes'},
'symbolizes':	{'symbolises','symbolize','symbolized'},
'symbolizing':	{'symbolising'},
'symbols':	{'symbol'},
'symmetric':	{'asymmetric'},
'symmetrical':	{'asymmetrical'},
'symmetry':	{'asymmetry'},
'symptom':	{'symptoms'},
'symptomatic':	{'asymptomatic'},
'symptoms':	{'symptom'},
'synagogue':	{'synagogues'},
'synagogues':	{'synagogue'},
'synapse':	{'synapses'},
'synapses':	{'synapse','synopses'},
'synchronisation':	{'synchronization'},
'synchronization':	{'synchronisation'},
'synchronize':	{'synchronized'},
'synchronized':	{'synchronize'},
'synchronous':	{'asynchronous'},
'syndicate':	{'syndicated'},
'syndicated':	{'syndicate'},
'syndrome':	{'syndromes'},
'syndromes':	{'syndrome'},
'synonym':	{'synonyms'},
'synonyms':	{'synonym'},
'synopses':	{'synapses','synopsis'},
'synopsis':	{'synopses'},
'synthesize':	{'synthesized','synthesizer'},
'synthesized':	{'synthesize','synthesizer'},
'synthesizer':	{'synthesize','synthesized'},
'syria':	{'syrian'},
'syrian':	{'syria'},
'syringe':	{'syringes'},
'syringes':	{'syringe'},
'system':	{'systems'},
'systems':	{'system'},
't':	{'a','at','b','c','ct','d','e','et','f','ft','g','h','ht','i','it','j','k','kt','l','mt','nt','o','p','pt','q','r','ta','tb','tc','te','th','ti','tl','tm','tn','to','ts','tv','tx','u','ut','v','vt','w','x','y','z'},
'ta':	{'a','ba','ca','da','ea','eta','fa','ga','ha','ia','ka','la','ma','na','pa','ra','sa','t','tab','tad','tag','tai','tam','tan','tao','tap','tar','tat','tau','tax','tb','tc','te','tea','th','ti','tia','tl','tm','tn','to','ts','tv','tx','uta','va','wa','ya','za'},
'tab':	{'ab','cab','dab','fab','gab','jab','lab','nab','stab','ta','tabs','tad','tag','tai','tam','tan','tao','tap','tar','tat','tau','tax','tb','tub'},
'tabbed':	{'stabbed','tabled'},
'table':	{'able','cable','fable','gable','sable','stable','tabled','tables','tablet','tale'},
'tabled':	{'tabbed','table','tables','tablet','tailed'},
'tables':	{'cables','fables','gables','stables','table','tabled','tablet','tablets','tales'},
'tablespoon':	{'tablespoons'},
'tablespoons':	{'tablespoon'},
'tablet':	{'table','tabled','tables','tablets'},
'tablets':	{'tables','tablet'},
'taboo':	{'tabor'},
'tabor':	{'labor','taboo'},
'tabs':	{'abs','cabs','labs','tab','tags','taps','tubs'},
'tabular':	{'tubular'},
'tacit':	{'tact'},
'tack':	{'back','hack','jack','lack','mack','pack','rack','sack','stack','tacky','taco','tact','talk','tank','task','tick','track','tuck'},
'tackle':	{'tackled','tackles','tickle'},
'tackled':	{'tackle','tackles'},
'tackles':	{'tackle','tackled'},
'tackling':	{'tickling'},
'tacky':	{'tack','wacky'},
'taco':	{'tack','tact','tao','waco'},
'tact':	{'act','fact','pact','tacit','tack','taco','taft','tart','tat','tract'},
'tactic':	{'lactic','tactics'},
'tactics':	{'tactic'},
'tad':	{'ad','bad','cad','dad','fad','had','lad','mad','pad','rad','sad','ta','tab','tag','tai','tam','tan','tao','tap','tar','tat','tau','tax','ted','toad','tod','trad','wad'},
'taft':	{'aft','daft','raft','tact','tart','tat'},
'tag':	{'ag','bag','dag','fag','gag','jag','lag','mag','nag','rag','sag','stag','ta','tab','tad','tags','tai','tam','tan','tang','tao','tap','tar','tat','tau','tax','tug'},
'tagged':	{'bagged','gagged','jagged','lagged','ragged'},
'tagging':	{'bagging','gagging','lagging','nagging'},
'tags':	{'bags','gags','lags','rags','tabs','tag','taps'},
'tai':	{'ai','bai','sai','ta','tab','tad','tag','tail','tam','tan','tao','tap','tar','tat','tau','tax','taxi','thai','ti','wai'},
'tail':	{'bail','dail','fail','hail','jail','mail','nail','rail','sail','tai','tails','tall','tamil','til','toil','trail'},
'tailed':	{'failed','hailed','jailed','mailed','nailed','sailed','tabled','tiled','trailed'},
'tailor':	{'sailor','tailors','taylor'},
'tailors':	{'sailors','tailor'},
'tails':	{'fails','hails','jails','mails','nails','rails','sails','tail','trails'},
'tainted':	{'fainted','painted','tinted'},
'take':	{'bake','cake','fake','lake','make','rake','sake','stake','taken','taker','takes','tale','tame','tape','tate','wake'},
'taken':	{'take','taker','takes','token','waken'},
'takeover':	{'makeover'},
'taker':	{'baker','maker','take','taken','takers','takes','tanker','taper'},
'takers':	{'bakers','makers','taker','takes','tankers'},
'takes':	{'bakes','cakes','fakes','lakes','makes','rakes','sakes','stakes','take','taken','taker','takers','tales','tames','tapes','taxes','wakes'},
'taking':	{'baking','making','raking','talking','taming','taping','tasking','taxing','waking'},
'tala':	{'ala','gala','mala','tale','talk','tall','tara'},
'tale':	{'ale','bale','dale','gale','hale','male','pale','sale','stale','table','take','tala','tales','talk','tall','tame','tape','tate','tile','vale','yale'},
'talent':	{'talents'},
'talents':	{'talent'},
'tales':	{'ales','bales','males','pales','sales','tables','takes','tale','talks','tames','tapes','taxes','thales','tiles','wales'},
'talk':	{'stalk','tack','tala','tale','talks','tall','tank','task','walk'},
'talked':	{'tasked','walked'},
'talking':	{'stalking','taking','tasking','walking'},
'talks':	{'stalks','tales','talk','tanks','tasks','walks'},
'tall':	{'all','ball','call','fall','gall','hall','mall','pall','stall','tail','tala','tale','talk','tally','tell','till','toll','wall'},
'taller':	{'caller','teller','waller'},
'tallied':	{'allied','rallied'},
'tally':	{'ally','bally','cally','rally','sally','tall','tully','wally'},
'talon':	{'salon'},
'tam':	{'am','cam','dam','ham','jam','lam','ram','sam','ta','tab','tad','tag','tai','tame','tan','tao','tap','tar','tat','tau','tax','team','tm','tom','tram','yam'},
'tame':	{'came','dame','fame','game','lame','name','same','take','tale','tam','tamed','tames','tape','tate','time','tome'},
'tamed':	{'famed','named','tame','tames','taped','taxed','teamed','timed'},
'tames':	{'games','james','names','takes','tales','tame','tamed','tapes','taxes','thames','times'},
'tamil':	{'tail'},
'taming':	{'gaming','naming','taking','taping','taxing','teaming','timing'},
'tammy':	{'tummy'},
'tamper':	{'camper','damper','hamper','pamper','taper','temper'},
'tampon':	{'tarpon'},
'tan':	{'an','ban','can','fan','han','jan','lan','man','nan','pan','ran','ta','tab','tad','tag','tai','tam','tang','tank','tao','tap','tar','tat','tau','tax','ten','than','tin','tn','ton','van','wan'},
'tance':	{'dance','lance','nance','stance','trance'},
'tandy':	{'candy','dandy','handy','randy','sandy'},
'tang':	{'ang','bang','dang','fang','gang','hang','pang','rang','sang','tag','tan','tango','tank','thang','ting','yang'},
'tangle':	{'angle','bangle','dangle','tangled'},
'tangled':	{'angled','mangled','tangle'},
'tango':	{'mango','tang'},
'tank':	{'bank','hank','rank','sank','tack','talk','tan','tang','tanks','task','thank','wank','yank'},
'tanker':	{'banker','taker','tankers','tanner','tinker'},
'tankers':	{'bankers','takers','tanker'},
'tanks':	{'banks','hanks','ranks','talks','tank','tasks','thanks'},
'tanned':	{'banned','canned','fanned','manned','tanner'},
'tanner':	{'banner','manner','tanker','tanned'},
'tanning':	{'banning','canning','fanning','tannins'},
'tannins':	{'tanning'},
'tantra':	{'mantra'},
'tanzania':	{'tanzanian'},
'tanzanian':	{'tanzania'},
'tao':	{'gao','hao','lao','mao','ta','tab','taco','tad','tag','tai','tam','tan','tap','tar','tat','tau','tax','tho','tko','to','too','two'},
'tap':	{'cap','gap','hap','lap','map','nap','pap','rap','sap','ta','tab','tad','tag','tai','tam','tan','tao','tape','taps','tar','tat','tau','tax','tip','top','trap','yap','zap'},
'tapas':	{'tapes','taps'},
'tape':	{'ape','cape','rape','take','tale','tame','tap','taped','taper','tapes','taps','tate','taupe','type'},
'taped':	{'caped','raped','tamed','tape','taper','tapes','tapped','taxed','typed'},
'taper':	{'paper','taker','tamper','tape','taped','tapes'},
'tapered':	{'papered'},
'tapes':	{'apes','capes','rapes','takes','tales','tames','tapas','tape','taped','taper','taps','taxes','types'},
'taping':	{'gaping','raping','taking','taming','tapping','taxing','typing'},
'tapped':	{'capped','mapped','taped','tipped','topped','trapped'},
'tapping':	{'capping','mapping','taping','tipping','topping','trapping'},
'taps':	{'caps','gaps','laps','maps','tabs','tags','tap','tapas','tape','tapes','tips','tops','traps'},
'tar':	{'ar','bar','car','dar','ear','far','gar','jar','mar','oar','par','star','ta','tab','tad','tag','tai','tam','tan','tao','tap','tara','tart','tat','tau','tax','tear','tor','var','war'},
'tara':	{'ara','mara','nara','para','tala','tar','tart','tera','tiara'},
'target':	{'targets'},
'targets':	{'target'},
'tariff':	{'tariffs'},
'tariffs':	{'tariff'},
'tarot':	{'tart','trot'},
'tarpon':	{'tampon'},
'tart':	{'art','bart','cart','dart','fart','hart','kart','mart','part','start','tact','taft','tar','tara','tarot','tarts','tat','tort'},
'tartan':	{'tarzan'},
'tarts':	{'arts','carts','darts','karts','parts','starts','tart','torts','warts'},
'tarzan':	{'tartan'},
'task':	{'ask','mask','tack','talk','tank','tasks'},
'tasked':	{'asked','masked','talked','tasted'},
'tasking':	{'asking','masking','taking','talking','tasting'},
'tasks':	{'asks','masks','talks','tanks','task'},
'tasmania':	{'tasmanian'},
'tasmanian':	{'tasmania'},
'taste':	{'caste','haste','paste','tasted','tastes','tasty','tate','waste'},
'tasted':	{'lasted','pasted','tasked','taste','tastes','tested','toasted','wasted'},
'tasteful':	{'wasteful'},
'tastefully':	{'wastefully'},
'tastes':	{'pastes','taste','tasted','wastes'},
'tasting':	{'casting','fasting','lasting','pasting','tasking','testing','wasting'},
'tasty':	{'hasty','nasty','taste'},
'tat':	{'at','bat','cat','dat','eat','fat','hat','kat','lat','mat','oat','pat','rat','sat','stat','ta','tab','tact','tad','taft','tag','tai','tam','tan','tao','tap','tar','tart','tate','tau','tax','tet','that','tit','tnt','tot','tut','twat','vat','wat'},
'tate':	{'ate','date','fate','gate','hate','late','mate','pate','rate','state','take','tale','tame','tape','taste','tat','tote'},
'tattoo':	{'tattoos'},
'tattoos':	{'tattoo'},
'tatum':	{'datum'},
'tau':	{'au','ta','tab','tad','tag','tai','tam','tan','tao','tap','tar','tat','tax','tou'},
'taught':	{'caught'},
'taupe':	{'tape'},
'tavern':	{'cavern'},
'tax':	{'ax','fax','lax','max','sax','ta','tab','tad','tag','tai','tam','tan','tao','tap','tar','tat','tau','taxi','tux','tx','wax'},
'taxed':	{'axed','faxed','tamed','taped','taxes','waxed'},
'taxes':	{'axes','faxes','takes','tales','tames','tapes','taxed','taxis','waxes'},
'taxi':	{'maxi','tai','tax','taxis'},
'taxing':	{'axing','faxing','taking','taming','taping','waxing'},
'taxis':	{'axis','taxes','taxi'},
'taxpayer':	{'taxpayers'},
'taxpayers':	{'taxpayer'},
'taylor':	{'tailor'},
'tb':	{'ab','b','bb','db','eb','gb','kb','lb','mb','nb','ob','pb','rb','sb','t','ta','tab','tc','te','th','ti','tl','tm','tn','to','ts','tub','tv','tx','yb'},
'tc':	{'ac','bc','c','cc','dc','ec','etc','ftc','kc','mc','nc','otc','pc','sc','t','ta','tb','te','th','thc','ti','tic','tl','tlc','tm','tn','to','ts','tv','tx'},
'te':	{'ate','be','ce','de','e','ee','fe','ge','he','ie','le','me','ne','pe','se','t','ta','tb','tc','tea','ted','tee','ten','tet','th','the','ti','tie','tl','tm','tn','to','toe','ts','tv','tx','ute','ve','we','xe','ye'},
'tea':	{'dea','ea','lea','pea','sea','ta','te','teak','teal','team','tear','teas','ted','tee','ten','tera','tet','thea','tia','yea'},
'teach':	{'beach','each','leach','peach','reach','tech'},
'teacher':	{'teachers','teaches'},
'teachers':	{'teacher','teaches'},
'teaches':	{'beaches','peaches','reaches','teacher','teachers'},
'teaching':	{'leaching','reaching','teachings'},
'teachings':	{'teaching'},
'teak':	{'beak','leak','peak','steak','tea','teal','team','tear','teas','tweak','weak'},
'teal':	{'deal','heal','meal','real','seal','steal','tea','teak','team','tear','teas','tell','veal','zeal'},
'team':	{'beam','seam','steam','tam','tea','teak','teal','teams','tear','teas','term','tram'},
'teamed':	{'beamed','steamed','tamed','teased','termed'},
'teaming':	{'beaming','steaming','taming','tearing','teasing'},
'teammate':	{'teammates'},
'teammates':	{'teammate'},
'teams':	{'beams','seams','steams','team','tears','teas','terms'},
'tear':	{'bear','dear','ear','fear','gear','hear','lear','near','pear','rear','tar','tea','teak','teal','team','tears','teas','wear','year'},
'tearing':	{'bearing','fearing','gearing','hearing','nearing','rearing','teaming','teasing','wearing'},
'tears':	{'bears','dears','ears','fears','gears','hears','nears','pears','teams','tear','teas','wears','years'},
'teas':	{'peas','seas','tea','teak','teal','team','teams','tear','tears','tease','tees','tens','texas','yeas'},
'tease':	{'cease','ease','lease','teas','teased','teaser','tense'},
'teased':	{'ceased','eased','leased','teamed','tease','teaser'},
'teaser':	{'tease','teased','tenser'},
'teasing':	{'ceasing','easing','leasing','teaming','tearing'},
'teaspoon':	{'teaspoons'},
'teaspoons':	{'teaspoon'},
'tech':	{'teach','techs'},
'technician':	{'technicians'},
'technicians':	{'technician'},
'technique':	{'techniques'},
'techniques':	{'technique'},
'technologist':	{'technologists'},
'technologists':	{'technologist'},
'techs':	{'tech'},
'ted':	{'bed','ed','fed','led','med','qed','red','tad','te','tea','tee','ten','tend','tet','tied','tod','wed','zed'},
'teddy':	{'eddy'},
'tee':	{'bee','ee','fee','gee','lee','nee','pee','see','te','tea','ted','teen','tees','ten','tet','the','thee','tie','toe','tree','wee'},
'teen':	{'been','keen','seen','tee','teens','teeny','tees','ten','tern','then','tren','tween'},
'teenage':	{'teenager'},
'teenager':	{'teenage','teenagers'},
'teenagers':	{'teenager'},
'teens':	{'teen','teeny','tees','tens'},
'teeny':	{'teen','teens'},
'tees':	{'bees','fees','lees','sees','teas','tee','teen','teens','tens','ties','toes','trees','tues'},
'teeth':	{'tenth'},
'telecom':	{'telecoms'},
'telecommunication':	{'telecommunications'},
'telecommunications':	{'telecommunication'},
'telecoms':	{'telecom'},
'telegraph':	{'telegraphs'},
'telegraphs':	{'telegraph'},
'telephone':	{'telephoned','telephones','telephony'},
'telephoned':	{'telephone','telephones'},
'telephones':	{'telephone','telephoned'},
'telephony':	{'telephone'},
'telescope':	{'telescopes'},
'telescopes':	{'telescope'},
'television':	{'televisions'},
'televisions':	{'television'},
'tell':	{'bell','cell','dell','ell','fell','hell','sell','tall','teal','tells','till','toll','well','yell'},
'teller':	{'heller','keller','seller','taller'},
'telling':	{'belling','selling','yelling'},
'tells':	{'bells','cells','hells','sells','tell','tolls','wells','yells'},
'telnet':	{'tenet'},
'temp':	{'hemp','tempo','temps','tempt'},
'temper':	{'tamper','tempers'},
'temperature':	{'temperatures'},
'temperatures':	{'temperature'},
'tempers':	{'temper'},
'template':	{'templates'},
'templates':	{'template'},
'temple':	{'temples'},
'temples':	{'temple'},
'tempo':	{'temp','temps','tempt'},
'temps':	{'temp','tempo','tempt','tempts'},
'tempt':	{'temp','tempo','temps','tempts'},
'temptation':	{'temptations'},
'temptations':	{'temptation'},
'tempts':	{'temps','tempt'},
'ten':	{'ben','den','en','fen','gen','hen','ken','men','pen','sen','tan','te','tea','ted','tee','teen','tend','tens','tent','tern','tet','then','tin','tn','ton','tren','wen','yen','zen'},
'tenant':	{'tenants'},
'tenants':	{'tenant'},
'tend':	{'bend','end','fend','lend','mend','send','ted','ten','tends','tens','tent','trend'},
'tended':	{'ended','mended','tender','tented'},
'tender':	{'bender','fender','gender','lender','render','sender','tended','tenders','tenser'},
'tendered':	{'rendered'},
'tendering':	{'rendering'},
'tenders':	{'fenders','genders','lenders','renders','senders','tender'},
'tending':	{'bending','ending','lending','mending','pending','sending','vending'},
'tendon':	{'tendons'},
'tendons':	{'tendon'},
'tends':	{'bends','ends','lends','mends','sends','tend','tens','tents','trends'},
'tenet':	{'genet','telnet','tenets','tent'},
'tenets':	{'tenet','tents'},
'tenor':	{'tensor'},
'tens':	{'ens','hens','lens','pens','sens','teas','teens','tees','ten','tend','tends','tense','tent','tents','tins','tons'},
'tense':	{'dense','sense','tease','tens','tenser'},
'tensely':	{'densely'},
'tenser':	{'teaser','tender','tense','tensor'},
'tension':	{'pension','tensions'},
'tensions':	{'pensions','tension'},
'tensor':	{'censor','sensor','tenor','tenser'},
'tent':	{'bent','cent','dent','gent','kent','lent','rent','sent','ten','tend','tenet','tens','tenth','tents','test','tet','text','tint','tnt','trent','vent','went'},
'tentacle':	{'tentacles'},
'tentacles':	{'tentacle'},
'tented':	{'rented','tended','tested','tinted','vented'},
'tenth':	{'teeth','tent','tenths','tents'},
'tenths':	{'tenth','tents'},
'tents':	{'cents','dents','gents','rents','tends','tenets','tens','tent','tenth','tenths','tests','texts','vents'},
'tenure':	{'tenured'},
'tenured':	{'tenure'},
'tera':	{'era','tara','tea','term','tern','tetra'},
'teresa':	{'theresa'},
'term':	{'germ','perm','team','tera','terms','tern','therm'},
'termed':	{'teamed'},
'terminal':	{'terminals'},
'terminals':	{'terminal'},
'terminate':	{'terminated','terminates'},
'terminated':	{'terminate','terminates'},
'terminates':	{'terminate','terminated'},
'termination':	{'germination','terminations'},
'terminations':	{'termination'},
'termite':	{'termites'},
'termites':	{'termite'},
'terms':	{'germs','teams','term'},
'tern':	{'bern','fern','kern','stern','teen','ten','tera','term','torn','turn'},
'terrace':	{'terraced','terraces'},
'terraced':	{'terrace','terraces'},
'terraces':	{'terrace','terraced'},
'terrible':	{'terribly'},
'terribly':	{'terrible'},
'terrier':	{'merrier'},
'terror':	{'error'},
'terrorism':	{'terrorist'},
'terrorist':	{'terrorism','terrorists'},
'terrorists':	{'terrorist'},
'terry':	{'berry','ferry','jerry','merry','perry'},
'test':	{'best','est','fest','jest','lest','nest','pest','rest','tent','tests','tet','text','vest','west','zest'},
'tested':	{'nested','rested','tasted','tented','tester','vested'},
'tester':	{'ester','jester','tested','testers'},
'testers':	{'esters','tester'},
'testified':	{'testifies'},
'testifies':	{'testified'},
'testimonial':	{'testimonials'},
'testimonials':	{'testimonial'},
'testing':	{'nesting','resting','tasting','vesting'},
'testis':	{'tests'},
'tests':	{'nests','pests','rests','tents','test','testis','texts','vests'},
'tet':	{'bet','et','get','jet','let','met','net','pet','set','tat','te','tea','ted','tee','ten','tent','test','text','tit','tnt','tot','tut','vet','wet','yet'},
'tetra':	{'tera'},
'texan':	{'texas'},
'texas':	{'teas','texan','texts'},
'text':	{'next','tent','test','tet','texts'},
'textbook':	{'textbooks'},
'textbooks':	{'textbook'},
'textile':	{'textiles'},
'textiles':	{'textile'},
'texts':	{'tents','tests','texas','text'},
'texture':	{'textured','textures'},
'textured':	{'texture','textures'},
'textures':	{'texture','textured'},
'th':	{'eh','h','nh','nth','oh','ph','rh','sh','t','ta','tb','tc','te','thc','the','tho','thy','ti','tl','tm','tn','to','ts','tv','tx','uh'},
'thai':	{'tai','than','that','thaw'},
'thales':	{'tales','thames','whales'},
'thames':	{'shames','tames','thales','themes'},
'than':	{'han','khan','shan','tan','thai','thane','thang','thank','that','thaw','then','thin'},
'thane':	{'than','thang','thank','thine'},
'thang':	{'chang','hang','shang','tang','than','thane','thank','thing','thong'},
'thank':	{'hank','shank','tank','than','thane','thang','thanks','think'},
'thanking':	{'thinking'},
'thanks':	{'hanks','shanks','tanks','thank','thinks'},
'that':	{'chat','hat','phat','tat','thai','than','thaw','twat','what'},
'thaw':	{'haw','shaw','thai','than','that'},
'thc':	{'tc','th','the','tho','thy','tic','tlc'},
'the':	{'he','she','te','tee','th','thc','thea','thee','them','then','they','tho','thy','tie','toe'},
'thea':	{'rhea','tea','the','thee','them','then','theta','they'},
'theater':	{'heater','theaters'},
'theaters':	{'heaters','theater'},
'theatre':	{'theatres'},
'theatres':	{'theatre'},
'thee':	{'tee','the','thea','them','theme','then','there','these','they','three','tree'},
'theft':	{'thefts'},
'thefts':	{'theft'},
'their':	{'heir','theirs'},
'theirs':	{'heirs','their'},
'them':	{'ahem','chem','hem','the','thea','thee','theme','then','therm','they'},
'theme':	{'thee','them','themed','themes','there','these','thyme'},
'themed':	{'theme','themes'},
'themes':	{'thames','theme','themed','theses'},
'then':	{'chen','hen','teen','ten','than','the','thea','thee','them','they','thin','tren','when'},
'thence':	{'hence','whence'},
'theologian':	{'theologians'},
'theologians':	{'theologian'},
'theorem':	{'theorems'},
'theorems':	{'theorem'},
'theorist':	{'theorists'},
'theorists':	{'theorist'},
'therapeutic':	{'therapeutics'},
'therapeutics':	{'therapeutic'},
'therapist':	{'therapists'},
'therapists':	{'therapist'},
'there':	{'here','thee','theme','therm','these','where'},
'thereafter':	{'hereafter'},
'thereby':	{'hereby','whereby'},
'therefor':	{'therefore'},
'therefore':	{'therefor','wherefore'},
'therein':	{'herein','thereon','wherein'},
'thereof':	{'hereof','thereon','whereof'},
'thereon':	{'therein','thereof'},
'theresa':	{'teresa'},
'thereto':	{'hereto'},
'thereunder':	{'hereunder'},
'thereupon':	{'whereupon'},
'therewith':	{'herewith'},
'therm':	{'term','them','there'},
'thermodynamic':	{'thermodynamics'},
'thermodynamics':	{'thermodynamic'},
'thermometer':	{'thermometers'},
'thermometers':	{'thermometer'},
'these':	{'thee','theme','there','theses','those'},
'theses':	{'themes','these','thesis'},
'thesis':	{'theses'},
'theta':	{'thea'},
'they':	{'hey','the','thea','thee','them','then','thy','trey','whey'},
'thick':	{'chick','think','tick','trick'},
'thicker':	{'thinker','ticker'},
'thief':	{'chief'},
'thigh':	{'high','thighs'},
'thighs':	{'highs','thigh'},
'thin':	{'chin','shin','than','then','thine','thing','think','thins','this','tin','twin'},
'thine':	{'rhine','shine','thane','thin','thing','think','thins','whine'},
'thing':	{'thang','thin','thine','things','thingy','think','thins','thong','ting','tying'},
'things':	{'thing','thingy','thinks','thins','thongs'},
'thingy':	{'thing','things','thinly'},
'think':	{'thank','thick','thin','thine','thing','thinks','thins','twink'},
'thinker':	{'thicker','thinkers','thinner','tinker'},
'thinkers':	{'thinker'},
'thinking':	{'thanking','thinning'},
'thinks':	{'thanks','things','think','thins'},
'thinly':	{'thingy'},
'thinned':	{'thinner'},
'thinner':	{'thinker','thinned'},
'thinness':	{'thinnest'},
'thinnest':	{'thinness'},
'thinning':	{'thinking'},
'thins':	{'thin','thine','thing','things','think','thinks','this','tins','twins'},
'third':	{'thirds'},
'thirds':	{'third'},
'thirst':	{'thirsts','thirsty'},
'thirsts':	{'thirst','thirsty'},
'thirsty':	{'thirst','thirsts','thirty'},
'thirteenth':	{'thirteenths'},
'thirteenths':	{'thirteenth'},
'thirtieth':	{'thirtieths'},
'thirtieths':	{'thirtieth'},
'thirty':	{'thirsty'},
'this':	{'his','thin','thins','thus'},
'thistle':	{'whistle'},
'thither':	{'hither','whither'},
'tho':	{'ho','rho','tao','th','thc','the','thor','thou','thy','tko','to','too','two','who'},
'thompson':	{'thomson'},
'thomson':	{'thompson'},
'thong':	{'thang','thing','thongs'},
'thongs':	{'things','thong'},
'thor':	{'tho','thorn','thou','tor'},
'thorn':	{'horn','thor','thorns','torn'},
'thorns':	{'horns','thorn'},
'thorough':	{'through'},
'those':	{'chose','hose','these','whose'},
'thou':	{'chou','tho','thor','tou','zhou'},
'though':	{'thought','through','tough','trough'},
'thought':	{'though','thoughts'},
'thoughts':	{'thought'},
'thousand':	{'thousands'},
'thousands':	{'thousand'},
'thousandth':	{'thousandths'},
'thousandths':	{'thousandth'},
'thrash':	{'thrush','trash'},
'thread':	{'threads','threat','tread'},
'threads':	{'thread','threats'},
'threat':	{'thread','threats','throat','treat'},
'threaten':	{'threatens'},
'threatens':	{'threaten'},
'threats':	{'threads','threat','throats','treats'},
'three':	{'thee','threes','threw','tree'},
'threes':	{'three','trees'},
'threesome':	{'threesomes'},
'threesomes':	{'threesome'},
'threshold':	{'thresholds'},
'thresholds':	{'threshold'},
'threw':	{'three','throw'},
'thrice':	{'thrive'},
'thrift':	{'thrifty'},
'thrifty':	{'thrift'},
'thrill':	{'thrills'},
'thrilled':	{'thriller'},
'thriller':	{'thrilled','thrillers'},
'thrillers':	{'thriller'},
'thrills':	{'thrill'},
'thrive':	{'thrice','thrives'},
'thrives':	{'thrive'},
'throat':	{'threat','throats'},
'throats':	{'threats','throat'},
'throne':	{'thrones'},
'thrones':	{'throne'},
'through':	{'thorough','though','trough'},
'throughout':	{'throughput'},
'throughput':	{'throughout'},
'throw':	{'threw','thrown','throws'},
'thrown':	{'throw','throws'},
'throws':	{'throw','thrown'},
'thrush':	{'thrash','thrust'},
'thrust':	{'thrush','trust'},
'thrusting':	{'trusting'},
'thug':	{'hug','thugs','thus','tug'},
'thugs':	{'hugs','thug','thurs','thus'},
'thumb':	{'thumbs'},
'thumbnail':	{'thumbnails'},
'thumbnails':	{'thumbnail'},
'thumbs':	{'thumb'},
'thunder':	{'thunders'},
'thunders':	{'thunder'},
'thunderstorm':	{'thunderstorms'},
'thunderstorms':	{'thunderstorm'},
'thurs':	{'thugs','thus','tours'},
'thursday':	{'thursdays'},
'thursdays':	{'thursday'},
'thus':	{'this','thug','thugs','thurs'},
'thy':	{'shy','th','thc','the','they','tho','toy','try','why'},
'thyme':	{'rhyme','theme'},
'ti':	{'ai','bi','ci','di','gi','hi','i','ii','ji','ki','li','mi','ni','pi','qi','ri','si','t','ta','tai','tb','tc','te','th','tia','tic','tie','til','tin','tip','tit','tl','tm','tn','to','ts','tv','tx','vi','wi','xi','yi'},
'tia':	{'cia','ia','pia','ta','tea','ti','tic','tie','til','tin','tip','tit','via'},
'tiara':	{'tara'},
'tic':	{'pic','sic','tc','thc','ti','tia','tick','tics','tie','til','tin','tip','tit','tlc'},
'tick':	{'dick','kick','lick','mick','nick','pick','rick','sick','stick','tack','thick','tic','ticks','tics','trick','tuck','wick'},
'ticked':	{'kicked','licked','picked','ticker','ticket','tricked','tucked','wicked'},
'ticker':	{'kicker','picker','sicker','sticker','thicker','ticked','ticket','tinker','tucker','wicker'},
'ticket':	{'picket','ticked','ticker','tickets','wicket'},
'tickets':	{'ticket','wickets'},
'ticking':	{'kicking','licking','picking','sticking','tickling','tricking'},
'tickle':	{'pickle','sickle','tackle','trickle'},
'tickling':	{'tackling','ticking'},
'ticks':	{'kicks','licks','picks','sticks','tick','tics','tricks'},
'tics':	{'mics','pics','tic','tick','ticks','ties','tins','tips','tits'},
'tidal':	{'vidal'},
'tide':	{'aide','hide','ride','side','tides','tidy','tie','tile','time','tire','wide'},
'tides':	{'aides','hides','rides','sides','tide','tidies','ties','tiles','times','tires'},
'tidied':	{'tidies'},
'tidies':	{'tides','tidied'},
'tidings':	{'timings'},
'tidy':	{'tide','tiny'},
'tie':	{'die','ie','lie','pie','te','tee','the','ti','tia','tic','tide','tied','tier','ties','tieu','til','tile','time','tin','tip','tire','tit','toe','vie'},
'tied':	{'died','lied','pied','ted','tie','tier','ties','tieu','tiled','timed','tired','tried'},
'tier':	{'pier','tie','tied','tiers','ties','tieu','tiger','timer','trier'},
'tiered':	{'tired'},
'tiers':	{'piers','tier','ties','tigers','timers'},
'ties':	{'dies','lies','pies','tees','tics','tides','tie','tied','tier','tiers','tieu','tiles','times','tins','tips','tires','tits','toes','tries','tues'},
'tieu':	{'lieu','tie','tied','tier','ties'},
'tiff':	{'diff','riff','stiff'},
'tiger':	{'niger','tier','tigers','timer'},
'tigers':	{'tiers','tiger','timers'},
'tight':	{'eight','fight','light','might','night','right','sight','tights','wight'},
'tighten':	{'lighten','tightens','tighter'},
'tightening':	{'lightening'},
'tightens':	{'tighten'},
'tighter':	{'fighter','lighter','tighten'},
'tightest':	{'lightest'},
'tightly':	{'lightly','nightly','rightly'},
'tightness':	{'lightness'},
'tights':	{'eights','fights','lights','nights','rights','sights','tight'},
'til':	{'il','mil','nil','oil','tail','ti','tia','tic','tie','tile','till','tilt','tin','tip','tit','tl','toil'},
'tile':	{'bile','file','mile','nile','pile','tale','tide','tie','til','tiled','tiles','till','tilt','time','tire','title','vile'},
'tiled':	{'filed','oiled','piled','tailed','tied','tile','tiles','tilted','timed','tired','titled'},
'tiles':	{'files','miles','piles','tales','tides','ties','tile','tiled','times','tires','titles'},
'tiling':	{'ailing','filing','piling','tilting','timing','tiring'},
'till':	{'bill','dill','fill','gill','hill','ill','kill','mill','pill','sill','still','tall','tell','til','tile','tilt','toll','twill','will'},
'tillage':	{'village'},
'tilt':	{'gilt','kilt','milt','silt','til','tile','till','tint','tit','wilt'},
'tilted':	{'tiled','tinted'},
'tilting':	{'tiling','tinting'},
'timber':	{'timbers','timer'},
'timbers':	{'timber','timers'},
'time':	{'dime','lime','mime','tame','tide','tie','tile','timed','timer','times','tire','tome'},
'timed':	{'aimed','tamed','tied','tiled','time','timer','times','timid','tired'},
'timeless':	{'tireless'},
'timeout':	{'timeouts'},
'timeouts':	{'timeout'},
'timer':	{'dimer','tier','tiger','timber','time','timed','timers','times'},
'timers':	{'tiers','tigers','timbers','timer','times'},
'times':	{'dimes','tames','tides','ties','tiles','time','timed','timer','timers','tires'},
'timescale':	{'timescales'},
'timescales':	{'timescale'},
'timeshare':	{'timeshares'},
'timeshares':	{'timeshare'},
'timetable':	{'timetables'},
'timetables':	{'timetable'},
'timid':	{'timed'},
'timing':	{'aiming','taming','tiling','timings','tiring'},
'timings':	{'tidings','timing'},
'tin':	{'bin','din','fin','gin','in','kin','lin','min','pin','qin','sin','tan','ten','thin','ti','tia','tic','tie','til','ting','tins','tint','tiny','tip','tit','tn','ton','twin','win','yin'},
'ting':	{'ding','king','ling','ming','ning','ping','qing','ring','sing','sting','tang','thing','tin','tins','tint','tiny','tying','wing','ying'},
'tinged':	{'hinged','ringed','tinted','winged'},
'tinker':	{'pinker','tanker','thinker','ticker'},
'tins':	{'bins','fins','ins','pins','sins','tens','thins','tics','ties','tin','ting','tint','tiny','tips','tits','tons','twins','wins'},
'tint':	{'hint','int','lint','mint','pint','stint','tent','tilt','tin','ting','tins','tiny','tit','tnt'},
'tinted':	{'hinted','tainted','tented','tilted','tinged'},
'tinting':	{'tilting'},
'tiny':	{'tidy','tin','ting','tins','tint'},
'tip':	{'dip','hip','ip','kip','lip','nip','pip','rip','sip','tap','ti','tia','tic','tie','til','tin','tipo','tips','tit','top','trip','vip','yip','zip'},
'tipo':	{'tip','tips','tito','typo'},
'tipped':	{'dipped','ripped','tapped','topped','tripped','zipped'},
'tipping':	{'dipping','ripping','sipping','tapping','topping','tripping'},
'tips':	{'dips','hips','lips','mips','rips','sips','taps','tics','ties','tins','tip','tipo','tits','tops','trips','zips'},
'tire':	{'dire','eire','fire','hire','ire','lire','sire','tide','tie','tile','time','tired','tires','titre','tore','tyre','wire'},
'tired':	{'aired','fired','hired','tied','tiered','tiled','timed','tire','tires','wired'},
'tireless':	{'timeless','wireless'},
'tires':	{'fires','hires','tides','ties','tiles','times','tire','tired','wires'},
'tiring':	{'airing','firing','hiring','tiling','timing','turing','wiring'},
'tissue':	{'issue','tissues'},
'tissues':	{'issues','tissue'},
'tit':	{'bit','fit','git','hit','it','kit','lit','mit','nit','pit','sit','tat','tet','ti','tia','tic','tie','til','tilt','tin','tint','tip','tito','tits','tnt','tot','tut','wit'},
'title':	{'tile','titled','titles','titre'},
'titled':	{'tiled','title','titles'},
'titles':	{'tiles','title','titled'},
'tito':	{'tipo','tit','tits'},
'titre':	{'litre','mitre','tire','title'},
'tits':	{'bits','fits','hits','its','kits','pits','sits','tics','ties','tins','tips','tit','tito','titus','tots','wits'},
'titty':	{'kitty','witty'},
'titus':	{'tits'},
'tko':	{'ko','tao','tho','to','too','two'},
'tl':	{'al','bl','cl','el','fl','il','l','ll','ml','t','ta','tb','tc','te','th','ti','til','tlc','tm','tn','to','ts','tv','tx','xl'},
'tlc':	{'tc','thc','tic','tl'},
'tm':	{'am','atm','bm','cm','em','fm','gm','hm','km','mm','nm','pm','rm','sm','t','ta','tam','tb','tc','te','th','ti','tl','tn','to','tom','ts','tv','tx','um','wm'},
'tn':	{'an','en','in','mn','on','rn','sn','t','ta','tan','tb','tc','te','ten','th','ti','tin','tl','tm','tnt','to','ton','ts','tv','tx','un','zn'},
'tnt':	{'ant','int','nt','ont','tat','tent','tet','tint','tit','tn','tot','tut'},
'to':	{'co','do','fo','go','ho','io','ko','lo','mo','no','o','po','pto','so','t','ta','tao','tb','tc','te','th','tho','ti','tko','tl','tm','tn','tod','toe','tom','ton','too','top','tor','tot','tou','tow','toy','ts','tv','two','tx','wo'},
'toad':	{'load','road','tad','tod','todd','told','trad'},
'toast':	{'boast','coast','roast'},
'toasted':	{'boasted','roasted','tasted','toaster'},
'toaster':	{'coaster','toasted','toasters'},
'toasters':	{'coasters','toaster'},
'tobacco':	{'tobaccos'},
'tobaccos':	{'tobacco'},
'tobey':	{'obey','toby'},
'tobin':	{'robin','toxin'},
'toby':	{'tobey','tory','toy'},
'tod':	{'bod','cod','dod','god','mod','nod','od','pod','rod','sod','tad','ted','to','toad','todd','toe','told','tom','ton','too','top','tor','tot','tou','tow','toy'},
'todd':	{'odd','toad','tod','told'},
'toddler':	{'toddlers'},
'toddlers':	{'toddler'},
'toe':	{'doe','foe','hoe','poe','roe','te','tee','the','tie','to','tod','toes','tom','tome','ton','tone','too','top','tor','tore','tot','tote','tou','tow','toy','woe'},
'toes':	{'does','foes','goes','hoes','tees','ties','toe','tones','tons','tops','tors','toss','totes','tots','toys','tues','woes'},
'tofu':	{'tou'},
'toggle':	{'goggle'},
'togo':	{'logo','too'},
'toil':	{'boil','coil','foil','oil','soil','tail','til','toll','tool'},
'toilet':	{'toilets'},
'toilets':	{'toilet'},
'token':	{'taken','tokens','woken'},
'tokens':	{'token'},
'told':	{'bold','cold','fold','gold','hold','mold','old','sold','toad','tod','todd','toll'},
'tolerance':	{'tolerances'},
'tolerances':	{'tolerance'},
'tolerate':	{'tolerated'},
'tolerated':	{'tolerate'},
'toll':	{'atoll','boll','doll','moll','poll','roll','tall','tell','till','toil','told','tolls','tool','troll'},
'tolls':	{'dolls','polls','rolls','tells','toll','tools','trolls'},
'tom':	{'atom','com','mom','pom','rom','tam','tm','to','tod','toe','tomb','tome','ton','too','top','tor','tot','tou','tow','toy'},
'tomb':	{'bomb','comb','omb','tom','tombs','tome','womb'},
'tombs':	{'bombs','combs','tomb'},
'tome':	{'come','dome','home','nome','rome','some','tame','time','toe','tom','tomb','tone','tore','tote'},
'tomography':	{'topography'},
'ton':	{'con','don','hon','ion','mon','non','on','ron','son','tan','ten','tin','tn','to','tod','toe','tom','tone','tons','too','top','tor','torn','tot','tou','tow','town','toy','von','won','yon'},
'tonal':	{'total'},
'tone':	{'bone','cone','done','gone','hone','lone','none','one','stone','toe','tome','ton','toned','toner','tones','tonne','tons','tore','tote','tune','tyne','zone'},
'toned':	{'boned','honed','stoned','tone','toner','tones','towed','tuned','zoned'},
'toner':	{'tone','toned','toners','tones','tower','tuner'},
'toners':	{'toner','tones','towers','tuners'},
'tones':	{'bones','cones','jones','ones','stones','toes','tone','toned','toner','toners','tonnes','tons','totes','tunes','zones'},
'tongue':	{'tongues'},
'tongues':	{'tongue'},
'tonic':	{'ionic','sonic','topic','toxic','tunic'},
'toning':	{'boning','stoning','towing','toying','tuning','zoning'},
'tonne':	{'donne','tone','tonnes'},
'tonnes':	{'tones','tonne'},
'tons':	{'cons','ions','sons','tens','tins','toes','ton','tone','tones','tops','tors','toss','tots','towns','toys'},
'too':	{'boo','coo','goo','loo','moo','poo','tao','tho','tko','to','tod','toe','togo','tom','ton','took','tool','top','tor','tot','tou','tow','toy','two','woo','zoo'},
'took':	{'book','cook','hook','look','nook','rook','too','tool'},
'tool':	{'cool','fool','pool','stool','toil','toll','too','took','tools','wool'},
'toolbar':	{'toolbars'},
'toolbars':	{'toolbar'},
'tooled':	{'cooled','fooled','pooled'},
'tooling':	{'cooling','fooling','pooling'},
'tools':	{'cools','fools','pools','stools','tolls','tool','wools'},
'tooth':	{'booth'},
'top':	{'atop','bop','cop','gop','hop','mop','op','pop','sop','stop','tap','tip','to','tod','toe','tom','ton','too','tops','tor','tot','tou','tow','toy','wop'},
'topic':	{'tonic','topics','toxic','tropic'},
'topical':	{'tropical','typical'},
'topics':	{'topic','tropics'},
'topography':	{'tomography','typography'},
'topped':	{'hopped','popped','stopped','tapped','tipped','topper'},
'topper':	{'copper','hopper','popper','stopper','topped','toppers'},
'toppers':	{'stoppers','topper'},
'topping':	{'hopping','popping','stopping','tapping','tipping'},
'tops':	{'cops','hops','ops','pops','stops','taps','tips','toes','tons','top','tors','toss','tots','toys'},
'tor':	{'for','nor','or','tar','thor','to','tod','toe','tom','ton','too','top','tore','torn','tors','tort','tory','tot','tou','tour','tow','toy'},
'torah':	{'torch'},
'torch':	{'porch','torah','touch'},
'torches':	{'touches'},
'tore':	{'bore','core','fore','gore','lore','more','ore','pore','sore','store','tire','toe','tome','tone','tor','torn','tors','tort','tory','tote','tyre','wore'},
'torment':	{'torrent'},
'torn':	{'born','corn','horn','morn','porn','tern','thorn','ton','tor','tore','tors','tort','tory','town','turn','worn'},
'torrent':	{'torment','torrents'},
'torrents':	{'torrent'},
'tors':	{'toes','tons','tops','tor','tore','torn','torso','tort','torts','torus','tory','toss','tots','tours','toys'},
'torso':	{'tors'},
'tort':	{'fort','hort','port','sort','tart','tor','tore','torn','tors','torts','tory','tot','tout','wort'},
'tortilla':	{'tortillas'},
'tortillas':	{'tortilla'},
'torts':	{'forts','ports','sorts','tarts','tors','tort','torus','tots','touts'},
'torture':	{'tortured'},
'tortured':	{'torture'},
'torus':	{'tors','torts'},
'tory':	{'gory','story','toby','tor','tore','torn','tors','tort','toy','try'},
'toss':	{'boss','loss','moss','ross','toes','tons','tops','tors','tots','toys'},
'tot':	{'bot','cot','dot','got','hot','lot','mot','not','pot','rot','sot','tat','tet','tit','tnt','to','tod','toe','tom','ton','too','top','tor','tort','tote','tots','tou','tout','tow','toy','trot','tut','wot'},
'total':	{'tonal','totals'},
'totaled':	{'totalled'},
'totaling':	{'totalling'},
'totalled':	{'totaled'},
'totalling':	{'totaling'},
'totals':	{'total'},
'tote':	{'cote','note','tate','toe','tome','tone','tore','tot','totem','totes','tots','vote'},
'totem':	{'tote','totes'},
'totes':	{'notes','toes','tones','tote','totem','tots','votes'},
'tots':	{'bots','cots','dots','lots','pots','rots','tits','toes','tons','tops','tors','torts','toss','tot','tote','totes','touts','toys'},
'tou':	{'cou','tau','thou','to','tod','toe','tofu','tom','ton','too','top','tor','tot','tour','tout','tow','toy','you'},
'touch':	{'couch','pouch','torch','touchy','tough','vouch'},
'touchdown':	{'touchdowns'},
'touchdowns':	{'touchdown'},
'touched':	{'touches'},
'touches':	{'couches','pouches','torches','touched'},
'touchy':	{'touch'},
'tough':	{'bough','cough','dough','lough','rough','though','touch','trough'},
'toughness':	{'roughness'},
'tour':	{'four','hour','our','pour','sour','tor','tou','tours','tout','your'},
'toured':	{'poured','soured','touted'},
'touring':	{'pouring','souring','turing'},
'tourism':	{'tourist'},
'tourist':	{'tourism','tourists'},
'tourists':	{'tourist'},
'tournament':	{'tournaments'},
'tournaments':	{'tournament'},
'tourney':	{'journey'},
'tours':	{'fours','hours','ours','pours','sours','thurs','tors','tour','touts','yours'},
'tout':	{'bout','gout','out','rout','stout','tort','tot','tou','tour','touts','trout','tut'},
'touted':	{'routed','toured'},
'touts':	{'bouts','outs','torts','tots','tours','tout'},
'tow':	{'bow','cow','how','low','now','ow','pow','row','sow','stow','to','tod','toe','tom','ton','too','top','tor','tot','tou','town','toy','vow','wow'},
'toward':	{'coward','howard','towards'},
'towards':	{'cowards','toward'},
'towed':	{'bowed','owed','rowed','sowed','toned','towel','tower','vowed'},
'towel':	{'bowel','towed','towels','tower','vowel'},
'towels':	{'bowels','towel','towers','vowels'},
'tower':	{'bower','lower','mower','power','toner','towed','towel','towers'},
'towering':	{'lowering','powering'},
'towers':	{'lowers','mowers','powers','toners','towels','tower'},
'towing':	{'bowing','lowing','mowing','owing','rowing','sowing','toning','toying'},
'town':	{'down','gown','own','sown','ton','torn','tow','towns'},
'townhouse':	{'townhouses'},
'townhouses':	{'townhouse'},
'towns':	{'downs','gowns','owns','tons','town'},
'township':	{'townships'},
'townships':	{'township'},
'toxic':	{'tonic','topic','toxin'},
'toxin':	{'tobin','toxic','toxins'},
'toxins':	{'toxin'},
'toy':	{'boy','coy','joy','soy','thy','to','toby','tod','toe','tom','ton','too','top','tor','tory','tot','tou','tow','toys','troy','try'},
'toying':	{'toning','towing','trying','tying'},
'toys':	{'boys','joys','toes','tons','tops','tors','toss','tots','toy'},
'trace':	{'brace','grace','race','traced','tracer','traces','track','tract','tracy','trade','trance','truce'},
'traced':	{'graced','raced','trace','tracer','traces','tracked','traded'},
'tracer':	{'racer','trace','traced','traces','tracker','trader'},
'traces':	{'braces','graces','races','trace','traced','tracer','tracks','tracts','trades'},
'tracing':	{'bracing','gracing','racing','tracking','trading'},
'track':	{'crack','rack','tack','trace','tracks','tract','tracy','trick','truck'},
'tracked':	{'cracked','traced','tracker','tricked'},
'tracker':	{'cracker','tracer','tracked','trucker'},
'tracking':	{'cracking','racking','tracing','tricking','trucking'},
'tracks':	{'cracks','racks','traces','track','tracts','tricks','trucks'},
'tract':	{'tact','trace','track','tracts','tracy','trait'},
'traction':	{'fraction'},
'tractor':	{'tractors','traitor'},
'tractors':	{'tractor'},
'tracts':	{'traces','tracks','tract','traits'},
'tracy':	{'trace','track','tract','tray'},
'trad':	{'brad','grad','rad','tad','toad','trade','tram','trap','tray','tread','triad'},
'trade':	{'grade','trace','trad','traded','trader','trades'},
'traded':	{'graded','traced','trade','trader','trades'},
'trademark':	{'trademarks'},
'trademarks':	{'trademark'},
'trader':	{'grader','tracer','trade','traded','traders','trades'},
'traders':	{'graders','trader','trades'},
'trades':	{'grades','traces','trade','traded','trader','traders'},
'trading':	{'grading','tracing'},
'tradition':	{'traditions'},
'traditions':	{'tradition'},
'trail':	{'frail','grail','rail','tail','trails','train','trait','trawl'},
'trailed':	{'tailed','trailer','trained'},
'trailer':	{'trailed','trailers','trainer'},
'trailers':	{'trailer','trainers'},
'trailing':	{'railing','training'},
'trails':	{'rails','tails','trail','trains','traits'},
'train':	{'brain','drain','grain','rain','strain','trail','trains','trait','twain'},
'trained':	{'drained','grained','rained','strained','trailed','trainee','trainer'},
'trainee':	{'trained','trainees','trainer'},
'trainees':	{'trainee','trainers'},
'trainer':	{'trailer','trained','trainee','trainers'},
'trainers':	{'trailers','trainees','trainer'},
'training':	{'draining','raining','straining','trailing','trainings'},
'trainings':	{'training'},
'trains':	{'brains','drains','grains','rains','strains','trails','train','traits','trans'},
'trait':	{'strait','tract','trail','train','traits'},
'traitor':	{'tractor'},
'traits':	{'straits','tracts','trails','trains','trait'},
'tram':	{'cram','dram','gram','ram','tam','team','trad','tramp','trap','tray','trim'},
'tramp':	{'ramp','tram','trap','trump'},
'trampoline':	{'trampolines'},
'trampolines':	{'trampoline'},
'trance':	{'france','tance','trace'},
'tranquility':	{'tranquillity'},
'tranquillity':	{'tranquility'},
'trans':	{'trains','traps','trays'},
'transaction':	{'transactions'},
'transactions':	{'transaction'},
'transcend':	{'transcends'},
'transcends':	{'transcend'},
'transcript':	{'transcripts'},
'transcription':	{'transcriptions'},
'transcriptions':	{'transcription'},
'transcripts':	{'transcript'},
'transducer':	{'transducers'},
'transducers':	{'transducer'},
'transfer':	{'transfers'},
'transfers':	{'transfer'},
'transform':	{'transforms'},
'transformation':	{'transformations'},
'transformations':	{'transformation'},
'transformed':	{'transformer'},
'transformer':	{'transformed','transformers'},
'transformers':	{'transformer'},
'transforms':	{'transform'},
'transistor':	{'transistors'},
'transistors':	{'transistor'},
'transit':	{'transits','transmit'},
'transition':	{'transitions'},
'transitions':	{'transition'},
'transits':	{'transit','transmits'},
'translate':	{'translated','translates'},
'translated':	{'translate','translates'},
'translates':	{'translate','translated'},
'translation':	{'translations'},
'translational':	{'transnational'},
'translations':	{'translation'},
'translator':	{'translators'},
'translators':	{'translator'},
'transmission':	{'transmissions'},
'transmissions':	{'transmission'},
'transmit':	{'transit','transmits'},
'transmits':	{'transits','transmit'},
'transmitted':	{'transmitter'},
'transmitter':	{'transmitted','transmitters'},
'transmitters':	{'transmitter'},
'transnational':	{'translational'},
'transplant':	{'transplants'},
'transplants':	{'transplant'},
'transport':	{'transports'},
'transported':	{'transporter'},
'transporter':	{'transported','transporters'},
'transporters':	{'transporter'},
'transports':	{'transport'},
'transsexual':	{'transsexuals'},
'transsexuals':	{'transsexual'},
'transvestite':	{'transvestites'},
'transvestites':	{'transvestite'},
'trap':	{'crap','rap','strap','tap','trad','tram','tramp','traps','tray','trip','wrap'},
'trapped':	{'strapped','tapped','tripped','wrapped'},
'trapping':	{'strapping','tapping','tripping','wrapping'},
'traps':	{'craps','straps','taps','trans','trap','trays','trips','wraps'},
'trash':	{'crash','rash','thrash','trashy'},
'trashed':	{'crashed'},
'trashy':	{'trash'},
'travel':	{'gravel','ravel','travels'},
'traveled':	{'traveler','travelled'},
'traveler':	{'traveled','travelers','traveller'},
'travelers':	{'traveler','travellers'},
'traveling':	{'travelling'},
'travelled':	{'traveled','traveller'},
'traveller':	{'traveler','travelled','travellers'},
'travellers':	{'travelers','traveller'},
'travelling':	{'traveling'},
'travels':	{'travel'},
'traverse':	{'traversed'},
'traversed':	{'traverse'},
'trawl':	{'crawl','trail'},
'tray':	{'bray','fray','gray','pray','ray','stray','tracy','trad','tram','trap','trays','trey','troy','try'},
'trays':	{'grays','prays','rays','trans','traps','tray'},
'tread':	{'bread','dread','read','thread','trad','treat','trend','triad'},
'treadmill':	{'treadmills'},
'treadmills':	{'treadmill'},
'treason':	{'reason'},
'treasure':	{'treasured','treasurer','treasures','treasury'},
'treasured':	{'treasure','treasurer','treasures'},
'treasurer':	{'treasure','treasured','treasures'},
'treasures':	{'treasure','treasured','treasurer'},
'treasury':	{'treasure'},
'treat':	{'great','threat','tread','treats','treaty','trent'},
'treated':	{'created'},
'treating':	{'creating'},
'treatment':	{'treatments'},
'treatments':	{'treatment'},
'treats':	{'greats','threats','treat','treaty'},
'treaty':	{'treat','treats'},
'treble':	{'tremble'},
'tree':	{'cree','free','tee','thee','three','trees','trek','tren','trey','true'},
'trees':	{'frees','tees','threes','tree','tries'},
'trek':	{'tree','tren','trey'},
'tremble':	{'treble','trembled','trembles'},
'trembled':	{'tremble','trembles'},
'trembles':	{'tremble','trembled'},
'tren':	{'aren','teen','ten','then','tree','trek','trend','trent','trey','wren'},
'trench':	{'french','wrench'},
'trenches':	{'wrenches'},
'trend':	{'tend','tread','tren','trends','trendy','trent'},
'trends':	{'tends','trend','trendy'},
'trendy':	{'trend','trends'},
'trent':	{'brent','rent','tent','treat','tren','trend'},
'trey':	{'frey','grey','prey','they','tray','tree','trek','tren','troy','try'},
'triad':	{'trad','tread','trial','tried'},
'trial':	{'atrial','rial','triad','trials','tribal'},
'trialed':	{'tripled'},
'trials':	{'trial'},
'triangle':	{'triangles'},
'triangles':	{'triangle'},
'tribal':	{'trial'},
'tribe':	{'bribe','tribes'},
'tribes':	{'bribes','tribe','tries','trikes'},
'tribunal':	{'tribunals'},
'tribunals':	{'tribunal'},
'tribune':	{'tribute'},
'tribute':	{'tribune','tributes'},
'tributes':	{'tribute'},
'trick':	{'brick','prick','rick','thick','tick','track','tricks','tricky','truck'},
'tricked':	{'ticked','tracked'},
'tricking':	{'ticking','tracking','trucking'},
'trickle':	{'tickle'},
'tricks':	{'bricks','ticks','tracks','trick','tricky','trucks'},
'tricky':	{'trick','tricks'},
'tried':	{'cried','dried','fried','tied','triad','trier','tries'},
'trier':	{'drier','tier','tried','tries','truer'},
'tries':	{'aries','cries','dries','fries','ties','trees','tribes','tried','trier','trikes','trips'},
'trig':	{'brig','orig','rig','trim','trio','trip'},
'trigger':	{'triggers'},
'triggers':	{'trigger'},
'trikes':	{'strikes','tribes','tries'},
'trim':	{'brim','grim','rim','tram','trig','trio','trip'},
'trimmed':	{'trimmer'},
'trimmer':	{'trimmed','trimmers'},
'trimmers':	{'trimmer'},
'trimming':	{'rimming','trimmings'},
'trimmings':	{'trimming'},
'trio':	{'brio','rio','trig','trim','trip'},
'trip':	{'drip','grip','rip','strip','tip','trap','trig','trim','trio','trips'},
'triple':	{'tripled','triples','triplet'},
'tripled':	{'trialed','triple','triples','triplet','tripped'},
'triples':	{'triple','tripled','triplet'},
'triplet':	{'triple','tripled','triples'},
'tripod':	{'tripods'},
'tripods':	{'tripod'},
'tripped':	{'gripped','ripped','stripped','tipped','trapped','tripled'},
'tripping':	{'dripping','gripping','ripping','stripping','tipping','trapping'},
'trips':	{'grips','rips','strips','tips','traps','tries','trip'},
'triton':	{'briton'},
'triumph':	{'triumphs'},
'triumphs':	{'triumph'},
'trivia':	{'trivial'},
'trivial':	{'trivia'},
'troll':	{'roll','stroll','toll','trolls'},
'trolley':	{'trolleys'},
'trolleys':	{'trolley'},
'trolling':	{'rolling','strolling'},
'trolls':	{'rolls','tolls','troll'},
'troop':	{'troops'},
'trooper':	{'troopers'},
'troopers':	{'trooper'},
'troops':	{'troop'},
'trophy':	{'atrophy'},
'tropic':	{'topic','tropics'},
'tropical':	{'topical'},
'tropics':	{'topics','tropic'},
'trot':	{'rot','tarot','tot','trout','troy'},
'trouble':	{'rouble','troubled','troubles'},
'troubled':	{'trouble','troubles'},
'troubles':	{'trouble','troubled'},
'trough':	{'rough','though','through','tough'},
'trouser':	{'trousers'},
'trousers':	{'trouser'},
'trout':	{'grout','rout','tout','trot'},
'trove':	{'drove','grove','prove','rove'},
'troy':	{'toy','tray','trey','trot','try'},
'truce':	{'bruce','trace','truck','true'},
'truck':	{'struck','track','trick','truce','trucks','trunk','tuck'},
'trucker':	{'tracker','truckers','tucker'},
'truckers':	{'trucker'},
'trucking':	{'tracking','tricking'},
'trucks':	{'tracks','tricks','truck','trunks'},
'true':	{'rue','tree','truce','truer'},
'truer':	{'trier','true'},
'truest':	{'trust'},
'trump':	{'tramp'},
'trumpet':	{'trumpets'},
'trumpets':	{'trumpet'},
'truncate':	{'truncated'},
'truncated':	{'truncate'},
'trunk':	{'drunk','truck','trunks'},
'trunks':	{'trucks','trunk'},
'truss':	{'trust','trusts'},
'trust':	{'crust','rust','thrust','truest','truss','trusts','trusty'},
'trusted':	{'rusted','trustee'},
'trustee':	{'trusted','trustees'},
'trustees':	{'trustee'},
'trusting':	{'rusting','thrusting'},
'trusts':	{'rusts','truss','trust','trusty'},
'trusty':	{'crusty','rusty','trust','trusts'},
'truth':	{'ruth','truths'},
'truths':	{'truth'},
'try':	{'cry','dry','fry','thy','tory','toy','tray','trey','troy'},
'trying':	{'crying','drying','frying','toying','tying'},
'ts':	{'as','bs','cs','es','hs','is','its','ks','ms','os','ps','ss','t','ta','tb','tc','te','th','ti','tl','tm','tn','to','tv','tx','us','vs'},
'tub':	{'cub','dub','hub','pub','rub','stub','sub','tab','tb','tuba','tube','tubs','tug','tut','tux'},
'tuba':	{'cuba','tub','tubal','tube','tubs','tuna'},
'tubal':	{'tuba'},
'tube':	{'cube','lube','tub','tuba','tubes','tubs','tune'},
'tubes':	{'cubes','lubes','tube','tubs','tues','tunes'},
'tubing':	{'tuning','turing'},
'tubs':	{'hubs','pubs','rubs','stubs','subs','tabs','tub','tuba','tube','tubes','tues'},
'tubular':	{'tabular'},
'tuck':	{'buck','duck','fuck','huck','luck','muck','puck','stuck','suck','tack','tick','truck','turk'},
'tucked':	{'ducked','sucked','ticked','tucker'},
'tucker':	{'fucker','sucker','ticker','trucker','tucked'},
'tudor':	{'tumor','tutor'},
'tues':	{'cues','dues','hues','tees','ties','toes','tubes','tubs','tunes'},
'tuesday':	{'tuesdays'},
'tuesdays':	{'tuesday'},
'tug':	{'aug','bug','dug','hug','jug','lug','mug','pug','rug','tag','thug','tub','tut','tux'},
'tulip':	{'tulips'},
'tulips':	{'tulip'},
'tully':	{'bully','fully','gully','sully','tally'},
'tumble':	{'bumble','fumble','humble','jumble','rumble','stumble','tumbled','tumbler'},
'tumbled':	{'humbled','stumbled','tumble','tumbler'},
'tumbler':	{'tumble','tumbled'},
'tumbling':	{'humbling','stumbling'},
'tummy':	{'dummy','mummy','tammy','yummy'},
'tumor':	{'humor','rumor','tudor','tumors','tumour','tutor'},
'tumors':	{'rumors','tumor','tumours','tutors'},
'tumour':	{'humour','rumour','tumor','tumours'},
'tumours':	{'tumors','tumour'},
'tuna':	{'luna','tuba','tune','una'},
'tune':	{'dune','june','rune','tone','tube','tuna','tuned','tuner','tunes','tyne'},
'tuned':	{'toned','tune','tuner','tunes','turned'},
'tuner':	{'toner','tune','tuned','tuners','tunes','turner'},
'tuners':	{'toners','tuner','tunes'},
'tunes':	{'dunes','runes','tones','tubes','tues','tune','tuned','tuner','tuners','tunis'},
'tunic':	{'tonic','tunis'},
'tuning':	{'toning','tubing','turing','turning'},
'tunis':	{'tunes','tunic'},
'tunisia':	{'tunisian'},
'tunisian':	{'tunisia'},
'tunnel':	{'funnel','tunnels'},
'tunnels':	{'tunnel'},
'turbine':	{'turbines'},
'turbines':	{'turbine'},
'turf':	{'surf','turk','turn'},
'turin':	{'turing','turn'},
'turing':	{'curing','during','tiring','touring','tubing','tuning','turin','turning'},
'turk':	{'tuck','turf','turn'},
'turkey':	{'turkeys','turnkey'},
'turkeys':	{'turkey'},
'turn':	{'burn','tern','torn','turf','turin','turk','turns','urn'},
'turned':	{'burned','tuned','turner'},
'turner':	{'burner','tuner','turned'},
'turning':	{'burning','tuning','turing'},
'turnkey':	{'turkey'},
'turnout':	{'burnout'},
'turnover':	{'turnovers'},
'turnovers':	{'turnover'},
'turns':	{'burns','turn','urns'},
'turntable':	{'turntables'},
'turntables':	{'turntable'},
'turtle':	{'turtles'},
'turtles':	{'turtle'},
'tuscan':	{'tuscany'},
'tuscany':	{'tuscan'},
'tut':	{'but','cut','gut','hut','nut','out','put','rut','tat','tet','tit','tnt','tot','tout','tub','tug','tux','ut'},
'tutor':	{'tudor','tumor','tutors'},
'tutorial':	{'tutorials'},
'tutorials':	{'tutorial'},
'tutors':	{'tumors','tutor'},
'tux':	{'aux','tax','tub','tug','tut','tx'},
'tuxedo':	{'tuxedos'},
'tuxedos':	{'tuxedo'},
'tv':	{'av','cv','ev','iv','jv','lv','nv','rv','t','ta','tb','tc','te','th','ti','tl','tm','tn','to','ts','tx','uv','v','wv','xv'},
'twain':	{'swain','train','twin'},
'twat':	{'swat','tat','that','wat'},
'tweak':	{'teak','tweaks','weak'},
'tweaks':	{'tweak'},
'tweed':	{'tween','weed'},
'tween':	{'teen','tweed'},
'tweeter':	{'sweeter'},
'twelfth':	{'twelfths'},
'twelfths':	{'twelfth'},
'twelve':	{'twelves'},
'twelves':	{'twelve'},
'twigs':	{'twins','wigs'},
'twill':	{'till','will'},
'twin':	{'thin','tin','twain','twink','twins','win'},
'twink':	{'think','twin','twins','wink'},
'twins':	{'thins','tins','twigs','twin','twink','wins'},
'twist':	{'twists'},
'twisted':	{'twister'},
'twister':	{'twisted'},
'twists':	{'twist'},
'twitch':	{'switch','witch'},
'two':	{'tao','tho','tko','to','too','wo'},
'tx':	{'ax','ex','ix','ox','px','t','ta','tax','tb','tc','te','th','ti','tl','tm','tn','to','ts','tux','tv','x','xx'},
'tying':	{'dying','lying','thing','ting','toying','trying','typing','vying','ying'},
'tyne':	{'tone','tune','type','tyre'},
'type':	{'hype','tape','tyne','typed','types','typo','tyre'},
'typed':	{'hyped','taped','type','types'},
'types':	{'tapes','type','typed','typos'},
'typical':	{'atypical','topical'},
'typing':	{'taping','tying'},
'typist':	{'typists'},
'typists':	{'typist'},
'typo':	{'tipo','type','typos'},
'typography':	{'topography'},
'typos':	{'types','typo'},
'tyre':	{'eyre','tire','tore','tyne','type'},
'u':	{'a','au','b','c','cu','d','du','e','eu','f','g','gu','h','i','j','ju','k','l','lu','mu','nu','o','p','pu','q','r','ru','su','t','uh','uk','um','un','up','ur','us','ut','uv','v','w','wu','x','y','z','zu'},
'uber':	{'ber','user'},
'ufo':	{'cfo','fo'},
'uganda':	{'ugandan'},
'ugandan':	{'uganda'},
'ugh':	{'uh'},
'uh':	{'duh','eh','h','huh','nh','oh','ph','rh','sh','th','u','ugh','uhf','uk','um','un','up','ur','us','ut','uv'},
'uhf':	{'hf','uh','vhf'},
'uk':	{'ak','bk','k','ok','u','uh','um','un','up','ur','us','ut','uv'},
'ulcer':	{'ulcers'},
'ulcers':	{'ulcer'},
'um':	{'am','bm','bum','cm','cum','em','fm','gm','gum','hm','hum','km','mm','mum','nm','pm','rm','rum','sm','sum','tm','u','uh','uk','un','up','ur','us','ut','uv','wm','yum'},
'umbrella':	{'umbrellas'},
'umbrellas':	{'umbrella'},
'umpire':	{'empire','umpires'},
'umpires':	{'empires','umpire'},
'un':	{'an','bun','dun','en','fun','gun','hun','in','mn','nun','on','pun','rn','run','sn','sun','tn','u','uh','uk','um','una','uni','up','ur','urn','us','usn','ut','uv','zn'},
'una':	{'ana','dna','luna','na','rna','tuna','un','uni','usa','uta'},
'unable':	{'enable','usable'},
'unauthorised':	{'unauthorized'},
'unauthorized':	{'unauthorised'},
'unbearable':	{'unbeatable'},
'unbeatable':	{'unbearable'},
'unbelievable':	{'unbelievably'},
'unbelievably':	{'unbelievable'},
'unbound':	{'inbound'},
'unbounded':	{'unfounded'},
'uncle':	{'uncles'},
'unclean':	{'unclear'},
'unclear':	{'unclean'},
'uncles':	{'uncle'},
'uncontextualised':	{'uncontextualized'},
'uncontextualized':	{'uncontextualised'},
'uncontrollable':	{'uncontrollably'},
'uncontrollably':	{'uncontrollable'},
'uncover':	{'uncovers'},
'uncovers':	{'uncover'},
'undated':	{'unrated','updated'},
'undead':	{'unread'},
'undeniable':	{'undeniably'},
'undeniably':	{'undeniable'},
'under':	{'funder'},
'underestimate':	{'underestimated','underestimates'},
'underestimated':	{'underestimate','underestimates'},
'underestimates':	{'underestimate','underestimated'},
'undergraduate':	{'undergraduates'},
'undergraduates':	{'undergraduate'},
'underlay':	{'underway'},
'underlie':	{'underlies','underline'},
'underlies':	{'underlie','underlines'},
'underline':	{'underlie','underlined','underlines','undermine'},
'underlined':	{'underline','underlines','undermined'},
'underlines':	{'underlies','underline','underlined','undermines'},
'underlining':	{'undermining'},
'undermine':	{'underline','undermined','undermines'},
'undermined':	{'underlined','undermine','undermines'},
'undermines':	{'underlines','undermine','undermined'},
'undermining':	{'underlining'},
'underscore':	{'underscored','underscores'},
'underscored':	{'underscore','underscores'},
'underscores':	{'underscore','underscored'},
'understand':	{'understands'},
'understandable':	{'understandably'},
'understandably':	{'understandable'},
'understanding':	{'understandings'},
'understandings':	{'understanding'},
'understands':	{'understand'},
'undertake':	{'undertaken','undertakes'},
'undertaken':	{'undertake','undertakes'},
'undertakes':	{'undertake','undertaken'},
'undertaking':	{'undertakings'},
'undertakings':	{'undertaking'},
'underway':	{'underlay'},
'underwriter':	{'underwriters'},
'underwriters':	{'underwriter'},
'undies':	{'indies'},
'undo':	{'unto'},
'unduly':	{'unruly'},
'unease':	{'uneasy'},
'uneasy':	{'unease'},
'unfit':	{'unit'},
'unfold':	{'unfolds','untold'},
'unfolds':	{'unfold'},
'unfounded':	{'unbounded','unfunded'},
'unfunded':	{'unfounded'},
'uni':	{'ni','un','una','unit','unix'},
'unified':	{'unifies'},
'unifies':	{'unified'},
'uniform':	{'uniforms'},
'uniformed':	{'uninformed'},
'uniforms':	{'uniform'},
'unify':	{'unity'},
'uninformed':	{'uniformed'},
'uninjured':	{'uninsured'},
'uninsured':	{'uninjured'},
'union':	{'anion','onion','unions','unison'},
'unions':	{'onions','union'},
'unison':	{'union'},
'unit':	{'knit','nit','unfit','uni','unite','units','unity','unix'},
'unite':	{'unit','united','unites','units','unity'},
'united':	{'unite','unites'},
'unites':	{'unite','united','units'},
'units':	{'knits','unit','unite','unites','unity'},
'unity':	{'unify','unit','unite','units'},
'universe':	{'universes'},
'universes':	{'universe'},
'unix':	{'nix','uni','unit'},
'unknown':	{'unknowns'},
'unknowns':	{'unknown'},
'unleaded':	{'unloaded'},
'unless':	{'sunless'},
'unlisted':	{'enlisted'},
'unload':	{'unloads','upload'},
'unloaded':	{'unleaded','uploaded'},
'unloading':	{'uploading'},
'unloads':	{'unload','uploads'},
'unlock':	{'unlocks'},
'unlocks':	{'unlock'},
'unmet':	{'unset'},
'unmistakable':	{'unmistakably'},
'unmistakably':	{'unmistakable'},
'unrated':	{'undated'},
'unread':	{'undead','unreal'},
'unreal':	{'unread'},
'unreasonable':	{'unreasonably'},
'unreasonably':	{'unreasonable'},
'unrivaled':	{'unrivalled'},
'unrivalled':	{'unrivaled'},
'unruly':	{'unduly'},
'unset':	{'inset','onset','sunset','unmet','upset'},
'unsure':	{'ensure','insure'},
'untie':	{'auntie','untied','until'},
'untied':	{'untie'},
'until':	{'untie'},
'untitled':	{'entitled'},
'unto':	{'into','onto','undo'},
'untold':	{'unfold'},
'unveil':	{'unveils'},
'unveils':	{'unveil'},
'up':	{'cup','dp','gp','hp','ip','kp','lp','mp','np','op','p','pup','sup','u','uh','uk','um','un','ur','us','ut','uv'},
'update':	{'updated','updater','updates'},
'updated':	{'undated','update','updater','updates'},
'updater':	{'update','updated','updates'},
'updates':	{'update','updated','updater'},
'upgrade':	{'upgraded','upgrades'},
'upgraded':	{'upgrade','upgrades'},
'upgrades':	{'upgrade','upgraded'},
'upheld':	{'uphold'},
'uphold':	{'upheld'},
'upload':	{'unload','uploads'},
'uploaded':	{'unloaded'},
'uploading':	{'unloading'},
'uploads':	{'unloads','upload'},
'upper':	{'supper','uppers'},
'uppers':	{'suppers','upper'},
'upset':	{'unset','upsets'},
'upsets':	{'upset'},
'upsilon':	{'epsilon'},
'upward':	{'upwards'},
'upwards':	{'upward'},
'ur':	{'ar','br','bur','cr','cur','dr','dur','er','fr','fur','hr','ir','jr','kr','lr','mr','or','our','pr','qr','r','sr','u','uh','uk','um','un','up','url','urn','us','ut','uv','yr','zr'},
'urban':	{'durban'},
'urea':	{'area'},
'urge':	{'purge','surge','urged','urges'},
'urged':	{'purged','surged','urge','urges'},
'urgent':	{'argent'},
'urges':	{'surges','urge','urged'},
'urging':	{'surging'},
'urine':	{'brine','murine'},
'url':	{'curl','furl','ur','urn'},
'urn':	{'burn','rn','turn','un','ur','url','urns','usn'},
'urns':	{'burns','turns','urn'},
'us':	{'as','bs','bus','cs','es','hs','is','ks','ms','mus','os','ps','pus','ss','ts','u','uh','uk','um','un','up','ur','usa','use','usn','ut','uv','vs'},
'usa':	{'gsa','sa','ssa','una','us','usaf','usda','use','usn','uta'},
'usable':	{'sable','unable'},
'usaf':	{'usa'},
'usage':	{'osage','sage','usages'},
'usages':	{'sages','usage'},
'usda':	{'usa'},
'use':	{'ese','fuse','muse','se','sse','us','usa','used','user','uses','usn','ute'},
'used':	{'fused','use','user','uses'},
'user':	{'uber','use','used','users','uses','usher','ussr'},
'users':	{'user','uses'},
'uses':	{'buses','fuses','use','used','user','users','usps'},
'usher':	{'user'},
'using':	{'sing'},
'usn':	{'isn','sn','un','urn','us','usa','use'},
'usps':	{'uses'},
'ussr':	{'user'},
'ut':	{'at','but','ct','cut','et','ft','gut','ht','hut','it','kt','mt','nt','nut','out','pt','put','rut','t','tut','u','uh','uk','um','un','up','ur','us','uta','ute','uv','vt'},
'uta':	{'eta','ta','una','usa','ut','utah','ute'},
'utah':	{'uta'},
'ute':	{'ate','cute','jute','mute','te','use','ut','uta'},
'utilisation':	{'utilization'},
'utilise':	{'utilised','utiliser','utilises','utilize'},
'utilised':	{'utilise','utiliser','utilises','utilized'},
'utiliser':	{'utilise','utilised','utilisers','utilises'},
'utilisers':	{'utiliser','utilises'},
'utilises':	{'utilise','utilised','utiliser','utilisers','utilizes'},
'utilising':	{'utilizing'},
'utility':	{'futility'},
'utilization':	{'utilisation'},
'utilize':	{'utilise','utilized','utilizes'},
'utilized':	{'utilised','utilize','utilizes'},
'utilizes':	{'utilises','utilize','utilized'},
'utilizing':	{'utilising'},
'utopia':	{'utopian'},
'utopian':	{'utopia'},
'utter':	{'butter','cutter','gutter','otter','putter'},
'utterance':	{'utterances'},
'utterances':	{'utterance'},
'uttered':	{'buttered','muttered'},
'uv':	{'av','cv','ev','iv','jv','lv','nv','rv','suv','tv','u','uh','uk','um','un','up','ur','us','ut','v','wv','xv'},
'v':	{'a','av','b','c','cv','d','e','ev','f','g','h','i','iv','j','jv','k','l','lv','nv','o','p','q','r','rv','t','tv','u','uv','va','vd','ve','vi','vs','vt','w','wv','x','xv','y','z'},
'va':	{'a','ba','ca','da','ea','fa','ga','ha','ia','iva','ka','la','ma','na','pa','ra','sa','ta','v','vac','van','var','vat','vd','ve','vi','via','vs','vt','wa','ya','za'},
'vac':	{'ac','lac','mac','pac','sac','va','van','var','vat','wac'},
'vacate':	{'vacated'},
'vacated':	{'vacate'},
'vacation':	{'vacations','vocation'},
'vacations':	{'vacation'},
'vaccination':	{'vaccinations'},
'vaccinations':	{'vaccination'},
'vaccine':	{'vaccines'},
'vaccines':	{'vaccine'},
'vacuum':	{'vacuums'},
'vacuums':	{'vacuum'},
'vagina':	{'vaginal'},
'vaginal':	{'vagina'},
'vague':	{'value','vogue'},
'vain':	{'cain','gain','jain','lain','main','pain','rain','van','vein'},
'vainly':	{'mainly'},
'valance':	{'balance','valence'},
'vale':	{'ale','bale','dale','gale','hale','male','pale','sale','tale','valet','value','valve','vase','vile','yale'},
'valence':	{'valance'},
'valentine':	{'valentines'},
'valentines':	{'valentine'},
'valet':	{'vale'},
'valiant':	{'variant'},
'validate':	{'validated','validates'},
'validated':	{'validate','validates'},
'validates':	{'validate','validated'},
'valley':	{'alley','galley','halley','valleys','volley'},
'valleys':	{'alleys','valley'},
'valor':	{'vapor'},
'valuable':	{'valuables'},
'valuables':	{'valuable'},
'valuation':	{'evaluation','valuations'},
'valuations':	{'evaluations','valuation'},
'value':	{'vague','vale','valued','valuer','values','valve'},
'valued':	{'value','valuer','values'},
'valuer':	{'value','valued','values'},
'values':	{'value','valued','valuer','valves'},
'valve':	{'vale','value','valves'},
'valves':	{'calves','halves','values','valve'},
'vampire':	{'vampires'},
'vampires':	{'vampire'},
'van':	{'an','ban','can','fan','han','jan','lan','man','nan','pan','ran','tan','va','vac','vain','vans','var','vat','von','wan'},
'vandals':	{'sandals'},
'vanish':	{'danish','varnish'},
'vanished':	{'banished','vanishes'},
'vanishes':	{'vanished'},
'vanity':	{'sanity'},
'vans':	{'ans','bans','cans','dans','evans','fans','mans','pans','sans','van'},
'vantage':	{'vintage'},
'vapor':	{'valor','vapors','vapour'},
'vapors':	{'vapor'},
'vapour':	{'vapor'},
'var':	{'ar','bar','car','dar','ear','far','gar','jar','mar','oar','par','tar','va','vac','van','vary','vat','vcr','war'},
'variable':	{'variables','variably'},
'variables':	{'variable'},
'variably':	{'variable'},
'variance':	{'variances'},
'variances':	{'variance'},
'variant':	{'valiant','variants'},
'variants':	{'variant'},
'variation':	{'variations'},
'variations':	{'variation'},
'varied':	{'varies'},
'varies':	{'aries','caries','ovaries','varied'},
'varnish':	{'garnish','vanish'},
'vary':	{'gary','mary','ovary','var','very','wary'},
'vase':	{'base','case','ease','vale','vases','vast'},
'vases':	{'bases','cases','eases','gases','vase'},
'vast':	{'cast','east','fast','hast','last','mast','past','vase','vat','vest'},
'vastly':	{'lastly'},
'vat':	{'at','bat','cat','dat','eat','fat','hat','kat','lat','mat','oat','pat','rat','sat','tat','va','vac','van','var','vast','vet','vt','wat'},
'vault':	{'fault','vaults'},
'vaults':	{'faults','vault'},
'vcr':	{'cr','var'},
'vd':	{'ad','cd','d','dd','dvd','ed','gd','id','md','nd','od','pd','sd','v','va','ve','vi','vs','vt'},
've':	{'ave','be','ce','de','e','ee','eve','fe','ge','he','ie','le','me','ne','pe','se','te','v','va','vd','veg','vet','vi','vie','vs','vt','we','xe','ye'},
'veal':	{'deal','heal','meal','real','seal','teal','veil','vial','zeal'},
'vector':	{'hector','rector','sector','vectors','victor'},
'vectors':	{'sectors','vector'},
'veg':	{'beg','eeg','leg','meg','peg','ve','vega','vet'},
'vega':	{'mega','veg','vegan'},
'vegan':	{'began','vega'},
'vegetable':	{'vegetables'},
'vegetables':	{'vegetable'},
'vegetarian':	{'vegetarians'},
'vegetarians':	{'vegetarian'},
'veggie':	{'veggies'},
'veggies':	{'veggie'},
'vehicle':	{'vehicles','vesicle'},
'vehicles':	{'vehicle','vesicles'},
'veil':	{'veal','veils','vein'},
'veiling':	{'ceiling'},
'veils':	{'veil','veins'},
'vein':	{'rein','vain','veil','veins'},
'veins':	{'reins','veils','vein'},
'vending':	{'bending','ending','lending','mending','pending','sending','tending','venting'},
'vendor':	{'vendors'},
'vendors':	{'vendor'},
'veneer':	{'veneers'},
'veneers':	{'veneer'},
'venezuela':	{'venezuelan'},
'venezuelan':	{'venezuela'},
'venous':	{'venus'},
'vent':	{'bent','cent','dent','event','gent','kent','lent','rent','sent','tent','vents','vest','vet','went'},
'vented':	{'rented','tented','vested'},
'venting':	{'renting','vending','vesting'},
'ventral':	{'central'},
'vents':	{'cents','dents','events','gents','rents','tents','vent','venus','vests','vets'},
'venture':	{'ventured','ventures'},
'ventured':	{'venture','ventures'},
'ventures':	{'venture','ventured'},
'venue':	{'avenue','venues','venus'},
'venues':	{'avenues','venue','venus'},
'venus':	{'genus','menus','venous','vents','venue','venues'},
'verb':	{'herb','serb','verbs','very'},
'verbal':	{'herbal'},
'verbs':	{'herbs','verb'},
'verde':	{'verdi','verge','verne','verse','verve'},
'verdi':	{'verde'},
'verdict':	{'verdicts'},
'verdicts':	{'verdict'},
'verge':	{'merge','serge','verde','verne','verse','verve'},
'verified':	{'verifier','verifies'},
'verifier':	{'verified','verifies'},
'verifies':	{'verified','verifier'},
'verify':	{'verily','verity'},
'verily':	{'verify','verity'},
'verity':	{'verify','verily'},
'verne':	{'verde','verge','verse','verve'},
'verse':	{'averse','verde','verge','verne','versed','verses','verso','verve'},
'versed':	{'verse','verses'},
'verses':	{'verse','versed','versus'},
'version':	{'aversion','versions'},
'versions':	{'version'},
'verso':	{'verse'},
'versus':	{'verses'},
'vertebrae':	{'vertebral','vertebrate'},
'vertebral':	{'vertebrae'},
'vertebrate':	{'vertebrae','vertebrates'},
'vertebrates':	{'vertebrate'},
'vertex':	{'vortex'},
'verve':	{'nerve','serve','verde','verge','verne','verse'},
'very':	{'every','vary','verb'},
'vesicle':	{'vehicle','vesicles'},
'vesicles':	{'vehicles','vesicle'},
'vessel':	{'vessels'},
'vessels':	{'vessel'},
'vest':	{'best','est','fest','jest','lest','nest','pest','rest','test','vast','vent','vesta','vests','vet','west','zest'},
'vesta':	{'esta','vest','vestal','vests','vista'},
'vestal':	{'vesta'},
'vested':	{'nested','rested','tested','vented'},
'vesting':	{'nesting','resting','testing','venting'},
'vests':	{'nests','pests','rests','tests','vents','vest','vesta','vets'},
'vet':	{'bet','et','get','jet','let','met','net','pet','set','tet','vat','ve','veg','vent','vest','veto','vets','vt','wet','yet'},
'veteran':	{'veterans'},
'veterans':	{'veteran'},
'veterinarian':	{'veterinarians'},
'veterinarians':	{'veterinarian'},
'veto':	{'vet','vets'},
'vets':	{'bets','gets','lets','nets','pets','sets','vents','vests','vet','veto','wets'},
'vfw':	{'vow'},
'vhf':	{'hf','uhf'},
'vi':	{'ai','bi','ci','di','gi','hi','i','ii','ji','ki','li','mi','ni','pi','qi','ri','si','ti','v','va','vd','ve','via','vie','vii','vim','vip','vs','vt','wi','xi','xvi','yi'},
'via':	{'cia','ia','pia','tia','va','vi','vial','vida','vie','vii','vila','vim','vip','visa','viva'},
'viability':	{'liability'},
'viable':	{'liable'},
'vial':	{'dial','rial','veal','via','vials','vidal','viral','vital'},
'vials':	{'dials','vial'},
'vibe':	{'vibes','vice','vie','vile','vine'},
'vibes':	{'vibe','vices','vines'},
'vibration':	{'vibrations'},
'vibrations':	{'vibration'},
'vibrator':	{'vibrators'},
'vibrators':	{'vibrator'},
'vice':	{'dice','ice','lice','mice','nice','rice','vibe','vices','vie','vile','vine','voice'},
'vices':	{'vibes','vice','vines','voices'},
'victim':	{'victims'},
'victims':	{'victim'},
'victor':	{'vector','victory'},
'victoria':	{'victorian'},
'victorian':	{'victoria'},
'victory':	{'victor'},
'vida':	{'ida','via','vidal','vila','visa','viva'},
'vidal':	{'tidal','vial','vida','viral','vital'},
'video':	{'videos'},
'videos':	{'video'},
'videotape':	{'videotaped','videotapes'},
'videotaped':	{'videotape','videotapes'},
'videotapes':	{'videotape','videotaped'},
'vie':	{'die','ie','lie','pie','tie','ve','vi','via','vibe','vice','vien','view','vii','vile','vim','vine','vip'},
'vien':	{'lien','vie','view','vixen'},
'vienna':	{'sienna'},
'view':	{'vie','vien','views'},
'viewed':	{'viewer'},
'viewer':	{'viewed','viewers'},
'viewers':	{'viewer'},
'viewpoint':	{'viewpoints'},
'viewpoints':	{'viewpoint'},
'views':	{'view'},
'vigil':	{'virgil'},
'vignette':	{'vignettes'},
'vignettes':	{'vignette'},
'vigor':	{'rigor','visor'},
'vigorous':	{'rigorous'},
'vigorously':	{'rigorously'},
'vii':	{'ii','iii','lii','vi','via','vie','viii','vim','vip','xii','xvii'},
'viii':	{'iii','vii','xiii','xviii'},
'viking':	{'biking','hiking','liking'},
'vila':	{'gila','via','vida','vile','villa','viola','visa','viva'},
'vile':	{'bile','file','mile','nile','pile','tile','vale','vibe','vice','vie','vila','ville','vine'},
'villa':	{'vila','villas','ville','viola'},
'village':	{'tillage','villager','villages'},
'villager':	{'village','villagers','villages'},
'villagers':	{'villager','villages'},
'villages':	{'village','villager','villagers'},
'villain':	{'villains'},
'villains':	{'villain'},
'villas':	{'villa'},
'ville':	{'lille','vile','villa'},
'vim':	{'aim','dim','him','rim','vi','via','vie','vii','vip'},
'vine':	{'cine','dine','fine','line','mine','nine','pine','sine','vibe','vice','vie','vile','vines','vino','wine','zine'},
'vines':	{'dines','fines','lines','mines','nines','pines','vibes','vices','vine','wines','zines'},
'vineyard':	{'vineyards'},
'vineyards':	{'vineyard'},
'vino':	{'vine'},
'vintage':	{'vantage','vintages'},
'vintages':	{'vintage'},
'viola':	{'vila','villa'},
'violate':	{'violated','violates'},
'violated':	{'violate','violates'},
'violates':	{'violate','violated'},
'violation':	{'violations'},
'violations':	{'violation'},
'violent':	{'violet'},
'violet':	{'violent'},
'vip':	{'dip','hip','ip','kip','lip','nip','pip','rip','sip','tip','vi','via','vie','vii','vim','yip','zip'},
'viper':	{'piper','riper','wiper'},
'viral':	{'vial','vidal','vital'},
'virgil':	{'vigil','virgin'},
'virgin':	{'virgil','virgins'},
'virginia':	{'virginian'},
'virginian':	{'virginia'},
'virgins':	{'virgin'},
'virtue':	{'virtues'},
'virtues':	{'virtue'},
'visa':	{'pisa','via','vida','vila','visas','vista','viva'},
'visas':	{'visa','vistas'},
'viscount':	{'discount'},
'visible':	{'visibly'},
'visibly':	{'visible'},
'vision':	{'visions'},
'visions':	{'vision'},
'visit':	{'visits'},
'visitor':	{'visitors'},
'visitors':	{'visitor'},
'visits':	{'visit'},
'visor':	{'vigor','visors'},
'visors':	{'visor'},
'vista':	{'vesta','visa','vistas'},
'vistas':	{'visas','vista'},
'visual':	{'visuals'},
'visualisation':	{'visualization'},
'visualise':	{'visualised','visualize'},
'visualised':	{'visualise','visualized'},
'visualising':	{'visualizing'},
'visualization':	{'visualisation'},
'visualize':	{'visualise','visualized'},
'visualized':	{'visualised','visualize'},
'visualizing':	{'visualising'},
'visuals':	{'visual'},
'vitae':	{'vital'},
'vital':	{'vial','vidal','viral','vitae'},
'vitamin':	{'vitamins'},
'vitamins':	{'vitamin'},
'viva':	{'diva','iva','via','vida','vila','visa'},
'vixen':	{'vien'},
'vocal':	{'focal','local','vocals'},
'vocals':	{'locals','vocal'},
'vocation':	{'location','vacation'},
'vogue':	{'rogue','vague'},
'voice':	{'vice','voiced','voices'},
'voiced':	{'voice','voices'},
'voices':	{'vices','voice','voiced'},
'void':	{'avoid','voids'},
'voids':	{'avoids','void'},
'vol':	{'col','fol','pol','sol','volt','von','vow'},
'volga':	{'volta'},
'volley':	{'valley'},
'volt':	{'bolt','colt','jolt','vol','volta','volts'},
'volta':	{'volga','volt','volts'},
'voltage':	{'voltages'},
'voltages':	{'voltage'},
'volts':	{'bolts','volt','volta'},
'volume':	{'volumes'},
'volumes':	{'volume'},
'volunteer':	{'volunteers'},
'volunteers':	{'volunteer'},
'vomit':	{'omit'},
'von':	{'avon','con','don','hon','ion','mon','non','on','ron','son','ton','van','vol','vow','won','yon'},
'vortex':	{'cortex','vertex'},
'vote':	{'cote','note','tote','voted','voter','votes'},
'voted':	{'noted','vote','voter','votes','vowed'},
'voter':	{'vote','voted','voters','votes'},
'voters':	{'voter','votes'},
'votes':	{'notes','totes','vote','voted','voter','voters'},
'voting':	{'noting'},
'votive':	{'motive'},
'vouch':	{'couch','pouch','touch'},
'voucher':	{'vouchers'},
'vouchers':	{'voucher'},
'vow':	{'bow','cow','how','low','now','ow','pow','row','sow','tow','vfw','vol','von','vows','wow'},
'vowed':	{'bowed','owed','rowed','sowed','towed','voted','vowel'},
'vowel':	{'bowel','towel','vowed','vowels'},
'vowels':	{'bowels','towels','vowel'},
'vows':	{'bows','cows','hows','lows','rows','sows','vow'},
'voyage':	{'voyaged','voyager','voyages'},
'voyaged':	{'voyage','voyager','voyages'},
'voyager':	{'voyage','voyaged','voyages'},
'voyages':	{'voyage','voyaged','voyager'},
'vs':	{'as','bs','cs','es','hs','is','ks','ms','os','ps','ss','ts','us','v','va','vd','ve','vi','vt'},
'vt':	{'at','ct','et','ft','ht','it','kt','mt','nt','pt','t','ut','v','va','vat','vd','ve','vet','vi','vs'},
'vulture':	{'culture'},
'vying':	{'dying','lying','tying','ying'},
'w':	{'a','b','c','d','e','f','g','h','i','j','k','kw','l','nw','o','ow','p','q','r','sw','t','u','v','wa','we','wi','wm','wo','wu','wv','wy','x','y','z'},
'wa':	{'a','ba','ca','da','ea','fa','ga','ha','ia','ka','la','ma','na','pa','ra','sa','ta','va','w','wac','wad','wai','wan','war','was','wat','wax','way','we','wi','wm','wo','wu','wv','wy','ya','za'},
'wac':	{'ac','lac','mac','pac','sac','vac','wa','waco','wad','wai','wan','war','was','wat','wax','way'},
'wacky':	{'tacky'},
'waco':	{'taco','wac'},
'wad':	{'ad','bad','cad','dad','fad','had','lad','mad','pad','rad','sad','tad','wa','wac','wade','wai','wan','wand','war','ward','was','wat','wax','way','wed'},
'wade':	{'ade','bade','fade','jade','made','sade','wad','wage','wake','ware','wave','wide'},
'wading':	{'fading','waging','waking','waning','waving','waxing'},
'wafer':	{'safer','wafers','wager','water'},
'wafers':	{'wafer','waters'},
'waffle':	{'raffle','waffles'},
'waffles':	{'raffles','waffle'},
'wage':	{'age','cage','gage','page','rage','sage','wade','waged','wager','wages','wake','ware','wave'},
'waged':	{'aged','caged','wage','wager','wages','waved','waxed'},
'wager':	{'eager','lager','pager','wafer','wage','waged','wages','wagner','water'},
'wagering':	{'watering'},
'wages':	{'ages','cages','pages','sages','wage','waged','wager','wakes','wales','wares','waves','waxes'},
'waging':	{'aging','caging','paging','raging','wading','waking','waning','waving','waxing'},
'wagner':	{'wager','wagoner','warner'},
'wagon':	{'wagons'},
'wagoner':	{'wagner'},
'wagons':	{'wagon'},
'wai':	{'ai','bai','sai','tai','wa','wac','wad','wait','wan','war','was','wat','wax','way','wei','wi'},
'wailing':	{'ailing','failing','mailing','nailing','railing','sailing','waiting'},
'waist':	{'waists','wait','wrist'},
'waists':	{'waist','waits','wrists'},
'wait':	{'await','bait','gait','wai','waist','waite','waits','want','wat','watt','whit','wit','writ'},
'waite':	{'wait','waited','waiter','waits','waive','waste','white','write'},
'waited':	{'awaited','waite','waiter','waived','wanted','wasted'},
'waiter':	{'waite','waited','waiters','waiver','walter','water','whiter','writer'},
'waiters':	{'waiter','waivers','waters','writers'},
'waiting':	{'awaiting','wailing','wanting','wasting','whiting','writing'},
'waits':	{'awaits','baits','waists','wait','waite','wants','warts','watts','wits'},
'waive':	{'naive','waite','waived','waiver','wave'},
'waived':	{'waited','waive','waiver','waved'},
'waiver':	{'waiter','waive','waived','waivers'},
'waivers':	{'waiters','waiver'},
'wake':	{'awake','bake','cake','fake','lake','make','rake','sake','take','wade','wage','waken','wakes','ware','wave','woke'},
'waken':	{'awaken','taken','wake','wakes','weaken','woken'},
'wakes':	{'bakes','cakes','fakes','lakes','makes','rakes','sakes','takes','wages','wake','waken','wales','wares','waves','waxes'},
'waking':	{'baking','making','raking','taking','wading','waging','walking','waning','waving','waxing'},
'wales':	{'ales','bales','males','pales','sales','tales','wages','wakes','walks','walls','wares','waves','waxes','whales'},
'walk':	{'talk','walks','wall','wank'},
'walked':	{'talked','walker','walled'},
'walker':	{'walked','walkers','waller','walter'},
'walkers':	{'walker'},
'walking':	{'talking','waking'},
'walks':	{'talks','wales','walk','walls'},
'walkway':	{'walkways'},
'walkways':	{'walkway'},
'wall':	{'all','ball','call','fall','gall','hall','mall','pall','tall','walk','walls','wally','well','will'},
'walled':	{'called','walked','waller','wallet','willed'},
'waller':	{'caller','taller','walker','walled','wallet','walter'},
'wallet':	{'ballet','mallet','pallet','walled','waller','wallets'},
'wallets':	{'pallets','wallet'},
'wallpaper':	{'wallpapers'},
'wallpapers':	{'wallpaper'},
'walls':	{'balls','calls','falls','halls','malls','wales','walks','wall','wally','wells','wills'},
'wally':	{'ally','bally','cally','rally','sally','tally','wall','walls'},
'walnut':	{'walnuts'},
'walnuts':	{'walnut'},
'walter':	{'alter','halter','salter','waiter','walker','waller','water'},
'walton':	{'dalton','wanton','wilton'},
'wan':	{'an','ban','can','fan','han','jan','lan','man','nan','pan','ran','swan','tan','van','wa','wac','wad','wai','wand','wank','want','war','warn','was','wasn','wat','wax','way','wen','win','won'},
'wand':	{'and','band','hand','land','rand','sand','wad','wan','wands','wank','want','ward','wind'},
'wander':	{'lander','sander','wanders','winder','wonder'},
'wandered':	{'wanderer','wondered'},
'wanderer':	{'wandered','wanderers'},
'wanderers':	{'wanderer'},
'wandering':	{'wondering'},
'wanders':	{'wander','wonders'},
'wands':	{'bands','hands','lands','sands','wand','wants','wards','winds'},
'waning':	{'wading','waging','waking','wanting','warning','waving','waxing','weaning','wining'},
'wank':	{'bank','hank','rank','sank','swank','tank','walk','wan','wand','want','wink','yank'},
'wanna':	{'anna'},
'want':	{'ant','cant','kant','pant','rant','wait','wan','wand','wank','wants','wat','watt','went','wont'},
'wanted':	{'waited','wasted'},
'wanting':	{'ranting','waiting','waning','wasting'},
'wanton':	{'canton','walton'},
'wants':	{'ants','pants','rants','waits','wands','want','warts','watts'},
'war':	{'ar','bar','car','dar','ear','far','gar','jar','mar','oar','par','tar','var','wa','wac','wad','wai','wan','ward','ware','warm','warn','warp','wars','wary','was','wat','wax','way','wear'},
'ward':	{'award','bard','card','hard','wad','wand','war','wards','ware','warm','warn','warp','wars','wary','word','yard'},
'warden':	{'garden','harden','warren'},
'wards':	{'awards','cards','wands','ward','wares','warms','warns','wars','warts','words','yards'},
'ware':	{'are','aware','bare','care','dare','fare','hare','mare','rare','wade','wage','wake','war','ward','wares','warm','warn','warp','wars','wary','wave','were','wire','wore'},
'warehouse':	{'warehouses'},
'warehouses':	{'warehouse'},
'wares':	{'ares','bares','cares','dares','fares','mares','wages','wakes','wales','wards','ware','warms','warns','wars','warts','waves','waxes','wires'},
'warm':	{'arm','farm','harm','swarm','war','ward','ware','warms','warn','warp','wars','wary','worm'},
'warmed':	{'armed','farmed','harmed','warmer','warned','warped','warred','wormed'},
'warmer':	{'farmer','warmed','warmers','warner'},
'warmers':	{'farmers','warmer'},
'warming':	{'farming','harming','warning','warring','worming'},
'warms':	{'arms','farms','harms','wards','wares','warm','warns','wars','warts','worms'},
'warn':	{'barn','darn','earn','wan','war','ward','ware','warm','warns','warp','wars','wary','wasn','worn','yarn'},
'warned':	{'earned','warmed','warner','warped','warred'},
'warner':	{'garner','wagner','warmer','warned'},
'warning':	{'earning','waning','warming','warnings','warring'},
'warnings':	{'earnings','warning'},
'warns':	{'barns','earns','wards','wares','warms','warn','wars','warts','yarns'},
'warp':	{'carp','harp','war','ward','ware','warm','warn','wars','wary','wasp'},
'warped':	{'warmed','warned','warred'},
'warrant':	{'warrants','warranty'},
'warrants':	{'warrant','warranty'},
'warranty':	{'warrant','warrants'},
'warred':	{'barred','marred','warmed','warned','warped','warren'},
'warren':	{'barren','warden','warred'},
'warring':	{'barring','earring','warming','warning'},
'wars':	{'bars','cars','ears','jars','mars','oars','war','ward','wards','ware','wares','warm','warms','warn','warns','warp','warts','wary','was','ways','wears'},
'warts':	{'arts','carts','darts','karts','parts','tarts','waits','wants','wards','wares','warms','warns','wars','watts'},
'wary':	{'gary','mary','vary','war','ward','ware','warm','warn','warp','wars','wavy','way','weary'},
'was':	{'as','gas','has','mas','oas','pas','wa','wac','wad','wai','wan','war','wars','wash','wasn','wasp','wat','wax','way','ways'},
'wash':	{'ash','bash','cash','dash','hash','lash','mash','nash','rash','sash','was','wasn','wasp','wish'},
'washed':	{'dashed','mashed','washer','washes','wasted','wished'},
'washer':	{'washed','washers','washes'},
'washers':	{'washer','washes'},
'washes':	{'ashes','dashes','hashes','lashes','washed','washer','washers','wastes','wishes'},
'washing':	{'bashing','cashing','dashing','hashing','wasting','wishing'},
'wasn':	{'hasn','wan','warn','was','wash','wasp'},
'wasp':	{'asp','gasp','warp','was','wash','wasn','wasps','wisp'},
'wasps':	{'wasp'},
'waste':	{'caste','haste','paste','taste','waite','wasted','wastes'},
'wasted':	{'lasted','pasted','tasted','waited','wanted','washed','waste','wastes'},
'wasteful':	{'tasteful'},
'wastefully':	{'tastefully'},
'wastes':	{'pastes','tastes','washes','waste','wasted'},
'wasting':	{'casting','fasting','lasting','pasting','tasting','waiting','wanting','washing'},
'wat':	{'at','bat','cat','dat','eat','fat','hat','kat','lat','mat','oat','pat','rat','sat','swat','tat','twat','vat','wa','wac','wad','wai','wait','wan','want','war','was','watt','wax','way','wet','what','wit','wot'},
'watch':	{'batch','catch','hatch','latch','match','patch','swatch','witch'},
'watched':	{'hatched','matched','patched','watcher','watches'},
'watcher':	{'catcher','watched','watchers','watches'},
'watchers':	{'watcher','watches'},
'watches':	{'batches','catches','latches','matches','patches','watched','watcher','watchers','witches'},
'watching':	{'catching','hatching','matching','patching'},
'water':	{'cater','eater','later','mater','wafer','wager','waiter','walter','waters','watery'},
'watercolor':	{'watercolour'},
'watercolour':	{'watercolor'},
'watered':	{'catered'},
'waterfall':	{'waterfalls'},
'waterfalls':	{'waterfall'},
'watering':	{'catering','wagering'},
'waters':	{'caters','eaters','haters','wafers','waiters','water','watery'},
'watershed':	{'watersheds'},
'watersheds':	{'watershed'},
'waterway':	{'waterways'},
'waterways':	{'waterway'},
'watery':	{'water','waters'},
'watt':	{'gatt','matt','wait','want','wat','watts','wyatt'},
'watts':	{'waits','wants','warts','watt'},
'waugh':	{'laugh'},
'wave':	{'ave','cave','fave','gave','have','pave','rave','save','wade','wage','waive','wake','ware','waved','waves','wavy','weave','wove'},
'waved':	{'caved','paved','saved','waged','waived','wave','waves','waxed','weaved'},
'waveform':	{'waveforms'},
'waveforms':	{'waveform'},
'wavelength':	{'wavelengths'},
'wavelengths':	{'wavelength'},
'waves':	{'caves','haves','raves','saves','wages','wakes','wales','wares','wave','waved','waxes','weaves','wives'},
'waving':	{'caving','having','paving','raving','saving','wading','waging','waking','waning','waxing','weaving'},
'wavy':	{'davy','navy','wary','wave','way'},
'wax':	{'ax','fax','lax','max','sax','tax','wa','wac','wad','wai','wan','war','was','wat','way'},
'waxed':	{'axed','faxed','taxed','waged','waved','waxes'},
'waxes':	{'axes','faxes','taxes','wages','wakes','wales','wares','waves','waxed'},
'waxing':	{'axing','faxing','taxing','wading','waging','waking','waning','waving'},
'way':	{'away','bay','cay','day','fay','gay','hay','jay','lay','may','nay','pay','ray','say','sway','wa','wac','wad','wai','wan','war','wary','was','wat','wavy','wax','ways','why','wy'},
'ways':	{'bays','days','gays','hays','lays','mays','nays','pays','rays','says','wars','was','way'},
'we':	{'awe','be','ce','de','e','ee','fe','ge','he','ie','le','me','ne','owe','pe','se','te','ve','w','wa','web','wed','wee','wei','wen','wet','wi','wm','wo','woe','wu','wv','wy','wye','xe','ye'},
'weak':	{'beak','leak','peak','teak','tweak','wear','week'},
'weaken':	{'waken','weaker'},
'weaker':	{'weaken','wearer','weaver'},
'weakly':	{'weekly'},
'wealth':	{'health','wealthy'},
'wealthiest':	{'healthiest'},
'wealthy':	{'healthy','wealth'},
'weaning':	{'leaning','meaning','waning','wearing','weaving'},
'weapon':	{'weapons'},
'weapons':	{'weapon'},
'wear':	{'bear','dear','ear','fear','gear','hear','lear','near','pear','rear','swear','tear','war','weak','wears','weary','weir','year'},
'wearer':	{'bearer','hearer','nearer','weaker','weaver'},
'wearing':	{'bearing','fearing','gearing','hearing','nearing','rearing','swearing','tearing','weaning','weaving'},
'wears':	{'bears','dears','ears','fears','gears','hears','nears','pears','swears','tears','wars','wear','weary','years'},
'weary':	{'leary','wary','wear','wears'},
'weasel':	{'easel'},
'weather':	{'feather','heather','leather','weathers'},
'weathered':	{'feathered'},
'weathering':	{'feathering'},
'weathers':	{'feathers','leathers','weather'},
'weave':	{'leave','wave','weaved','weaver','weaves'},
'weaved':	{'leaved','waved','weave','weaver','weaves'},
'weaver':	{'beaver','weaker','wearer','weave','weaved','weavers','weaves'},
'weavers':	{'leavers','weaver','weaves'},
'weaves':	{'leaves','waves','weave','weaved','weaver','weavers'},
'weaving':	{'leaving','waving','weaning','wearing'},
'web':	{'deb','eb','feb','we','webb','webs','wed','wee','wei','wen','wet'},
'webb':	{'ebb','web','webs'},
'webs':	{'web','webb','wets'},
'website':	{'websites'},
'websites':	{'website'},
'wed':	{'bed','ed','fed','led','med','owed','qed','red','ted','wad','we','web','wee','weed','wei','weld','wen','wet','zed'},
'wedding':	{'bedding','weddings','weeding','welding'},
'weddings':	{'wedding'},
'wedge':	{'edge','hedge','ledge','wedges'},
'wedges':	{'edges','hedges','wedge'},
'wednesday':	{'wednesdays'},
'wednesdays':	{'wednesday'},
'wee':	{'bee','ee','fee','gee','lee','nee','pee','see','tee','we','web','wed','weed','week','weep','wei','wen','were','wet','woe','wye'},
'weed':	{'deed','feed','heed','need','reed','seed','tweed','wed','wee','weeds','week','weep','weld'},
'weeded':	{'needed','seeded','welded'},
'weeding':	{'feeding','needing','seeding','wedding','weeping','welding'},
'weeds':	{'deeds','feeds','leeds','needs','reeds','seeds','weed','weeks'},
'week':	{'eek','geek','leek','meek','peek','seek','weak','wee','weed','weeks','weep'},
'weekday':	{'weekdays'},
'weekdays':	{'weekday'},
'weekend':	{'weekends'},
'weekends':	{'weekend'},
'weekly':	{'weakly'},
'weeks':	{'geeks','seeks','weeds','week'},
'weep':	{'beep','deep','jeep','keep','peep','sweep','wee','weed','week'},
'weeping':	{'keeping','peeping','sweeping','weeding'},
'wei':	{'lei','mei','pei','wai','we','web','wed','wee','weir','wen','wet','wi'},
'weigh':	{'leigh','weighs','weight'},
'weighed':	{'weighted'},
'weighing':	{'weighting'},
'weighs':	{'weigh','weight','weights'},
'weight':	{'eight','height','weigh','weighs','weights','wight','wright'},
'weighted':	{'weighed'},
'weighting':	{'weighing'},
'weights':	{'eights','heights','weighs','weight'},
'weill':	{'well','will'},
'weir':	{'heir','meir','wear','wei','weird'},
'weird':	{'weir'},
'welcome':	{'welcomed','welcomes'},
'welcomed':	{'welcome','welcomes'},
'welcomes':	{'welcome','welcomed'},
'weld':	{'geld','held','wed','weed','well','welt','wield','wild'},
'welded':	{'weeded','welder'},
'welder':	{'elder','welded','welders','wilder'},
'welders':	{'elders','welder'},
'welding':	{'wedding','weeding','wielding'},
'well':	{'bell','cell','dell','dwell','ell','fell','hell','sell','swell','tell','wall','weill','weld','wells','welt','will','yell'},
'welles':	{'wells'},
'wellington':	{'ellington'},
'wells':	{'bells','cells','dwells','hells','sells','swells','tells','walls','well','welles','wills','yells'},
'welt':	{'belt','dwelt','felt','melt','weld','well','went','wept','west','wet','wilt'},
'wen':	{'ben','den','en','fen','gen','hen','ken','men','owen','pen','sen','ten','wan','we','web','wed','wee','wei','went','wet','when','win','won','wren','yen','zen'},
'went':	{'bent','cent','dent','gent','kent','lent','rent','sent','tent','vent','want','welt','wen','wept','west','wet','wont'},
'wept':	{'kept','sept','swept','welt','went','west','wet'},
'were':	{'ere','here','mere','ware','wee','weren','where','wire','wore'},
'weren':	{'were','wren'},
'wessex':	{'essex'},
'west':	{'best','est','fest','jest','lest','nest','pest','rest','test','vest','welt','went','wept','wet','zest'},
'western':	{'westerns'},
'westerns':	{'western'},
'westward':	{'westwards'},
'westwards':	{'westward'},
'wet':	{'bet','et','get','jet','let','met','net','pet','set','tet','vet','wat','we','web','wed','wee','wei','welt','wen','went','wept','west','wets','wit','wot','yet'},
'wetland':	{'wetlands'},
'wetlands':	{'wetland'},
'wets':	{'bets','gets','lets','nets','pets','sets','vets','webs','wet','wits'},
'wetting':	{'betting','getting','letting','netting','setting'},
'whack':	{'hack','shack'},
'whale':	{'hale','shale','whales','while','whole'},
'whales':	{'thales','wales','whale'},
'what':	{'chat','hat','phat','that','wat','whats','wheat','whit'},
'whats':	{'chats','hats','what','wheats'},
'wheat':	{'cheat','heat','what','wheats'},
'wheats':	{'cheats','heats','whats','wheat'},
'wheel':	{'heel','wheels'},
'wheelchair':	{'wheelchairs'},
'wheelchairs':	{'wheelchair'},
'wheeled':	{'wheeler'},
'wheeler':	{'wheeled'},
'wheels':	{'heels','wheel'},
'when':	{'chen','hen','then','wen','whey','wren'},
'whence':	{'hence','thence'},
'whenever':	{'wherever'},
'where':	{'here','there','were','whore'},
'whereby':	{'hereby','thereby'},
'wherefore':	{'therefore'},
'wherein':	{'herein','therein'},
'whereof':	{'hereof','thereof'},
'whereupon':	{'thereupon'},
'wherever':	{'whenever'},
'whether':	{'whither'},
'whey':	{'hey','they','when','why'},
'while':	{'awhile','chile','whale','whine','white','whole'},
'whim':	{'him','whip','whit','whiz','whom'},
'whine':	{'rhine','shine','thine','while','white','wine'},
'whining':	{'shining','whiting','wining'},
'whip':	{'chip','hip','ship','whim','whips','whit','whiz'},
'whipped':	{'chipped','shipped'},
'whipping':	{'chipping','shipping','whopping'},
'whips':	{'chips','hips','ships','whip'},
'whisk':	{'whisky'},
'whiskey':	{'whisky'},
'whisky':	{'whisk','whiskey'},
'whisper':	{'whispers'},
'whispers':	{'whisper'},
'whistle':	{'thistle','whistled','whistler','whistles','whittle'},
'whistled':	{'whistle','whistler','whistles'},
'whistler':	{'whistle','whistled','whistles'},
'whistles':	{'whistle','whistled','whistler'},
'whit':	{'chit','hit','shit','wait','what','whim','whip','white','whiz','wit','writ'},
'white':	{'waite','while','whine','whit','whiter','whites','write'},
'whiter':	{'waiter','white','whites','whither','writer'},
'whites':	{'white','whiter','whitest','writes'},
'whitest':	{'whites'},
'whither':	{'hither','thither','whether','whiter'},
'whiting':	{'waiting','whining','writing'},
'whittle':	{'whistle'},
'whiz':	{'whim','whip','whit'},
'who':	{'ho','rho','tho','whom','why','wo','woo'},
'whoever':	{'whomever'},
'whole':	{'hole','whale','while','whore','whose'},
'wholesale':	{'wholesaler'},
'wholesaler':	{'wholesale','wholesalers'},
'wholesalers':	{'wholesaler'},
'wholly':	{'holly','woolly'},
'whom':	{'whim','who'},
'whomever':	{'whoever'},
'whopping':	{'chopping','hopping','shopping','whipping'},
'whore':	{'chore','shore','where','whole','whores','whose','wore'},
'whores':	{'chores','shores','whore'},
'whose':	{'chose','hose','those','whole','whore'},
'why':	{'shy','thy','way','whey','who','wy'},
'wi':	{'ai','bi','ci','di','gi','hi','i','ii','ji','ki','li','mi','ni','pi','qi','ri','si','ti','vi','w','wa','wai','we','wei','wig','win','wit','wm','wo','wu','wv','wy','xi','yi'},
'wick':	{'dick','kick','lick','mick','nick','pick','rick','sick','tick','wink'},
'wicked':	{'kicked','licked','picked','ticked','wicker','wicket'},
'wicker':	{'kicker','picker','sicker','ticker','wicked','wicket'},
'wicket':	{'picket','ticket','wicked','wicker','wickets'},
'wickets':	{'tickets','wicket'},
'wide':	{'aide','hide','ride','side','tide','wade','widen','wider','wife','wilde','wine','wipe','wire','wise'},
'widely':	{'wisely'},
'widen':	{'wide','wider'},
'wideness':	{'wiseness'},
'wider':	{'cider','rider','wide','widen','wilder','winder','wiper','wiser'},
'widest':	{'wildest','wisest'},
'widget':	{'midget','widgets'},
'widgets':	{'midgets','widget'},
'widow':	{'widows','window'},
'widowed':	{'widower'},
'widower':	{'widowed'},
'widows':	{'widow','windows'},
'width':	{'widths','with'},
'widths':	{'width'},
'wield':	{'field','weld','wild','yield'},
'wielding':	{'fielding','welding','yielding'},
'wiener':	{'winner'},
'wife':	{'fife','life','rife','wide','wine','wipe','wire','wise'},
'wig':	{'big','dig','fig','gig','jig','pig','rig','sig','wi','wigs','win','wing','wit'},
'wiggle':	{'giggle','wiggles'},
'wiggles':	{'giggles','wiggle'},
'wight':	{'eight','fight','light','might','night','right','sight','tight','weight','wright'},
'wigs':	{'digs','figs','gigs','pigs','rigs','twigs','wig','wings','wins','wits'},
'wild':	{'mild','weld','wield','wilde','will','wilt','wind'},
'wilde':	{'wide','wild','wilder'},
'wilder':	{'milder','welder','wider','wilde','winder'},
'wildest':	{'mildest','widest'},
'wildflower':	{'wildflowers'},
'wildflowers':	{'wildflower'},
'wildly':	{'mildly'},
'wildness':	{'mildness'},
'will':	{'bill','dill','fill','gill','hill','ill','kill','mill','pill','sill','till','twill','wall','weill','well','wild','wills','wilt'},
'willed':	{'billed','filled','killed','milled','walled'},
'willing':	{'billing','filling','killing','milling'},
'willis':	{'wills'},
'willow':	{'pillow','willows'},
'willows':	{'pillows','willow'},
'wills':	{'bills','fills','hills','ills','kills','mills','pills','walls','wells','will','willis'},
'wilson':	{'wilton'},
'wilt':	{'gilt','kilt','milt','silt','tilt','welt','wild','will','wit'},
'wilton':	{'milton','walton','wilson'},
'win':	{'bin','din','fin','gin','in','kin','lin','min','pin','qin','sin','tin','twin','wan','wen','wi','wig','wind','wine','wing','wink','wins','wit','won','yin'},
'wince':	{'since','winch','wine'},
'winch':	{'finch','inch','pinch','wince','witch'},
'wind':	{'bind','find','hind','kind','lind','mind','wand','wild','win','winds','windy','wine','wined','wing','wink','wins'},
'winded':	{'minded','winder','wined','winged'},
'winder':	{'binder','finder','hinder','kinder','wander','wider','wilder','winded','winger','winner','winter','wonder'},
'winding':	{'binding','finding','minding','winging','wining','winning'},
'window':	{'widow','windows'},
'windows':	{'widows','window'},
'winds':	{'binds','finds','kinds','minds','wands','wind','windy','wines','wings','wins'},
'windy':	{'lindy','wind','winds'},
'wine':	{'cine','dine','fine','line','mine','nine','pine','sine','swine','vine','whine','wide','wife','win','wince','wind','wined','wines','wing','wink','wins','wipe','wire','wise','zine'},
'wined':	{'dined','fined','lined','mined','wind','winded','wine','wines','winged','wiped','wired'},
'winery':	{'wintry'},
'wines':	{'dines','fines','lines','mines','nines','pines','vines','winds','wine','wined','wings','wins','wipes','wires','wives','zines'},
'wing':	{'ding','king','ling','ming','ning','owing','ping','qing','ring','sing','swing','ting','wig','win','wind','wine','wings','wink','wins','ying'},
'winged':	{'hinged','ringed','tinged','winded','wined','winger'},
'winger':	{'finger','ginger','linger','ringer','singer','swinger','winder','winged','winner','winter'},
'winging':	{'ringing','singing','swinging','winding','wining','winning'},
'wings':	{'kings','pings','rings','sings','swings','wigs','winds','wines','wing','wins'},
'wining':	{'dining','lining','mining','waning','whining','winding','winging','winning','wiping','wiring'},
'wink':	{'fink','ink','link','mink','pink','rink','sink','twink','wank','wick','win','wind','wine','wing','wins'},
'winner':	{'dinner','inner','sinner','wiener','winder','winger','winners','winter'},
'winners':	{'dinners','sinners','winner','winters'},
'winning':	{'inning','pinning','winding','winging','wining','winnings'},
'winnings':	{'innings','winning'},
'wins':	{'bins','fins','ins','pins','sins','tins','twins','wigs','win','wind','winds','wine','wines','wing','wings','wink','wits'},
'winter':	{'inter','winder','winger','winner','winters'},
'winters':	{'winners','winter'},
'wintry':	{'winery'},
'wipe':	{'pipe','ripe','swipe','wide','wife','wine','wiped','wiper','wipes','wire','wise'},
'wiped':	{'piped','wined','wipe','wiper','wipes','wired'},
'wiper':	{'piper','riper','viper','wider','wipe','wiped','wipers','wipes','wiser'},
'wipers':	{'wiper','wipes'},
'wipes':	{'pipes','wines','wipe','wiped','wiper','wipers','wires','wives'},
'wiping':	{'piping','wining','wiring'},
'wire':	{'dire','eire','fire','hire','ire','lire','sire','tire','ware','were','wide','wife','wine','wipe','wired','wires','wise','wore'},
'wired':	{'aired','fired','hired','tired','wined','wiped','wire','wires'},
'wireless':	{'tireless'},
'wires':	{'fires','hires','tires','wares','wines','wipes','wire','wired','wives'},
'wiring':	{'airing','firing','hiring','tiring','wining','wiping'},
'wise':	{'rise','wide','wife','wine','wipe','wire','wiser','wish','wisp'},
'wisely':	{'widely'},
'wiseness':	{'wideness'},
'wiser':	{'riser','wider','wiper','wise'},
'wisest':	{'widest'},
'wish':	{'dish','fish','swish','wash','wise','wisp','with'},
'wished':	{'fished','washed','wishes'},
'wishes':	{'dishes','fishes','washes','wished'},
'wishing':	{'fishing','washing'},
'wisp':	{'lisp','wasp','wise','wish'},
'wit':	{'bit','fit','git','hit','it','kit','lit','mit','nit','pit','sit','tit','wait','wat','wet','whit','wi','wig','wilt','win','with','wits','wot','writ'},
'witch':	{'bitch','ditch','fitch','hitch','itch','pitch','switch','twitch','watch','winch','with'},
'witches':	{'bitches','ditches','pitches','switches','watches'},
'with':	{'width','wish','wit','witch','wits'},
'withdraw':	{'withdrawn','withdraws','withdrew'},
'withdrawal':	{'withdrawals'},
'withdrawals':	{'withdrawal'},
'withdrawn':	{'withdraw','withdraws'},
'withdraws':	{'withdraw','withdrawn'},
'withdrew':	{'withdraw'},
'withheld':	{'withhold'},
'withhold':	{'withheld'},
'witness':	{'fitness'},
'witnessed':	{'witnesses'},
'witnesses':	{'witnessed'},
'wits':	{'bits','fits','hits','its','kits','pits','sits','tits','waits','wets','wigs','wins','wit','with'},
'witty':	{'kitty','titty'},
'wives':	{'dives','fives','gives','hives','ives','lives','waves','wines','wipes','wires'},
'wizard':	{'lizard'},
'wm':	{'am','bm','cm','em','fm','gm','hm','km','mm','nm','pm','rm','sm','tm','um','w','wa','we','wi','wo','wu','wv','wy'},
'wnw':	{'nw','wow','wsw','www'},
'wo':	{'co','do','fo','go','ho','io','ko','lo','mo','no','o','po','so','to','two','w','wa','we','who','wi','wm','woe','wok','won','woo','wop','wot','wow','wu','wv','wy'},
'woe':	{'doe','foe','hoe','poe','roe','toe','we','wee','wo','woes','wok','woke','won','woo','wop','wore','wot','wove','wow','wye'},
'woes':	{'does','foes','goes','hoes','toes','woe'},
'wok':	{'ok','wo','woe','woke','won','woo','wop','work','wot','wow'},
'woke':	{'awoke','coke','joke','poke','wake','woe','wok','woken','wore','wove','yoke'},
'woken':	{'awoken','token','waken','woke','women','woven'},
'wolf':	{'golf','rolf','wolfe','wolff','woof','woolf'},
'wolfe':	{'wolf','wolff'},
'wolff':	{'wolf','wolfe'},
'wolves':	{'solves'},
'woman':	{'oman','roman','women'},
'womb':	{'bomb','comb','omb','tomb'},
'women':	{'omen','woken','woman','woven'},
'won':	{'con','don','hon','ion','mon','non','on','ron','son','ton','von','wan','wen','win','wo','woe','wok','wont','woo','wop','worn','wot','wow','yon'},
'wonder':	{'fonder','ponder','wander','winder','wonders','yonder'},
'wondered':	{'pondered','wandered'},
'wondering':	{'pondering','wandering'},
'wonders':	{'wanders','wonder'},
'wont':	{'cont','dont','font','ont','want','went','won','wort','wot'},
'woo':	{'boo','coo','goo','loo','moo','poo','too','who','wo','woe','wok','won','wood','woof','wool','wop','wot','wow','zoo'},
'wood':	{'food','good','hood','mood','woo','woods','woody','woof','wool','word'},
'wooded':	{'hooded','wooden','worded'},
'wooden':	{'wooded'},
'woodland':	{'woodlands'},
'woodlands':	{'woodland'},
'woodman':	{'goodman'},
'woods':	{'foods','goods','hoods','moods','wood','woody','wools','words'},
'woody':	{'goody','moody','wood','woods'},
'woof':	{'roof','wolf','woo','wood','wool','woolf'},
'wool':	{'cool','fool','pool','tool','woo','wood','woof','woolf','wools'},
'woolf':	{'wolf','woof','wool','wools'},
'woolly':	{'coolly','wholly'},
'wools':	{'cools','fools','pools','tools','woods','wool','woolf'},
'wop':	{'bop','cop','gop','hop','mop','op','pop','sop','top','wo','woe','wok','won','woo','wot','wow'},
'word':	{'cord','ford','lord','sword','ward','wood','words','wore','work','world','worm','worn','wort'},
'worded':	{'corded','wooded','worked','wormed'},
'wording':	{'working','worming'},
'words':	{'cords','lords','swords','wards','woods','word','works','worlds','worms'},
'wore':	{'bore','core','fore','gore','lore','more','ore','pore','sore','swore','tore','ware','were','whore','wire','woe','woke','word','work','worm','worn','worse','wort','wove'},
'work':	{'cork','dork','fork','pork','wok','word','wore','works','worm','worn','wort','york'},
'worked':	{'corked','worded','worker','wormed'},
'worker':	{'worked','workers'},
'workers':	{'worker'},
'working':	{'corking','wording','workings','worming'},
'workings':	{'working'},
'workload':	{'workloads'},
'workloads':	{'workload'},
'workman':	{'workmen'},
'workmen':	{'workman'},
'workout':	{'workouts'},
'workouts':	{'workout'},
'workplace':	{'workplaces'},
'workplaces':	{'workplace'},
'works':	{'corks','forks','words','work','worms'},
'worksheet':	{'worksheets'},
'worksheets':	{'worksheet'},
'workshop':	{'workshops'},
'workshops':	{'workshop'},
'workstation':	{'workstations'},
'workstations':	{'workstation'},
'world':	{'word','worlds','would'},
'worlds':	{'words','world'},
'worm':	{'dorm','form','norm','warm','word','wore','work','worms','worn','wort'},
'wormed':	{'formed','warmed','worded','worked'},
'worming':	{'forming','warming','wording','working'},
'worms':	{'dorms','forms','norms','warms','words','works','worm'},
'worn':	{'born','corn','horn','morn','porn','sworn','torn','warn','won','word','wore','work','worm','wort'},
'worried':	{'worries'},
'worries':	{'worried'},
'worry':	{'sorry'},
'worse':	{'horse','morse','norse','wore','worsen','worst'},
'worsen':	{'worse'},
'worship':	{'worships'},
'worships':	{'worship'},
'worst':	{'horst','worse','wort'},
'wort':	{'fort','hort','port','sort','tort','wont','word','wore','work','worm','worn','worst','worth','wot'},
'worth':	{'forth','north','wort','worthy'},
'worthy':	{'worth'},
'wot':	{'bot','cot','dot','got','hot','lot','mot','not','pot','rot','sot','swot','tot','wat','wet','wit','wo','woe','wok','won','wont','woo','wop','wort','wow'},
'would':	{'could','gould','mould','world','wouldn','wound'},
'wouldn':	{'couldn','would'},
'wound':	{'bound','found','hound','mound','pound','round','sound','would','wounds'},
'wounded':	{'bounded','founded','pounded','rounded','sounded'},
'wounding':	{'bounding','founding','pounding','rounding','sounding'},
'wounds':	{'bounds','hounds','mounds','pounds','rounds','sounds','wound'},
'wove':	{'cove','dove','love','move','rove','wave','woe','woke','wore','woven'},
'woven':	{'oven','woken','women','wove'},
'wow':	{'bow','cow','how','low','now','ow','pow','row','sow','tow','vow','wnw','wo','woe','wok','won','woo','wop','wot','wsw','www'},
'wrap':	{'crap','rap','trap','wraps'},
'wrapped':	{'trapped','wrapper'},
'wrapper':	{'rapper','wrapped','wrappers'},
'wrappers':	{'rappers','wrapper'},
'wrapping':	{'trapping'},
'wraps':	{'craps','traps','wrap'},
'wrath':	{'wreath'},
'wreath':	{'breath','wrath','wreaths'},
'wreaths':	{'breaths','wreath'},
'wreck':	{'wrecks'},
'wrecks':	{'wreck'},
'wren':	{'aren','tren','wen','weren','when'},
'wrench':	{'french','trench','wretch'},
'wrenches':	{'trenches'},
'wrestle':	{'wrestler'},
'wrestler':	{'wrestle','wrestlers'},
'wrestlers':	{'wrestler'},
'wretch':	{'wrench'},
'wright':	{'bright','fright','right','weight','wight'},
'wrinkle':	{'wrinkled','wrinkles'},
'wrinkled':	{'wrinkle','wrinkles'},
'wrinkles':	{'wrinkle','wrinkled'},
'wrist':	{'grist','waist','wrists','writ'},
'wrists':	{'waists','wrist'},
'writ':	{'brit','grit','wait','whit','wit','wrist','write'},
'write':	{'rite','waite','white','writ','writer','writes','wrote'},
'writer':	{'waiter','whiter','write','writers','writes'},
'writers':	{'waiters','writer','writes'},
'writes':	{'rites','whites','write','writer','writers'},
'writing':	{'waiting','whiting','writings'},
'writings':	{'writing'},
'written':	{'britten'},
'wrong':	{'prong','wrongs'},
'wrongs':	{'wrong'},
'wrote':	{'write'},
'wrought':	{'brought','drought'},
'wsw':	{'ssw','sw','wnw','wow','www'},
'wu':	{'au','cu','du','eu','gu','ju','lu','mu','nu','pu','ru','su','u','w','wa','we','wi','wm','wo','wv','wy','zu'},
'wv':	{'av','cv','ev','iv','jv','lv','nv','rv','tv','uv','v','w','wa','we','wi','wm','wo','wu','wy','xv'},
'www':	{'wnw','wow','wsw'},
'wy':	{'by','dy','ky','ly','my','ny','w','wa','way','we','why','wi','wm','wo','wu','wv','wye','y'},
'wyatt':	{'watt'},
'wye':	{'aye','bye','dye','eye','rye','we','wee','woe','wy','ye'},
'wylie':	{'kylie'},
'x':	{'a','ax','b','c','d','e','ex','f','g','h','i','ix','j','k','l','o','ox','p','px','q','r','t','tx','u','v','w','xe','xi','xl','xv','xx','y','z'},
'xe':	{'axe','be','ce','de','e','ee','fe','ge','he','ie','le','me','ne','pe','se','te','ve','we','x','xi','xl','xv','xx','ye'},
'xi':	{'ai','bi','ci','di','gi','hi','i','ii','ji','ki','li','mi','ni','pi','qi','ri','si','ti','vi','wi','x','xe','xii','xiv','xix','xl','xv','xvi','xx','xxi','yi'},
'xian':	{'gian'},
'xii':	{'ii','iii','lii','vii','xi','xiii','xiv','xix','xvi','xvii','xxi','xxii'},
'xiii':	{'iii','viii','xii','xvii','xviii','xxii','xxiii'},
'xiv':	{'hiv','iv','liv','xi','xii','xix','xv'},
'xix':	{'dix','fix','ix','mix','nix','pix','six','xi','xii','xiv','xx','xxx'},
'xl':	{'al','bl','cl','el','fl','il','l','ll','ml','tl','x','xe','xi','xv','xx'},
'xmas':	{'mas'},
'xv':	{'av','cv','ev','iv','jv','lv','nv','rv','tv','uv','v','wv','x','xe','xi','xiv','xl','xvi','xx'},
'xvi':	{'vi','xi','xii','xv','xvii','xxi'},
'xvii':	{'vii','xii','xiii','xvi','xviii','xxii'},
'xviii':	{'viii','xiii','xvii','xxiii'},
'xx':	{'ax','ex','ix','ox','px','tx','x','xe','xi','xix','xl','xv','xxi','xxx'},
'xxi':	{'xi','xii','xvi','xx','xxii','xxx'},
'xxii':	{'xii','xiii','xvii','xxi','xxiii'},
'xxiii':	{'xiii','xviii','xxii'},
'xxx':	{'xix','xx','xxi'},
'y':	{'a','b','by','c','d','dy','e','f','g','h','i','j','k','ky','l','ly','my','ny','o','p','q','r','t','u','v','w','wy','x','ya','yb','ye','yi','yr','z'},
'ya':	{'a','ba','ca','da','ea','fa','ga','ha','ia','ka','la','ma','na','pa','ra','sa','ta','va','wa','y','yak','yam','yap','yb','ye','yea','yi','yr','za'},
'yacht':	{'yachts'},
'yachts':	{'yacht'},
'yak':	{'ak','oak','ya','yam','yank','yap'},
'yale':	{'ale','bale','dale','gale','hale','male','pale','sale','tale','vale','yule'},
'yam':	{'am','cam','dam','ham','jam','lam','ram','sam','tam','ya','yak','yap','yum'},
'yang':	{'ang','bang','dang','fang','gang','hang','pang','rang','sang','tang','yank','ying'},
'yank':	{'bank','hank','rank','sank','tank','wank','yak','yang'},
'yap':	{'cap','gap','hap','lap','map','nap','pap','rap','sap','tap','ya','yak','yam','yip','zap'},
'yard':	{'bard','card','hard','ward','yards','yarn'},
'yards':	{'cards','wards','yard','yarns'},
'yarn':	{'barn','darn','earn','warn','yard','yarns','yawn'},
'yarns':	{'barns','earns','warns','yards','yarn'},
'yawn':	{'dawn','fawn','lawn','pawn','yarn'},
'yb':	{'ab','b','bb','db','eb','gb','kb','lb','mb','nb','ob','pb','rb','sb','tb','y','ya','ye','yi','yr'},
'ye':	{'aye','be','bye','ce','de','dye','e','ee','eye','fe','ge','he','ie','le','me','ne','pe','rye','se','te','ve','we','wye','xe','y','ya','yb','yea','yen','yer','yes','yet','yew','yi','yr'},
'yea':	{'dea','ea','lea','pea','sea','tea','ya','ye','yeah','year','yeas','yen','yer','yes','yet','yew'},
'yeah':	{'yea','year','yeas'},
'year':	{'bear','dear','ear','fear','gear','hear','lear','near','pear','rear','tear','wear','yea','yeah','years','yeas','yer'},
'yearly':	{'dearly','early','nearly'},
'yearning':	{'earning','learning'},
'years':	{'bears','dears','ears','fears','gears','hears','nears','pears','tears','wears','year','yeas','yeats'},
'yeas':	{'peas','seas','teas','yea','yeah','year','years','yeast','yeats','yes'},
'yeast':	{'beast','east','feast','least','yeas'},
'yeats':	{'beats','eats','feats','heats','keats','meats','seats','years','yeas'},
'yell':	{'bell','cell','dell','ell','fell','hell','sell','tell','well','yells'},
'yelling':	{'belling','selling','telling'},
'yellow':	{'fellow','mellow'},
'yells':	{'bells','cells','hells','sells','tells','wells','yell'},
'yemen':	{'semen'},
'yen':	{'ben','den','en','fen','gen','hen','ken','men','pen','sen','ten','wen','ye','yea','yer','yes','yet','yew','yin','yon','zen'},
'yer':	{'aer','ber','der','dyer','er','fer','ger','her','ker','per','ye','yea','year','yen','yes','yet','yew','yr'},
'yes':	{'ayes','des','dyes','es','eyes','les','mes','res','ye','yea','yeas','yen','yer','yet','yew'},
'yet':	{'bet','et','get','jet','let','met','net','pet','set','tet','vet','wet','ye','yea','yen','yer','yes','yeti','yew'},
'yeti':	{'yet'},
'yew':	{'dew','few','jew','mew','new','pew','sew','ye','yea','yen','yer','yes','yet'},
'yi':	{'ai','bi','ci','di','gi','hi','i','ii','ji','ki','li','mi','ni','pi','qi','ri','si','ti','vi','wi','xi','y','ya','yb','ye','yin','yip','yr'},
'yield':	{'field','wield','yields'},
'yielded':	{'fielded'},
'yielding':	{'fielding','wielding'},
'yields':	{'fields','yield'},
'yin':	{'bin','din','fin','gin','in','kin','lin','min','pin','qin','sin','tin','win','yen','yi','ying','yip','yon'},
'ying':	{'ding','dying','king','ling','lying','ming','ning','ping','qing','ring','sing','ting','tying','vying','wing','yang','yin'},
'yip':	{'dip','hip','ip','kip','lip','nip','pip','rip','sip','tip','vip','yap','yi','yin','zip'},
'yoga':	{'yogi'},
'yogi':	{'yoga'},
'yoke':	{'coke','joke','poke','woke'},
'yolk':	{'folk','polk','york'},
'yon':	{'con','don','hon','ion','lyon','mon','non','on','ron','son','ton','von','won','yen','yin','you'},
'yonder':	{'fonder','ponder','wonder'},
'york':	{'cork','dork','fork','pork','work','yolk'},
'you':	{'cou','tou','yon','your'},
'youngster':	{'youngsters'},
'youngsters':	{'youngster'},
'your':	{'four','hour','our','pour','sour','tour','you','yours'},
'yours':	{'fours','hours','ours','pours','sours','tours','your'},
'yourselves':	{'ourselves'},
'youth':	{'mouth','south','youths'},
'youthful':	{'mouthful'},
'youths':	{'mouths','youth'},
'yr':	{'ar','br','cr','dr','er','fr','hr','ir','jr','kr','lr','mr','or','pr','qr','r','sr','ur','y','ya','yb','ye','yer','yi','zr'},
'yule':	{'mule','rule','yale'},
'yum':	{'bum','cum','gum','hum','mum','rum','sum','um','yam','yuma'},
'yuma':	{'puma','yum'},
'yummy':	{'dummy','mummy','tummy'},
'z':	{'a','az','b','c','cz','d','e','f','g','h','hz','i','j','k','l','o','p','q','r','t','u','v','w','x','y','za','zn','zr','zu'},
'za':	{'a','ba','ca','da','ea','fa','ga','ha','ia','ka','la','ma','na','pa','ra','sa','ta','va','wa','ya','z','zap','zn','zr','zu'},
'zambia':	{'gambia','zambian'},
'zambian':	{'gambian','zambia'},
'zap':	{'cap','gap','hap','lap','map','nap','pap','rap','sap','tap','yap','za','zip'},
'zeal':	{'deal','heal','meal','real','seal','teal','veal'},
'zealous':	{'jealous'},
'zed':	{'bed','ed','fed','led','med','qed','red','ted','wed','zen'},
'zen':	{'ben','den','en','fen','gen','hen','ken','men','pen','sen','ten','wen','yen','zed','zn'},
'zero':	{'hero','nero','zeros'},
'zeros':	{'eros','zero'},
'zest':	{'best','est','fest','jest','lest','nest','pest','rest','test','vest','west'},
'zeta':	{'beta','eta','meta'},
'zhi':	{'chi','hi','phi'},
'zhou':	{'chou','thou'},
'zillion':	{'billion','million'},
'zinc':	{'inc','zine'},
'zine':	{'cine','dine','fine','line','mine','nine','pine','sine','vine','wine','zinc','zines','zone'},
'zines':	{'dines','fines','lines','mines','nines','pines','vines','wines','zine','zones'},
'zion':	{'ion','lion'},
'zionism':	{'zionist'},
'zionist':	{'zionism'},
'zip':	{'dip','hip','ip','kip','lip','nip','pip','rip','sip','tip','vip','yip','zap','zips'},
'zipped':	{'dipped','ripped','tipped','zipper'},
'zipper':	{'ripper','zipped'},
'zips':	{'dips','hips','lips','mips','rips','sips','tips','zip'},
'zn':	{'an','en','in','mn','on','rn','sn','tn','un','z','za','zen','zr','zu'},
'zombie':	{'zombies'},
'zombies':	{'zombie'},
'zone':	{'bone','cone','done','gone','hone','lone','none','one','ozone','tone','zine','zoned','zones'},
'zoned':	{'boned','honed','toned','zone','zones'},
'zones':	{'bones','cones','jones','ones','tones','zines','zone','zoned'},
'zoning':	{'boning','toning'},
'zoo':	{'boo','coo','goo','loo','moo','poo','too','woo','zoom','zoos'},
'zoom':	{'boom','doom','loom','room','zoo','zoos'},
'zooming':	{'booming','looming'},
'zoos':	{'coos','zoo','zoom'},
'zr':	{'ar','br','cr','dr','er','fr','hr','ir','jr','kr','lr','mr','or','pr','qr','r','sr','ur','yr','z','za','zn','zu'},
'zu':	{'au','cu','du','eu','gu','ju','lu','mu','nu','pu','ru','su','u','wu','z','za','zn','zr'},
'zulu':	{'lulu'},
}

'''
import editdistance
editdistance.eval('banana', 'bahama')
# 2L
'''