wordattr={'A.C.': {'abbrev': 'A_C_'},
 'A.D.': {'abbrev': 'A_D_'},
 'A.D.L.': {'abbrev': 'A_D_L_'},
 'A.F.': {'abbrev': 'A_F_'},
 'A.G.': {'abbrev': 'A_G_'},
 'A.H.': {'abbrev': 'A_H_'},
 'A.J.C.': {'abbrev': 'A_J_C_'},
 'A.L.': {'abbrev': 'A_L_'},
 'A.P.': {'abbrev': 'A_P_'},
 'A.T.B.': {'abbrev': 'A_T_B_'},
 'Adm.': {'abbrev': 'Adm_'},
 'Ala.': {'abbrev': 'Ala_'},
 'Apr.': {'abbrev': 'Apr_'},
 'Ariz.': {'abbrev': 'Ariz_'},
 'Ark.': {'abbrev': 'Ark_'},
 'Aug.': {'abbrev': 'Aug_'},
 'B.B.': {'abbrev': 'B_B_'},
 'B.F.': {'abbrev': 'B_F_'},
 'B.J.': {'abbrev': 'B_J_'},
 'B.V.': {'abbrev': 'B_V_'},
 'Bancorp.': {'abbrev': 'Bancorp_'},
 'Bhd.': {'abbrev': 'Bhd_'},
 'Bros.': {'abbrev': 'Bros_'},
 'C.B.': {'abbrev': 'C_B_'},
 'C.E.': {'abbrev': 'C_E_'},
 'C.J.': {'abbrev': 'C_J_'},
 'C.J.B.': {'abbrev': 'C_J_B_'},
 'C.R.': {'abbrev': 'C_R_'},
 'C.S.': {'abbrev': 'C_S_'},
 'C.W.': {'abbrev': 'C_W_'},
 'CO.': {'abbrev': 'CO_'},
 'CORP.': {'abbrev': 'CORP_'},
 'COS.': {'abbrev': 'COS_'},
 'Calif.': {'abbrev': 'Calif_'},
 'Canada-U.S.': {'abbrev': 'Canada-U_S_'},
 'Capt.': {'abbrev': 'Capt_'},
 'Cie.': {'abbrev': 'Cie_'},
 'Col.': {'abbrev': 'Col_'},
 'Colo.': {'abbrev': 'Colo_'},
 'Conn.': {'abbrev': 'Conn_'},
 'D.C.': {'abbrev': 'D_C_'},
 'D.H.': {'abbrev': 'D_H_'},
 'D.S.': {'abbrev': 'D_S_'},
 'D.T.': {'abbrev': 'D_T_'},
 'Dec.': {'abbrev': 'Dec_'},
 'Del.': {'abbrev': 'Del_'},
 'Dept.': {'abbrev': 'Dept_'},
 'Dr.': {'abbrev': 'Dr_'},
 'E.C.': {'abbrev': 'E_C_'},
 'E.E.': {'abbrev': 'E_E_'},
 'E.M.': {'abbrev': 'E_M_'},
 'E.W.': {'abbrev': 'E_W_'},
 'Etc.': {'abbrev': 'Etc_'},
 'F.A.': {'abbrev': 'F_A_'},
 'F.E.': {'abbrev': 'F_E_'},
 'F.H.': {'abbrev': 'F_H_'},
 'F.J.': {'abbrev': 'F_J_'},
 'F.W.': {'abbrev': 'F_W_'},
 'Feb.': {'abbrev': 'Feb_'},
 'Fla.': {'abbrev': 'Fla_'},
 'G.D.': {'abbrev': 'G_D_'},
 'G.L.': {'abbrev': 'G_L_'},
 'G.O.': {'abbrev': 'G_O_'},
 'G.S.': {'abbrev': 'G_S_'},
 'G.m.b.H.': {'abbrev': 'G_m_b_H_'},
 'Ga.': {'abbrev': 'Ga_'},
 'Gen.': {'abbrev': 'Gen_'},
 'Gov.': {'abbrev': 'Gov_'},
 'H.F.': {'abbrev': 'H_F_'},
 'H.G.': {'abbrev': 'H_G_'},
 'H.H.': {'abbrev': 'H_H_'},
 'H.J.': {'abbrev': 'H_J_'},
 'H.L.': {'abbrev': 'H_L_'},
 'H.R.': {'abbrev': 'H_R_'},
 'I.B.M.': {'abbrev': 'I_B_M_'},
 'I.C.H.': {'abbrev': 'I_C_H_'},
 'I.E.P.': {'abbrev': 'I_E_P_'},
 'I.W.': {'abbrev': 'I_W_'},
 'INC.': {'abbrev': 'INC_'},
 'Ill.': {'abbrev': 'Ill_'},
 'Ind.': {'abbrev': 'Ind_'},
 'J.B.': {'abbrev': 'J_B_'},
 'J.C.': {'abbrev': 'J_C_'},
 'J.D.': {'abbrev': 'J_D_'},
 'J.E.': {'abbrev': 'J_E_'},
 'J.F.': {'abbrev': 'J_F_'},
 'J.L.': {'abbrev': 'J_L_'},
 'J.M.': {'abbrev': 'J_M_'},
 'J.P.': {'abbrev': 'J_P_'},
 'J.R.': {'abbrev': 'J_R_'},
 'J.X.': {'abbrev': 'J_X_'},
 'Jan.': {'abbrev': 'Jan_'},
 'Jansz.': {'abbrev': 'Jansz_'},
 'Japan-U.S.': {'abbrev': 'Japan-U_S_'},
 'Jos.': {'abbrev': 'Jos_'},
 'Jr.': {'abbrev': 'Jr_'},
 'Jul.': {'abbrev': 'Jul_'},
 'Jun.': {'abbrev': 'Jun_'},
 'Kan.': {'abbrev': 'Kan_'},
 'Ky.': {'abbrev': 'Ky_'},
 'L.A.': {'abbrev': 'L_A_'},
 'L.F.': {'abbrev': 'L_F_'},
 'L.H.': {'abbrev': 'L_H_'},
 'L.J.': {'abbrev': 'L_J_'},
 'L.L.': {'abbrev': 'L_L_'},
 'L.P.': {'abbrev': 'L_P_'},
 'La.': {'abbrev': 'La_'},
 'Lt.': {'abbrev': 'Lt_'},
 'Ltd.': {'abbrev': 'Ltd_'},
 'M.A.': {'abbrev': 'M_A_'},
 'M.B.A.': {'abbrev': 'M_B_A_'},
 'M.D.': {'abbrev': 'M_D_'},
 'M.E.': {'abbrev': 'M_E_'},
 'M.J.': {'abbrev': 'M_J_'},
 'M.R.': {'abbrev': 'M_R_'},
 'M.W.': {'abbrev': 'M_W_'},
 'Maj.': {'abbrev': 'Maj_'},
 'Mar.': {'abbrev': 'Mar_'},
 'Mass.': {'abbrev': 'Mass_'},
 'Md.': {'abbrev': 'Md_'},
 'Messrs.': {'abbrev': 'Messrs_'},
 'Mfg.': {'abbrev': 'Mfg_'},
 'Mich.': {'abbrev': 'Mich_'},
 'Minn.': {'abbrev': 'Minn_'},
 'Miss.': {'abbrev': 'Miss_'},
 'Mo.': {'abbrev': 'Mo_'},
 'Mr.': {'abbrev': 'Mr_'},
 'Mrs.': {'abbrev': 'Mrs_'},
 'Ms.': {'abbrev': 'Ms_'},
 'N.A.': {'abbrev': 'N_A_'},
 'N.C.': {'abbrev': 'N_C_'},
 'N.H.': {'abbrev': 'N_H_'},
 'N.J.': {'abbrev': 'N_J_'},
 'N.M.': {'abbrev': 'N_M_'},
 'N.V.': {'abbrev': 'N_V_'},
 'N.Y.': {'abbrev': 'N_Y_'},
 'Neb.': {'abbrev': 'Neb_'},
 'Nev.': {'abbrev': 'Nev_'},
 'No.': {'abbrev': 'No_'},
 'Nos.': {'abbrev': 'Nos_'},
 'Nov.': {'abbrev': 'Nov_'},
 'O.P.': {'abbrev': 'O_P_'},
 'Oct.': {'abbrev': 'Oct_'},
 'Okla.': {'abbrev': 'Okla_'},
 'Ore.': {'abbrev': 'Ore_'},
 'P.J.': {'abbrev': 'P_J_'},
 'P.R.': {'abbrev': 'P_R_'},
 'Pa.': {'abbrev': 'Pa_'},
 'Ph.': {'abbrev': 'Ph_'},
 'Prof.': {'abbrev': 'Prof_'},
 'Prop.': {'abbrev': 'Prop_'},
 'R.B.': {'abbrev': 'R_B_'},
 'R.D.': {'abbrev': 'R_D_'},
 'R.H.': {'abbrev': 'R_H_'},
 'R.I.': {'abbrev': 'R_I_'},
 'R.L.': {'abbrev': 'R_L_'},
 'R.P.': {'abbrev': 'R_P_'},
 'R.R.': {'abbrev': 'R_R_'},
 'Rep.': {'abbrev': 'Rep_'},
 'Reps.': {'abbrev': 'Reps_'},
 'Rev.': {'abbrev': 'Rev_'},
 'S.A.': {'abbrev': 'S_A_'},
 'S.C.': {'abbrev': 'S_C_'},
 'S.G.': {'abbrev': 'S_G_'},
 'S.S.': {'abbrev': 'S_S_'},
 'S.p.A.': {'abbrev': 'S_p_A_'},
 'Sen.': {'abbrev': 'Sen_'},
 'Sens.': {'abbrev': 'Sens_'},
 'Sept.': {'abbrev': 'Sept_'},
 'Sino-U.S.': {'abbrev': 'Sino-U_S_'},
 'Sr.': {'abbrev': 'Sr_'},
 'St.': {'abbrev': 'St_'},
 'T.T.': {'abbrev': 'T_T_'},
 'T.V.': {'abbrev': 'T_V_'},
 'Tenn.': {'abbrev': 'Tenn_'},
 'Tex.': {'abbrev': 'Tex_'},
 'U.K.': {'abbrev': 'U_K_'},
 'U.N.': {'abbrev': 'U_N_'},
 'U.S.': {'abbrev': 'U_S_'},
 'U.S.-U.K.': {'abbrev': 'U_S_-U_K_'},
 'U.S.-U.S.S.R.': {'abbrev': 'U_S_-U_S_S_R_'},
 'U.S.A.': {'abbrev': 'U_S_A_'},
 'U.S.S.R.': {'abbrev': 'U_S_S_R_'},
 'V.H.': {'abbrev': 'V_H_'},
 'Va.': {'abbrev': 'Va_'},
 'Vt.': {'abbrev': 'Vt_'},
 'W.A.': {'abbrev': 'W_A_'},
 'W.D.': {'abbrev': 'W_D_'},
 'W.I.': {'abbrev': 'W_I_'},
 'W.J.': {'abbrev': 'W_J_'},
 'W.N.': {'abbrev': 'W_N_'},
 'W.R.': {'abbrev': 'W_R_'},
 'W.Va.': {'abbrev': 'W_Va_'},
 'Wash.': {'abbrev': 'Wash_'},
 'Wis.': {'abbrev': 'Wis_'},
 'Wyo.': {'abbrev': 'Wyo_'},
 'Y.J.': {'abbrev': 'Y_J_'},
 'a.m.': {'abbrev': 'a_m_', 'nns_exp_exc': ''},
 "cont'd.": {'abbrev': "cont'd_"},
 'days.': {'abbrev': 'days_'},
 'ft.': {'abbrev': 'ft_'},
 'i.e.': {'abbrev': 'i_e_'},
 'non-U.S.': {'abbrev': 'non-U_S_'},
 'p.m.': {'abbrev': 'p_m_', 'nns_exp_exc': ''},
 'vs.': {'abbrev': 'vs_'},
 'april': {'cap_word': 'April', 'nn_to_nns': 'aprils', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'august': {'cap_word': 'August', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'december': {'cap_word': 'December', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'english': {'cap_word': 'English', 'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': '', 'art_an': ''},
 'february': {'cap_word': 'February', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'friday': {'cap_word': 'Friday', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'god': {'cap_word': 'God', 'nn_to_nns': 'gods', 'n_is_nc': '', 'n_is_sb': '0'},
 'january': {'cap_word': 'January', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'july': {'cap_word': 'July', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'june': {'cap_word': 'June', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'may': {'cap_word': 'May', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'monday': {'cap_word': 'Monday', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'word_to_seg': '_weekday'},
 'november': {'cap_word': 'November', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'october': {'cap_word': 'October', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'saturday': {'cap_word': 'Saturday', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'september': {'cap_word': 'September', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'sunday': {'cap_word': 'Sunday', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'thursday': {'cap_word': 'Thursday', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'tuesday': {'cap_word': 'Tuesday', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'wednesday': {'cap_word': 'Wednesday', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'abuja': {'cap_word': 'Abuja'},
 'abu_dhabi': {'cap_word': 'Abu_Dhabi'},
 'accra': {'cap_word': 'Accra', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'addis_ababa': {'cap_word': 'Addis_Ababa'},
 'adelaide': {'cap_word': 'Adelaide'},
 'aden': {'cap_word': 'Aden', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'afghanistan': {'cap_word': 'Afghanistan', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'africa': {'cap_word': 'Africa', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'afrikaans': {'cap_word': 'Afrikaans'},
 'alabama': {'cap_word': 'Alabama', 'n_is_sb': '2', 'n_is_sth': '2'},
 'alaska': {'cap_word': 'Alaska', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'albania': {'cap_word': 'Albania', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'albanian': {'cap_word': 'Albanian', 'n_is_sb': '0'},
 'albany': {'cap_word': 'Albany'},
 'algeria': {'cap_word': 'Algeria', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'algiers': {'cap_word': 'Algiers', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'allah': {'cap_word': 'Allah', 'art_an': '', 'n_is_sb': '0'},
 'america': {'cap_word': 'America', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'american': {'cap_word': 'American', 'n_is_sb': '0'},
 'american_samoa': {'cap_word': 'American_Samoa'},
 'amharic': {'cap_word': 'Amharic'},
 'amman': {'cap_word': 'Amman', 'art_an': ''},
 'amsterdam': {'cap_word': 'Amsterdam', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'anchorage': {'cap_word': 'Anchorage', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'andorra': {'cap_word': 'Andorra', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'angola': {'cap_word': 'Angola', 'nn_to_nns': 'angolas', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'anguilla': {'cap_word': 'Anguilla', 'n_is_sb': '0'},
 'ankara': {'cap_word': 'Ankara', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'annapolis': {'cap_word': 'Annapolis'},
 'antananarivo': {'cap_word': 'Antananarivo'},
 'antigua_and_barbuda': {'cap_word': 'Antigua_and_Barbuda'},
 'apia': {'cap_word': 'Apia'},
 'arabic': {'cap_word': 'Arabic', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'argentina': {'cap_word': 'Argentina', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'arizona': {'cap_word': 'Arizona', 'n_is_sth': '0'},
 'arkansas': {'cap_word': 'Arkansas'},
 'armenia': {'cap_word': 'Armenia', 'art_an': ''},
 'armenian': {'cap_word': 'Armenian', 'n_is_sb': '2', 'n_is_sth': '2'},
 'aruba': {'cap_word': 'Aruba'},
 'ashkhabad': {'cap_word': 'Ashkhabad'},
 'asia': {'cap_word': 'Asia', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'asmara': {'cap_word': 'Asmara'},
 'astana': {'cap_word': 'Astana'},
 'asuncion': {'cap_word': 'Asuncion'},
 'athens': {'cap_word': 'Athens', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'atlanta': {'cap_word': 'Atlanta', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'augusta': {'cap_word': 'Augusta'},
 'austin': {'cap_word': 'Austin', 'art_an': ''},
 'australia': {'cap_word': 'Australia', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'australian': {'cap_word': 'Australian', 'n_is_sb': '2', 'n_is_sth': '2'},
 'austria': {'cap_word': 'Austria', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'azerbaijan': {'cap_word': 'Azerbaijan', 'n_is_sth': '', 'art_an': ''},
 'azores': {'cap_word': 'Azores'},
 'baghdad': {'cap_word': 'Baghdad', 'n_is_nu': '', 'n_is_sth': ''},
 'bahamas': {'cap_word': 'Bahamas'},
 'baku': {'cap_word': 'Baku'},
 'bamako': {'cap_word': 'Bamako', 'n_is_nu': '', 'n_is_sth': ''},
 'bangkok': {'cap_word': 'Bangkok', 'n_is_sth': ''},
 'bangladesh': {'cap_word': 'Bangladesh', 'n_is_sth': ''},
 'bangui': {'cap_word': 'Bangui', 'n_is_nu': '', 'n_is_sth': ''},
 'banjul': {'cap_word': 'Banjul', 'n_is_nu': '', 'n_is_sth': ''},
 'barbados': {'cap_word': 'Barbados', 'nn_to_nns': 'barbadoses', 'n_is_nu': '', 'n_is_sth': ''},
 'barcelona': {'cap_word': 'Barcelona', 'n_is_nu': '', 'n_is_sth': ''},
 'basseterre': {'cap_word': 'Basseterre'},
 'baton_rouge': {'cap_word': 'Baton_Rouge'},
 'beijing': {'cap_word': 'Beijing', 'n_is_nu': '', 'n_is_sth': ''},
 'beirut': {'cap_word': 'Beirut', 'n_is_sth': ''},
 'belarus': {'cap_word': 'Belarus'},
 'belgium': {'cap_word': 'Belgium', 'nn_to_nns': 'belgiums', 'n_is_nu': '', 'n_is_sth': ''},
 'belgrade': {'cap_word': 'Belgrade', 'n_is_nu': '', 'n_is_sth': ''},
 'belize': {'cap_word': 'Belize'},
 'bengali': {'cap_word': 'Bengali', 'n_is_sb': '2', 'n_is_sth': '2'},
 'benin': {'cap_word': 'Benin'},
 'berlin': {'cap_word': 'Berlin', 'n_is_nu': '', 'n_is_sth': ''},
 'bermuda': {'cap_word': 'Bermuda'},
 'bern': {'cap_word': 'Bern', 'n_is_nu': '', 'n_is_sth': ''},
 'bhutan': {'cap_word': 'Bhutan', 'n_is_nu': '', 'n_is_sth': ''},
 'bikini': {'cap_word': 'Bikini', 'nn_to_nns': 'bikinis', 'n_is_nc': '', 'n_is_sth': ''},
 'bishkek': {'cap_word': 'Bishkek'},
 'bismarck': {'cap_word': 'Bismarck', 'n_is_sb': '0'},
 'bissau': {'cap_word': 'Bissau'},
 'bogota': {'cap_word': 'Bogota', 'n_is_nu': '', 'n_is_sth': ''},
 'boise': {'cap_word': 'Boise'},
 'bolivia': {'cap_word': 'Bolivia', 'n_is_sth': ''},
 'bosnia_and_herzegovina': {'cap_word': 'Bosnia_and_Herzegovina'},
 'boston': {'cap_word': 'Boston', 'n_is_nu': '', 'n_is_sth': ''},
 'botswana': {'cap_word': 'Botswana', 'n_is_nu': '', 'n_is_sth': ''},
 'brasilia': {'cap_word': 'Brasilia', 'n_is_nu': '', 'n_is_sth': ''},
 'bratislava': {'cap_word': 'Bratislava'},
 'brazil': {'cap_word': 'Brazil', 'n_is_nu': '', 'n_is_sth': ''},
 'brazilian': {'cap_word': 'Brazilian', 'n_is_sb': '0'},
 'brazzaville': {'cap_word': 'Brazzaville'},
 'bridgetown': {'cap_word': 'Bridgetown'},
 'brisbane': {'cap_word': 'Brisbane'},
 'british_virgin_islands': {'cap_word': 'British_Virgin_Islands'},
 'briton': {'cap_word': 'Briton', 'n_is_sb': '0'},
 'brunei': {'cap_word': 'Brunei', 'n_is_nu': '', 'n_is_sth': ''},
 'brussels': {'cap_word': 'Brussels'},
 'bucharest': {'cap_word': 'Bucharest', 'n_is_nu': '', 'n_is_sth': ''},
 'budapest': {'cap_word': 'Budapest', 'n_is_sth': ''},
 'buddhism': {'cap_word': 'Buddhism', 'n_is_nu': '', 'n_is_sth': ''},
 'buenos_aires': {'cap_word': 'Buenos_Aires'},
 'bujumbura': {'cap_word': 'Bujumbura'},
 'bulgaria': {'cap_word': 'Bulgaria', 'n_is_sth': ''},
 'bulgarian': {'cap_word': 'Bulgarian', 'n_is_sb': '0'},
 'burkina_faso': {'cap_word': 'Burkina_Faso'},
 'burma': {'cap_word': 'Burma', 'n_is_sth': ''},
 'burmese': {'cap_word': 'Burmese', 'n_is_sb': '0'},
 'burundi': {'cap_word': 'Burundi', 'n_is_sth': ''},
 'cairo': {'cap_word': 'Cairo', 'n_is_nu': '', 'n_is_sth': ''},
 'california': {'cap_word': 'California', 'n_is_nu': '', 'n_is_sth': ''},
 'cambodia': {'cap_word': 'Cambodia', 'n_is_nu': '', 'n_is_sth': ''},
 'cameroon': {'cap_word': 'Cameroon', 'n_is_nu': '', 'n_is_sth': ''},
 'canada': {'cap_word': 'Canada', 'n_is_nu': '', 'n_is_sth': ''},
 'canadian': {'cap_word': 'Canadian', 'n_is_sb': '0'},
 'canberra': {'cap_word': 'Canberra', 'n_is_nu': '', 'n_is_sth': ''},
 'cape_town': {'cap_word': 'Cape_Town'},
 'cape_verde': {'cap_word': 'Cape_Verde'},
 'caracas': {'cap_word': 'Caracas', 'n_is_nu': '', 'n_is_sth': ''},
 'carson_city': {'cap_word': 'Carson_City'},
 'casablanca': {'cap_word': 'Casablanca'},
 'castries': {'cap_word': 'Castries', 'n_is_nu': '', 'n_is_sth': ''},
 'cayenne': {'cap_word': 'Cayenne', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'cayman_islands': {'cap_word': 'Cayman_Islands'},
 'central_africa': {'cap_word': 'Central_Africa'},
 'chad': {'cap_word': 'Chad', 'n_is_sth': ''},
 'charleston': {'cap_word': 'Charleston'},
 'cheyenne': {'cap_word': 'Cheyenne', 'n_is_sb': '2', 'n_is_sth': '2'},
 'chicago': {'cap_word': 'Chicago', 'n_is_nu': '', 'n_is_sth': ''},
 'chile': {'cap_word': 'Chile', 'n_is_nu': '', 'n_is_sth': ''},
 'china': {'cap_word': 'China', 'n_is_nu': '', 'n_is_sth': ''},
 'chinese': {'cap_word': 'Chinese', 'n_is_nc': '', 'n_is_sb': '0'},
 'chisinau': {'cap_word': 'Chisinau'},
 'christianity': {'cap_word': 'Christianity', 'n_is_nu': '', 'n_is_sth': ''},
 'colombia': {'cap_word': 'Colombia', 'n_is_nu': '', 'n_is_sth': ''},
 'colombo': {'cap_word': 'Colombo', 'n_is_nu': '', 'n_is_sth': ''},
 'colorado': {'cap_word': 'Colorado', 'n_is_nu': '', 'n_is_sth': ''},
 'columbia': {'cap_word': 'Columbia', 'n_is_nu': '', 'n_is_sth': ''},
 'columbus': {'cap_word': 'Columbus', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'comoros': {'cap_word': 'Comoros'},
 'conakry': {'cap_word': 'Conakry'},
 'concord': {'cap_word': 'Concord', 'n_is_nu': '', 'n_is_sth': ''},
 'connecticut': {'cap_word': 'Connecticut', 'n_is_nu': '', 'n_is_sth': ''},
 'copenhagen': {'cap_word': 'Copenhagen', 'n_is_sth': ''},
 'costa_rica': {'cap_word': 'Costa_Rica'},
 'croatia': {'cap_word': 'Croatia', 'n_is_nu': '', 'n_is_sth': ''},
 'cuba': {'cap_word': 'Cuba'},
 'cyprus': {'cap_word': 'Cyprus', 'n_is_sth': '0'},
 'czech': {'cap_word': 'Czech', 'n_is_nc': '', 'n_is_sb': '0'},
 'czechoslovakia': {'cap_word': 'Czechoslovakia', 'n_is_nu': ''},
 'dakar': {'cap_word': 'Dakar'},
 'danish': {'cap_word': 'Danish'},
 'darwin': {'cap_word': 'Darwin', 'n_is_sb': '0'},
 'dar_es_salaam': {'cap_word': 'Dar_es_Salaam'},
 'delaware': {'cap_word': 'Delaware', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'denmark': {'cap_word': 'Denmark', 'n_is_nu': '', 'n_is_sth': ''},
 'denver': {'cap_word': 'Denver', 'n_is_nu': '', 'n_is_sth': ''},
 'des_moines': {'cap_word': 'Des_Moines'},
 'detroit': {'cap_word': 'Detroit', 'n_is_nu': '', 'n_is_sth': ''},
 'dhaka': {'cap_word': 'Dhaka'},
 'district_of_columbia': {'cap_word': 'District_of_Columbia'},
 'djibouti': {'cap_word': 'Djibouti', 'n_is_nu': '', 'n_is_sth': ''},
 'doha': {'cap_word': 'Doha'},
 'dominica': {'cap_word': 'Dominica', 'n_is_nu': '', 'n_is_sth': ''},
 'dominican_republic': {'cap_word': 'Dominican_Republic'},
 'dover': {'cap_word': 'Dover'},
 'dublin': {'cap_word': 'Dublin', 'n_is_nu': '', 'n_is_sth': ''},
 'dushanbe': {'cap_word': 'Dushanbe'},
 'dutch': {'cap_word': 'Dutch', 'n_is_sb': '0'},
 'dutchman': {'cap_word': 'Dutchman', 'n_is_sb': '0'},
 'east_timor': {'cap_word': 'East_Timor'},
 'ecuador': {'cap_word': 'Ecuador', 'n_is_nc': '', 'art_an': '', 'n_is_sth': '0'},
 'edmonton': {'cap_word': 'Edmonton'},
 'egypt': {'cap_word': 'Egypt', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'egyptian': {'cap_word': 'Egyptian', 'nn_to_nns': 'egyptians', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'el_salvador': {'cap_word': 'El_Aalvador'},
 'emirate': {'cap_word': 'Emirate', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'englishman': {'cap_word': 'Englishman', 'n_is_sb': '0'},
 'equatorial_guinea': {'cap_word': 'Equatorial_Guinea'},
 'eritrea': {'cap_word': 'Eritrea'},
 'estonia': {'cap_word': 'Estonia', 'art_an': ''},
 'estonian': {'cap_word': 'Estonian'},
 'ethiopia': {'cap_word': 'Ethiopia', 'n_is_sth': '', 'art_an': ''},
 'europe': {'cap_word': 'Europe', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'faeroe_islands': {'cap_word': 'Faeroe_Islands'},
 'fiji': {'cap_word': 'Fiji'},
 'finland': {'cap_word': 'Finland', 'n_is_nu': '', 'n_is_sth': ''},
 'finnish': {'cap_word': 'Finnish'},
 'flemish': {'cap_word': 'Flemish'},
 'florida': {'cap_word': 'Florida', 'n_is_nu': '', 'n_is_sth': ''},
 'france': {'cap_word': 'France', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'frankfort': {'cap_word': 'Frankfort'},
 'frankfurt': {'cap_word': 'Frankfurt'},
 'freetown': {'cap_word': 'Freetown'},
 'french': {'cap_word': 'French', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'frenchman': {'cap_word': 'Frenchman', 'n_is_sb': '0'},
 'french_polynesia': {'cap_word': 'French_Polynesia'},
 'funafuti': {'cap_word': 'Funafuti'},
 'gabon': {'cap_word': 'Gabon', 'n_is_nu': '', 'n_is_sth': ''},
 'gaborone': {'cap_word': 'Gaborone'},
 'gaelic': {'cap_word': 'Gaelic'},
 'gambia': {'cap_word': 'Gambia', 'n_is_nu': '', 'n_is_sth': ''},
 'geneva': {'cap_word': 'Geneva', 'n_is_nu': '', 'n_is_sth': ''},
 'georgetown': {'cap_word': 'Georgetown', 'n_is_nu': '', 'n_is_sth': ''},
 'georgia': {'cap_word': 'Georgia', 'n_is_nu': '', 'n_is_sth': ''},
 'georgian': {'cap_word': 'Georgian', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'german': {'cap_word': 'German', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'germany': {'cap_word': 'Germany', 'n_is_nu': '', 'n_is_sth': ''},
 'ghana': {'cap_word': 'Ghana', 'n_is_sth': ''},
 'greece': {'cap_word': 'Greece', 'n_is_nu': '', 'n_is_sth': ''},
 'greek': {'cap_word': 'Greek', 'nn_to_nns': 'greeks', 'n_is_nc': '', 'n_is_sb': '0'},
 'greenland': {'cap_word': 'Greenland'},
 'grenada': {'cap_word': 'Grenada'},
 'guadeloupe': {'cap_word': 'Guadeloupe'},
 'guam': {'cap_word': 'Guam'},
 'guatemala': {'cap_word': 'Guatemala', 'n_is_nu': '', 'n_is_sth': ''},
 'guinea': {'cap_word': 'Guinea', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'guinea-bissau': {'cap_word': 'Guinea-bissau', 'n_is_nu': '', 'n_is_sth': ''},
 'gujarati': {'cap_word': 'Gujarati', 'n_is_sb': '2', 'n_is_sth': '2'},
 'guyana': {'cap_word': 'Guyana', 'n_is_nu': '', 'n_is_sth': ''},
 'haiti': {'cap_word': 'Haiti', 'n_is_nu': '', 'n_is_sth': ''},
 'halifax': {'cap_word': 'Halifax'},
 'hamilton': {'cap_word': 'Hamilton', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'hanoi': {'cap_word': 'Hanoi', 'n_is_sth': ''},
 'harare': {'cap_word': 'Harare'},
 'harrisburg': {'cap_word': 'Harrisburg'},
 'hartford': {'cap_word': 'Hartford'},
 'havana': {'cap_word': 'Havana', 'n_is_nu': '', 'n_is_sth': ''},
 'hawaii': {'cap_word': 'Hawaii', 'n_is_nu': '', 'n_is_sth': ''},
 'hebrew': {'cap_word': 'Hebrew', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'helena': {'cap_word': 'Helena'},
 'hellenic_republic': {'cap_word': 'Hellenic_Republic'},
 'hellenism': {'cap_word': 'Hellenism'},
 'helsinki': {'cap_word': 'Helsinki', 'n_is_sb': '0'},
 'hindi': {'cap_word': 'Hindi'},
 'holland': {'cap_word': 'Holland', 'n_is_nu': '', 'n_is_sth': ''},
 'honduras': {'cap_word': 'Honduras', 'n_is_sth': ''},
 'hong_kong': {'cap_word': 'Hong_Kong'},
 'honiara': {'cap_word': 'Honiara'},
 'honolulu': {'cap_word': 'Honolulu', 'n_is_sth': ''},
 'houston': {'cap_word': 'Houston', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'hungarian': {'cap_word': 'Hungarian', 'n_is_sb': '0'},
 'hungary': {'cap_word': 'Hungary'},
 'iceland': {'cap_word': 'Iceland', 'art_an': ''},
 'icelandic': {'cap_word': 'Icelandic'},
 'idaho': {'cap_word': 'Idaho'},
 'illinois': {'cap_word': 'Illinois', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'india': {'cap_word': 'India', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'indian': {'cap_word': 'Indian', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'indiana': {'cap_word': 'Indiana', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'indianapolis': {'cap_word': 'Indianapolis', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'indonesia': {'cap_word': 'Indonesia', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'indonesian': {'cap_word': 'Indonesian', 'n_is_sb': '0'},
 'iowa': {'cap_word': 'Iowa', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'iran': {'cap_word': 'Iran', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'iraq': {'cap_word': 'Iraq', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ireland': {'cap_word': 'Ireland', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'irishman': {'cap_word': 'Irishman', 'n_is_sb': '0'},
 'islamabad': {'cap_word': 'Islamabad', 'n_is_sth': '', 'art_an': ''},
 'israel': {'cap_word': 'Israel', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'israeli': {'cap_word': 'Israeli', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'istanbul': {'cap_word': 'Istanbul', 'n_is_sth': '', 'art_an': ''},
 'italian': {'cap_word': 'Italian', 'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'italy': {'cap_word': 'Italy', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ivory_coast': {'cap_word': 'Ivory_Coast'},
 'jackson': {'cap_word': 'Jackson', 'n_is_nu': '', 'n_is_sb': '0'},
 'jakarta': {'cap_word': 'Jakarta', 'n_is_nu': '', 'n_is_sth': ''},
 'jamaica': {'cap_word': 'Jamaica', 'n_is_nu': '', 'n_is_sth': ''},
 'jamestown': {'cap_word': 'Jamestown'},
 'japan': {'cap_word': 'Japan', 'n_is_nu': '', 'n_is_sth': ''},
 'japanese': {'cap_word': 'Japanese', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'jefferson_city': {'cap_word': 'Jefferson_City'},
 'jerusalem': {'cap_word': 'Jerusalem', 'n_is_nu': '', 'n_is_sth': ''},
 'jesus': {'cap_word': 'Jesus', 'n_is_nu': '', 'n_is_sb': '0'},
 'johannesburg': {'cap_word': 'Johannesburg'},
 'jordan': {'cap_word': 'Jordan', 'n_is_nu': '', 'n_is_sth': ''},
 'juneau': {'cap_word': 'Juneau'},
 'kabul': {'cap_word': 'Kabul', 'n_is_nu': '', 'n_is_sth': ''},
 'kampala': {'cap_word': 'Kampala', 'n_is_nu': '', 'n_is_sth': ''},
 'kansas': {'cap_word': 'Kansas', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'karachi': {'cap_word': 'Karachi'},
 'kathmandu': {'cap_word': 'Kathmandu'},
 'kazakh': {'cap_word': 'Kazakh', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'kentucky': {'cap_word': 'Kentucky', 'n_is_nu': '', 'n_is_sth': ''},
 'kenya': {'cap_word': 'Kenya', 'n_is_nu': '', 'n_is_sth': ''},
 'khartoum': {'cap_word': 'Khartoum', 'n_is_nu': '', 'n_is_sth': ''},
 'khmer': {'cap_word': 'Khmer', 'n_is_sb': '2', 'n_is_sth': '2'},
 'kiev': {'cap_word': 'Kiev', 'n_is_nu': '', 'n_is_sth': ''},
 'kigali': {'cap_word': 'Kigali', 'n_is_nu': '', 'n_is_sth': ''},
 'kingston': {'cap_word': 'Kingston'},
 'kingstown': {'cap_word': 'Kingstown'},
 'kinshasa': {'cap_word': 'Kinshasa'},
 'kiribati': {'cap_word': 'Kiribati'},
 'korea': {'cap_word': 'Korea', 'n_is_nu': '', 'n_is_sth': ''},
 'korean': {'cap_word': 'Korean', 'nn_to_nns': 'koreans', 'n_is_nc': '', 'n_is_sb': '0'},
 'kuala_lumpur': {'cap_word': 'Kuala_Lumpur'},
 'kuwait': {'cap_word': 'Kuwait', 'n_is_nu': '', 'n_is_sth': ''},
 'kuwait_city': {'cap_word': 'Kuwait_City'},
 'lagos': {'cap_word': 'Lagos'},
 'lahore': {'cap_word': 'Lahore'},
 'lansing': {'cap_word': 'Lansing'},
 'lao': {'cap_word': 'Lao', 'n_is_sb': '0'},
 'laos': {'cap_word': 'Laos'},
 'latvia': {'cap_word': 'Latvia'},
 'latvian': {'cap_word': 'Latvian', 'n_is_sb': '0'},
 'la_paz': {'cap_word': 'La_Paz'},
 'lebanon': {'cap_word': 'Lebanon', 'n_is_nu': '', 'n_is_sth': ''},
 'lesotho': {'cap_word': 'Lesotho', 'n_is_nu': '', 'n_is_sth': ''},
 'liberia': {'cap_word': 'Liberia', 'n_is_sth': ''},
 'libreville': {'cap_word': 'Libreville'},
 'libya': {'cap_word': 'Libya', 'n_is_nu': '', 'n_is_sth': ''},
 'liechtenstein': {'cap_word': 'Liechtenstein'},
 'lilongwe': {'cap_word': 'Lilongwe'},
 'lima': {'cap_word': 'Lima', 'n_is_nu': '', 'n_is_sth': ''},
 'lincoln': {'cap_word': 'Lincoln', 'n_is_nu': '', 'n_is_sb': '0'},
 'lisbon': {'cap_word': 'Lisbon'},
 'lithuania': {'cap_word': 'Lithuania', 'n_is_sth': ''},
 'lithuanian': {'cap_word': 'Lithuanian', 'n_is_sb': '0'},
 'little_rock': {'cap_word': 'Little_Rock'},
 'ljubljana': {'cap_word': 'Ljubljana'},
 'lome': {'cap_word': 'Lome', 'n_is_nu': '', 'n_is_sth': ''},
 'london': {'cap_word': 'London', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'los_angeles': {'cap_word': 'Los_Angeles'},
 'louisiana': {'cap_word': 'Louisiana', 'n_is_nu': '', 'n_is_sth': ''},
 'luanda': {'cap_word': 'Luanda', 'n_is_nu': '', 'n_is_sth': ''},
 'lusaka': {'cap_word': 'Lusaka', 'n_is_nu': '', 'n_is_sth': ''},
 'luxembourg': {'cap_word': 'Luxembourg', 'n_is_nu': '', 'n_is_sth': ''},
 'macao': {'cap_word': 'Macao', 'n_is_nu': '', 'n_is_sth': ''},
 'macedonia': {'cap_word': 'Macedonia', 'n_is_nu': '', 'n_is_sth': ''},
 'madagascar': {'cap_word': 'Madagascar', 'n_is_nu': '', 'n_is_sth': ''},
 'madison': {'cap_word': 'Madison', 'n_is_sb': '0'},
 'madrid': {'cap_word': 'Madrid', 'n_is_nu': '', 'n_is_sth': ''},
 'maine': {'cap_word': 'Maine', 'n_is_nu': '', 'n_is_sth': ''},
 'malabo': {'cap_word': 'Malabo', 'n_is_nu': '', 'n_is_sth': ''},
 'malawi': {'cap_word': 'Malawi', 'n_is_nu': '', 'n_is_sth': ''},
 'malay': {'cap_word': 'Malay', 'n_is_sb': '0'},
 'malaysia': {'cap_word': 'Malaysia', 'n_is_nu': '', 'n_is_sth': ''},
 'maldives': {'cap_word': 'Maldives', 'n_is_nu': '', 'n_is_sth': ''},
 'mali': {'cap_word': 'Mali'},
 'malta': {'cap_word': 'Malta', 'n_is_nu': '', 'n_is_sth': ''},
 'maltese': {'cap_word': 'Maltese', 'n_is_sb': '2', 'n_is_sth': '2'},
 'managua': {'cap_word': 'Managua'},
 'manama': {'cap_word': 'Manama', 'n_is_nu': '', 'n_is_sth': ''},
 'manila': {'cap_word': 'Manila', 'n_is_nu': '', 'n_is_sth': ''},
 'maputo': {'cap_word': 'Maputo'},
 'marshall_islands': {'cap_word': 'Marshall_Islands'},
 'martinique': {'cap_word': 'Martinique'},
 'marxism': {'cap_word': 'Marxism'},
 'maryland': {'cap_word': 'Maryland', 'n_is_nu': '', 'n_is_sth': ''},
 'maseru': {'cap_word': 'Maseru', 'n_is_nu': '', 'n_is_sth': ''},
 'massachusetts': {'cap_word': 'Massachusetts', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'mauritania': {'cap_word': 'Mauritania', 'n_is_nu': '', 'n_is_sth': ''},
 'mauritius': {'cap_word': 'Mauritius', 'n_is_nu': '', 'n_is_sth': ''},
 'mbabane': {'cap_word': 'Mbabane'},
 'melbourne': {'cap_word': 'Melbourne', 'n_is_sth': ''},
 'mexico': {'cap_word': 'Mexico', 'n_is_nu': '', 'n_is_sth': ''},
 'mexico_city': {'cap_word': 'Mexico_City'},
 'michigan': {'cap_word': 'Michigan'},
 'micronesia': {'cap_word': 'Micronesia', 'n_is_nu': '', 'n_is_sth': ''},
 'minneapolis': {'cap_word': 'Minneapolis', 'n_is_nu': '', 'n_is_sth': ''},
 'minnesota': {'cap_word': 'Minnesota', 'n_is_nu': '', 'n_is_sth': ''},
 'minsk': {'cap_word': 'Minsk', 'n_is_nu': '', 'n_is_sth': ''},
 'mississippi': {'cap_word': 'Mississippi'},
 'missouri': {'cap_word': 'Missouri', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'mogadishu': {'cap_word': 'Mogadishu', 'n_is_nu': '', 'n_is_sth': ''},
 'moldova': {'cap_word': 'Moldova', 'n_is_nu': '', 'n_is_sth': ''},
 'monaco': {'cap_word': 'Monaco'},
 'mongolia': {'cap_word': 'Mongolia', 'n_is_nu': '', 'n_is_sth': ''},
 'mongolian': {'cap_word': 'Mongolian', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'monrovia': {'cap_word': 'Monrovia', 'n_is_nu': '', 'n_is_sth': ''},
 'montana': {'cap_word': 'Montana', 'n_is_nu': '', 'n_is_sth': ''},
 'montenegro': {'cap_word': 'Montenegro', 'n_is_sth': ''},
 'montevideo': {'cap_word': 'Montevideo', 'n_is_nu': '', 'n_is_sth': ''},
 'montgomery': {'cap_word': 'Montgomery', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'montpelier': {'cap_word': 'Montpelier'},
 'montreal': {'cap_word': 'Montreal', 'n_is_nu': '', 'n_is_sth': ''},
 'montserrat': {'cap_word': 'Montserrat'},
 'morocco': {'cap_word': 'Morocco', 'n_is_sth': ''},
 'moscow': {'cap_word': 'Moscow', 'n_is_nu': '', 'n_is_sth': ''},
 'mozambique': {'cap_word': 'Mozambique'},
 'muscat': {'cap_word': 'Muscat', 'n_is_nc': '', 'n_is_sth': ''},
 'myanmar': {'cap_word': 'Myanmar'},
 "n'djamena": {'cap_word': "N'djamena"},
 'nairobi': {'cap_word': 'Nairobi'},
 'namibia': {'cap_word': 'Namibia', 'n_is_nu': '', 'n_is_sth': ''},
 'nashville': {'cap_word': 'Nashville'},
 'nassau': {'cap_word': 'Nassau'},
 'nauru': {'cap_word': 'Nauru', 'n_is_nu': '', 'n_is_sth': ''},
 'nebraska': {'cap_word': 'Nebraska'},
 'nepal': {'cap_word': 'Nepal', 'n_is_sth': ''},
 'nepali': {'cap_word': 'Nepali', 'n_is_sb': '0'},
 'netherlands': {'cap_word': 'Netherlands', 'n_is_nu': '', 'n_is_sth': ''},
 'netherlands_antilles': {'cap_word': 'Netherlands_Antilles'},
 'nevada': {'cap_word': 'Nevada'},
 'new_caledonia': {'cap_word': 'New_Caledonia'},
 'new_delhi': {'cap_word': 'New_Delhi'},
 'new_hampshire': {'cap_word': 'New_Hampshire'},
 'new_jersey': {'cap_word': 'New_Jersey'},
 'new_mexico': {'cap_word': 'New_Mexico'},
 'new_orleans': {'cap_word': 'New_Orleans'},
 'new_york': {'cap_word': 'New_York'},
 'new_zealand': {'cap_word': 'New_Zealand'},
 'new_zealander': {'cap_word': 'New_Zealander'},
 'niamey': {'cap_word': 'Niamey'},
 'nicaragua': {'cap_word': 'Nicaragua', 'n_is_nu': '', 'n_is_sth': ''},
 'nicosia': {'cap_word': 'Nicosia'},
 'niger': {'cap_word': 'Niger'},
 'nigeria': {'cap_word': 'Nigeria', 'n_is_nu': '', 'n_is_sth': ''},
 'north_carolina': {'cap_word': 'North_Carolina'},
 'north_dakota': {'cap_word': 'North_Dakota'},
 'north_korea': {'cap_word': 'North_Korea'},
 'norway': {'cap_word': 'Norway', 'n_is_nu': '', 'n_is_sth': ''},
 'norwegian': {'cap_word': 'Norwegian', 'n_is_sb': '0'},
 'nouakchott': {'cap_word': 'Nouakchott'},
 'oceania': {'cap_word': 'Oceania', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ohio': {'cap_word': 'Ohio'},
 'oklahoma': {'cap_word': 'Oklahoma'},
 'oklahoma_city': {'cap_word': 'Oklahoma_City'},
 'olympia': {'cap_word': 'Olympia'},
 'oman': {'cap_word': 'Oman', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'oregon': {'cap_word': 'Oregon'},
 'oslo': {'cap_word': 'Oslo', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ottawa': {'cap_word': 'Ottawa', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'pago_pago': {'cap_word': 'Pago_Pago'},
 'pakistan': {'cap_word': 'Pakistan', 'n_is_nu': '', 'n_is_sth': ''},
 'palestine': {'cap_word': 'Palestine', 'n_is_sth': ''},
 'panama': {'cap_word': 'Panama', 'n_is_nu': '', 'n_is_sth': ''},
 'papua_new_guinea': {'cap_word': 'Papua_New_Guinea'},
 'paraguay': {'cap_word': 'Paraguay', 'n_is_sth': ''},
 'paris': {'cap_word': 'Paris', 'n_is_nu': '', 'n_is_sth': ''},
 'pennsylvania': {'cap_word': 'Pennsylvania'},
 "people's_republic_of_china": {'cap_word': "People's_Republic_of_China"},
 'persian': {'cap_word': 'Persian', 'n_is_sb': '2', 'n_is_sth': '2'},
 'perth': {'cap_word': 'Perth'},
 'peru': {'cap_word': 'Peru', 'n_is_nu': '', 'n_is_sth': ''},
 'philadelphia': {'cap_word': 'Philadelphia', 'n_is_nu': '', 'n_is_sth': ''},
 'philippines': {'cap_word': 'Philippines', 'n_is_nu': '', 'n_is_sth': ''},
 'phoenix': {'cap_word': 'Phoenix', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'pierre': {'cap_word': 'Pierre'},
 'plymouth': {'cap_word': 'Plymouth'},
 'poland': {'cap_word': 'Poland', 'n_is_nu': '', 'n_is_sth': ''},
 'port-au-prince': {'cap_word': 'Port-au-prince'},
 'port-of-spain': {'cap_word': 'Port-of-spain'},
 'portugal': {'cap_word': 'Portugal', 'n_is_nu': '', 'n_is_sth': ''},
 'portuguese': {'cap_word': 'Portuguese', 'n_is_sb': '2', 'n_is_sth': '2'},
 'port_louis': {'cap_word': 'Port_Louis'},
 'port_moresby': {'cap_word': 'Port_Moresby'},
 'prague': {'cap_word': 'Prague', 'n_is_nu': '', 'n_is_sth': ''},
 'praia': {'cap_word': 'Praia'},
 'pretoria': {'cap_word': 'Pretoria'},
 'providence': {'cap_word': 'Providence', 'n_is_nu': '', 'n_is_sth': ''},
 'puerto_rico': {'cap_word': 'Puerto_Rico'},
 'pyongyang': {'cap_word': 'Pyongyang', 'n_is_sth': ''},
 'qatar': {'cap_word': 'Qatar'},
 'quito': {'cap_word': 'Quito'},
 'rabat': {'cap_word': 'Rabat'},
 'raleigh': {'cap_word': 'Raleigh', 'n_is_sb': '0'},
 'rangoon': {'cap_word': 'Rangoon', 'n_is_nu': '', 'n_is_sth': ''},
 'republic_of_the_congo': {'cap_word': 'Republic_of_the_Congo'},
 'reykjavik': {'cap_word': 'Reykjavik'},
 'rhode_island': {'cap_word': 'Rhode_Island'},
 'richmond': {'cap_word': 'Richmond'},
 'riga': {'cap_word': 'Riga'},
 'rio_de_janeiro': {'cap_word': 'Rio_de_Janeiro'},
 'riyadh': {'cap_word': 'Riyadh'},
 'romania': {'cap_word': 'Romania', 'n_is_nu': '', 'n_is_sth': ''},
 'romanian': {'cap_word': 'Romanian', 'n_is_sb': '0'},
 'rome': {'cap_word': 'Rome', 'n_is_nu': '', 'n_is_sth': ''},
 'roseau': {'cap_word': 'Roseau'},
 'russia': {'cap_word': 'Russia', 'n_is_nu': '', 'n_is_sth': ''},
 'russian': {'cap_word': 'Russian', 'n_is_nc': '', 'n_is_sb': '0'},
 'rwanda': {'cap_word': 'Rwanda', 'n_is_nu': '', 'n_is_sth': ''},
 'sacramento': {'cap_word': 'Sacramento'},
 "saint_john's": {'cap_word': "Saint_John's"},
 'salem': {'cap_word': 'Salem'},
 'salt_lake_city': {'cap_word': 'Salt_Lake_City'},
 'samoa': {'cap_word': 'Samoa'},
 'santa_fe': {'cap_word': 'Santa_Fe'},
 'santiago': {'cap_word': 'Santiago', 'n_is_nu': '', 'n_is_sth': ''},
 'santo_domingo': {'cap_word': 'Santo_Domingo'},
 'san_francisco': {'cap_word': 'San_Francisco'},
 'san_jose': {'cap_word': 'San_Jose'},
 'san_juan': {'cap_word': 'San_Juan'},
 'san_marino': {'cap_word': 'San_Marino'},
 'san_salvador': {'cap_word': 'San_Salvador'},
 'sao_paulo': {'cap_word': 'Sao_Paulo'},
 'sao_tome': {'cap_word': 'Sao_Tome'},
 'sao_tome_and_principe': {'cap_word': 'Sao_Tome_and_Principe'},
 'sarajevo': {'cap_word': 'Sarajevo'},
 'saudi_arabia': {'cap_word': 'Saudi_Arabia'},
 'scotsman': {'cap_word': 'Scotsman', 'n_is_sb': '0'},
 'seattle': {'cap_word': 'Seattle', 'n_is_nu': '', 'n_is_sth': ''},
 'senegal': {'cap_word': 'Senegal'},
 'seoul': {'cap_word': 'Seoul', 'n_is_nu': '', 'n_is_sth': ''},
 'serbia': {'cap_word': 'Serbia', 'n_is_nu': '', 'n_is_sth': ''},
 'serbo-croatian': {'cap_word': 'Serbo-croatian'},
 'seychelles': {'cap_word': 'Seychelles', 'n_is_nu': '', 'n_is_sth': ''},
 'shanghai': {'cap_word': 'Shanghai', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'sierra_leone': {'cap_word': 'Sierra_Leone'},
 'sikkim': {'cap_word': 'Sikkim', 'n_is_nu': '', 'n_is_sth': ''},
 'singapore': {'cap_word': 'Singapore', 'n_is_nu': '', 'n_is_sth': ''},
 'sinhalese': {'cap_word': 'Sinhalese', 'n_is_sb': '0'},
 'skopje': {'cap_word': 'Skopje'},
 'slovak': {'cap_word': 'Slovak', 'n_is_nc': '', 'n_is_sb': '0'},
 'slovakia': {'cap_word': 'Slovakia', 'n_is_sth': ''},
 'slovenia': {'cap_word': 'Slovenia', 'n_is_sth': ''},
 'sofia': {'cap_word': 'Sofia', 'n_is_nu': '', 'n_is_sth': ''},
 'solomon_islands': {'cap_word': 'Solomon_Islands'},
 'somali': {'cap_word': 'Somali', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '0'},
 'somalia': {'cap_word': 'Somalia', 'n_is_nu': '', 'n_is_sth': ''},
 'south_africa': {'cap_word': 'South_Africa'},
 'south_carolina': {'cap_word': 'South_Carolina'},
 'south_dakota': {'cap_word': 'South_Dakota'},
 'south_korea': {'cap_word': 'South_Korea'},
 'spain': {'cap_word': 'Spain', 'n_is_nu': '', 'n_is_sth': ''},
 'spaniard': {'cap_word': 'Spaniard', 'n_is_sb': '0'},
 'spanish': {'cap_word': 'Spanish', 'n_is_sb': '0'},
 'springfield': {'cap_word': 'Springfield'},
 'sri_lanka': {'cap_word': 'Sri_Lanka'},
 "st._john's": {'cap_word': "St._John's"},
 'st._lucia': {'cap_word': 'St._Lucia'},
 'st._paul': {'cap_word': 'St._Paul'},
 'st._vincent_and_the_grenadines': {'cap_word': 'St._Vincent_and_the_grenadines'},
 'stockholm': {'cap_word': 'Stockholm', 'n_is_nu': '', 'n_is_sth': ''},
 'sudan': {'cap_word': 'Sudan', 'n_is_nu': '', 'n_is_sth': ''},
 'suriname': {'cap_word': 'Suriname'},
 'suva': {'cap_word': 'Suva'},
 'swaziland': {'cap_word': 'Swaziland'},
 'sweden': {'cap_word': 'Sweden', 'n_is_nu': '', 'n_is_sth': ''},
 'swedish': {'cap_word': 'Swedish'},
 'swiss': {'cap_word': 'Swiss', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'switzerland': {'cap_word': 'Switzerland', 'n_is_nu': '', 'n_is_sth': ''},
 'sydney': {'cap_word': 'Sydney', 'n_is_nu': '', 'n_is_sth': ''},
 'syria': {'cap_word': 'Syria', 'n_is_nu': '', 'n_is_sth': ''},
 'tadzhik': {'cap_word': 'Tadzhik', 'n_is_sb': '0'},
 'tagalog': {'cap_word': 'Tagalog', 'n_is_sb': '2', 'n_is_sth': '2'},
 'taipei': {'cap_word': 'Taipei', 'n_is_sth': ''},
 'taiwan': {'cap_word': 'Taiwan', 'n_is_nu': '', 'n_is_sth': ''},
 'tajikistan': {'cap_word': 'Tajikistan'},
 'tallahassee': {'cap_word': 'Tallahassee'},
 'tallinn': {'cap_word': 'Tallinn'},
 'tanzania': {'cap_word': 'Tanzania', 'n_is_sth': ''},
 'tarawa': {'cap_word': 'Tarawa'},
 'tashkent': {'cap_word': 'Tashkent'},
 'tbilisi': {'cap_word': 'Tbilisi'},
 'tegucigalpa': {'cap_word': 'Tegucigalpa'},
 'tehran': {'cap_word': 'Tehran', 'n_is_sth': ''},
 'tennessee': {'cap_word': 'Tennessee', 'n_is_nu': '', 'n_is_sth': ''},
 'texas': {'cap_word': 'Texas', 'n_is_nu': '', 'n_is_sth': ''},
 'thai': {'cap_word': 'Thai', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'thailand': {'cap_word': 'Thailand', 'n_is_nu': '', 'n_is_sth': ''},
 'togo': {'cap_word': 'Togo', 'n_is_nu': '', 'n_is_sth': ''},
 'tokyo': {'cap_word': 'Tokyo', 'n_is_nu': '', 'n_is_sth': ''},
 'tonga': {'cap_word': 'Tonga', 'n_is_nu': '', 'n_is_sth': ''},
 'topeka': {'cap_word': 'Topeka'},
 'toronto': {'cap_word': 'Toronto'},
 'trenton': {'cap_word': 'Trenton'},
 'trinidad_and_tobago': {'cap_word': 'Trinidad_and_Tobago'},
 'tripoli': {'cap_word': 'Tripoli', 'n_is_nu': '', 'n_is_sth': ''},
 'tunis': {'cap_word': 'Tunis'},
 'tunisia': {'cap_word': 'Tunisia'},
 'turkish': {'cap_word': 'Turkish'},
 'turkmenistan': {'cap_word': 'Turkmenistan'},
 'tuvalu': {'cap_word': 'Tuvalu'},
 'uganda': {'cap_word': 'Uganda', 'n_is_sth': ''},
 'ukraine': {'cap_word': 'Ukraine', 'n_is_nu': '', 'n_is_sth': ''},
 'ukrainian': {'cap_word': 'Ukrainian'},
 'united_arab_emirates': {'cap_word': 'United_Arab_Emirates'},
 'united_kingdom': {'cap_word': 'United_Kingdom'},
 'united_states': {'cap_word': 'United_States'},
 'united_states_virgin_islands': {'cap_word': 'United_States_Virgin_Islands'},
 'urdu': {'cap_word': 'Urdu'},
 'uruguay': {'cap_word': 'Uruguay', 'n_is_sth': '', 'art_an': ''},
 'utah': {'cap_word': 'Utah'},
 'uzbek': {'cap_word': 'Uzbek', 'art_an': '', 'n_is_sb': '0'},
 'uzbekistan': {'cap_word': 'Uzbekistan', 'n_is_sth': '', 'art_an': ''},
 'vaduz': {'cap_word': 'Vaduz'},
 'valletta': {'cap_word': 'Valletta'},
 'vancouver': {'cap_word': 'Vancouver', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'vanuatu': {'cap_word': 'Vanuatu'},
 'vatican': {'cap_word': 'Vatican', 'n_is_nu': '', 'n_is_sth': ''},
 'venezuela': {'cap_word': 'Venezuela', 'n_is_nu': '', 'n_is_sth': ''},
 'vermont': {'cap_word': 'Vermont'},
 'victoria': {'cap_word': 'Victoria', 'n_is_nu': '', 'n_is_sb': '0'},
 'vienna': {'cap_word': 'Vienna', 'n_is_nu': '', 'n_is_sth': ''},
 'vientiane': {'cap_word': 'Vientiane'},
 'vietnam': {'cap_word': 'Vietnam', 'n_is_nu': '', 'n_is_sth': ''},
 'vietnamese': {'cap_word': 'Vietnamese', 'n_is_sb': '0'},
 'vilnius': {'cap_word': 'Vilnius'},
 'virginia': {'cap_word': 'Virginia', 'n_is_nu': '', 'n_is_sth': ''},
 'vladivostok': {'cap_word': 'Vladivostok', 'n_is_nu': '', 'n_is_sth': ''},
 'wales': {'cap_word': 'Wales', 'n_is_nu': '', 'n_is_sth': ''},
 'warsaw': {'cap_word': 'Warsaw', 'n_is_sth': ''},
 'washington': {'cap_word': 'Washington', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'wellington': {'cap_word': 'Wellington', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'welsh': {'cap_word': 'Welsh', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'welshman': {'cap_word': 'Welshman', 'n_is_sb': '0'},
 'western_sahara': {'cap_word': 'Western_Sahara'},
 'west_virginia': {'cap_word': 'West_Virginia'},
 'white_russia': {'cap_word': 'White_Russia'},
 'windhoek': {'cap_word': 'Windhoek'},
 'winnipeg': {'cap_word': 'Winnipeg'},
 'wisconsin': {'cap_word': 'Wisconsin'},
 'wyoming': {'cap_word': 'Wyoming'},
 'yangon': {'cap_word': 'Yangon'},
 'yaounde': {'cap_word': 'Yaounde'},
 'yemen': {'cap_word': 'Yemen', 'n_is_sth': ''},
 'yerevan': {'cap_word': 'Yerevan'},
 'yugoslavia': {'cap_word': 'Yugoslavia', 'n_is_nu': '', 'n_is_sth': ''},
 'zagreb': {'cap_word': 'Zagreb'},
 'zambia': {'cap_word': 'Zambia'},
 'zen': {'cap_word': 'Zen'},
 'zimbabwe': {'cap_word': 'Zimbabwe', 'n_is_nu': '', 'n_is_sth': ''},
 'zurich': {'cap_word': 'Zurich', 'n_is_nu': '', 'n_is_sth': ''},
 'Belmopan': {'cap_word': 'Belmopan'},
 'Ashgabat': {'cap_word': 'Ashgabat'},
 'Agana': {'cap_word': 'Agana'},
 'Dili': {'cap_word': 'Dili'},
 'Gangtok': {'cap_word': 'Gangtok'},
 'Kamchatka': {'cap_word': 'Kamchatka'},
 'Kodak': {'cap_word': 'Kodak'},
 'Majuro': {'cap_word': 'Majuro'},
 'Malagasy': {'cap_word': 'Malagasy'},
 'Moldavian': {'cap_word': 'Moldavian'},
 'Moroni': {'cap_word': 'Moroni'},
 'Oranjestad': {'cap_word': 'Oranjestad'},
 'Ouagadougou': {'cap_word': 'Ouagadougou'},
 'Podgorica': {'cap_word': 'Podgorica'},
 'Puritans': {'cap_word': 'Puritans'},
 'Stoics': {'cap_word': 'Stoics'},
 'Thimphu': {'cap_word': 'Thimphu'},
 'Willemstad': {'cap_word': 'Willemstad'},
 'Yamoussoukro': {'cap_word': 'Yamoussoukro'},
 'YAREN': {'cap_word': 'YAREN'},
 'ad_dawha': {'cap_word': 'Ad_Dawha'},
 'angra_do_heroismo': {'cap_word': 'Angra_do_Heroismo'},
 'bahrain_islands': {'cap_word': 'Bahrain_Islands'},
 'bandar_seri_begawan': {'cap_word': 'Bandar_Seri_Begawan'},
 'basse-terre': {'cap_word': 'Basse-terre'},
 'belarus_minsk': {'cap_word': 'Belarus_Minsk'},
 'canary_is': {'cap_word': 'Canary_is'},
 'charlotte_amalie': {'cap_word': 'Charlotte_Amalie'},
 'chatham_island': {'cap_word': 'Chatham_Island'},
 'congo_rep.': {'cap_word': 'Congo_Rep.'},
 'cook_islands': {'cap_word': 'Cook_Islands'},
 'cote_d_ivoire': {'cap_word': 'Cote_d_Ivoire'},
 'el_aaiun': {'cap_word': 'El_Aaiun'},
 'fort-de-france': {'cap_word': 'Fort-de-france'},
 'french_guyana': {'cap_word': 'French_Guyana'},
 'guyana_francaise': {'cap_word': 'Guyana_Francaise'},
 'las_palmas': {'cap_word': 'Las_Palmas'},
 'naypyidaw': {'cap_word': 'Naypyidaw'},
 'netherlands_amsterdam': {'cap_word': 'Netherlands_Amsterdam'},
 'northern_mariana_island': {'cap_word': 'Northern_Mariana_Island'},
 'noumea': {'cap_word': 'Noumea'},
 'nukualofa': {'cap_word': 'Nukualofa'},
 'palikir': {'cap_word': 'Palikir'},
 'pitcairn_island': {'cap_word': 'Pitcairn_Island'},
 'porto-novo': {'cap_word': 'Porto-novo'},
 'road_town': {'cap_word': 'Road_Town'},
 'saint-denis': {'cap_word': 'Saint-denis'},
 "saint_george's": {'cap_word': "Saint_George's"},
 'sana/sanaa': {'cap_word': 'Sana/sanaa'},
 'st.kitts_and_nevis': {'cap_word': 'St.kitts_and_Nevis'},
 'st.paul': {'cap_word': 'St.paul'},
 'st._helena': {'cap_word': 'St._Helena'},
 'surinam_paramaribo': {'cap_word': 'Surinam_Paramaribo'},
 'the_valley': {'cap_word': 'The_Valley'},
 'tokelau_islands': {'cap_word': 'Tokelau_Islands'},
 'turkhmen': {'cap_word': 'Turkhmen'},
 'turks_and_caicos_islands': {'cap_word': 'Turks_and_Caicos_Islands'},
 'ulan_batar': {'cap_word': 'Ulan_Batar'},
 'united_states(of_america)': {'cap_word': 'United_States(of_America)'},
 'verde_cape': {'cap_word': 'Verde_Cape'},
 'verde_praia': {'cap_word': 'Verde_Praia'},
 'wallis_and_futuna': {'cap_word': 'Wallis_and_Futuna'},
 'washington,_dc': {'cap_word': 'Washington,_DC'},
 'washington_dc': {'cap_word': 'Washington_DC'},
 'mexican': {'cap_word': 'Mexican', 'n_is_sb': '2', 'n_is_sth': '2'},
 'african': {'cap_word': 'African', 'n_is_sb': '0'},
 'asian': {'cap_word': 'Asian', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'pacific': {'cap_word': 'Pacific', 'n_is_nu': '', 'n_is_sth': ''},
 'british': {'cap_word': 'British', 'n_is_sb': '0'},
 "'neath": {'func_word': ''},
 "'s": {'func_word': ''},
 "'til": {'func_word': ''},
 "'till": {'func_word': ''},
 '1': {'func_word': ''},
 '10': {'func_word': ''},
 '11': {'func_word': ''},
 '12': {'func_word': ''},
 '13': {'func_word': ''},
 '14': {'func_word': ''},
 '18': {'func_word': ''},
 '26': {'func_word': ''},
 '3': {'func_word': ''},
 '38': {'func_word': ''},
 '4': {'func_word': ''},
 '5': {'func_word': ''},
 '60': {'func_word': ''},
 '7': {'func_word': ''},
 '8': {'func_word': ''},
 '9': {'func_word': ''},
 'a': {'func_word': ''},
 'aboard': {'func_word': ''},
 'about': {'func_word': ''},
 'above': {'func_word': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'above_and_beyond': {'func_word': ''},
 'across': {'func_word': ''},
 'after': {'func_word': ''},
 'afterwards': {'func_word': ''},
 'against': {'func_word': ''},
 'albeit': {'func_word': ''},
 'all': {'func_word': ''},
 'all_along': {'func_word': ''},
 'all_over': {'func_word': ''},
 'all_through': {'func_word': ''},
 'all_up_with': {'func_word': ''},
 'aloft': {'func_word': ''},
 'along': {'func_word': ''},
 'alongside': {'func_word': ''},
 'also': {'func_word': ''},
 'although': {'func_word': ''},
 'am': {'func_word': '', 'n_is_nu': '', 'nns_exp_exc': ''},
 'amid': {'func_word': ''},
 'amidst': {'func_word': ''},
 'among': {'func_word': ''},
 'amongst': {'func_word': ''},
 'an': {'func_word': ''},
 'and': {'func_word': ''},
 'another': {'func_word': ''},
 'anti': {'func_word': '', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'prefix': ''},
 'any': {'func_word': ''},
 'anybody': {'func_word': ''},
 'anyhow': {'func_word': ''},
 'anymore': {'func_word': ''},
 'anyone': {'func_word': ''},
 'anything': {'func_word': ''},
 'anything_but': {'func_word': ''},
 'anyway': {'func_word': ''},
 'anywhere': {'func_word': ''},
 'apres': {'func_word': ''},
 'apropos': {'func_word': ''},
 'are': {'func_word': ''},
 'around': {'func_word': ''},
 'as': {'func_word': ''},
 'astride': {'func_word': ''},
 'as_a_consequence_of': {'func_word': ''},
 'as_a_result_of': {'func_word': ''},
 'as_compared_to': {'func_word': ''},
 'as_compared_with': {'func_word': ''},
 'as_distinct_from': {'func_word': ''},
 'as_distinguished_from': {'func_word': ''},
 'as_far_as': {'func_word': ''},
 'as_if': {'func_word': ''},
 'as_long_as': {'func_word': ''},
 'as_much_as': {'func_word': ''},
 'as_opposed_to': {'func_word': ''},
 'as_regards': {'func_word': ''},
 'as_result_of': {'func_word': ''},
 'as_soon_as': {'func_word': ''},
 'as_though': {'func_word': ''},
 'as_well_as': {'func_word': ''},
 'at': {'func_word': '', 'art_an': ''},
 'athwart': {'func_word': ''},
 'atop': {'func_word': ''},
 'a_few': {'func_word': ''},
 'a_little': {'func_word': ''},
 'back_of': {'func_word': ''},
 'bar': {'func_word': '', 'nn_to_nns': 'bars', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'barred', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_against': '', 'vb_to_vbz': 'bars', 'vb_to_vbd': 'barred', 'vb_to_vbn': 'barred', 'vb_to_jj': 'barred', 'vb_to_vbg': 'baring', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'barred': {'func_word': '', 'jj_to_nn': 'bar', 'jj_to_vb': 'bar', 'vbd_to_vb': 'bar', 'vbn_to_vb': 'bar', 'vbn_to_vbg': 'baring', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'barring': {'func_word': ''},
 'bars': {'func_word': '', 'nns_to_nn': 'bar', 'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'bar'},
 'be': {'func_word': '', 'v_vbg': '', 'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vbe': '', 'v_n_jj': '', 'v_n_to_vb': '', 'v_compcl': '', 'v_pass_non': ''},
 'because': {'func_word': ''},
 'because_of': {'func_word': ''},
 'been': {'func_word': ''},
 'before': {'func_word': ''},
 'behind': {'func_word': '', 'nn_to_nns': 'behinds', 'n_is_nc': '', 'n_is_sth': ''},
 'being': {'func_word': '', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'beings': {'func_word': ''},
 'below': {'func_word': ''},
 'beneath': {'func_word': ''},
 'beside': {'func_word': ''},
 'besides': {'func_word': ''},
 'between': {'func_word': ''},
 'betwixt': {'func_word': ''},
 'beyond': {'func_word': ''},
 'both': {'func_word': ''},
 'but': {'func_word': ''},
 'but_that': {'func_word': ''},
 'by': {'func_word': ''},
 'by_comparison_with': {'func_word': ''},
 'by_dint_of': {'func_word': ''},
 'by_means_of': {'func_word': ''},
 'by_order_of': {'func_word': ''},
 'by_reason_of': {'func_word': ''},
 'by_the_order_of': {'func_word': ''},
 'by_virtue_of': {'func_word': ''},
 'by_way_of': {'func_word': ''},
 'can': {'func_word': '', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'canning', 'vb_to_jj': 'canning', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'canned': {'func_word': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'canning': {'func_word': '', 'jj_to_nn': 'can', 'jj_to_vb': 'can', 'nn_to_vb': 'can'},
 'cannot': {'func_word': ''},
 'cans': {'func_word': ''},
 'care_of': {'func_word': ''},
 'certain': {'func_word': '', 'jj_to_rb': 'certainly', 'jj_to_nn': 'certainty', 'nn_to_rb': 'certainly', 'be_jj_to_vb': ''},
 'certainly': {'func_word': '', 'rb_to_nn': 'certainty', 'rb_to_jj': 'certain'},
 'certainty': {'func_word': '', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'certain', 'nn_to_rb': 'certainly'},
 'circa': {'func_word': ''},
 'com': {'func_word': ''},
 'corp': {'func_word': '', 'n_is_nc': '', 'n_is_sth': ''},
 'could': {'func_word': ''},
 'courtesy_of': {'func_word': ''},
 'cum': {'func_word': ''},
 'despite': {'func_word': '', 'n_is_nu': '', 'n_is_sth': ''},
 'did': {'func_word': '', 'vbd_to_vb': 'do', 'vbd_to_vbn': 'done'},
 'dislike': {'func_word': '', 'n_is_nu': '', 'n_is_sth': '', 'v_vbg': '', 'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vbg_non': '', 'vt_typical': ''},
 'disliked': {'func_word': '', 'vbd_eq_vbn': ''},
 'dislikes': {'func_word': ''},
 'disliking': {'func_word': ''},
 'do': {'func_word': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_n': '', 'v_with': '', 'v_for': '', 'v_vb': '', 'vb_to_vbz': 'does', 'vb_to_vbd': 'did', 'vb_to_vbn': 'done', 'v_n_to_vb': '', 'v_vbg': '', 'vb_to_vbg': 'doing', 'v_compcl_non': ''},
 'does': {'func_word': '', 'vbz_to_vb': 'do'},
 'doing': {'func_word': '', 'vbg_to_vb': 'do', 'vbg_to_vbn': 'done'},
 'don': {'func_word': '', 'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'done': {'func_word': '', 'vbn_to_vb': 'do', 'vbn_to_vbd': 'did', 'vbn_to_vbg': 'doing'},
 'down': {'func_word': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'downwards': {'func_word': ''},
 'during': {'func_word': ''},
 'each': {'func_word': ''},
 'each_other': {'func_word': ''},
 'either': {'func_word': ''},
 'ere': {'func_word': ''},
 'even_as': {'func_word': ''},
 'even_if': {'func_word': ''},
 'even_though': {'func_word': ''},
 'every': {'func_word': ''},
 'everybody': {'func_word': ''},
 'everyday': {'func_word': ''},
 'everyone': {'func_word': '', 'n_is_sb': '0'},
 'everything': {'func_word': ''},
 'everywhere': {'func_word': ''},
 'every_time': {'func_word': ''},
 'ever_since': {'func_word': ''},
 'ex': {'func_word': '', 'art_an': '', 'n_is_sb': '0'},
 'except': {'func_word': '', 'vb_to_nn': 'exception', 'vb_to_jj': 'exceptional', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'exception': {'func_word': '', 'nn_to_nns': 'exceptions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'except', 'nn_to_jj': 'exceptional'},
 'exceptional': {'func_word': '', 'jj_to_nn': 'exception', 'jj_to_vb': 'except', 'nn_to_vb': 'except'},
 'exceptions': {'func_word': '', 'nns_to_nn': 'exception'},
 'except_for': {'func_word': ''},
 'except_that': {'func_word': ''},
 'eyeball_to_eyeball_with': {'func_word': ''},
 'face_to_face_with': {'func_word': ''},
 'few': {'func_word': '', 'jj_to_jjr': 'fewer', 'jj_to_jjs': 'fewest'},
 'fewer': {'func_word': ''},
 'fewest': {'func_word': ''},
 'for': {'func_word': ''},
 'for_fear_of': {'func_word': ''},
 'for_lack_of': {'func_word': ''},
 'for_sake_of': {'func_word': ''},
 'for_the_benefit_of': {'func_word': ''},
 'for_the_purpose_of': {'func_word': ''},
 'for_the_sake_of': {'func_word': ''},
 'from': {'func_word': ''},
 'from_lack_of': {'func_word': ''},
 'had': {'func_word': '', 'vbd_to_vb': 'have', 'vbn_to_vb': 'have', 'vbn_to_vbg': 'having', 'vt_typical': '', 'vbd_eq_vbn': ''},
 'has': {'func_word': '', 'vbz_to_vb': 'have', 'vt_typical': ''},
 'have': {'func_word': '', 'n_is_sb': '0', 'v_n': '', 'v_n_vb': '', 'v_n_n': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_vb': '', 'vb_to_vbz': 'has', 'vb_to_vbd': 'had', 'vb_to_vbn': 'had', 'v_n_vbg': '', 'vb_to_vbg': 'having', 'v_n_to_vb': '', 'v_n_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'vt_typical': ''},
 'haven': {'func_word': '', 'n_is_nc': '', 'n_is_sth': ''},
 'haves': {'func_word': ''},
 'having': {'func_word': '', 'vbg_to_vb': 'have', 'vbg_to_vbn': 'had'},
 'he': {'func_word': '', 'n_is_sb': '0', 'prp_is_sub_case': ''},
 'head_and_shoulders_above': {'func_word': ''},
 'her': {'func_word': '', 'n_is_sb': '0', 'prp_is_obj_case': '', 'prp_obj_to_sub': 'she'},
 'hers': {'func_word': '', 'prp_poss': ''},
 'herself': {'func_word': ''},
 'him': {'func_word': '', 'n_is_sb': '0', 'prp_is_obj_case': '', 'prp_obj_to_sub': 'his'},
 'himself': {'func_word': ''},
 'his': {'func_word': '', 'prp_poss': '', 'prp_sub_to_obj': 'him'},
 'i': {'func_word': '', 'prp_is_sub_case': ''},
 'idem': {'func_word': ''},
 'if': {'func_word': ''},
 'if_not': {'func_word': ''},
 'if_only': {'func_word': ''},
 'ii': {'func_word': ''},
 'iii': {'func_word': ''},
 'in': {'func_word': '', 'art_an': '', 'nn_to_jj': 'inner', 'rb_to_jj': 'inner'},
 'inasmuch_as': {'func_word': ''},
 'inner': {'func_word': '', 'jj_to_rb': 'in', 'jj_to_nn': 'in', 'nn_to_rb': 'in'},
 'inside': {'func_word': '', 'jj_to_nn': 'insider', 'nn_to_nns': 'insides', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'rb_to_nn': 'insider'},
 'insider': {'func_word': '', 'nn_to_nns': 'insiders', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nn_to_jj': 'inside', 'nn_to_rb': 'inside'},
 'insiders': {'func_word': '', 'nns_to_nn': 'insider'},
 'inside_of': {'func_word': ''},
 'instead_of': {'func_word': ''},
 'into': {'func_word': ''},
 'into_contact_with': {'func_word': ''},
 'in_accordance_with': {'func_word': ''},
 'in_addition_to': {'func_word': ''},
 'in_advance_of': {'func_word': ''},
 'in_agreement_with': {'func_word': ''},
 'in_aid_of': {'func_word': ''},
 'in_back_of': {'func_word': ''},
 'in_behalf_of': {'func_word': ''},
 'in_between': {'func_word': ''},
 'in_cahoots_with': {'func_word': ''},
 'in_care_of': {'func_word': ''},
 'in_case': {'func_word': ''},
 'in_case_of': {'func_word': ''},
 'in_charge_of': {'func_word': ''},
 'in_common_with': {'func_word': ''},
 'in_company_with': {'func_word': ''},
 'in_comparison_to': {'func_word': ''},
 'in_comparison_with': {'func_word': ''},
 'in_compliance_with': {'func_word': ''},
 'in_conflict_with': {'func_word': ''},
 'in_conformity_with': {'func_word': ''},
 'in_connection_with': {'func_word': ''},
 'in_consideration_of': {'func_word': ''},
 'in_contact_with': {'func_word': ''},
 'in_contrast_to': {'func_word': ''},
 'in_contrast_with': {'func_word': ''},
 'in_default_of': {'func_word': ''},
 'in_deference_to': {'func_word': ''},
 'in_defiance_of': {'func_word': ''},
 'in_disregard_of': {'func_word': ''},
 'in_excess_of': {'func_word': ''},
 'in_exchange_for': {'func_word': ''},
 'in_expectation_of': {'func_word': ''},
 'in_face_of': {'func_word': ''},
 'in_favor_of': {'func_word': ''},
 'in_favour_of': {'func_word': ''},
 'in_front_of': {'func_word': ''},
 'in_fulfillment_of': {'func_word': ''},
 'in_hopes_of': {'func_word': ''},
 'in_hope_of': {'func_word': ''},
 'in_keeping_with': {'func_word': ''},
 'in_lieu_of': {'func_word': ''},
 'in_light_of': {'func_word': ''},
 'in_line_with': {'func_word': ''},
 'in_memory_of': {'func_word': ''},
 'in_need_of': {'func_word': ''},
 'in_obedience_to': {'func_word': ''},
 'in_opposition_to': {'func_word': ''},
 'in_order_for': {'func_word': ''},
 'in_order_that': {'func_word': ''},
 'in_order_to': {'func_word': ''},
 'in_place_of': {'func_word': ''},
 'in_point_of': {'func_word': ''},
 'in_preference_to': {'func_word': ''},
 'in_process_of': {'func_word': ''},
 'in_proportion_to': {'func_word': ''},
 'in_pursuit_of': {'func_word': ''},
 'in_quest_of': {'func_word': ''},
 'in_re': {'func_word': ''},
 'in_recognition_of': {'func_word': ''},
 'in_reference_to': {'func_word': ''},
 'in_regard_to': {'func_word': ''},
 'in_relation_to': {'func_word': ''},
 'in_reply_to': {'func_word': ''},
 'in_respect_of': {'func_word': ''},
 'in_return_for': {'func_word': ''},
 'in_search_of': {'func_word': ''},
 'in_spite_of': {'func_word': ''},
 'in_support_of': {'func_word': ''},
 'in_terms_of': {'func_word': ''},
 'in_the_back_of': {'func_word': ''},
 'in_the_case_of': {'func_word': ''},
 'in_the_course_of': {'func_word': ''},
 'in_the_event_of': {'func_word': ''},
 'in_the_face_of': {'func_word': ''},
 'in_the_favor_of': {'func_word': ''},
 'in_the_front_of': {'func_word': ''},
 'in_the_interest_of': {'func_word': ''},
 'in_the_light_of': {'func_word': ''},
 'in_the_matter_of': {'func_word': ''},
 'in_the_middle_of': {'func_word': ''},
 'in_the_midst_of': {'func_word': ''},
 'in_the_name_of': {'func_word': ''},
 'in_the_order_of': {'func_word': ''},
 'in_the_place_of': {'func_word': ''},
 'in_the_presence_of': {'func_word': ''},
 'in_the_process_of': {'func_word': ''},
 'in_the_vicinity_of': {'func_word': ''},
 'in_the_way_of': {'func_word': ''},
 'in_touch_with': {'func_word': ''},
 'in_view_of': {'func_word': ''},
 'in_want_of': {'func_word': ''},
 'is': {'func_word': ''},
 'it': {'func_word': '', 'nn_to_nns': '', 'n_is_sth': '', 'prp_is_obj_case': '', 'prp_is_sub_case': ''},
 'its': {'func_word': '', 'prp_poss': ''},
 'itself': {'func_word': ''},
 'just_in_case': {'func_word': ''},
 'least': {'func_word': ''},
 'less': {'func_word': '', 'jj_to_vb': 'lessen', 'nn_to_vb': 'lessen', 'rb_to_vb': 'lessen'},
 'lessen': {'func_word': '', 'nn_to_jj': 'less', 'nn_to_rb': 'less', 'vb_to_rb': 'less', 'vb_to_nn': 'less', 'vb_to_jj': 'less', 'v_compcl_non': '', 'v_infcl_non': ''},
 'lessened': {'func_word': '', 'vbd_eq_vbn': ''},
 'lessening': {'func_word': ''},
 'lesser': {'func_word': ''},
 'lest': {'func_word': ''},
 'li': {'func_word': ''},
 'like': {'func_word': '', 'n_is_nc': '', 'n_is_sth': '', 'v_vbg': '', 'v_to_vb': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vsub_is_sb': '', 'vbd_eq_vbn': '', 'vbg_non': '', 'vt_typical': ''},
 'liked': {'func_word': '', 'vbd_eq_vbn': ''},
 'likes': {'func_word': ''},
 'like_in': {'func_word': ''},
 'liking': {'func_word': '', 'n_is_nc': '', 'n_is_sth': ''},
 'little_short_of': {'func_word': ''},
 'll': {'func_word': ''},
 'many': {'func_word': '', 'jj_nns': '', 'confu_pair': 'much'},
 'me': {'func_word': '', 'n_is_sb': '0', 'prp_to_prp$': 'my', 'prp_is_obj_case': '', 'prp_obj_to_sub': 'I'},
 'mid': {'func_word': ''},
 'midst': {'func_word': '', 'n_is_nu': '', 'n_is_sth': ''},
 'mine': {'func_word': '', 'nn_to_nns': 'mines', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'v_for': '', 'v_compcl_non': '', 'nc_typical': '', 'prp_poss': ''},
 'minus': {'func_word': '', 'n_is_nc': '', 'n_is_sth': ''},
 'modulo': {'func_word': ''},
 'more': {'func_word': '', 'n_is_sth': '2'},
 'most': {'func_word': '', 'jj_to_rb': 'mostly', 'nn_to_rb': 'mostly'},
 'mostly': {'func_word': '', 'rb_to_nn': 'most', 'rb_to_jj': 'most'},
 'much': {'func_word': '', 'n_is_nu': '', 'n_is_sth': '', 'confu_pair': 'many'},
 'must': {'func_word': '', 'n_is_nc': '', 'n_is_sth': ''},
 'my': {'func_word': '', 'prp$_to_prp': 'me'},
 'myself': {'func_word': ''},
 'near': {'func_word': '', 'jj_to_rb': 'nearly', 'jj_to_nn': 'nearness', 'rb_to_nn': 'nearness', 'be_jj_to_vbg': '', 'jj_to_jjr': 'nearer', 'jj_to_jjs': 'nearest'},
 'nearby': {'func_word': ''},
 'nearer': {'func_word': ''},
 'nearest': {'func_word': ''},
 'nearly': {'func_word': '', 'rb_to_nn': 'nearness', 'rb_to_jj': 'near'},
 'nearness': {'func_word': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'near', 'nn_to_rb': 'nearly'},
 'neath': {'func_word': ''},
 'need': {'func_word': '', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_vbg': '', 'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'needs', 'vb_to_vbd': 'needed', 'vb_to_vbn': 'needed', 'v_n_to_vb': '', 'v_vb': '', 'vb_to_vbg': 'needing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vbg_non': ''},
 'never_mind': {'func_word': ''},
 'next': {'func_word': ''},
 'next_door_to': {'func_word': ''},
 'nigh': {'func_word': '', 'jj_to_jjr': 'nigher', 'jj_to_jjs': 'nighest', 'rb_to_rbr': 'nigher', 'rb_to_rbs': 'nighest'},
 'no': {'func_word': '', 'n_is_nc': '', 'n_is_sth': '', 'confu_pair': 'not'},
 'no.': {'func_word': ''},
 'nobody': {'func_word': '', 'n_is_sth': '', 'n_is_sb': '0', 'nn_to_nns': 'nobodies'},
 'nor': {'func_word': ''},
 'not': {'func_word': '', 'confu_pair': 'no'},
 'nothing': {'func_word': ''},
 'nothing_short_of': {'func_word': ''},
 'notwithstanding': {'func_word': ''},
 'not_only': {'func_word': ''},
 'now': {'func_word': ''},
 'nowadays': {'func_word': '', 'n_is_nu': '', 'n_is_sth': ''},
 'nowhere': {'func_word': ''},
 'now_that': {'func_word': ''},
 'no_matter': {'func_word': ''},
 "o'": {'func_word': ''},
 "o'er": {'func_word': ''},
 'of': {'func_word': ''},
 'off': {'func_word': ''},
 'of_the_order_of': {'func_word': ''},
 'on': {'func_word': ''},
 'once': {'func_word': ''},
 'one': {'func_word': '', 'nn_to_nns': 'ones', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ones': {'func_word': '', 'nns_to_nn': 'one'},
 'oneself': {'func_word': ''},
 'only': {'func_word': ''},
 'onto': {'func_word': ''},
 'on_account': {'func_word': ''},
 'on_account_of': {'func_word': ''},
 'on_behalf_of': {'func_word': ''},
 'on_board': {'func_word': ''},
 'on_grounds_of': {'func_word': ''},
 'on_pain_of': {'func_word': ''},
 'on_par_with': {'func_word': ''},
 'on_the_basis_of': {'func_word': ''},
 'on_the_grounds_of': {'func_word': ''},
 'on_the_occasion_of': {'func_word': ''},
 'on_the_order_of': {'func_word': ''},
 'on_the_part_of': {'func_word': ''},
 'on_the_point_of': {'func_word': ''},
 'on_the_side_of': {'func_word': ''},
 'on_the_strength_of': {'func_word': ''},
 'on_the_top_of': {'func_word': ''},
 'on_top_of': {'func_word': ''},
 'opposite': {'func_word': '', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2', 'vb_to_nn': 'opposition', 'vb_to_jj': 'oppositional', 'nc_typical': ''},
 'opposites': {'func_word': ''},
 'or': {'func_word': '', 'art_an': ''},
 'org': {'func_word': ''},
 'or_else': {'func_word': ''},
 'other': {'func_word': ''},
 'others': {'func_word': ''},
 'other_than': {'func_word': ''},
 'our': {'func_word': ''},
 'ours': {'func_word': '', 'prp_to_prp$': 'our', 'prp_poss': ''},
 'ourselves': {'func_word': ''},
 'out': {'func_word': '', 'nn_to_nns': 'outs', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'outside', 'nn_to_jj': 'outsider', 'nn_to_rb': 'outward', 'vbg_non': ''},
 'outer': {'func_word': ''},
 'outside': {'func_word': '', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vb_to_rb': 'outward', 'vb_to_nn': 'out', 'vb_to_jj': 'outsider'},
 'outsider': {'func_word': '', 'jj_to_rb': 'outward', 'jj_to_nn': 'out', 'jj_to_vb': 'outside', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'outsiders': {'func_word': ''},
 'outward': {'func_word': '', 'rb_to_nn': 'out', 'rb_to_jj': 'outsider', 'rb_to_vb': 'outside'},
 'outwards': {'func_word': ''},
 'out_of': {'func_word': ''},
 'out_of_all_proportion_to': {'func_word': ''},
 'out_of_bounds_to': {'func_word': ''},
 'out_of_keeping_with': {'func_word': ''},
 'out_of_proportion_to': {'func_word': ''},
 'out_of_the_way_of': {'func_word': ''},
 'out_of_touch_with': {'func_word': ''},
 'over': {'func_word': '', 'art_an': ''},
 'over_against': {'func_word': ''},
 'over_and_above': {'func_word': ''},
 'past': {'func_word': '', 'nn_to_nns': 'pasts', 'n_is_nc': '', 'n_is_sth': ''},
 'per': {'func_word': ''},
 'plus': {'func_word': '', 'nn_to_nns': 'pluses', 'n_is_nc': '', 'n_is_sth': ''},
 'pluses': {'func_word': '', 'nns_to_nn': 'plus'},
 'provided': {'func_word': '', 'vbd_to_vb': 'provide', 'vbn_to_vb': 'provide', 'vbn_to_vbg': 'providing', 'vbd_eq_vbn': ''},
 'provided_that': {'func_word': ''},
 'providing': {'func_word': '', 'vbg_to_vb': 'provide', 'vbg_to_vbn': 'provided'},
 'pursuant_to': {'func_word': ''},
 'qua': {'func_word': ''},
 'rather_than': {'func_word': ''},
 're': {'func_word': '', 'n_is_sb': '0'},
 'round': {'func_word': '', 'jj_to_rb': 'roundly', 'nn_to_nns': 'rounds', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'roundly', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'jj_to_jjr': 'rounder', 'jj_to_jjs': 'roundest'},
 'roundabout': {'func_word': '', 'jj_to_rb': 'roundly', 'jj_to_nn': 'round', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'rounded': {'func_word': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'rounder': {'func_word': '', 'n_is_nc': '', 'n_is_sb': '0'},
 'roundest': {'func_word': ''},
 'roundly': {'func_word': '', 'rb_to_nn': 'round', 'rb_to_jj': 'round'},
 'roundness': {'func_word': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'round', 'nn_to_rb': 'roundly'},
 'rounds': {'func_word': '', 'nns_to_nn': 'round'},
 's': {'func_word': ''},
 'said': {'func_word': '', 'vbd_to_vb': 'say', 'vbn_to_vb': 'say', 'vbn_to_vbg': 'saying', 'vbd_eq_vbn': ''},
 'sans': {'func_word': ''},
 'save': {'func_word': '', 'n_is_nc': '', 'n_is_sth': '', 'v_vbg': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_with': '', 'v_from': '', 'vb_to_vbz': 'saves', 'vb_to_vbd': 'saved', 'vb_to_vbn': 'saved', 'vb_to_vbg': 'saving', 'vt_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'saved': {'func_word': '', 'vbd_to_vb': 'save', 'vbn_to_vb': 'save', 'vbn_to_vbg': 'saving', 'vbd_eq_vbn': ''},
 'saves': {'func_word': '', 'vbz_to_vb': 'save'},
 'saving': {'func_word': '', 'nn_to_nns': 'savings', 'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'save', 'vbg_to_vbn': 'saved'},
 'savings': {'func_word': '', 'nns_to_nn': 'saving', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'says': {'func_word': '', 'vbz_to_vb': 'say'},
 'seeing': {'func_word': '', 'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'see', 'vbg_to_vbn': 'seen'},
 'self': {'func_word': '', 'nn_to_nns': 'selves', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_jj': 'selfish', 'nn_to_rb': 'selfishly', 'n_is_sth': '2'},
 'selfish': {'func_word': '', 'jj_to_rb': 'selfishly', 'jj_to_nn': 'selfishness'},
 'selfishly': {'func_word': '', 'rb_to_nn': 'selfishness', 'rb_to_jj': 'selfish'},
 'selfishness': {'func_word': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'selfish', 'nn_to_rb': 'selfishly'},
 'selves': {'func_word': '', 'nns_to_nn': 'self'},
 'shall': {'func_word': ''},
 'shan': {'func_word': ''},
 'she': {'func_word': '', 'n_is_sb': '0', 'prp_is_sub_case': '', 'prp_sub_to_obj': 'her'},
 'short_of': {'func_word': ''},
 'should': {'func_word': ''},
 'side_by_side_with': {'func_word': ''},
 'since': {'func_word': ''},
 'so': {'func_word': ''},
 'some': {'func_word': ''},
 'somebody': {'func_word': '', 'n_is_nc': '', 'n_is_sb': '0'},
 'somehow': {'func_word': ''},
 'someone': {'func_word': ''},
 'something': {'func_word': '', 'suffix': 'cd'},
 'sometime': {'func_word': ''},
 'sometimes': {'func_word': ''},
 'somewhere': {'func_word': ''},
 'so_as_to': {'func_word': ''},
 'so_far_from': {'func_word': ''},
 'so_that': {'func_word': ''},
 'such': {'func_word': ''},
 'suchlike': {'func_word': ''},
 'such_as': {'func_word': ''},
 'suppose': {'func_word': '', 'v_compcl': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'suppses', 'vb_to_vbd': 'supposed', 'vb_to_vbn': 'supposed', 'vb_to_rb': 'supposedly', 'vb_to_nn': 'supposition', 'vb_to_jj': 'supposed', 'vb_to_vbg': 'supposing', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'vbg_non': '', 'vt_typical': ''},
 'supposed': {'func_word': '', 'jj_to_rb': 'supposedly', 'jj_to_nn': 'supposition', 'jj_to_vb': 'suppose', 'vbd_to_vb': 'suppose', 'vbn_to_vb': 'suppose', 'vbn_to_vbg': 'supposing', 'jj_ed': '', 'be_jj_to_vb': '', 'vbd_eq_vbn': ''},
 'supposes': {'func_word': ''},
 'supposing': {'func_word': '', 'vbg_to_vb': 'suppose', 'vbg_to_vbn': 'supposed'},
 't': {'func_word': ''},
 'than': {'func_word': ''},
 'thanks_to': {'func_word': ''},
 'that': {'func_word': '', 'jj_to_nn': 'this'},
 'the': {'func_word': ''},
 'thee': {'func_word': ''},
 'their': {'func_word': '', 'prp$_to_prp': 'them'},
 'theirs': {'func_word': '', 'prp_poss': ''},
 'them': {'func_word': '', 'n_is_sb': '0', 'prp_to_prp$': 'their', 'prp_is_obj_case': '', 'prp_obj_to_sub': 'they'},
 'themselves': {'func_word': ''},
 'then': {'func_word': '', 'n_is_nu': '', 'n_is_sth': '', 'confu_pair': 'than'},
 'there': {'func_word': ''},
 'these': {'func_word': '', 'jj_to_nn': 'this'},
 'they': {'func_word': '', 'n_is_sb': '0', 'prp_is_sub_case': '', 'prp_sub_to_obj': 'them'},
 'this': {'func_word': '', 'nn_to_jj': 'those'},
 'those': {'func_word': '', 'jj_to_nn': 'this'},
 'thou': {'func_word': ''},
 'though': {'func_word': ''},
 'through': {'func_word': ''},
 'throughout': {'func_word': ''},
 'through_the_use_of': {'func_word': ''},
 'til': {'func_word': ''},
 'till': {'func_word': '', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'times': {'func_word': '', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'to': {'func_word': ''},
 'too': {'func_word': ''},
 'toward': {'func_word': ''},
 'towards': {'func_word': ''},
 'uncertain': {'func_word': ''},
 'uncertainties': {'func_word': '', 'nns_to_nn': 'uncertainty'},
 'uncertainty': {'func_word': '', 'nn_to_nns': 'uncertainties', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'under': {'func_word': ''},
 'underneath': {'func_word': ''},
 'under_cover_of': {'func_word': ''},
 'under_pain_of': {'func_word': ''},
 'under_penalty_of': {'func_word': ''},
 'under_the_cover_of': {'func_word': ''},
 'unless': {'func_word': ''},
 'unlike': {'func_word': ''},
 'until': {'func_word': ''},
 'unto': {'func_word': ''},
 'unwilling': {'func_word': ''},
 'unwillingly': {'func_word': ''},
 'up': {'func_word': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'upon': {'func_word': ''},
 'upside': {'func_word': '', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'up_and_down': {'func_word': ''},
 'us': {'func_word': '', 'n_is_sb': '0', 'prp_is_obj_case': '', 'prp_obj_to_sub': 'we'},
 'various': {'func_word': '', 'jj_to_rb': 'variously', 'jj_to_nn': 'variance', 'jj_nns': ''},
 'variously': {'func_word': '', 'rb_to_nn': 'variance', 'rb_to_jj': 'various'},
 'versus': {'func_word': ''},
 'very': {'func_word': ''},
 'via': {'func_word': ''},
 'vice': {'func_word': '', 'nn_to_nns': 'vices', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'vis-a-vis': {'func_word': ''},
 'was': {'func_word': ''},
 'we': {'func_word': '', 'n_is_sb': '0', 'prp_is_sub_case': '', 'prp_sub_to_obj': 'us'},
 'were': {'func_word': ''},
 'what': {'func_word': ''},
 'whatever': {'func_word': ''},
 'what_with': {'func_word': ''},
 'when': {'func_word': ''},
 'whenever': {'func_word': ''},
 'whereas': {'func_word': ''},
 'whereupon': {'func_word': ''},
 'whether': {'func_word': ''},
 'which': {'func_word': ''},
 'whichever': {'func_word': ''},
 'while': {'func_word': '', 'nn_to_nns': 'whiles', 'n_is_nc': '', 'n_is_sth': ''},
 'whilst': {'func_word': ''},
 'who': {'func_word': '', 'prp_is_sub_case': ''},
 'whoever': {'func_word': ''},
 'whom': {'func_word': '', 'prp_is_obj_case': ''},
 'whose': {'func_word': ''},
 'will': {'func_word': '', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'willing', 'nn_to_rb': 'willingly', 'v_compcl': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'willing': {'func_word': '', 'jj_to_rb': 'willingly', 'jj_to_nn': 'will', 'be_jj_to_vb': ''},
 'willingly': {'func_word': '', 'rb_to_nn': 'will', 'rb_to_jj': 'willing'},
 'willingness': {'func_word': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'willing', 'nn_to_rb': 'willingly'},
 'with': {'func_word': ''},
 'within': {'func_word': ''},
 'within_reach_of': {'func_word': ''},
 'within_the_reach_of': {'func_word': ''},
 'without': {'func_word': ''},
 'without_regard_to': {'func_word': ''},
 'without_respect_to': {'func_word': ''},
 'with_an_eye_to': {'func_word': ''},
 'with_a_view_to': {'func_word': ''},
 'with_reference_to': {'func_word': ''},
 'with_regards_to': {'func_word': ''},
 'with_regard_to': {'func_word': ''},
 'with_relation_to': {'func_word': ''},
 'with_respect_to': {'func_word': ''},
 'with_the_exception_of': {'func_word': ''},
 'with_the_intention_of': {'func_word': ''},
 'with_the_object_of': {'func_word': ''},
 'with_the_purpose_of': {'func_word': ''},
 'with_the_view_of': {'func_word': ''},
 'worth': {'func_word': '', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'worthy', 'nn_to_rb': 'worthily', 'vb_to_rb': 'worthily', 'vb_to_jj': 'worthy', 'v_vbg': ''},
 'worthless': {'func_word': ''},
 'worthy': {'func_word': '', 'jj_to_rb': 'worthily', 'jj_to_nn': 'worth', 'jj_to_vb': 'worth', 'nn_to_nns': 'worthies', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'jj_to_jjr': 'worthier', 'jj_to_jjs': 'worthiest'},
 'would': {'func_word': ''},
 'ye': {'func_word': ''},
 'yet': {'func_word': ''},
 'yonder': {'func_word': ''},
 'you': {'func_word': '', 'n_is_sb': '0', 'prp_to_prp$': 'your', 'prp_is_obj_case': '', 'prp_is_sub_case': ''},
 'your': {'func_word': '', 'prp$_to_prp': 'you'},
 'yours': {'func_word': '', 'prp_poss': ''},
 'yourself': {'func_word': '', 'n_is_sb': '0'},
 'yourselves': {'func_word': ''},
 'happy': {'jj_to_nn': 'happiness', 'jj_to_rb': 'happily', 'be_jj_to_vb': '', 'jj_to_jjr': 'happier', 'jj_to_jjs': 'happiest'},
 'violent': {'jj_to_nn': 'violence', 'jj_to_rb': 'violently'},
 'strong': {'jj_to_jjr': 'stronger', 'jj_to_rb': 'strongly', 'nn_to_rb': 'strongly', 'jj_to_nn': 'strength', 'jj_to_jjs': 'strongest'},
 'beautiful': {'more_jj': '', 'jj_to_nn': 'beauty', 'jj_to_vb': 'beautify'},
 'abandoned': {'jj_to_rb': 'abandonedly', 'jj_to_nn': 'abandonment', 'jj_to_vb': 'abandon', 'vbd_to_vb': 'abandon', 'vbn_to_vb': 'abandon', 'vbn_to_vbg': 'abandoning', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'able': {'jj_to_rb': 'ably', 'jj_to_nn': 'ability', 'vb_to_rb': 'ably', 'be_jj_to_vb': '', 'suffix': 'vb'},
 'absent': {'jj_to_rb': 'absently', 'jj_to_nn': 'absence', 'vb_to_rb': 'absently', 'vb_to_nn': 'absence', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'absolute': {'jj_to_rb': 'absolutely', 'jj_to_nn': 'absolution', 'vb_to_rb': 'absolutely', 'vb_to_nn': 'absolution'},
 'abstract': {'jj_to_rb': 'abstractly', 'jj_to_nn': 'abstraction', 'nn_to_nns': 'abstracts', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vb_to_rb': 'abstractly', 'vb_to_nn': 'abstraction', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'academic': {'jj_to_rb': 'academically', 'jj_to_nn': 'academy', 'nn_to_nns': 'academics', 'n_is_nc': '', 'art_an': '', 'n_is_sb': '0'},
 'acceptable': {'jj_to_rb': 'acceptably', 'jj_to_nn': 'acceptance', 'jj_to_vb': 'accept'},
 'accessible': {'jj_to_rb': 'accessibly', 'jj_to_nn': 'access', 'jj_to_vb': 'access'},
 'accidental': {'jj_to_rb': 'accidentally', 'jj_to_nn': 'accident'},
 'according': {'jj_to_rb': 'accordingly', 'jj_to_nn': 'accordance', 'jj_to_vb': 'accord'},
 'accurate': {'jj_to_rb': 'accurately', 'jj_to_nn': 'accuracy'},
 'active': {'jj_to_rb': 'actively', 'jj_to_nn': 'activity', 'jj_to_vb': 'activate', 'art_an': '', 'n_is_sb': '0'},
 'actual': {'jj_to_rb': 'actually', 'jj_to_nn': 'actuality', 'jj_to_vb': 'actualize'},
 'adequate': {'jj_to_rb': 'adequately', 'jj_to_nn': 'adequacy', 'vb_to_rb': 'adequately', 'vb_to_nn': 'adequacy'},
 'adjacent': {'jj_to_rb': 'adjacently', 'jj_to_nn': 'adjacence', 'vb_to_rb': 'adjacently', 'vb_to_nn': 'adjacence', 'be_jj_to_vbg': ''},
 'adjusted': {'jj_to_rb': 'adjustable', 'jj_to_nn': 'adjustment', 'jj_to_vb': 'adjust', 'vbd_to_vb': 'adjust', 'vbn_to_vb': 'adjust', 'vbn_to_vbg': 'adjusting', 'be_jj_to_vbg': '', 'vbd_eq_vbn': ''},
 'allowable': {'jj_to_rb': 'allowably', 'jj_to_nn': 'allowance', 'jj_to_vb': 'allow'},
 'alterable': {'jj_to_rb': 'alterably', 'jj_to_nn': 'alteration', 'jj_to_vb': 'alter'},
 'annual': {'jj_to_rb': 'annually', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_rb': 'annually'},
 'anticipative': {'jj_to_rb': 'anticipatively', 'jj_to_nn': 'anticipation', 'jj_to_vb': 'anticipate'},
 'anxious': {'jj_to_rb': 'anxiously', 'jj_to_nn': 'anxiety'},
 'apologetical': {'jj_to_rb': 'apologetically', 'jj_to_nn': 'apology', 'jj_to_vb': 'apologize'},
 'applicable': {'jj_to_rb': 'applicably', 'jj_to_nn': 'application', 'jj_to_vb': 'apply'},
 'appreciable': {'jj_to_rb': 'appreciably', 'jj_to_nn': 'appreciation', 'jj_to_vb': 'appreciate'},
 'approachable': {'jj_to_rb': 'approachably', 'jj_to_nn': 'approach', 'jj_to_vb': 'approach'},
 'appropriate': {'jj_to_rb': 'appropriately', 'jj_to_nn': 'appropriateness', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'v_to': '', 'vb_to_vbz': 'appropriates', 'vb_to_vbd': 'appropriated', 'vb_to_vbn': 'appropriated', 'vb_to_rb': 'appropriately', 'vb_to_nn': 'appropriateness', 'vb_to_vbg': 'appropriating', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'approximate': {'jj_to_rb': 'approximately', 'jj_to_nn': 'approximation', 'v_to_vbg': '', 'v_to_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'approximates', 'vb_to_vbd': 'approximated', 'vb_to_vbn': 'approximated', 'vb_to_rb': 'approximately', 'vb_to_nn': 'approximation', 'vb_to_vbg': 'approximating', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'arbitrary': {'jj_to_rb': 'arbitrarily', 'jj_to_nn': 'arbitrariness', 'jj_to_vb': 'arbitrate'},
 'arch': {'jj_to_rb': 'archly', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_rb': 'archly', 'vb_to_rb': 'archly', 'vbd_eq_vbn': ''},
 'arched': {'jj_to_rb': 'archly', 'jj_to_nn': 'arch', 'jj_to_vb': 'arch', 'vbd_eq_vbn': ''},
 'attentive': {'jj_to_rb': 'attentively', 'jj_to_nn': 'attention'},
 'attractive': {'jj_to_rb': 'attractively', 'jj_to_nn': 'attraction', 'jj_to_vb': 'attract'},
 'awkward': {'jj_to_rb': 'awkwardly', 'jj_to_nn': 'awkwardness'},
 'bad': {'jj_to_rb': 'badly', 'jj_to_nn': 'badness', 'nn_to_nns': 'bads', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'badly', 'jj_to_jjr': 'worse', 'jj_to_jjs': 'worst', 'rb_to_rbr': 'worse', 'rb_to_rbs': 'worst'},
 'biased': {'jj_to_rb': 'bias', 'jj_to_nn': 'bias', 'jj_to_vb': 'bias', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'bitter': {'jj_to_rb': 'bitterly', 'jj_to_nn': 'bitterness', 'nn_to_nns': 'bitters', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'bitterly', 'vb_to_rb': 'bitterly', 'vb_to_nn': 'bitterness', 'be_jj_to_vb': '', 'jj_to_jjs': 'bitterest'},
 'black': {'jj_to_rb': 'blackly', 'jj_to_nn': 'blackness', 'nn_to_nns': 'blacks', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_rb': 'blackly', 'vb_to_rb': 'blackly', 'vb_to_nn': 'blackness', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'n_is_sth': '2', 'jj_to_jjr': 'blacker', 'jj_to_jjs': 'blackest'},
 'bloody': {'jj_to_rb': 'bloodily', 'jj_to_nn': 'blood', 'jj_to_vb': 'blood', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'jj_to_jjr': 'bloodier', 'jj_to_jjs': 'bloodiest'},
 'bold': {'jj_to_rb': 'boldly', 'jj_to_nn': 'boldness', 'nn_to_rb': 'boldly', 'jj_to_jjr': 'bolder', 'jj_to_jjs': 'boldest'},
 'brave': {'jj_to_rb': 'bravely', 'jj_to_nn': 'bravery', 'nn_to_nns': 'braves', 'n_is_nc': '', 'n_is_sb': '0', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'braves', 'vb_to_vbd': 'braved', 'vb_to_vbn': 'braved', 'vb_to_rb': 'bravely', 'vb_to_nn': 'bravery', 'vb_to_vbg': 'braving', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'jj_to_jjr': 'braver', 'jj_to_jjs': 'bravest'},
 'bright': {'jj_to_rb': 'brightly', 'jj_to_nn': 'brightness', 'jj_to_vb': 'brighten', 'nn_to_vb': 'brighten', 'nn_to_rb': 'brightly', 'jj_to_jjr': 'brighter', 'jj_to_jjs': 'brightest'},
 'bulky': {'jj_to_rb': 'bulkily', 'jj_to_nn': 'bulk', 'jj_to_vb': 'bulk'},
 'bush': {'jj_to_rb': 'bushily', 'nn_to_nns': 'bushes', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_rb': 'bushily', 'vb_to_rb': 'bushily', 'vbg_non': '', 'v_pass_non': ''},
 'bushy': {'jj_to_rb': 'bushily', 'jj_to_nn': 'bush', 'jj_to_vb': 'bush', 'jj_to_jjr': 'bushier', 'jj_to_jjs': 'bushiest'},
 'capable': {'jj_to_rb': 'capably', 'jj_to_nn': 'capacity', 'jj_to_vb': 'capacitate'},
 'careful': {'jj_to_rb': 'carefully', 'jj_to_nn': 'care', 'jj_to_vb': 'care', 'be_jj_to_vb': ''},
 'cautious': {'jj_to_rb': 'cautiously', 'jj_to_nn': 'caution', 'jj_to_vb': 'caution'},
 'center': {'jj_to_rb': 'centrally', 'jj_to_nn': 'centre', 'jj_to_vb': 'centre', 'nn_to_nns': 'centers', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': ''},
 'central': {'jj_to_rb': 'centrally', 'jj_to_nn': 'centre', 'jj_to_vb': 'centre', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'centre', 'nn_to_jj': 'center', 'nn_to_rb': 'centrally', 'be_jj_to_vbg': ''},
 'ceremonial': {'jj_to_rb': 'ceremonially', 'jj_to_nn': 'ceremony', 'nn_to_rb': 'ceremonially'},
 'changeable': {'jj_to_rb': 'changeably', 'jj_to_nn': 'change', 'jj_to_vb': 'change'},
 'cheap': {'jj_to_rb': 'cheaply', 'jj_to_nn': 'cheapness', 'jj_to_jjr': 'cheaper', 'jj_to_jjs': 'cheapest'},
 'chemical': {'jj_to_rb': 'chemically', 'nn_to_nns': 'chemicals', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'chemically'},
 'chief': {'jj_to_rb': 'chiefly', 'nn_to_nns': 'chiefs', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_rb': 'chiefly', 'nc_typical': ''},
 'childish': {'jj_to_rb': 'childishly', 'jj_to_nn': 'child'},
 'choice': {'jj_to_rb': 'choicely', 'jj_to_vb': 'choose', 'nn_to_nns': 'choices', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'choose', 'nn_to_rb': 'choicely'},
 'chosen': {'jj_to_rb': 'choicely', 'jj_to_nn': 'choice', 'jj_to_vb': 'choose', 'n_is_sb': '0', 'vbn_to_vb': 'choose', 'vbn_to_vbd': 'chose', 'vbn_to_vbg': 'choosing'},
 'circular': {'jj_to_rb': 'circularly', 'jj_to_nn': 'circle', 'jj_to_vb': 'circle', 'n_is_nc': '', 'n_is_sth': ''},
 'civil': {'jj_to_rb': 'civilly', 'jj_to_nn': 'civilian'},
 'civilian': {'jj_to_rb': 'civilly', 'nn_to_nns': 'civilians', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'civil', 'nn_to_rb': 'civilly', 'nc_typical': ''},
 'clean': {'jj_to_rb': 'cleanly', 'jj_to_nn': 'cleaness', 'nn_to_rb': 'cleanly', 'v_n': '', 'nsubjpass': '', 'v_with': '', 'v_of': '', 'vb_to_rb': 'cleanly', 'vb_to_nn': 'cleaness', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'jj_to_jjr': 'cleaner', 'jj_to_jjs': 'cleanest'},
 'cleared': {'jj_to_rb': 'clear', 'jj_to_nn': 'clearness', 'jj_to_vb': 'clear', 'vbd_to_vb': 'clear', 'vbn_to_vb': 'clear', 'vbn_to_vbg': 'clearing', 'vbd_eq_vbn': ''},
 'clever': {'jj_to_rb': 'cleverly', 'jj_to_nn': 'cleverness'},
 'coarse': {'jj_to_rb': 'coarsely', 'jj_to_nn': 'coarseness'},
 'coherent': {'jj_to_rb': 'coherently', 'jj_to_nn': 'coherence'},
 'cold': {'jj_to_rb': 'coldly', 'jj_to_nn': 'coldness', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'coldly', 'rb_to_nn': 'coldness', 'jj_to_jjr': 'colder', 'jj_to_jjs': 'coldest'},
 'comfortable': {'jj_to_rb': 'comfortably', 'jj_to_nn': 'comfort', 'jj_to_vb': 'comfort', 'nn_to_nns': 'comfortables', 'n_is_nc': '', 'be_jj_to_vb': ''},
 'commercial': {'jj_to_rb': 'commercially', 'jj_to_nn': 'commerce', 'nn_to_nns': 'commercials', 'n_is_nc': '', 'n_is_sth': ''},
 'common': {'jj_to_rb': 'commonly', 'jj_to_nn': 'commonness', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_rb': 'commonly', 'jj_to_jjr': 'commoner', 'jj_to_jjs': 'commonest'},
 'complete': {'jj_to_rb': 'completely', 'jj_to_nn': 'completion', 'v_vbg': '', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_about': '', 'v_of': '', 'v_to': '', 'vb_to_vbz': 'completes', 'vb_to_vbd': 'completed', 'vb_to_vbn': 'completed', 'vb_to_rb': 'completely', 'vb_to_nn': 'completion', 'vb_to_vbg': 'completing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'complex': {'jj_to_rb': 'complexly', 'jj_to_nn': 'complexity', 'nn_to_nns': 'complexes', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'complexly', 'nc_typical': ''},
 'confident': {'jj_to_rb': 'confidently', 'jj_to_nn': 'confidence'},
 'conscientious': {'jj_to_rb': 'conscientiously', 'jj_to_nn': 'conscience'},
 'conscious': {'jj_to_rb': 'consciously', 'jj_to_nn': 'consciousness'},
 'consequent': {'jj_to_rb': 'consequently', 'jj_to_nn': 'consequence'},
 'constant': {'jj_to_rb': 'constantly', 'jj_to_nn': 'constancy', 'nn_to_nns': 'constants', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'constantly'},
 'contrary': {'jj_to_rb': 'contrarily', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_rb': 'contrarily', 'be_jj_to_vbg': '', 'n_is_nc': ''},
 'convenient': {'jj_to_rb': 'conveniently', 'jj_to_nn': 'convenience'},
 'cool': {'jj_to_rb': 'coolly', 'jj_to_nn': 'coolness', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_rb': 'coolly', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'cools', 'vb_to_vbd': 'cooled', 'vb_to_vbn': 'cooled', 'vb_to_rb': 'coolly', 'vb_to_nn': 'coolness', 'vb_to_vbg': 'cooling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'jj_to_jjr': 'cooler', 'jj_to_jjs': 'coolest'},
 'coward': {'jj_to_rb': 'cowardly', 'jj_to_nn': 'cowardice', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_rb': 'cowardly'},
 'crack': {'jj_to_rb': 'cracking', 'nn_to_nns': 'cracks', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'cracking', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'vb_to_vbz': 'cracks', 'vb_to_vbd': 'cracked', 'vb_to_vbn': 'cracked', 'vb_to_rb': 'cracking', 'vb_to_vbg': 'cracking', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'creative': {'jj_to_rb': 'creatively', 'jj_to_nn': 'creation', 'jj_to_vb': 'create'},
 'criminal': {'jj_to_rb': 'criminally', 'jj_to_nn': 'crime', 'jj_to_vb': 'crime', 'nn_to_nns': 'criminals', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'crime', 'nn_to_rb': 'criminally', 'nc_typical': ''},
 'critical': {'jj_to_rb': 'critically', 'jj_to_nn': 'critic'},
 'cross': {'jj_to_rb': 'crossly', 'n_is_sb': '0', 'nn_to_rb': 'crossly', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'crosses', 'vb_to_vbd': 'crossed', 'vb_to_vbn': 'crossed', 'vb_to_rb': 'crossly', 'vb_to_vbg': 'crossing', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'crossed': {'jj_to_rb': 'crossly', 'jj_to_nn': 'cross', 'jj_to_vb': 'cross', 'vbd_to_vb': 'cross', 'vbn_to_vb': 'cross', 'vbn_to_vbg': 'crossing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'cruel': {'jj_to_rb': 'cruelly', 'jj_to_nn': 'cruelty', 'jj_to_jjr': 'crueller', 'jj_to_jjs': 'cruellest'},
 'curious': {'jj_to_rb': 'curiously', 'jj_to_nn': 'curiosity', 'be_jj_to_vb': ''},
 'current': {'jj_to_rb': 'currently', 'jj_to_nn': 'currency', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_rb': 'currently'},
 'dangerous': {'jj_to_rb': 'dangerously', 'jj_to_nn': 'danger', 'be_jj_to_vbg': '', 'be_jj_to_vb': ''},
 'dark': {'jj_to_rb': 'darkly', 'jj_to_nn': 'darkness', 'n_is_nu': '', 'n_is_sth': '', 'jj_to_jjr': 'darker', 'jj_to_jjs': 'darkest'},
 'daily': {'jj_to_rb': 'day', 'jj_to_nn': 'day', 'nn_to_nns': 'dailies', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'day', 'nn_to_rb': 'day', 'rb_to_nn': 'day', 'rb_to_jj': 'day', 'nc_typical': ''},
 'dead': {'jj_to_rb': 'deadly', 'jj_to_nn': 'death', 'jj_to_vb': 'die', 'n_is_nu': '', 'n_is_sb': '2', 'nn_to_vb': 'die', 'nn_to_rb': 'deadly', 'confu_pair': 'death', 'n_is_sth': '2'},
 'deaf': {'jj_to_rb': 'deafly', 'jj_to_nn': 'deafness'},
 'deep': {'jj_to_rb': 'deeply', 'jj_to_vb': 'deepen', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'deepen', 'nn_to_rb': 'deeply', 'jj_to_jjr': 'deeper', 'jj_to_jjs': 'deepest', 'rb_to_rbr': 'deeper', 'rb_to_rbs': 'deepest'},
 'definite': {'jj_to_rb': 'definitely', 'jj_to_nn': 'definitiveness'},
 'delicate': {'jj_to_rb': 'delicately', 'jj_to_nn': 'delicacy'},
 'difficult': {'jj_to_rb': 'difficultly', 'jj_to_nn': 'difficulty', 'be_jj_to_vb': ''},
 'dimensional': {'jj_to_rb': 'dimensionally', 'jj_to_nn': 'dimension'},
 'dimension': {'jj_to_rb': 'dimensionally', 'nn_to_nns': 'dimensions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'dimensional', 'nn_to_rb': 'dimensionally'},
 'discrete': {'jj_to_rb': 'discretely', 'jj_to_nn': 'discretion', 'nn_to_rb': 'discretely'},
 'diverse': {'jj_to_rb': 'diversely', 'jj_to_nn': 'diversity', 'jj_to_vb': 'diversify'},
 'domestic': {'jj_to_rb': 'domestically', 'nn_to_nns': 'domestics', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_rb': 'domestically', 'n_is_sth': '2'},
 'doubtful': {'jj_to_rb': 'doubtfully', 'jj_to_nn': 'doubt', 'jj_to_vb': 'doubt'},
 'dramatic': {'jj_to_rb': 'dramatically', 'jj_to_nn': 'drama', 'jj_to_vb': 'dramatize'},
 'dream': {'jj_to_rb': 'dreamily', 'nn_to_nns': 'dreams', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'dreamily', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_about': '', 'v_of': '', 'vb_to_vbz': 'dreams', 'vb_to_vbd': 'dreamed,dreamt', 'vb_to_vbn': 'dreamed,dreamt', 'vb_to_rb': 'dreamily', 'vb_to_vbg': 'dreaming', 'vbd_eq_vbn': ''},
 'dreamy': {'jj_to_rb': 'dreamily', 'jj_to_nn': 'dream', 'jj_to_vb': 'dream', 'jj_to_jjr': 'dreamier', 'jj_to_jjs': 'dreamiest'},
 'dry': {'jj_to_rb': 'drily', 'jj_to_nn': 'dryness', 'nn_to_nns': 'drys', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_rb': 'drily', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'dries', 'vb_to_vbd': 'dried', 'vb_to_vbn': 'dried', 'vb_to_rb': 'drily', 'vb_to_nn': 'dryness', 'vb_to_vbg': 'drying', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'jj_to_jjr': 'drier', 'jj_to_jjs': 'driest'},
 'dull': {'jj_to_rb': 'dully', 'jj_to_nn': 'dullness', 'nn_to_rb': 'dully', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'dulls', 'vb_to_vbd': 'dulled', 'vb_to_vbn': 'dulled', 'vb_to_rb': 'dully', 'vb_to_nn': 'dullness', 'vb_to_vbg': 'dulling', 'vbd_eq_vbn': '', 'jj_to_jjr': 'duller', 'jj_to_jjs': 'dullest'},
 'dynamic': {'jj_to_rb': 'dynamically', 'nn_to_nns': 'dynamics', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'dynamically'},
 'eager': {'jj_to_rb': 'eagerly', 'jj_to_nn': 'eagerness', 'art_an': '', 'nn_to_rb': 'eagerly', 'be_jj_to_vb': ''},
 'earnest': {'jj_to_rb': 'earnestly', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_rb': 'earnestly'},
 'economic': {'jj_to_rb': 'economically', 'jj_to_nn': 'economy'},
 'efficient': {'jj_to_rb': 'efficiently', 'jj_to_nn': 'efficiency'},
 'elastic': {'jj_to_rb': 'elastically', 'jj_to_nn': 'elasticity', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_rb': 'elastically'},
 'electric': {'jj_to_rb': 'electrically', 'jj_to_nn': 'electricity', 'art_an': '', 'nn_to_rb': 'electrically'},
 'empirical': {'jj_to_rb': 'empirically', 'jj_to_nn': 'empiricism'},
 'empty': {'jj_to_rb': 'emptily', 'art_an': '', 'nn_to_rb': 'emptily', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'empties', 'vb_to_vbd': 'emptied', 'vb_to_vbn': 'emptied', 'vb_to_rb': 'emptily', 'vb_to_vbg': 'emptying', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'jj_to_jjr': 'emptier', 'jj_to_jjs': 'emptiest'},
 'emptied': {'jj_to_rb': 'emptily', 'jj_to_nn': 'empty', 'jj_to_vb': 'empty', 'vbd_to_vb': 'empty', 'vbn_to_vb': 'empty', 'vbn_to_vbg': 'emptying', 'vbd_eq_vbn': ''},
 'energetic': {'jj_to_rb': 'energetically', 'jj_to_nn': 'energy'},
 'enormous': {'jj_to_rb': 'enormously', 'jj_to_nn': 'enormity'},
 'environmental': {'jj_to_rb': 'environmentally', 'jj_to_nn': 'environment'},
 'equivalent': {'jj_to_rb': 'equivalently', 'jj_to_nn': 'equivalence', 'nn_to_nns': 'equivalents', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_rb': 'equivalently', 'be_jj_to_vbg': ''},
 'erroneous': {'jj_to_rb': 'erroneously', 'jj_to_nn': 'error'},
 'essential': {'jj_to_rb': 'essentially', 'jj_to_nn': 'essence', 'nn_to_nns': 'essentials', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_rb': 'essentially', 'be_jj_to_vbg': '', 'be_jj_to_vb': ''},
 'ethical': {'jj_to_rb': 'ethically', 'jj_to_nn': 'ethic', 'nn_to_rb': 'ethically'},
 'ethic': {'jj_to_rb': 'ethically', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'ethical', 'nn_to_rb': 'ethically'},
 'ethnic': {'jj_to_rb': 'ethnically', 'jj_to_nn': 'ethnicity'},
 'eventual': {'jj_to_rb': 'eventually', 'jj_to_nn': 'eventuality'},
 'excellent': {'jj_to_rb': 'excellently', 'jj_to_nn': 'excellence', 'jj_to_vb': 'excel'},
 'excessive': {'jj_to_rb': 'excessively', 'jj_to_nn': 'excess'},
 'excess': {'jj_to_rb': 'excessively', 'nn_to_nns': 'excesses', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'excessive', 'nn_to_rb': 'excessively'},
 'explosive': {'jj_to_rb': 'explosively', 'jj_to_nn': 'explosion', 'jj_to_vb': 'explode', 'nn_to_nns': 'explosives', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'explode', 'nn_to_rb': 'explosively'},
 'express': {'jj_to_rb': 'expressively', 'jj_to_nn': 'expression', 'nn_to_nns': 'expresses', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_rb': 'expressively', 'v_compcl': '', 'v_to_n': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'expresses', 'vb_to_vbd': 'expressed', 'vb_to_vbn': 'expressed', 'vb_to_rb': 'expressively', 'vb_to_nn': 'expression', 'vb_to_vbg': 'expressing', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vt_typical': ''},
 'expressive': {'jj_to_rb': 'expressively', 'jj_to_nn': 'expression', 'jj_to_vb': 'express'},
 'extensive': {'jj_to_rb': 'extensively', 'jj_to_nn': 'extension', 'jj_to_vb': 'extend'},
 'external': {'jj_to_rb': 'externally', 'jj_to_nn': 'externality', 'jj_to_vb': 'externalise', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'externalise', 'nn_to_rb': 'externally'},
 'extreme': {'jj_to_rb': 'extremely', 'nn_to_nns': 'extremes', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_rb': 'extremely'},
 'factual': {'jj_to_rb': 'factually', 'jj_to_nn': 'fact'},
 'faint': {'jj_to_rb': 'faintly', 'jj_to_nn': 'faintness', 'n_is_nc': '', 'n_is_sth': '', 'vb_to_rb': 'faintly', 'vb_to_nn': 'faintness', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': '', 'jj_to_jjr': 'fainter', 'jj_to_jjs': 'faintest'},
 'faithful': {'jj_to_rb': 'faithfully', 'jj_to_nn': 'faith', 'n_is_nc': '', 'n_is_sth': ''},
 'FALSE': {'jj_to_rb': 'falsely', 'jj_to_nn': 'falsehood', 'rb_to_nn': 'falsehood'},
 'familiar': {'jj_to_rb': 'familiarly', 'jj_to_nn': 'familiarity', 'nn_to_nns': 'familiars', 'n_is_nc': '', 'n_is_sb': '0'},
 'fancy': {'jj_to_rb': 'fancily', 'jj_to_nn': 'fanciness', 'nn_to_nns': 'fancies', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'fancily', 'v_compcl': '', 'v_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'fancies', 'vb_to_vbd': 'fancied', 'vb_to_vbn': 'fancied', 'vb_to_rb': 'fancily', 'vb_to_nn': 'fanciness', 'vb_to_vbg': 'fancying', 'vbd_eq_vbn': '', 'v_whcl_non': '', 'vbg_non': '', 'jj_to_jjr': 'fancier', 'jj_to_jjs': 'fanciest'},
 'fancied': {'jj_to_rb': 'fancily', 'jj_to_nn': 'fanciness', 'jj_to_vb': 'fancy', 'vbd_to_vb': 'fancy', 'vbn_to_vb': 'fancy', 'vbn_to_vbg': 'fancying', 'vbd_eq_vbn': ''},
 'fat': {'jj_to_rb': 'fatly', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_rb': 'fatly', 'vb_to_rb': 'fatly', 'jj_to_jjr': 'fatter', 'jj_to_jjs': 'fattest'},
 'fatty': {'jj_to_rb': 'fatly', 'jj_to_nn': 'fat', 'jj_to_vb': 'fat', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'fat', 'nn_to_jj': 'fat', 'nn_to_rb': 'fatly'},
 'faulty': {'jj_to_rb': 'faultily', 'jj_to_nn': 'fault', 'jj_to_vb': 'fault', 'jj_to_jjr': 'faultier', 'jj_to_jjs': 'faultiest'},
 'favourable': {'jj_to_rb': 'favourably', 'jj_to_nn': 'favour', 'jj_to_vb': 'favour', 'nn_to_vb': 'favour', 'nn_to_rb': 'favourably'},
 'federal': {'jj_to_rb': 'federally', 'jj_to_nn': 'federation', 'n_is_sb': '0', 'nn_to_rb': 'federally'},
 'fierce': {'jj_to_rb': 'fiercely', 'jj_to_nn': 'fierceness', 'jj_to_jjr': 'fiercer', 'jj_to_jjs': 'fiercest'},
 'final': {'jj_to_rb': 'finally', 'jj_to_vb': 'finalise', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'finalise', 'nn_to_rb': 'finally'},
 'fine': {'jj_to_rb': 'finely', 'jj_to_nn': 'fineness', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'finely', 'v_n': '', 'nsubjpass': '', 'v_for': '', 'vb_to_rb': 'finely', 'vb_to_nn': 'fineness', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': '', 'jj_to_jjr': 'finer', 'jj_to_jjs': 'finest'},
 'first': {'jj_to_rb': 'firstly', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'firstly'},
 'flexible': {'jj_to_rb': 'flexibly', 'jj_to_nn': 'flexibility'},
 'fond': {'jj_to_rb': 'fondly', 'jj_to_nn': 'fondness', 'nn_to_rb': 'fondly', 'jj_to_jjr': 'fonder', 'jj_to_jjs': 'fondest'},
 'formal': {'jj_to_rb': 'formally', 'jj_to_nn': 'formality', 'nn_to_rb': 'formally'},
 'former': {'jj_to_rb': 'formerly', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_rb': 'formerly', 'n_is_sth': '2'},
 'foundational': {'jj_to_rb': 'foundationally', 'jj_to_nn': 'foundation'},
 'fresh': {'jj_to_rb': 'freshly', 'jj_to_nn': 'freshness', 'nn_to_rb': 'freshly', 'rb_to_nn': 'freshness', 'jj_to_jjr': 'fresher', 'jj_to_jjs': 'freshest'},
 'fundamental': {'jj_to_rb': 'fundamentally', 'nn_to_nns': 'fundamentals', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'fundamentally', 'be_jj_to_vbg': ''},
 'funeral': {'jj_to_rb': 'funerally', 'nn_to_nns': 'funerals', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'funerally', 'nc_typical': ''},
 'generous': {'jj_to_rb': 'generously', 'jj_to_nn': 'generosity'},
 'gentle': {'jj_to_rb': 'gently', 'nn_to_rb': 'gently', 'vb_to_rb': 'gently', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'jj_to_jjr': 'gentler', 'jj_to_jjs': 'gentlest'},
 'global': {'jj_to_rb': 'globally', 'jj_to_nn': 'globe', 'jj_to_vb': 'globe'},
 'golden': {'jj_to_rb': 'goldenly', 'jj_to_nn': 'gold', 'nn_to_rb': 'goldenly'},
 'gold': {'jj_to_rb': 'goldenly', 'nn_to_nns': 'golds', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'golden', 'nn_to_rb': 'goldenly'},
 'gradual': {'jj_to_rb': 'gradually', 'nn_to_rb': 'gradually'},
 'grand': {'jj_to_rb': 'grandly', 'nn_to_nns': 'grands', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'grandly', 'jj_to_jjr': 'grander', 'jj_to_jjs': 'grandest'},
 'grateful': {'jj_to_rb': 'gratefully', 'jj_to_nn': 'gratefulness', 'be_jj_to_vb': ''},
 'grave': {'jj_to_rb': 'gravely', 'nn_to_nns': 'graves', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'gravely', 'vb_to_rb': 'gravely', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'jj_to_jjr': 'graver', 'jj_to_jjs': 'gravest'},
 'great': {'jj_to_rb': 'greatly', 'jj_to_nn': 'greatness', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'greatly', 'jj_to_jjr': 'greater', 'jj_to_jjs': 'greatest'},
 'greedy': {'jj_to_rb': 'greedily', 'jj_to_nn': 'greed', 'jj_to_jjr': 'greedier', 'jj_to_jjs': 'greediest'},
 'guilty': {'jj_to_rb': 'guiltily', 'jj_to_nn': 'guilt', 'jj_to_jjr': 'guiltier', 'jj_to_jjs': 'guiltiest'},
 'hair': {'jj_to_rb': 'hairily', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_rb': 'hairily', 'vb_to_rb': 'hairily'},
 'hairy': {'jj_to_rb': 'hairily', 'jj_to_nn': 'hair', 'jj_to_vb': 'hair', 'jj_to_jjr': 'hairier', 'jj_to_jjs': 'hairiest'},
 'hasty': {'jj_to_rb': 'hastily', 'jj_to_nn': 'haste', 'jj_to_vb': 'haste', 'nn_to_vb': 'haste', 'nn_to_rb': 'hastily', 'jj_to_jjr': 'hastier', 'jj_to_jjs': 'hastiest'},
 'high': {'jj_to_rb': 'highly', 'jj_to_nn': 'highness', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'highly', 'rb_to_nn': 'highness', 'jj_to_jjr': 'higher', 'jj_to_jjs': 'highest'},
 'historic': {'jj_to_rb': 'historically', 'jj_to_nn': 'history'},
 'honest': {'jj_to_rb': 'honestly', 'jj_to_nn': 'honesty'},
 'hopeful': {'jj_to_rb': 'hopefully', 'jj_to_nn': 'hope', 'jj_to_vb': 'hope', 'n_is_sb': '0'},
 'hungry': {'jj_to_rb': 'hungrily', 'jj_to_nn': 'hunger', 'jj_to_vb': 'hunger', 'jj_to_jjr': 'hungrier', 'jj_to_jjs': 'hungriest'},
 'hurried': {'jj_to_rb': 'hurriedly', 'jj_to_nn': 'hurry', 'jj_to_vb': 'hurry', 'vbd_to_vb': 'hurry', 'vbn_to_vb': 'hurry', 'vbn_to_vbg': 'hurrying', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'ice': {'jj_to_rb': 'icily', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_rb': 'icily', 'vb_to_rb': 'icily', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'icy': {'jj_to_rb': 'icily', 'jj_to_nn': 'ice', 'jj_to_vb': 'ice', 'jj_to_jjr': 'icier', 'jj_to_jjs': 'iciest'},
 'ideal': {'jj_to_rb': 'ideally', 'nn_to_nns': 'ideals', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2', 'nn_to_rb': 'ideally'},
 'identical': {'jj_to_rb': 'identically', 'nn_to_rb': 'identically'},
 'ideological': {'jj_to_rb': 'ideologically', 'jj_to_nn': 'ideology'},
 'ill': {'jj_to_rb': 'illy', 'jj_to_nn': 'illness', 'nn_to_nns': 'ills', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_rb': 'illy', 'rb_to_nn': 'illness'},
 'immediate': {'jj_to_rb': 'immediately', 'jj_to_nn': 'immediacy'},
 'immense': {'jj_to_rb': 'immensely', 'jj_to_nn': 'immenseness'},
 'implicit': {'jj_to_rb': 'implicitly', 'jj_to_nn': 'implicity'},
 'important': {'jj_to_rb': 'importantly', 'jj_to_nn': 'importance', 'be_jj_to_vb': ''},
 'incident': {'jj_to_rb': 'incidentally', 'jj_to_nn': 'incidence', 'nn_to_nns': 'incidents', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_rb': 'incidentally', 'nc_typical': ''},
 'increasing': {'jj_to_rb': 'increasingly', 'jj_to_nn': 'increase', 'jj_to_vb': 'increase', 'vbg_to_vb': 'increase', 'vbg_to_vbn': 'increased'},
 'independent': {'jj_to_rb': 'independently', 'jj_to_nn': 'independence', 'nn_to_nns': 'independents', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nn_to_rb': 'independently'},
 'industrial': {'jj_to_rb': 'industrially', 'jj_to_nn': 'industry', 'nn_to_rb': 'industrially'},
 'inevitable': {'jj_to_rb': 'inevitably', 'jj_to_nn': 'inevitability'},
 'inherent': {'jj_to_rb': 'inherently', 'jj_to_nn': 'inherence'},
 'instant': {'jj_to_rb': 'instantly', 'jj_to_nn': 'instance', 'nn_to_nns': 'instants', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_rb': 'instantly'},
 'instrumental': {'jj_to_rb': 'instrumentally', 'jj_to_nn': 'instrument', 'nn_to_rb': 'instrumentally'},
 'integral': {'jj_to_rb': 'integrally', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_rb': 'integrally'},
 'intelligent': {'jj_to_rb': 'intelligently', 'jj_to_nn': 'intelligence'},
 'intense': {'jj_to_rb': 'intensely', 'jj_to_nn': 'intensity', 'jj_to_vb': 'intensify', 'jj_to_jjr': 'intenser', 'jj_to_jjs': 'intensest'},
 'internal': {'jj_to_rb': 'internally', 'jj_to_vb': 'internalize'},
 'inward': {'jj_to_rb': 'inwardly', 'nn_to_rb': 'inwardly'},
 'jealous': {'jj_to_rb': 'jealously', 'jj_to_nn': 'jealousy'},
 'jointed': {'jj_to_rb': 'jointly', 'jj_to_nn': 'joint', 'jj_to_vb': 'joint', 'vbd_to_vb': 'joint', 'vbn_to_vb': 'joint', 'vbn_to_vbg': 'jointing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'joint': {'jj_to_rb': 'jointly', 'jj_to_nn': 'join', 'jj_to_vb': 'join', 'nn_to_nns': 'joints', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'join', 'nn_to_rb': 'jointly', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'joints', 'vb_to_vbd': 'jointed', 'vb_to_vbn': 'jointed', 'vb_to_rb': 'jointly', 'vb_to_nn': 'join', 'vb_to_vbg': 'jointing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'juicy': {'jj_to_rb': 'juicily', 'jj_to_nn': 'juice', 'jj_to_jjr': 'juicier', 'jj_to_jjs': 'juiciest'},
 'kind': {'jj_to_rb': 'kindly', 'jj_to_nn': 'kindness', 'nn_to_nns': 'kinds', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'kindly', 'n_is_nu': '', 'n_of_nn': '', 'n_of_nns': '', 'jj_to_jjr': 'kinder', 'jj_to_jjs': 'kindest'},
 'lasting': {'jj_to_rb': 'last', 'jj_to_nn': 'last', 'jj_to_vb': 'last', 'nn_to_vb': 'last', 'nn_to_jj': 'last', 'nn_to_rb': 'last', 'vbg_to_vb': 'last', 'vbg_to_vbn': 'lasted'},
 'late': {'jj_to_rb': 'lately', 'jj_to_nn': 'lateness', 'jj_to_jjr': 'later', 'jj_to_jjs': 'latest', 'rb_to_rbr': 'later', 'rb_to_rbs': 'latest'},
 'lazy': {'jj_to_rb': 'lazily', 'jj_to_nn': 'laziness', 'nn_to_rb': 'lazily', 'jj_to_vb': 'laze', 'jj_to_jjr': 'lazier', 'jj_to_jjs': 'laziest'},
 'legal': {'jj_to_rb': 'legally', 'jj_to_nn': 'legality', 'nn_to_rb': 'legally'},
 'literary': {'jj_to_rb': 'literarily', 'jj_to_nn': 'literature'},
 'living': {'jj_to_rb': 'lively', 'jj_to_vb': 'live', 'nn_to_nns': 'livings', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'live', 'nn_to_rb': 'lively', 'vbg_to_vb': 'live', 'vbg_to_vbn': 'lived'},
 'live': {'jj_to_rb': 'lively', 'jj_to_nn': 'living', 'nn_to_jj': 'living', 'nn_to_rb': 'lively', 'v_to_vb': '', 'v_to_vbg': '', 'vdo': '', 'v_on': '', 'v_in': '', 'v_with': '', 'v_for': '', 'vb_to_vbz': 'lives', 'vb_to_vbd': 'lived', 'vb_to_vbn': 'lived', 'vb_to_rb': 'lively', 'vb_to_nn': 'living', 'vb_to_jj': 'living', 'jj_to_vbg': 'living', 'vb_to_vbg': 'living', 'vbd_eq_vbn': ''},
 'local': {'jj_to_rb': 'locally', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_rb': 'locally', 'n_is_sth': '2'},
 'logical': {'jj_to_rb': 'logically', 'jj_to_nn': 'logic'},
 'logic': {'jj_to_rb': 'logically', 'nn_to_nns': 'logics', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'logical', 'nn_to_rb': 'logically'},
 'loud': {'jj_to_rb': 'loudly', 'jj_to_nn': 'loudness', 'nn_to_rb': 'loudly', 'rb_to_nn': 'loudness', 'jj_to_jjr': 'louder', 'jj_to_jjs': 'loudest', 'rb_to_rbr': 'louder', 'rb_to_rbs': 'loudest'},
 'loyal': {'jj_to_rb': 'loyally', 'jj_to_nn': 'loyalty', 'nn_to_rb': 'loyally'},
 'lucky': {'jj_to_rb': 'luckily', 'jj_to_nn': 'luck', 'jj_to_vb': 'luck', 'be_jj_to_vb': '', 'jj_to_jjr': 'luckier', 'jj_to_jjs': 'luckiest'},
 'mad': {'jj_to_rb': 'madly', 'jj_to_nn': 'madness', 'nn_to_rb': 'madly', 'jj_to_jjr': 'madder', 'jj_to_jjs': 'maddest'},
 'main': {'jj_to_rb': 'mainly', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'mainly'},
 'manual': {'jj_to_rb': 'manually', 'nn_to_nns': 'manuals', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'manually'},
 'mass': {'jj_to_rb': 'massively', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'massively', 'vb_to_rb': 'massively', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'massive': {'jj_to_rb': 'massively', 'jj_to_nn': 'mass', 'jj_to_vb': 'mass'},
 'material': {'jj_to_rb': 'materially', 'nn_to_nns': 'materials', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_rb': 'materially', 'n_is_sth': '2'},
 'mature': {'jj_to_rb': 'maturely', 'jj_to_nn': 'maturity', 'vb_to_rb': 'maturely', 'vb_to_nn': 'maturity', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'mean': {'jj_to_rb': 'meanly', 'jj_to_nn': 'meanness', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_vbg': '', 'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_to': '', 'vb_to_vbz': 'means', 'vb_to_vbd': 'meaned', 'vb_to_vbn': 'meaned', 'vb_to_rb': 'meanly', 'vb_to_nn': 'meanness', 'vb_to_vbg': 'meaning', 'vbg_non': '', 'vt_typical': '', 'be_jj_to_vb': '', 'be_jj_to_n': '', 'jj_to_jjr': 'meaner', 'jj_to_jjs': 'meanest'},
 'mechanical': {'jj_to_rb': 'mechanically', 'jj_to_nn': 'mechanic'},
 'mechanic': {'jj_to_rb': 'mechanically', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '0', 'nn_to_jj': 'mechanical', 'nn_to_rb': 'mechanically'},
 'medical': {'jj_to_rb': 'medically', 'nn_to_nns': 'medicals', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'medically'},
 'mental': {'jj_to_rb': 'mentally', 'jj_to_nn': 'mentality', 'nn_to_rb': 'mentally'},
 'merciful': {'jj_to_rb': 'mercifully', 'jj_to_nn': 'mercy'},
 'mere': {'jj_to_rb': 'merely', 'nn_to_nns': 'meres', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'merely', 'jj_to_jjs': 'merest'},
 'merry': {'jj_to_rb': 'merrily', 'jj_to_nn': 'merriness', 'nn_to_rb': 'merrily', 'jj_to_jjr': 'merrier', 'jj_to_jjs': 'merriest'},
 'methodical': {'jj_to_rb': 'methodically', 'jj_to_nn': 'method'},
 'method': {'jj_to_rb': 'methodically', 'nn_to_nns': 'methods', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'methodical', 'nn_to_rb': 'methodically'},
 'mild': {'jj_to_rb': 'mildly', 'jj_to_nn': 'mildness', 'nn_to_rb': 'mildly', 'jj_to_jjr': 'milder', 'jj_to_jjs': 'mildest'},
 'minimum': {'jj_to_rb': 'minimally', 'jj_to_vb': 'minimise', 'nn_to_nns': 'minima', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'minimise', 'nn_to_rb': 'minimally'},
 'minimal': {'jj_to_rb': 'minimally', 'jj_to_nn': 'minimum', 'jj_to_vb': 'minimise'},
 'miserable': {'jj_to_rb': 'miserably', 'jj_to_nn': 'misery'},
 'modest': {'jj_to_rb': 'modestly', 'jj_to_nn': 'modesty', 'nn_to_rb': 'modestly'},
 'moral': {'jj_to_rb': 'morally', 'jj_to_nn': 'morality', 'nn_to_nns': 'morals', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'morally', 'nc_typical': ''},
 'muddy': {'jj_to_rb': 'muddily', 'jj_to_nn': 'mud', 'jj_to_vb': 'mud', 'vb_to_rb': 'muddily', 'vb_to_nn': 'mud', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'vt_typical': '', 'jj_to_jjr': 'muddier', 'jj_to_jjs': 'muddiest'},
 'multiple': {'jj_to_rb': 'multiply', 'jj_to_nn': 'multiplication', 'jj_to_vb': 'multiply', 'nn_to_nns': 'multiples', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'multiply', 'nn_to_jj': 'multiply', 'nn_to_rb': 'multiply'},
 'musical': {'jj_to_rb': 'musically', 'jj_to_nn': 'music', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'musically', 'nc_typical': ''},
 'mysterious': {'jj_to_rb': 'mysteriously', 'jj_to_nn': 'mystery'},
 'narrow': {'jj_to_rb': 'narrowly', 'jj_to_nn': 'narrowness', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'narrowly', 'vb_to_rb': 'narrowly', 'vb_to_nn': 'narrowness', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'jj_to_jjr': 'narrower', 'jj_to_jjs': 'narrowest'},
 'national': {'jj_to_rb': 'nationally', 'jj_to_nn': 'nation', 'nn_to_nns': 'nationals', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_rb': 'nationally'},
 'native': {'jj_to_rb': 'natively', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_rb': 'natively'},
 'natural': {'jj_to_rb': 'naturally', 'jj_to_nn': 'nature', 'nn_to_nns': 'naturals', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_rb': 'naturally', 'n_is_sth': '2'},
 'neat': {'jj_to_rb': 'neatly', 'jj_to_nn': 'neatness', 'jj_to_jjr': 'neater', 'jj_to_jjs': 'neatest'},
 'necessary': {'jj_to_rb': 'necessarily', 'jj_to_nn': 'necessity', 'nn_to_nns': 'necessaries', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'necessarily', 'be_jj_to_vbg': '', 'be_jj_to_vb': ''},
 'new': {'jj_to_rb': 'newly', 'jj_to_nn': 'newness', 'nn_to_rb': 'newly', 'rb_to_nn': 'newness', 'be_jj_to_vbg': '', 'jj_to_jjr': 'newer', 'jj_to_jjs': 'newest'},
 'nice': {'jj_to_rb': 'nicely', 'jj_to_nn': 'niceness', 'nn_to_rb': 'nicely', 'be_jj_to_vb': '', 'jj_to_jjr': 'nicer', 'jj_to_jjs': 'nicest'},
 'night': {'jj_to_rb': 'nightly', 'nn_to_nns': 'nights', 'n_is_nc': '', 'nn_to_rb': 'nightly'},
 'noble': {'jj_to_rb': 'nobly', 'jj_to_nn': 'nobility', 'nn_to_nns': 'nobles', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_rb': 'nobly', 'vb_to_rb': 'nobly', 'vb_to_nn': 'nobility', 'jj_to_jjr': 'nobler', 'jj_to_jjs': 'noblest'},
 'noisy': {'jj_to_rb': 'noisily', 'jj_to_nn': 'noise', 'jj_to_vb': 'noise', 'jj_to_jjr': 'noisier', 'jj_to_jjs': 'noisiest'},
 'nonsensical': {'jj_to_rb': 'nonsensically', 'jj_to_nn': 'nonsense'},
 'nonsense': {'jj_to_rb': 'nonsensically', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'nonsensical', 'nn_to_rb': 'nonsensically'},
 'normal': {'jj_to_rb': 'normally', 'jj_to_nn': 'normality', 'jj_to_vb': 'normalize', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'normalize', 'nn_to_rb': 'normally', 'nu_typical': ''},
 'notable': {'jj_to_rb': 'notably', 'jj_to_nn': 'note', 'jj_to_vb': 'note', 'nn_to_nns': 'notables', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'note', 'nn_to_rb': 'notably'},
 'noticeable': {'jj_to_rb': 'noticeably', 'jj_to_nn': 'notice', 'jj_to_vb': 'notice', 'be_jj_to_vbg': ''},
 'obedient': {'jj_to_rb': 'obediently', 'jj_to_nn': 'obedience', 'jj_to_vb': 'obey'},
 'objective': {'jj_to_rb': 'objectively', 'jj_to_nn': 'objection', 'jj_to_vb': 'object', 'nn_to_nns': 'objectives', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'occasional': {'jj_to_rb': 'occasionally', 'jj_to_nn': 'occasion'},
 'offensive': {'jj_to_rb': 'offensively', 'jj_to_nn': 'offendence', 'jj_to_vb': 'offend', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'official': {'jj_to_rb': 'officially', 'jj_to_nn': 'officialdom', 'nn_to_nns': 'officials', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nc_typical': ''},
 'oiled': {'jj_to_rb': 'oily', 'jj_to_nn': 'oiliness', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'open': {'jj_to_rb': 'openly', 'jj_to_nn': 'openness', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'opens', 'vb_to_vbd': 'opened', 'vb_to_vbn': 'opened', 'vb_to_rb': 'openly', 'vb_to_nn': 'openness', 'vb_to_vbg': 'opening', 'be_jj_to_vbg': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'ordinary': {'jj_to_rb': 'ordinarily', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2', 'nn_to_rb': 'ordinarily'},
 'orientational': {'jj_to_rb': 'originally', 'jj_to_nn': 'orientation', 'jj_to_vb': 'orient'},
 'original': {'jj_to_rb': 'originally', 'jj_to_nn': 'origin', 'jj_to_vb': 'originate', 'nn_to_nns': 'originals', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'confu_pair': 'origin'},
 'painful': {'jj_to_rb': 'painfully', 'jj_to_nn': 'pain', 'jj_to_vb': 'pain'},
 'pale': {'jj_to_rb': 'palely', 'jj_to_nn': 'paleness', 'nn_to_nns': 'pales', 'n_is_nc': '', 'n_is_sth': '', 'vb_to_rb': 'palely', 'vb_to_nn': 'paleness', 'vbd_eq_vbn': '', 'jj_to_jjr': 'paler', 'jj_to_jjs': 'palest'},
 'partial': {'jj_to_rb': 'partially', 'jj_to_nn': 'particle', 'jj_to_vb': 'part'},
 'particular': {'jj_to_rb': 'particularly', 'jj_to_nn': 'particularity', 'n_is_nc': '', 'n_is_sth': ''},
 'passive': {'jj_to_rb': 'passively', 'jj_to_nn': 'passivity', 'n_is_nc': '', 'n_is_sth': ''},
 'patient': {'jj_to_rb': 'patiently', 'jj_to_nn': 'patience', 'nn_to_nns': 'patients', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'peaceful': {'jj_to_rb': 'peacefully', 'jj_to_nn': 'peace'},
 'peculiar': {'jj_to_rb': 'peculiarly', 'jj_to_nn': 'peculiarity'},
 'perfect': {'jj_to_rb': 'perfectly', 'jj_to_nn': 'perfection', 'vbd_eq_vbn': ''},
 'periodical': {'jj_to_rb': 'periodically', 'jj_to_nn': 'period', 'n_is_nc': '', 'n_is_sth': ''},
 'persistent': {'jj_to_rb': 'persistently', 'jj_to_nn': 'persistence', 'jj_to_vb': 'persist'},
 'persuasive': {'jj_to_rb': 'persuasively', 'jj_to_nn': 'persuasion', 'jj_to_vb': 'persuade'},
 'philosophical': {'jj_to_rb': 'philosophically'},
 'pink': {'jj_to_rb': 'pinkly', 'jj_to_nn': 'pinkness', 'nn_to_nns': 'pinks', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'pleasant': {'jj_to_rb': 'pleasantly', 'jj_to_nn': 'pleasure', 'be_jj_to_vb': '', 'jj_to_jjr': 'pleasanter', 'jj_to_jjs': 'pleasantest'},
 'poisonous': {'jj_to_rb': 'poisonously', 'jj_to_nn': 'poisoner', 'jj_to_vb': 'poison'},
 'polite': {'jj_to_rb': 'politely', 'jj_to_nn': 'politeness', 'be_jj_to_vb': ''},
 'political': {'jj_to_rb': 'politically', 'jj_to_nn': 'politician'},
 'popular': {'jj_to_rb': 'popularly', 'jj_to_nn': 'popularity'},
 'possible': {'jj_to_rb': 'possibly', 'jj_to_nn': 'possibility', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'be_jj_to_vb': ''},
 'precedent': {'jj_to_rb': 'precedently', 'jj_to_nn': 'precedence', 'jj_to_vb': 'precede', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'precise': {'jj_to_rb': 'precisely', 'jj_to_nn': 'precision'},
 'predictable': {'jj_to_rb': 'predictably', 'jj_to_nn': 'predictability', 'jj_to_vb': 'predict'},
 'predominant': {'jj_to_rb': 'predominantly', 'jj_to_nn': 'predominance', 'jj_to_vb': 'predominate'},
 'preferable': {'jj_to_rb': 'preferably', 'jj_to_nn': 'preference', 'jj_to_vb': 'prefer', 'be_jj_to_vbg': ''},
 'present': {'jj_to_rb': 'presently', 'jj_to_nn': 'presence', 'nn_to_nns': 'presents', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'presents', 'vb_to_vbd': 'presented', 'vb_to_vbn': 'presented', 'vb_to_rb': 'presently', 'vb_to_nn': 'presence', 'vb_to_vbg': 'presenting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vt_typical': ''},
 'presidential': {'jj_to_rb': 'presidentially', 'jj_to_nn': 'president'},
 'presumable': {'jj_to_rb': 'presumably', 'jj_to_nn': 'presumption', 'jj_to_vb': 'presume'},
 'pretty': {'jj_to_rb': 'prettily', 'jj_to_nn': 'prettiness', 'jj_to_jjr': 'prettier', 'jj_to_jjs': 'prettiest'},
 'private': {'jj_to_rb': 'privately', 'jj_to_nn': 'privacy', 'nn_to_nns': 'privates', 'n_is_nc': '', 'n_is_sb': '0'},
 'probable': {'jj_to_rb': 'probably', 'jj_to_nn': 'probability', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'problematic': {'jj_to_rb': 'problematically', 'jj_to_nn': 'problem'},
 'procedural': {'jj_to_rb': 'procedurally', 'jj_to_nn': 'procedure', 'jj_to_vb': 'proceed'},
 'productive': {'jj_to_rb': 'productively', 'jj_to_nn': 'production'},
 'professional': {'jj_to_rb': 'professionally', 'jj_to_nn': 'professionalism', 'nn_to_nns': 'professionals', 'n_is_nc': '', 'n_is_sb': '0'},
 'progressive': {'jj_to_rb': 'progressively', 'jj_to_nn': 'progress', 'jj_to_vb': 'progress', 'n_is_sb': '0'},
 'prohibitive': {'jj_to_rb': 'prohibitively', 'jj_to_nn': 'prohibition', 'jj_to_vb': 'prohibit'},
 'prompt': {'jj_to_rb': 'promptly', 'nn_to_nns': 'prompts', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'promptly', 'vb_to_rb': 'promptly', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'proportional': {'jj_to_rb': 'proportionally', 'n_is_nc': '', 'n_is_sth': ''},
 'prospective': {'jj_to_rb': 'prospectively', 'jj_to_nn': 'prospection', 'jj_to_vb': 'prospect'},
 'protective': {'jj_to_rb': 'protectively', 'jj_to_nn': 'protection', 'jj_to_vb': 'protect'},
 'provisional': {'jj_to_rb': 'provisionally', 'jj_to_nn': 'provision'},
 'psychological': {'jj_to_rb': 'psychologically', 'jj_to_nn': 'psychology'},
 'publical': {'jj_to_rb': 'publically', 'jj_to_nn': 'publicity'},
 'punctual': {'jj_to_rb': 'punctually', 'jj_to_nn': 'punctuality'},
 'pure': {'jj_to_rb': 'purely', 'jj_to_nn': 'pureness', 'jj_to_jjr': 'purer', 'jj_to_jjs': 'purest'},
 'purposive': {'jj_to_rb': 'purposively', 'jj_to_nn': 'purposiveness'},
 'qualitative': {'jj_to_rb': 'qualitatively'},
 'questionable': {'jj_to_rb': 'quickly', 'jj_to_nn': 'quickness'},
 'quick': {'jj_to_rb': 'quietly', 'jj_to_nn': 'quietness', 'n_is_nu': '', 'n_is_sth': '', 'jj_to_jjr': 'quicker', 'jj_to_jjs': 'quickest', 'rb_to_rbr': 'quicker', 'rb_to_rbs': 'quickest'},
 'random': {'jj_to_rb': 'randomly', 'jj_to_nn': 'randomness'},
 'rank': {'jj_to_rb': 'rankly', 'nn_to_nns': 'ranks', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'rankly', 'v_to_vbg': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'ranks', 'vb_to_vbd': 'ranked', 'vb_to_vbn': 'ranked', 'vb_to_rb': 'rankly', 'vb_to_vbg': 'ranking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'jj_to_jjr': 'ranker', 'jj_to_jjs': 'rankest'},
 'rapid': {'jj_to_rb': 'rapidly', 'jj_to_nn': 'rapidity', 'nn_to_nns': 'rapids', 'n_is_nc': '', 'n_is_sth': ''},
 'rare': {'jj_to_rb': 'rarely', 'jj_to_nn': 'rareness', 'jj_to_jjr': 'rarer', 'jj_to_jjs': 'rarest'},
 'rational': {'jj_to_rb': 'rationally', 'jj_to_nn': 'rationalisation', 'jj_to_vb': 'rationalise'},
 'raw': {'jj_to_rb': 'rawly', 'jj_to_nn': 'rawness', 'n_is_nu': '', 'n_is_sth': ''},
 'reactive': {'jj_to_rb': 'reactively', 'jj_to_nn': 'reaction', 'jj_to_vb': 'reactivate'},
 'real': {'jj_to_rb': 'really', 'jj_to_nn': 'reality', 'n_is_nc': '', 'n_is_sth': ''},
 'reasonable': {'jj_to_rb': 'reasonably', 'jj_to_nn': 'reason'},
 'reflective': {'jj_to_rb': 'reflectively', 'jj_to_nn': 'reflection', 'jj_to_vb': 'reflect'},
 'regional': {'jj_to_rb': 'regionally', 'jj_to_nn': 'region'},
 'regretful': {'jj_to_rb': 'regretfully', 'jj_to_nn': 'regret', 'jj_to_vb': 'regret'},
 'regular': {'jj_to_rb': 'regularly', 'jj_to_nn': 'regularity', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'relevant': {'jj_to_rb': 'relevantly', 'jj_to_nn': 'relevance', 'be_jj_to_vbg': ''},
 'religious': {'jj_to_rb': 'religiously', 'jj_to_nn': 'religion', 'n_is_sb': '0'},
 'reluctant': {'jj_to_rb': 'reluctantly', 'jj_to_nn': 'reluctance', 'be_jj_to_vb': ''},
 'reliable': {'jj_to_rb': 'reliably', 'jj_to_nn': 'reliability', 'jj_to_vb': 'rely'},
 'remarkable': {'jj_to_rb': 'remarkably', 'jj_to_nn': 'remark'},
 'repeated': {'jj_to_rb': 'repeatedly', 'jj_to_nn': 'repetition', 'jj_to_vb': 'repeat', 'vbd_to_vb': 'repeat', 'vbn_to_vb': 'repeat', 'vbn_to_vbg': 'repeating', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'representative': {'jj_to_rb': 'representively', 'jj_to_nn': 'representation', 'jj_to_vb': 'represent', 'nn_to_nns': 'representatives', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'represent', 'nn_to_rb': 'representively', 'nc_typical': ''},
 'reservations': {'jj_to_rb': 'reserves', 'jj_to_nn': 'reserve', 'jj_to_vb': 'reserve', 'nns_to_nn': 'reservation'},
 'respectful': {'jj_to_rb': 'respectively', 'jj_to_nn': 'respect', 'jj_to_vb': 'respect'},
 'respectable': {'jj_to_rb': 'respectively', 'jj_to_nn': 'respect', 'jj_to_vb': 'respect'},
 'respective': {'jj_to_rb': 'respectively', 'jj_to_nn': 'respect', 'jj_to_vb': 'respect'},
 'restrictive': {'jj_to_rb': 'restrictively', 'jj_to_nn': 'restriction', 'jj_to_vb': 'restrict'},
 'rich': {'jj_to_rb': 'richly', 'jj_to_nn': 'richness', 'jj_to_jjr': 'richer', 'jj_to_jjs': 'richest'},
 'rightful': {'jj_to_rb': 'rightfully', 'jj_to_nn': 'rightness', 'jj_to_vb': 'right'},
 'rigid': {'jj_to_rb': 'rigidly', 'jj_to_nn': 'rigidity'},
 'risky': {'jj_to_rb': 'riskily', 'jj_to_nn': 'risk', 'jj_to_vb': 'risk', 'jj_to_jjr': 'riskier', 'jj_to_jjs': 'riskiest'},
 'rough': {'jj_to_rb': 'roughly', 'jj_to_nn': 'roughness', 'nn_to_nns': 'roughs', 'n_is_sth': '', 'vbd_eq_vbn': '', 'jj_to_jjr': 'rougher', 'jj_to_jjs': 'roughest'},
 'royal': {'jj_to_rb': 'royally', 'jj_to_nn': 'royalty', 'nn_to_nns': 'royals', 'n_is_sb': '0'},
 'rude': {'jj_to_rb': 'rudely', 'jj_to_nn': 'rudeness', 'be_jj_to_vb': '', 'jj_to_jjr': 'ruder', 'jj_to_jjs': 'rudest'},
 'sad': {'jj_to_rb': 'sadly', 'jj_to_nn': 'sadness', 'jj_to_vb': 'sadden', 'jj_to_jjr': 'sadder', 'jj_to_jjs': 'saddest'},
 'safe': {'jj_to_rb': 'safely', 'jj_to_nn': 'safety', 'n_is_nc': '', 'n_is_sth': '', 'jj_to_jjr': 'safer', 'jj_to_jjs': 'safest'},
 'scarce': {'jj_to_rb': 'scarcely', 'jj_to_nn': 'scarcity', 'jj_to_jjr': 'scarcer', 'jj_to_jjs': 'scarcest'},
 'schematic': {'jj_to_rb': 'schematically', 'jj_to_nn': 'scheme', 'jj_to_vb': 'scheme'},
 'scientific': {'jj_to_rb': 'scientifically', 'jj_to_nn': 'science'},
 'scornful': {'jj_to_rb': 'scornfully', 'jj_to_nn': 'scorn', 'jj_to_vb': 'scorn'},
 'second': {'jj_to_rb': 'secondly', 'nn_to_nns': 'seconds', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_rb': 'secondly', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'seconds', 'vb_to_vbd': 'seconded', 'vb_to_vbn': 'seconded', 'vb_to_rb': 'secondly', 'vb_to_vbg': 'seconding', 'vbd_eq_vbn': '', 'quantifier': ''},
 'secret': {'jj_to_rb': 'secretly', 'nn_to_nns': 'secrets', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'secretly', 'nc_typical': ''},
 'secure': {'jj_to_rb': 'securely', 'jj_to_nn': 'security', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'secures', 'vb_to_vbd': 'secured', 'vb_to_vbn': 'secured', 'vb_to_rb': 'securely', 'vb_to_nn': 'security', 'vb_to_vbg': 'securing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'selective': {'jj_to_rb': 'selectively', 'jj_to_nn': 'select', 'jj_to_vb': 'select'},
 'sensible': {'jj_to_rb': 'sensibly', 'jj_to_nn': 'sense', 'jj_to_vb': 'sense'},
 'sensitive': {'jj_to_rb': 'sensitively', 'jj_to_nn': 'sensitivity', 'be_jj_to_n': ''},
 'separate': {'jj_to_rb': 'separately', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'separately', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'v_from': '', 'vb_to_rb': 'separately', 'vbd_eq_vbn': ''},
 'sequential': {'jj_to_rb': 'sequentially', 'jj_to_nn': 'sequence', 'jj_to_vb': 'sequence'},
 'serious': {'jj_to_rb': 'seriously', 'jj_to_nn': 'seriousness'},
 'severe': {'jj_to_rb': 'severely', 'jj_to_nn': 'severity', 'jj_to_jjr': 'severer', 'jj_to_jjs': 'severest'},
 'sexual': {'jj_to_rb': 'sexually', 'jj_to_nn': 'sex', 'jj_to_vb': 'sex'},
 'shaky': {'jj_to_rb': 'shakily', 'jj_to_nn': 'shake', 'jj_to_vb': 'shake', 'jj_to_jjr': 'shakier', 'jj_to_jjs': 'shakiest'},
 'shallow': {'jj_to_rb': 'shallowly', 'jj_to_nn': 'shallowness', 'vb_to_rb': 'shallowly', 'vb_to_nn': 'shallowness', 'jj_to_jjr': 'shallower', 'jj_to_jjs': 'shallowest'},
 'shameful': {'jj_to_rb': 'shamefully', 'jj_to_nn': 'shame', 'jj_to_vb': 'shame'},
 'sharp': {'jj_to_rb': 'sharply', 'jj_to_nn': 'sharpness', 'n_is_nc': '', 'n_is_sth': '', 'vb_to_rb': 'sharply', 'vb_to_nn': 'sharpness', 'jj_to_jjr': 'sharper', 'jj_to_jjs': 'sharpest'},
 'short': {'jj_to_rb': 'shortly', 'jj_to_vb': 'shorten', 'nn_to_nns': 'shorts', 'n_is_sth': '', 'nn_to_vb': 'shorten', 'nn_to_rb': 'shortly', 'jj_to_jjr': 'shorter', 'jj_to_jjs': 'shortest'},
 'sick': {'jj_to_rb': 'sickly', 'jj_to_nn': 'sickness', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'sickly', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'jj_to_jjr': 'sicker', 'jj_to_jjs': 'sickest'},
 'significant': {'jj_to_rb': 'significantly', 'jj_to_nn': 'significance', 'jj_to_vb': 'signify'},
 'insignificant': {'jj_to_rb': 'significantly', 'jj_to_nn': 'significance', 'jj_to_vb': 'signify'},
 'silent': {'jj_to_rb': 'silently', 'jj_to_nn': 'silence', 'jj_to_vb': 'silence'},
 'similar': {'jj_to_rb': 'similarly', 'jj_to_nn': 'similarity', 'be_jj_to_vbg': ''},
 'simple': {'jj_to_rb': 'simply', 'jj_to_nn': 'simpleness', 'jj_to_vb': 'simplify', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'jj_to_jjr': 'simpler', 'jj_to_jjs': 'simplest'},
 'simulate': {'jj_to_rb': 'simulatedly', 'jj_to_nn': 'simulation', 'vb_to_rb': 'simulatedly', 'vb_to_nn': 'simulation', 'v_compcl_non': '', 'v_infcl_non': ''},
 'stimulated': {'jj_to_rb': 'simulatedly', 'jj_to_nn': 'simulation', 'jj_to_vb': 'simulate', 'vbd_eq_vbn': ''},
 'sincere': {'jj_to_rb': 'sincerely', 'jj_to_nn': 'sincerity'},
 'singing': {'jj_to_rb': 'singingly', 'jj_to_nn': 'sing', 'jj_to_vb': 'sing', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'sing', 'nn_to_rb': 'singingly', 'vbg_to_vb': 'sing', 'vbg_to_vbn': 'sung'},
 'sixteenth': {'jj_to_rb': 'sixthly', 'jj_to_nn': 'six'},
 'sixteen': {'jj_to_rb': 'sixthly', 'jj_to_nn': 'six', 'nn_to_jj': 'sixteenth', 'nn_to_rb': 'sixthly'},
 'sixth': {'jj_to_rb': 'sixthly', 'jj_to_nn': 'six', 'nn_to_jj': 'sixteenth', 'nn_to_rb': 'sixthly'},
 'sixtieth': {'jj_to_rb': 'sixthly', 'jj_to_nn': 'six', 'nn_to_jj': 'sixteenth', 'nn_to_rb': 'sixthly'},
 'skilled': {'jj_to_rb': 'skilfully', 'jj_to_nn': 'skill', 'jj_ed': ''},
 'skilful': {'jj_to_rb': 'skilfully', 'jj_to_nn': 'skill'},
 'slight': {'jj_to_rb': 'slightly', 'nn_to_nns': 'slights', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'slightly', 'vb_to_rb': 'slightly', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'jj_to_jjr': 'slighter', 'jj_to_jjs': 'slightest'},
 'slighting': {'jj_to_rb': 'slightly', 'jj_to_nn': 'slight', 'jj_to_vb': 'slight'},
 'slow': {'jj_to_rb': 'slowly', 'nn_to_rb': 'slowly', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_to': '', 'vb_to_vbz': 'slows', 'vb_to_vbd': 'slowed', 'vb_to_vbn': 'slowed', 'vb_to_rb': 'slowly', 'vb_to_vbg': 'slowing', 'vbd_eq_vbn': '', 'jj_to_jjr': 'slower', 'jj_to_jjs': 'slowest', 'rb_to_rbr': 'slower', 'rb_to_rbs': 'slowest'},
 'smoked': {'jj_to_rb': 'smoking', 'jj_to_nn': 'smoke', 'jj_to_vb': 'smoke', 'vbd_to_vb': 'smoke', 'vbn_to_vb': 'smoke', 'vbn_to_vbg': 'smoking', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'smoothed': {'jj_to_rb': 'smoothly', 'jj_to_nn': 'smooth', 'jj_to_vb': 'smooth', 'vbd_eq_vbn': ''},
 'softened': {'jj_to_rb': 'softly', 'jj_to_nn': 'soft', 'jj_to_vb': 'soften', 'vbd_eq_vbn': ''},
 'soft': {'jj_to_rb': 'softly', 'jj_to_vb': 'soften', 'nn_to_vb': 'soften', 'nn_to_jj': 'softened', 'nn_to_rb': 'softly', 'jj_to_jjr': 'softer', 'jj_to_jjs': 'softest'},
 'sole': {'jj_to_rb': 'solely', 'nn_to_nns': 'soles', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_rb': 'solely', 'vb_to_rb': 'solely', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'solemn': {'jj_to_rb': 'solemnly', 'jj_to_nn': 'solemnity'},
 'solidified': {'jj_to_rb': 'solidly', 'jj_to_nn': 'solid', 'jj_to_vb': 'solidify', 'vbd_eq_vbn': ''},
 'sour': {'jj_to_rb': 'sourly', 'nn_to_rb': 'sourly', 'vb_to_rb': 'sourly', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'specialist': {'jj_to_rb': 'specially', 'jj_to_nn': 'special', 'jj_to_vb': 'specialize', 'nn_to_nns': 'specialists', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'specialize', 'nn_to_rb': 'specially', 'nc_typical': ''},
 'specialized': {'jj_to_rb': 'specially', 'jj_to_nn': 'special', 'jj_to_vb': 'specialize', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'specific': {'jj_to_rb': 'specifically', 'nn_to_nns': 'specifics', 'n_is_sth': '', 'nn_to_rb': 'specifically'},
 'specifical': {'jj_to_rb': 'specifically', 'jj_to_nn': 'specific'},
 'spherical': {'jj_to_rb': 'spherically', 'jj_to_nn': 'sphere', 'jj_to_vb': 'sphere'},
 'sphere': {'jj_to_rb': 'spherically', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'spherical', 'nn_to_rb': 'spherically', 'vb_to_rb': 'spherically', 'vb_to_jj': 'spherical'},
 'spotted': {'jj_to_rb': 'spot', 'jj_to_nn': 'spot', 'jj_to_vb': 'spot', 'nn_to_vb': 'spot', 'nn_to_rb': 'spot', 'vbd_to_vb': 'spot', 'vbn_to_vb': 'spot', 'vbn_to_vbg': 'spotting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'square': {'jj_to_rb': 'squarely', 'nn_to_nns': 'squares', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_rb': 'squarely', 'vb_to_rb': 'squarely'},
 'steady': {'jj_to_rb': 'steadily', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_rb': 'steadily', 'vb_to_rb': 'steadily', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'n_is_sth': '2', 'jj_to_jjr': 'steadier', 'jj_to_jjs': 'steadiest'},
 'steam': {'jj_to_rb': 'steaming', 'nn_to_nns': 'steams', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_rb': 'steaming', 'vb_to_rb': 'steaming', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nu_typical': ''},
 'steamed': {'jj_to_rb': 'steaming', 'jj_to_nn': 'steam', 'jj_to_vb': 'steam', 'vbd_eq_vbn': ''},
 'steerable': {'jj_to_rb': 'steered', 'jj_to_nn': 'steer', 'jj_to_vb': 'steer'},
 'stiffened': {'jj_to_rb': 'stiff', 'jj_to_nn': 'stiff', 'jj_to_vb': 'stiff', 'vbd_eq_vbn': ''},
 'stinging': {'jj_to_rb': 'stingingly', 'jj_to_nn': 'sting', 'jj_to_vb': 'sting'},
 'stone': {'jj_to_rb': 'stonily', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_rb': 'stonily', 'vb_to_rb': 'stonily'},
 'stoned': {'jj_to_rb': 'stonily', 'jj_to_nn': 'stone', 'jj_to_vb': 'stone', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'stony': {'jj_to_rb': 'stonily', 'jj_to_nn': 'stone', 'jj_to_vb': 'stone', 'jj_to_jjr': 'stonier', 'jj_to_jjs': 'stoniest'},
 'strategic': {'jj_to_rb': 'strategically', 'jj_to_nn': 'strategy'},
 'strict': {'jj_to_rb': 'strictly', 'jj_to_nn': 'strictness', 'jj_to_jjr': 'stricter', 'jj_to_jjs': 'strictest'},
 'stupid': {'jj_to_rb': 'stupidly', 'nn_to_nns': 'stupids', 'n_is_sb': '0', 'nn_to_rb': 'stupidly', 'jj_to_jjr': 'stupider', 'jj_to_jjs': 'stupidest'},
 'stylized': {'jj_to_rb': 'stylishly', 'jj_to_nn': 'style', 'jj_to_vb': 'style', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'stylised': {'jj_to_rb': 'stylishly', 'jj_to_nn': 'style', 'jj_to_vb': 'style'},
 'stylish': {'jj_to_rb': 'stylishly', 'jj_to_nn': 'style', 'jj_to_vb': 'style'},
 'substantial': {'jj_to_rb': 'substantially', 'jj_to_nn': 'substance', 'nn_to_rb': 'substantially'},
 'substantive': {'jj_to_rb': 'substantially', 'jj_to_nn': 'substance', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'substantial', 'nn_to_rb': 'substantially'},
 'succeeding': {'jj_to_rb': 'successfully', 'jj_to_nn': 'success', 'jj_to_vb': 'succeed', 'vbg_to_vb': 'succeed', 'vbg_to_vbn': 'succeeded'},
 'successful': {'jj_to_rb': 'successfully', 'jj_to_nn': 'success', 'jj_to_vb': 'succeed'},
 'successive': {'jj_to_rb': 'successively', 'jj_to_nn': 'successor'},
 'sudden': {'jj_to_rb': 'suddenly', 'nn_to_rb': 'suddenly'},
 'sufficient': {'jj_to_rb': 'sufficiently', 'jj_to_nn': 'sufficiency'},
 'sunny': {'jj_to_rb': 'sunnily', 'jj_to_nn': 'sun', 'jj_to_jjr': 'sunnier', 'jj_to_jjs': 'sunniest'},
 'suppositive': {'jj_to_rb': 'supposedly', 'jj_to_nn': 'supposition', 'jj_to_vb': 'suppose', 'nn_to_vb': 'suppose', 'nn_to_jj': 'supposed', 'nn_to_rb': 'supposedly'},
 'suppositional': {'jj_to_rb': 'supposedly', 'jj_to_nn': 'supposition', 'jj_to_vb': 'suppose'},
 'supposititious': {'jj_to_rb': 'supposedly', 'jj_to_nn': 'supposition', 'jj_to_vb': 'suppose'},
 'unsure': {'jj_to_rb': 'sure', 'jj_to_nn': 'sure'},
 'surface': {'jj_to_rb': 'surficially', 'nn_to_nns': 'surfaces', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_rb': 'surficially', 'vb_to_rb': 'surficially', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'surficial': {'jj_to_rb': 'surficially', 'jj_to_nn': 'surface', 'jj_to_vb': 'surface'},
 'surfaced': {'jj_to_rb': 'surficially', 'jj_to_nn': 'surface', 'jj_to_vb': 'surface', 'vbd_eq_vbn': ''},
 'surprise': {'jj_to_rb': 'surprisingly', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'surprised', 'nn_to_rb': 'surprisingly', 'v_n': '', 'nsubjpass': '', 'vb_to_rb': 'surprisingly', 'vb_to_vbn': 'surprised', 'nn_to_vbn': 'surprised', 'vbd_eq_vbn': '', 'vt_typical': '', 'be_nn_in.nn_to_jj': ''},
 'surprising': {'jj_to_rb': 'surprisingly', 'jj_to_nn': 'surprise', 'jj_to_vb': 'surprise', 'sth_be_jj': ''},
 'surprised': {'jj_to_rb': 'surprisingly', 'jj_to_nn': 'surprise', 'jj_to_vb': 'surprise', 'vbn_to_nn': 'surprise', 'sb_be_jj': '', 'jj_ed': '', 'be_jj_to_vb': '', 'vbd_eq_vbn': ''},
 'suspicious': {'jj_to_rb': 'suspiciously', 'jj_to_nn': 'suspicion', 'jj_to_vb': 'suspicion'},
 'sweet': {'jj_to_rb': 'sweetly', 'nn_to_nns': 'sweets', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_rb': 'sweetly', 'jj_to_jjr': 'sweeter', 'jj_to_jjs': 'sweetest'},
 'swim': {'jj_to_rb': 'swimmingly', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'swimmingly', 'v_to_vbg': '', 'v_n': '', 'v_in': '', 'v_to': '', 'vb_to_vbz': 'swims', 'vb_to_vbd': 'swimmed,swam', 'vb_to_vbn': 'swimmed,swum', 'vb_to_rb': 'swimmingly', 'vb_to_vbg': 'swiming', 'vi_typical': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'swimming': {'jj_to_rb': 'swimmingly', 'jj_to_nn': 'swim', 'jj_to_vb': 'swim', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'swim', 'nn_to_jj': 'swim', 'nn_to_rb': 'swimmingly', 'nu_typical': ''},
 'swimmable': {'jj_to_rb': 'swimmingly', 'jj_to_nn': 'swim', 'jj_to_vb': 'swim'},
 'swing': {'jj_to_rb': 'swinging', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'swinging', 'vb_to_vbz': 'swings', 'vb_to_vbd': 'swung', 'vb_to_vbn': 'swung', 'vb_to_rb': 'swinging', 'vb_to_vbg': 'swinging', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'symbolic': {'jj_to_rb': 'symbolically', 'jj_to_nn': 'symbol', 'jj_to_vb': 'symbolise'},
 'sympathetic': {'jj_to_rb': 'sympathetically', 'jj_to_nn': 'sympathy', 'nn_to_rb': 'sympathetically'},
 'systematic': {'jj_to_rb': 'systematically', 'jj_to_nn': 'system'},
 'taxable': {'jj_to_rb': 'taxably', 'jj_to_nn': 'tax', 'jj_to_vb': 'tax'},
 'technological': {'jj_to_rb': 'technologically', 'jj_to_nn': 'technology'},
 'telegraphic': {'jj_to_rb': 'telegraphically', 'jj_to_nn': 'telegraph', 'jj_to_vb': 'telegraph'},
 'temporary': {'jj_to_rb': 'temporarily', 'nn_to_rb': 'temporarily'},
 'tender': {'jj_to_rb': 'tenderly', 'nn_to_nns': 'tenders', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_rb': 'tenderly', 'vb_to_rb': 'tenderly', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'n_is_sth': '2', 'jj_to_jjr': 'tenderer', 'jj_to_jjs': 'tenderest'},
 'tense': {'jj_to_rb': 'tensely', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'tensely', 'vb_to_rb': 'tensely', 'vbd_eq_vbn': '', 'jj_to_jjr': 'tenser', 'jj_to_jjs': 'tensest'},
 'terrible': {'jj_to_rb': 'terribly', 'jj_to_nn': 'terribleness'},
 'textual': {'jj_to_rb': 'textually', 'jj_to_nn': 'text', 'jj_to_vb': 'text'},
 'textural': {'jj_to_rb': 'textually', 'jj_to_nn': 'text', 'jj_to_vb': 'text'},
 'thankful': {'jj_to_rb': 'thankfully', 'jj_to_nn': 'thank', 'jj_to_vb': 'thank'},
 'theatrical': {'jj_to_rb': 'theatrically', 'jj_to_nn': 'theatre', 'jj_to_vb': 'theatricalize'},
 'thematic': {'jj_to_rb': 'thematically', 'jj_to_nn': 'theme'},
 'theme': {'jj_to_rb': 'thematically', 'nn_to_nns': 'themes', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'thematic', 'nn_to_rb': 'thematically', 'nc_typical': ''},
 'theoretical': {'jj_to_rb': 'theoretically', 'jj_to_nn': 'theory'},
 'thick': {'jj_to_rb': 'thickly', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_rb': 'thickly', 'jj_to_jjr': 'thicker', 'jj_to_jjs': 'thickest'},
 'thin': {'jj_to_rb': 'thinly', 'nn_to_rb': 'thinly', 'vb_to_rb': 'thinly', 'jj_to_jjr': 'thinner', 'jj_to_jjs': 'thinnest'},
 'think': {'jj_to_rb': 'thoughtfully', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_rb': 'thoughtfully', 'v_compcl': '', 'v_to_vb': '', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_about': '', 'v_for': '', 'v_of': '', 'vb_to_vbz': 'thinks', 'vb_to_vbd': 'thought', 'vb_to_vbn': 'thought', 'vb_to_rb': 'thoughtfully', 'vb_to_vbg': 'thinking', 'v_n_jj': ''},
 'thinking': {'jj_to_rb': 'thoughtfully', 'jj_to_nn': 'think', 'jj_to_vb': 'think', 'n_is_nu': '', 'nn_to_vb': 'think', 'nn_to_jj': 'think', 'nn_to_rb': 'thoughtfully', 'vbg_to_vb': 'think', 'vbg_to_vbn': 'thought', 'nu_typical': ''},
 'thoughtful': {'jj_to_rb': 'thoughtfully', 'jj_to_nn': 'think', 'jj_to_vb': 'think'},
 'thirtieth': {'jj_to_rb': 'thirstily', 'jj_to_nn': 'thirty'},
 'thorough': {'jj_to_rb': 'thoroughly', 'jj_to_nn': 'thoroughness'},
 'threaded': {'jj_to_rb': 'threadbare', 'jj_to_nn': 'thread', 'jj_to_vb': 'thread', 'vbd_eq_vbn': ''},
 'third': {'jj_to_rb': 'thirdly', 'jj_to_nn': 'three', 'nn_to_nns': 'thirds', 'n_is_sth': ''},
 'thunderous': {'jj_to_rb': 'thunderously', 'jj_to_nn': 'thunder'},
 'tidy': {'jj_to_rb': 'tidily', 'nn_to_rb': 'tidily', 'v_n': '', 'nsubjpass': '', 'vb_to_rb': 'tidily', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'jj_to_jjr': 'tidier', 'jj_to_jjs': 'tidiest'},
 'tight': {'jj_to_rb': 'tightly', 'jj_to_nn': 'tightness', 'jj_to_vb': 'tighten', 'jj_to_jjr': 'tighter', 'jj_to_jjs': 'tightest'},
 'timeless': {'jj_to_rb': 'timely', 'jj_to_nn': 'time', 'jj_to_vb': 'time'},
 'tired': {'jj_to_rb': 'tiredly', 'jj_to_nn': 'tire', 'jj_to_vb': 'tire', 'sb_be_jj': '', 'vbd_eq_vbn': ''},
 'topical': {'jj_to_rb': 'topically', 'jj_to_nn': 'topic'},
 'total': {'jj_to_rb': 'totally', 'jj_to_vb': 'totalize', 'nn_to_nns': 'totals', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'totalize', 'nn_to_rb': 'totally', 'v_n': '', 'nsubjpass': '', 'vb_to_rb': 'totally', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'tough': {'jj_to_rb': 'toughly', 'jj_to_vb': 'toughen', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_vb': 'toughen', 'nn_to_rb': 'toughly', 'jj_to_jjr': 'tougher', 'jj_to_jjs': 'toughest'},
 'traditional': {'jj_to_rb': 'traditionally', 'jj_to_nn': 'tradition'},
 'traditionary': {'jj_to_rb': 'traditionally', 'jj_to_nn': 'tradition'},
 'traditionalistic': {'jj_to_rb': 'traditionally', 'jj_to_nn': 'tradition'},
 'transformational': {'jj_to_rb': 'transformationally', 'jj_to_nn': 'transformat', 'jj_to_vb': 'transform'},
 'transitory': {'jj_to_rb': 'transitionally', 'jj_to_nn': 'transit', 'jj_to_vb': 'transit'},
 'transitional': {'jj_to_rb': 'transitionally', 'jj_to_nn': 'transit', 'jj_to_vb': 'transit'},
 'transmissive': {'jj_to_rb': 'transmissively', 'jj_to_nn': 'transmission', 'jj_to_vb': 'transmit'},
 'troublesome': {'jj_to_rb': 'troublesomely', 'jj_to_nn': 'trouble', 'jj_to_vb': 'trouble'},
 'TRUE': {'jj_to_rb': 'truly', 'jj_to_nn': 'truth'},
 'truetable': {'jj_to_rb': 'truly', 'jj_to_nn': 'truth'},
 'truthful': {'jj_to_rb': 'truly', 'jj_to_nn': 'truth'},
 'tuneless': {'jj_to_rb': 'tunelessly', 'jj_to_nn': 'tune', 'jj_to_vb': 'tune'},
 'ugly': {'jj_to_rb': 'uglily', 'jj_to_nn': 'uglifier', 'jj_to_vb': 'uglify', 'jj_to_jjr': 'uglier', 'jj_to_jjs': 'ugliest'},
 'uniform': {'jj_to_rb': 'uniformly', 'nn_to_nns': 'uniforms', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'uniformly', 'vb_to_rb': 'uniformly', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'unique': {'jj_to_rb': 'uniquely', 'nn_to_rb': 'uniquely'},
 'unitive': {'jj_to_rb': 'unitively', 'jj_to_nn': 'unity', 'jj_to_vb': 'unite'},
 'universal': {'jj_to_rb': 'universally', 'jj_to_nn': 'universe'},
 'upsetting': {'jj_to_rb': 'upsettingly', 'jj_to_nn': 'upset', 'jj_to_vb': 'upset', 'sth_be_jj': ''},
 'urgent': {'jj_to_rb': 'urgently', 'jj_to_nn': 'urge', 'jj_to_vb': 'urge'},
 'useful': {'jj_to_rb': 'usefully', 'jj_to_nn': 'use', 'jj_to_vb': 'use'},
 'valid': {'jj_to_rb': 'validly', 'jj_to_nn': 'validation', 'jj_to_vb': 'validate'},
 'validated': {'jj_to_rb': 'validly', 'jj_to_nn': 'validation', 'jj_to_vb': 'validate', 'vbd_eq_vbn': ''},
 'valuable': {'jj_to_rb': 'valuably', 'jj_to_nn': 'value', 'jj_to_vb': 'value', 'nn_to_vb': 'value', 'nn_to_rb': 'valuably'},
 'variable': {'jj_to_rb': 'variably', 'jj_to_nn': 'vary', 'jj_to_vb': 'vary', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'vary', 'nn_to_rb': 'variably'},
 'victorious': {'jj_to_rb': 'victoriously', 'jj_to_nn': 'victory'},
 'violable': {'jj_to_rb': 'violably', 'jj_to_nn': 'violator', 'jj_to_vb': 'violate'},
 'virtual': {'jj_to_rb': 'virtually', 'jj_to_nn': 'virtualization', 'jj_to_vb': 'virtualize'},
 'virtuous': {'jj_to_rb': 'virtuously', 'jj_to_nn': 'virtue', 'jj_to_vb': 'virtue'},
 'visible': {'jj_to_rb': 'visibly', 'jj_to_nn': 'visibility'},
 'visional': {'jj_to_rb': 'visionally', 'jj_to_nn': 'vision', 'jj_to_vb': 'vision'},
 'visual': {'jj_to_rb': 'visually', 'jj_to_nn': 'visualisation', 'jj_to_vb': 'visualise'},
 'voiced': {'jj_to_rb': 'voicelessly', 'jj_to_nn': 'voice', 'jj_to_vb': 'voice', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'voluntary': {'jj_to_rb': 'voluntarily', 'n_is_sb': '2', 'nn_to_rb': 'voluntarily', 'n_is_sth': '2'},
 'warm': {'jj_to_rb': 'warmly', 'nn_to_rb': 'warmly', 'vb_to_rb': 'warmly', 'jj_to_nn': 'warmness', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'jj_to_jjr': 'warmer', 'jj_to_jjs': 'warmest'},
 'wasteful': {'jj_to_rb': 'wastefully', 'jj_to_nn': 'waste', 'jj_to_vb': 'wast'},
 'waxy': {'jj_to_rb': 'waxily', 'jj_to_nn': 'wax', 'jj_to_vb': 'wax'},
 'weak': {'jj_to_rb': 'weakly', 'jj_to_nn': 'weakness', 'jj_to_vb': 'weaken', 'jj_to_jjr': 'weaker', 'jj_to_jjs': 'weakest'},
 'wealthy': {'jj_to_rb': 'wealthily', 'jj_to_nn': 'wealth', 'jj_to_jjr': 'wealthier', 'jj_to_jjs': 'wealthiest'},
 'wearable': {'jj_to_rb': 'wearily', 'jj_to_nn': 'wear', 'jj_to_vb': 'wear', 'n_is_nc': '', 'n_is_sth': ''},
 'welcome': {'jj_to_rb': 'welcomely', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'welcomely', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'welcomes', 'vb_to_vbd': 'welcomed', 'vb_to_vbn': 'welcomed', 'vb_to_rb': 'welcomely', 'vb_to_vbg': 'welcoming', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'wet': {'jj_to_rb': 'wetly', 'jj_to_vb': 'wetten', 'nn_to_nns': 'wets', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'wetten', 'nn_to_rb': 'wetly', 'vb_eq_vbd': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'jj_to_jjr': 'wetter', 'jj_to_jjs': 'wettest', 'vbd_eq_vbn': ''},
 'whole': {'jj_to_rb': 'wholly', 'nn_to_nns': 'wholes', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'wholly'},
 'wide': {'jj_to_rb': 'widely', 'jj_to_vb': 'widen', 'nn_to_vb': 'widen', 'nn_to_rb': 'widely', 'jj_to_jjr': 'wider', 'jj_to_jjs': 'widest'},
 'wild': {'jj_to_rb': 'wildly', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'wildly', 'jj_to_jjr': 'wilder', 'jj_to_jjs': 'wildest'},
 'windy': {'jj_to_rb': 'windily', 'jj_to_nn': 'wind', 'jj_to_vb': 'wind', 'jj_to_jjr': 'windier', 'jj_to_jjs': 'windiest'},
 'wintry': {'jj_to_rb': 'wintrily', 'jj_to_nn': 'winter', 'jj_to_jjr': 'wintrier', 'jj_to_jjs': 'wintriest'},
 'wireless': {'jj_to_rb': 'wirelessly', 'jj_to_nn': 'wire', 'jj_to_vb': 'wire', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'wise': {'jj_to_rb': 'wisely', 'jj_to_vb': 'wisen', 'n_is_nu': '', 'n_is_sb': '2', 'nn_to_vb': 'wisen', 'nn_to_rb': 'wisely', 'n_is_sth': '2', 'jj_to_jjr': 'wiser', 'jj_to_jjs': 'wisest'},
 'wishful': {'jj_to_rb': 'wishfully', 'jj_to_nn': 'wish', 'jj_to_vb': 'wish'},
 'wonderful': {'jj_to_rb': 'wonderfully', 'jj_to_nn': 'wonder', 'jj_to_vb': 'wonder'},
 'wordless': {'jj_to_rb': 'wordlessly', 'jj_to_nn': 'word', 'jj_to_vb': 'word'},
 'worshipful': {'jj_to_rb': 'worshipfully', 'jj_to_nn': 'worship', 'jj_to_vb': 'worship'},
 'youthful': {'jj_to_rb': 'youthfully', 'jj_to_nn': 'youth', 'jj_to_vb': 'youthen'},
 'youthy': {'jj_to_rb': 'youthfully', 'jj_to_nn': 'youth', 'jj_to_vb': 'youthen'},
 'accountable': {'jj_to_nn': 'account', 'jj_to_vb': 'account'},
 'accumulative': {'jj_to_nn': 'accumulation', 'jj_to_vb': 'accumulate'},
 'achievable': {'jj_to_nn': 'achievement', 'jj_to_vb': 'achieve'},
 'acquisitive': {'jj_to_nn': 'acquisition', 'jj_to_vb': 'acquire'},
 'adaptable': {'jj_to_nn': 'adaptation', 'jj_to_vb': 'adapt'},
 'additive': {'jj_to_nn': 'addition', 'jj_to_vb': 'add', 'nn_to_nns': 'additives', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'administrative': {'jj_to_nn': 'administration', 'jj_to_vb': 'administrate'},
 'admirable': {'jj_to_nn': 'admiration', 'jj_to_vb': 'admire'},
 'admitted': {'jj_to_nn': 'admission', 'jj_to_vb': 'admit', 'be_jj_to_vbg': '', 'vbd_eq_vbn': ''},
 'adoptive': {'jj_to_nn': 'adoption', 'jj_to_vb': 'adopt'},
 'advanced': {'jj_to_nn': 'advance', 'jj_to_vb': 'advance', 'vbd_to_vb': 'advance', 'vbn_to_vb': 'advance', 'vbn_to_vbg': 'advancing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'advantaged': {'jj_to_nn': 'affair', 'jj_to_vb': 'advantage', 'vbd_to_vb': 'advantage', 'vbn_to_vb': 'advantage', 'vbn_to_vbg': 'advantaging', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'adventurous': {'jj_to_nn': 'afternoon', 'jj_to_vb': 'adventure'},
 'advertising': {'jj_to_nn': 'agent', 'jj_to_vb': 'advertise', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'advisory': {'jj_to_nn': 'aim', 'jj_to_vb': 'advise', 'nn_to_nns': 'advisories', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'affective': {'jj_to_nn': 'affect', 'jj_to_vb': 'affect'},
 'affordable': {'jj_to_nn': 'affordance', 'jj_to_vb': 'afford'},
 'aggregative': {'jj_to_nn': 'aggregation', 'jj_to_vb': 'aggregate'},
 'agreeable': {'jj_to_nn': 'agreement', 'jj_to_vb': 'agree'},
 'agricultural': {'jj_to_nn': 'agriculture'},
 'aided': {'jj_to_nn': 'aid', 'vbd_eq_vbn': ''},
 'allocative': {'jj_to_nn': 'allocation', 'jj_to_vb': 'allocate'},
 'ambiguous': {'jj_to_nn': 'ambiguity'},
 'ambitious': {'jj_to_nn': 'ambition'},
 'amenable': {'jj_to_nn': 'amendment', 'jj_to_vb': 'amend'},
 'amusing': {'jj_to_nn': 'amusement', 'jj_to_vb': 'amuse', 'sth_be_jj': ''},
 'analogous': {'jj_to_nn': 'analogy', 'jj_to_vb': 'analogize', 'be_jj_to_vbg': ''},
 'analytic': {'jj_to_nn': 'analysis', 'jj_to_vb': 'analyse'},
 'angry': {'jj_to_nn': 'anger', 'be_jj_to_vb': '', 'jj_to_jjr': 'angrier', 'jj_to_jjs': 'angriest'},
 'angled': {'jj_to_nn': 'angle', 'jj_to_vb': 'angle', 'vbd_to_vb': 'angle', 'vbn_to_vb': 'angle', 'vbn_to_vbg': 'angling', 'vbd_eq_vbn': ''},
 'annoying': {'jj_to_nn': 'annoyance', 'vbg_to_vb': 'annoy', 'vbg_to_vbn': 'annoyed'},
 'annoyed': {'jj_to_nn': 'annoyance', 'n_is_sb': '0', 'vbd_to_vb': 'annoy', 'vbn_to_vb': 'annoy', 'vbn_to_vbg': 'annoying', 'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'answering': {'jj_to_nn': 'answer', 'jj_to_vb': 'answer', 'nn_to_vb': 'answer', 'vbg_to_vb': 'answer', 'vbg_to_vbn': 'answered'},
 'apologetic': {'jj_to_nn': 'apology'},
 'appendant': {'jj_to_nn': 'appendix', 'jj_to_vb': 'append', 'nn_to_vb': 'append'},
 'applaudable': {'jj_to_nn': 'applause', 'jj_to_vb': 'applaud'},
 'appointive': {'jj_to_nn': 'appointment', 'jj_to_vb': 'appoint'},
 'approving': {'jj_to_nn': 'approval', 'jj_to_vb': 'approve', 'vbg_to_vb': 'approve', 'vbg_to_vbn': 'approved'},
 'arguable': {'jj_to_nn': 'argument', 'jj_to_vb': 'argue'},
 'arisen': {'jj_to_nn': 'arise', 'jj_to_vb': 'arise', 'vi_typical': ''},
 'armed': {'jj_to_nn': 'arm', 'jj_to_vb': 'arm', 'nn_to_vb': 'arm', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'arranged': {'jj_to_nn': 'arrangement', 'jj_to_vb': 'arrange', 'vbd_to_vb': 'arrange', 'vbn_to_vb': 'arrange', 'vbn_to_vbg': 'arranging', 'vbd_eq_vbn': ''},
 'arresting': {'jj_to_nn': 'arrest', 'jj_to_vb': 'arrest', 'vbg_to_vb': 'arrest', 'vbg_to_vbn': 'arrested'},
 'arrived': {'jj_to_nn': 'arrival', 'jj_to_vb': 'arrive', 'vbd_to_vb': 'arrive', 'vbn_to_vb': 'arrive', 'vbn_to_vbg': 'arriving', 'vbd_eq_vbn': ''},
 'arrowed': {'jj_to_nn': 'arrow', 'jj_to_vb': 'arrow', 'jj_ed': ''},
 'artistic': {'jj_to_nn': 'art', 'jj_to_vb': 'art'},
 'articled': {'jj_to_nn': 'article', 'jj_to_vb': 'article', 'vbd_to_vb': 'article', 'vbn_to_vb': 'article', 'vbn_to_vbg': 'articling', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'artificial': {'jj_to_nn': 'artificiality', 'jj_to_vb': 'artificialize'},
 'assembling': {'jj_to_nn': 'assembly', 'jj_to_vb': 'assemble', 'nn_to_vb': 'assemble'},
 'assessable': {'jj_to_nn': 'assessment', 'jj_to_vb': 'assess'},
 'assigned': {'jj_to_nn': 'assignment', 'jj_to_vb': 'assign', 'vbd_eq_vbn': ''},
 'assistant': {'jj_to_nn': 'assistance', 'jj_to_vb': 'assist', 'nn_to_nns': 'assistants', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nn_to_vb': 'assist', 'nc_typical': ''},
 'associate': {'jj_to_nn': 'association', 'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'associates', 'vb_to_vbd': 'associated', 'vb_to_vbn': 'associated', 'vb_to_nn': 'association', 'vb_to_vbg': 'associating', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'n_is_sth': '2'},
 'assumed': {'jj_to_nn': 'assumption', 'jj_to_vb': 'assume', 'vbd_to_vb': 'assume', 'vbn_to_vb': 'assume', 'vbn_to_vbg': 'assuming', 'vbd_eq_vbn': ''},
 'assured': {'jj_to_nn': 'assurance', 'jj_to_vb': 'assure', 'vbd_to_vb': 'assure', 'vbn_to_vb': 'assure', 'vbn_to_vbg': 'assuring', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'astonishing': {'jj_to_nn': 'astonishment', 'jj_to_vb': 'astonish', 'sth_be_jj': ''},
 'attaching': {'jj_to_nn': 'attachment', 'jj_to_vb': 'attach', 'vbg_to_vb': 'attach', 'vbg_to_vbn': 'attached'},
 'attacking': {'jj_to_nn': 'attack', 'jj_to_vb': 'attack', 'vbg_to_vb': 'attack', 'vbg_to_vbn': 'attacked'},
 'attainable': {'jj_to_nn': 'attainment', 'jj_to_vb': 'attain'},
 'attempted': {'jj_to_nn': 'attempt', 'jj_to_vb': 'attempt', 'vbd_eq_vbn': ''},
 'attendant': {'jj_to_nn': 'attendance', 'jj_to_vb': 'attend', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nn_to_vb': 'attend'},
 'attributable': {'jj_to_nn': 'attribution', 'jj_to_vb': 'attribute'},
 'authoritative': {'jj_to_nn': 'authority', 'jj_to_vb': 'authorize'},
 'automatic': {'jj_to_nn': 'automation', 'jj_to_vb': 'automate', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'automate', 'rb_to_nn': 'automation', 'rb_to_vb': 'automate'},
 'available': {'jj_to_nn': 'availability', 'jj_to_vb': 'avail', 'be_jj_to_vbg': ''},
 'averaged': {'jj_to_nn': 'average', 'jj_to_vb': 'average', 'vbd_eq_vbn': ''},
 'avoidable': {'jj_to_nn': 'avoidance', 'jj_to_vb': 'avoid'},
 'awake': {'jj_to_nn': 'awakeness', 'jj_to_vb': 'awaken', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'awakes', 'vb_to_vbd': 'awaked', 'vb_to_vbn': 'awaked', 'vb_to_nn': 'awakeness', 'vb_to_vbg': 'awaking', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vbg_non': ''},
 'aware': {'jj_to_nn': 'awareness'},
 'baking': {'jj_to_nn': 'bake', 'jj_to_vb': 'bake', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'bake', 'vbg_to_vb': 'bake', 'vbg_to_vbn': 'baked'},
 'balanced': {'jj_to_nn': 'balance', 'jj_to_vb': 'balance', 'vbd_to_vb': 'balance', 'vbn_to_vb': 'balance', 'vbn_to_vbg': 'balancing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'banded': {'jj_to_nn': 'band', 'jj_to_vb': 'band', 'vbd_to_vb': 'band', 'vbn_to_vb': 'band', 'vbn_to_vbg': 'banding', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'bare': {'jj_to_nn': 'baring', 'vb_to_nn': 'baring', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'jj_to_jjr': 'barer', 'jj_to_jjs': 'barest'},
 'base': {'jj_to_nn': 'basis', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_in': '', 'vb_to_vbz': 'bases', 'vb_to_vbd': 'based', 'vb_to_vbn': 'based', 'vb_to_nn': 'basis', 'vb_to_vbg': 'basing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'jj_to_jjr': 'baser', 'jj_to_jjs': 'basest'},
 'basic': {'jj_to_nn': 'basis', 'jj_to_vb': 'base', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'base', 'nn_to_jj': 'base'},
 'bathed': {'jj_to_nn': 'bath', 'jj_to_vb': 'bath', 'vbd_to_vb': 'bath', 'vbn_to_vb': 'bath', 'vbn_to_vbg': 'bathing', 'vbd_eq_vbn': ''},
 'beaked': {'jj_to_nn': 'beak'},
 'beamed': {'jj_to_nn': 'beam', 'jj_to_vb': 'beam', 'vbd_eq_vbn': ''},
 'bearded': {'jj_to_nn': 'beard', 'jj_to_vb': 'beard', 'vbd_to_vb': 'beard', 'vbn_to_vb': 'beard', 'vbn_to_vbg': 'bearding', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'beaten': {'jj_to_nn': 'beat', 'jj_to_vb': 'beat', 'vb_to_nn': 'beat', 'vb_to_jj': 'beat'},
 'bedding': {'jj_to_nn': 'bed', 'jj_to_vb': 'bed', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'bed'},
 'behavioural': {'jj_to_nn': 'behaviour'},
 'believing': {'jj_to_nn': 'belief', 'jj_to_vb': 'believe', 'vbg_to_vb': 'believe', 'vbg_to_vbn': 'believed'},
 'belted': {'jj_to_nn': 'belting', 'jj_to_vb': 'belt', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'beneficial': {'jj_to_nn': 'benefit', 'jj_to_vb': 'benefit'},
 'binding': {'jj_to_nn': 'bind', 'jj_to_vb': 'bind', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'bind'},
 'biting': {'jj_to_nn': 'bite', 'jj_to_vb': 'bite', 'vbg_to_vb': 'bite', 'vbg_to_vbn': 'bitten'},
 'blamed': {'jj_to_nn': 'blame', 'jj_to_vb': 'blame', 'vbd_to_vb': 'blame', 'vbn_to_vb': 'blame', 'vbn_to_vbg': 'blaming', 'vbd_eq_vbn': ''},
 'blessed': {'jj_to_nn': 'blessing', 'jj_to_vb': 'bless', 'vbd_to_vb': 'bless', 'vbn_to_vb': 'bless', 'vbn_to_vbg': 'blessing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'blind': {'jj_to_nn': 'blindness', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'blinds', 'vb_to_vbd': 'blinded', 'vb_to_vbn': 'blinded', 'vb_to_rb': 'blindly', 'vb_to_nn': 'blindness', 'rb_to_nn': 'blindness', 'vb_to_vbg': 'blinding', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'blocked': {'jj_to_nn': 'block', 'jj_to_vb': 'block', 'vbd_to_vb': 'block', 'vbn_to_vb': 'block', 'vbn_to_vbg': 'blocking', 'vbd_eq_vbn': ''},
 'blown': {'jj_to_nn': 'blow', 'jj_to_vb': 'blow', 'nn_to_vb': 'blow', 'vbn_to_vb': 'blow', 'vbn_to_vbd': 'blew', 'vbn_to_vbg': 'blowing'},
 'blue': {'jj_to_nn': 'blueness', 'nn_to_nns': 'blues', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'blues', 'vb_to_vbd': 'blued', 'vb_to_vbn': 'blued', 'vb_to_nn': 'blueness', 'vb_to_vbg': 'bluing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'jj_to_jjr': 'bluer', 'jj_to_jjs': 'bluest'},
 'boastful': {'jj_to_nn': 'boast', 'jj_to_vb': 'boast'},
 'bodily': {'jj_to_nn': 'body', 'jj_to_vb': 'body', 'nn_to_vb': 'body', 'rb_to_nn': 'body', 'rb_to_vb': 'body'},
 'boiling': {'jj_to_nn': 'boil', 'jj_to_vb': 'boil', 'nn_to_vb': 'boil', 'vb_to_vbz': 'boilings', 'vb_to_vbd': 'boilinged', 'vb_to_vbn': 'boilinged', 'rb_to_nn': 'boil', 'rb_to_vb': 'boil', 'vbg_to_vb': 'boil', 'vbg_to_vbn': 'boiled'},
 'bonding': {'jj_to_nn': 'bond', 'jj_to_vb': 'bond', 'nn_to_vb': 'bond'},
 'boned': {'jj_to_nn': 'bone', 'jj_to_vb': 'bone', 'nn_to_vb': 'bone', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'bordered': {'jj_to_nn': 'border', 'jj_to_vb': 'border', 'vbd_eq_vbn': ''},
 'borrowed': {'jj_to_nn': 'borrowing', 'jj_to_vb': 'borrow', 'vbd_to_vb': 'borrow', 'vbn_to_vb': 'borrow', 'vbn_to_vbg': 'borrowing', 'vbd_eq_vbn': ''},
 'bottled': {'jj_to_nn': 'bottle', 'jj_to_vb': 'bottle', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'bounded': {'jj_to_nn': 'bound', 'jj_to_vb': 'bound', 'vbd_to_vb': 'bound', 'vbn_to_vb': 'bound', 'vbn_to_vbg': 'bounding', 'vbd_eq_vbn': ''},
 'bowed': {'jj_to_nn': 'bow', 'jj_to_vb': 'bow', 'vbd_eq_vbn': ''},
 'breakable': {'jj_to_nn': 'break', 'jj_to_vb': 'break'},
 'broad': {'jj_to_nn': 'breadth', 'jj_to_vb': 'broaden', 'nn_to_nns': 'broads', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_vb': 'broaden', 'rb_to_nn': 'breadth', 'rb_to_vb': 'broaden', 'n_is_sth': '2', 'jj_to_jjr': 'broader', 'jj_to_jjs': 'broadest'},
 'brotherly': {'jj_to_nn': 'brother', 'rb_to_nn': 'brother'},
 'brushed': {'jj_to_nn': 'brush', 'jj_to_vb': 'brush', 'vbd_to_vb': 'brush', 'vbn_to_vb': 'brush', 'vbn_to_vbg': 'brushing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'bundling': {'jj_to_nn': 'bundle', 'jj_to_vb': 'bundle', 'nn_to_vb': 'bundle'},
 'burning': {'jj_to_nn': 'burn', 'jj_to_vb': 'burn', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'burn', 'vbg_to_vb': 'burn', 'vbg_to_vbn': 'burned'},
 'bursting': {'jj_to_nn': 'burst', 'jj_to_vb': 'burst', 'vbg_to_vb': 'burst', 'vbg_to_vbn': 'bursted'},
 'buried': {'jj_to_nn': 'burying', 'jj_to_vb': 'bury', 'vbd_to_vb': 'bury', 'vbn_to_vb': 'bury', 'vbn_to_vbg': 'burying', 'vbd_eq_vbn': ''},
 'buttered': {'jj_to_nn': 'butter', 'jj_to_vb': 'butter', 'vbd_to_vb': 'butter', 'vbn_to_vb': 'butter', 'vbn_to_vbg': 'buttering', 'vbd_eq_vbn': ''},
 'buttoned': {'jj_to_nn': 'button', 'jj_to_vb': 'button', 'vbd_to_vb': 'button', 'vbn_to_vb': 'button', 'vbn_to_vbg': 'buttoning', 'vbd_eq_vbn': ''},
 'caged': {'jj_to_nn': 'cage', 'jj_to_vb': 'cage', 'vbd_eq_vbn': ''},
 'calculating': {'jj_to_nn': 'calculation', 'jj_to_vb': 'calculate', 'vbg_to_vb': 'calculate', 'vbg_to_vbn': 'calculated'},
 'called': {'jj_to_nn': 'call', 'jj_to_vb': 'call', 'vbd_to_vb': 'call', 'vbn_to_vb': 'call', 'vbn_to_vbg': 'calling', 'vbd_eq_vbn': ''},
 'camped': {'jj_to_nn': 'camp', 'jj_to_vb': 'camp', 'vbd_to_vb': 'camp', 'vbn_to_vb': 'camp', 'vbn_to_vbg': 'camping', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'capped': {'jj_to_nn': 'cap', 'jj_to_vb': 'cap', 'vbd_to_vb': 'cap', 'vbn_to_vb': 'cap', 'vbn_to_vbg': 'capping', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'caped': {'jj_to_nn': 'cape'},
 'carrying': {'jj_to_nn': 'carry', 'jj_to_vb': 'carry', 'nn_to_vb': 'carry', 'vbg_to_vb': 'carry', 'vbg_to_vbn': 'carried'},
 'catching': {'jj_to_nn': 'catch', 'jj_to_vb': 'catch', 'vbg_to_vb': 'catch', 'vbg_to_vbn': 'caught'},
 'categorial': {'jj_to_nn': 'category', 'jj_to_vb': 'categorise'},
 'caved': {'jj_to_nn': 'cave', 'jj_to_vb': 'cave', 'vbd_eq_vbn': ''},
 'chained': {'jj_to_nn': 'chain', 'jj_to_vb': 'chain', 'vbd_eq_vbn': ''},
 'challenging': {'jj_to_nn': 'challenge', 'jj_to_vb': 'challenge', 'vbg_to_vb': 'challenge', 'vbg_to_vbn': 'challenged', 'sth_be_jj': ''},
 'characteristic': {'jj_to_nn': 'character', 'jj_to_vb': 'character', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'character'},
 'charming': {'jj_to_nn': 'charm', 'jj_to_vb': 'charm'},
 'cheating': {'jj_to_nn': 'cheat', 'jj_to_vb': 'cheat', 'nn_to_vb': 'cheat', 'vbg_to_vb': 'cheat', 'vbg_to_vbn': 'cheated'},
 'checked': {'jj_to_nn': 'check', 'jj_to_vb': 'check', 'vbd_to_vb': 'check', 'vbn_to_vb': 'check', 'vbn_to_vbg': 'checking', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'cheerful': {'jj_to_nn': 'cheer', 'jj_to_vb': 'cheer'},
 'civilized': {'jj_to_nn': 'civilisation', 'jj_to_vb': 'civilize', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'clarified': {'jj_to_nn': 'clarification', 'jj_to_vb': 'clarify', 'vbd_eq_vbn': ''},
 'classified': {'jj_to_nn': 'class', 'jj_to_vb': 'class', 'nn_to_vb': 'class', 'nn_to_jj': 'class', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'classic': {'jj_to_nn': 'classical', 'nn_to_nns': 'classics', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'nn_to_jj': 'classical'},
 'clear': {'jj_to_nn': 'clearness', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_of': '', 'v_from': '', 'vb_to_vbz': 'clears', 'vb_to_vbd': 'cleared', 'vb_to_vbn': 'cleared', 'vb_to_nn': 'clearness', 'rb_to_nn': 'clearness', 'jj_to_rb': 'clearly', 'vb_to_vbg': 'clearing', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'jj_to_jjr': 'clearer', 'jj_to_jjs': 'clearest'},
 'climbing': {'jj_to_nn': 'climb', 'jj_to_vb': 'climb', 'nn_to_vb': 'climb', 'vbg_to_vb': 'climb', 'vbg_to_vbn': 'climbed'},
 'close': {'jj_to_nn': 'closeness', 'nn_to_nns': 'closes', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'closes', 'vb_to_vbd': 'closed', 'vb_to_vbn': 'closed', 'vb_to_nn': 'closeness', 'rb_to_nn': 'closeness', 'vb_to_vbg': 'closing', 'be_jj_to_vbg': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'jj_to_jjr': 'closer', 'jj_to_jjs': 'closest'},
 'cloudy': {'jj_to_nn': 'cloud', 'jj_to_vb': 'cloud'},
 'clubbed': {'jj_to_nn': 'club', 'jj_to_vb': 'club', 'vbd_eq_vbn': ''},
 'coincident': {'jj_to_nn': 'coherence', 'jj_to_vb': 'coincide'},
 'collapsible': {'jj_to_nn': 'collapse', 'jj_to_vb': 'collapse'},
 'collective': {'jj_to_nn': 'collection', 'jj_to_vb': 'collect', 'nn_to_nns': 'collectives', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'collect'},
 'colonial': {'jj_to_nn': 'colonization', 'jj_to_vb': 'colonize', 'n_is_sb': '0', 'nn_to_vb': 'colonize'},
 'colorful': {'jj_to_nn': 'colour', 'jj_to_vb': 'colour'},
 'combined': {'jj_to_nn': 'combination', 'jj_to_vb': 'combine', 'vbd_to_vb': 'combine', 'vbn_to_vb': 'combine', 'vbn_to_vbg': 'combining', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'commanding': {'jj_to_nn': 'command', 'jj_to_vb': 'command', 'vbg_to_vb': 'command', 'vbg_to_vbn': 'commanded'},
 'committed': {'jj_to_nn': 'commitment', 'jj_to_vb': 'commit', 'be_vbn_to_vbg': '', 'be_jj_to_vbg': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'communicative': {'jj_to_nn': 'communication', 'jj_to_vb': 'communicate'},
 'comparative': {'jj_to_nn': 'comparison', 'jj_to_vb': 'compare'},
 'compatible': {'jj_to_nn': 'compatibility'},
 'compensatory': {'jj_to_nn': 'compensation', 'jj_to_vb': 'compensate'},
 'competing': {'jj_to_nn': 'competition', 'jj_to_vb': 'compete', 'vbg_to_vb': 'compete', 'vbg_to_vbn': 'competed'},
 'compiled': {'jj_to_nn': 'compilation', 'jj_to_vb': 'compile', 'vbd_eq_vbn': ''},
 'complaining': {'jj_to_nn': 'complaint', 'jj_to_vb': 'complain', 'vbg_to_vb': 'complain', 'vbg_to_vbn': 'complained'},
 'complementary': {'jj_to_nn': 'complement', 'jj_to_vb': 'complement'},
 'complicated': {'jj_to_nn': 'complication', 'jj_to_vb': 'complicate', 'vb_to_vbz': 'complicateds', 'vb_to_vbd': 'complicateded', 'vb_to_vbn': 'complicateded', 'vb_to_vbg': 'complicateding', 'vbd_eq_vbn': '', 'jj_ed': ''},
 'composed': {'jj_to_nn': 'composition', 'jj_to_vb': 'compose', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'compounded': {'jj_to_nn': 'compound', 'jj_to_vb': 'compound', 'vbd_eq_vbn': ''},
 'computational': {'jj_to_nn': 'computation', 'jj_to_vb': 'compute'},
 'conceivable': {'jj_to_nn': 'conception', 'jj_to_vb': 'conceive'},
 'concentrated': {'jj_to_nn': 'concentration', 'jj_to_vb': 'concentrate', 'vbd_to_vb': 'concentrate', 'vbn_to_vb': 'concentrate', 'vbn_to_vbg': 'concentrating', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'conceptual': {'jj_to_nn': 'concept', 'jj_to_vb': 'conceptualise'},
 'concerned': {'jj_to_nn': 'concern', 'jj_to_vb': 'concern', 'vbd_to_vb': 'concern', 'vbn_to_vb': 'concern', 'vbn_to_vbg': 'concerning', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'conclusive': {'jj_to_nn': 'conclusion', 'jj_to_vb': 'conclude'},
 'conditional': {'jj_to_nn': 'condition', 'jj_to_vb': 'condition'},
 'conductive': {'jj_to_nn': 'conduct', 'jj_to_vb': 'conduct'},
 'confessed': {'jj_to_nn': 'confession', 'jj_to_vb': 'confess', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'confined': {'jj_to_nn': 'confine', 'jj_to_vb': 'confine', 'be_vbn_to_vbg': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'confirmed': {'jj_to_nn': 'confirmation', 'jj_to_vb': 'confirm', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'conflictive': {'jj_to_nn': 'conflict', 'jj_to_vb': 'conflict'},
 'conform': {'jj_to_nn': 'conformation', 'vb_to_nn': 'conformation', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'conformable': {'jj_to_nn': 'conformation', 'jj_to_vb': 'conform'},
 'confusing': {'jj_to_nn': 'confusion', 'jj_to_vb': 'confuse', 'sth_be_jj': ''},
 'connected': {'jj_to_nn': 'connection', 'jj_to_vb': 'connect', 'vbd_to_vb': 'connect', 'vbn_to_vb': 'connect', 'vbn_to_vbg': 'connecting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'consenting': {'jj_to_nn': 'consensus', 'jj_to_vb': 'consent', 'vbg_to_vb': 'consent', 'vbg_to_vbn': 'consented'},
 'considerable': {'jj_to_nn': 'consideration', 'jj_to_vb': 'consider'},
 'consistent': {'jj_to_nn': 'consistency', 'jj_to_vb': 'consist'},
 'constitutive': {'jj_to_nn': 'constitution', 'jj_to_vb': 'constitute', 'nn_to_vb': 'constitute'},
 'constrained': {'jj_to_nn': 'constraint', 'jj_to_vb': 'constrain', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'constructive': {'jj_to_nn': 'construction', 'jj_to_vb': 'construct'},
 'consultative': {'jj_to_nn': 'consultation', 'jj_to_vb': 'consult'},
 'consuming': {'jj_to_nn': 'consumption', 'jj_to_vb': 'consume'},
 'contactable': {'jj_to_nn': 'contact', 'jj_to_vb': 'contact'},
 'contained': {'jj_to_nn': 'containing', 'jj_to_vb': 'contain', 'vbd_to_vb': 'contain', 'vbn_to_vb': 'contain', 'vbn_to_vbg': 'containing', 'vbd_eq_vbn': ''},
 'contextual': {'jj_to_nn': 'context', 'jj_to_vb': 'contextualise'},
 'continuous': {'jj_to_nn': 'continuity', 'jj_to_vb': 'continue'},
 'contracted': {'jj_to_nn': 'contract', 'jj_to_vb': 'contract', 'vbd_to_vb': 'contract', 'vbn_to_vb': 'contract', 'vbn_to_vbg': 'contracting', 'vbd_eq_vbn': ''},
 'contradictory': {'jj_to_nn': 'contradiction', 'jj_to_vb': 'contradict', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'contradict'},
 'contrastive': {'jj_to_nn': 'contrast', 'jj_to_vb': 'contrast'},
 'contributed': {'jj_to_nn': 'contribution', 'jj_to_vb': 'contribute', 'vbd_to_vb': 'contribute', 'vbn_to_vb': 'contribute', 'vbn_to_vbg': 'contributing', 'vbd_eq_vbn': ''},
 'controllable': {'jj_to_nn': 'control', 'jj_to_vb': 'control'},
 'controversial': {'jj_to_nn': 'controversy', 'jj_to_vb': 'controvert'},
 'conventional': {'jj_to_nn': 'convention', 'jj_to_vb': 'convene'},
 'converse': {'jj_to_nn': 'conversation', 'n_is_nc': '', 'n_is_sth': '', 'vb_to_nn': 'conversation', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'convertible': {'jj_to_nn': 'conversion', 'jj_to_vb': 'convert', 'nn_to_vb': 'convert'},
 'cooking': {'jj_to_nn': 'cook', 'jj_to_vb': 'cook', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'cook', 'vbg_to_vb': 'cook', 'vbg_to_vbn': 'cooked'},
 'cooperative': {'jj_to_nn': 'cooperation', 'jj_to_vb': 'cooperate', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'cooperate'},
 'coordinate': {'jj_to_nn': 'coordination', 'n_is_nc': '', 'n_is_sth': '', 'vb_to_nn': 'coordination', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'coordinative': {'jj_to_nn': 'coordination', 'jj_to_vb': 'coordinate'},
 'copied': {'jj_to_nn': 'copy', 'jj_to_vb': 'copy', 'vbd_to_vb': 'copy', 'vbn_to_vb': 'copy', 'vbn_to_vbg': 'copying', 'vbd_eq_vbn': ''},
 'cored': {'jj_to_nn': 'core', 'jj_to_vb': 'core', 'vbd_to_vb': 'core', 'vbn_to_vb': 'core', 'vbn_to_vbg': 'coring', 'vbd_eq_vbn': ''},
 'corked': {'jj_to_nn': 'cork', 'jj_to_vb': 'cork', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'cornered': {'jj_to_nn': 'corner', 'jj_to_vb': 'corner', 'vbd_to_vb': 'corner', 'vbn_to_vb': 'corner', 'vbn_to_vbg': 'cornering', 'vbd_eq_vbn': ''},
 'corporate': {'jj_to_nn': 'corporation', 'vb_to_nn': 'corporation'},
 'correct': {'jj_to_nn': 'correction', 'v_n': '', 'nsubjpass': '', 'vb_to_nn': 'correction', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'corresponding': {'jj_to_nn': 'correspondence', 'jj_to_vb': 'correspond'},
 'costly': {'jj_to_nn': 'cost', 'jj_to_vb': 'cost', 'nn_to_vb': 'cost', 'jj_to_jjr': 'costlier', 'jj_to_jjs': 'costliest'},
 'countable': {'jj_to_nn': 'count', 'jj_to_vb': 'count'},
 'courageous': {'jj_to_nn': 'courage'},
 'covering': {'jj_to_nn': 'coverage', 'jj_to_vb': 'cover', 'nn_to_nns': 'coverings', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'cover', 'vbg_to_vb': 'cover', 'vbg_to_vbn': 'covered'},
 'cowardly': {'jj_to_nn': 'cowardice', 'rb_to_nn': 'cowardice', 'rb_to_jj': 'coward'},
 'cracking': {'jj_to_nn': 'crack', 'jj_to_vb': 'crack', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'crack', 'nn_to_jj': 'crack', 'rb_to_nn': 'crack', 'rb_to_jj': 'crack', 'rb_to_vb': 'crack', 'vbg_to_vb': 'crack', 'vbg_to_vbn': 'cracked'},
 'crashed': {'jj_to_nn': 'crash', 'jj_to_vb': 'crash', 'vbd_to_vb': 'crash', 'vbn_to_vb': 'crash', 'vbn_to_vbg': 'crashing', 'vbd_eq_vbn': ''},
 'creeping': {'jj_to_nn': 'creep', 'jj_to_vb': 'creep', 'nn_to_vb': 'creep'},
 'cropped': {'jj_to_nn': 'crop', 'jj_to_vb': 'crop', 'vbd_to_vb': 'crop', 'vbn_to_vb': 'crop', 'vbn_to_vbg': 'cropping', 'vbd_eq_vbn': ''},
 'crowded': {'jj_to_nn': 'crowd', 'jj_to_vb': 'crowd', 'vbd_to_vb': 'crowd', 'vbn_to_vb': 'crowd', 'vbn_to_vbg': 'crowding', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'crowned': {'jj_to_nn': 'crown', 'jj_to_vb': 'crown', 'vbd_to_vb': 'crown', 'vbn_to_vb': 'crown', 'vbn_to_vbg': 'crowning', 'vbd_eq_vbn': ''},
 'crushed': {'jj_to_nn': 'crush', 'jj_to_vb': 'crush', 'vbd_eq_vbn': ''},
 'crying': {'jj_to_nn': 'cry', 'jj_to_vb': 'cry', 'vbg_to_vb': 'cry', 'vbg_to_vbn': 'cried'},
 'cultivated': {'jj_to_nn': 'cultivation', 'jj_to_vb': 'cultivate', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'cultural': {'jj_to_nn': 'culture', 'jj_to_vb': 'culture'},
 'curable': {'jj_to_nn': 'cure', 'jj_to_vb': 'cure'},
 'curly': {'jj_to_nn': 'curl', 'jj_to_vb': 'curl', 'jj_to_jjr': 'curlier', 'jj_to_jjs': 'curliest'},
 'cursed': {'jj_to_nn': 'curse', 'jj_to_vb': 'curse', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'curved': {'jj_to_nn': 'curve', 'jj_to_vb': 'curve', 'nn_to_vb': 'curve', 'nn_to_jj': 'curve', 'vbd_to_vb': 'curve', 'vbn_to_vb': 'curve', 'vbn_to_vbg': 'curving', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'cutting': {'jj_to_nn': 'cut', 'jj_to_vb': 'cut', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'cut', 'nn_to_jj': 'cut', 'vbg_to_vb': 'cut', 'vbg_to_vbn': 'cut'},
 'cyclical': {'jj_to_nn': 'cycle', 'jj_to_vb': 'cycle'},
 'damaging': {'jj_to_nn': 'damage', 'jj_to_vb': 'damage', 'vbg_to_vb': 'damage', 'vbg_to_vbn': 'damaged'},
 'damp': {'jj_to_nn': 'dampness', 'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vb_to_nn': 'dampness', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nu_typical': '', 'jj_to_jjr': 'damper', 'jj_to_jjs': 'dampest'},
 'daring': {'jj_to_nn': 'dare', 'jj_to_vb': 'dare', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'dare', 'vbg_to_vb': 'dare', 'vbg_to_vbn': 'dared'},
 'dated': {'jj_to_nn': 'date', 'jj_to_vb': 'date', 'vbd_to_vb': 'date', 'vbn_to_vb': 'date', 'vbn_to_vbg': 'dating', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'debatable': {'jj_to_nn': 'debate', 'jj_to_vb': 'debate'},
 'decayed': {'jj_to_nn': 'decay', 'jj_to_vb': 'decay', 'vbd_eq_vbn': ''},
 'deceived': {'jj_to_nn': 'deception', 'jj_to_vb': 'deceive', 'vbd_eq_vbn': ''},
 'decided': {'jj_to_nn': 'deception', 'jj_to_vb': 'decide', 'vbd_to_vb': 'decide', 'vbn_to_vb': 'decide', 'vbn_to_vbg': 'deciding', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'declared': {'jj_to_nn': 'declaration', 'jj_to_vb': 'declare', 'vbd_to_vb': 'declare', 'vbn_to_vb': 'declare', 'vbn_to_vbg': 'declaring', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'declining': {'jj_to_nn': 'declination', 'jj_to_vb': 'decline', 'vbg_to_vb': 'decline', 'vbg_to_vbn': 'declined'},
 'decreasing': {'jj_to_nn': 'decrease', 'jj_to_vb': 'decrease'},
 'deducible': {'jj_to_nn': 'deduction', 'jj_to_vb': 'deduce'},
 'defeated': {'jj_to_nn': 'defeat', 'jj_to_vb': 'defeat', 'vbd_to_vb': 'defeat', 'vbn_to_vb': 'defeat', 'vbn_to_vbg': 'defeating', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'defending': {'jj_to_nn': 'defence', 'jj_to_vb': 'defend', 'vbg_to_vb': 'defend', 'vbg_to_vbn': 'defended'},
 'definable': {'jj_to_nn': 'definition', 'jj_to_vb': 'define'},
 'delayed': {'jj_to_nn': 'delay', 'jj_to_vb': 'delay', 'vbd_to_vb': 'delay', 'vbn_to_vb': 'delay', 'vbn_to_vbg': 'delaying', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'delightful': {'jj_to_nn': 'delight', 'jj_to_vb': 'delight'},
 'delivered': {'jj_to_nn': 'delivery', 'jj_to_vb': 'deliver', 'vbd_to_vb': 'deliver', 'vbn_to_vb': 'deliver', 'vbn_to_vbg': 'delivering', 'vbd_eq_vbn': ''},
 'demanding': {'jj_to_nn': 'demand', 'jj_to_vb': 'demand', 'vbg_to_vb': 'demand', 'vbg_to_vbn': 'demanded'},
 'demonstrable': {'jj_to_nn': 'demonstration', 'jj_to_vb': 'demonstrate'},
 'denotive': {'jj_to_nn': 'denotation', 'jj_to_vb': 'denote'},
 'deniable': {'jj_to_nn': 'denial', 'jj_to_vb': 'deny'},
 'departmental': {'jj_to_nn': 'department'},
 'depressed': {'jj_to_nn': 'depression', 'jj_to_vb': 'depress', 'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'derivative': {'jj_to_nn': 'derivation', 'jj_to_vb': 'derive', 'n_is_nu': '', 'n_is_sth': ''},
 'descending': {'jj_to_nn': 'descent', 'jj_to_vb': 'descend', 'nn_to_vb': 'descend'},
 'descriptive': {'jj_to_nn': 'description', 'jj_to_vb': 'describe'},
 'deserted': {'jj_to_nn': 'desert', 'jj_to_vb': 'desert', 'vbd_to_vb': 'desert', 'vbn_to_vb': 'desert', 'vbn_to_vbg': 'deserting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'designing': {'jj_to_nn': 'design', 'jj_to_vb': 'design', 'nn_to_vb': 'design', 'vbg_to_vb': 'design', 'vbg_to_vbn': 'designed'},
 'desirable': {'jj_to_nn': 'desire', 'jj_to_vb': 'desire'},
 'despairing': {'jj_to_nn': 'despair', 'jj_to_vb': 'despair'},
 'detailed': {'jj_to_nn': 'detail', 'jj_to_vb': 'detail', 'vbd_to_vb': 'detail', 'vbn_to_vb': 'detail', 'vbn_to_vbg': 'detailing', 'vbd_eq_vbn': ''},
 'detectable': {'jj_to_nn': 'detection', 'jj_to_vb': 'detect'},
 'determinate': {'jj_to_nn': 'determination', 'jj_to_vb': 'determine'},
 'developed': {'jj_to_nn': 'development', 'jj_to_vb': 'develop', 'vbd_to_vb': 'develop', 'vbn_to_vb': 'develop', 'vbn_to_vbg': 'developing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'devoted': {'jj_to_nn': 'devotion', 'jj_to_vb': 'devote', 'be_vbn_to_vbg': '', 'jj_ed': '', 'be_jj_to_vbg': '', 'vbd_eq_vbn': ''},
 'dying': {'jj_to_nn': 'die', 'jj_to_vb': 'die', 'nn_to_vb': 'die', 'vbg_to_vb': 'die', 'vbg_to_vbn': 'died'},
 'different': {'jj_to_nn': 'difference', 'jj_to_vb': 'differ', 'be_jj_to_vbg': '', 'jj_to_rb': 'differently'},
 'differentiated': {'jj_to_nn': 'differentiation', 'jj_to_vb': 'differentiate', 'vbd_eq_vbn': ''},
 'diminished': {'jj_to_nn': 'diminution', 'jj_to_vb': 'diminish', 'vbd_eq_vbn': ''},
 'dipping': {'jj_to_nn': 'dip', 'jj_to_vb': 'dip', 'nn_to_vb': 'dip'},
 'direct': {'jj_to_nn': 'direction', 'v_compcl': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_against': '', 'v_to': '', 'vb_to_vbz': 'directs', 'vb_to_vbd': 'directed', 'vb_to_vbn': 'directed', 'vb_to_nn': 'direction', 'rb_to_nn': 'direction', 'vb_to_vbg': 'directing', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'dirty': {'jj_to_nn': 'dirt', 'jj_to_vb': 'dirt', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'dirties', 'vb_to_vbd': 'dirtied', 'vb_to_vbn': 'dirtied', 'vb_to_vbg': 'dirtying', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'jj_to_jjr': 'dirtier', 'jj_to_jjs': 'dirtiest'},
 'disappointing': {'jj_to_nn': 'disappointment', 'jj_to_vb': 'disappoint', 'vbg_to_vb': 'disappoint', 'vbg_to_vbn': 'disappointed', 'sth_be_jj': ''},
 'disappointed': {'jj_to_nn': 'disappointment', 'jj_to_vb': 'disappoint', 'vbd_to_vb': 'disappoint', 'vbn_to_vb': 'disappoint', 'vbn_to_vbg': 'disappointing', 'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'disciplinary': {'jj_to_nn': 'discipline', 'jj_to_vb': 'discipline'},
 'discriminating': {'jj_to_nn': 'discrimination', 'jj_to_vb': 'discriminate'},
 'diseased': {'jj_to_nn': 'disease', 'jj_to_vb': 'disease', 'jj_ed': ''},
 'disgusting': {'jj_to_nn': 'disgust', 'jj_to_vb': 'disgust', 'sth_be_jj': ''},
 'dismissive': {'jj_to_nn': 'dismission', 'jj_to_vb': 'dismiss'},
 'displaced': {'jj_to_nn': 'displacement', 'jj_to_vb': 'displace', 'nn_to_vb': 'displace', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'displayed': {'jj_to_nn': 'display', 'jj_to_vb': 'display', 'vbd_to_vb': 'display', 'vbn_to_vb': 'display', 'vbn_to_vbg': 'displaying', 'vbd_eq_vbn': ''},
 'disposable': {'jj_to_nn': 'disposal', 'jj_to_vb': 'dispose'},
 'distant': {'jj_to_nn': 'distance', 'jj_to_vb': 'distance'},
 'distinct': {'jj_to_nn': 'distinction'},
 'distinctive': {'jj_to_nn': 'distinction'},
 'distorted': {'jj_to_nn': 'distortion', 'jj_to_vb': 'distort', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'distributive': {'jj_to_nn': 'distribution', 'jj_to_vb': 'distribute'},
 'disturbing': {'jj_to_nn': 'disturbance', 'jj_to_vb': 'disturb', 'vbg_to_vb': 'disturb', 'vbg_to_vbn': 'disturbed', 'sth_be_jj': ''},
 'diving': {'jj_to_nn': 'dive', 'jj_to_vb': 'dive', 'nn_to_vb': 'dive'},
 'divided': {'jj_to_nn': 'division', 'jj_to_vb': 'divide', 'vbd_to_vb': 'divide', 'vbn_to_vb': 'divide', 'vbn_to_vbg': 'dividing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'documented': {'jj_to_nn': 'documentation', 'jj_to_vb': 'document', 'vbd_to_vb': 'document', 'vbn_to_vb': 'document', 'vbn_to_vbg': 'documenting', 'vbd_eq_vbn': ''},
 'dogged': {'jj_to_nn': 'dog', 'jj_to_vb': 'dog', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'dominant': {'jj_to_nn': 'domination', 'jj_to_vb': 'dominate', 'nn_to_nns': 'dominants', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'dominate'},
 'dragging': {'jj_to_nn': 'drag', 'jj_to_vb': 'drag'},
 'drawn': {'jj_to_nn': 'draw', 'jj_to_vb': 'draw', 'vbn_to_vb': 'draw', 'vbn_to_vbd': 'drew', 'vbn_to_vbg': 'drawing'},
 'dressed': {'jj_to_nn': 'dress', 'jj_to_vb': 'dress', 'vbd_to_vb': 'dress', 'vbn_to_vb': 'dress', 'vbn_to_vbg': 'dressing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'drunk': {'jj_to_nn': 'drink', 'jj_to_vb': 'drink', 'nn_to_nns': 'drunks', 'n_is_nc': '', 'n_is_sb': '0', 'vbn_to_vb': 'drink', 'vbn_to_vbd': 'drank', 'vbn_to_vbg': 'drinking'},
 'driven': {'jj_to_nn': 'drive', 'jj_to_vb': 'drive'},
 'dropped': {'jj_to_nn': 'drop', 'jj_to_vb': 'drop', 'vbd_to_vb': 'drop', 'vbn_to_vb': 'drop', 'vbn_to_vbg': 'droping', 'vbd_eq_vbn': ''},
 'drowning': {'jj_to_nn': 'drown', 'jj_to_vb': 'drown', 'nn_to_vb': 'drown'},
 'drummed': {'jj_to_nn': 'drum', 'jj_to_vb': 'drum', 'vbd_eq_vbn': ''},
 'early': {'jj_to_nn': 'earliness', 'rb_to_nn': 'earliness', 'jj_to_jjr': 'earlier', 'jj_to_jjs': 'earliest', 'rb_to_rbr': 'earlier', 'rb_to_rbs': 'earliest'},
 'earthy': {'jj_to_nn': 'earth', 'jj_to_vb': 'earth', 'jj_to_jjr': 'earthier', 'jj_to_jjs': 'earthiest'},
 'easy': {'jj_to_nn': 'easiness', 'rb_to_nn': 'easiness', 'jj_to_rb': 'easily', 'be_jj_to_vb': '', 'jj_to_jjr': 'easier', 'jj_to_jjs': 'easiest', 'rb_to_rbr': 'easier', 'rb_to_rbs': 'easiest'},
 'editorial': {'jj_to_nn': 'edition', 'jj_to_vb': 'edit', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'edit'},
 'educational': {'jj_to_nn': 'education', 'jj_to_vb': 'educate'},
 'effective': {'jj_to_nn': 'effect', 'jj_to_vb': 'effect'},
 'elderly': {'jj_to_nn': 'elder'},
 'elect': {'jj_to_nn': 'election', 'v_n': '', 'v_n_to_vb': '', 'v_n_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'elects', 'vb_to_vbd': 'elected', 'vb_to_vbn': 'elected', 'vb_to_nn': 'election', 'vb_to_vbg': 'electing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'electoral': {'jj_to_nn': 'election', 'jj_to_vb': 'elect'},
 'eliminating': {'jj_to_nn': 'elimination', 'jj_to_vb': 'eliminate'},
 'emergent': {'jj_to_nn': 'emergence', 'jj_to_vb': 'emerge'},
 'emphatic': {'jj_to_nn': 'emphasis', 'jj_to_vb': 'emphasize'},
 'employed': {'jj_to_nn': 'employment', 'jj_to_vb': 'employ', 'vbd_to_vb': 'employ', 'vbn_to_vb': 'employ', 'vbn_to_vbg': 'employing', 'vbd_eq_vbn': ''},
 'enclosed': {'jj_to_nn': 'enclosure', 'jj_to_vb': 'enclose', 'vbd_eq_vbn': ''},
 'encouraging': {'jj_to_nn': 'encouragement', 'jj_to_vb': 'encourage', 'vbg_to_vb': 'encourage', 'vbg_to_vbn': 'encouraged', 'sth_be_jj': ''},
 'ended': {'jj_to_nn': 'end', 'jj_to_vb': 'end', 'vbd_eq_vbn': ''},
 'enforced': {'jj_to_nn': 'enforcement', 'jj_to_vb': 'enforce', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'enhanced': {'jj_to_nn': 'enhancement', 'jj_to_vb': 'enhance', 'vbd_to_vb': 'enhance', 'vbn_to_vb': 'enhance', 'vbn_to_vbg': 'enhancing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'enjoyable': {'jj_to_nn': 'enjoyment', 'jj_to_vb': 'enjoy'},
 'entered': {'jj_to_nn': 'entrance', 'jj_to_vb': 'enter', 'vbd_to_vb': 'enter', 'vbn_to_vb': 'enter', 'vbn_to_vbg': 'entering', 'vbd_eq_vbn': ''},
 'entertaining': {'jj_to_nn': 'entertainment', 'jj_to_vb': 'entertain', 'sth_be_jj': ''},
 'envious': {'jj_to_nn': 'envy', 'jj_to_vb': 'envy'},
 'equal': {'jj_to_nn': 'equality', 'nn_to_nns': 'equals', 'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'equals', 'vb_to_vbd': 'equalled', 'vb_to_vbn': 'equalled', 'vb_to_nn': 'equality', 'jj_to_rb': 'equally', 'vb_to_vbg': 'equalling', 'vt_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'be_jj_to_vbg': '', 'n_is_sth': '2'},
 'equational': {'jj_to_nn': 'equation', 'jj_to_vb': 'equate'},
 'eroding': {'jj_to_nn': 'erosion', 'jj_to_vb': 'erode'},
 'escaped': {'jj_to_nn': 'escape', 'jj_to_vb': 'escape', 'vbd_to_vb': 'escape', 'vbn_to_vb': 'escape', 'vbn_to_vbg': 'escaping', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'established': {'jj_to_nn': 'establishment', 'jj_to_vb': 'establish', 'vbd_to_vb': 'establish', 'vbn_to_vb': 'establish', 'vbn_to_vbg': 'establishing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'estimated': {'jj_to_nn': 'estimation', 'jj_to_vb': 'estimate', 'vbd_to_vb': 'estimate', 'vbn_to_vb': 'estimate', 'vbn_to_vbg': 'estimating', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'evaluative': {'jj_to_nn': 'evaluation', 'jj_to_vb': 'evaluate'},
 'evolutionary': {'jj_to_nn': 'evolution', 'jj_to_vb': 'evolve'},
 'examining': {'jj_to_nn': 'examination', 'jj_to_vb': 'examine', 'vbg_to_vb': 'examine', 'vbg_to_vbn': 'examined'},
 'exchanging': {'jj_to_nn': 'exchange', 'jj_to_vb': 'exchange', 'vbg_to_vb': 'exchange', 'vbg_to_vbn': 'exchanged'},
 'excited': {'jj_to_nn': 'excitement', 'jj_to_vb': 'excite', 'sb_be_jj': '', 'be_jj_to_vb': '', 'vbd_eq_vbn': ''},
 'exclusive': {'jj_to_nn': 'exclusion', 'jj_to_vb': 'exclude'},
 'excusing': {'jj_to_nn': 'excuse', 'jj_to_vb': 'excuse', 'vbg_to_vb': 'excuse', 'vbg_to_vbn': 'excused'},
 'exercised': {'jj_to_nn': 'exercise', 'jj_to_vb': 'exercise', 'vbd_eq_vbn': ''},
 'exhibited': {'jj_to_nn': 'exhibition', 'jj_to_vb': 'exhibit', 'vbd_eq_vbn': ''},
 'existent': {'jj_to_nn': 'existence', 'jj_to_vb': 'exist', 'nn_to_vb': 'exist'},
 'expansive': {'jj_to_nn': 'expansion', 'jj_to_vb': 'expand'},
 'expected': {'jj_to_nn': 'expectation', 'jj_to_vb': 'expect', 'vbd_to_vb': 'expect', 'vbn_to_vb': 'expect', 'vbn_to_vbg': 'expecting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'expensive': {'jj_to_nn': 'expense', 'jj_to_vb': 'expense'},
 'experienced': {'jj_to_nn': 'experience', 'jj_to_vb': 'experience', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'experimental': {'jj_to_nn': 'experiment', 'jj_to_vb': 'experiment'},
 'explanatory': {'jj_to_nn': 'explanation', 'jj_to_vb': 'explain'},
 'exploitive': {'jj_to_nn': 'exploitation', 'jj_to_vb': 'exploit'},
 'exploratory': {'jj_to_nn': 'exploration', 'jj_to_vb': 'explore'},
 'exporting': {'jj_to_nn': 'export', 'jj_to_vb': 'export', 'nn_to_vb': 'export'},
 'exposed': {'jj_to_nn': 'exposure', 'jj_to_vb': 'expose', 'vbd_to_vb': 'expose', 'vbn_to_vb': 'expose', 'vbn_to_vbg': 'exposing', 'jj_ed': '', 'be_jj_to_vbg': '', 'vbd_eq_vbn': ''},
 'extract': {'jj_to_nn': 'extraction', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vb_to_nn': 'extraction', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'extracted': {'jj_to_nn': 'extraction', 'jj_to_vb': 'extract', 'vbd_eq_vbn': ''},
 'faced': {'jj_to_nn': 'face', 'jj_to_vb': 'face', 'vbd_to_vb': 'face', 'vbn_to_vb': 'face', 'vbn_to_vbg': 'facing', 'vbd_eq_vbn': ''},
 'facilitative': {'jj_to_nn': 'facilitation', 'jj_to_vb': 'facilitate'},
 'factored': {'jj_to_nn': 'factor', 'jj_to_vb': 'factor', 'vbd_to_vb': 'factor', 'vbn_to_vb': 'factor', 'vbn_to_vbg': 'factoring', 'vbd_eq_vbn': ''},
 'faded': {'jj_to_nn': 'fade', 'jj_to_vb': 'fade', 'vbd_eq_vbn': ''},
 'failed': {'jj_to_nn': 'failure', 'jj_to_vb': 'fail', 'vbd_to_vb': 'fail', 'vbn_to_vb': 'fail', 'vbn_to_vbg': 'failing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'fair': {'jj_to_nn': 'fairness', 'nn_to_nns': 'fairs', 'n_is_nc': '', 'n_is_sth': '', 'vb_to_nn': 'fairness', 'rb_to_nn': 'fairness', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': '', 'jj_to_jjr': 'fairer', 'jj_to_jjs': 'fairest'},
 'fallen': {'jj_to_nn': 'fall', 'jj_to_vb': 'fall'},
 'fanned': {'jj_to_nn': 'fan', 'jj_to_vb': 'fan', 'vbd_to_vb': 'fan', 'vbn_to_vb': 'fan', 'vbn_to_vbg': 'faning', 'vbd_eq_vbn': ''},
 'fashionable': {'jj_to_nn': 'fashion', 'jj_to_vb': 'fashion'},
 'fast': {'jj_to_nn': 'fastness', 'n_is_nc': '', 'n_is_sth': '', 'vb_to_nn': 'fastness', 'rb_to_nn': 'fastness', 'v_compcl_non': '', 'v_pass_non': '', 'jj_to_jjr': 'faster', 'jj_to_jjs': 'fastest'},
 'fearful': {'jj_to_nn': 'fear', 'jj_to_vb': 'fear'},
 'feathered': {'jj_to_nn': 'feather', 'jj_to_vb': 'feather', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'featured': {'jj_to_nn': 'feature', 'jj_to_vb': 'feature', 'vbd_to_vb': 'feature', 'vbn_to_vb': 'feature', 'vbn_to_vbg': 'featuring', 'vbd_eq_vbn': ''},
 'feverish': {'jj_to_nn': 'fever', 'jj_to_vb': 'fever'},
 'fighting': {'jj_to_nn': 'fight', 'jj_to_vb': 'fight', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'fight'},
 'filled': {'jj_to_nn': 'fill', 'jj_to_vb': 'fill', 'vbd_eq_vbn': ''},
 'filmed': {'jj_to_nn': 'film', 'jj_to_vb': 'film', 'vbd_eq_vbn': ''},
 'financial': {'jj_to_nn': 'finance', 'jj_to_vb': 'finance'},
 'finished': {'jj_to_nn': 'finish', 'jj_to_vb': 'finish', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'firm': {'jj_to_nn': 'firmness', 'nn_to_nns': 'firms', 'n_is_nc': '', 'n_is_sth': '', 'vb_to_nn': 'firmness', 'rb_to_nn': 'firmness', 'vbd_eq_vbn': '', 'nc_typical': '', 'jj_to_jjr': 'firmer', 'jj_to_jjs': 'firmest'},
 'fit': {'jj_to_nn': 'fitness', 'nn_to_nns': 'fits', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'v_in': '', 'v_for': '', 'vb_to_nn': 'fitness', 'be_jj_to_vb': '', 'jj_to_jjr': 'fitter', 'jj_to_jjs': 'fittest'},
 'fitted': {'jj_to_nn': 'fitness', 'jj_to_vb': 'fit', 'jj_ed': '', 'be_jj_to_vb': '', 'vbd_eq_vbn': ''},
 'fixable': {'jj_to_nn': 'fix', 'jj_to_vb': 'fix'},
 'flavoured': {'jj_to_nn': 'flavour', 'jj_to_vb': 'flavour', 'vbd_to_vb': 'flavour', 'vbn_to_vb': 'flavour', 'vbn_to_vbg': 'flavouring', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'floating': {'jj_to_nn': 'float', 'jj_to_vb': 'float'},
 'flooded': {'jj_to_nn': 'flood', 'jj_to_vb': 'flood', 'vbd_to_vb': 'flood', 'vbn_to_vb': 'flood', 'vbn_to_vbg': 'flooding', 'vbd_eq_vbn': ''},
 'flowing': {'jj_to_nn': 'flow', 'jj_to_vb': 'flow', 'vbg_to_vb': 'flow', 'vbg_to_vbn': 'flown'},
 'fluctuating': {'jj_to_nn': 'fluctuation', 'jj_to_vb': 'fluctuate'},
 'flying': {'jj_to_nn': 'fly', 'jj_to_vb': 'fly', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'fly', 'nn_to_jj': 'fly', 'vbg_to_vb': 'fly', 'vbg_to_vbn': 'flied'},
 'focused': {'jj_to_nn': 'focus', 'jj_to_vb': 'focus', 'vbd_to_vb': 'focus', 'vbn_to_vb': 'focus', 'vbn_to_vbg': 'focusing', 'vbd_eq_vbn': ''},
 'folding': {'jj_to_nn': 'fold', 'jj_to_vb': 'fold', 'vbg_to_vb': 'fold', 'vbg_to_vbn': 'folded'},
 'following': {'jj_to_nn': 'follow', 'jj_to_vb': 'follow', 'nn_to_nns': 'followings', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'follow', 'vbg_to_vb': 'follow', 'vbg_to_vbn': 'followed'},
 'fool': {'jj_to_nn': 'foolishness', 'n_is_nc': '', 'n_is_sb': '0', 'vb_to_nn': 'foolishness', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'foolish': {'jj_to_nn': 'foolishness', 'jj_to_vb': 'fool', 'be_jj_to_vb': ''},
 'forceful': {'jj_to_nn': 'force', 'jj_to_vb': 'force'},
 'forested': {'jj_to_nn': 'forest', 'jj_to_vb': 'forest', 'vbd_to_vb': 'forest', 'vbn_to_vb': 'forest', 'vbn_to_vbg': 'foresting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'forgiving': {'jj_to_nn': 'forgiveness', 'jj_to_vb': 'forgive', 'vbg_to_vb': 'forgive', 'vbg_to_vbn': 'forgiven'},
 'formed': {'jj_to_nn': 'formation', 'jj_to_vb': 'form', 'vbd_to_vb': 'form', 'vbn_to_vb': 'form', 'vbn_to_vbg': 'forming', 'vbd_eq_vbn': ''},
 'formulaic': {'jj_to_nn': 'formula', 'jj_to_vb': 'formulate'},
 'fortunate': {'jj_to_nn': 'fortune', 'jj_to_vb': 'fortune'},
 'founded': {'jj_to_nn': 'founding', 'jj_to_vb': 'found', 'vbd_eq_vbn': ''},
 'framed': {'jj_to_nn': 'frame', 'jj_to_vb': 'frame', 'vbd_eq_vbn': ''},
 'free': {'jj_to_nn': 'freedom', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_of': '', 'v_from': '', 'vb_to_vbz': 'frees', 'vb_to_vbd': 'freed', 'vb_to_vbn': 'freed', 'vb_to_nn': 'freedom', 'rb_to_nn': 'freedom', 'vb_to_vbg': 'freeing', 'vbd_eq_vbn': '', 'be_jj_to_vb': '', 'suffix': 'nn', 'jj_to_jjr': 'freer', 'jj_to_jjs': 'freest'},
 'frozen': {'jj_to_nn': 'freeze', 'jj_to_vb': 'freeze'},
 'frequent': {'jj_to_nn': 'frequency', 'vb_to_nn': 'frequency', 'vbd_eq_vbn': ''},
 'friendly': {'jj_to_nn': 'friend', 'rb_to_nn': 'friend', 'jj_to_jjr': 'friendlier', 'jj_to_jjs': 'friendliest'},
 'frightful': {'jj_to_nn': 'fright', 'jj_to_vb': 'fright'},
 'full': {'jj_to_nn': 'fullness', 'n_is_nu': '', 'n_is_sth': '', 'vb_to_vbz': 'fulls', 'vb_to_vbd': 'fulled', 'vb_to_vbn': 'fulled', 'vb_to_nn': 'fullness', 'rb_to_nn': 'fullness', 'vb_to_vbg': 'fulling', 'vbd_eq_vbn': '', 'be_jj_to_vbg': '', 'jj_to_jjr': 'fuller', 'jj_to_jjs': 'fullest'},
 'funny': {'jj_to_nn': 'fun', 'jj_to_vb': 'fun', 'n_is_nc': '', 'n_is_sb': '0', 'jj_to_jjr': 'funnier', 'jj_to_jjs': 'funniest'},
 'functional': {'jj_to_nn': 'function', 'jj_to_vb': 'function'},
 'gatherable': {'jj_to_nn': 'gather', 'jj_to_vb': 'gather'},
 'gay': {'jj_to_nn': 'gaiety', 'nn_to_nns': 'gays', 'n_is_nc': '', 'n_is_sb': '0'},
 'general': {'jj_to_nn': 'generality', 'jj_to_vb': 'generalise', 'nn_to_nns': 'generals', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'generalise'},
 'generative': {'jj_to_nn': 'generation', 'jj_to_vb': 'generate'},
 'get': {'jj_to_nn': 'getting', 'v_to_n': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vbe': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_to_vbz': 'gets', 'vb_to_vbd': 'got', 'vb_to_vbn': 'gotten', 'v_n_vbg': '', 'v_vbg': '', 'vb_to_vbg': 'getting', 'vi_typical': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'gifted': {'jj_to_nn': 'gift', 'jj_to_vb': 'gift', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'given': {'jj_to_nn': 'give', 'jj_to_vb': 'give', 'be_vbn_to_vbg': '', 'vbn_to_vb': 'give', 'rb_to_nn': 'give', 'rb_to_vb': 'give', 'vbn_to_vbd': 'gave', 'vbn_to_vbg': 'giving'},
 'glad': {'jj_to_nn': 'gladness', 'vb_to_nn': 'gladness', 'be_jj_to_vb': '', 'jj_to_jjr': 'gladder', 'jj_to_jjs': 'gladdest'},
 'glorious': {'jj_to_nn': 'glory', 'jj_to_vb': 'glory'},
 'gone': {'jj_to_nn': 'go', 'jj_to_vb': 'go', 'vbn_to_vb': 'go', 'vbn_to_vbd': 'went', 'vbn_to_vbg': 'going'},
 'good': {'jj_to_nn': 'goodness', 'n_is_nu': '', 'n_is_sth': '', 'rb_to_nn': 'goodness', 'be_jj_to_vb': ''},
 'governing': {'jj_to_nn': 'government', 'jj_to_vb': 'govern', 'vbg_to_vb': 'govern', 'vbg_to_vbn': 'governed'},
 'graceful': {'jj_to_nn': 'grace', 'jj_to_vb': 'grace'},
 'grassy': {'jj_to_nn': 'grass', 'jj_to_vb': 'grass', 'nn_to_vb': 'grass', 'jj_to_jjr': 'grassier', 'jj_to_jjs': 'grassiest'},
 'greasy': {'jj_to_nn': 'grease', 'jj_to_vb': 'grease', 'jj_to_jjr': 'greasier', 'jj_to_jjs': 'greasiest'},
 'green': {'jj_to_nn': 'greenness', 'nn_to_nns': 'greens', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vb_to_nn': 'greenness', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'jj_to_jjr': 'greener', 'jj_to_jjs': 'greenest'},
 'grinding': {'jj_to_nn': 'grind', 'jj_to_vb': 'grind', 'nn_to_vb': 'grind'},
 'grounded': {'jj_to_nn': 'ground', 'jj_to_vb': 'ground', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'grouped': {'jj_to_nn': 'group', 'jj_to_vb': 'group', 'vbd_eq_vbn': ''},
 'grown': {'jj_to_nn': 'growth', 'jj_to_vb': 'grow', 'vbn_to_vb': 'grow', 'vbn_to_vbd': 'grew', 'vbn_to_vbg': 'growing'},
 'guaranteed': {'jj_to_nn': 'guarantee', 'jj_to_vb': 'guarantee', 'vbd_to_vb': 'guarantee', 'vbn_to_vb': 'guarantee', 'vbn_to_vbg': 'guaranteeing', 'vbd_eq_vbn': ''},
 'guarding': {'jj_to_nn': 'guard', 'jj_to_vb': 'guard', 'vbg_to_vb': 'guard', 'vbg_to_vbn': 'guarded'},
 'guiding': {'jj_to_nn': 'guide', 'jj_to_vb': 'guide', 'nn_to_vb': 'guide', 'vbg_to_vb': 'guide', 'vbg_to_vbn': 'guided'},
 'habitual': {'jj_to_nn': 'habit', 'jj_to_vb': 'habit'},
 'hammered': {'jj_to_nn': 'hammer', 'jj_to_vb': 'hammer', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'handed': {'jj_to_nn': 'hand', 'jj_to_vb': 'hand', 'vbd_to_vb': 'hand', 'vbn_to_vb': 'hand', 'vbn_to_vbg': 'handing', 'vbd_eq_vbn': ''},
 'handling': {'jj_to_nn': 'handle', 'jj_to_vb': 'handle', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'handle', 'vbg_to_vb': 'handle', 'vbg_to_vbn': 'handled'},
 'hanging': {'jj_to_nn': 'hang', 'jj_to_vb': 'hang', 'nn_to_nns': 'hangings', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'hang', 'vbg_to_vb': 'hang', 'vbg_to_vbn': 'hung'},
 'hard': {'jj_to_nn': 'hardness', 'jj_to_vb': 'harden', 'rb_to_nn': 'hardness', 'rb_to_vb': 'harden', 'be_jj_to_vb': '', 'jj_to_jjr': 'harder', 'jj_to_jjs': 'hardest'},
 'harmful': {'jj_to_nn': 'harm', 'jj_to_vb': 'harm'},
 'harvesting': {'jj_to_nn': 'harvest', 'jj_to_vb': 'harvest', 'nn_to_vb': 'harvest'},
 'headed': {'jj_to_nn': 'head', 'jj_to_vb': 'head', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'healthy': {'jj_to_nn': 'health', 'jj_to_jjr': 'healthier', 'jj_to_jjs': 'healthiest'},
 'heaping': {'jj_to_nn': 'heap', 'jj_to_vb': 'heap', 'nn_to_vb': 'heap'},
 'heated': {'jj_to_nn': 'heat', 'jj_to_vb': 'heat', 'vbd_to_vb': 'heat', 'vbn_to_vb': 'heat', 'vbn_to_vbg': 'heating', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'heavenly': {'jj_to_nn': 'heaven', 'rb_to_nn': 'heaven'},
 'helpful': {'jj_to_nn': 'help', 'jj_to_vb': 'help', 'be_jj_to_vbg': '', 'be_jj_to_vb': ''},
 'hesitating': {'jj_to_nn': 'hesitation', 'jj_to_vb': 'hesitate', 'vbg_to_vb': 'hesitate', 'vbg_to_vbn': 'hesitated'},
 'hidden': {'jj_to_nn': 'hide', 'jj_to_vb': 'hide', 'nn_to_vb': 'hide', 'vbn_to_vb': 'hide', 'vbn_to_vbd': 'hid', 'vbn_to_vbg': 'hiding'},
 'hierarchical': {'jj_to_nn': 'hierarchy'},
 'highlighted': {'jj_to_nn': 'highlight', 'jj_to_vb': 'highlight', 'vbd_to_vb': 'highlight', 'vbn_to_vb': 'highlight', 'vbn_to_vbg': 'highlighting', 'vbd_eq_vbn': ''},
 'hilly': {'jj_to_nn': 'hill', 'jj_to_vb': 'hill', 'nn_to_vb': 'hill', 'jj_to_jjr': 'hillier', 'jj_to_jjs': 'hilliest'},
 'holy': {'jj_to_nn': 'holiness', 'jj_to_rb': 'holily', 'jj_to_jjr': 'holier', 'jj_to_jjs': 'holiest'},
 'honourable': {'jj_to_nn': 'honour', 'jj_to_vb': 'honour'},
 'hooked': {'jj_to_nn': 'hook', 'jj_to_vb': 'hook', 'vbd_to_vb': 'hook', 'vbn_to_vb': 'hook', 'vbn_to_vbg': 'hooking', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'hot': {'jj_to_nn': 'hotness', 'vb_to_nn': 'hotness', 'rb_to_nn': 'hotness', 'jj_to_jjr': 'hotter', 'jj_to_jjs': 'hottest'},
 'hourly': {'jj_to_nn': 'hour', 'rb_to_nn': 'hour'},
 'housed': {'jj_to_nn': 'house', 'jj_to_vb': 'house', 'vbd_to_vb': 'house', 'vbn_to_vb': 'house', 'vbn_to_vbg': 'housing', 'vbd_eq_vbn': ''},
 'hunting': {'jj_to_nn': 'hunt', 'jj_to_vb': 'hunt', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'hunt', 'vbg_to_vb': 'hunt', 'vbg_to_vbn': 'hunted'},
 'hurtful': {'jj_to_nn': 'hurt', 'jj_to_vb': 'hurt'},
 'hypothetical': {'jj_to_nn': 'hypothesis', 'jj_to_vb': 'hypothesize'},
 'identifiable': {'jj_to_nn': 'identification', 'jj_to_vb': 'identify'},
 'ignorant': {'jj_to_nn': 'ignorance', 'jj_to_vb': 'ignore'},
 'illustrative': {'jj_to_nn': 'illustration', 'jj_to_vb': 'illustrate'},
 'imaginative': {'jj_to_nn': 'imagination', 'jj_to_vb': 'imagine'},
 'imitated': {'jj_to_nn': 'imitation', 'jj_to_vb': 'imitate', 'vbd_eq_vbn': ''},
 'immigrant': {'jj_to_nn': 'immigration', 'jj_to_vb': 'immigrate', 'nn_to_nns': 'immigrants', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nn_to_vb': 'immigrate'},
 'impacted': {'jj_to_nn': 'impact', 'jj_to_vb': 'impact', 'vbd_to_vb': 'impact', 'vbn_to_vb': 'impact', 'vbn_to_vbg': 'impacting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'implemented': {'jj_to_nn': 'implementation', 'jj_to_vb': 'implement', 'vbd_to_vb': 'implement', 'vbn_to_vb': 'implement', 'vbn_to_vbg': 'implementing', 'vbd_eq_vbn': ''},
 'implicated': {'jj_to_nn': 'implication', 'jj_to_vb': 'implicate', 'vbd_eq_vbn': ''},
 'implied': {'jj_to_nn': 'imply', 'vbd_to_vb': 'imply', 'vbn_to_vb': 'imply', 'vbn_to_vbg': 'implying', 'vbd_eq_vbn': ''},
 'imposed': {'jj_to_nn': 'imposition', 'jj_to_vb': 'impose', 'vbd_to_vb': 'impose', 'vbn_to_vb': 'impose', 'vbn_to_vbg': 'imposing', 'vbd_eq_vbn': ''},
 'improving': {'jj_to_nn': 'improvement', 'jj_to_vb': 'improve', 'vbg_to_vb': 'improve', 'vbg_to_vbn': 'improved'},
 'inclining': {'jj_to_nn': 'inclination', 'jj_to_vb': 'incline', 'nn_to_vb': 'incline'},
 'inclusive': {'jj_to_nn': 'inclusion', 'jj_to_vb': 'include'},
 'incorporate': {'jj_to_nn': 'incorporation', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'incorporates', 'vb_to_vbd': 'incorporated', 'vb_to_vbn': 'incorporated', 'vb_to_nn': 'incorporation', 'vb_to_vbg': 'incorporating', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'indexed': {'jj_to_nn': 'index', 'jj_to_vb': 'index', 'vbd_to_vb': 'index', 'vbn_to_vb': 'index', 'vbn_to_vbg': 'indexing', 'vbd_eq_vbn': ''},
 'indicative': {'jj_to_nn': 'indication', 'jj_to_vb': 'indicate', 'nn_to_vb': 'indicate'},
 'individual': {'jj_to_nn': 'individuality', 'jj_to_vb': 'individualise', 'nn_to_nns': 'individuals', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nn_to_vb': 'individualise'},
 'inducing': {'jj_to_nn': 'induction', 'jj_to_vb': 'induce'},
 'inferred': {'jj_to_nn': 'inference', 'jj_to_vb': 'infer', 'vbd_eq_vbn': ''},
 'influential': {'jj_to_nn': 'influence', 'jj_to_vb': 'influence', 'nn_to_vb': 'influence'},
 'informing': {'jj_to_nn': 'information', 'jj_to_vb': 'inform', 'vbg_to_vb': 'inform', 'vbg_to_vbn': 'informed'},
 'inhibited': {'jj_to_nn': 'inhibition', 'jj_to_vb': 'inhibit', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'initial': {'jj_to_nn': 'initialization', 'jj_to_vb': 'initialize', 'nn_to_nns': 'initials', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'initialize', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'initials', 'vb_to_vbd': 'initialed', 'vb_to_vbn': 'initialed', 'vb_to_nn': 'initialization', 'vb_to_vbg': 'initialing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'initiate': {'jj_to_nn': 'initiation', 'n_is_sb': '0', 'vb_to_nn': 'initiation', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'initiative': {'jj_to_nn': 'initiation', 'jj_to_vb': 'initiate', 'nn_to_nns': 'initiatives', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'initiate', 'nn_to_jj': 'initiate'},
 'injured': {'jj_to_nn': 'injury', 'jj_to_vb': 'injure', 'vbd_to_vb': 'injure', 'vbn_to_vb': 'injure', 'vbn_to_vbg': 'injuring', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'inky': {'jj_to_nn': 'ink', 'jj_to_vb': 'ink'},
 'innovative': {'jj_to_nn': 'innovation', 'jj_to_vb': 'innovate'},
 'inquiring': {'jj_to_nn': 'inquiry', 'jj_to_vb': 'inquire'},
 'inserted': {'jj_to_nn': 'insertion', 'jj_to_vb': 'insert', 'vbd_eq_vbn': ''},
 'insightful': {'jj_to_nn': 'insight'},
 'inspected': {'jj_to_nn': 'inspection', 'jj_to_vb': 'inspect', 'vbd_eq_vbn': ''},
 'institutional': {'jj_to_nn': 'institution', 'jj_to_vb': 'institute'},
 'instructive': {'jj_to_nn': 'instruction', 'jj_to_vb': 'instruct'},
 'insulting': {'jj_to_nn': 'insult', 'jj_to_vb': 'insult'},
 'insured': {'jj_to_nn': 'insurance', 'jj_to_vb': 'insure', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nn_to_vb': 'insure', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'integrate': {'jj_to_nn': 'integration', 'vb_to_nn': 'integration', 'v_compcl_non': '', 'v_whcl_non': ''},
 'integrated': {'jj_to_nn': 'integration', 'jj_to_vb': 'integrate', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'intent': {'jj_to_nn': 'intention', 'jj_to_vb': 'intend', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'intend'},
 'interactive': {'jj_to_nn': 'interaction', 'jj_to_vb': 'interact'},
 'interesting': {'jj_to_nn': 'interest', 'jj_to_vb': 'interest', 'vbg_to_vb': 'interest', 'vbg_to_vbn': 'interested', 'sth_be_jj': '', 'be_jj_to_vb': ''},
 'intermediate': {'jj_to_nn': 'intermediation', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'vb_to_nn': 'intermediation'},
 'interpretive': {'jj_to_nn': 'interpretation', 'jj_to_vb': 'interpret'},
 'interrupted': {'jj_to_nn': 'interrupt', 'jj_to_vb': 'interrupt', 'vbd_eq_vbn': ''},
 'intervening': {'jj_to_nn': 'intervention', 'jj_to_vb': 'intervene'},
 'invented': {'jj_to_nn': 'invention', 'jj_to_vb': 'invent', 'vbd_eq_vbn': ''},
 'investigative': {'jj_to_nn': 'investigation', 'jj_to_vb': 'investigate'},
 'inviting': {'jj_to_nn': 'invitation', 'jj_to_vb': 'invite', 'vbg_to_vb': 'invite', 'vbg_to_vbn': 'invited'},
 'involved': {'jj_to_nn': 'involvement', 'jj_to_vb': 'involve', 'vbd_to_vb': 'involve', 'vbn_to_vb': 'involve', 'vbn_to_vbg': 'involving', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'isolate': {'jj_to_nn': 'isolation', 'vb_to_nn': 'isolation', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'isolated': {'jj_to_nn': 'isolation', 'jj_to_vb': 'isolate', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'issued': {'jj_to_nn': 'issue', 'jj_to_vb': 'issue', 'nn_to_vb': 'issue', 'vbd_to_vb': 'issue', 'vbn_to_vb': 'issue', 'vbn_to_vbg': 'issuing', 'vbd_eq_vbn': ''},
 'joking': {'jj_to_nn': 'joke', 'jj_to_vb': 'joke', 'vbg_to_vb': 'joke', 'vbg_to_vbn': 'joked'},
 'joyful': {'jj_to_nn': 'joy', 'jj_to_vb': 'joy', 'be_jj_to_vb': ''},
 'judged': {'jj_to_nn': 'judgment', 'jj_to_vb': 'judge', 'vbd_to_vb': 'judge', 'vbn_to_vb': 'judge', 'vbn_to_vbg': 'judging', 'vbd_eq_vbn': ''},
 'jumping': {'jj_to_nn': 'jump', 'jj_to_vb': 'jump', 'nn_to_vb': 'jump', 'vbg_to_vb': 'jump', 'vbg_to_vbn': 'jumped'},
 'justifiable': {'jj_to_nn': 'justification', 'jj_to_vb': 'justify'},
 'kept': {'jj_to_nn': 'keep', 'jj_to_vb': 'keep', 'vbd_to_vb': 'keep', 'vbn_to_vb': 'keep', 'vbn_to_vbg': 'keeping', 'vbd_eq_vbn': ''},
 'kicking': {'jj_to_nn': 'kick', 'jj_to_vb': 'kick', 'nn_to_vb': 'kick', 'vbg_to_vb': 'kick', 'vbg_to_vbn': 'kicked'},
 'killed': {'jj_to_nn': 'killing', 'jj_to_vb': 'kill', 'vbd_to_vb': 'kill', 'vbn_to_vb': 'kill', 'vbn_to_vbg': 'killing', 'vbd_eq_vbn': ''},
 'kindly': {'jj_to_nn': 'kindness', 'rb_to_nn': 'kindness', 'rb_to_jj': 'kind'},
 'kissing': {'jj_to_nn': 'kiss', 'jj_to_vb': 'kiss', 'vbg_to_vb': 'kiss', 'vbg_to_vbn': 'kissed'},
 'knotted': {'jj_to_nn': 'knot', 'jj_to_vb': 'knot', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'known': {'jj_to_nn': 'knowing', 'jj_to_vb': 'know', 'vbn_to_vb': 'know', 'vbn_to_vbg': 'knowing', 'vbn_to_vbd': 'knew'},
 'labeled': {'jj_to_nn': 'label', 'jj_to_vb': 'label', 'vbd_to_vb': 'label', 'vbn_to_vb': 'label', 'vbn_to_vbg': 'labelling', 'vbd_eq_vbn': ''},
 'lacking': {'jj_to_nn': 'lack', 'jj_to_vb': 'lack', 'vbg_to_vb': 'lack', 'vbg_to_vbn': 'lacked'},
 'landed': {'jj_to_nn': 'land', 'jj_to_vb': 'land', 'vbd_to_vb': 'land', 'vbn_to_vb': 'land', 'vbn_to_vbg': 'landing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'laughable': {'jj_to_nn': 'laugh', 'jj_to_vb': 'laugh'},
 'lawful': {'jj_to_nn': 'law', 'jj_to_vb': 'law'},
 'layered': {'jj_to_nn': 'layer', 'jj_to_vb': 'layer', 'vbd_to_vb': 'layer', 'vbn_to_vb': 'layer', 'vbn_to_vbg': 'layering', 'vbd_eq_vbn': ''},
 'lead': {'jj_to_nn': 'leader', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_to_n': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_with': '', 'vb_to_vbz': 'leads', 'vb_to_vbd': 'led', 'vb_to_vbn': 'led', 'vb_to_nn': 'leader', 'vb_to_vbg': 'leading', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'leading': {'jj_to_nn': 'leader', 'jj_to_vb': 'lead', 'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'lead', 'vbg_to_vbn': 'led'},
 'leafy': {'jj_to_nn': 'leaf', 'jj_to_vb': 'leaf', 'jj_to_jjr': 'leafier', 'jj_to_jjs': 'leafiest'},
 'learned': {'jj_to_nn': 'learning', 'jj_to_vb': 'learn', 'vbn_to_vbg': 'learning', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'legislative': {'jj_to_nn': 'legislation', 'jj_to_vb': 'legislate', 'nn_to_vb': 'legislate'},
 'lengthy': {'jj_to_nn': 'length', 'jj_to_vb': 'lengthen', 'jj_to_jjr': 'lengthier', 'jj_to_jjs': 'lengthiest'},
 'liberal': {'jj_to_nn': 'liberty', 'jj_to_vb': 'liberalize', 'n_is_sb': '0', 'nn_to_vb': 'liberalize'},
 'licensed': {'jj_to_nn': 'licence', 'jj_to_vb': 'licence', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'lying': {'jj_to_nn': 'lie', 'jj_to_vb': 'lie', 'nn_to_vb': 'lie', 'vbg_to_vb': 'lie', 'vbg_to_vbn': 'lied'},
 'lifting': {'jj_to_nn': 'lift', 'jj_to_vb': 'lift', 'nn_to_vb': 'lift', 'vbg_to_vb': 'lift', 'vbg_to_vbn': 'lifted'},
 'likely': {'jj_to_nn': 'likelihood', 'rb_to_nn': 'likelihood', 'be_jj_to_vb': '', 'jj_to_jjr': 'likelier', 'jj_to_jjs': 'likeliest'},
 'limited': {'jj_to_nn': 'limitation', 'jj_to_vb': 'limit', 'be_vbn_to_vbg': '', 'nn_to_vb': 'limit', 'vbd_to_vb': 'limit', 'vbn_to_vb': 'limit', 'vbn_to_nn': 'limit', 'vbn_to_vbg': 'limiting', 'jj_ed': '', 'be_jj_to_vbg': '', 'vbd_eq_vbn': ''},
 'lined': {'jj_to_nn': 'line', 'jj_to_vb': 'line', 'vbd_eq_vbn': ''},
 'linked': {'jj_to_nn': 'link', 'jj_to_vb': 'link', 'be_vbn_to_vbg': '', 'vbd_to_vb': 'link', 'vbn_to_vb': 'link', 'vbn_to_vbg': 'linking', 'vbd_eq_vbn': ''},
 'listed': {'jj_to_nn': 'list', 'jj_to_vb': 'list', 'vbd_to_vb': 'list', 'vbn_to_vb': 'list', 'vbn_to_vbg': 'listing', 'vbd_eq_vbn': ''},
 'listening': {'jj_to_nn': 'listen', 'jj_to_vb': 'listen', 'nn_to_vb': 'listen', 'vbg_to_vb': 'listen', 'vbg_to_vbn': 'listened'},
 'loaded': {'jj_to_nn': 'load', 'jj_to_vb': 'load', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'locked': {'jj_to_nn': 'lock', 'jj_to_vb': 'lock', 'vbd_to_vb': 'lock', 'vbn_to_vb': 'lock', 'vbn_to_vbg': 'locking', 'vbd_eq_vbn': ''},
 'lone': {'jj_to_nn': 'loneliness'},
 'lonely': {'jj_to_nn': 'loneliness', 'nn_to_jj': 'lone', 'jj_to_jjr': 'lonelier', 'jj_to_jjs': 'loneliest'},
 'looking': {'jj_to_nn': 'look', 'jj_to_vb': 'look', 'vbg_to_vb': 'look', 'vbg_to_vbn': 'looked'},
 'lost': {'jj_to_nn': 'losing', 'jj_to_vb': 'lose', 'vbd_to_vb': 'lose', 'vbn_to_vb': 'lose', 'vbn_to_vbg': 'losing', 'vbd_eq_vbn': ''},
 'lovable': {'jj_to_nn': 'love', 'jj_to_vb': 'love', 'nn_to_vb': 'love'},
 'mailed': {'jj_to_nn': 'mail', 'jj_to_vb': 'mail', 'vbd_to_vb': 'mail', 'vbn_to_vb': 'mail', 'vbn_to_vbg': 'mailing', 'vbd_eq_vbn': ''},
 'maintained': {'jj_to_nn': 'maintenance', 'jj_to_vb': 'maintain', 'vbd_to_vb': 'maintain', 'vbn_to_vb': 'maintain', 'vbn_to_vbg': 'maintaining', 'vbd_eq_vbn': ''},
 'major': {'jj_to_nn': 'majority', 'nn_to_nns': 'majors', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '', 'vb_to_nn': 'majority', 'vbd_eq_vbn': ''},
 'makable': {'jj_to_nn': 'make', 'jj_to_vb': 'make'},
 'manly': {'jj_to_nn': 'man', 'jj_to_vb': 'man', 'nn_to_vb': 'man', 'rb_to_nn': 'man', 'rb_to_vb': 'man', 'jj_to_jjr': 'manlier', 'jj_to_jjs': 'manliest'},
 'managing': {'jj_to_nn': 'management', 'jj_to_vb': 'manage', 'vbg_to_vb': 'manage', 'vbg_to_vbn': 'managed'},
 'manipulative': {'jj_to_nn': 'manipulation', 'jj_to_vb': 'manipulate'},
 'manufacturing': {'jj_to_nn': 'manufacture', 'jj_to_vb': 'manufacture', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'manufacture'},
 'marching': {'jj_to_nn': 'march', 'jj_to_vb': 'march', 'vbg_to_vb': 'march', 'vbg_to_vbn': 'marched'},
 'marginal': {'jj_to_nn': 'margin', 'jj_to_vb': 'margin'},
 'marked': {'jj_to_nn': 'mark', 'jj_to_vb': 'mark', 'vbd_to_vb': 'mark', 'vbn_to_vb': 'mark', 'vbn_to_vbg': 'marking', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'married': {'jj_to_nn': 'marriage', 'jj_to_vb': 'marry', 'nn_to_vb': 'marry', 'vbd_to_vb': 'marry', 'vbn_to_vb': 'marry', 'vbn_to_vbg': 'marrying', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'masterful': {'jj_to_nn': 'master', 'jj_to_vb': 'master'},
 'matched': {'jj_to_nn': 'match', 'jj_to_vb': 'match', 'vbd_to_vb': 'match', 'vbn_to_vb': 'match', 'vbn_to_vbg': 'matching', 'vbd_eq_vbn': ''},
 'maximum': {'jj_to_nn': 'maximisation', 'jj_to_vb': 'maximise', 'nn_to_nns': 'maxima', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'maximise', 'nc_typical': ''},
 'measurable': {'jj_to_nn': 'measurement', 'jj_to_vb': 'measure'},
 'mediate': {'jj_to_nn': 'mediation', 'vb_to_nn': 'mediation', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'melted': {'jj_to_nn': 'melt', 'jj_to_vb': 'melt', 'vbd_eq_vbn': ''},
 'memorial': {'jj_to_nn': 'memory', 'jj_to_vb': 'memorise', 'nn_to_nns': 'memorials', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'memorise', 'nc_typical': ''},
 'mentioned': {'jj_to_nn': 'mention', 'jj_to_vb': 'mention', 'vbd_to_vb': 'mention', 'vbn_to_vb': 'mention', 'vbn_to_vbg': 'mentioning', 'vbd_eq_vbn': ''},
 'migrant': {'jj_to_nn': 'migration', 'jj_to_vb': 'migrate', 'n_is_nc': '', 'n_is_sb': '3', 'nn_to_vb': 'migrate', 'n_is_sth': '3'},
 'milky': {'jj_to_nn': 'milk', 'jj_to_vb': 'milk', 'nn_to_vb': 'milk', 'jj_to_jjr': 'milkier', 'jj_to_jjs': 'milkiest'},
 'milled': {'jj_to_nn': 'mill', 'jj_to_vb': 'mill', 'vbd_eq_vbn': ''},
 'minded': {'jj_to_nn': 'mind', 'jj_to_vb': 'mind', 'vbd_to_vb': 'mind', 'vbn_to_vb': 'mind', 'vbn_to_vbg': 'minding', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'ministerial': {'jj_to_nn': 'ministry'},
 'mistaken': {'jj_to_nn': 'mistake', 'jj_to_vb': 'mistake'},
 'mixed': {'jj_to_nn': 'mixture', 'jj_to_vb': 'mix', 'vbd_to_vb': 'mix', 'vbn_to_vb': 'mix', 'vbn_to_vbg': 'mixing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'moderate': {'jj_to_nn': 'moderation', 'n_is_sb': '0', 'vb_to_nn': 'moderation', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'modified': {'jj_to_nn': 'modification', 'jj_to_vb': 'modify', 'vbd_eq_vbn': ''},
 'momentary': {'jj_to_nn': 'moment'},
 'monthly': {'jj_to_nn': 'month', 'n_is_nc': '', 'n_is_sth': '', 'rb_to_nn': 'month'},
 'motional': {'jj_to_nn': 'motion', 'jj_to_vb': 'motion'},
 'motive': {'jj_to_nn': 'motivation', 'jj_to_vb': 'motivate', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'motivate', 'vb_to_nn': 'motivation'},
 'moving': {'jj_to_nn': 'movement', 'jj_to_vb': 'move', 'vbg_to_vb': 'move', 'vbg_to_vbn': 'moved', 'sth_be_jj': ''},
 'multiply': {'jj_to_nn': 'multiplication', 'v_n': '', 'nsubjpass': '', 'vb_to_nn': 'multiplication', 'rb_to_nn': 'multiplication', 'v_prprtcl_non': ''},
 'nailing': {'jj_to_nn': 'nail', 'jj_to_vb': 'nail'},
 'needled': {'jj_to_nn': 'needle', 'jj_to_vb': 'needle', 'vbd_eq_vbn': ''},
 'negative': {'jj_to_nn': 'negate', 'jj_to_vb': 'nagate', 'nn_to_nns': 'negatives', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'nagate', 'vb_to_nn': 'negate', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'neglected': {'jj_to_nn': 'neglect', 'jj_to_vb': 'neglect', 'vbd_eq_vbn': ''},
 'nested': {'jj_to_nn': 'nest', 'jj_to_vb': 'nest', 'vbd_eq_vbn': ''},
 'neutral': {'jj_to_nn': 'neutrality', 'jj_to_vb': 'neutralize', 'nn_to_nns': 'neutrals', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_vb': 'neutralize', 'n_is_sth': '2'},
 'nightly': {'jj_to_nn': 'night', 'rb_to_nn': 'night', 'rb_to_jj': 'night'},
 'numbered': {'jj_to_nn': 'number', 'jj_to_vb': 'number', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'obtainable': {'jj_to_nn': 'obtain'},
 'obvious': {'jj_to_nn': 'obviousness', 'jj_to_rb': 'obviously'},
 'occupantional': {'jj_to_nn': 'occupation', 'jj_to_vb': 'occupy'},
 'occurent': {'jj_to_nn': 'occurrence', 'jj_to_vb': 'occur'},
 'operational': {'jj_to_nn': 'operation', 'jj_to_vb': 'operate'},
 'oppositional': {'jj_to_nn': 'opposition', 'jj_to_vb': 'opposite'},
 'optional': {'jj_to_nn': 'option'},
 'orangish': {'jj_to_nn': 'orange'},
 'organisational': {'jj_to_nn': 'organisation', 'jj_to_vb': 'organize'},
 'ornamental': {'jj_to_nn': 'ornament', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'own': {'jj_to_nn': 'owner', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'owns', 'vb_to_vbd': 'owned', 'vb_to_vbn': 'owned', 'vb_to_nn': 'owner', 'vb_to_vbg': 'owning', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'parentage': {'jj_to_nn': 'parent', 'jj_to_vb': 'parent', 'n_is_nu': '', 'n_is_sth': ''},
 'parental': {'jj_to_nn': 'parent', 'jj_to_vb': 'parent'},
 'participatory': {'jj_to_nn': 'participation', 'jj_to_vb': 'participate'},
 'personality': {'jj_to_nn': 'person', 'nn_to_nns': 'personalities', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2', 'n_is_nu': ''},
 'phenomenal': {'jj_to_nn': 'phenomenon'},
 'photography': {'jj_to_nn': 'photographer', 'jj_to_vb': 'photograph', 'n_is_nu': '', 'n_is_sth': ''},
 'powdery': {'jj_to_nn': 'powder', 'jj_to_vb': 'powder'},
 'powerful': {'jj_to_nn': 'power', 'jj_to_vb': 'power'},
 'preventable': {'jj_to_nn': 'prevention', 'jj_to_vb': 'prevent'},
 'profitable': {'jj_to_nn': 'profit', 'jj_to_vb': 'profit'},
 'pushy': {'jj_to_nn': 'push', 'jj_to_jjr': 'pushier', 'jj_to_jjs': 'pushiest'},
 'recoverable': {'jj_to_nn': 'recovery', 'jj_to_vb': 'recover'},
 'rejective': {'jj_to_nn': 'rejection', 'jj_to_vb': 'reject'},
 'removable': {'jj_to_nn': 'removal', 'jj_to_vb': 'remove'},
 'replaceable': {'jj_to_nn': 'replacement', 'jj_to_vb': 'replace'},
 'residential': {'jj_to_nn': 'resident', 'jj_to_vb': 'reside'},
 'resistible': {'jj_to_nn': 'resist', 'jj_to_vb': 'resist'},
 'resourceful': {'jj_to_nn': 'resource'},
 'respondent': {'jj_to_nn': 'response', 'jj_to_vb': 'respond', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'nn_to_vb': 'respond'},
 'responsive': {'jj_to_nn': 'response', 'jj_to_vb': 'respond'},
 'responsible': {'jj_to_nn': 'responsibility'},
 'reversible': {'jj_to_nn': 'reversal', 'jj_to_vb': 'reverse'},
 'revolutionary': {'jj_to_nn': 'revolution', 'jj_to_vb': 'revolutionise', 'nn_to_nns': 'revolutionaries', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0', 'nn_to_vb': 'revolutionise'},
 'ripe': {'jj_to_nn': 'ripeness', 'jj_to_jjr': 'riper', 'jj_to_jjs': 'ripest'},
 'rocky': {'jj_to_nn': 'rock', 'jj_to_vb': 'rock', 'jj_to_jjr': 'rockier', 'jj_to_jjs': 'rockiest'},
 'rusty': {'jj_to_nn': 'rust', 'jj_to_vb': 'rust', 'jj_to_jjr': 'rustier', 'jj_to_jjs': 'rustiest'},
 'sacred': {'jj_to_nn': 'sacredness', 'jj_ed': ''},
 'sacrificial': {'jj_to_nn': 'sacrifice'},
 'salty': {'jj_to_nn': 'salt', 'jj_to_vb': 'salt', 'jj_to_jjr': 'saltier', 'jj_to_jjs': 'saltiest'},
 'same': {'jj_to_nn': 'sameness'},
 'sandy': {'jj_to_nn': 'sand', 'jj_to_jjr': 'sandier', 'jj_to_jjs': 'sandiest'},
 'satisfactory': {'jj_to_nn': 'satisfication', 'jj_to_vb': 'satisfy'},
 'shadowy': {'jj_to_nn': 'shadow', 'jj_to_vb': 'shadow'},
 'shiny': {'jj_to_nn': 'shine', 'jj_to_vb': 'shine', 'jj_to_jjr': 'shinier', 'jj_to_jjs': 'shiniest'},
 'silverish': {'jj_to_nn': 'silver', 'jj_to_vb': 'silver'},
 'sunk': {'jj_to_nn': 'sink', 'jj_to_vb': 'sink', 'vbn_to_vb': 'sink', 'vbn_to_vbd': 'sank', 'vbn_to_vbg': 'sinking', 'vbd_eq_vbn': ''},
 'sinking': {'jj_to_nn': 'sink', 'jj_to_vb': 'sink', 'nn_to_vb': 'sink', 'nn_to_jj': 'sunk', 'vbg_to_vb': 'sink', 'vbg_to_vbn': 'sunk'},
 'sisterly': {'jj_to_nn': 'sister'},
 'situated': {'jj_to_nn': 'situation', 'jj_to_vb': 'situate', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'sized': {'jj_to_nn': 'size', 'vbd_to_vb': 'size', 'vbn_to_vb': 'size', 'vbn_to_vbg': 'sizing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'skinned': {'jj_to_nn': 'skin', 'jj_to_vb': 'skin', 'vbd_to_vb': 'skin', 'vbn_to_vb': 'skin', 'vbn_to_vbg': 'skinning', 'vbd_eq_vbn': ''},
 'sleeping': {'jj_to_nn': 'sleep', 'jj_to_vb': 'sleep', 'nn_to_vb': 'sleep', 'vbg_to_jj': 'sleepy', 'vbg_to_vb': 'sleep', 'vbg_to_vbn': 'slept'},
 'sleepy': {'jj_to_nn': 'sleep', 'jj_to_vb': 'sleep', 'jj_to_vbg': 'sleeping', 'jj_to_jjr': 'sleepier', 'jj_to_jjs': 'sleepiest'},
 'sleepless': {'jj_to_nn': 'sleep', 'jj_to_vb': 'sleep'},
 'sliding': {'jj_to_nn': 'slide', 'jj_to_vb': 'slide', 'nn_to_vb': 'slide', 'vbg_to_vb': 'slide', 'vbg_to_vbn': 'slided'},
 'slipping': {'jj_to_nn': 'slip', 'jj_to_vb': 'slip', 'nn_to_vb': 'slip', 'vbg_to_vb': 'slip', 'vbg_to_vbn': 'slipped'},
 'slipped': {'jj_to_nn': 'slip', 'jj_to_vb': 'slip', 'vbd_to_vb': 'slip', 'vbn_to_vb': 'slip', 'vbn_to_vbg': 'slipping', 'vbd_eq_vbn': ''},
 'sloped': {'jj_to_nn': 'slope', 'jj_to_vb': 'slope', 'vbd_eq_vbn': ''},
 'smiling': {'jj_to_nn': 'smile', 'jj_to_vb': 'smile', 'vbg_to_vb': 'smile', 'vbg_to_vbn': 'smiled'},
 'smoking': {'jj_to_nn': 'smoke', 'jj_to_vb': 'smoke', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'smoke', 'rb_to_nn': 'smoke', 'rb_to_vb': 'smoke', 'vbg_to_vb': 'smoke', 'vbg_to_vbn': 'smoked', 'nu_typical': ''},
 'soiled': {'jj_to_nn': 'soil', 'jj_to_vb': 'soil', 'nn_to_vb': 'soil', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'solved': {'jj_to_nn': 'solution', 'jj_to_vb': 'solve', 'vbd_to_vb': 'solve', 'vbn_to_vb': 'solve', 'vbn_to_vbg': 'solving', 'vbd_eq_vbn': ''},
 'sorry': {'jj_to_nn': 'sorriness', 'be_jj_to_vb': '', 'jj_to_jjr': 'sorrier', 'jj_to_jjs': 'sorriest'},
 'sorted': {'jj_to_nn': 'sort', 'jj_to_vb': 'sort', 'vbd_to_vb': 'sort', 'vbn_to_vb': 'sort', 'vbn_to_vbg': 'sorting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'sounding': {'jj_to_nn': 'sound', 'jj_to_vb': 'sound', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'sound', 'vbg_to_vb': 'sound', 'vbg_to_vbn': 'sounded'},
 'sourced': {'jj_to_nn': 'source', 'vbd_eq_vbn': ''},
 'spaced': {'jj_to_nn': 'space', 'jj_to_vb': 'space'},
 'sparing': {'jj_to_nn': 'spare', 'jj_to_vb': 'spare', 'vbg_to_vb': 'spare', 'vbg_to_vbn': 'spared'},
 'spared': {'jj_to_nn': 'spare', 'jj_to_vb': 'spare', 'vbd_to_vb': 'spare', 'vbn_to_vb': 'spare', 'vbn_to_vbg': 'sparing', 'vbd_eq_vbn': ''},
 'speaking': {'jj_to_nn': 'speaker', 'jj_to_vb': 'speak', 'nn_to_vb': 'speak', 'vbg_to_vb': 'speak', 'vbg_to_vbn': 'spoken'},
 'spoken': {'jj_to_nn': 'speaker', 'jj_to_vb': 'speak', 'vbn_to_vb': 'speak', 'vbn_to_vbd': 'spoke', 'vbn_to_vbg': 'speaking'},
 'specifiable': {'jj_to_nn': 'specifies', 'jj_to_vb': 'specify'},
 'specified': {'jj_to_nn': 'specifies', 'jj_to_vb': 'specify', 'vbd_to_vb': 'specify', 'vbn_to_vb': 'specify', 'vbn_to_vbg': 'specifying', 'vbd_eq_vbn': ''},
 'speeding': {'jj_to_nn': 'speed', 'jj_to_vb': 'speed', 'nn_to_vb': 'speed'},
 'speedy': {'jj_to_nn': 'speed', 'jj_to_vb': 'speed', 'nn_to_vb': 'speed', 'nn_to_jj': 'speeding', 'jj_to_jjr': 'speedier', 'jj_to_jjs': 'speediest'},
 'spent': {'jj_to_nn': 'spend', 'jj_to_vb': 'spend', 'vbd_to_vb': 'spend', 'vbn_to_vb': 'spend', 'vbn_to_vbg': 'spending', 'vbd_eq_vbn': ''},
 'spun': {'jj_to_nn': 'spin', 'jj_to_vb': 'spin', 'vbd_to_vb': 'spin', 'vbn_to_vb': 'spin', 'vbn_to_vbg': 'spinning', 'vbd_eq_vbn': ''},
 'spinning': {'jj_to_nn': 'spin', 'jj_to_vb': 'spin', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'spin', 'nn_to_jj': 'spun', 'vbg_to_vb': 'spin', 'vbg_to_vbn': 'spun'},
 'spiritual': {'jj_to_nn': 'spirit', 'jj_to_vb': 'spirit', 'nn_to_nns': 'spirituals', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'spirit'},
 'spitting': {'jj_to_nn': 'spit', 'jj_to_vb': 'spit', 'nn_to_vb': 'spit'},
 'splitting': {'jj_to_nn': 'split', 'jj_to_vb': 'split'},
 'spoiled': {'jj_to_nn': 'spoil', 'jj_to_vb': 'spoil', 'vbd_to_vb': 'spoil', 'vbn_to_vb': 'spoil', 'vbn_to_vbg': 'spoiling', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'sporting': {'jj_to_nn': 'sport', 'jj_to_vb': 'sport'},
 'sprung': {'jj_to_nn': 'spring', 'jj_to_vb': 'spring', 'nn_to_vb': 'spring'},
 'stabilized': {'jj_to_nn': 'stable', 'jj_to_vb': 'stable', 'vbd_eq_vbn': ''},
 'stabilised': {'jj_to_nn': 'stable', 'jj_to_vb': 'stable', 'vbd_eq_vbn': ''},
 'staged': {'jj_to_nn': 'stage', 'jj_to_vb': 'stage'},
 'stained': {'jj_to_nn': 'stain', 'jj_to_vb': 'stain', 'vbd_eq_vbn': ''},
 'stamped': {'jj_to_nn': 'stamp', 'jj_to_vb': 'stamp', 'vbd_eq_vbn': ''},
 'standing': {'jj_to_nn': 'stand', 'jj_to_vb': 'stand', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'stand', 'vbg_to_vb': 'stand', 'vbg_to_vbn': 'stood'},
 'starred': {'jj_to_nn': 'star', 'jj_to_vb': 'star', 'vbd_eq_vbn': ''},
 'stated': {'jj_to_nn': 'state', 'jj_to_vb': 'state', 'vbd_to_vb': 'state', 'vbn_to_vb': 'state', 'vbn_to_vbg': 'stating', 'vbd_eq_vbn': ''},
 'statistical': {'jj_to_nn': 'statistic'},
 'stolen': {'jj_to_nn': 'steal', 'jj_to_vb': 'steal', 'vbn_to_vb': 'steal', 'vbn_to_vbd': 'stole', 'vbn_to_vbg': 'stealing'},
 'stealing': {'jj_to_nn': 'steal', 'jj_to_vb': 'steal', 'nn_to_vb': 'steal', 'nn_to_jj': 'stolen', 'vbg_to_vb': 'steal', 'vbg_to_vbn': 'stolen'},
 'steaming': {'jj_to_nn': 'steam', 'jj_to_vb': 'steam', 'nn_to_vb': 'steam', 'nn_to_jj': 'steam', 'rb_to_nn': 'steam', 'rb_to_jj': 'steam', 'rb_to_vb': 'steam'},
 'stemmed': {'jj_to_nn': 'stem', 'jj_to_vb': 'stem', 'vbd_eq_vbn': ''},
 'sticking': {'jj_to_nn': 'stick', 'jj_to_vb': 'stick', 'nn_to_vb': 'stick', 'vbg_to_vb': 'stick', 'vbg_to_vbn': 'stuck'},
 'stuck': {'jj_to_nn': 'stick', 'jj_to_vb': 'stick', 'nn_to_vb': 'stick', 'nn_to_jj': 'sticking', 'vbd_to_vb': 'stick', 'vbn_to_vb': 'stick', 'vbn_to_vbg': 'sticking', 'vbd_eq_vbn': ''},
 'stirring': {'jj_to_nn': 'stir', 'jj_to_vb': 'stir'},
 'stopped': {'jj_to_nn': 'stop', 'jj_to_vb': 'stop', 'vbd_to_vb': 'stop', 'vbn_to_vb': 'stop', 'vbn_to_vbg': 'stopping', 'vbd_eq_vbn': ''},
 'storing': {'jj_to_nn': 'store', 'jj_to_vb': 'store', 'nn_to_vb': 'store', 'vbg_to_vb': 'store', 'vbg_to_vbn': 'stored'},
 'stored': {'jj_to_nn': 'store', 'jj_to_vb': 'store', 'vbd_to_vb': 'store', 'vbn_to_vb': 'store', 'vbn_to_vbg': 'storing', 'vbd_eq_vbn': ''},
 'strapping': {'jj_to_nn': 'strap', 'jj_to_vb': 'strap', 'nn_to_vb': 'strap'},
 'strapped': {'jj_to_nn': 'strap', 'jj_to_vb': 'strap', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'stressful': {'jj_to_nn': 'stress', 'jj_to_vb': 'stress'},
 'stressed': {'jj_to_nn': 'stress', 'jj_to_vb': 'stress', 'vbd_to_vb': 'stress', 'vbn_to_vb': 'stress', 'vbn_to_vbg': 'stressing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'stretched': {'jj_to_nn': 'stretch', 'jj_to_vb': 'stretch', 'be_vbn_to_vbg': '', 'vbd_to_vb': 'stretch', 'vbn_to_vb': 'stretch', 'vbn_to_vbg': 'stretching', 'vbd_eq_vbn': ''},
 'striking': {'jj_to_nn': 'strike', 'jj_to_vb': 'strike', 'vbg_to_vb': 'strike', 'vbg_to_vbn': 'struck'},
 'struck': {'jj_to_nn': 'strike', 'jj_to_vb': 'strike', 'nn_to_vb': 'strike', 'nn_to_jj': 'striking', 'vbd_to_vb': 'strike', 'vbn_to_vb': 'strike', 'vbn_to_vbg': 'striking', 'vbd_eq_vbn': ''},
 'stringed': {'jj_to_nn': 'string', 'jj_to_vb': 'string'},
 'stripped': {'jj_to_nn': 'strip', 'jj_to_vb': 'strip', 'vbd_eq_vbn': ''},
 'striped': {'jj_to_nn': 'stripe', 'jj_to_vb': 'stripe', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'struggling': {'jj_to_nn': 'struggle', 'jj_to_vb': 'struggle', 'vbg_to_vb': 'struggle', 'vbg_to_vbn': 'struggled'},
 'studied': {'jj_to_nn': 'study', 'jj_to_vb': 'study', 'vbd_to_vb': 'study', 'vbn_to_vb': 'study', 'vbn_to_vbg': 'studying', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'stuffed': {'jj_to_nn': 'stuff', 'jj_to_vb': 'stuff', 'be_vbn_to_vbg': '', 'vbd_to_vb': 'stuff', 'vbn_to_vb': 'stuff', 'vbn_to_vbg': 'stuffing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'subsidized': {'jj_to_nn': 'subsidy', 'jj_to_vb': 'subsidise', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'subsidised': {'jj_to_nn': 'subsidy', 'jj_to_vb': 'subsidise', 'vbd_eq_vbn': ''},
 'substitutive': {'jj_to_nn': 'substitute', 'jj_to_vb': 'substitute'},
 'sucking': {'jj_to_nn': 'suck', 'jj_to_vb': 'suck', 'vbg_to_vb': 'suck', 'vbg_to_vbn': 'sucked'},
 'suffering': {'jj_to_nn': 'suffer', 'jj_to_vb': 'suffer', 'nn_to_nns': 'sufferings', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'suffer', 'vbg_to_vb': 'suffer', 'vbg_to_vbn': 'suffered'},
 'sugary': {'jj_to_nn': 'sugar', 'jj_to_vb': 'sugar'},
 'suggested': {'jj_to_nn': 'suggestion', 'jj_to_vb': 'suggest', 'vbd_to_vb': 'suggest', 'vbn_to_vb': 'suggest', 'vbn_to_vbg': 'suggesting', 'vbd_eq_vbn': ''},
 'suited': {'jj_to_nn': 'suit', 'jj_to_vb': 'suit', 'vbd_to_vb': 'suit', 'vbn_to_vb': 'suit', 'vbn_to_vbg': 'suiting', 'vbd_eq_vbn': ''},
 'suitable': {'jj_to_nn': 'suit', 'jj_to_vb': 'suit'},
 'summing': {'jj_to_nn': 'sum', 'jj_to_vb': 'sum', 'nn_to_vb': 'sum'},
 'summational': {'jj_to_nn': 'sum', 'jj_to_vb': 'sum'},
 'supplementary': {'jj_to_nn': 'supplement', 'jj_to_vb': 'supplement', 'nn_to_vb': 'supplement'},
 'supplied': {'jj_to_nn': 'supply', 'jj_to_vb': 'supply', 'vbd_to_vb': 'supply', 'vbn_to_vb': 'supply', 'vbn_to_vbg': 'supplying', 'vbd_eq_vbn': ''},
 'supplying': {'jj_to_nn': 'supply', 'jj_to_vb': 'supply', 'nn_to_vb': 'supply', 'nn_to_jj': 'supplied', 'vbg_to_vb': 'supply', 'vbg_to_vbn': 'supplied'},
 'supported': {'jj_to_nn': 'support', 'jj_to_vb': 'support', 'vbd_to_vb': 'support', 'vbn_to_vb': 'support', 'vbn_to_vbg': 'supporting', 'vbd_eq_vbn': ''},
 'supporting': {'jj_to_nn': 'support', 'jj_to_vb': 'support', 'vbg_to_vb': 'support', 'vbg_to_vbn': 'supported'},
 'supportive': {'jj_to_nn': 'support', 'jj_to_vb': 'support'},
 'supportable': {'jj_to_nn': 'support', 'jj_to_vb': 'support'},
 'surrounding': {'jj_to_nn': 'surround', 'jj_to_vb': 'surround', 'nn_to_vb': 'surround', 'nn_to_jj': 'surround', 'vbg_to_vb': 'surround', 'vbg_to_vbn': 'surrounded'},
 'surrounded': {'jj_to_nn': 'surround', 'jj_to_vb': 'surround', 'vbd_to_vb': 'surround', 'vbn_to_vb': 'surround', 'vbn_to_vbg': 'surrounding', 'vbd_eq_vbn': ''},
 'survived': {'jj_to_nn': 'survival', 'jj_to_vb': 'survive', 'vbd_to_vb': 'survive', 'vbn_to_vb': 'survive', 'vbn_to_vbg': 'surviving', 'vbd_eq_vbn': ''},
 'surviving': {'jj_to_nn': 'survival', 'jj_to_vb': 'survive', 'vbg_to_vb': 'survive', 'vbg_to_vbn': 'survived'},
 'suspected': {'jj_to_nn': 'suspect', 'jj_to_vb': 'suspect', 'vbd_to_vb': 'suspect', 'vbn_to_vb': 'suspect', 'vbn_to_vbg': 'suspecting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'suspectable': {'jj_to_nn': 'suspect', 'jj_to_vb': 'suspect'},
 'suspended': {'jj_to_nn': 'suspension', 'jj_to_vb': 'suspend', 'vbd_eq_vbn': ''},
 'sustained': {'jj_to_nn': 'sustainability', 'jj_to_vb': 'sustain', 'vbd_to_vb': 'sustain', 'vbn_to_vb': 'sustain', 'vbn_to_vbg': 'sustaining', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'sustaining': {'jj_to_nn': 'sustainability', 'jj_to_vb': 'sustain', 'vbg_to_vb': 'sustain', 'vbg_to_vbn': 'sustained'},
 'sustainable': {'jj_to_nn': 'sustainability', 'jj_to_vb': 'sustain'},
 'sworn': {'jj_to_nn': 'swear', 'jj_to_vb': 'swear', 'vbn_to_vb': 'swear', 'vbn_to_vbd': 'swore', 'vbn_to_vbg': 'swearing'},
 'swore': {'jj_to_nn': 'swear', 'jj_to_vb': 'swear', 'vbd_to_vb': 'swear', 'vbd_to_vbn': 'sworn'},
 'sweated': {'jj_to_nn': 'sweat', 'jj_to_vb': 'sweat', 'vbd_eq_vbn': ''},
 'swept': {'jj_to_nn': 'sweep', 'jj_to_vb': 'sweep', 'vbd_to_vb': 'sweep', 'vbn_to_vb': 'sweep', 'vbn_to_vbg': 'sweeping', 'vbd_eq_vbn': ''},
 'sweeping': {'jj_to_nn': 'sweep', 'jj_to_vb': 'sweep', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'sweep', 'nn_to_jj': 'swept', 'vbg_to_vb': 'sweep', 'vbg_to_vbn': 'swept'},
 'swellish': {'jj_to_nn': 'swell', 'jj_to_vb': 'swell'},
 'swinging': {'jj_to_nn': 'swing', 'jj_to_vb': 'swing', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'swing', 'nn_to_jj': 'swing', 'rb_to_nn': 'swing', 'rb_to_jj': 'swing', 'rb_to_vb': 'swing', 'vbg_to_vb': 'swing', 'vbg_to_vbn': 'swung'},
 'tailored': {'jj_to_nn': 'tailor', 'jj_to_vb': 'tailor', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'tailorable': {'jj_to_nn': 'tailor', 'jj_to_vb': 'tailor'},
 'taking': {'jj_to_nn': 'take', 'jj_to_vb': 'take', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'take', 'vbg_to_vb': 'take', 'vbg_to_vbn': 'taken'},
 'talking': {'jj_to_nn': 'talk', 'jj_to_vb': 'talk', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'talk', 'vbg_to_vb': 'talk', 'vbg_to_vbn': 'talked'},
 'tameable': {'jj_to_nn': 'tame', 'jj_to_vb': 'tame'},
 'tapped': {'jj_to_nn': 'tap', 'jj_to_vb': 'tap', 'vbd_eq_vbn': ''},
 'taped': {'jj_to_nn': 'tape', 'jj_to_vb': 'tape', 'vbd_eq_vbn': ''},
 'targeted': {'jj_to_nn': 'target', 'jj_to_vb': 'target', 'vbd_eq_vbn': ''},
 'tasteless': {'jj_to_nn': 'taste', 'jj_to_vb': 'taste'},
 'tearing': {'jj_to_nn': 'tear', 'jj_to_vb': 'tear', 'vbg_to_vb': 'tear', 'vbg_to_vbn': 'torn'},
 'telling': {'jj_to_nn': 'tell', 'jj_to_vb': 'tell', 'nn_to_vb': 'tell', 'vbg_to_vb': 'tell', 'vbg_to_vbn': 'told'},
 'tempting': {'jj_to_nn': 'tempter', 'jj_to_vb': 'tempt', 'sth_be_jj': ''},
 'tempted': {'jj_to_nn': 'tempter', 'jj_to_vb': 'tempt', 'vbd_eq_vbn': ''},
 'tenth': {'jj_to_nn': 'ten'},
 'terminate': {'jj_to_nn': 'terminal', 'vb_to_nn': 'terminal', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'terminated': {'jj_to_nn': 'terminal', 'jj_to_vb': 'terminate', 'vbd_eq_vbn': ''},
 'tested': {'jj_to_nn': 'test', 'jj_to_vb': 'test', 'vbd_to_vb': 'test', 'vbn_to_vb': 'test', 'vbn_to_vbg': 'testing', 'vbd_eq_vbn': ''},
 'testing': {'jj_to_nn': 'test', 'jj_to_vb': 'test', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'test', 'nn_to_jj': 'tested', 'vbg_to_vb': 'test', 'vbg_to_vbn': 'tested'},
 'thirteenth': {'jj_to_nn': 'thirteen'},
 'thronlike': {'jj_to_nn': 'thorn'},
 'thornless': {'jj_to_nn': 'thorn'},
 'thousandth': {'jj_to_nn': 'thousand'},
 'threatened': {'jj_to_nn': 'threat', 'jj_to_vb': 'threat', 'vbd_to_vb': 'threaten', 'vbn_to_vb': 'threaten', 'vbn_to_vbg': 'threatening', 'sb_be_jj': '', 'vbd_eq_vbn': ''},
 'tidal': {'jj_to_nn': 'tide', 'jj_to_vb': 'tide', 'nn_to_vb': 'tide'},
 'tieless': {'jj_to_nn': 'tie', 'jj_to_vb': 'untie'},
 'tongueless': {'jj_to_nn': 'tongue', 'jj_to_vb': 'tongue'},
 'toothed': {'jj_to_nn': 'tooth', 'jj_to_vb': 'tooth', 'jj_ed': ''},
 'touchable': {'jj_to_nn': 'touch', 'jj_to_vb': 'touch'},
 'traceless': {'jj_to_nn': 'trace', 'jj_to_vb': 'trace'},
 'traceable': {'jj_to_nn': 'trace', 'jj_to_vb': 'trace'},
 'tradable': {'jj_to_nn': 'trade', 'jj_to_vb': 'trade'},
 'transferable': {'jj_to_nn': 'transfer', 'jj_to_vb': 'transfer'},
 'travelled': {'jj_to_nn': 'travel', 'jj_to_vb': 'travel', 'vbd_to_vb': 'travel', 'vbn_to_vb': 'travel', 'vbn_to_vbg': 'traveling', 'vbd_eq_vbn': ''},
 'treated': {'jj_to_nn': 'treat', 'jj_to_vb': 'treat', 'vbd_to_vb': 'treat', 'vbn_to_vb': 'treat', 'vbn_to_vbg': 'treating', 'vbd_eq_vbn': ''},
 'trickish': {'jj_to_nn': 'trick', 'jj_to_vb': 'trick'},
 'trustable': {'jj_to_nn': 'trust', 'jj_to_vb': 'trust'},
 'tried': {'jj_to_nn': 'try', 'jj_to_vb': 'try', 'vbd_to_vb': 'try', 'vbn_to_vb': 'try', 'vbn_to_vbg': 'trying', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'turned': {'jj_to_nn': 'turn', 'jj_to_vb': 'turn', 'vbd_to_vb': 'turn', 'vbn_to_vb': 'turn', 'vbn_to_vbg': 'turning', 'vbd_eq_vbn': ''},
 'twelfth': {'jj_to_nn': 'twelve'},
 'twentieth': {'jj_to_nn': 'twenty'},
 'utilisable': {'jj_to_nn': 'utilization', 'jj_to_vb': 'utilize'},
 'villagey': {'jj_to_nn': 'village', 'jj_to_vb': 'village'},
 'votable': {'jj_to_nn': 'vote', 'jj_to_vb': 'vote'},
 'voyageable': {'jj_to_nn': 'voyage', 'jj_to_vb': 'voyage'},
 'washed': {'jj_to_nn': 'wash', 'jj_to_vb': 'wash', 'vbd_to_vb': 'wash', 'vbn_to_vb': 'wash', 'vbn_to_vbg': 'washing', 'vbd_eq_vbn': ''},
 'waterless': {'jj_to_nn': 'water', 'jj_to_vb': 'water'},
 'waveless': {'jj_to_nn': 'wave', 'jj_to_vb': 'wave'},
 'wavelike': {'jj_to_nn': 'wave', 'jj_to_vb': 'wave'},
 'woven': {'jj_to_nn': 'weave', 'jj_to_vb': 'weave'},
 'weedless': {'jj_to_nn': 'weed', 'jj_to_vb': 'weed'},
 'weekly': {'jj_to_nn': 'week', 'n_is_nc': '', 'n_is_sth': '', 'rb_to_nn': 'week'},
 'weighable': {'jj_to_nn': 'weigh', 'jj_to_vb': 'weigh'},
 'whipped': {'jj_to_nn': 'whip', 'jj_to_vb': 'whip', 'vbd_eq_vbn': ''},
 'whisppery': {'jj_to_nn': 'whisper', 'jj_to_vb': 'whisper'},
 'whitish': {'jj_to_nn': 'white', 'jj_to_vb': 'whiten'},
 'wifelike': {'jj_to_nn': 'wife'},
 'winnable': {'jj_to_nn': 'win', 'jj_to_vb': 'win'},
 'woody': {'jj_to_nn': 'wood', 'jj_to_vb': 'wooden'},
 'woolly': {'jj_to_nn': 'wool', 'jj_to_vb': 'woollen'},
 'workless': {'jj_to_nn': 'work', 'jj_to_vb': 'work'},
 'yellowish': {'jj_to_nn': 'yellow'},
 'young': {'jj_to_nn': 'youngster', 'n_is_sb': '2', 'n_is_sth': '2', 'n_is_collective': '', 'jj_to_jjr': 'younger', 'jj_to_jjs': 'youngest'},
 'diligent': {'jj_to_nn': 'diligence'},
 'alternative': {'jj_to_vb': 'alternate', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'alternate'},
 'becoming': {'jj_to_vb': 'become', 'nn_to_vb': 'become', 'vbg_to_vb': 'become', 'vbg_to_vbn': 'become'},
 'breathing': {'jj_to_vb': 'breathe', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'breathe', 'vbg_to_vb': 'breathe', 'vbg_to_vbn': 'breathed'},
 'burying': {'jj_to_vb': 'bury', 'nn_to_vb': 'bury', 'nn_to_jj': 'buried', 'vbg_to_vb': 'bury', 'vbg_to_vbn': 'buried'},
 'coming': {'jj_to_vb': 'come', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'come', 'vbg_to_vb': 'come', 'vbg_to_vbn': 'come'},
 'containing': {'jj_to_vb': 'contain', 'nn_to_vb': 'contain', 'vbg_to_vb': 'contain', 'vbg_to_vbn': 'contained'},
 'dependent': {'jj_to_vb': 'depend', 'nn_to_nns': 'dependents', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'depend'},
 'eating': {'jj_to_vb': 'eat', 'nn_to_vb': 'eat', 'vbg_to_vb': 'eat', 'vbg_to_vbn': 'eaten'},
 'founding': {'jj_to_vb': 'found', 'nn_to_vb': 'found'},
 'healing': {'jj_to_vb': 'heal', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'heal'},
 'imitation': {'jj_to_vb': 'imitate', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'imitate'},
 'item': {'jj_to_vb': 'itemise', 'nn_to_nns': 'items', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'itemise'},
 'killing': {'jj_to_vb': 'kill', 'nn_to_nns': 'killings', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'kill', 'vbg_to_vb': 'kill', 'vbg_to_vbn': 'killed'},
 'knowing': {'jj_to_vb': 'know', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'know', 'nn_to_jj': 'known', 'vbg_to_vbn': 'known', 'vbg_to_vb': 'know'},
 'lending': {'jj_to_vb': 'lend', 'nn_to_vb': 'lend', 'vbg_to_vb': 'lend', 'vbg_to_vbn': 'lent'},
 'loose': {'jj_to_vb': 'loosen', 'nn_to_vb': 'loosen', 'rb_to_vb': 'loosen', 'jj_to_jjr': 'looser', 'jj_to_jjs': 'loosest'},
 'losing': {'jj_to_vb': 'lose', 'nn_to_vb': 'lose', 'nn_to_jj': 'lost', 'vbg_to_vb': 'lose', 'vbg_to_vbn': 'lost'},
 'missing': {'jj_to_vb': 'miss', 'nn_to_vb': 'miss', 'vbg_to_vb': 'miss', 'vbg_to_vbn': 'missed'},
 'modern': {'jj_to_vb': 'modernize', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'nn_to_vb': 'modernize'},
 'sitting': {'jj_to_vb': 'sit', 'nn_to_nns': 'sittings', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'sit', 'vbg_to_vb': 'sit', 'vbg_to_vbn': 'sat'},
 'straight': {'jj_to_vb': 'straighten', 'nn_to_nns': 'straights', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_vb': 'straighten', 'rb_to_vb': 'straighten', 'n_is_sth': '2', 'jj_to_jjr': 'straighter', 'jj_to_jjs': 'straightest'},
 'terminal': {'jj_to_vb': 'terminate', 'nn_to_nns': 'terminals', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'terminate', 'nn_to_jj': 'terminate', 'nc_typical': ''},
 'white': {'jj_to_vb': 'whiten', 'nn_to_nns': 'whites', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0', 'nn_to_vb': 'whiten', 'jj_to_jjr': 'whiter', 'jj_to_jjs': 'whitest'},
 'aux': {'dep_inversed': ''},
 'amod': {'dep_inversed': ''},
 'det': {'dep_inversed': ''},
 'advmod': {'dep_inversed': ''},
 'nsubj': {'dep_inversed': ''},
 'num': {'dep_inversed': ''},
 'predet': {'dep_inversed': ''},
 'designed': {'be_vbn_to_vb': '', 'vbd_to_vb': 'design', 'vbn_to_vb': 'design', 'vbn_to_vbg': 'designing', 'vbd_eq_vbn': ''},
 'lured': {'be_vbn_to_vbg': '', 'vbd_eq_vbn': ''},
 'accustomed': {'be_vbn_to_vbg': '', 'be_jj_to_vbg': '', 'vbd_eq_vbn': ''},
 'geared': {'be_vbn_to_vbg': '', 'vbd_eq_vbn': ''},
 'dedicated': {'be_vbn_to_vbg': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'addressed': {'be_vbn_to_vbg': '', 'vbd_to_vb': 'address', 'vbn_to_vb': 'address', 'vbn_to_vbg': 'addressing', 'vbd_eq_vbn': ''},
 'used': {'be_vbn_to_vbg': '', 'vbd_to_vb': 'use', 'vbn_to_vb': 'use', 'vbn_to_vbg': 'using', 'jj_ed': '', 'be_jj_to_vbg': '', 'vbd_eq_vbn': ''},
 'applied': {'be_vbn_to_vbg': '', 'vbd_to_vb': 'apply', 'vbn_to_vb': 'apply', 'vbn_to_vbg': 'applying', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'paid': {'be_vbn_to_vbg': '', 'vbd_to_vb': 'pay', 'vbn_to_vb': 'pay', 'vbn_to_vbg': 'paying', 'vbd_eq_vbn': ''},
 'reduced': {'be_vbn_to_vbg': '', 'vbd_to_vb': 'reduce', 'vbn_to_vb': 'reduce', 'vbn_to_vbg': 'reducing', 'be_jj_to_vbg': '', 'vbd_eq_vbn': ''},
 'directed': {'be_vbn_to_vbg': '', 'vbd_to_vb': 'direct', 'vbn_to_vb': 'direct', 'vbn_to_vbg': 'directing', 'vbd_eq_vbn': ''},
 'slanted': {'be_vbn_to_vbg': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'needed': {'be_vbn_to_vbg': '', 'vbd_to_vb': 'need', 'vbn_to_vb': 'need', 'vbn_to_vbg': 'needing', 'vbd_eq_vbn': ''},
 'compared': {'be_vbn_to_vbg': '', 'vbd_to_vb': 'compare', 'vbn_to_vb': 'compare', 'vbn_to_vbg': 'comparing', 'be_jj_to_vbg': '', 'vbd_eq_vbn': ''},
 'restricted': {'be_vbn_to_vbg': '', 'vbd_to_vb': 'restrict', 'vbn_to_vb': 'restrict', 'vbn_to_vbg': 'restricting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'attached': {'be_vbn_to_vbg': '', 'vbd_to_vb': 'attach', 'vbn_to_vb': 'attach', 'vbn_to_vbg': 'attaching', 'be_jj_to_vbg': '', 'vbd_eq_vbn': ''},
 'optimistic': {'jj_to_nn': 'optimism'},
 'abacus': {'nn_to_nns': 'abacuses', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'echo': {'nn_to_nns': 'echoes', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'embargo': {'nn_to_nns': 'embargoes', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'hero': {'nn_to_nns': 'heroes', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'negro': {'nn_to_nns': 'negroes', 'n_is_nc': '', 'n_is_sb': '0'},
 'potato': {'nn_to_nns': 'potatoes', 'n_is_nc': '', 'n_is_sth': ''},
 'tomato': {'nn_to_nns': 'tomatoes', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'torpedo': {'nn_to_nns': 'torpedoes', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'veto': {'nn_to_nns': 'vetoes', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vbg_non': ''},
 'actress': {'nn_to_nns': 'actresses', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nc_typical': ''},
 'beach': {'nn_to_nns': 'beaches', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_at': '', 'vb_to_vbz': 'beaches', 'vb_to_vbd': 'beached', 'vb_to_vbn': 'beached', 'vb_to_vbg': 'beaching', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'bonus': {'nn_to_nns': 'bonuses', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'boss': {'nn_to_nns': 'bosses', 'n_is_nc': '', 'n_is_sb': '0', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'bosses', 'vb_to_vbd': 'bossed', 'vb_to_vbn': 'bossed', 'vb_to_vbg': 'bossing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'box': {'nn_to_nns': 'boxes', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'branch': {'nn_to_nns': 'branches', 'n_is_nc': '', 'n_is_sth': '', 'vb_to_vbz': 'branches', 'vb_to_vbd': 'branched', 'vb_to_vbn': 'branched', 'vb_to_vbg': 'branching', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'bunch': {'nn_to_nns': 'bunches', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'bunches', 'vb_to_vbd': 'bunched', 'vb_to_vbn': 'bunched', 'vb_to_vbg': 'bunching', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': '', 'n_of_nns': 'noun_attr'},
 'class': {'nn_to_nns': 'classes', 'n_is_nc': '', 'n_is_sth': '', 'n_is_collective': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'crash': {'nn_to_nns': 'crashes', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'crashed', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'crashes', 'vb_to_vbd': 'crashed', 'vb_to_vbn': 'crashed', 'vb_to_jj': 'crashed', 'vb_to_vbg': 'crashing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'nc_typical': ''},
 'dish': {'nn_to_nns': 'dishes', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'dishes', 'vb_to_vbd': 'dished', 'vb_to_vbn': 'dished', 'vb_to_vbg': 'dishing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'fix': {'nn_to_nns': 'fixes', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'fixable', 'v_n': '', 'v_to': '', 'vb_to_jj': 'fixable', 'vt_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'glass': {'nn_to_nns': 'glasses', 'n_is_nc': '', 'n_is_sth': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'glasses', 'vb_to_vbd': 'glassed', 'vb_to_vbn': 'glassed', 'vb_to_vbg': 'glassing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'gross': {'nn_to_nns': 'grosses', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'jj_to_jjr': 'grosser', 'jj_to_jjs': 'grossest'},
 'guess': {'nn_to_nns': 'guesses', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_from': '', 'vb_to_vbz': 'guesses', 'vb_to_vbd': 'guessed', 'vb_to_vbn': 'guessed', 'vb_to_vbg': 'guessing', 'vbd_eq_vbn': ''},
 'headmistress': {'nn_to_nns': 'headmistresses', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'inch': {'nn_to_nns': 'inches', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_to_vbg': '', 'vdo': '', 'vb_to_vbz': 'inches', 'vb_to_vbd': 'inched', 'vb_to_vbn': 'inched', 'vb_to_vbg': 'inching', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'nc_typical': '', 'quantifier': ''},
 'index': {'nn_to_nns': 'indexes', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'indexed', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'indexes', 'vb_to_vbd': 'indexed', 'vb_to_vbn': 'indexed', 'vb_to_jj': 'indexed', 'vb_to_vbg': 'indexing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'kiss': {'nn_to_nns': 'kisses', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'kissing', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'kisses', 'vb_to_vbd': 'kissed', 'vb_to_vbn': 'kissed', 'vb_to_jj': 'kissing', 'vb_to_vbg': 'kissing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'nc_typical': ''},
 'launch': {'nn_to_nns': 'launches', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'launches', 'vb_to_vbd': 'launched', 'vb_to_vbn': 'launched', 'vb_to_vbg': 'launching', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'match': {'nn_to_nns': 'matches', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_jj': 'matched', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'matches', 'vb_to_vbd': 'matched', 'vb_to_vbn': 'matched', 'vb_to_jj': 'matched', 'vb_to_vbg': 'matching', 'vbd_eq_vbn': '', 'nc_typical': '', 'n_is_sth': '2'},
 'pass': {'nn_to_nns': 'passes', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_for': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'passes', 'vb_to_vbd': 'passed', 'vb_to_vbn': 'passed', 'nn_to_vbn': 'passed', 'vb_to_vbg': 'passing', 'vbd_eq_vbn': ''},
 'peach': {'nn_to_nns': 'peaches', 'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'press': {'nn_to_nns': 'presses', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_for': '', 'v_against': '', 'vb_to_vbz': 'presses', 'vb_to_vbd': 'pressed', 'vb_to_vbn': 'pressed', 'vb_to_vbg': 'pressing', 'n_is_collective': '', 'vbd_eq_vbn': ''},
 'princess': {'nn_to_nns': 'princesses', 'n_is_nc': '', 'n_is_sb': '0'},
 'process': {'nn_to_nns': 'processes', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vt_typical': '', 'nc_typical': ''},
 'sandwich': {'nn_to_nns': 'sandwiches', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'sandwiches', 'vb_to_vbd': 'sandwiched', 'vb_to_vbn': 'sandwiched', 'vb_to_vbg': 'sandwiching', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'scratch': {'nn_to_nns': 'scratches', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'vb_to_vbz': 'scratches', 'vb_to_vbd': 'scratched', 'vb_to_vbn': 'scratched', 'vb_to_vbg': 'scratching', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'nc_typical': ''},
 'search': {'nn_to_nns': 'searches', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_for': '', 'vb_to_vbz': 'searches', 'vb_to_vbd': 'searched', 'vb_to_vbn': 'searched', 'vb_to_vbg': 'searching', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'smash': {'nn_to_nns': 'smashes', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'stomach': {'nn_to_nns': 'stomaches', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'switch': {'nn_to_nns': 'switches', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_to': '', 'vb_to_vbz': 'switches', 'vb_to_vbd': 'switched', 'vb_to_vbn': 'switched', 'vb_to_vbg': 'switching', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'virus': {'nn_to_nns': 'viruses', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'waitress': {'nn_to_nns': 'waitresses', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'watch': {'nn_to_nns': 'watches', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl': '', 'v_vbg': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'vdo': '', 'v_at': '', 'v_for': '', 'v_vb': '', 'vb_to_vbz': 'watches', 'vb_to_vbd': 'watched', 'vb_to_vbn': 'watched', 'v_n_vb': '', 'v_n_vbg': '', 'vb_to_vbg': 'watching', 'vbd_eq_vbn': ''},
 'wish': {'nn_to_nns': 'wishes', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'wishful', 'nn_to_rb': 'wishfully', 'v_compcl': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'wishes', 'vb_to_vbd': 'wished', 'vb_to_vbn': 'wished', 'vb_to_rb': 'wishfully', 'vb_to_jj': 'wishful', 'vb_to_vbg': 'wishing', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'chairman': {'nn_to_nns': 'chairmen', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'child': {'nn_to_nns': 'children', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'childish', 'nn_to_rb': 'childishly', 'nc_typical': ''},
 'craftsman': {'nn_to_nns': 'craftsmen', 'n_is_nc': '', 'n_is_sb': '0'},
 'crisis': {'nn_to_nns': 'crises', 'n_is_nc': '', 'n_is_sth': ''},
 'criterion': {'nn_to_nns': 'critera', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'datum': {'nn_to_nns': 'data', 'n_is_nc': '', 'n_is_sth': ''},
 'fisherman': {'nn_to_nns': 'fishermen', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'foot': {'nn_to_nns': 'feet', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'nc_typical': '', 'n_is_unit': '', 'quantifier': ''},
 'gentleman': {'nn_to_nns': 'gentlemen', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'grandchild': {'nn_to_nns': 'grandchildren', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'mailman': {'nn_to_nns': 'mailmen', 'n_is_nc': '', 'n_is_sb': '0'},
 'man': {'nn_to_nns': 'men', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'manly', 'nn_to_rb': 'manly', 'vb_to_rb': 'manly', 'vb_to_jj': 'manly', 'nc_typical': ''},
 'medium': {'nn_to_nns': 'media', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'mouse': {'nn_to_nns': 'mice', 'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'penalty': {'nn_to_nns': 'penaltiese', 'n_is_nc': '', 'n_is_sth': ''},
 'policeman': {'nn_to_nns': 'policemen', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'postman': {'nn_to_nns': 'postmen', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'salesman': {'nn_to_nns': 'salesmen', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'seaman': {'nn_to_nns': 'seamen', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'spokesman': {'nn_to_nns': 'spokesmen', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'sportman': {'nn_to_nns': 'sportmen', 'n_is_nc': '', 'n_is_sb': '0'},
 'tooth': {'nn_to_nns': 'teeth', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'toothed', 'vb_to_jj': 'toothed', 'nc_typical': ''},
 'woman': {'nn_to_nns': 'women', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'addendum': {'nn_to_nns': 'addenda', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'agendum': {'nn_to_nns': 'agenda'},
 'alga': {'nn_to_nns': 'algae', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '3'},
 'alumna': {'nn_to_nns': 'alumnae', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'alumnus': {'nn_to_nns': 'alumni', 'n_is_sb': '0'},
 'amoeba': {'nn_to_nns': 'amoebae', 'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'analysis': {'nn_to_nns': 'analyses', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'analyze', 'nn_to_jj': 'analytic'},
 'antenna': {'nn_to_nns': 'antennae', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'apex': {'nn_to_nns': 'apexes', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'appendix': {'nn_to_nns': 'appendixes', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'append', 'nn_to_jj': 'appendant', 'nc_typical': ''},
 'automaton': {'nn_to_nns': 'automata', 'n_is_sb': '2', 'n_is_sth': '2'},
 'axis': {'nn_to_nns': 'axes', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'bacillus': {'nn_to_nns': 'bacilli', 'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'bacterium': {'nn_to_nns': 'bacteria', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'nc_typical': ''},
 'basis': {'nn_to_nns': 'bases', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'base', 'nn_to_jj': 'base'},
 'beau': {'nn_to_nns': 'beaux', 'n_is_nc': '', 'n_is_sb': '0'},
 'buffalo': {'nn_to_nns': 'buffaloes', 'n_is_nc': '', 'n_is_sb': '3', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_sth': '3'},
 'bureau': {'nn_to_nns': 'bureaus', 'n_is_nc': '', 'n_is_sth': ''},
 'cactus': {'nn_to_nns': 'cactuses', 'n_is_nc': '', 'n_is_sth': ''},
 'calf': {'nn_to_nns': 'calves', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'cargo': {'nn_to_nns': 'cargos', 'n_is_nc': '', 'n_is_sth': ''},
 'cervix': {'nn_to_nns': 'cervixes', 'n_is_nc': '', 'n_is_sth': ''},
 'cherub': {'nn_to_nns': 'cherubim', 'n_is_sb': '0'},
 'commando': {'nn_to_nns': 'commandoes', 'n_is_nc': '', 'n_is_sb': '0'},
 'concerto': {'nn_to_nns': 'concerti', 'n_is_nc': '', 'n_is_sth': ''},
 'corpus': {'nn_to_nns': 'corpora', 'n_is_nc': '', 'n_is_sth': ''},
 'curriculum': {'nn_to_nns': 'curricula', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'diagnosis': {'nn_to_nns': 'diagnoses', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'dwarf': {'nn_to_nns': 'dwarfs', 'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': ''},
 'ellipsis': {'nn_to_nns': 'ellipses', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'emphasis': {'nn_to_nns': 'emphases', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'emphasize', 'nn_to_jj': 'emphatic'},
 'erratum': {'nn_to_nns': 'errata'},
 'fireman': {'nn_to_nns': 'firemen', 'n_is_nc': '', 'n_is_sb': '0'},
 'fish': {'nn_to_nns': 'fishes', 'n_is_nc': '', 'n_is_nu': '', 'v_to_vbg': '', 'v_about': '', 'v_for': '', 'vbd_eq_vbn': ''},
 'focus': {'nn_to_nns': 'focuses', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'focused', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'vb_to_vbz': 'focuses', 'vb_to_vbd': 'focused', 'vb_to_vbn': 'focused', 'vb_to_jj': 'focused', 'vb_to_vbg': 'focusing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'formula': {'nn_to_nns': 'formulas', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'formulate', 'nn_to_jj': 'formulaic'},
 'fungus': {'nn_to_nns': 'fungi', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'genius': {'nn_to_nns': 'geniuses', 'n_is_nc': '', 'n_is_sb': '0'},
 'genus': {'nn_to_nns': 'genera', 'n_is_nc': '', 'n_is_sth': ''},
 'goose': {'nn_to_nns': 'geese', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'gymnasium': {'nn_to_nns': 'gymnasia', 'n_is_nu': '', 'n_is_sth': '', 'nc_typical': ''},
 'halo': {'nn_to_nns': 'haloes', 'n_is_nc': '', 'n_is_sth': ''},
 'hippopotamus': {'nn_to_nns': 'hippopotami', 'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'hoof': {'nn_to_nns': 'hoofs', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'kangaroo': {'nn_to_nns': 'kangaroos', 'n_is_nc': '', 'n_is_sb': '3', 'nc_typical': '', 'n_is_sth': '3'},
 'larva': {'nn_to_nns': 'larvae', 'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'leaf': {'nn_to_nns': 'leaves', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'leafy', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'leafs', 'vb_to_vbd': 'leafed', 'vb_to_vbn': 'leafed', 'vb_to_jj': 'leafy', 'vb_to_vbg': 'leafing', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'libretto': {'nn_to_nns': 'libretti', 'n_is_nc': '', 'n_is_sth': ''},
 'life': {'nn_to_nns': 'lives', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'n_is_nu': ''},
 'loaf': {'nn_to_nns': 'loaves', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'looker-on': {'nn_to_nns': 'lookers-on', 'n_is_sb': '0'},
 'louse': {'nn_to_nns': 'lice', 'n_is_nc': '', 'n_is_sb': '3', 'vbd_eq_vbn': '', 'n_is_sth': '3'},
 'man doctor': {'nn_to_nns': 'men doctors'},
 'man-day': {'nn_to_nns': 'man-days'},
 'manservant': {'nn_to_nns': 'menservants', 'n_is_nc': '', 'n_is_sb': '0'},
 'man-time': {'nn_to_nns': 'men-times'},
 'matrix': {'nn_to_nns': 'matrices', 'n_is_sth': '', 'n_is_nc': ''},
 'memorandum': {'nn_to_nns': 'memoranda', 'n_is_nc': '', 'n_is_sth': ''},
 'millennium': {'nn_to_nns': 'millenniums', 'n_is_nc': '', 'n_is_sth': ''},
 'mosquito': {'nn_to_nns': 'mosquitoes', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'nc_typical': ''},
 'motto': {'nn_to_nns': 'mottos', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'nebula': {'nn_to_nns': 'nebulae', 'n_is_nc': '', 'n_is_sth': ''},
 'neurosis': {'nn_to_nns': 'neuroses'},
 'oasis': {'nn_to_nns': 'oases', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'octopus': {'nn_to_nns': 'octopuses', 'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'optimum': {'nn_to_nns': 'optima'},
 'ovum': {'nn_to_nns': 'ova', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ox': {'nn_to_nns': 'oxen', 'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'paralysis': {'nn_to_nns': 'paralyses', 'n_is_nu': '', 'n_is_sth': ''},
 'parenthesis': {'nn_to_nns': 'parentheses', 'n_is_nc': '', 'n_is_sth': ''},
 'penny': {'nn_to_nns': 'pence', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'phenomenon': {'nn_to_nns': 'phenomena', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'phenomenal', 'nc_typical': ''},
 'plateau': {'nn_to_nns': 'plateaux', 'n_is_nc': '', 'n_is_sth': ''},
 'radius': {'nn_to_nns': 'radiuses', 'n_is_nc': '', 'n_is_sth': ''},
 'scarf': {'nn_to_nns': 'scarfs', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'schema': {'nn_to_nns': 'schemata', 'n_is_nc': '', 'n_is_sth': ''},
 'seed': {'nn_to_nns': 'seeds', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'seeds', 'vb_to_vbd': 'seeded', 'vb_to_vbn': 'seeded', 'vb_to_vbg': 'seeding', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vbg_non': ''},
 'seraph': {'nn_to_nns': 'seraphim', 'n_is_sb': '0'},
 'sheaf': {'nn_to_nns': 'sheaves', 'n_is_nc': '', 'n_is_sth': ''},
 'shelf': {'nn_to_nns': 'shelves', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'sister-in-law': {'nn_to_nns': 'sisters-in-law', 'n_is_nc': '', 'n_is_sb': '0'},
 'solo': {'nn_to_nns': 'soli', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'stadium': {'nn_to_nns': 'stadiums', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'stigma': {'nn_to_nns': 'stigmata', 'n_is_nu': '', 'n_is_sth': ''},
 'still life': {'nn_to_nns': 'still lifes'},
 'stimulus': {'nn_to_nns': 'stimuli', 'n_is_nc': '', 'n_is_sth': ''},
 'stratum': {'nn_to_nns': 'stratums', 'n_is_nc': '', 'n_is_sth': ''},
 'syllabus': {'nn_to_nns': 'syllabi', 'n_is_nc': '', 'n_is_sth': ''},
 'symposium': {'nn_to_nns': 'symposiums', 'n_is_nc': '', 'n_is_sth': ''},
 'synopsis': {'nn_to_nns': 'synopses', 'n_is_nc': '', 'n_is_sth': ''},
 'synthesis': {'nn_to_nns': 'syntheses', 'n_is_nu': '', 'n_is_sth': '', 'n_is_nc': ''},
 'tableau': {'nn_to_nns': 'tableaus', 'n_is_nc': '', 'n_is_sth': ''},
 'tempo': {'nn_to_nns': 'tempi', 'n_is_nc': '', 'n_is_sth': ''},
 'terminus': {'nn_to_nns': 'termini', 'n_is_nc': '', 'n_is_sth': ''},
 'thesis': {'nn_to_nns': 'theses', 'n_is_nc': '', 'n_is_sth': ''},
 'tornado': {'nn_to_nns': 'tornados', 'n_is_nc': '', 'n_is_sth': ''},
 'ultimatum': {'nn_to_nns': 'ultimata', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'vacuum': {'nn_to_nns': 'vacua', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'vertebra': {'nn_to_nns': 'vertebrae', 'n_is_nc': '', 'n_is_sth': ''},
 'virtuoso': {'nn_to_nns': 'virtuosi', 'n_is_nc': '', 'n_is_sb': '0'},
 'vita': {'nn_to_nns': 'vitae'},
 'volcano': {'nn_to_nns': 'volcanos', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'vortex': {'nn_to_nns': 'vortices', 'n_is_nc': '', 'n_is_sth': ''},
 'zero': {'nn_to_nns': 'zeroes', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'elf': {'nn_to_nns': 'elves', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'half': {'nn_to_nns': 'halves', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'knife': {'nn_to_nns': 'knives', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'thief': {'nn_to_nns': 'thieves', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'wife': {'nn_to_nns': 'wives', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'wifelike', 'nc_typical': ''},
 'attorney': {'nn_to_nns': 'attorneies', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'baby': {'nn_to_nns': 'babies', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'body': {'nn_to_nns': 'bodies', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'bodily', 'nn_to_rb': 'bodily', 'vb_to_rb': 'bodily', 'vb_to_jj': 'bodily', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'category': {'nn_to_nns': 'categories', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'categorise', 'nn_to_jj': 'categorial', 'nc_typical': ''},
 'century': {'nn_to_nns': 'centuries', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'city': {'nn_to_nns': 'cities', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'community': {'nn_to_nns': 'communities', 'n_is_nc': '', 'n_is_sth': '', 'n_is_collective': ''},
 'contemporary': {'nn_to_nns': 'contemporaries', 'n_is_nc': '', 'n_is_sb': '0'},
 'country': {'nn_to_nns': 'countries', 'n_is_nc': '', 'n_is_sth': ''},
 'county': {'nn_to_nns': 'counties', 'n_is_nc': '', 'n_is_sth': ''},
 'cry': {'nn_to_nns': 'cries', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'crying', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_about': '', 'v_for': '', 'vb_to_vbz': 'cries', 'vb_to_vbd': 'cried', 'vb_to_vbn': 'cried', 'vb_to_jj': 'crying', 'vb_to_vbg': 'crying', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_pass_non': ''},
 'diary': {'nn_to_nns': 'diaries', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'dictionary': {'nn_to_nns': 'dictionaries', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'directory': {'nn_to_nns': 'directories', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'enemy': {'nn_to_nns': 'enemies', 'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_collective': '', 'nc_typical': '', 'n_is_sth': '2'},
 'factory': {'nn_to_nns': 'factories', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'fly': {'nn_to_nns': 'flies', 'n_is_nc': '', 'n_is_sb': '3', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'flies', 'vb_to_vbd': 'flied', 'vb_to_vbn': 'flied', 'vb_to_vbg': 'flying', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'nc_typical': '', 'n_is_sth': '3'},
 'fry': {'nn_to_nns': 'fries', 'n_is_nc': '', 'n_is_sb': '2', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'fries', 'vb_to_vbd': 'fried', 'vb_to_vbn': 'fried', 'vb_to_vbg': 'frying', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'n_is_sth': '2'},
 'geography': {'nn_to_nns': 'geographies', 'n_is_nc': '', 'n_is_sth': '', 'nu_typical': ''},
 'granny': {'nn_to_nns': 'grannies', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'grocery': {'nn_to_nns': 'groceries', 'n_is_nc': '', 'n_is_sth': ''},
 'hobby': {'nn_to_nns': 'hobbies', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nc_typical': ''},
 'jury': {'nn_to_nns': 'juries', 'n_is_nc': '', 'n_is_sth': '', 'n_is_collective': ''},
 'laboratory': {'nn_to_nns': 'laboratories', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'lady': {'nn_to_nns': 'ladies', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'library': {'nn_to_nns': 'libraries', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'lorry': {'nn_to_nns': 'lorries', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'majority': {'nn_to_nns': 'majorities', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'major', 'nn_to_jj': 'major', 'n_is_collective': ''},
 'ministry': {'nn_to_nns': 'ministries', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'ministerial', 'nc_typical': ''},
 'mystery': {'nn_to_nns': 'mysteries', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'mysterious', 'nn_to_rb': 'mysteriously'},
 'party': {'nn_to_nns': 'parties', 'n_is_nc': '', 'n_is_collective': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'photocopy': {'nn_to_nns': 'photocopies', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'photocopies', 'vb_to_vbd': 'photocopied', 'vb_to_vbn': 'photocopied', 'vb_to_vbg': 'photocopying', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'primary': {'nn_to_nns': 'primaries', 'n_is_nc': '', 'n_is_sth': '0'},
 'reply': {'nn_to_nns': 'replies', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'v_to_vbg': '', 'v_to_n': '', 'vdo': '', 'v_with': '', 'v_to': '', 'vb_to_vbz': 'replies', 'vb_to_vbd': 'replied', 'vb_to_vbn': 'replied', 'vb_to_vbg': 'replying', 'vi_typical': '', 'vbd_eq_vbn': '', 'n_is_nc': ''},
 'secretary': {'nn_to_nns': 'secretaries', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'story': {'nn_to_nns': 'stories', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'strawberry': {'nn_to_nns': 'strawberries', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'summary': {'nn_to_nns': 'summaries', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'tendency': {'nn_to_nns': 'tendencies', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'tend', 'nc_typical': '', 'n_is_nc': ''},
 'quality': {'nn_to_nns': 'qualities', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'absence': {'nn_to_nns': 'absences', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'absent', 'nn_to_jj': 'absent', 'nn_to_rb': 'absently'},
 'abstention': {'nn_to_nns': 'abstentions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'abstraction': {'nn_to_nns': 'abstractions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'abstract', 'nn_to_jj': 'abstract', 'nn_to_rb': 'abstractly'},
 'abuse': {'nn_to_nns': 'abuses', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_of': '', 'vb_to_vbz': 'abuses', 'vb_to_vbd': 'abused', 'vb_to_vbn': 'abused', 'vb_to_vbg': 'abusing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'academy': {'nn_to_nns': 'academies', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'academic', 'nn_to_rb': 'academically'},
 'accelerator': {'nn_to_nns': 'accelerators', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'accent': {'nn_to_nns': 'accents', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'acceptance': {'nn_to_nns': 'acceptances', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'accept', 'nn_to_jj': 'acceptable', 'nn_to_rb': 'acceptably'},
 'accession': {'nn_to_nns': 'accessions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'accessory': {'nn_to_nns': 'accessories', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'accident': {'nn_to_nns': 'accidents', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'accidental', 'nn_to_rb': 'accidentally', 'nc_typical': ''},
 'acclamation': {'nn_to_nns': 'acclamations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'accommodation': {'nn_to_nns': 'accommodations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'accommodate', 'nu_typical': ''},
 'accord': {'nn_to_nns': 'accords', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vb_to_rb': 'accordingly', 'vb_to_nn': 'accordance', 'vb_to_jj': 'according', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'account': {'nn_to_nns': 'accounts', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'accountable', 'v_to_vbg': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'accounts', 'vb_to_vbd': 'accounted', 'vb_to_vbn': 'accounted', 'vb_to_jj': 'accountable', 'vb_to_vbg': 'accounting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'ace': {'nn_to_nns': 'aces', 'n_is_nc': '', 'art_an': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'ache': {'nn_to_nns': 'aches', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_from': '', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'achievement': {'nn_to_nns': 'achievements', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'achieve', 'nn_to_jj': 'achievable'},
 'acid': {'nn_to_nns': 'acids', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'acoustic': {'nn_to_nns': 'acoustics', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'acquaintance': {'nn_to_nns': 'acquaintances', 'n_is_nc': '', 'art_an': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'act': {'nn_to_nns': 'acts', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_against': '', 'vb_to_vbz': 'acts', 'vb_to_vbd': 'acted', 'vb_to_vbn': 'acted', 'vb_to_nn': 'action', 'vb_to_vbg': 'acting', 'vbd_eq_vbn': ''},
 'action': {'nn_to_nns': 'actions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'act'},
 'activist': {'nn_to_nns': 'activists', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'activity': {'nn_to_nns': 'activities', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'activate', 'nn_to_jj': 'active', 'nn_to_rb': 'actively', 'nc_typical': ''},
 'actor': {'nn_to_nns': 'actors', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nc_typical': ''},
 'actuality': {'nn_to_nns': 'actualities', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'actualize', 'nn_to_jj': 'actual', 'nn_to_rb': 'actually'},
 'actuary': {'nn_to_nns': 'actuaries', 'n_is_nc': '', 'art_an': '', 'n_is_sb': '0'},
 'adage': {'nn_to_nns': 'adages', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'adaptation': {'nn_to_nns': 'adaptations', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'adapt', 'nn_to_jj': 'adaptable', 'nu_typical': ''},
 'adapter': {'nn_to_nns': 'adapters', 'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'addiction': {'nn_to_nns': 'addictions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'addition': {'nn_to_nns': 'additions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'add', 'nn_to_jj': 'additive'},
 'address': {'nn_to_nns': 'addresses', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'addresses', 'vb_to_vbd': 'addressed', 'vb_to_vbn': 'addressed', 'vb_to_vbg': 'addressing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'nc_typical': ''},
 'adept': {'nn_to_nns': 'adepts', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'adherent': {'nn_to_nns': 'adherents', 'n_is_nc': '', 'art_an': '', 'n_is_sb': '0'},
 'adhesion': {'nn_to_nns': 'adhesions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'adhesive': {'nn_to_nns': 'adhesives', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'adjective': {'nn_to_nns': 'adjectives', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'adjuster': {'nn_to_nns': 'adjusters', 'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'adjustment': {'nn_to_nns': 'adjustments', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'adjust', 'nn_to_jj': 'adjusted', 'nn_to_rb': 'adjustable'},
 'administration': {'nn_to_nns': 'administrations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'administrate', 'nn_to_jj': 'administrative', 'nu_typical': ''},
 'administrator': {'nn_to_nns': 'administrators', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'admirer': {'nn_to_nns': 'admirers', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'admission': {'nn_to_nns': 'admissions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'admit', 'nn_to_jj': 'admitted', 'n_is_nu': ''},
 'admonition': {'nn_to_nns': 'admonitions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'adolescent': {'nn_to_nns': 'adolescents', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'adoption': {'nn_to_nns': 'adoptions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'adopt', 'nn_to_jj': 'adoptive'},
 'adornment': {'nn_to_nns': 'adornments', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'adult': {'nn_to_nns': 'adults', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nc_typical': ''},
 'advancement': {'nn_to_nns': 'advancements', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'advantage': {'nn_to_nns': 'advantages', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_to': '', 'vb_to_vbz': 'advantages', 'vb_to_vbd': 'advantaged', 'vb_to_vbn': 'advantaged', 'vb_to_jj': 'advantaged', 'nn_to_jj': 'advantageous', 'vb_to_vbg': 'advantaging', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'adventure': {'nn_to_nns': 'adventures', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vb_to_jj': 'adventurous', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'adventurer': {'nn_to_nns': 'adventurers', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'adverb': {'nn_to_nns': 'adverbs', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'advertisement': {'nn_to_nns': 'advertisements', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'adviser': {'nn_to_nns': 'advisers', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'affect': {'nn_to_nns': 'affects', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'affective', 'vb_to_jj': 'affective', 'vbd_eq_vbn': '', 'vb_to_nn': 'effect', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'afternoon': {'nn_to_nns': 'afternoons', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'adventure', 'nn_to_jj': 'adventurous'},
 'age': {'nn_to_nns': 'ages', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'agency': {'nn_to_nns': 'agencies', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'agent': {'nn_to_nns': 'agents', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nn_to_vb': 'advertise', 'nn_to_jj': 'advertising'},
 'aggravation': {'nn_to_nns': 'aggravations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'agony': {'nn_to_nns': 'agonies', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'agreement': {'nn_to_nns': 'agreements', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'agree', 'nn_to_jj': 'agreeable'},
 'aim': {'nn_to_nns': 'aims', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'advise', 'nn_to_jj': 'advisory', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_for': '', 'vb_to_vbz': 'aims', 'vb_to_vbd': 'aimed', 'vb_to_vbn': 'aimed', 'vb_to_vbg': 'aiming', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'air': {'nn_to_nns': 'airs', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'airs', 'vb_to_vbd': 'aired', 'vb_to_vbn': 'aired', 'vb_to_vbg': 'airing', 'vbd_eq_vbn': '', 'nu_typical': '', 'n_is_nc': ''},
 'airfield': {'nn_to_nns': 'airfields', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'airing': {'nn_to_nns': 'airings', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbg_to_vb': 'air', 'vbg_to_vbn': 'aired'},
 'airline': {'nn_to_nns': 'airlines', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'airliner': {'nn_to_nns': 'airliners', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'airman': {'nn_to_nns': 'airmen', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'airplane': {'nn_to_nns': 'airplanes', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'airport': {'nn_to_nns': 'airports', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'airship': {'nn_to_nns': 'airships', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'airstream': {'nn_to_nns': 'airstreams', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'airway': {'nn_to_nns': 'airways', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'album': {'nn_to_nns': 'albums', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'alchemist': {'nn_to_nns': 'alchemists', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'alexander': {'nn_to_nns': 'alexanders', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'alexandria': {'nn_to_nns': 'alexandrias', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'algebra': {'nn_to_nns': 'algebras', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nu_typical': ''},
 'amount': {'nn_to_nns': 'amounts', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_to_vbg': '', 'v_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'amounts', 'vb_to_vbd': 'amounted', 'vb_to_vbn': 'amounted', 'vb_to_vbg': 'amounting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'vi_typical': ''},
 'ampere': {'nn_to_nns': 'amperes', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ancestor': {'nn_to_nns': 'ancestors', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nc_typical': ''},
 'anchor': {'nn_to_nns': 'anchors', 'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'v_n': '', 'nsubjpass': '', 'v_to': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'n_is_sth': '2'},
 'angel': {'nn_to_nns': 'angels', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'angle': {'nn_to_nns': 'angles', 'n_is_nc': '', 'art_an': '', 'nn_to_jj': 'angled', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'angles', 'vb_to_vbd': 'angled', 'vb_to_vbn': 'angled', 'vb_to_jj': 'angled', 'vb_to_vbg': 'angling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': '', 'n_is_sth': '0'},
 'animal': {'nn_to_nns': 'animals', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'animation': {'nn_to_nns': 'animations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ankle': {'nn_to_nns': 'ankles', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'announcer': {'nn_to_nns': 'announcers', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'answer': {'nn_to_nns': 'answers', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'answering', 'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'answers', 'vb_to_vbd': 'answered', 'vb_to_vbn': 'answered', 'vb_to_jj': 'answering', 'vb_to_vbg': 'answering', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'vt_typical': '', 'nc_typical': ''},
 'ant': {'nn_to_nns': 'ants', 'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'nc_typical': '', 'n_is_sth': '3'},
 'anticipation': {'nn_to_nns': 'anticipations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'anticipate', 'nn_to_jj': 'anticipative', 'nn_to_rb': 'anticipatively'},
 'anxiety': {'nn_to_nns': 'anxieties', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'anxious', 'nn_to_rb': 'anxiously'},
 'apartment': {'nn_to_nns': 'apartments', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'apparatus': {'nn_to_nns': 'apparatuses', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'apparel': {'nn_to_nns': 'apparels', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'appearance': {'nn_to_nns': 'appearances', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'appear'},
 'appeasement': {'nn_to_nns': 'appeasements', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'appellation': {'nn_to_nns': 'appellations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'appendage': {'nn_to_nns': 'appendages', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'appetite': {'nn_to_nns': 'appetites', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'applause': {'nn_to_nns': 'applauses', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'applaud', 'nn_to_jj': 'applaudable', 'nu_typical': ''},
 'apple': {'nn_to_nns': 'apples', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'appliance': {'nn_to_nns': 'appliances', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'applicant': {'nn_to_nns': 'applicants', 'n_is_nc': '', 'art_an': '', 'n_is_sb': '0', 'nc_typical': ''},
 'application': {'nn_to_nns': 'applications', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'apply', 'nn_to_jj': 'applicable', 'nn_to_rb': 'applicably'},
 'appointment': {'nn_to_nns': 'appointments', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2', 'nn_to_vb': 'appoint', 'nn_to_jj': 'appointive'},
 'apportionment': {'nn_to_nns': 'apportionments', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'appraisal': {'nn_to_nns': 'appraisals', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'appraiser': {'nn_to_nns': 'appraisers', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'appreciation': {'nn_to_nns': 'appreciations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'appreciate', 'nn_to_jj': 'appreciable', 'nn_to_rb': 'appreciably'},
 'apprehension': {'nn_to_nns': 'apprehensions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'apprentice': {'nn_to_nns': 'apprentices', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'vbd_eq_vbn': ''},
 'approach': {'nn_to_nns': 'approaches', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'approachable', 'nn_to_rb': 'approachably', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'approaches', 'vb_to_vbd': 'approached', 'vb_to_vbn': 'approached', 'vb_to_rb': 'approachably', 'vb_to_jj': 'approachable', 'vb_to_vbg': 'approaching', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'nc_typical': ''},
 'appropriation': {'nn_to_nns': 'appropriations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'approval': {'nn_to_nns': 'approvals', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'approve', 'nn_to_jj': 'approving', 'nu_typical': ''},
 'approximation': {'nn_to_nns': 'approximations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'approximate', 'nn_to_jj': 'approximate', 'nn_to_rb': 'approximately'},
 'arbitration': {'nn_to_nns': 'arbitrations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'argument': {'nn_to_nns': 'arguments', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'argue', 'nn_to_jj': 'arguable', 'vb_to_vbz': 'arguments', 'vb_to_vbd': 'argumented', 'vb_to_vbn': 'argumented', 'vb_to_vbg': 'argumenting', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'arrangement': {'nn_to_nns': 'arrangements', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'arrange', 'nn_to_jj': 'arranged'},
 'array': {'nn_to_nns': 'arraies', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'arrow': {'nn_to_nns': 'arrows', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'arrowed', 'vb_to_jj': 'arrowed'},
 'artist': {'nn_to_nns': 'artists', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nc_typical': ''},
 'ash': {'nn_to_nns': 'ashes', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aspect': {'nn_to_nns': 'aspects', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'assembly': {'nn_to_nns': 'assemblies', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'assemble', 'nn_to_jj': 'assembling'},
 'association': {'nn_to_nns': 'associations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'associate', 'nn_to_jj': 'associate'},
 'astronaut': {'nn_to_nns': 'astronauts', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nc_typical': ''},
 'athlete': {'nn_to_nns': 'athletes', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nn_to_jj': 'athletic'},
 'atom': {'nn_to_nns': 'atoms', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'attempt': {'nn_to_nns': 'attempts', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'attempted', 'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vb_to_jj': 'attempted', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'audience': {'nn_to_nns': 'audiences', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_collective': '', 'nc_typical': ''},
 'author': {'nn_to_nns': 'authors', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'authority': {'nn_to_nns': 'authorities', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nn_to_vb': 'authorize', 'nn_to_jj': 'authoritative'},
 'automobile': {'nn_to_nns': 'automobiles', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'award': {'nn_to_nns': 'awards', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'awards', 'vb_to_vbd': 'awarded', 'vb_to_vbn': 'awarded', 'vb_to_vbg': 'awarding', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'nc_typical': ''},
 'babylonian': {'nn_to_nns': 'babylonians', 'n_is_nc': '', 'n_is_sb': '0', 'cap_word': 'Babylonian'},
 'babysitter': {'nn_to_nns': 'babysitters', 'n_is_nc': '', 'n_is_sb': '0'},
 'baby-sitter': {'nn_to_nns': 'baby-sitters', 'n_is_nc': '', 'n_is_sb': '0'},
 'bachelor': {'nn_to_nns': 'bachelors', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'back': {'nn_to_nns': 'backs', 'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'n_is_sth': '2'},
 'backup': {'nn_to_nns': 'backups', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'backwater': {'nn_to_nns': 'backwaters', 'n_is_nc': '', 'n_is_sth': ''},
 'backyard': {'nn_to_nns': 'backyards', 'n_is_nc': '', 'n_is_sth': ''},
 'badminton': {'nn_to_nns': 'badmintons', 'n_is_nc': '', 'n_is_sth': '', 'nu_typical': ''},
 'bag': {'nn_to_nns': 'bags', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'nc_typical': ''},
 'balance': {'nn_to_nns': 'balances', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'balanced', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_with': '', 'v_against': '', 'vb_to_vbz': 'balances', 'vb_to_vbd': 'balanced', 'vb_to_vbn': 'balanced', 'vb_to_jj': 'balanced', 'vb_to_vbg': 'balancing', 'vbd_eq_vbn': ''},
 'balcony': {'nn_to_nns': 'balconies', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'ball': {'nn_to_nns': 'balls', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'ballet': {'nn_to_nns': 'ballets', 'n_is_nc': '', 'n_is_sth': ''},
 'banana': {'nn_to_nns': 'bananas', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'band': {'nn_to_nns': 'bands', 'n_is_nc': '', 'n_is_sth': '', 'n_is_collective': '', 'nn_to_jj': 'banded', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_against': '', 'vb_to_vbz': 'bands', 'vb_to_vbd': 'banded', 'vb_to_vbn': 'banded', 'vb_to_jj': 'banded', 'vb_to_vbg': 'banding', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'bandit': {'nn_to_nns': 'bandits', 'n_is_nc': '', 'n_is_sb': '0'},
 'bang': {'nn_to_nns': 'bangs', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'bangs', 'vb_to_vbd': 'banged', 'vb_to_vbn': 'banged', 'vb_to_vbg': 'banging', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'banger': {'nn_to_nns': 'bangers', 'n_is_nc': '', 'n_is_sth': ''},
 'banister': {'nn_to_nns': 'banisters', 'n_is_nc': '', 'n_is_sth': ''},
 'bank': {'nn_to_nns': 'banks', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_whcl_non': '', 'nc_typical': ''},
 'banker': {'nn_to_nns': 'bankers', 'n_is_nc': '', 'n_is_sb': '0'},
 'bankruptcy': {'nn_to_nns': 'bankruptcies', 'n_is_nc': '', 'n_is_sth': ''},
 'banner': {'nn_to_nns': 'banners', 'n_is_nc': '', 'n_is_sth': ''},
 'banquet': {'nn_to_nns': 'banquets', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'banquette': {'nn_to_nns': 'banquettes', 'n_is_nc': '', 'n_is_sth': ''},
 'barbarity': {'nn_to_nns': 'barbarities', 'n_is_nc': '', 'n_is_sth': ''},
 'barbecue': {'nn_to_nns': 'barbecues', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'barbell': {'nn_to_nns': 'barbells', 'n_is_nc': '', 'n_is_sth': ''},
 'barber': {'nn_to_nns': 'barbers', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'barbershop': {'nn_to_nns': 'barbershops', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'bard': {'nn_to_nns': 'bards', 'n_is_nc': '', 'n_is_sb': '0'},
 'bargain': {'nn_to_nns': 'bargains', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'nsubjpass': '', 'v_with': '', 'v_about': '', 'v_for': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'barge': {'nn_to_nns': 'barges', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'baritone': {'nn_to_nns': 'baritones', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'bark': {'nn_to_nns': 'barks', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'v_at': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'barker': {'nn_to_nns': 'barkers', 'n_is_nc': '', 'n_is_sb': '0'},
 'barn': {'nn_to_nns': 'barns', 'n_is_nc': '', 'n_is_sth': ''},
 'barometer': {'nn_to_nns': 'barometers', 'n_is_nc': '', 'n_is_sth': ''},
 'baron': {'nn_to_nns': 'barons', 'n_is_nc': '', 'n_is_sb': '0'},
 'barracuda': {'nn_to_nns': 'barracudas', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'barrage': {'nn_to_nns': 'barrages', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'barrel': {'nn_to_nns': 'barrels', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'barren': {'nn_to_nns': 'barrens', 'n_is_sth': ''},
 'barricade': {'nn_to_nns': 'barricades', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'barrier': {'nn_to_nns': 'barriers', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'barrio': {'nn_to_nns': 'barrios', 'n_is_nc': '', 'n_is_sth': ''},
 'barrister': {'nn_to_nns': 'barristers', 'n_is_nc': '', 'n_is_sb': '0'},
 'baseball': {'nn_to_nns': 'baseballs', 'n_is_nc': '', 'n_is_sth': ''},
 'baseboard': {'nn_to_nns': 'baseboards', 'n_is_nc': '', 'n_is_sth': ''},
 'basket': {'nn_to_nns': 'baskets', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'basketball': {'nn_to_nns': 'basketballs', 'n_is_nc': '', 'n_is_sth': ''},
 'bass': {'nn_to_nns': 'basses', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'bat': {'nn_to_nns': 'bats', 'n_is_nc': '', 'n_is_sb': '3', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'bats', 'vb_to_vbd': 'batted', 'vb_to_vbn': 'batted', 'vb_to_vbg': 'bating', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'nc_typical': '', 'n_is_sth': '3'},
 'batch': {'nn_to_nns': 'batches', 'n_is_nc': '', 'n_is_sth': '', 'n_of_nns': ''},
 'bath': {'nn_to_nns': 'baths', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'bathed', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'baths', 'vb_to_vbd': 'bathed', 'vb_to_vbn': 'bathed', 'vb_to_jj': 'bathed', 'vb_to_vbg': 'bathing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'bathroom': {'nn_to_nns': 'bathrooms', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'battle': {'nn_to_nns': 'battles', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'vdo': '', 'v_with': '', 'v_for': '', 'v_against': '', 'vb_to_vbz': 'battles', 'vb_to_vbd': 'battled', 'vb_to_vbn': 'battled', 'vb_to_vbg': 'battling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'bean': {'nn_to_nns': 'beans', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'bear': {'nn_to_nns': 'bears', 'n_is_nc': '', 'n_is_sb': '0', 'v_vbg': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'bears', 'vb_to_vbd': 'beared', 'vb_to_vbn': 'beared', 'vb_to_vbg': 'bearing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'beard': {'nn_to_nns': 'beards', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_jj': 'bearded', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'beards', 'vb_to_vbd': 'bearded', 'vb_to_vbn': 'bearded', 'vb_to_jj': 'bearded', 'vb_to_vbg': 'bearding', 'vbd_eq_vbn': '', 'n_is_sth': '2'},
 'bearer': {'nn_to_nns': 'bearers', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'bearing': {'nn_to_nns': 'bearings', 'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'bear', 'vbg_to_vbn': 'beared'},
 'beast': {'nn_to_nns': 'beasts', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '', 'nc_typical': ''},
 'beat': {'nn_to_nns': 'beats', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_to_vbg': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vb_eq_vbd': '', 'v_on': '', 'v_at': '', 'v_with': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'beater': {'nn_to_nns': 'beaters', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'beating': {'nn_to_nns': 'beatings', 'n_is_nc': '', 'n_is_sth': ''},
 'beautician': {'nn_to_nns': 'beauticians', 'n_is_nc': '', 'n_is_sb': '0'},
 'beautification': {'nn_to_nns': 'beautifications', 'n_is_nc': '', 'n_is_sth': ''},
 'beauty': {'nn_to_nns': 'beauties', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '', 'nn_to_vb': 'beautify', 'nn_to_jj': 'beautiful', 'n_is_nu': ''},
 'bed': {'nn_to_nns': 'beds', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'bedding', 'vb_to_jj': 'bedding', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'bedouin': {'nn_to_nns': 'bedouins', 'n_is_nc': '', 'n_is_sb': '0'},
 'bedrock': {'nn_to_nns': 'bedrocks', 'n_is_nc': '', 'n_is_sth': ''},
 'bedroom': {'nn_to_nns': 'bedrooms', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'bedside': {'nn_to_nns': 'bedsides', 'n_is_nc': '', 'n_is_sth': ''},
 'bedspread': {'nn_to_nns': 'bedspreads', 'n_is_nc': '', 'n_is_sth': ''},
 'bee': {'nn_to_nns': 'bees', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'beech': {'nn_to_nns': 'beeches', 'n_is_nc': '', 'n_is_sth': ''},
 'beef': {'nn_to_nns': 'beefs', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nu_typical': ''},
 'beggar': {'nn_to_nns': 'beggars', 'n_is_nc': '', 'n_is_sb': '0'},
 'beginner': {'nn_to_nns': 'beginners', 'n_is_nc': '', 'n_is_sb': '0'},
 'beginning': {'nn_to_nns': 'beginnings', 'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'begin', 'vbg_to_vbn': 'began'},
 'behalf': {'nn_to_nns': 'behalfs', 'n_is_nc': '', 'n_is_sth': ''},
 'behavior': {'nn_to_nns': 'behaviors', 'n_is_nc': '', 'n_is_sth': '', 'n_is_nu': ''},
 'belief': {'nn_to_nns': 'beliefs', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'believe', 'nn_to_jj': 'believing'},
 'believer': {'nn_to_nns': 'believers', 'n_is_nc': '', 'n_is_sb': '0'},
 'bell': {'nn_to_nns': 'bells', 'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'belle': {'nn_to_nns': 'belles', 'n_is_nc': '', 'n_is_sb': '0'},
 'belt': {'nn_to_nns': 'belts', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'belted', 'vb_to_nn': 'belting', 'vb_to_jj': 'belted', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'bench': {'nn_to_nns': 'benches', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'berry': {'nn_to_nns': 'berries', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'bike': {'nn_to_nns': 'bikes', 'n_is_nc': '', 'n_is_sth': '', 'vdo': '', 'vb_to_vbz': 'bikes', 'vb_to_vbd': 'biked', 'vb_to_vbn': 'biked', 'vb_to_vbg': 'biking', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'bill': {'nn_to_nns': 'bills', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'bills', 'vb_to_vbd': 'billed', 'vb_to_vbn': 'billed', 'vb_to_vbg': 'billing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'bird': {'nn_to_nns': 'birds', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'birdcage': {'nn_to_nns': 'birdcages', 'n_is_nc': '', 'n_is_sth': ''},
 'birth': {'nn_to_nns': 'births', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'birthday': {'nn_to_nns': 'birthdays', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'birthplace': {'nn_to_nns': 'birthplaces', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'birthrate': {'nn_to_nns': 'birthrates', 'n_is_nc': '', 'n_is_sth': ''},
 'biscuit': {'nn_to_nns': 'biscuits', 'n_is_nc': '', 'n_is_sth': ''},
 'bisexual': {'nn_to_nns': 'bisexuals', 'n_is_nc': '', 'n_is_sb': '0'},
 'bit': {'nn_to_nns': 'bits', 'n_is_nc': '', 'n_is_sth': '', 'vbd_to_vb': 'bite', 'vbd_to_vbn': 'bitten', 'vbd_eq_vbn': ''},
 'bitch': {'nn_to_nns': 'bitches', 'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_sth': '2', 'dirtyword': ''},
 'bite': {'nn_to_nns': 'bites', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'biting', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'vb_to_vbz': 'bites', 'vb_to_vbd': 'bit', 'vb_to_vbn': 'bitten', 'vb_to_jj': 'biting', 'vb_to_vbg': 'biting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'blackbird': {'nn_to_nns': 'blackbirds', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'blackboard': {'nn_to_nns': 'blackboards', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'blacklist': {'nn_to_nns': 'blacklists', 'n_is_nc': '', 'n_is_sth': ''},
 'blackout': {'nn_to_nns': 'blackouts', 'n_is_nc': '', 'n_is_sth': ''},
 'blacksmith': {'nn_to_nns': 'blacksmiths', 'n_is_nc': '', 'n_is_sb': '0'},
 'blank': {'nn_to_nns': 'blanks', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'blanket': {'nn_to_nns': 'blankets', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'block': {'nn_to_nns': 'blocks', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'blocked', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_with': '', 'vb_to_vbz': 'blocks', 'vb_to_vbd': 'blocked', 'vb_to_vbn': 'blocked', 'vb_to_jj': 'blocked', 'vb_to_vbg': 'blocking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'bloom': {'nn_to_nns': 'blooms', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'bloomer': {'nn_to_nns': 'bloomers', 'n_is_nc': '', 'n_is_sth': ''},
 'blossom': {'nn_to_nns': 'blossoms', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'blot': {'nn_to_nns': 'blots', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'blotter': {'nn_to_nns': 'blotters', 'n_is_nc': '', 'n_is_sth': ''},
 'blouse': {'nn_to_nns': 'blouses', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'blueberry': {'nn_to_nns': 'blueberries', 'n_is_nc': '', 'n_is_sth': ''},
 'bluff': {'nn_to_nns': 'bluffs', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'boat': {'nn_to_nns': 'boats', 'n_is_nc': '', 'n_is_sth': '', 'vdo': '', 'vb_to_vbz': 'boats', 'vb_to_vbd': 'boated', 'vb_to_vbn': 'boated', 'vb_to_vbg': 'boating', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'bodyguard': {'nn_to_nns': 'bodyguards', 'n_is_nc': '', 'n_is_sb': '0'},
 'bog': {'nn_to_nns': 'bogs', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'bomb': {'nn_to_nns': 'bombs', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'bombs', 'vb_to_vbd': 'bombed', 'vb_to_vbn': 'bombed', 'vb_to_vbg': 'bombing', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'bone': {'nn_to_nns': 'bones', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'boned', 'vb_to_jj': 'boned', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'book': {'nn_to_nns': 'books', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'books', 'vb_to_vbd': 'booked', 'vb_to_vbn': 'booked', 'vb_to_vbg': 'booking', 'vt_typical': '', 'vbd_eq_vbn': '', 'nc_typical': '', 'v_whcl_non': ''},
 'bookman': {'nn_to_nns': 'bookmen', 'n_is_nc': '', 'n_is_sb': '0', 'n_is_sth': ''},
 'bookmark': {'nn_to_nns': 'bookmarks', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'bookseller': {'nn_to_nns': 'booksellers', 'n_is_nc': '', 'n_is_sb': '0'},
 'bookshelf': {'nn_to_nns': 'bookshelves', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'bookshop': {'nn_to_nns': 'bookshops', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'bookstore': {'nn_to_nns': 'bookstores', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'bookworm': {'nn_to_nns': 'bookworms', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'boom': {'nn_to_nns': 'booms', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'boomer': {'nn_to_nns': 'boomers', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'boon': {'nn_to_nns': 'boons', 'n_is_nc': '', 'n_is_sth': ''},
 'boost': {'nn_to_nns': 'boosts', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'booster': {'nn_to_nns': 'boosters', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'boot': {'nn_to_nns': 'boots', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'boots', 'vb_to_vbd': 'booted', 'vb_to_vbn': 'booted', 'vb_to_vbg': 'booting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'borrowing': {'nn_to_nns': 'borrowings', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'borrow', 'nn_to_jj': 'borrowed', 'vbg_to_vb': 'borrow', 'vbg_to_vbn': 'borrowed'},
 'bottom': {'nn_to_nns': 'bottoms', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'boundary': {'nn_to_nns': 'boundaries', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'bow': {'nn_to_nns': 'bows', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'nc_typical': ''},
 'bowl': {'nn_to_nns': 'bowls', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'bowls', 'vb_to_vbd': 'bowled', 'vb_to_vbn': 'bowled', 'vb_to_vbg': 'bowling', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'boy': {'nn_to_nns': 'boys', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'boyfriend': {'nn_to_nns': 'boyfriends', 'n_is_nc': '', 'n_is_sb': '0'},
 'bracelet': {'nn_to_nns': 'bracelets', 'n_is_nc': '', 'n_is_sth': ''},
 'bracket': {'nn_to_nns': 'brackets', 'n_is_nc': '', 'n_is_sth': ''},
 'brain': {'nn_to_nns': 'brains', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'brand': {'nn_to_nns': 'brands', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'brandy': {'nn_to_nns': 'brandies', 'n_is_sth': ''},
 'brass': {'nn_to_nns': 'brasses', 'n_is_nc': '', 'n_is_sth': ''},
 'brassiere': {'nn_to_nns': 'brassieres', 'n_is_nc': '', 'n_is_sth': ''},
 'brat': {'nn_to_nns': 'brats', 'n_is_nc': '', 'n_is_sb': '0'},
 'bread': {'nn_to_nns': 'breads', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'nu_typical': ''},
 'breadbasket': {'nn_to_nns': 'breadbaskets', 'n_is_nc': '', 'n_is_sth': ''},
 'breadwinner': {'nn_to_nns': 'breadwinners', 'n_is_nc': '', 'n_is_sb': '0'},
 'break': {'nn_to_nns': 'breaks', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'breakable', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'breaks', 'vb_to_vbd': 'broke', 'vb_to_vbn': 'broken', 'vb_to_jj': 'breakable', 'vb_to_vbg': 'breaking', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'brew': {'nn_to_nns': 'brews', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'brewer': {'nn_to_nns': 'brewers', 'n_is_nc': '', 'n_is_sb': '0'},
 'brewery': {'nn_to_nns': 'breweries', 'n_is_nc': '', 'n_is_sth': ''},
 'bribe': {'nn_to_nns': 'bribes', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'brick': {'nn_to_nns': 'bricks', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vb_to_vbz': 'bricks', 'vb_to_vbd': 'bricked', 'vb_to_vbn': 'bricked', 'vb_to_vbg': 'bricking', 'vbd_eq_vbn': ''},
 'bricklayer': {'nn_to_nns': 'bricklayers', 'n_is_nc': '', 'n_is_sb': '0'},
 'brickyard': {'nn_to_nns': 'brickyards', 'n_is_nc': '', 'n_is_sth': ''},
 'bride': {'nn_to_nns': 'brides', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'bridegroom': {'nn_to_nns': 'bridegrooms', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'bridesmaid': {'nn_to_nns': 'bridesmaids', 'n_is_nc': '', 'n_is_sb': '0'},
 'bridge': {'nn_to_nns': 'bridges', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'bridges', 'vb_to_vbd': 'bridged', 'vb_to_vbn': 'bridged', 'vb_to_vbg': 'bridging', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'nc_typical': ''},
 'bridle': {'nn_to_nns': 'bridles', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'brief': {'nn_to_nns': 'briefs', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'jj_to_jjr': 'briefer', 'jj_to_jjs': 'briefest'},
 'briefcase': {'nn_to_nns': 'briefcases', 'n_is_nc': '', 'n_is_sth': ''},
 'briefing': {'nn_to_nns': 'briefings', 'n_is_nc': '', 'n_is_sth': ''},
 'brig': {'nn_to_nns': 'brigs', 'n_is_nc': '', 'n_is_sth': ''},
 'brigade': {'nn_to_nns': 'brigades', 'n_is_nc': '', 'n_is_sth': ''},
 'brim': {'nn_to_nns': 'brims', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'brink': {'nn_to_nns': 'brinks', 'n_is_nc': '', 'n_is_sth': ''},
 'brioche': {'nn_to_nns': 'brioches', 'n_is_nc': '', 'n_is_sth': ''},
 'bristle': {'nn_to_nns': 'bristles', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'broadcast': {'nn_to_nns': 'broadcasts', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'v_on': '', 'v_in': '', 'v_whcl_non': ''},
 'broadcaster': {'nn_to_nns': 'broadcasters', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'broadside': {'nn_to_nns': 'broadsides', 'n_is_nc': '', 'n_is_sth': ''},
 'brocade': {'nn_to_nns': 'brocades', 'n_is_nc': '', 'n_is_sth': ''},
 'brochure': {'nn_to_nns': 'brochures', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'broiler': {'nn_to_nns': 'broilers', 'n_is_nc': '', 'n_is_sth': ''},
 'broker': {'nn_to_nns': 'brokers', 'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'brokerage': {'nn_to_nns': 'brokerages', 'n_is_nc': '', 'n_is_sth': ''},
 'bromide': {'nn_to_nns': 'bromides', 'n_is_nc': '', 'n_is_sth': ''},
 'bronco': {'nn_to_nns': 'broncos', 'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'bronze': {'nn_to_nns': 'bronzes', 'n_is_nc': '', 'n_is_sth': ''},
 'broom': {'nn_to_nns': 'brooms', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'brow': {'nn_to_nns': 'brows', 'n_is_nc': '', 'n_is_sth': ''},
 'brush': {'nn_to_nns': 'brushes', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'brushed', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_with': '', 'v_against': '', 'vb_to_vbz': 'brushes', 'vb_to_vbd': 'brushed', 'vb_to_vbn': 'brushed', 'vb_to_jj': 'brushed', 'vb_to_vbg': 'brushing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'bucket': {'nn_to_nns': 'buckets', 'n_is_nc': '', 'n_is_sth': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'buckets', 'vb_to_vbd': 'bucketed', 'vb_to_vbn': 'bucketed', 'vb_to_vbg': 'bucketing', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'building': {'nn_to_nns': 'buildings', 'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'build', 'vbg_to_vbn': 'built'},
 'bulb': {'nn_to_nns': 'bulbs', 'n_is_nc': '', 'n_is_sth': ''},
 'bull': {'nn_to_nns': 'bulls', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bullet': {'nn_to_nns': 'bullets', 'n_is_nc': '', 'n_is_sth': ''},
 'bundle': {'nn_to_nns': 'bundles', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'bundling', 'vb_to_jj': 'bundling', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'bus': {'nn_to_nns': 'buses', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'butterfly': {'nn_to_nns': 'butterflies', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'button': {'nn_to_nns': 'buttons', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'buttoned', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'buttons', 'vb_to_vbd': 'buttoned', 'vb_to_vbn': 'buttoned', 'vb_to_jj': 'buttoned', 'vb_to_vbg': 'buttoning', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'buzz': {'nn_to_nns': 'buzzes', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'cabbage': {'nn_to_nns': 'cabbages', 'n_is_nc': '', 'n_is_sth': ''},
 'cabin': {'nn_to_nns': 'cabins', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cabinet': {'nn_to_nns': 'cabinets', 'n_is_nc': '', 'n_is_sth': ''},
 'cable': {'nn_to_nns': 'cables', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'cables', 'vb_to_vbd': 'cabled', 'vb_to_vbn': 'cabled', 'vb_to_vbg': 'cabling', 'vbd_eq_vbn': ''},
 'cafe': {'nn_to_nns': 'cafes', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'cafeteria': {'nn_to_nns': 'cafeterias', 'n_is_sth': '', 'nc_typical': ''},
 'cage': {'nn_to_nns': 'cages', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'caged', 'vb_to_jj': 'caged', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'calculation': {'nn_to_nns': 'calculations', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'calculate', 'nn_to_jj': 'calculating'},
 'calculator': {'nn_to_nns': 'calculators', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'calendar': {'nn_to_nns': 'calendars', 'n_is_nc': '', 'n_is_sth': '', 'vb_to_vbz': 'calendars', 'vb_to_vbd': 'calendared', 'vb_to_vbn': 'calendared', 'vb_to_vbg': 'calendaring', 'vbd_eq_vbn': ''},
 'calender': {'nn_to_nns': 'calenders', 'n_is_nc': '', 'n_is_sth': ''},
 'camel': {'nn_to_nns': 'camels', 'n_is_nc': '', 'n_is_sb': '3', 'nc_typical': '', 'n_is_sth': '3'},
 'camp': {'nn_to_nns': 'camps', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'camped', 'vdo': '', 'vb_to_vbz': 'camps', 'vb_to_vbd': 'camped', 'vb_to_vbn': 'camped', 'vb_to_jj': 'camped', 'vb_to_vbg': 'camping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vi_typical': ''},
 'campus': {'nn_to_nns': 'campuses', 'n_is_nc': '', 'n_is_sth': ''},
 'canal': {'nn_to_nns': 'canals', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'candidate': {'nn_to_nns': 'candidates', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'candle': {'nn_to_nns': 'candles', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'candy': {'nn_to_nns': 'candies', 'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'candies', 'vb_to_vbd': 'candied', 'vb_to_vbn': 'candied', 'vb_to_vbg': 'candying', 'vbd_eq_vbn': ''},
 'canteen': {'nn_to_nns': 'canteens', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'capital': {'nn_to_nns': 'capitals', 'n_is_nc': '', 'n_is_sth': ''},
 'captain': {'nn_to_nns': 'captains', 'n_is_nc': '', 'n_is_sb': '0', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'captains', 'vb_to_vbd': 'captained', 'vb_to_vbn': 'captained', 'vb_to_vbg': 'captaining', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'car': {'nn_to_nns': 'cars', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'card': {'nn_to_nns': 'cards', 'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cardinal': {'nn_to_nns': 'cardinals', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'career': {'nn_to_nns': 'carrers', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'carnation': {'nn_to_nns': 'carnations', 'n_is_nc': '', 'n_is_sth': ''},
 'carpenter': {'nn_to_nns': 'carpenters', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'carpet': {'nn_to_nns': 'carpets', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'carpets', 'vb_to_vbd': 'carpeted', 'vb_to_vbn': 'carpeted', 'vb_to_vbg': 'carpeting', 'vbd_eq_vbn': ''},
 'carriage': {'nn_to_nns': 'carriages', 'n_is_nc': '', 'n_is_sth': ''},
 'carrier': {'nn_to_nns': 'carriers', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'carrot': {'nn_to_nns': 'carrots', 'n_is_nc': '', 'n_is_sth': ''},
 'carry': {'nn_to_nns': 'carries', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'carrying', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'vb_to_vbz': 'carries', 'vb_to_vbd': 'carried', 'vb_to_vbn': 'carried', 'vb_to_jj': 'carrying', 'vb_to_vbg': 'carrying', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'cart': {'nn_to_nns': 'carts', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'carter': {'nn_to_nns': 'carters', 'n_is_nc': '', 'n_is_sb': '0'},
 'cartoon': {'nn_to_nns': 'cartoons', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'case': {'nn_to_nns': 'cases', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'casino': {'nn_to_nns': 'casinos', 'n_is_nc': '', 'n_is_sth': ''},
 'cassette': {'nn_to_nns': 'cassettes', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'cast': {'nn_to_nns': 'casts', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'v_on': '', 'v_about': '', 'v_of': '', 'vb_to_vbz': 'casts', 'vb_to_vbg': 'casting', 'n_is_collective': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'castle': {'nn_to_nns': 'castles', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'cat': {'nn_to_nns': 'cats', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'catalog': {'nn_to_nns': 'catalogs', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'catalogue': {'nn_to_nns': 'catalogues', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'catcher': {'nn_to_nns': 'catchers', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'catholic': {'nn_to_nns': 'catholics', 'n_is_nc': '', 'n_is_sb': '0'},
 'cause': {'nn_to_nns': 'causes', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'v_of': '', 'vb_to_vbz': 'causes', 'vb_to_vbd': 'caused', 'vb_to_vbn': 'caused', 'vb_to_vbg': 'causing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'caution': {'nn_to_nns': 'cautions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'cautious', 'nn_to_rb': 'cautiously', 'vb_to_rb': 'cautiously', 'vb_to_jj': 'cautious', 'v_prprtcl_non': ''},
 'cave': {'nn_to_nns': 'caves', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'caved', 'vb_to_jj': 'caved', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'CD': {'nn_to_nns': 'CDs', 'n_is_nc': '', 'n_is_sth': ''},
 'cease-fire': {'nn_to_nns': 'cease-fires', 'n_is_nc': '', 'n_is_sth': ''},
 'ceiling': {'nn_to_nns': 'ceilings', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'celebration': {'nn_to_nns': 'celebrations', 'n_is_nc': '', 'n_is_sth': ''},
 'celebrity': {'nn_to_nns': 'celebrities', 'n_is_nc': '', 'n_is_sb': '0'},
 'cell': {'nn_to_nns': 'cells', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'cellar': {'nn_to_nns': 'cellars', 'n_is_nc': '', 'n_is_sth': ''},
 'cellphone': {'nn_to_nns': 'cellphones', 'n_is_nc': '', 'n_is_sth': ''},
 'census': {'nn_to_nns': 'censuses', 'n_is_nc': '', 'n_is_sth': ''},
 'centre': {'nn_to_nns': 'centres', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'center', 'nn_to_rb': 'centrally', 'vb_to_rb': 'centrally', 'vb_to_jj': 'center', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'ceremony': {'nn_to_nns': 'ceremonies', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'ceremonial', 'nn_to_rb': 'ceremonially'},
 'certi\x1dficate': {'nn_to_nns': 'certi\x1dficates', 'n_is_nc': ''},
 'chain': {'nn_to_nns': 'chains', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'chained', 'vb_to_jj': 'chained', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'chair': {'nn_to_nns': 'chairs', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'challenge': {'nn_to_nns': 'challenges', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'challenging', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_for': '', 'v_to': '', 'vb_to_vbz': 'challenges', 'vb_to_vbd': 'challenged', 'vb_to_vbn': 'challenged', 'vb_to_jj': 'challenging', 'vb_to_vbg': 'challenging', 'vbd_eq_vbn': ''},
 'chamber': {'nn_to_nns': 'chambers', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'champagne': {'nn_to_nns': 'champagnes', 'n_is_nc': '', 'n_is_sth': ''},
 'champion': {'nn_to_nns': 'champions', 'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'nc_typical': ''},
 'chance': {'nn_to_nns': 'chances', 'n_is_nc': '', 'n_is_sth': '', 'v_vbg': '', 'vbd_eq_vbn': '', 'v_whcl_non': '', 'v_pass_non': '', 'n_is_nu': ''},
 'chancellor': {'nn_to_nns': 'chancellors', 'n_is_nc': '', 'n_is_sb': '0'},
 'channel': {'nn_to_nns': 'channels', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'chapter': {'nn_to_nns': 'chapters', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'character': {'nn_to_nns': 'characters', 'n_is_nc': '', 'n_is_sb': '0', 'n_is_sth': '', 'nn_to_jj': 'characteristic', 'vb_to_jj': 'characteristic', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'charge': {'nn_to_nns': 'charges', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_of': '', 'v_against': '', 'vb_to_vbz': 'charges', 'vb_to_vbd': 'charged', 'vb_to_vbn': 'charged', 'vb_to_vbg': 'charging', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'charity': {'nn_to_nns': 'charities', 'n_is_nc': '', 'n_is_sth': ''},
 'charm': {'nn_to_nns': 'charms', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'charming', 'vb_to_jj': 'charming', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'chart': {'nn_to_nns': 'charts', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': '', 'nc_typical': ''},
 'charter': {'nn_to_nns': 'charters', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'chase': {'nn_to_nns': 'chases', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'chases', 'vb_to_vbd': 'chased', 'vb_to_vbn': 'chased', 'vb_to_vbg': 'chasing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'cheat': {'nn_to_nns': 'cheats', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_jj': 'cheating', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_at': '', 'vb_to_vbz': 'cheats', 'vb_to_vbd': 'cheated', 'vb_to_vbn': 'cheated', 'vb_to_jj': 'cheating', 'vb_to_vbg': 'cheating', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'cheek': {'nn_to_nns': 'cheeks', 'n_is_nc': '', 'n_is_sth': ''},
 'cheese': {'nn_to_nns': 'cheeses', 'n_is_nc': '', 'n_is_sth': ''},
 'chef': {'nn_to_nns': 'chefs', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'chemist': {'nn_to_nns': 'chemists', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'chemistry': {'nn_to_nns': 'chemistries', 'n_is_nc': '', 'n_is_sth': '', 'nu_typical': ''},
 'cheque': {'nn_to_nns': 'cheques', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'cherry': {'nn_to_nns': 'cherries', 'n_is_nc': '', 'n_is_sth': ''},
 'chess': {'nn_to_nns': 'chesses', 'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'chest': {'nn_to_nns': 'chests', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'chicken': {'nn_to_nns': 'chickens', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'childhood': {'nn_to_nns': 'childhoods', 'n_is_nu': '', 'n_is_sth': '', 'n_is_nc': '', 'n_usu_singular': ''},
 'chimney': {'nn_to_nns': 'chimneys', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'chin': {'nn_to_nns': 'chins', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'chocolate': {'nn_to_nns': 'chocolates', 'n_is_nc': '', 'n_is_sth': ''},
 'chorus': {'nn_to_nns': 'choruses', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'chronicle': {'nn_to_nns': 'chronicles', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'chrysanthemum': {'nn_to_nns': 'chrysanthemums', 'n_is_nc': '', 'n_is_sth': ''},
 'church': {'nn_to_nns': 'churches', 'n_is_nc': '', 'n_is_sth': ''},
 'cigar': {'nn_to_nns': 'cigars', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'cigarette': {'nn_to_nns': 'cigarettes', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'cinema': {'nn_to_nns': 'cinemas', 'n_is_nc': '', 'n_is_sth': ''},
 'circle': {'nn_to_nns': 'circles', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'circular', 'nn_to_rb': 'circularly', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vb_to_rb': 'circularly', 'vb_to_jj': 'circular', 'v_compcl_non': '', 'v_prprtcl_non': '', 'nc_typical': ''},
 'circuit': {'nn_to_nns': 'circuits', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'circulation': {'nn_to_nns': 'circulations', 'n_is_nc': '', 'n_is_sth': ''},
 'circumstance': {'nn_to_nns': 'circumstances', 'n_is_nc': '', 'n_is_sth': ''},
 'circus': {'nn_to_nns': 'circuses', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nc_typical': ''},
 'citizen': {'nn_to_nns': 'citizens', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'claim': {'nn_to_nns': 'claims', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'vb_to_vbz': 'claims', 'vb_to_vbd': 'claimed', 'vb_to_vbn': 'claimed', 'vb_to_vbg': 'claiming', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'clash': {'nn_to_nns': 'clashes', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'classroom': {'nn_to_nns': 'classrooms', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'cleaner': {'nn_to_nns': 'cleaners', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'cleanup': {'nn_to_nns': 'cleanups', 'n_is_nc': '', 'n_is_sth': ''},
 'clerk': {'nn_to_nns': 'clerks', 'n_is_nc': '', 'n_is_sb': '0', 'vb_to_vbz': 'clerks', 'vb_to_vbd': 'clerked', 'vb_to_vbn': 'clerked', 'vb_to_vbg': 'clerking', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'click': {'nn_to_nns': 'clicks', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'vb_to_vbz': 'clicks', 'vb_to_vbd': 'clicked', 'vb_to_vbn': 'clicked', 'vb_to_vbg': 'clicking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'client': {'nn_to_nns': 'clients', 'n_is_nc': '', 'n_is_sb': '0'},
 'cliff': {'nn_to_nns': 'cliffs', 'n_is_nc': '', 'n_is_sth': ''},
 'climate': {'nn_to_nns': 'climates', 'n_is_nc': '', 'n_is_sth': ''},
 'climb': {'nn_to_nns': 'climbs', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'climbing', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'climbs', 'vb_to_vbd': 'climbed', 'vb_to_vbn': 'climbed', 'vb_to_jj': 'climbing', 'vb_to_vbg': 'climbing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'clinic': {'nn_to_nns': 'clinics', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'clock': {'nn_to_nns': 'clocks', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_in': '', 'v_of': '', 'vb_to_vbz': 'clocks', 'vb_to_vbd': 'clocked', 'vb_to_vbn': 'clocked', 'vb_to_vbg': 'clocking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'closet': {'nn_to_nns': 'closets', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'closets', 'vb_to_vbd': 'closeted', 'vb_to_vbn': 'closeted', 'vb_to_vbg': 'closeting', 'vbd_eq_vbn': ''},
 'cloth': {'nn_to_nns': 'cloths', 'n_is_nc': '', 'n_is_sth': ''},
 'cloud': {'nn_to_nns': 'clouds', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'cloudy', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'clouds', 'vb_to_vbd': 'clouded', 'vb_to_vbn': 'clouded', 'vb_to_jj': 'cloudy', 'vb_to_vbg': 'clouding', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'club': {'nn_to_nns': 'clubs', 'n_is_nc': '', 'n_is_sth': '', 'n_is_collective': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'clue': {'nn_to_nns': 'clues', 'n_is_nc': '', 'n_is_sth': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'clues', 'vb_to_vbd': 'clued', 'vb_to_vbn': 'clued', 'vb_to_vbg': 'cluing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'coach': {'nn_to_nns': 'coaches', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'coaches', 'vb_to_vbd': 'coached', 'vb_to_vbn': 'coached', 'vb_to_vbg': 'coaching', 'vbd_eq_vbn': ''},
 'coal': {'nn_to_nns': 'coals', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'coals', 'vb_to_vbd': 'coaled', 'vb_to_vbn': 'coaled', 'vb_to_vbg': 'coaling', 'vbd_eq_vbn': '', 'n_is_nu': ''},
 'coast': {'nn_to_nns': 'coasts', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'vdo': '', 'v_on': '', 'v_at': '', 'vb_to_vbz': 'coasts', 'vb_to_vbd': 'coasted', 'vb_to_vbn': 'coasted', 'vb_to_vbg': 'coasting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'coat': {'nn_to_nns': 'coats', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_with': '', 'vb_to_vbz': 'coats', 'vb_to_vbd': 'coated', 'vb_to_vbn': 'coated', 'vb_to_vbg': 'coating', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'code': {'nn_to_nns': 'codes', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'codes', 'vb_to_vbd': 'coded', 'vb_to_vbn': 'coded', 'vb_to_vbg': 'coding', 'vbd_eq_vbn': '', 'v_whcl_non': '', 'vbg_non': ''},
 'coil': {'nn_to_nns': 'coils', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'coin': {'nn_to_nns': 'coins', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'coins', 'vb_to_vbd': 'coined', 'vb_to_vbn': 'coined', 'vb_to_vbg': 'coining', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'collar': {'nn_to_nns': 'collars', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'collars', 'vb_to_vbd': 'collared', 'vb_to_vbn': 'collared', 'vb_to_vbg': 'collaring', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'colleague': {'nn_to_nns': 'colleagues', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'collect': {'nn_to_nns': 'collects', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'collects', 'vb_to_vbd': 'collected', 'vb_to_vbn': 'collected', 'vb_to_nn': 'collection', 'vb_to_jj': 'collective', 'vb_to_vbg': 'collecting', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'college': {'nn_to_nns': 'colleges', 'n_is_nc': '', 'n_is_sth': ''},
 'colony': {'nn_to_nns': 'colonies', 'n_is_nc': '', 'n_is_sth': ''},
 'color': {'nn_to_nns': 'colors', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_jj': '', 'v_compcl_non': ''},
 'colors': {'nn_to_nns': 'colorses', 'nns_to_nn': 'color', 'n_is_nc': '', 'n_is_sth': ''},
 'column': {'nn_to_nns': 'columns', 'n_is_nc': '', 'n_is_sth': ''},
 'comb': {'nn_to_nns': 'combs', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'combat': {'nn_to_nns': 'combats', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'combine': {'nn_to_nns': 'combines', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_against': '', 'vb_to_vbz': 'combines', 'vb_to_vbd': 'combined', 'vb_to_vbn': 'combined', 'vb_to_nn': 'combination', 'vb_to_jj': 'combined', 'vb_to_vbg': 'combining', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'comeback': {'nn_to_nns': 'comebacks', 'n_is_nc': '', 'n_is_sth': ''},
 'comedy': {'nn_to_nns': 'comedies', 'n_is_nc': '', 'n_is_sth': ''},
 'comfort': {'nn_to_nns': 'comforts', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'comfortable', 'nn_to_rb': 'comfortably', 'vb_to_rb': 'comfortably', 'vb_to_jj': 'comfortable', 'vbd_eq_vbn': '', 'v_whcl_non': ''},
 'command': {'nn_to_nns': 'commands', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'commanding', 'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'commands', 'vb_to_vbd': 'commanded', 'vb_to_vbn': 'commanded', 'vb_to_jj': 'commanding', 'vb_to_vbg': 'commanding', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'commander': {'nn_to_nns': 'commanders', 'n_is_nc': '', 'n_is_sb': '0'},
 'comment': {'nn_to_nns': 'comments', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_about': '', 'v_to': '', 'vb_to_vbz': 'comments', 'vb_to_vbd': 'commented', 'vb_to_vbn': 'commented', 'vb_to_vbg': 'commenting', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'commentary': {'nn_to_nns': 'commentaries', 'n_is_nc': '', 'n_is_sth': ''},
 'commission': {'nn_to_nns': 'commissions', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'commissions', 'vb_to_vbd': 'commissioned', 'vb_to_vbn': 'commissioned', 'vb_to_vbg': 'commissioning', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'committee': {'nn_to_nns': 'committees', 'n_is_nc': '', 'n_is_sth': '', 'n_is_collective': '', 'nc_typical': ''},
 'commodity': {'nn_to_nns': 'commodities', 'n_is_nc': '', 'n_is_sth': ''},
 'communication': {'nn_to_nns': 'communications', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'communicate', 'nn_to_jj': 'communicative', 'n_is_nu': ''},
 'communist': {'nn_to_nns': 'communists', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'companion': {'nn_to_nns': 'companions', 'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'company': {'nn_to_nns': 'companies', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_collective': '', 'nn_to_vb': 'accompany', 'n_is_sth': '2'},
 'comparison': {'nn_to_nns': 'comparisons', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'compare', 'nn_to_jj': 'comparative'},
 'compass': {'nn_to_nns': 'compasses', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'compensation': {'nn_to_nns': 'compensations', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'compensate', 'nn_to_jj': 'compensatory'},
 'competition': {'nn_to_nns': 'competitions', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_vb': 'compete', 'nn_to_jj': 'competing', 'n_is_nu': ''},
 'competitor': {'nn_to_nns': 'competitors', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'complaint': {'nn_to_nns': 'complaints', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'complain', 'nn_to_jj': 'complaining'},
 'completion': {'nn_to_nns': 'completions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'complete', 'nn_to_jj': 'complete', 'nn_to_rb': 'completely'},
 'component': {'nn_to_nns': 'components', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'composer': {'nn_to_nns': 'composers', 'n_is_nc': '', 'n_is_sb': '0'},
 'composite': {'nn_to_nns': 'composites', 'n_is_nc': '', 'n_is_sth': ''},
 'composition': {'nn_to_nns': 'compositions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'compose', 'nn_to_jj': 'composed'},
 'compound': {'nn_to_nns': 'compounds', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'comprehension': {'nn_to_nns': 'comprehensions', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'comprehend'},
 'computer': {'nn_to_nns': 'computers', 'n_is_nc': '', 'nn_to_vb': 'compute', 'nn_to_jj': 'computational', 'nc_typical': '', 'n_is_sth': '2'},
 'comrade': {'nn_to_nns': 'comrades', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'con': {'nn_to_nns': 'cons', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'concentrate': {'nn_to_nns': 'concentrates', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'concentrated', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_at': '', 'v_in': '', 'vb_to_vbz': 'concentrates', 'vb_to_vbd': 'concentrated', 'vb_to_vbn': 'concentrated', 'vb_to_nn': 'concentration', 'vb_to_jj': 'concentrated', 'vb_to_vbg': 'concentrating', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'concentration': {'nn_to_nns': 'concentrations', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'concentrate', 'nn_to_jj': 'concentrated'},
 'concept': {'nn_to_nns': 'concepts', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'conceptualise', 'nn_to_jj': 'conceptual', 'nc_typical': ''},
 'concern': {'nn_to_nns': 'concerns', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'concerned', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'concerns', 'vb_to_vbd': 'concerned', 'vb_to_vbn': 'concerned', 'vb_to_jj': 'concerned', 'vb_to_vbg': 'concerning', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'concert': {'nn_to_nns': 'concerts', 'n_is_nc': '', 'n_is_sth': '', 'vb_to_vbz': 'concerts', 'vb_to_vbd': 'concerted', 'vb_to_vbn': 'concerted', 'vb_to_vbg': 'concerting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'conclusion': {'nn_to_nns': 'conclusions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'conclude', 'nn_to_jj': 'conclusive'},
 'condition': {'nn_to_nns': 'conditions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'conditional', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'v_of': '', 'vb_to_vbz': 'conditions', 'vb_to_vbd': 'conditioned', 'vb_to_vbn': 'conditioned', 'vb_to_jj': 'conditional', 'vb_to_vbg': 'conditioning', 'vbd_eq_vbn': '', 'v_whcl_non': ''},
 'conductor': {'nn_to_nns': 'conductors', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'cone': {'nn_to_nns': 'cones', 'n_is_nc': '', 'n_is_sth': ''},
 'conference': {'nn_to_nns': 'conferences', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'confer'},
 'con\x1dfine': {'nn_to_nns': 'con\x1dfines', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'con\x1dfines', 'vb_to_vbd': 'con\x1dfined', 'vb_to_vbn': 'con\x1dfined', 'vb_to_vbg': 'con\x1dfining', 'vbd_eq_vbn': ''},
 'confirmation': {'nn_to_nns': 'confirmations', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'confirm', 'nn_to_jj': 'confirmed'},
 'conflict': {'nn_to_nns': 'conflicts', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'conflictive', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'conflicts', 'vb_to_vbd': 'conflicted', 'vb_to_vbn': 'conflicted', 'vb_to_jj': 'conflictive', 'vb_to_vbg': 'conflicting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'confrontation': {'nn_to_nns': 'confrontations', 'n_is_nc': '', 'n_is_sth': ''},
 'confusion': {'nn_to_nns': 'confusions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'confuse', 'nn_to_jj': 'confusing', 'nn_to_vbn': 'confused', 'n_is_nu': ''},
 'congress': {'nn_to_nns': 'congresses', 'n_is_nc': '', 'n_is_sth': ''},
 'congressman': {'nn_to_nns': 'congressmen', 'n_is_nc': '', 'n_is_sb': '0'},
 'consequence': {'nn_to_nns': 'sonsequences', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'consequent', 'nn_to_rb': 'consequently'},
 'conservation': {'nn_to_nns': 'conservations', 'n_is_nc': '', 'n_is_sth': '', 'nu_typical': ''},
 'conservative': {'nn_to_nns': 'conservatives', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'consideration': {'nn_to_nns': 'considerations', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'consider', 'nn_to_jj': 'considerable'},
 'consolidation': {'nn_to_nns': 'consolidations', 'n_is_nc': '', 'n_is_sth': ''},
 'consortium': {'nn_to_nns': 'consortiums', 'n_is_nc': '', 'n_is_sth': ''},
 'conspiracy': {'nn_to_nns': 'conspiracies', 'n_is_nc': '', 'n_is_sth': ''},
 'construct': {'nn_to_nns': 'constructs', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'constructive', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'constructs', 'vb_to_vbd': 'constructed', 'vb_to_vbn': 'constructed', 'vb_to_nn': 'construction', 'vb_to_jj': 'constructive', 'vb_to_vbg': 'constructing', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'consultant': {'nn_to_nns': 'consultants', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'consumer': {'nn_to_nns': 'consumers', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'consume', 'nn_to_jj': 'consuming'},
 'container': {'nn_to_nns': 'containers', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'contender': {'nn_to_nns': 'contenders', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'contention': {'nn_to_nns': 'contentions', 'n_is_nc': '', 'n_is_sth': ''},
 'contest': {'nn_to_nns': 'contests', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'contests', 'vb_to_vbd': 'contested', 'vb_to_vbn': 'contested', 'vb_to_vbg': 'contesting', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'context': {'nn_to_nns': 'contexts', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'contextualise', 'nn_to_jj': 'contextual'},
 'continent': {'nn_to_nns': 'continents', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'contract': {'nn_to_nns': 'contracts', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'contracted', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'contracts', 'vb_to_vbd': 'contracted', 'vb_to_vbn': 'contracted', 'vb_to_jj': 'contracted', 'vb_to_vbg': 'contracting', 'vbd_eq_vbn': ''},
 'contractor': {'nn_to_nns': 'contractors', 'n_is_nc': '', 'n_is_sb': '0'},
 'contrast': {'nn_to_nns': 'contrasts', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'contrastive', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'contrasts', 'vb_to_vbd': 'contrasted', 'vb_to_vbn': 'contrasted', 'vb_to_jj': 'contrastive', 'vb_to_vbg': 'contrasting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'contribution': {'nn_to_nns': 'contributions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'contribute', 'nn_to_jj': 'contributed'},
 'control': {'nn_to_nns': 'controls', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'nn_to_jj': 'controllable', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'controls', 'vb_to_vbd': 'controled', 'vb_to_vbn': 'controled', 'vb_to_jj': 'controllable', 'vb_to_vbg': 'controling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'controversy': {'nn_to_nns': 'controversies', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'controvert', 'nn_to_jj': 'controversial'},
 'conversation': {'nn_to_nns': 'conversations', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'converse', 'nn_to_jj': 'converse'},
 'conversion': {'nn_to_nns': 'conversions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'convert', 'nn_to_jj': 'convertible'},
 'convert': {'nn_to_nns': 'converts', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'convertible', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'converts', 'vb_to_vbd': 'converted', 'vb_to_vbn': 'converted', 'vb_to_nn': 'conversion', 'vb_to_jj': 'convertible', 'vb_to_vbg': 'converting', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'conviction': {'nn_to_nns': 'convictions', 'n_is_nc': '', 'n_is_sth': ''},
 'cook': {'nn_to_nns': 'cooks', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'cooking', 'v_to_vbg': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'cooks', 'vb_to_vbd': 'cooked', 'vb_to_vbn': 'cooked', 'vb_to_jj': 'cooking', 'vb_to_vbg': 'cooking', 'vt_typical': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'cooker': {'nn_to_nns': 'cookers', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'cookie': {'nn_to_nns': 'cookies', 'n_is_nc': '', 'nc_typical': '', 'n_is_sth': '0'},
 'cop': {'nn_to_nns': 'cops', 'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'cope': {'nn_to_nns': 'copes', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'copes', 'vb_to_vbd': 'coped', 'vb_to_vbn': 'coped', 'vb_to_vbg': 'coping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'copper': {'nn_to_nns': 'coppers', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'copy': {'nn_to_nns': 'copies', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'copied', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'copies', 'vb_to_vbd': 'copied', 'vb_to_vbn': 'copied', 'vb_to_jj': 'copied', 'vb_to_vbg': 'copying', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'core': {'nn_to_nns': 'cores', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'cored', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'cores', 'vb_to_vbd': 'cored', 'vb_to_vbn': 'cored', 'vb_to_jj': 'cored', 'vb_to_vbg': 'coring', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'corner': {'nn_to_nns': 'corners', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'cornered', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'corners', 'vb_to_vbd': 'cornered', 'vb_to_vbn': 'cornered', 'vb_to_jj': 'cornered', 'vb_to_vbg': 'cornering', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'nc_typical': ''},
 'corporation': {'nn_to_nns': 'corporations', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'corporate', 'nn_to_jj': 'corporate', 'nc_typical': ''},
 'correspondent': {'nn_to_nns': 'correspondents', 'n_is_nc': '', 'n_is_sb': '0'},
 'corridor': {'nn_to_nns': 'corridors', 'n_is_nc': '', 'n_is_sth': ''},
 'cottage': {'nn_to_nns': 'cottages', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'council': {'nn_to_nns': 'councils', 'n_is_nc': '', 'n_is_sth': '', 'n_is_collective': ''},
 'count': {'nn_to_nns': 'counts', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'countable', 'v_to_vbg': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'counts', 'vb_to_vbd': 'counted', 'vb_to_vbn': 'counted', 'vb_to_jj': 'countable', 'vb_to_vbg': 'counting', 'vbd_eq_vbn': ''},
 'counter': {'nn_to_nns': 'counters', 'n_is_nc': '', 'n_is_sb': '2', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'counters', 'vb_to_vbd': 'countered', 'vb_to_vbn': 'countered', 'vb_to_vbg': 'countering', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'coup': {'nn_to_nns': 'coups', 'n_is_nc': '', 'n_is_sth': ''},
 'couple': {'nn_to_nns': 'couples', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'couples', 'vb_to_vbd': 'coupled', 'vb_to_vbn': 'coupled', 'vb_to_vbg': 'coupling', 'nn_of_nns': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'nc_typical': '', 'n_of_nns': '', 'n_is_collective': ''},
 'course': {'nn_to_nns': 'courses', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'courses', 'vb_to_vbd': 'coursed', 'vb_to_vbn': 'coursed', 'vb_to_vbg': 'coursing', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'court': {'nn_to_nns': 'courts', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'courts', 'vb_to_vbd': 'courted', 'vb_to_vbn': 'courted', 'vb_to_vbg': 'courting', 'vbd_eq_vbn': ''},
 'courthouse': {'nn_to_nns': 'courthouses', 'n_is_nc': '', 'n_is_sth': ''},
 'courtroom': {'nn_to_nns': 'courtrooms', 'n_is_nc': '', 'n_is_sth': ''},
 'cousin': {'nn_to_nns': 'cousins', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'cover': {'nn_to_nns': 'covers', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'covering', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'covers', 'vb_to_vbd': 'covered', 'vb_to_vbn': 'covered', 'vb_to_nn': 'coverage', 'vb_to_jj': 'covering', 'vb_to_vbg': 'covering', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'cow': {'nn_to_nns': 'cows', 'n_is_nc': '', 'n_is_sb': '3', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'cows', 'vb_to_vbd': 'cowed', 'vb_to_vbn': 'cowed', 'vb_to_vbg': 'cowing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': '', 'n_is_sth': '3'},
 'cox': {'nn_to_nns': 'coxes', 'n_is_nc': '', 'n_is_sb': '0'},
 'craft': {'nn_to_nns': 'crafts', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'cream': {'nn_to_nns': 'creams', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'creation': {'nn_to_nns': 'creations', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'create', 'nn_to_jj': 'creative', 'nn_to_rb': 'creatively'},
 'creator': {'nn_to_nns': 'creators', 'n_is_nc': '', 'n_is_sb': '0'},
 'creature': {'nn_to_nns': 'creatures', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'credit': {'nn_to_nns': 'credits', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'credits', 'vb_to_vbd': 'credited', 'vb_to_vbn': 'credited', 'vb_to_vbg': 'crediting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'creditcard': {'nn_to_nns': 'creditcards', 'n_is_nc': '', 'n_is_sth': ''},
 'crew': {'nn_to_nns': 'crews', 'n_is_nc': '', 'n_is_sth': '', 'vb_to_vbz': 'crews', 'vb_to_vbd': 'crewed', 'vb_to_vbn': 'crewed', 'vb_to_vbg': 'crewing', 'n_is_collective': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'crime': {'nn_to_nns': 'crimes', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'criminal', 'nn_to_rb': 'criminally', 'vb_to_rb': 'criminally', 'vb_to_jj': 'criminal'},
 'crisp': {'nn_to_nns': 'crisps', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'jj_to_jjr': 'crisper', 'jj_to_jjs': 'crispest'},
 'critic': {'nn_to_nns': 'critics', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'critical', 'nn_to_rb': 'critically'},
 'crop': {'nn_to_nns': 'crops', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'cropped', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'crops', 'vb_to_vbd': 'cropped', 'vb_to_vbn': 'cropped', 'vb_to_jj': 'cropped', 'vb_to_vbg': 'cropping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'crowd': {'nn_to_nns': 'crowds', 'n_is_nc': '', 'n_is_sth': '', 'n_is_collective': '', 'nn_to_jj': 'crowded', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'crowds', 'vb_to_vbd': 'crowded', 'vb_to_vbn': 'crowded', 'vb_to_jj': 'crowded', 'vb_to_vbg': 'crowding', 'vbd_eq_vbn': ''},
 'crown': {'nn_to_nns': 'crowns', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'crowned', 'v_n': '', 'v_n_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'crowns', 'vb_to_vbd': 'crowned', 'vb_to_vbn': 'crowned', 'vb_to_jj': 'crowned', 'vb_to_vbg': 'crowning', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'cruise': {'nn_to_nns': 'cruises', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'cult': {'nn_to_nns': 'cults', 'n_is_nc': '', 'n_is_sth': ''},
 'cup': {'nn_to_nns': 'cups', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'cupboard': {'nn_to_nns': 'cupboards', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'curator': {'nn_to_nns': 'curators', 'n_is_nc': '', 'n_is_sb': '0'},
 'curb': {'nn_to_nns': 'curbs', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'cure': {'nn_to_nns': 'cures', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'curable', 'vb_to_jj': 'curable', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'currency': {'nn_to_nns': 'currencies', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'current', 'nn_to_rb': 'currently'},
 'curtain': {'nn_to_nns': 'curtains', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'curtains', 'vb_to_vbd': 'curtained', 'vb_to_vbn': 'curtained', 'vb_to_vbg': 'curtaining', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'curve': {'nn_to_nns': 'curves', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'curves', 'vb_to_vbd': 'curved', 'vb_to_vbn': 'curved', 'vb_to_vbg': 'curving', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'cushion': {'nn_to_nns': 'cushions', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'cushions', 'vb_to_vbd': 'cushioned', 'vb_to_vbn': 'cushioned', 'vb_to_vbg': 'cushioning', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'customer': {'nn_to_nns': 'customers', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'custom': {'nn_to_nns': 'customs', 'n_is_nc': '', 'n_is_sth': ''},
 'cut': {'nn_to_nns': 'cuts', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'v_from': '', 'vb_to_vbz': 'cuts', 'vb_to_vbg': 'cutting', 'vbn_to_vbg': 'cutting', 'vt_typical': '', 'v_compcl_non': ''},
 'cycle': {'nn_to_nns': 'cycles', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'cyclical', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'cycles', 'vb_to_vbd': 'cycled', 'vb_to_vbn': 'cycled', 'vb_to_jj': 'cyclical', 'vb_to_vbg': 'cycling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'dad': {'nn_to_nns': 'dads', 'n_is_nc': '', 'n_is_sb': '0'},
 'daffodil': {'nn_to_nns': 'daffodils', 'n_is_nc': '', 'n_is_sth': ''},
 'dance': {'nn_to_nns': 'dances', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_for': '', 'v_to': '', 'vb_to_vbz': 'dances', 'vb_to_vbd': 'danced', 'vb_to_vbn': 'danced', 'vb_to_vbg': 'dancing', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'dancer': {'nn_to_nns': 'dancers', 'n_is_nc': '', 'n_is_sb': '0'},
 'darling': {'nn_to_nns': 'darlings', 'n_is_nc': '', 'n_is_sb': '0'},
 'database': {'nn_to_nns': 'databases', 'n_is_nc': '', 'n_is_sth': ''},
 'date': {'nn_to_nns': 'dates', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'dated', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'dates', 'vb_to_vbd': 'dated', 'vb_to_vbn': 'dated', 'vb_to_jj': 'dated', 'vb_to_vbg': 'dating', 'vbd_eq_vbn': ''},
 'daughter': {'nn_to_nns': 'daughters', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'dawn': {'nn_to_nns': 'dawns', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'day': {'nn_to_nns': 'days', 'n_is_nc': '', 'n_is_sth': '2', 'quantifier': ''},
 'deadline': {'nn_to_nns': 'deadlines', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'dealer': {'nn_to_nns': 'dealers', 'n_is_nc': '', 'n_is_sb': '0'},
 'dealing': {'nn_to_nns': 'dealings', 'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'deal', 'vbg_to_vbn': 'dealt'},
 'dean': {'nn_to_nns': 'deans', 'n_is_nc': '', 'n_is_sb': '0'},
 'dear': {'nn_to_nns': 'dears', 'n_is_nc': '', 'n_is_sb': '0', 'jj_to_jjr': 'dearer', 'jj_to_jjs': 'dearest'},
 'death': {'nn_to_nns': 'deaths', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_vb': 'die', 'nn_to_jj': 'dead', 'nn_to_rb': 'deadly'},
 'debate': {'nn_to_nns': 'debates', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'debatable', 'v_compcl': '', 'v_vbg': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'debates', 'vb_to_vbd': 'debated', 'vb_to_vbn': 'debated', 'vb_to_jj': 'debatable', 'vb_to_vbg': 'debating', 'vbd_eq_vbn': ''},
 'debris': {'nn_to_nns': 'debrises', 'n_is_nc': '', 'n_is_sth': ''},
 'decade': {'nn_to_nns': 'decades', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'decision': {'nn_to_nns': 'decisions', 'n_is_nc': '', 'n_is_sth': ''},
 'deck': {'nn_to_nns': 'decks', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'declaration': {'nn_to_nns': 'declarations', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'declare', 'nn_to_jj': 'declared'},
 'decline': {'nn_to_nns': 'declines', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'declining', 'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'declines', 'vb_to_vbd': 'declined', 'vb_to_vbn': 'declined', 'vb_to_nn': 'declination', 'vb_to_jj': 'declining', 'vb_to_vbg': 'declining', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': '', 'n_usu_singular': ''},
 'default': {'nn_to_nns': 'defaults', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'defect': {'nn_to_nns': 'defects', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'defendant': {'nn_to_nns': 'defendants', 'n_is_nc': '', 'n_is_sb': '0'},
 'defender': {'nn_to_nns': 'defenders', 'n_is_nc': '', 'n_is_sb': '0'},
 'defense': {'nn_to_nns': 'defenses', 'n_is_nc': '', 'n_is_sth': ''},
 'deficit': {'nn_to_nns': 'deficits', 'n_is_nc': '', 'n_is_sth': ''},
 'definition': {'nn_to_nns': 'definitions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'define', 'nn_to_jj': 'definable'},
 'degree': {'nn_to_nns': 'degrees', 'n_is_nc': '', 'n_is_sth': ''},
 'delegation': {'nn_to_nns': 'delegations', 'n_is_nc': '', 'n_is_sth': ''},
 'delivery': {'nn_to_nns': 'deliveries', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'deliver', 'nn_to_jj': 'delivered'},
 'delta': {'nn_to_nns': 'deltas', 'n_is_nc': '', 'n_is_sth': ''},
 'demand': {'nn_to_nns': 'demands', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'demanding', 'v_compcl': '', 'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_of': '', 'v_from': '', 'vb_to_vbz': 'demands', 'vb_to_vbd': 'demanded', 'vb_to_vbn': 'demanded', 'vb_to_jj': 'demanding', 'vb_to_vbg': 'demanding', 'vbd_eq_vbn': '', 'v_whcl_non': '', 'vt_typical': ''},
 'democracy': {'nn_to_nns': 'democracies', 'n_is_nc': '', 'n_is_sth': ''},
 'demonstration': {'nn_to_nns': 'demonstrations', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'demonstrate', 'nn_to_jj': 'demonstrable'},
 'dentist': {'nn_to_nns': 'dentists', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'department': {'nn_to_nns': 'departments', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'departmental', 'nc_typical': ''},
 'departure': {'nn_to_nns': 'departures', 'n_is_nc': '', 'n_is_sth': ''},
 'deposit': {'nn_to_nns': 'deposits', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'deposits', 'vb_to_vbd': 'deposited', 'vb_to_vbn': 'deposited', 'vb_to_vbg': 'depositing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'depression': {'nn_to_nns': 'depressions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'depress', 'nn_to_jj': 'depressed'},
 'depth': {'nn_to_nns': 'depths', 'n_is_nc': '', 'n_is_sth': ''},
 'deputy': {'nn_to_nns': 'deputies', 'n_is_nc': '', 'n_is_sb': '0'},
 'description': {'nn_to_nns': 'descriptions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'describe', 'nn_to_jj': 'descriptive'},
 'desert': {'nn_to_nns': 'deserts', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_to_n': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'deserts', 'vb_to_vbd': 'deserted', 'vb_to_vbn': 'deserted', 'vb_to_vbg': 'deserting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'design': {'nn_to_nns': 'designs', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'designing', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'designs', 'vb_to_vbd': 'designed', 'vb_to_vbn': 'designed', 'vb_to_jj': 'designing', 'vb_to_vbg': 'designing', 'vt_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'designer': {'nn_to_nns': 'designers', 'n_is_nc': '', 'n_is_sb': '0'},
 'desk': {'nn_to_nns': 'desks', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'desktop': {'nn_to_nns': 'desktops', 'n_is_nc': '', 'n_is_sth': ''},
 'destination': {'nn_to_nns': 'destinations', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'detail': {'nn_to_nns': 'details', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'detailed', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'details', 'vb_to_vbd': 'detailed', 'vb_to_vbn': 'detailed', 'vb_to_jj': 'detailed', 'vb_to_vbg': 'detailing', 'vbd_eq_vbn': ''},
 'detective': {'nn_to_nns': 'detectives', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'developer': {'nn_to_nns': 'developers', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'development': {'nn_to_nns': 'developments', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'develop', 'nn_to_jj': 'developed', 'nn_to_vbg': 'developing', 'nn_to_vbn': 'developed', 'n_is_nu': ''},
 'device': {'nn_to_nns': 'devices', 'n_is_nc': '', 'n_is_sth': ''},
 'devil': {'nn_to_nns': 'devils', 'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'diagram': {'nn_to_nns': 'diagrams', 'n_is_nc': '', 'n_is_sth': '', 'vb_to_vbz': 'diagrams', 'vb_to_vbd': 'diagramed', 'vb_to_vbn': 'diagramed', 'vb_to_vbg': 'diagraming', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'dialog': {'nn_to_nns': 'dialogs', 'n_is_nc': '', 'n_is_sth': ''},
 'dialogue': {'nn_to_nns': 'dialogues', 'n_is_nc': '', 'n_is_sth': ''},
 'diamond': {'nn_to_nns': 'diamonds', 'n_is_nc': '', 'n_is_sth': ''},
 'diet': {'nn_to_nns': 'diets', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'difference': {'nn_to_nns': 'differences', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'differ', 'nn_to_jj': 'different'},
 'difficulty': {'nn_to_nns': 'difficulties', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'difficult', 'nn_to_rb': 'difficultly'},
 'dig': {'nn_to_nns': 'digs', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_in': '', 'v_for': '', 'vb_to_vbz': 'digs', 'vb_to_vbd': 'digged', 'vb_to_vbn': 'digged', 'vb_to_vbg': 'digging', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'dinner': {'nn_to_nns': 'dinners', 'n_is_nc': '', 'n_is_sth': ''},
 'diplomat': {'nn_to_nns': 'diplomats', 'n_is_nc': '', 'n_is_sb': '0'},
 'direction': {'nn_to_nns': 'directions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'direct', 'nn_to_jj': 'direct', 'nn_to_rb': 'direct'},
 'director': {'nn_to_nns': 'directors', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'disability': {'nn_to_nns': 'disabilities', 'n_is_nc': '', 'n_is_sth': ''},
 'disadvantage': {'nn_to_nns': 'disadvantages', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'disappointment': {'nn_to_nns': 'disappointments', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'disappoint', 'nn_to_jj': 'disappointing'},
 'disaster': {'nn_to_nns': 'disasters', 'n_is_nc': '', 'n_is_sth': ''},
 'disc': {'nn_to_nns': 'discs', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'discipline': {'nn_to_nns': 'disciplines', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'disciplinary', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'disciplines', 'vb_to_vbd': 'disciplined', 'vb_to_vbn': 'disciplined', 'vb_to_jj': 'disciplinary', 'vb_to_vbg': 'disciplining', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'disclosure': {'nn_to_nns': 'disclosures', 'n_is_nc': '', 'n_is_sth': ''},
 'discount': {'nn_to_nns': 'discounts', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'discounts', 'vb_to_vbd': 'discounted', 'vb_to_vbn': 'discounted', 'vb_to_vbg': 'discounting', 'vbd_eq_vbn': ''},
 'discovery': {'nn_to_nns': 'discoveries', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'discover'},
 'discrimination': {'nn_to_nns': 'discriminations', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'discriminate', 'nn_to_jj': 'discriminating', 'nu_typical': ''},
 'disk': {'nn_to_nns': 'disks', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'distance': {'nn_to_nns': 'distances', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'distant', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'distances', 'vb_to_vbd': 'distanced', 'vb_to_vbn': 'distanced', 'vb_to_jj': 'distant', 'vb_to_vbg': 'distancing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'distinction': {'nn_to_nns': 'distinctions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'distinct'},
 'district': {'nn_to_nns': 'districts', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'diversity': {'nn_to_nns': 'diversities', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'diversify', 'nn_to_jj': 'diverse', 'nn_to_rb': 'diversely'},
 'divide': {'nn_to_nns': 'divides', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'divided', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'divides', 'vb_to_vbd': 'divided', 'vb_to_vbn': 'divided', 'vb_to_nn': 'division', 'vb_to_jj': 'divided', 'vb_to_vbg': 'dividing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'dividend': {'nn_to_nns': 'dividends', 'n_is_nc': '', 'n_is_sth': ''},
 'division': {'nn_to_nns': 'divisions', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '', 'nn_to_vb': 'divide', 'nn_to_jj': 'divided'},
 'divorce': {'nn_to_nns': 'divorces', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'divorces', 'vb_to_vbd': 'divorced', 'vb_to_vbn': 'divorced', 'vb_to_vbg': 'divorcing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'doctor': {'nn_to_nns': 'doctors', 'n_is_nc': '', 'n_is_sb': '0', 'vb_to_vbz': 'doctors', 'vb_to_vbd': 'doctored', 'vb_to_vbn': 'doctored', 'vb_to_vbg': 'doctoring', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'document': {'nn_to_nns': 'documents', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'documented', 'vb_to_vbz': 'documents', 'vb_to_vbd': 'documented', 'vb_to_vbn': 'documented', 'vb_to_nn': 'documentation', 'vb_to_jj': 'documented', 'vb_to_vbg': 'documenting', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'documentary': {'nn_to_nns': 'documentaries', 'n_is_nc': '', 'n_is_sth': ''},
 'dog': {'nn_to_nns': 'dogs', 'n_is_nc': '', 'n_is_sb': '3', 'nn_to_jj': 'dogged', 'vb_to_jj': 'dogged', 'nc_typical': '', 'n_is_sth': '3'},
 'dollar': {'nn_to_nns': 'dollars', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'donkey': {'nn_to_nns': 'donkeys', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'donor': {'nn_to_nns': 'donors', 'n_is_nc': '', 'n_is_sb': '0'},
 'door': {'nn_to_nns': 'doors', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'dorm': {'nn_to_nns': 'dorms', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'dormitory': {'nn_to_nns': 'dormitories', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'dose': {'nn_to_nns': 'doses', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'dot': {'nn_to_nns': 'dots', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_about': '', 'vb_to_vbz': 'dots', 'vb_to_vbd': 'dotted', 'vb_to_vbn': 'dotted', 'vb_to_vbg': 'doting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'doubt': {'nn_to_nns': 'doubts', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'doubtful', 'nn_to_rb': 'doubtfully', 'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'doubts', 'vb_to_vbd': 'doubted', 'vb_to_vbn': 'doubted', 'vb_to_rb': 'doubtfully', 'vb_to_jj': 'doubtful', 'vb_to_vbg': 'doubting', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'dough': {'nn_to_nns': 'doughs', 'n_is_nc': '', 'n_is_sth': '', 'n_is_nu': ''},
 'downtown': {'nn_to_nns': 'downtowns', 'n_is_nc': '', 'n_is_sth': ''},
 'dozen': {'nn_to_nns': 'dozens', 'n_is_nc': '', 'n_is_sth': ''},
 'draft': {'nn_to_nns': 'drafts', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'dragon': {'nn_to_nns': 'dragons', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'drain': {'nn_to_nns': 'drains', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'drama': {'nn_to_nns': 'dramas', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'dramatize', 'nn_to_jj': 'dramatic', 'nn_to_rb': 'dramatically'},
 'draw': {'nn_to_nns': 'draws', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'drawn', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'draws', 'vb_to_vbd': 'drew', 'vb_to_vbn': 'drawn', 'vb_to_jj': 'drawn', 'vb_to_vbg': 'drawing', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'drawer': {'nn_to_nns': 'drawers', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'drawing': {'nn_to_nns': 'drawings', 'n_is_sth': '', 'vb_to_vbz': 'drawings', 'vb_to_vbd': 'drawinged', 'vb_to_vbn': 'drawinged', 'vb_to_vbg': 'drawinging', 'vbg_to_vb': 'draw', 'vbg_to_vbn': 'drawn', 'vbd_eq_vbn': ''},
 'drink': {'nn_to_nns': 'drinks', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'drunk', 'v_to_n': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'drinks', 'vb_to_vbd': 'drank', 'vb_to_vbn': 'drunk', 'vb_to_jj': 'drunk', 'vb_to_vbg': 'drinking', 'v_compcl_non': ''},
 'driver': {'nn_to_nns': 'drivers', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'drop': {'nn_to_nns': 'drops', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'dropped', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'drops', 'vb_to_vbd': 'dropped', 'vb_to_vbn': 'dropped', 'vb_to_jj': 'dropped', 'vb_to_vbg': 'droping', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'drought': {'nn_to_nns': 'droughts', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'drug': {'nn_to_nns': 'drugs', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'drugs', 'vb_to_vbd': 'drugged', 'vb_to_vbn': 'drugged', 'vb_to_vbg': 'druging', 'vbd_eq_vbn': '', 'vbg_non': '', 'nc_typical': ''},
 'druggist': {'nn_to_nns': 'druggists', 'n_is_nc': '', 'n_is_sb': '0'},
 'drugstore': {'nn_to_nns': 'drugstores', 'n_is_nc': '', 'n_is_sth': ''},
 'drum': {'nn_to_nns': 'drums', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_jj': 'drummed', 'vb_to_jj': 'drummed', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'dude': {'nn_to_nns': 'dudes', 'n_is_nc': '', 'n_is_sb': '0'},
 'dugout': {'nn_to_nns': 'dugouts', 'n_is_nc': '', 'n_is_sth': ''},
 'duke': {'nn_to_nns': 'dukes', 'n_is_nc': '', 'n_is_sb': '0'},
 'dump': {'nn_to_nns': 'dumps', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_in': '', 'vb_to_vbz': 'dumps', 'vb_to_vbd': 'dumpped', 'vb_to_vbn': 'dumpped', 'vb_to_vbg': 'dumping', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'duty': {'nn_to_nns': 'duties', 'n_is_nc': '', 'n_is_sth': ''},
 'ear': {'nn_to_nns': 'ears', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'earthquake': {'nn_to_nns': 'earthquakes', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'economist': {'nn_to_nns': 'economists', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'economy': {'nn_to_nns': 'economies', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'economic', 'nn_to_rb': 'economically'},
 'edge': {'nn_to_nns': 'edges', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'edges', 'vb_to_vbd': 'edged', 'vb_to_vbn': 'edged', 'vb_to_vbg': 'edging', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'edition': {'nn_to_nns': 'editions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'edit', 'nn_to_jj': 'editorial', 'nc_typical': ''},
 'editor': {'nn_to_nns': 'editors', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nc_typical': ''},
 'effect': {'nn_to_nns': 'effects', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'effective', 'vb_to_jj': 'effective', 'vbd_eq_vbn': '', 'nn_to_vb': 'affect', 'v_prprtcl_non': '', 'v_infcl_non': '', 'n_is_nu': ''},
 'efficiency': {'nn_to_nns': 'efficiencies', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'efficient', 'nn_to_rb': 'efficiently'},
 'effort': {'nn_to_nns': 'efforts', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_nu': ''},
 'egg': {'nn_to_nns': 'eggs', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vb_to_vbz': 'eggs', 'vb_to_vbd': 'egged', 'vb_to_vbn': 'egged', 'vb_to_vbg': 'egging', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'elbow': {'nn_to_nns': 'elbows', 'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'elder': {'nn_to_nns': 'elders', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nn_to_jj': 'elderly'},
 'electronics': {'nn_to_nns': 'electronicses', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'element': {'nn_to_nns': 'elements', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'elephant': {'nn_to_nns': 'elephants', 'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'nc_typical': '', 'n_is_sth': '3'},
 'elevator': {'nn_to_nns': 'elevators', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'elite': {'nn_to_nns': 'elites', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'embassy': {'nn_to_nns': 'embassies', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'embrace': {'nn_to_nns': 'embraces', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'emergency': {'nn_to_nns': 'emergencies', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'emotion': {'nn_to_nns': 'emotions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'emperor': {'nn_to_nns': 'emperors', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nc_typical': ''},
 'empire': {'nn_to_nns': 'empires', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'employee': {'nn_to_nns': 'employees', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'employer': {'nn_to_nns': 'employers', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'encounter': {'nn_to_nns': 'encounters', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'encounters', 'vb_to_vbd': 'encountered', 'vb_to_vbn': 'encountered', 'vb_to_vbg': 'encountering', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'end': {'nn_to_nns': 'ends', 'n_is_nc': '', 'art_an': '', 'n_is_sb': '2', 'nn_to_jj': 'ended', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'v_in': '', 'v_with': '', 'vb_to_jj': 'ended', 'vbd_eq_vbn': '', 'n_is_sth': '2'},
 'endorsement': {'nn_to_nns': 'endorsements', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'energy': {'nn_to_nns': 'energies', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'energetic', 'nn_to_rb': 'energetically', 'n_is_nu': ''},
 'engine': {'nn_to_nns': 'engines', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'engineer': {'nn_to_nns': 'engineers', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'engineers', 'vb_to_vbd': 'engineered', 'vb_to_vbn': 'engineered', 'vb_to_vbg': 'engineering', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'enterprise': {'nn_to_nns': 'enterprises', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'entertainer': {'nn_to_nns': 'entertainers', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'enthusiasm': {'nn_to_nns': 'enthusiasms', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'entrance': {'nn_to_nns': 'entrances', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'enter', 'nn_to_jj': 'entered', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'entrances', 'vb_to_vbd': 'entranced', 'vb_to_vbn': 'entranced', 'vb_to_vbg': 'entrancing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'entry': {'nn_to_nns': 'entries', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'envelope': {'nn_to_nns': 'envelopes', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'environment': {'nn_to_nns': 'environments', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'environmental', 'nn_to_rb': 'environmentally'},
 'epic': {'nn_to_nns': 'epics', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'epidemic': {'nn_to_nns': 'epidemics', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'equity': {'nn_to_nns': 'equities', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'era': {'nn_to_nns': 'eras', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'eraser': {'nn_to_nns': 'erasers', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'error': {'nn_to_nns': 'errors', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'erroneous', 'nn_to_rb': 'erroneously'},
 'essay': {'nn_to_nns': 'essays', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_to_vb': '', 'v_n': '', 'v_on': '', 'v_in': '', 'v_about': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'establishment': {'nn_to_nns': 'establishments', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'establish', 'nn_to_jj': 'established'},
 'estate': {'nn_to_nns': 'estates', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'estimate': {'nn_to_nns': 'estimates', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'estimated', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'vb_to_vbz': 'estimates', 'vb_to_vbd': 'estimated', 'vb_to_vbn': 'estimated', 'vb_to_nn': 'estimation', 'vb_to_jj': 'estimated', 'vb_to_vbg': 'estimating', 'vbd_eq_vbn': ''},
 'euro': {'nn_to_nns': 'euros', 'n_is_nc': '', 'n_is_sth': ''},
 'eve': {'nn_to_nns': 'eves', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'event': {'nn_to_nns': 'events', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'evidence': {'nn_to_nns': 'evidences', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_whcl_non': '', 'vbg_non': '', 'n_is_nu': ''},
 'evil': {'nn_to_nns': 'evils', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'evolution': {'nn_to_nns': 'evolutions', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'evolve', 'nn_to_jj': 'evolutionary'},
 'exam': {'nn_to_nns': 'exams', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'examination': {'nn_to_nns': 'examinations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'examine', 'nn_to_jj': 'examining'},
 'example': {'nn_to_nns': 'examples', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'excitement': {'nn_to_nns': 'excitements', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'excite', 'nn_to_jj': 'excited', 'n_is_nu': ''},
 'excuse': {'nn_to_nns': 'excuses', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'excusing', 'v_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'excuses', 'vb_to_vbd': 'excused', 'vb_to_vbn': 'excused', 'vb_to_jj': 'excusing', 'vb_to_vbg': 'excusing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vbg_non': '', 'vt_typical': '', 'nc_typical': ''},
 'execution': {'nn_to_nns': 'executions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'executive': {'nn_to_nns': 'executives', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'exercise': {'nn_to_nns': 'exercises', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'exercised', 'v_n': '', 'nsubjpass': '', 'vb_to_jj': 'exercised', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'exhibit': {'nn_to_nns': 'exhibits', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'exhibited', 'vb_to_nn': 'exhibition', 'vb_to_jj': 'exhibited', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'exile': {'nn_to_nns': 'exiles', 'n_is_nc': '', 'art_an': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'n_is_sth': '2'},
 'existence': {'nn_to_nns': 'existences', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'exist', 'nn_to_jj': 'existent'},
 'exit': {'nn_to_nns': 'exits', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'exits', 'vb_to_vbd': 'exited', 'vb_to_vbn': 'exited', 'vb_to_vbg': 'exiting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'expectation': {'nn_to_nns': 'expectations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'expect', 'nn_to_jj': 'expected'},
 'expense': {'nn_to_nns': 'expenses', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'expensive', 'vb_to_jj': 'expensive'},
 'experience': {'nn_to_nns': 'experiences', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'experienced', 'vb_to_jj': 'experienced'},
 'experiment': {'nn_to_nns': 'experiments', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'experimental', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_with': '', 'vb_to_vbz': 'experiments', 'vb_to_vbd': 'experimented', 'vb_to_vbn': 'experimented', 'vb_to_jj': 'experimental', 'vb_to_vbg': 'experimenting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'expert': {'nn_to_nns': 'experts', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nc_typical': ''},
 'explanation': {'nn_to_nns': 'explanations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'explain', 'nn_to_jj': 'explanatory'},
 'exploration': {'nn_to_nns': 'explorations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'explore', 'nn_to_jj': 'exploratory'},
 'explorer': {'nn_to_nns': 'explorers', 'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'nc_typical': '', 'n_is_sth': '2'},
 'explosion': {'nn_to_nns': 'explosions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'explode', 'nn_to_jj': 'explosive', 'nn_to_rb': 'explosively'},
 'export': {'nn_to_nns': 'exports', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'exporting', 'v_n': '', 'nsubjpass': '', 'v_from': '', 'v_to': '', 'vb_to_jj': 'exporting', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'expose': {'nn_to_nns': 'exposes', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'exposes', 'vb_to_vbd': 'exposed', 'vb_to_vbn': 'exposed', 'vb_to_nn': 'exposure', 'vb_to_jj': 'exposed', 'vb_to_vbg': 'exposing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'exposure': {'nn_to_nns': 'exposures', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'expose', 'nn_to_jj': 'exposed'},
 'expression': {'nn_to_nns': 'expressions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'express', 'nn_to_jj': 'express', 'nn_to_rb': 'expressively'},
 'extension': {'nn_to_nns': 'extensions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'extend', 'nn_to_jj': 'extensive', 'nn_to_rb': 'extensively'},
 'extra': {'nn_to_nns': 'extras', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'eye': {'nn_to_nns': 'eyes', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': '', 'vbd_eq_vbn': ''},
 'fabric': {'nn_to_nns': 'fabrics', 'n_is_nc': '', 'n_is_sth': ''},
 'face': {'nn_to_nns': 'faces', 'n_is_nc': '', 'nn_to_jj': 'faced', 'v_vbg': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'faces', 'vb_to_vbd': 'faced', 'vb_to_vbn': 'faced', 'vb_to_jj': 'faced', 'vb_to_vbg': 'facing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': '', 'nc_typical': '', 'n_is_sth': '2'},
 'facility': {'nn_to_nns': 'facilities', 'n_is_nc': '', 'n_is_sth': ''},
 'facing': {'nn_to_nns': 'facings', 'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'face', 'vbg_to_vbn': 'faced'},
 'fact': {'nn_to_nns': 'facts', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'factual', 'nn_to_rb': 'factually'},
 'factor': {'nn_to_nns': 'factors', 'n_is_nc': '', 'nn_to_jj': 'factored', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'factors', 'vb_to_vbd': 'factored', 'vb_to_vbn': 'factored', 'vb_to_jj': 'factored', 'vb_to_vbg': 'factoring', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'n_is_sth': '2'},
 'faculty': {'nn_to_nns': 'faculties', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'failing': {'nn_to_nns': 'failings', 'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'fail', 'vbg_to_vbn': 'failed'},
 'failure': {'nn_to_nns': 'failures', 'n_is_nu': '', 'n_is_sb': '2', 'nn_to_vb': 'fail', 'nn_to_jj': 'failed', 'n_is_sth': '2', 'n_is_nc': ''},
 'fairytale': {'nn_to_nns': 'fairytales', 'n_is_nc': '', 'n_is_sth': ''},
 'fake': {'nn_to_nns': 'fakes', 'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'n_is_sth': '2'},
 'fall': {'nn_to_nns': 'falls', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'nsubjpass': '', 'vbe': '', 'vdo': '', 'v_on': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'falls', 'vb_to_vbd': 'falled', 'vb_to_vbn': 'falled', 'vb_to_vbg': 'falling', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'family': {'nn_to_nns': 'families', 'n_is_nc': '', 'n_is_sb': '0', 'n_is_collective': ''},
 'fan': {'nn_to_nns': 'fans', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_jj': 'fanned', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'fans', 'vb_to_vbd': 'fanned', 'vb_to_vbn': 'fanned', 'vb_to_jj': 'fanned', 'vb_to_vbg': 'faning', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'fantasy': {'nn_to_nns': 'fantasies', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'fare': {'nn_to_nns': 'fares', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'farm': {'nn_to_nns': 'farms', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'farms', 'vb_to_vbd': 'farmed', 'vb_to_vbn': 'farmed', 'vb_to_vbg': 'farming', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'farmer': {'nn_to_nns': 'farmers', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'fate': {'nn_to_nns': 'fates', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'vbd_eq_vbn': ''},
 'father': {'nn_to_nns': 'fathers', 'n_is_nc': '', 'n_is_sb': '0', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'faucet': {'nn_to_nns': 'faucets', 'n_is_nc': '', 'n_is_sth': ''},
 'fault': {'nn_to_nns': 'faults', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'faulty', 'nn_to_rb': 'faultily', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'faults', 'vb_to_vbd': 'faulted', 'vb_to_vbn': 'faulted', 'vb_to_rb': 'faultily', 'vb_to_jj': 'faulty', 'vb_to_vbg': 'faulting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'fax': {'nn_to_nns': 'faxs', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'feather': {'nn_to_nns': 'feathers', 'n_is_nc': '', 'nn_to_jj': 'feathered', 'vb_to_jj': 'feathered', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': '', 'n_is_sth': '0'},
 'feature': {'nn_to_nns': 'features', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'featured', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'features', 'vb_to_vbd': 'featured', 'vb_to_vbn': 'featured', 'vb_to_jj': 'featured', 'vb_to_vbg': 'featuring', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'federation': {'nn_to_nns': 'federations', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'federal', 'nn_to_rb': 'federally'},
 'fee': {'nn_to_nns': 'fees', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'feedback': {'nn_to_nns': 'feedbacks', 'n_is_nc': '', 'n_is_sth': ''},
 'feeling': {'nn_to_nns': 'feelings', 'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'feel', 'vbg_to_vbn': 'felt'},
 'fellow': {'nn_to_nns': 'fellows', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'female': {'nn_to_nns': 'females', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'fence': {'nn_to_nns': 'fences', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'fences', 'vb_to_vbd': 'fenced', 'vb_to_vbn': 'fenced', 'vb_to_vbg': 'fencing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'festival': {'nn_to_nns': 'festivals', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'fiber': {'nn_to_nns': 'fibers', 'n_is_nc': '', 'n_is_sth': ''},
 'fiction': {'nn_to_nns': 'fictions', 'n_is_nc': '', 'n_is_sth': ''},
 'field': {'nn_to_nns': 'fields', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'nc_typical': ''},
 'fight': {'nn_to_nns': 'fights', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'fighting', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_with': '', 'v_for': '', 'v_against': '', 'vb_to_jj': 'fighting'},
 'fighter': {'nn_to_nns': 'fighters', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'figure': {'nn_to_nns': 'figures', 'n_is_nc': '', 'n_is_sb': '2', 'v_compcl': '', 'v_vbg': '', 'v_to_vbg': '', 'v_n': '', 'v_on': '', 'v_in': '', 'vbd_eq_vbn': '', 'nc_typical': '', 'n_is_sth': '2'},
 'file': {'nn_to_nns': 'files', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'nc_typical': ''},
 'filling': {'nn_to_nns': 'fillings', 'n_is_nc': '', 'n_is_sth': ''},
 'film': {'nn_to_nns': 'films', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'filmed', 'v_n': '', 'nsubjpass': '', 'vb_to_jj': 'filmed', 'vbd_eq_vbn': ''},
 'finale': {'nn_to_nns': 'finales', 'n_is_nc': '', 'n_is_sth': ''},
 'find': {'nn_to_nns': 'finds', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_n': '', 'v_n_to_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_for': '', 'v_against': '', 'v_n_vbg': '', 'vt_typical': ''},
 'finding': {'nn_to_nns': 'findings', 'n_is_nc': '', 'n_is_sth': ''},
 'finger': {'nn_to_nns': 'fingers', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'firefighter': {'nn_to_nns': 'firefighters', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'fisher': {'nn_to_nns': 'fishers', 'n_is_nc': '', 'n_is_sb': '0'},
 'fist': {'nn_to_nns': 'fists', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'flag': {'nn_to_nns': 'flags', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_infcl_non': '', 'nc_typical': ''},
 'flash': {'nn_to_nns': 'flashes', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_with': '', 'vb_to_vbz': 'flashes', 'vb_to_vbd': 'flashed', 'vb_to_vbn': 'flashed', 'vb_to_vbg': 'flashing', 'vbd_eq_vbn': ''},
 'flat': {'nn_to_nns': 'flats', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': '', 'jj_to_jjr': 'flatter', 'jj_to_jjs': 'flattest'},
 'flavor': {'nn_to_nns': 'flavors', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'fleet': {'nn_to_nns': 'fleets', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'flight': {'nn_to_nns': 'flights', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'float': {'nn_to_nns': 'floats', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'floating', 'vb_to_jj': 'floating', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'flock': {'nn_to_nns': 'flocks', 'n_is_nc': '', 'n_is_sth': '', 'n_is_collective': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': '', 'n_of_nn': '', 'n_of_nns': ''},
 'flood': {'nn_to_nns': 'floods', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'flooded', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'floods', 'vb_to_vbd': 'flooded', 'vb_to_vbn': 'flooded', 'vb_to_jj': 'flooded', 'vb_to_vbg': 'flooding', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'floor': {'nn_to_nns': 'floors', 'n_is_nc': '', 'n_is_sth': '', 'vb_to_vbz': 'floors', 'vb_to_vbd': 'floored', 'vb_to_vbn': 'floored', 'vb_to_vbg': 'flooring', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'flower': {'nn_to_nns': 'flowers', 'n_is_nc': '', 'n_is_sth': '', 'vb_to_vbz': 'flowers', 'vb_to_vbd': 'flowered', 'vb_to_vbn': 'flowered', 'vb_to_vbg': 'flowering', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'flu': {'nn_to_nns': 'flus', 'n_is_nc': '', 'n_is_sth': '', 'nu_typical': ''},
 'fold': {'nn_to_nns': 'folds', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'folding', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'folds', 'vb_to_vbd': 'folded', 'vb_to_vbn': 'folded', 'vb_to_jj': 'folding', 'vb_to_vbg': 'folding', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'folk': {'nn_to_nns': 'folks', 'n_is_nc': '', 'n_is_sth': ''},
 'food': {'nn_to_nns': 'foods', 'n_is_nu': '', 'n_is_sth': '', 'n_is_nc': ''},
 'football': {'nn_to_nns': 'footballs', 'n_is_nc': '', 'n_is_sth': ''},
 'forecast': {'nn_to_nns': 'forecasts', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'vt_typical': '', 'nc_typical': ''},
 'forest': {'nn_to_nns': 'forests', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'forested', 'vb_to_vbz': 'forests', 'vb_to_vbd': 'forested', 'vb_to_vbn': 'forested', 'vb_to_jj': 'forested', 'vb_to_vbg': 'foresting', 'vbd_eq_vbn': ''},
 'fork': {'nn_to_nns': 'forks', 'n_is_nc': '', 'n_is_sth': '', 'vb_to_vbz': 'forks', 'vb_to_vbd': 'forked', 'vb_to_vbn': 'forked', 'vb_to_vbg': 'forking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'form': {'nn_to_nns': 'forms', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'formed', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'forms', 'vb_to_vbd': 'formed', 'vb_to_vbn': 'formed', 'vb_to_nn': 'formation', 'vb_to_jj': 'formed', 'vb_to_vbg': 'forming', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'format': {'nn_to_nns': 'formats', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'formation': {'nn_to_nns': 'formations', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'form', 'nn_to_jj': 'formed'},
 'fortnight': {'nn_to_nns': 'fortnights', 'n_is_nc': '', 'n_is_sth': ''},
 'fortune': {'nn_to_nns': 'fortunes', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'fortunate', 'vb_to_jj': 'fortunate', 'n_is_nu': ''},
 'forum': {'nn_to_nns': 'forums', 'n_is_nc': '', 'n_is_sth': ''},
 'foul': {'nn_to_nns': 'fouls', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'jj_to_jjr': 'fouler', 'jj_to_jjs': 'foulest'},
 'founder': {'nn_to_nns': 'founders', 'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'fox': {'nn_to_nns': 'foxes', 'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'fraction': {'nn_to_nns': 'fractions', 'n_is_nc': '', 'n_is_sth': ''},
 'frame': {'nn_to_nns': 'frames', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'freeway': {'nn_to_nns': 'freeways', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'freeze': {'nn_to_nns': 'freezes', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'frozen', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_in': '', 'v_with': '', 'vb_to_vbz': 'freezes', 'vb_to_vbd': 'freezed', 'vb_to_vbn': 'freezed', 'vb_to_jj': 'frozen', 'vb_to_vbg': 'freezing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'freezer': {'nn_to_nns': 'freezers', 'n_is_nc': '', 'n_is_sth': ''},
 'freshman': {'nn_to_nns': 'freshmen', 'n_is_nc': '', 'n_is_sb': '0'},
 'fridge': {'nn_to_nns': 'fridges', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'friend': {'nn_to_nns': 'friends', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'friendly', 'nn_to_rb': 'friendly', 'nc_typical': ''},
 'friendship': {'nn_to_nns': 'friendships', 'n_is_nc': '', 'n_is_sth': ''},
 'frog': {'nn_to_nns': 'frogs', 'n_is_nc': '', 'n_is_sb': '3', 'nc_typical': '', 'n_is_sth': '3'},
 'front': {'nn_to_nns': 'fronts', 'n_is_nc': '', 'n_is_sb': '2', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'fronts', 'vb_to_vbd': 'fronted', 'vb_to_vbn': 'fronted', 'vb_to_vbg': 'fronting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'n_is_sth': '2'},
 'fruit': {'nn_to_nns': 'fruits', 'n_is_nc': '', 'n_is_sth': '', 'vdo': '', 'vb_to_vbz': 'fruits', 'vb_to_vbd': 'fruited', 'vb_to_vbn': 'fruited', 'vb_to_vbg': 'fruiting', 'vbd_eq_vbn': '', 'nn_eq_nns': '', 'n_is_nu': ''},
 'frustration': {'nn_to_nns': 'frustrations', 'n_is_nc': '', 'n_is_sth': '', 'n_is_nu': ''},
 'function': {'nn_to_nns': 'functions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'functional', 'v_to_vbg': '', 'vdo': '', 'vb_to_vbz': 'functions', 'vb_to_vbd': 'functioned', 'vb_to_vbn': 'functioned', 'vb_to_jj': 'functional', 'vb_to_vbg': 'functioning', 'vbd_eq_vbn': '', 'v_pass_non': '', 'vi_typical': ''},
 'fund': {'nn_to_nns': 'funds', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'funds', 'vb_to_vbd': 'funded', 'vb_to_vbn': 'funded', 'vb_to_vbg': 'funding', 'vbd_eq_vbn': ''},
 'future': {'nn_to_nns': 'futures', 'n_is_nc': '', 'n_is_sth': '', 'nsubjpass': ''},
 'futurologist': {'nn_to_nns': 'futurologists', 'n_is_nc': ''},
 'gain': {'nn_to_nns': 'gains', 'n_is_nc': '', 'n_is_sth': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'gains', 'vb_to_vbd': 'gained', 'vb_to_vbn': 'gained', 'vb_to_vbg': 'gaining', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'gallery': {'nn_to_nns': 'galleries', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'gallon': {'nn_to_nns': 'gallons', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': '', 'quantifier': ''},
 'gamble': {'nn_to_nns': 'gambles', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_pass_non': ''},
 'gambling': {'nn_to_nns': 'gamblings', 'n_is_nc': '', 'n_is_sth': ''},
 'game': {'nn_to_nns': 'games', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'gang': {'nn_to_nns': 'gangs', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'gangs', 'vb_to_vbd': 'ganged', 'vb_to_vbn': 'ganged', 'vb_to_vbg': 'ganging', 'n_is_collective': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'gap': {'nn_to_nns': 'gaps', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'garage': {'nn_to_nns': 'garages', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'garages', 'vb_to_vbd': 'garaged', 'vb_to_vbn': 'garaged', 'vb_to_vbg': 'garaging', 'vbd_eq_vbn': ''},
 'garbage': {'nn_to_nns': 'garbages', 'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'garden': {'nn_to_nns': 'gardens', 'n_is_nc': '', 'n_is_sth': '', 'vdo': '', 'vb_to_vbz': 'gardens', 'vb_to_vbd': 'gardened', 'vb_to_vbn': 'gardened', 'vb_to_vbg': 'gardening', 'vbd_eq_vbn': ''},
 'garlic': {'nn_to_nns': 'garlics', 'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'gate': {'nn_to_nns': 'gates', 'n_is_nc': '', 'n_is_sth': ''},
 'gather': {'nn_to_nns': 'gathers', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'gatherable', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_about': '', 'v_for': '', 'vb_to_vbz': 'gathers', 'vb_to_vbd': 'gathered', 'vb_to_vbn': 'gathered', 'vb_to_jj': 'gatherable', 'vb_to_vbg': 'gathering', 'vbd_eq_vbn': ''},
 'gauge': {'nn_to_nns': 'gauges', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'gear': {'nn_to_nns': 'gears', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'gender': {'nn_to_nns': 'genders', 'n_is_nc': '', 'n_is_sth': ''},
 'gene': {'nn_to_nns': 'genes', 'n_is_nc': '', 'n_is_sth': ''},
 'generation': {'nn_to_nns': 'generations', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'generate', 'nn_to_jj': 'generative'},
 'genre': {'nn_to_nns': 'genres', 'n_is_nc': '', 'n_is_sth': ''},
 'geographer': {'nn_to_nns': 'geographers', 'n_is_nc': '', 'n_is_sb': '0'},
 'geologist': {'nn_to_nns': 'geologists', 'n_is_nc': '', 'n_is_sb': '0'},
 'gesture': {'nn_to_nns': 'gestures', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'vbd_eq_vbn': ''},
 'giant': {'nn_to_nns': 'giants', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'gift': {'nn_to_nns': 'gifts', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'gifted', 'vb_to_jj': 'gifted', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'girl': {'nn_to_nns': 'girls', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'girlfriend': {'nn_to_nns': 'girlfriends', 'n_is_nc': '', 'n_is_sb': '0'},
 'glimpse': {'nn_to_nns': 'glimpses', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'globe': {'nn_to_nns': 'globes', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'global', 'nn_to_rb': 'globally', 'vb_to_rb': 'globally', 'vb_to_jj': 'global', 'nc_typical': ''},
 'glory': {'nn_to_nns': 'glories', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'glorious', 'vb_to_jj': 'glorious', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'glove': {'nn_to_nns': 'gloves', 'n_is_nc': '', 'n_is_sth': '', 'vb_to_vbz': 'gloves', 'vb_to_vbd': 'gloved', 'vb_to_vbn': 'gloved', 'vb_to_vbg': 'gloving', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'goal': {'nn_to_nns': 'goals', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'goalie': {'nn_to_nns': 'goalies', 'n_is_nc': '', 'n_is_sb': '0'},
 'government': {'nn_to_nns': 'governments', 'n_is_nc': '', 'n_is_sth': '', 'n_is_collective': '', 'nn_to_vb': 'govern', 'nn_to_jj': 'governing'},
 'governor': {'nn_to_nns': 'governors', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'grab': {'nn_to_nns': 'grabs', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_for': '', 'v_from': '', 'vb_to_vbz': 'grabs', 'vb_to_vbd': 'grabbed', 'vb_to_vbn': 'grabbed', 'vb_to_vbg': 'grabbing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'grace': {'nn_to_nns': 'graces', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'graceful', 'vb_to_jj': 'graceful', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'grade': {'nn_to_nns': 'grades', 'n_is_nc': '', 'n_is_sb': '2', 'v_n': '', 'v_n_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'grades', 'vb_to_vbd': 'graded', 'vb_to_vbn': 'graded', 'vb_to_vbg': 'grading', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'graduate': {'nn_to_nns': 'graduates', 'n_is_nc': '', 'n_is_sb': '0', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'v_at': '', 'v_in': '', 'v_from': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'grain': {'nn_to_nns': 'grains', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'gram': {'nn_to_nns': 'grams', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nc_typical': '', 'quantifier': ''},
 'grandad': {'nn_to_nns': 'grandads', 'n_is_nc': '', 'n_is_sb': '0'},
 'granddaughter': {'nn_to_nns': 'granddaughters', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'grandfather': {'nn_to_nns': 'grandfathers', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'grandma': {'nn_to_nns': 'grandmas', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'grandmother': {'nn_to_nns': 'grandmothers', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'grandparent': {'nn_to_nns': 'grandparents', 'n_is_nc': '', 'n_is_sb': '0'},
 'grandson': {'nn_to_nns': 'grandsons', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'grant': {'nn_to_nns': 'grants', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'grants', 'vb_to_vbd': 'granted', 'vb_to_vbn': 'granted', 'vb_to_vbg': 'granting', 'vbd_eq_vbn': ''},
 'grape': {'nn_to_nns': 'grapes', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'grapefruit': {'nn_to_nns': 'grapefruits', 'n_is_nc': '', 'n_is_sth': ''},
 'graph': {'nn_to_nns': 'graphs', 'n_is_nc': '', 'n_is_sth': '', 'vb_to_vbz': 'graphs', 'vb_to_vbd': 'graphed', 'vb_to_vbn': 'graphed', 'vb_to_vbg': 'graphing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'grass': {'nn_to_nns': 'grasses', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_jj': 'grassy', 'vb_to_jj': 'grassy', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'gray': {'nn_to_nns': 'grays', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'grey': {'nn_to_nns': 'greys', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'grill': {'nn_to_nns': 'grills', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'grip': {'nn_to_nns': 'grips', 'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'n_is_sth': '2'},
 'group': {'nn_to_nns': 'groups', 'n_is_nc': '', 'n_is_sth': '', 'n_is_collective': '', 'vbd_eq_vbn': '', 'nc_typical': '', 'n_of_nns': ''},
 'growth': {'nn_to_nns': 'growths', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'grow', 'nn_to_jj': 'grown'},
 'guarantee': {'nn_to_nns': 'guarantees', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '', 'nn_to_jj': 'guaranteed', 'v_compcl': '', 'v_to_vb': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'guarantees', 'vb_to_vbd': 'guaranteed', 'vb_to_vbn': 'guaranteed', 'vb_to_jj': 'guaranteed', 'vb_to_vbg': 'guaranteeing', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'guard': {'nn_to_nns': 'guards', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_jj': 'guarding', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_against': '', 'v_from': '', 'vb_to_vbz': 'guards', 'vb_to_vbd': 'guarded', 'vb_to_vbn': 'guarded', 'vb_to_jj': 'guarding', 'vb_to_vbg': 'guarding', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'n_is_sth': '2'},
 'guest': {'nn_to_nns': 'guests', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'guidance': {'nn_to_nns': 'guidances', 'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'guide': {'nn_to_nns': 'guides', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'guiding', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'guides', 'vb_to_vbd': 'guided', 'vb_to_vbn': 'guided', 'vb_to_jj': 'guiding', 'vb_to_vbg': 'guiding', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'guidebook': {'nn_to_nns': 'guidebooks', 'n_is_nc': '', 'n_is_sth': ''},
 'guider': {'nn_to_nns': 'guiders', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'guitar': {'nn_to_nns': 'guitars', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'gulf': {'nn_to_nns': 'gulfs', 'n_is_nc': '', 'n_is_sth': ''},
 'gun': {'nn_to_nns': 'guns', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'gunner': {'nn_to_nns': 'gunners', 'n_is_nc': '', 'n_is_sb': '0'},
 'guy': {'nn_to_nns': 'guys', 'n_is_nc': '', 'n_is_sb': '0', 'v_n': '', 'nsubjpass': '', 'vdo': ''},
 'gym': {'nn_to_nns': 'gyms', 'n_is_nc': '', 'n_is_sth': ''},
 'habit': {'nn_to_nns': 'habits', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'habitual', 'vb_to_jj': 'habitual', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'hairdresser': {'nn_to_nns': 'hairdressers', 'n_is_nc': '', 'n_is_sb': '0'},
 'hall': {'nn_to_nns': 'halls', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nc_typical': ''},
 'halt': {'nn_to_nns': 'halts', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'hand': {'nn_to_nns': 'hands', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'handed', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'hands', 'vb_to_vbd': 'handed', 'vb_to_vbn': 'handed', 'vb_to_jj': 'handed', 'vb_to_vbg': 'handing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'handbag': {'nn_to_nns': 'handbags', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'handle': {'nn_to_nns': 'handles', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'handling', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'handles', 'vb_to_vbd': 'handled', 'vb_to_vbn': 'handled', 'vb_to_jj': 'handling', 'vb_to_vbg': 'handling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'harbor': {'nn_to_nns': 'harbors', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'hardware': {'nn_to_nns': 'hardwares', 'n_is_nc': '', 'n_is_sth': ''},
 'harvest': {'nn_to_nns': 'harvests', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'harvesting', 'v_n': '', 'nsubjpass': '', 'vb_to_jj': 'harvesting', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'hat': {'nn_to_nns': 'hats', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'hats', 'vb_to_vbd': 'hatted', 'vb_to_vbn': 'hatted', 'vb_to_vbg': 'hating', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'head': {'nn_to_nns': 'heads', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'v_for': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'headache': {'nn_to_nns': 'headaches', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'heading': {'nn_to_nns': 'headings', 'n_is_nc': '', 'n_is_sth': ''},
 'headline': {'nn_to_nns': 'headlines', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'headmaster': {'nn_to_nns': 'headmasters', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'headteacher': {'nn_to_nns': 'headteachers', 'n_is_nc': '', 'nc_typical': ''},
 'hearing': {'nn_to_nns': 'hearings', 'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'hear', 'vbg_to_vbn': 'heard'},
 'heart': {'nn_to_nns': 'hearts', 'n_is_nc': '', 'n_is_sth': ''},
 'heater': {'nn_to_nns': 'heaters', 'n_is_nc': '', 'n_is_sth': ''},
 'heaven': {'nn_to_nns': 'heavens', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'heavenly', 'nn_to_rb': 'heavenly'},
 'heel': {'nn_to_nns': 'heels', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'height': {'nn_to_nns': 'heights', 'n_is_nc': '', 'n_is_sth': ''},
 'helicopter': {'nn_to_nns': 'helicopters', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'help': {'nn_to_nns': 'helps', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'helpful', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'v_n_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_to': '', 'v_vb': '', 'vb_to_vbz': 'helps', 'vb_to_vbd': 'helped', 'vb_to_vbn': 'helped', 'vb_to_jj': 'helpful', 'v_vbg': '', 'vb_to_vbg': 'helping', 'vbd_eq_vbn': '', 'n_is_nc': ''},
 'heritage': {'nn_to_nns': 'heritages', 'n_is_nc': '', 'n_is_sth': ''},
 'heroin': {'nn_to_nns': 'heroins', 'n_is_nc': '', 'n_is_sth': ''},
 'hide': {'nn_to_nns': 'hides', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'hidden', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'hides', 'vb_to_vbd': 'hid', 'vb_to_vbn': 'hidden', 'vb_to_jj': 'hidden', 'vb_to_vbg': 'hiding', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'highlight': {'nn_to_nns': 'highlights', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'highlighted', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'highlights', 'vb_to_vbd': 'highlighted', 'vb_to_vbn': 'highlighted', 'vb_to_jj': 'highlighted', 'vb_to_vbg': 'highlighting', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'highway': {'nn_to_nns': 'highways', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'hike': {'nn_to_nns': 'hikes', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'n_is_nc': ''},
 'hill': {'nn_to_nns': 'hills', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'hilly', 'vb_to_jj': 'hilly', 'nc_typical': ''},
 'hint': {'nn_to_nns': 'hints', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'hip': {'nn_to_nns': 'hips', 'n_is_nc': '', 'n_is_sth': '', 'jj_to_jjr': 'hipper', 'jj_to_jjs': 'hippest'},
 'historian': {'nn_to_nns': 'historians', 'n_is_nc': '', 'n_is_sb': '0'},
 'history': {'nn_to_nns': 'histories', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'historic', 'nn_to_rb': 'historically'},
 'hit': {'nn_to_nns': 'hits', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'vb_to_vbz': 'hits', 'vb_to_vbg': 'hitting', 'vbn_to_vbg': 'hitting', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'hitler': {'nn_to_nns': 'hitlers', 'n_is_nc': '', 'n_is_sb': '0'},
 'hockey': {'nn_to_nns': 'hockeys', 'n_is_nc': '', 'n_is_sth': ''},
 'holder': {'nn_to_nns': 'holders', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'hole': {'nn_to_nns': 'holes', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'holes', 'vb_to_vbd': 'holed', 'vb_to_vbn': 'holed', 'vb_to_vbg': 'holing', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'holiday': {'nn_to_nns': 'holidays', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'hollow': {'nn_to_nns': 'hollows', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'holocaust': {'nn_to_nns': 'holocausts', 'n_is_nc': '', 'n_is_sth': ''},
 'home': {'nn_to_nns': 'homes', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_pass_non': ''},
 'homeland': {'nn_to_nns': 'homelands', 'n_is_nc': '', 'n_is_sth': ''},
 'homer': {'nn_to_nns': 'homers', 'n_is_nc': '', 'n_is_sth': ''},
 'hometown': {'nn_to_nns': 'hometowns', 'n_is_nc': '', 'n_is_sth': ''},
 'hook': {'nn_to_nns': 'hooks', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'hooked', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'vb_to_vbz': 'hooks', 'vb_to_vbd': 'hooked', 'vb_to_vbn': 'hooked', 'vb_to_jj': 'hooked', 'vb_to_vbg': 'hooking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'nc_typical': ''},
 'horizon': {'nn_to_nns': 'horizons', 'n_is_nc': '', 'n_is_sth': ''},
 'horizontal': {'nn_to_nns': 'horizontals', 'n_is_nc': '', 'n_is_sth': ''},
 'horror': {'nn_to_nns': 'horrors', 'n_is_nc': '', 'n_is_sth': ''},
 'horse': {'nn_to_nns': 'horses', 'n_is_nc': '', 'n_is_sb': '3', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_about': '', 'vb_to_vbz': 'horses', 'vb_to_vbd': 'horsed', 'vb_to_vbn': 'horsed', 'vb_to_vbg': 'hoping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'nc_typical': '', 'n_is_sth': '3'},
 'hospital': {'nn_to_nns': 'hospitals', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'host': {'nn_to_nns': 'hosts', 'n_is_nc': '', 'n_is_sb': '2', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'hosts', 'vb_to_vbd': 'hosted', 'vb_to_vbn': 'hosted', 'vb_to_vbg': 'hosting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vt_typical': '', 'nc_typical': '', 'n_is_sth': '2'},
 'hotel': {'nn_to_nns': 'hotels', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': '', 'n_is_place': ''},
 'hour': {'nn_to_nns': 'hours', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'hourly', 'nn_to_rb': 'hourly', 'nc_typical': '', 'quantifier': ''},
 'house': {'nn_to_nns': 'houses', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'housed', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'houses', 'vb_to_vbd': 'housed', 'vb_to_vbn': 'housed', 'vb_to_jj': 'housed', 'vb_to_vbg': 'housing', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'household': {'nn_to_nns': 'households', 'n_is_nc': '', 'n_is_sth': ''},
 'housing': {'nn_to_nns': 'housings', 'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'house', 'vbg_to_vbn': 'housed'},
 'human': {'nn_to_nns': 'humans', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'humanitarian': {'nn_to_nns': 'humanitarians', 'n_is_nc': '', 'n_is_sb': '0'},
 'hundred': {'nn_to_nns': 'hundreds', 'n_is_nc': '', 'n_is_sth': ''},
 'hundredpercenter': {'nn_to_nns': 'hundredpercenters', 'n_is_nc': '', 'n_is_sb': '0'},
 'hundredth': {'nn_to_nns': 'hundredths', 'n_is_nc': '', 'n_is_sth': ''},
 'hunt': {'nn_to_nns': 'hunts', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'hunting', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'hunts', 'vb_to_vbd': 'hunted', 'vb_to_vbn': 'hunted', 'vb_to_jj': 'hunting', 'vb_to_vbg': 'hunting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'hunter': {'nn_to_nns': 'hunters', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'hurricane': {'nn_to_nns': 'hurricanes', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'husband': {'nn_to_nns': 'husbands', 'n_is_nc': '', 'n_is_sb': '0', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'icon': {'nn_to_nns': 'icons', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'idea': {'nn_to_nns': 'ideas', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'identification': {'nn_to_nns': 'identifications', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'identify', 'nn_to_jj': 'identifiable', 'nu_typical': ''},
 'identity': {'nn_to_nns': 'identities', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'idiot': {'nn_to_nns': 'idiots', 'n_is_nc': '', 'art_an': '', 'n_is_sb': '0'},
 'illegal': {'nn_to_nns': 'illegals', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'illness': {'nn_to_nns': 'illnesses', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'ill', 'nn_to_rb': 'illy'},
 'illustration': {'nn_to_nns': 'illustrations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'illustrate', 'nn_to_jj': 'illustrative'},
 'image': {'nn_to_nns': 'images', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2', 'nn_to_vb': 'imagine', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'imagination': {'nn_to_nns': 'imaginations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'imagine', 'nn_to_jj': 'imaginative'},
 'immunity': {'nn_to_nns': 'immunities', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'implement': {'nn_to_nns': 'implements', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'implemented', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'implements', 'vb_to_vbd': 'implemented', 'vb_to_vbn': 'implemented', 'vb_to_nn': 'implementation', 'vb_to_jj': 'implemented', 'vb_to_vbg': 'implementing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'import': {'nn_to_nns': 'imports', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'imports', 'vb_to_vbd': 'imported', 'vb_to_vbn': 'imported', 'vb_to_vbg': 'importing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vt_typical': ''},
 'impression': {'nn_to_nns': 'impressions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'improvement': {'nn_to_nns': 'improvements', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'improve', 'nn_to_jj': 'improving'},
 'incentive': {'nn_to_nns': 'incentives', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'increase': {'nn_to_nns': 'increases', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'increasing', 'nn_to_rb': 'increasingly', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'increases', 'vb_to_vbd': 'increased', 'vb_to_vbn': 'increased', 'vb_to_rb': 'increasingly', 'vb_to_jj': 'increasing', 'vb_to_vbg': 'increasing', 'n_is_nu': '', 'vbd_eq_vbn': ''},
 'indication': {'nn_to_nns': 'indications', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'indicate', 'nn_to_jj': 'indicative'},
 'indictment': {'nn_to_nns': 'indictments', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'industry': {'nn_to_nns': 'industries', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'industrial', 'nn_to_rb': 'industrially'},
 'infant': {'nn_to_nns': 'infants', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'infection': {'nn_to_nns': 'infections', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ingredient': {'nn_to_nns': 'ingredients', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'injury': {'nn_to_nns': 'injuries', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'injure', 'nn_to_jj': 'injured'},
 'inning': {'nn_to_nns': 'innings', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'innocent': {'nn_to_nns': 'innocents', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'innovation': {'nn_to_nns': 'innovations', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'innovate', 'nn_to_jj': 'innovative'},
 'inquiry': {'nn_to_nns': 'inquiries', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'inquire', 'nn_to_jj': 'inquiring'},
 'insect': {'nn_to_nns': 'insects', 'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'nc_typical': '', 'n_is_sth': '3'},
 'insert': {'nn_to_nns': 'inserts', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'inserted', 'v_n': '', 'nsubjpass': '', 'vb_to_nn': 'insertion', 'vb_to_jj': 'inserted', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'inspection': {'nn_to_nns': 'inspections', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'inspect', 'nn_to_jj': 'inspected'},
 'inspector': {'nn_to_nns': 'inspectors', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'inspiration': {'nn_to_nns': 'inspirations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_nu': ''},
 'installation': {'nn_to_nns': 'installations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'instance': {'nn_to_nns': 'instances', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'instant', 'nn_to_rb': 'instantly', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'instances', 'vb_to_vbd': 'instanced', 'vb_to_vbn': 'instanced', 'vb_to_vbg': 'instancing', 'vbd_eq_vbn': ''},
 'institute': {'nn_to_nns': 'institutes', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'institutional', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'institutes', 'vb_to_vbd': 'instituted', 'vb_to_vbn': 'instituted', 'vb_to_nn': 'institution', 'vb_to_jj': 'institutional', 'vb_to_vbg': 'instituting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'nc_typical': ''},
 'instrument': {'nn_to_nns': 'instruments', 'n_is_nc': '', 'art_an': '', 'nn_to_jj': 'instrumental', 'nn_to_rb': 'instrumentally', 'vbd_eq_vbn': '', 'nc_typical': '', 'n_is_sth': '0'},
 'insult': {'nn_to_nns': 'insults', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'insulting', 'vb_to_jj': 'insulting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'insurer': {'nn_to_nns': 'insurers', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'intellectual': {'nn_to_nns': 'intellectuals', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'intensity': {'nn_to_nns': 'intensities', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'intensify', 'nn_to_jj': 'intense', 'nn_to_rb': 'intensely'},
 'intention': {'nn_to_nns': 'intentions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'intend', 'nn_to_jj': 'intent'},
 'interception': {'nn_to_nns': 'interceptions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'interest': {'nn_to_nns': 'interests', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'interesting', 'v_to_vbg': '', 'v_n': '', 'vdo': '', 'vb_to_vbz': 'interests', 'vb_to_vbd': 'interested', 'vb_to_vbn': 'interested', 'vb_to_jj': 'interesting', 'vb_to_vbg': 'interesting', 'vbd_eq_vbn': ''},
 'interior': {'nn_to_nns': 'interiors', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'international': {'nn_to_nns': 'internationals', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'interpreter': {'nn_to_nns': 'interpreters', 'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'nc_typical': '', 'n_is_sth': '2'},
 'interval': {'nn_to_nns': 'intervals', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'intervention': {'nn_to_nns': 'interventions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'intervene', 'nn_to_jj': 'intervening'},
 'interview': {'nn_to_nns': 'interviews', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'interviews', 'vb_to_vbd': 'interviewed', 'vb_to_vbn': 'interviewed', 'vb_to_vbg': 'interviewing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'intimate': {'nn_to_nns': 'intimates', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'introduction': {'nn_to_nns': 'introductions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'introduce', 'nn_to_rb': 'introductory'},
 'invasion': {'nn_to_nns': 'invasions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'inventory': {'nn_to_nns': 'inventories', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'investigator': {'nn_to_nns': 'investigators', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'investment': {'nn_to_nns': 'investments', 'n_is_nc': '', 'art_an': '', 'nn_to_vb': 'invest', 'n_is_sth': '0'},
 'investor': {'nn_to_nns': 'investors', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'invitation': {'nn_to_nns': 'invitations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'invite', 'nn_to_jj': 'inviting'},
 'involvement': {'nn_to_nns': 'involvements', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'involve', 'nn_to_jj': 'involved'},
 'iron': {'nn_to_nns': 'irons', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'irons', 'vb_to_vbd': 'ironed', 'vb_to_vbn': 'ironed', 'vb_to_vbg': 'ironing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'irony': {'nn_to_nns': 'ironies', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'island': {'nn_to_nns': 'islands', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'issue': {'nn_to_nns': 'issues', 'n_is_nc': '', 'art_an': '', 'nn_to_jj': 'issued', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'issues', 'vb_to_vbd': 'issued', 'vb_to_vbn': 'issued', 'vb_to_jj': 'issued', 'vb_to_vbg': 'issuing', 'vbd_eq_vbn': '', 'n_is_sth': '0'},
 'jack': {'nn_to_nns': 'jacks', 'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'n_is_sth': '2'},
 'jacket': {'nn_to_nns': 'jackets', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'jail': {'nn_to_nns': 'jails', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'vbg_non': ''},
 'jasmine': {'nn_to_nns': 'jasmines', 'n_is_nc': '', 'n_is_sth': ''},
 'jean': {'nn_to_nns': 'jeans', 'n_is_nc': '', 'n_is_sth': ''},
 'jersey': {'nn_to_nns': 'jerseys', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'jet': {'nn_to_nns': 'jets', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'job': {'nn_to_nns': 'jobs', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'join': {'nn_to_nns': 'joins', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'joint', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_in': '', 'v_with': '', 'vb_to_vbz': 'joins', 'vb_to_vbd': 'joined', 'vb_to_vbn': 'joined', 'vb_to_jj': 'joint', 'vb_to_vbg': 'joining', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'joining': {'nn_to_nns': 'joinings', 'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'join', 'vbg_to_vbn': 'joined'},
 'joke': {'nn_to_nns': 'jokes', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'joking', 'v_to_vbg': '', 'vdo': '', 'v_with': '', 'v_about': '', 'vb_to_vbz': 'jokes', 'vb_to_vbd': 'joked', 'vb_to_vbn': 'joked', 'vb_to_jj': 'joking', 'vb_to_vbg': 'joking', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'journal': {'nn_to_nns': 'journals', 'n_is_nc': '', 'n_is_sth': ''},
 'journalist': {'nn_to_nns': 'journalists', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'journey': {'nn_to_nns': 'journeys', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'vdo': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'joy': {'nn_to_nns': 'joys', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'joyful', 'vb_to_jj': 'joyful', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_nu': ''},
 'judge': {'nn_to_nns': 'judges', 'n_is_nc': '', 'n_is_sb': '0', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'judges', 'vb_to_vbd': 'judged', 'vb_to_vbn': 'judged', 'vb_to_nn': 'judgment', 'vb_to_jj': 'judged', 'vb_to_vbg': 'judging', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'judgment': {'nn_to_nns': 'judgments', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'judge', 'nn_to_jj': 'judged'},
 'juice': {'nn_to_nns': 'juices', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'juicy', 'nn_to_rb': 'juicily'},
 'jump': {'nn_to_nns': 'jumps', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'jumping', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'jumps', 'vb_to_vbd': 'jumped', 'vb_to_vbn': 'jumped', 'vb_to_jj': 'jumping', 'vb_to_vbg': 'jumping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'jumper': {'nn_to_nns': 'jumpers', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'junior': {'nn_to_nns': 'juniors', 'n_is_nc': '', 'n_is_sb': '0'},
 'jurisdiction': {'nn_to_nns': 'jurisdictions', 'n_is_nc': '', 'n_is_sth': ''},
 'justice': {'nn_to_nns': 'justices', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'juvenile': {'nn_to_nns': 'juveniles', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'keep': {'nn_to_nns': 'keeps', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'kept', 'v_vbg': '', 'v_to_vbg': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vbe': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_on': '', 'vb_to_vbz': 'keeps', 'vb_to_vbd': 'kept', 'vb_to_vbn': 'kept', 'vb_to_jj': 'kept', 'v_n_vbg': '', 'v_n_a': '', 'vb_to_vbg': 'keeping', 'vi_typical': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'keeper': {'nn_to_nns': 'keepers', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'keepsake': {'nn_to_nns': 'keepsakes', 'n_is_nc': '', 'n_is_sth': ''},
 'kettle': {'nn_to_nns': 'kettles', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'key': {'nn_to_nns': 'keys', 'n_is_nc': '', 'n_is_sb': '2', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'be_jj_to_vbg': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'keyboard': {'nn_to_nns': 'keyboards', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'kick': {'nn_to_nns': 'kicks', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'kicking', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_against': '', 'vb_to_vbz': 'kicks', 'vb_to_vbd': 'kicked', 'vb_to_vbn': 'kicked', 'vb_to_jj': 'kicking', 'vb_to_vbg': 'kicking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'kid': {'nn_to_nns': 'kids', 'n_is_nc': '', 'n_is_sb': '2', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'n_is_sth': '2'},
 'kill': {'nn_to_nns': 'kills', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'kills', 'vb_to_vbd': 'killed', 'vb_to_vbn': 'killed', 'vb_to_nn': 'killing', 'vb_to_jj': 'killing', 'vb_to_vbg': 'killing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'killer': {'nn_to_nns': 'killers', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'kilogram': {'nn_to_nns': 'kilograms', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': '', 'quantifier': ''},
 'kilometer': {'nn_to_nns': 'kilometers', 'n_is_nc': '', 'n_is_sth': '', 'quantifier': '', 'n_is_unit': ''},
 'kilometre': {'nn_to_nns': 'kilometres', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'king': {'nn_to_nns': 'kings', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'kitchen': {'nn_to_nns': 'kitchens', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'knee': {'nn_to_nns': 'knees', 'n_is_nc': '', 'n_is_sb': '2', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'knees', 'vb_to_vbd': 'kneed', 'vb_to_vbn': 'kneed', 'vb_to_vbg': 'kneeing', 'vbd_eq_vbn': '', 'nc_typical': '', 'n_is_sth': '2'},
 'knight': {'nn_to_nns': 'knights', 'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': ''},
 'knock': {'nn_to_nns': 'knocks', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_at': '', 'vb_to_vbz': 'knocks', 'vb_to_vbd': 'knocked', 'vb_to_vbn': 'knocked', 'vb_to_vbg': 'knocking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'knot': {'nn_to_nns': 'knots', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'knotted', 'vb_to_jj': 'knotted', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'lab': {'nn_to_nns': 'labs', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'label': {'nn_to_nns': 'labels', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'labeled', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'labels', 'vb_to_vbd': 'labeled', 'vb_to_vbn': 'labeled', 'vb_to_jj': 'labeled', 'vb_to_vbg': 'labelling', 'vbd_eq_vbn': ''},
 'lad': {'nn_to_nns': 'lads', 'n_is_nc': '', 'n_is_sb': '0'},
 'ladder': {'nn_to_nns': 'ladders', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'ladders', 'vb_to_vbd': 'laddered', 'vb_to_vbn': 'laddered', 'vb_to_vbg': 'laddering', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'lake': {'nn_to_nns': 'lakes', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'lamp': {'nn_to_nns': 'lamps', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'land': {'nn_to_nns': 'lands', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'landed', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_in': '', 'vb_to_vbz': 'lands', 'vb_to_vbd': 'landed', 'vb_to_vbn': 'landed', 'vb_to_jj': 'landed', 'vb_to_vbg': 'landing', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'n_is_nc': ''},
 'landlord': {'nn_to_nns': 'landlords', 'n_is_nc': '', 'n_is_sb': '0'},
 'landmark': {'nn_to_nns': 'landmarks', 'n_is_nc': '', 'n_is_sth': ''},
 'landscape': {'nn_to_nns': 'landscapes', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'landscapes', 'vb_to_vbd': 'landscaped', 'vb_to_vbn': 'landscaped', 'vb_to_vbg': 'landscaping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'lane': {'nn_to_nns': 'lanes', 'n_is_nc': '', 'n_is_sth': ''},
 'language': {'nn_to_nns': 'languages', 'n_is_nc': '', 'n_is_sth': ''},
 'lap': {'nn_to_nns': 'laps', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'laser': {'nn_to_nns': 'lasers', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'last': {'nn_to_nns': 'lasts', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'lasts', 'vb_to_vbd': 'lasted', 'vb_to_vbn': 'lasted', 'vb_to_vbg': 'lasting', 'vbd_eq_vbn': ''},
 'latern': {'nn_to_nns': 'laterns', 'n_is_nc': ''},
 'latin': {'nn_to_nns': 'latins', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'cap_word': 'Latin'},
 'latter': {'nn_to_nns': 'latters', 'n_is_nc': '', 'n_is_sth': ''},
 'laugh': {'nn_to_nns': 'laughs', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'laughable', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_at': '', 'v_in': '', 'vb_to_vbz': 'laughs', 'vb_to_vbd': 'laughed', 'vb_to_vbn': 'laughed', 'vb_to_jj': 'laughable', 'vb_to_vbg': 'laughing', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'nc_typical': ''},
 'law': {'nn_to_nns': 'laws', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'lawful', 'vb_to_jj': 'lawful'},
 'lawn': {'nn_to_nns': 'lawns', 'n_is_nc': '', 'n_is_sth': ''},
 'lawyer': {'nn_to_nns': 'lawyers', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'lay': {'nn_to_nns': 'lays', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_on': '', 'v_in': '', 'v_about': '', 'vb_to_vbz': 'lays', 'vb_to_vbd': 'laid', 'vb_to_vbn': 'laid', 'vb_to_vbg': 'laying', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'layer': {'nn_to_nns': 'layers', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_jj': 'layered', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'layers', 'vb_to_vbd': 'layered', 'vb_to_vbn': 'layered', 'vb_to_jj': 'layered', 'vb_to_vbg': 'layering', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'n_is_sth': '2'},
 'leader': {'nn_to_nns': 'leaders', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'lead', 'nn_to_jj': 'lead', 'nc_typical': ''},
 'league': {'nn_to_nns': 'leagues', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'lease': {'nn_to_nns': 'leases', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'leather': {'nn_to_nns': 'leathers', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'lecture': {'nn_to_nns': 'lectures', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'leg': {'nn_to_nns': 'legs', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'legacy': {'nn_to_nns': 'legacies', 'n_is_nc': '', 'n_is_sth': ''},
 'legend': {'nn_to_nns': 'legends', 'n_is_nc': '', 'n_is_sth': ''},
 'lemon': {'nn_to_nns': 'lemons', 'n_is_nc': '', 'n_is_sth': ''},
 'length': {'nn_to_nns': 'lengths', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'lengthen', 'nn_to_jj': 'lengthy'},
 'lesson': {'nn_to_nns': 'lessons', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'letter': {'nn_to_nns': 'letters', 'n_is_nc': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'level': {'nn_to_nns': 'levels', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'leverage': {'nn_to_nns': 'leverages', 'n_is_nc': '', 'n_is_sth': ''},
 'liability': {'nn_to_nns': 'liabilities', 'n_is_nc': '', 'n_is_sth': ''},
 'librarian': {'nn_to_nns': 'librarians', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'license': {'nn_to_nns': 'licenses', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'lid': {'nn_to_nns': 'lids', 'n_is_nc': '', 'n_is_sth': ''},
 'lie': {'nn_to_nns': 'lies', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'lying', 'v_to_vbg': '', 'vbe': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_in': '', 'v_to': '', 'vb_to_vbz': 'lies', 'vb_to_vbd': 'lied', 'vb_to_vbn': 'lied', 'vb_to_jj': 'lying', 'vb_to_vbg': 'lying', 'vi_typical': '', 'v_compcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'lifetime': {'nn_to_nns': 'lifetimes', 'n_is_nu': '', 'n_is_sth': ''},
 'lift': {'nn_to_nns': 'lifts', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'lifting', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'lifts', 'vb_to_vbd': 'lifted', 'vb_to_vbn': 'lifted', 'vb_to_jj': 'lifting', 'vb_to_vbg': 'lifting', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'likelihood': {'nn_to_nns': 'likelihoods', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'likely', 'nn_to_rb': 'likely'},
 'lilac': {'nn_to_nns': 'lilacs', 'n_is_nc': '', 'n_is_sth': ''},
 'lily': {'nn_to_nns': 'lilies', 'n_is_nc': '', 'n_is_sth': ''},
 'limit': {'nn_to_nns': 'limits', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'limited', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'limits', 'vb_to_vbd': 'limited', 'vb_to_vbn': 'limited', 'vb_to_nn': 'limitation', 'vb_to_jj': 'limited', 'nn_to_vbn': 'limited', 'vb_to_vbg': 'limiting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'line': {'nn_to_nns': 'lines', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'lined', 'v_n': '', 'nsubjpass': '', 'vb_to_jj': 'lined', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'linguist': {'nn_to_nns': 'linguists', 'n_is_nc': '', 'n_is_sb': '0'},
 'link': {'nn_to_nns': 'links', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'linked', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'links', 'vb_to_vbd': 'linked', 'vb_to_vbn': 'linked', 'vb_to_jj': 'linked', 'vb_to_vbg': 'linking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'lion': {'nn_to_nns': 'lions', 'n_is_nc': '', 'n_is_sb': '3', 'nc_typical': '', 'n_is_sth': '3'},
 'liquid': {'nn_to_nns': 'liquids', 'n_is_nc': '', 'n_is_sth': ''},
 'list': {'nn_to_nns': 'lists', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'listed', 'v_to_vbg': '', 'vdo': '', 'vb_to_vbz': 'lists', 'vb_to_vbd': 'listed', 'vb_to_vbn': 'listed', 'vb_to_jj': 'listed', 'vb_to_vbg': 'listing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'nc_typical': ''},
 'litre': {'nn_to_nns': 'litres', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': '', 'quantifier': ''},
 'liver': {'nn_to_nns': 'livers', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'load': {'nn_to_nns': 'loads', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'loaded', 'v_n': '', 'nsubjpass': '', 'v_with': '', 'vb_to_jj': 'loaded', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'nc_typical': ''},
 'loan': {'nn_to_nns': 'loans', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'lobby': {'nn_to_nns': 'lobbies', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'location': {'nn_to_nns': 'locations', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'locate'},
 'locator': {'nn_to_nns': 'locators', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'lock': {'nn_to_nns': 'locks', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'locked', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'locks', 'vb_to_vbd': 'locked', 'vb_to_vbn': 'locked', 'vb_to_jj': 'locked', 'vb_to_vbg': 'locking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'log': {'nn_to_nns': 'logs', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'logo': {'nn_to_nns': 'logos', 'n_is_nc': '', 'n_is_sth': ''},
 'lord': {'nn_to_nns': 'lords', 'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'loser': {'nn_to_nns': 'losers', 'n_is_nc': '', 'n_is_sb': '0'},
 'loss': {'nn_to_nns': 'losses', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'lose'},
 'lottery': {'nn_to_nns': 'lotteries', 'n_is_nc': '', 'n_is_sth': ''},
 'lotus': {'nn_to_nns': 'lotuses', 'n_is_nc': '', 'n_is_sth': ''},
 'lounge': {'nn_to_nns': 'lounges', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'love': {'nn_to_nns': 'loves', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'lovable', 'v_vbg': '', 'v_to_vb': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'loves', 'vb_to_vbd': 'loved', 'vb_to_vbn': 'loved', 'vb_to_jj': 'lovable', 'vb_to_vbg': 'loving', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'lover': {'nn_to_nns': 'lovers', 'n_is_nc': '', 'n_is_sb': '0'},
 'low': {'nn_to_nns': 'lows', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'jj_to_jjr': 'lower', 'jj_to_jjs': 'lowest', 'rb_to_rbr': 'lower', 'rb_to_rbs': 'lowest'},
 'loyalty': {'nn_to_nns': 'loyalties', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'loyal', 'nn_to_rb': 'loyally'},
 'lump': {'nn_to_nns': 'lumps', 'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'n_is_sth': '2'},
 'lunch': {'nn_to_nns': 'lunches', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'lung': {'nn_to_nns': 'lungs', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'lure': {'nn_to_nns': 'lures', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'luxury': {'nn_to_nns': 'luxuries', 'n_is_nc': '', 'n_is_sth': ''},
 'mac': {'nn_to_nns': 'macs', 'n_is_nc': '', 'n_is_sth': ''},
 'machine': {'nn_to_nns': 'machines', 'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'machinery': {'nn_to_nns': 'machineries', 'n_is_nc': '', 'n_is_sth': ''},
 'madam': {'nn_to_nns': 'madams', 'n_is_nc': '', 'n_is_sb': '0'},
 'magazine': {'nn_to_nns': 'magazines', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'magnolia': {'nn_to_nns': 'magnolias', 'n_is_nc': '', 'n_is_sth': ''},
 'mail': {'nn_to_nns': 'mails', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'mailed', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'mails', 'vb_to_vbd': 'mailed', 'vb_to_vbn': 'mailed', 'vb_to_jj': 'mailed', 'vb_to_vbg': 'mailing', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'make': {'nn_to_nns': 'makes', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'makable', 'v_to_vb': '', 'v_n': '', 'v_n_n': '', 'v_n_to_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_for': '', 'v_vb': '', 'vb_to_vbz': 'makes', 'vb_to_vbd': 'made', 'vb_to_vbn': 'made', 'vb_to_jj': 'makable', 'v_n_vb': '', 'vb_to_vbg': 'making', 'vt_typical': '', 'v_compcl_non': ''},
 'male': {'nn_to_nns': 'males', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'mall': {'nn_to_nns': 'malls', 'n_is_nc': '', 'n_is_sth': ''},
 'manager': {'nn_to_nns': 'managers', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'mandate': {'nn_to_nns': 'mandates', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'manner': {'nn_to_nns': 'manners', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'mansion': {'nn_to_nns': 'mansions', 'n_is_nc': '', 'n_is_sth': ''},
 'manufacturer': {'nn_to_nns': 'manufacturers', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'map': {'nn_to_nns': 'maps', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'margin': {'nn_to_nns': 'margins', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'marginal', 'vb_to_jj': 'marginal', 'vbd_eq_vbn': ''},
 'marine': {'nn_to_nns': 'marines', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'mark': {'nn_to_nns': 'marks', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'marked', 'v_compcl': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'marks', 'vb_to_vbd': 'marked', 'vb_to_vbn': 'marked', 'vb_to_jj': 'marked', 'vb_to_vbg': 'marking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'nc_typical': ''},
 'market': {'nn_to_nns': 'markets', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'marketplace': {'nn_to_nns': 'marketplaces', 'n_is_nc': '', 'n_is_sth': ''},
 'marriage': {'nn_to_nns': 'marriages', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'marry', 'nn_to_jj': 'married'},
 'master': {'nn_to_nns': 'masters', 'n_is_nc': '', 'n_is_sb': '0', 'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'mathematician': {'nn_to_nns': 'mathematicians', 'n_is_nc': '', 'n_is_sb': '0'},
 'mayor': {'nn_to_nns': 'mayors', 'n_is_nc': '', 'n_is_sb': '0'},
 'meal': {'nn_to_nns': 'meals', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'meaning': {'nn_to_nns': 'meanings', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'mean', 'nn_to_jj': 'mean', 'nn_to_rb': 'meanly', 'vbg_to_vb': 'mean', 'vbg_to_vbn': 'meaned'},
 'measure': {'nn_to_nns': 'measures', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'measurable', 'v_to_vbg': '', 'vdo': '', 'v_against': '', 'vb_to_vbz': 'measures', 'vb_to_vbd': 'measured', 'vb_to_vbn': 'measured', 'vb_to_nn': 'measurement', 'vb_to_jj': 'measurable', 'vb_to_vbg': 'measuring', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'medal': {'nn_to_nns': 'medals', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'medication': {'nn_to_nns': 'medications', 'n_is_nc': '', 'n_is_sth': ''},
 'meeting': {'nn_to_nns': 'meetings', 'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'meet', 'vbg_to_vbn': 'met'},
 'melon': {'nn_to_nns': 'melons', 'n_is_nc': '', 'n_is_sth': ''},
 'member': {'nn_to_nns': 'members', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'membership': {'nn_to_nns': 'memberships', 'n_is_nc': '', 'n_is_sth': ''},
 'memo': {'nn_to_nns': 'memos', 'n_is_nc': '', 'n_is_sth': ''},
 'memory': {'nn_to_nns': 'memories', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'memorize', 'nn_to_jj': 'memorial'},
 'menu': {'nn_to_nns': 'menus', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'merchant': {'nn_to_nns': 'merchants', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'mess': {'nn_to_nns': 'messes', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'messes', 'vb_to_vbd': 'messed', 'vb_to_vbn': 'messed', 'vb_to_vbg': 'messing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'message': {'nn_to_nns': 'messages', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'metro': {'nn_to_nns': 'metros', 'n_is_nc': '', 'n_is_sth': ''},
 'middle': {'nn_to_nns': 'middles', 'n_is_nc': '', 'n_is_sth': ''},
 'midway': {'nn_to_nns': 'midways', 'n_is_nc': '', 'n_is_sth': ''},
 'mike': {'nn_to_nns': 'mikes', 'n_is_nc': '', 'n_is_sth': ''},
 'mile': {'nn_to_nns': 'miles', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'militant': {'nn_to_nns': 'militants', 'n_is_nc': '', 'n_is_sb': '0'},
 'miller': {'nn_to_nns': 'millers', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'milligram': {'nn_to_nns': 'milligrams', 'n_is_nc': '', 'n_is_sth': ''},
 'millimetre': {'nn_to_nns': 'millimetres', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'million': {'nn_to_nns': 'millions', 'n_is_nc': '', 'n_is_sth': ''},
 'millionaire': {'nn_to_nns': 'millionaires', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'mineral': {'nn_to_nns': 'minerals', 'n_is_nc': '', 'n_is_sth': ''},
 'minister': {'nn_to_nns': 'ministers', 'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'minor': {'nn_to_nns': 'minors', 'n_is_nc': '', 'n_is_sb': '0'},
 'minority': {'nn_to_nns': 'minorities', 'n_is_nc': '', 'n_is_sth': '', 'n_is_collective': ''},
 'minute': {'nn_to_nns': 'minutes', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': '', 'quantifier': '', 'jj_to_jjr': 'minuter', 'jj_to_jjs': 'minutest'},
 'miracle': {'nn_to_nns': 'miracles', 'n_is_nc': '', 'n_is_sth': ''},
 'mirror': {'nn_to_nns': 'mirrors', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'nc_typical': ''},
 'misconduct': {'nn_to_nns': 'misconducts', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'missile': {'nn_to_nns': 'missiles', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'mission': {'nn_to_nns': 'missions', 'n_is_nc': '', 'n_is_sth': ''},
 'mistake': {'nn_to_nns': 'mistakes', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'mistaken', 'v_compcl': '', 'v_n': '', 'v_for': '', 'vb_to_jj': 'mistaken', 'vt_typical': ''},
 'mixture': {'nn_to_nns': 'mixtures', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'mix', 'nn_to_jj': 'mixed'},
 'mob': {'nn_to_nns': 'mobs', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'mobile': {'nn_to_nns': 'mobiles', 'n_is_nc': '', 'n_is_sth': ''},
 'mobilephone': {'nn_to_nns': 'mobilephones', 'n_is_nc': '', 'n_is_sth': ''},
 'mode': {'nn_to_nns': 'modes', 'n_is_nc': '', 'n_is_sth': ''},
 'model': {'nn_to_nns': 'models', 'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'moment': {'nn_to_nns': 'moments', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'momentary', 'nc_typical': ''},
 'monitor': {'nn_to_nns': 'monitors', 'n_is_nc': '', 'n_is_sb': '2', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'monitors', 'vb_to_vbd': 'monitored', 'vb_to_vbn': 'monitored', 'vb_to_vbg': 'monitoring', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'monopoly': {'nn_to_nns': 'monopolies', 'n_is_nc': '', 'n_is_sth': ''},
 'monster': {'nn_to_nns': 'monsters', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'month': {'nn_to_nns': 'months', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'monthly', 'nn_to_rb': 'monthly', 'nc_typical': '', 'quantifier': ''},
 'mood': {'nn_to_nns': 'moods', 'n_is_nc': '', 'n_is_sth': ''},
 'moon': {'nn_to_nns': 'moons', 'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'morning': {'nn_to_nns': 'mornings', 'n_is_nc': '', 'n_is_sth': ''},
 'mortgage': {'nn_to_nns': 'mortgages', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'mother': {'nn_to_nns': 'mothers', 'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'motion': {'nn_to_nns': 'motions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'motional', 'vb_to_jj': 'motional', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'motor': {'nn_to_nns': 'motors', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'motorbike': {'nn_to_nns': 'motorbikes', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'motorway': {'nn_to_nns': 'motorways', 'n_is_nc': '', 'n_is_sth': ''},
 'mound': {'nn_to_nns': 'mounds', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'mount': {'nn_to_nns': 'mounts', 'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'n_is_sth': '2'},
 'mountain': {'nn_to_nns': 'mountains', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': '', 'n_of_nn': '', 'n_of_nns': ''},
 'mouth': {'nn_to_nns': 'mouths', 'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'move': {'nn_to_nns': 'moves', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'moving', 'v_to_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'moves', 'vb_to_vbd': 'moved', 'vb_to_vbn': 'moved', 'vb_to_nn': 'movement', 'vb_to_jj': 'moving', 'vb_to_vbg': 'moving', 'nn_to_vbg': 'moving', 'vbd_eq_vbn': ''},
 'movement': {'nn_to_nns': 'movements', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'move', 'nn_to_jj': 'moving'},
 'movie': {'nn_to_nns': 'movies', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'mud': {'nn_to_nns': 'muds', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'muddy', 'nn_to_rb': 'muddily', 'vb_to_rb': 'muddily', 'vb_to_jj': 'muddy', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nu_typical': ''},
 'murphy': {'nn_to_nns': 'murphies', 'n_is_nc': '', 'n_is_sth': ''},
 'muscle': {'nn_to_nns': 'muscles', 'n_is_nc': '', 'n_is_nu': '', 'vbd_eq_vbn': '', 'n_is_sth': '0'},
 'museum': {'nn_to_nns': 'museums', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'mushroom': {'nn_to_nns': 'mushrooms', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'musician': {'nn_to_nns': 'musicians', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'musical', 'nn_to_rb': 'musically', 'nc_typical': ''},
 'muslim': {'nn_to_nns': 'muslims', 'n_is_nc': '', 'n_is_sb': '0'},
 'nail': {'nn_to_nns': 'nails', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'nailing', 'vb_to_jj': 'nailing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'name': {'nn_to_nns': 'names', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'names', 'vb_to_vbd': 'named', 'vb_to_vbn': 'named', 'vb_to_vbg': 'naming', 'vbd_eq_vbn': '', 'vt_typical': '', 'nc_typical': ''},
 'narcissus': {'nn_to_nns': 'narcissi', 'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'narrative': {'nn_to_nns': 'narratives', 'n_is_nc': '', 'n_is_sth': ''},
 'nation': {'nn_to_nns': 'nations', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'nn_to_jj': 'national', 'nn_to_rb': 'nationally', 'nc_typical': ''},
 'navy': {'nn_to_nns': 'navies', 'n_is_nc': '', 'n_is_sth': '', 'n_is_collective': ''},
 'nazi': {'nn_to_nns': 'nazis', 'n_is_nc': '', 'n_is_sb': '0', 'cap_word': 'Nazi'},
 'neck': {'nn_to_nns': 'necks', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'needle': {'nn_to_nns': 'needles', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'needled', 'vb_to_jj': 'needled', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'neighbor': {'nn_to_nns': 'neighbors', 'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'neighbour': {'nn_to_nns': 'neighbours', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'neighbourhood': {'nn_to_nns': 'neighbourhoods', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'nephew': {'nn_to_nns': 'nephews', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'nest': {'nn_to_nns': 'nests', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'nested', 'vb_to_jj': 'nested', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'network': {'nn_to_nns': 'networks', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'newsletter': {'nn_to_nns': 'newsletters', 'n_is_nc': '', 'n_is_sth': ''},
 'newspaper': {'nn_to_nns': 'newspapers', 'n_is_nc': '', 'n_is_sth': '', 'n_is_nu': ''},
 'niche': {'nn_to_nns': 'niches', 'n_is_nc': '', 'n_is_sth': ''},
 'nickname': {'nn_to_nns': 'nicknames', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'niece': {'nn_to_nns': 'nieces', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'nightmare': {'nn_to_nns': 'nightmares', 'n_is_nc': '', 'n_is_sth': ''},
 'noise': {'nn_to_nns': 'noises', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'noisy', 'nn_to_rb': 'noisily', 'vb_to_rb': 'noisily', 'vb_to_jj': 'noisy', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_nu': ''},
 'northeast': {'nn_to_nns': 'northeasts', 'n_is_nu': '', 'n_is_sth': ''},
 'nose': {'nn_to_nns': 'noses', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'note': {'nn_to_nns': 'notes', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'notable', 'nn_to_rb': 'notably', 'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'notes', 'vb_to_vbd': 'noted', 'vb_to_vbn': 'noted', 'vb_to_rb': 'notably', 'vb_to_jj': 'notable', 'vb_to_vbg': 'noting', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'vt_typical': ''},
 'notebook': {'nn_to_nns': 'notebooks', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'notice': {'nn_to_nns': 'notices', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'noticeable', 'nn_to_rb': 'noticeably', 'v_compcl': '', 'v_vbg': '', 'v_to_vb': '', 'v_n': '', 'v_n_vb': '', 'nsubjpass': '', 'vdo': '', 'v_vb': '', 'vb_to_vbz': 'notices', 'vb_to_vbd': 'noticed', 'vb_to_vbn': 'noticed', 'vb_to_rb': 'noticeably', 'vb_to_jj': 'noticeable', 'v_n_vbg': '', 'vb_to_vbg': 'noticing', 'vbd_eq_vbn': ''},
 'notion': {'nn_to_nns': 'notions', 'n_is_nc': '', 'n_is_sth': ''},
 'novel': {'nn_to_nns': 'novels', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'novelist': {'nn_to_nns': 'novelists', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'nuisance': {'nn_to_nns': 'nuisances', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'nurse': {'nn_to_nns': 'nurses', 'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'nc_typical': ''},
 'nut': {'nn_to_nns': 'nuts', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'object': {'nn_to_nns': 'objects', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_to': '', 'vb_to_vbz': 'objects', 'vb_to_vbd': 'objected', 'vb_to_vbn': 'objected', 'vb_to_rb': 'objectively', 'vb_to_nn': 'objection', 'vb_to_jj': 'objective', 'vb_to_vbg': 'objecting', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_pass_non': '', 'nc_typical': ''},
 'objection': {'nn_to_nns': 'objections', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'object', 'nn_to_jj': 'objective', 'nn_to_rb': 'objectively'},
 'obligation': {'nn_to_nns': 'obligations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'occasion': {'nn_to_nns': 'occasions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'occasional', 'nn_to_rb': 'occasionally', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'occupation': {'nn_to_nns': 'occupations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'occupy', 'nn_to_jj': 'occupantional'},
 'ocean': {'nn_to_nns': 'oceans', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'offer': {'nn_to_nns': 'offers', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_to_vb': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'offers', 'vb_to_vbd': 'offered', 'vb_to_vbn': 'offered', 'vb_to_vbg': 'offering', 'vbd_eq_vbn': '', 'nc_typical': '', 'v_sb_n': ''},
 'office': {'nn_to_nns': 'offices', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'officer': {'nn_to_nns': 'officers', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nc_typical': ''},
 'onion': {'nn_to_nns': 'onions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'opener': {'nn_to_nns': 'openers', 'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'opera': {'nn_to_nns': 'operas', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'operator': {'nn_to_nns': 'operators', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nc_typical': ''},
 'opinion': {'nn_to_nns': 'opinions', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'opponent': {'nn_to_nns': 'opponents', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'opportunity': {'nn_to_nns': 'opportunities', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'option': {'nn_to_nns': 'options', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'optional'},
 'orange': {'nn_to_nns': 'oranges', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'orangish'},
 'orchestra': {'nn_to_nns': 'orchestras', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'order': {'nn_to_nns': 'orders', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'orders', 'vb_to_vbd': 'ordered', 'vb_to_vbn': 'ordered', 'vb_to_vbg': 'ordering', 'vt_typical': '', 'vbd_eq_vbn': '', 'v_that_n_vb': '虚拟语气从句should可省略'},
 'organ': {'nn_to_nns': 'organs', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'organic': {'nn_to_nns': 'organics', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'organization': {'nn_to_nns': 'organizations', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'origin': {'nn_to_nns': 'origins', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'originate', 'nn_to_jj': 'original', 'nn_to_rb': 'originally'},
 'orphan': {'nn_to_nns': 'orphans', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'vbd_eq_vbn': ''},
 'ounce': {'nn_to_nns': 'ounces', 'n_is_nc': '', 'art_an': '', 'n_is_sb': '2', 'n_is_sth': '2', 'quantifier': ''},
 'outcome': {'nn_to_nns': 'outcomes', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'output': {'nn_to_nns': 'outputs', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'vbd_eq_vbn': ''},
 'oven': {'nn_to_nns': 'ovens', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'overall': {'nn_to_nns': 'overalls', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'overhaul': {'nn_to_nns': 'overhauls', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'overhead': {'nn_to_nns': 'overheads', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'owner': {'nn_to_nns': 'owners', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nn_to_vb': 'own', 'nn_to_jj': 'own', 'nc_typical': ''},
 'pace': {'nn_to_nns': 'paces', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'pack': {'nn_to_nns': 'packs', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'packs', 'vb_to_vbd': 'packed', 'vb_to_vbn': 'packed', 'vb_to_nn': 'package', 'vb_to_vbg': 'packing', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'nc_typical': '', 'n_of_nns': ''},
 'package': {'nn_to_nns': 'packages', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'pack', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'packet': {'nn_to_nns': 'packets', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'pact': {'nn_to_nns': 'pacts', 'n_is_nc': '', 'n_is_sth': ''},
 'pad': {'nn_to_nns': 'pads', 'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'n_is_sth': '2'},
 'page': {'nn_to_nns': 'pages', 'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': '', 'n_is_sth': '2', 'n_is_unit': ''},
 'pain': {'nn_to_nns': 'pains', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'painful', 'nn_to_rb': 'painfully', 'vb_to_rb': 'painfully', 'vb_to_jj': 'painful', 'v_prprtcl_non': '', 'vbg_non': '', 'n_is_nu': ''},
 'painter': {'nn_to_nns': 'painters', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'pair': {'nn_to_nns': 'pairs', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'nc_typical': '', 'n_of_nns': ''},
 'palace': {'nn_to_nns': 'palaces', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'palm': {'nn_to_nns': 'palms', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'pan': {'nn_to_nns': 'pans', 'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'panel': {'nn_to_nns': 'panels', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'panic': {'nn_to_nns': 'panics', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'parade': {'nn_to_nns': 'parades', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'parallel': {'nn_to_nns': 'parallels', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'parcel': {'nn_to_nns': 'parcels', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'parent': {'nn_to_nns': 'parents', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'parentage', 'vb_to_jj': 'parentage', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'park': {'nn_to_nns': 'parks', 'n_is_nc': '', 'n_is_sb': '2', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'parks', 'vb_to_vbd': 'parked', 'vb_to_vbn': 'parked', 'vb_to_vbg': 'parking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'parliament': {'nn_to_nns': 'parliaments', 'n_is_nc': '', 'n_is_sth': ''},
 'parole': {'nn_to_nns': 'paroles', 'n_is_nc': '', 'n_is_sth': ''},
 'part': {'nn_to_nns': 'parts', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'v_with': '', 'v_from': '', 'vb_to_rb': 'partially', 'vb_to_nn': 'particle', 'vb_to_jj': 'partial', 'vbd_eq_vbn': ''},
 'partisan': {'nn_to_nns': 'partisans', 'n_is_nc': '', 'n_is_sb': '0'},
 'partner': {'nn_to_nns': 'partners', 'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'partnership': {'nn_to_nns': 'partnerships', 'n_is_nc': '', 'n_is_sth': ''},
 'passage': {'nn_to_nns': 'passages', 'n_is_nc': '', 'n_is_sth': ''},
 'passenger': {'nn_to_nns': 'passengers', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'passer': {'nn_to_nns': 'passers', 'n_is_nc': '', 'n_is_sb': '0'},
 'passion': {'nn_to_nns': 'passions', 'n_is_nc': '', 'n_is_sth': ''},
 'passport': {'nn_to_nns': 'passports', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'pasta': {'nn_to_nns': 'pastas', 'n_is_nc': '', 'n_is_sth': ''},
 'pastor': {'nn_to_nns': 'pastors', 'n_is_nc': '', 'n_is_sb': '0'},
 'pat': {'nn_to_nns': 'pats', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'patent': {'nn_to_nns': 'patents', 'n_is_nc': '', 'n_is_sth': ''},
 'path': {'nn_to_nns': 'paths', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'patrol': {'nn_to_nns': 'patrols', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'pattern': {'nn_to_nns': 'patterns', 'n_is_nc': '', 'n_is_sth': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'pause': {'nn_to_nns': 'pauses', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'pauses', 'vb_to_vbd': 'paused', 'vb_to_vbn': 'paused', 'vb_to_vbg': 'pausing', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'payment': {'nn_to_nns': 'payments', 'n_is_nc': '', 'n_is_sth': ''},
 'peak': {'nn_to_nns': 'peaks', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_pass_non': '', 'nns_exp_exc': ''},
 'pear': {'nn_to_nns': 'pears', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'pen': {'nn_to_nns': 'pens', 'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'pencil': {'nn_to_nns': 'pencils', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'pension': {'nn_to_nns': 'pensions', 'n_is_nc': '', 'n_is_sth': ''},
 'peony': {'nn_to_nns': 'peonies', 'n_is_nc': '', 'n_is_sth': ''},
 'pepper': {'nn_to_nns': 'peppers', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'percent': {'nn_to_nns': 'percents', 'n_is_nc': '', 'n_is_sth': '', 'nn_of_nns': '', 'n_is_unit': ''},
 'percentage': {'nn_to_nns': 'percentages', 'n_is_nc': '', 'n_is_sth': ''},
 'perception': {'nn_to_nns': 'perceptions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'perceive'},
 'performance': {'nn_to_nns': 'performances', 'n_is_nc': '', 'n_is_sth': ''},
 'performer': {'nn_to_nns': 'performers', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'period': {'nn_to_nns': 'periods', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'periodical', 'nn_to_rb': 'periodically', 'nc_typical': ''},
 'permanent': {'nn_to_nns': 'permanents', 'n_is_nc': '', 'n_is_sth': ''},
 'permission': {'nn_to_nns': 'permissions', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'permit', 'nu_typical': ''},
 'permit': {'nn_to_nns': 'permits', 'n_is_nc': '', 'n_is_sb': '2', 'v_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_of': '', 'vb_to_vbz': 'permits', 'vb_to_vbd': 'permitted', 'vb_to_vbn': 'permitted', 'vb_to_nn': 'permission', 'vb_to_vbg': 'permiting', 'vbd_eq_vbn': '', 'nc_typical': '', 'n_is_sth': '2'},
 'person': {'nn_to_nns': 'persons', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'personality', 'nc_typical': ''},
 'perspective': {'nn_to_nns': 'perspectives', 'n_is_nc': '', 'n_is_sth': ''},
 'peso': {'nn_to_nns': 'pesos', 'n_is_nc': '', 'n_is_sth': ''},
 'pet': {'nn_to_nns': 'pets', 'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'petition': {'nn_to_nns': 'petitions', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'pharmaceutical': {'nn_to_nns': 'pharmaceuticals', 'n_is_nc': '', 'n_is_sth': ''},
 'phase': {'nn_to_nns': 'phases', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'philosopher': {'nn_to_nns': 'philosophers', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'philosophise'},
 'philosophy': {'nn_to_nns': 'philosophies', 'n_is_nc': '', 'n_is_sth': ''},
 'phone': {'nn_to_nns': 'phones', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'phones', 'vb_to_vbd': 'phoned', 'vb_to_vbn': 'phoned', 'vb_to_vbg': 'phoning', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'photo': {'nn_to_nns': 'photos', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'photograph': {'nn_to_nns': 'photographs', 'n_is_nc': '', 'n_is_sth': '', 'vb_to_nn': 'photographer', 'vb_to_jj': 'photography', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'nc_typical': ''},
 'photographer': {'nn_to_nns': 'photographers', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'photograph', 'nn_to_jj': 'photography', 'nc_typical': ''},
 'phrase': {'nn_to_nns': 'phrases', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'physical': {'nn_to_nns': 'physicals', 'n_is_nc': '', 'jj_to_nn': 'physics'},
 'physician': {'nn_to_nns': 'physicians', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'physicist': {'nn_to_nns': 'physicists', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'physiologist': {'nn_to_nns': 'physiologists', 'n_is_nc': '', 'n_is_sb': '0'},
 'pianist': {'nn_to_nns': 'pianists', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'piano': {'nn_to_nns': 'pianos', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'piazza': {'nn_to_nns': 'piazzas', 'n_is_nc': '', 'n_is_sth': ''},
 'pickup': {'nn_to_nns': 'pickups', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'picture': {'nn_to_nns': 'pictures', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'pie': {'nn_to_nns': 'pies', 'n_is_nc': '', 'n_is_sth': ''},
 'piece': {'nn_to_nns': 'pieces', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'pig': {'nn_to_nns': 'pigs', 'n_is_nc': '', 'n_is_sb': '3', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': '', 'n_is_sth': '3'},
 'pile': {'nn_to_nns': 'piles', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'n_of_nns': '', 'n_of_nn': ''},
 'pill': {'nn_to_nns': 'pills', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'pilot': {'nn_to_nns': 'pilots', 'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'pin': {'nn_to_nns': 'pins', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_on': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'vt_typical': '', 'nc_typical': ''},
 'pine': {'nn_to_nns': 'pines', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_for': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'pineapple': {'nn_to_nns': 'pineapples', 'n_is_nc': '', 'n_is_sth': ''},
 'pint': {'nn_to_nns': 'pints', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'pioneer': {'nn_to_nns': 'pioneers', 'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'nc_typical': ''},
 'pipe': {'nn_to_nns': 'pipes', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'pipeline': {'nn_to_nns': 'pipelines', 'n_is_nc': '', 'n_is_sth': ''},
 'pit': {'nn_to_nns': 'pits', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'pitch': {'nn_to_nns': 'pitches', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'place': {'nn_to_nns': 'places', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'v_on': '', 'v_in': '', 'vb_to_vbz': 'places', 'vb_to_vbd': 'placed', 'vb_to_vbn': 'placed', 'vb_to_vbg': 'placing', 'nc_typical': '', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'plain': {'nn_to_nns': 'plains', 'n_is_nc': '', 'n_is_sth': '', 'jj_to_jjr': 'plainer', 'jj_to_jjs': 'plainest'},
 'plan': {'nn_to_nns': 'plans', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'v_on': '', 'v_for': '', 'vb_to_vbz': 'plans', 'vb_to_vbd': 'planned', 'vb_to_vbn': 'planned', 'nn_to_vbg': 'planning', 'vb_to_vbg': 'planing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'nc_typical': ''},
 'plane': {'nn_to_nns': 'planes', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'planet': {'nn_to_nns': 'planets', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'plant': {'nn_to_nns': 'plants', 'n_is_nc': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': '', 'n_is_sth': '2'},
 'plate': {'nn_to_nns': 'plates', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'platform': {'nn_to_nns': 'platforms', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'player': {'nn_to_nns': 'players', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'playwright': {'nn_to_nns': 'playwrights', 'n_is_nc': '', 'n_is_sb': '0'},
 'plea': {'nn_to_nns': 'pleas', 'n_is_nc': '', 'n_is_sth': ''},
 'pleasure': {'nn_to_nns': 'pleasures', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'pleasant', 'n_is_nu': ''},
 'pledge': {'nn_to_nns': 'pledges', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'plot': {'nn_to_nns': 'plots', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'nc_typical': ''},
 'plug': {'nn_to_nns': 'plugs', 'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'plum': {'nn_to_nns': 'plums', 'n_is_nc': '', 'n_is_sth': ''},
 'plunge': {'nn_to_nns': 'plunges', 'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'pocket': {'nn_to_nns': 'pockets', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'poem': {'nn_to_nns': 'poems', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'poet': {'nn_to_nns': 'poets', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'point': {'nn_to_nns': 'points', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'points', 'vb_to_vbd': 'pointed', 'vb_to_vbn': 'pointed', 'vb_to_vbg': 'pointing', 'vi_typical': '', 'vbd_eq_vbn': ''},
 'pole': {'nn_to_nns': 'poles', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'policy': {'nn_to_nns': 'policies', 'n_is_nc': '', 'n_is_sth': ''},
 'politician': {'nn_to_nns': 'politicians', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'political', 'nn_to_rb': 'politically', 'nc_typical': ''},
 'poll': {'nn_to_nns': 'polls', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_whcl_non': ''},
 'pomegranate': {'nn_to_nns': 'pomegranates', 'n_is_nc': '', 'n_is_sth': ''},
 'pond': {'nn_to_nns': 'ponds', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'pool': {'nn_to_nns': 'pools', 'n_is_nc': '', 'n_is_sth': ''},
 'pop': {'nn_to_nns': 'pops', 'n_is_nc': '', 'n_is_sb': '2', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'pops', 'vb_to_vbd': 'popped', 'vb_to_vbn': 'popped', 'vb_to_vbg': 'popping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'n_is_sth': '2'},
 'pope': {'nn_to_nns': 'popes', 'n_is_nc': '', 'n_is_sb': '0'},
 'population': {'nn_to_nns': 'populations', 'n_is_nc': '', 'n_is_sth': '', 'n_is_collective': ''},
 'port': {'nn_to_nns': 'ports', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'porter': {'nn_to_nns': 'porters', 'n_is_nc': '', 'n_is_sb': '0'},
 'portfolio': {'nn_to_nns': 'portfolios', 'n_is_nc': '', 'n_is_sth': ''},
 'portion': {'nn_to_nns': 'portions', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'portrait': {'nn_to_nns': 'portraits', 'n_is_nc': '', 'n_is_sth': ''},
 'pose': {'nn_to_nns': 'poses', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'poses', 'vb_to_vbd': 'posed', 'vb_to_vbn': 'posed', 'vb_to_vbg': 'posing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'position': {'nn_to_nns': 'positions', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'positive': {'nn_to_nns': 'positives', 'n_is_nc': '', 'n_is_sth': ''},
 'possession': {'nn_to_nns': 'possessions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'possess'},
 'possibility': {'nn_to_nns': 'possibilities', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'possible', 'nn_to_rb': 'possibly', 'n_of_n': '', 'n_for_n': '', 'n_of_vbg_n': '', 'n_that': ''},
 'post': {'nn_to_nns': 'posts', 'n_is_nc': '', 'n_is_sb': '2', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'posts', 'vb_to_vbd': 'posted', 'vb_to_vbn': 'posted', 'vb_to_vbg': 'posting', 'vbd_eq_vbn': '', 'n_is_sth': '2'},
 'poster': {'nn_to_nns': 'posters', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'pot': {'nn_to_nns': 'pots', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'pound': {'nn_to_nns': 'pounds', 'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'n_is_sth': '2', 'quantifier': ''},
 'praise': {'nn_to_nns': 'praises', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'prayer': {'nn_to_nns': 'prayers', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_vb': 'pray', 'n_is_sth': '2'},
 'predecessor': {'nn_to_nns': 'predecessors', 'n_is_nc': '', 'n_is_sb': '0'},
 'pregnancy': {'nn_to_nns': 'pregnancies', 'n_is_nc': '', 'n_is_sth': ''},
 'preliminary': {'nn_to_nns': 'preliminaries', 'n_is_nc': '', 'n_is_sth': ''},
 'premier': {'nn_to_nns': 'premiers', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'premise': {'nn_to_nns': 'premises', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'premium': {'nn_to_nns': 'premiums', 'n_is_nc': '', 'n_is_sth': ''},
 'preparation': {'nn_to_nns': 'preparations', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'prepare', 'n_is_nu': ''},
 'prescription': {'nn_to_nns': 'prescriptions', 'n_is_nc': '', 'n_is_sth': ''},
 'presentation': {'nn_to_nns': 'presentations', 'n_is_nc': '', 'n_is_sth': ''},
 'preserve': {'nn_to_nns': 'preserves', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'preserves', 'vb_to_vbd': 'preserved', 'vb_to_vbn': 'preserved', 'vb_to_nn': 'preservation', 'vb_to_vbg': 'preserving', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'presidency': {'nn_to_nns': 'presidencies', 'n_is_nc': '', 'n_is_sth': ''},
 'president': {'nn_to_nns': 'presidents', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'presidential', 'nn_to_rb': 'presidentially', 'nc_typical': ''},
 'pressing': {'nn_to_nns': 'pressings', 'n_is_nc': '', 'n_is_sth': '', 'vbg_to_nn': 'pressure', 'vbg_to_vb': 'press', 'vbg_to_vbn': 'pressed'},
 'price': {'nn_to_nns': 'prices', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': ''},
 'priest': {'nn_to_nns': 'priests', 'n_is_nc': '', 'n_is_sb': '0'},
 'prince': {'nn_to_nns': 'princes', 'n_is_nc': '', 'n_is_sb': '0'},
 'principle': {'nn_to_nns': 'principles', 'n_is_nc': '', 'n_is_sth': ''},
 'print': {'nn_to_nns': 'prints', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_in': '', 'v_with': '', 'v_from': '', 'vb_to_vbz': 'prints', 'vb_to_vbd': 'printed', 'vb_to_vbn': 'printed', 'vb_to_nn': 'printer', 'vb_to_vbg': 'printing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'printer': {'nn_to_nns': 'printers', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_vb': 'print', 'n_is_sth': '2'},
 'prior': {'nn_to_nns': 'priors', 'n_is_nc': '', 'n_is_sb': '0'},
 'prison': {'nn_to_nns': 'prisons', 'n_is_nc': '', 'n_is_sth': '', 'vb_to_nn': 'prisoner'},
 'prisoner': {'nn_to_nns': 'prisoners', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'prison', 'nc_typical': ''},
 'privilege': {'nn_to_nns': 'privileges', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'prize': {'nn_to_nns': 'prizes', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'pro': {'nn_to_nns': 'pros', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'prefix': 'jj|nn'},
 'probe': {'nn_to_nns': 'probes', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'problem': {'nn_to_nns': 'problems', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'problematic', 'nn_to_rb': 'problematically', 'nc_typical': ''},
 'procedure': {'nn_to_nns': 'procedures', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'proceed', 'nn_to_jj': 'procedural', 'nn_to_rb': 'procedurally'},
 'proceeding': {'nn_to_nns': 'proceedings', 'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'proceed', 'vbg_to_vbn': 'proceded'},
 'producer': {'nn_to_nns': 'producers', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_vb': 'produce', 'n_is_sth': '2'},
 'product': {'nn_to_nns': 'products', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'produce'},
 'profession': {'nn_to_nns': 'professions', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'professor': {'nn_to_nns': 'professors', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'profile': {'nn_to_nns': 'profiles', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'program': {'nn_to_nns': 'programs', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'programme': {'nn_to_nns': 'programmes', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'project': {'nn_to_nns': 'projects', 'n_is_nc': '', 'n_is_sth': '', 'vb_to_nn': 'projection', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'promotion': {'nn_to_nns': 'promotions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'promote'},
 'proof': {'nn_to_nns': 'proofs', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'property': {'nn_to_nns': 'properties', 'n_is_nc': '', 'n_is_sth': ''},
 'proportion': {'nn_to_nns': 'proportions', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'proposal': {'nn_to_nns': 'proposals', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'propose'},
 'prosecution': {'nn_to_nns': 'prosecutions', 'n_is_nc': '', 'n_is_sth': ''},
 'prosecutor': {'nn_to_nns': 'prosecutors', 'n_is_nc': '', 'n_is_sb': '0'},
 'prospect': {'nn_to_nns': 'prospects', 'n_is_nc': '', 'n_is_sb': '2', 'vb_to_rb': 'prospectively', 'vb_to_nn': 'prospection', 'vb_to_jj': 'prospective', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'prosperity': {'nn_to_nns': 'prosperities', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'prosperous'},
 'protein': {'nn_to_nns': 'proteins', 'n_is_nc': '', 'n_is_sth': ''},
 'province': {'nn_to_nns': 'provinces', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'provision': {'nn_to_nns': 'provisions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'provisional', 'nn_to_rb': 'provisionally', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'provisions': {'nn_to_nns': 'provisionses', 'nns_to_nn': 'provision', 'n_is_nc': '', 'n_is_sth': ''},
 'psychology': {'nn_to_nns': 'psychologies', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'psychological', 'nn_to_rb': 'psychologically'},
 'pub': {'nn_to_nns': 'pubs', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'public': {'nn_to_nns': 'publics', 'n_is_nc': '', 'n_is_sth': '', 'n_is_collective': ''},
 'publication': {'nn_to_nns': 'publications', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'publicize'},
 'puck': {'nn_to_nns': 'pucks', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'pump': {'nn_to_nns': 'pumps', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'v_to': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'punch': {'nn_to_nns': 'punches', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'punches', 'vb_to_vbd': 'punched', 'vb_to_vbn': 'punched', 'vb_to_vbg': 'punching', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'punishment': {'nn_to_nns': 'punishments', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'punish'},
 'pupil': {'nn_to_nns': 'pupils', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'purple': {'nn_to_nns': 'purples', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'purplish'},
 'purpose': {'nn_to_nns': 'purposes', 'n_is_nc': '', 'n_is_sth': '', 'v_vbg': '', 'v_to_vb': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'purse': {'nn_to_nns': 'purses', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'pursuit': {'nn_to_nns': 'pursuits', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'pursue'},
 'quarter': {'nn_to_nns': 'quarters', 'n_is_nc': '', 'nc_typical': '', 'n_is_sth': '0'},
 'quarterly': {'nn_to_nns': 'quarterlies', 'n_is_nc': '', 'n_is_sth': ''},
 'queen': {'nn_to_nns': 'queens', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'quest': {'nn_to_nns': 'quests', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'question': {'nn_to_nns': 'questions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_rb': 'questionably', 'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'questions', 'vb_to_vbd': 'questioned', 'vb_to_vbn': 'questioned', 'vb_to_rb': 'questionably', 'vb_to_nn': 'questionnaire', 'vb_to_vbg': 'questioning', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'queue': {'nn_to_nns': 'queues', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'quid': {'nn_to_nns': 'quids', 'n_is_nc': '', 'n_is_sth': ''},
 'quote': {'nn_to_nns': 'quotes', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'quotes', 'vb_to_vbd': 'quoted', 'vb_to_vbn': 'quoted', 'vb_to_nn': 'quotation', 'vb_to_vbg': 'quoting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'race': {'nn_to_nns': 'races', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_about': '', 'v_for': '', 'v_against': '', 'v_to': '', 'vb_to_vbz': 'races', 'vb_to_vbd': 'raced', 'vb_to_vbn': 'raced', 'vb_to_vbg': 'racing', 'vbd_eq_vbn': ''},
 'radar': {'nn_to_nns': 'radars', 'n_is_nc': '', 'n_is_sth': ''},
 'radiation': {'nn_to_nns': 'radiations', 'n_is_nc': '', 'n_is_sth': '', 'n_is_nu': ''},
 'radical': {'nn_to_nns': 'radicals', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'radio': {'nn_to_nns': 'radios', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'v_to': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'rage': {'nn_to_nns': 'rages', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'rail': {'nn_to_nns': 'rails', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'v_to_vbg': '', 'vdo': '', 'v_at': '', 'v_against': '', 'vb_to_vbz': 'rails', 'vb_to_vbd': 'railed', 'vb_to_vbn': 'railed', 'vb_to_vbg': 'railing', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'railroad': {'nn_to_nns': 'railroads', 'n_is_nc': '', 'n_is_sth': ''},
 'railway': {'nn_to_nns': 'railways', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'raise': {'nn_to_nns': 'raises', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'raises', 'vb_to_vbd': 'raised', 'vb_to_vbn': 'raised', 'vb_to_vbg': 'raising', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'rally': {'nn_to_nns': 'rallies', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'rap': {'nn_to_nns': 'raps', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'rape': {'nn_to_nns': 'rapes', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': ''},
 'rate': {'nn_to_nns': 'rates', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'rates', 'vb_to_vbd': 'rated', 'vb_to_vbn': 'rated', 'vb_to_vbg': 'rating', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'rating': {'nn_to_nns': 'ratings', 'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'rate', 'vbg_to_vbn': 'rated'},
 'ratio': {'nn_to_nns': 'ratios', 'n_is_nc': '', 'n_is_sth': ''},
 'ray': {'nn_to_nns': 'rays', 'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'reader': {'nn_to_nns': 'readers', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_vb': 'read', 'n_is_sth': '2'},
 'reading': {'nn_to_nns': 'readings', 'n_is_nc': '', 'n_is_sth': '', 'vbg_to_nn': 'read', 'vbg_to_vb': 'read', 'vbg_to_vbn': 'read', 'n_is_nu': ''},
 'reality': {'nn_to_nns': 'realities', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'real', 'nn_to_rb': 'really'},
 'rear': {'nn_to_nns': 'rears', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'reason': {'nn_to_nns': 'reasons', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'reasonable', 'nn_to_rb': 'reasonably', 'v_compcl': '', 'vdo': '', 'v_on': '', 'v_with': '', 'v_about': '', 'vb_to_vbz': 'reasons', 'vb_to_vbd': 'reasoned', 'vb_to_vbn': 'reasoned', 'vb_to_vbg': 'reasoning', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'nc_typical': ''},
 'rebel': {'nn_to_nns': 'rebels', 'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'recall': {'nn_to_nns': 'recalls', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'v_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'recalls', 'vb_to_vbd': 'recalled', 'vb_to_vbn': 'recalled', 'vb_to_vbg': 'recalling', 'vbd_eq_vbn': ''},
 'receiver': {'nn_to_nns': 'receivers', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '', 'nc_typical': ''},
 'reception': {'nn_to_nns': 'receptions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'receive'},
 'receptionist': {'nn_to_nns': 'receptionists', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'recipe': {'nn_to_nns': 'recipes', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'recommendation': {'nn_to_nns': 'recommendations', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'recommend'},
 'record': {'nn_to_nns': 'records', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'records', 'vb_to_vbd': 'recorded', 'vb_to_vbn': 'recorded', 'vb_to_vbg': 'recording', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'recording': {'nn_to_nns': 'recordings', 'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'record', 'vbg_to_vbn': 'recorded'},
 'recount': {'nn_to_nns': 'recounts', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'vbd_eq_vbn': ''},
 'recovery': {'nn_to_nns': 'recoveries', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'recover', 'nn_to_jj': 'recoverable'},
 'red': {'nn_to_nns': 'reds', 'n_is_nc': '', 'n_is_sb': '2', 'jj_ed': '', 'n_is_sth': '2', 'jj_to_jjr': 'redder', 'jj_to_jjs': 'reddest'},
 'reduction': {'nn_to_nns': 'reductions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'reduce'},
 'reed': {'nn_to_nns': 'reeds', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'reference': {'nn_to_nns': 'references', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'refer', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'referendum': {'nn_to_nns': 'referendums', 'n_is_nc': '', 'n_is_sth': ''},
 'refrigerator': {'nn_to_nns': 'refrigerators', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'refuge': {'nn_to_nns': 'refuges', 'n_is_nc': '', 'n_is_sth': ''},
 'refugee': {'nn_to_nns': 'refugees', 'n_is_nc': '', 'n_is_sb': '0'},
 'regard': {'nn_to_nns': 'regards', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'regards', 'vb_to_vbd': 'regarded', 'vb_to_vbn': 'regarded', 'vb_to_vbg': 'regarding', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'regime': {'nn_to_nns': 'regimes', 'n_is_nc': '', 'n_is_sth': ''},
 'region': {'nn_to_nns': 'regions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'regional', 'nn_to_rb': 'regionally'},
 'registration': {'nn_to_nns': 'registrations', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'register'},
 'regulation': {'nn_to_nns': 'regulations', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'regulate'},
 'reject': {'nn_to_nns': 'rejects', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'rejects', 'vb_to_vbd': 'rejected', 'vb_to_vbn': 'rejected', 'vb_to_nn': 'rejection', 'vb_to_jj': 'rejective', 'vb_to_vbg': 'rejecting', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vt_typical': ''},
 'relationship': {'nn_to_nns': 'relationships', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'relate'},
 'relative': {'nn_to_nns': 'relatives', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'be_jj_to_vbg': '', 'n_is_sth': '2'},
 'release': {'nn_to_nns': 'releases', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'releases', 'vb_to_vbd': 'released', 'vb_to_vbn': 'released', 'vb_to_vbg': 'releasing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'relief': {'nn_to_nns': 'reliefs', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_vb': 'relieve', 'n_is_nc': ''},
 'remainder': {'nn_to_nns': 'remainders', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'remain'},
 'reminder': {'nn_to_nns': 'reminders', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_vb': 'remind'},
 'remove': {'nn_to_nns': 'removes', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'removes', 'vb_to_vbd': 'removed', 'vb_to_vbn': 'removed', 'vb_to_nn': 'removal', 'vb_to_jj': 'removable', 'vb_to_vbg': 'removing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'rent': {'nn_to_nns': 'rents', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_for': '', 'vb_to_vbz': 'rents', 'vb_to_vbd': 'rented', 'vb_to_vbn': 'rented', 'vb_to_vbg': 'renting', 'vbd_eq_vbn': ''},
 'rental': {'nn_to_nns': 'rentals', 'n_is_nu': '', 'n_is_sth': ''},
 'reorganization': {'nn_to_nns': 'reorganizations', 'n_is_nu': '', 'n_is_sth': ''},
 'repair': {'nn_to_nns': 'repairs', 'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'repairs', 'vb_to_vbd': 'repaired', 'vb_to_vbn': 'repaired', 'vb_to_vbg': 'repairing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'repeat': {'nn_to_nns': 'repeats', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'vb_to_vbz': 'repeats', 'vb_to_vbd': 'repeated', 'vb_to_vbn': 'repeated', 'vb_to_rb': 'repeatedly', 'vb_to_nn': 'repetition', 'vb_to_jj': 'repeated', 'vb_to_vbg': 'repeating', 'vbd_eq_vbn': ''},
 'replacement': {'nn_to_nns': 'replacements', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_vb': 'replace', 'nn_to_jj': 'replaceable'},
 'report': {'nn_to_nns': 'reports', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_vbg': '', 'v_to_vbg': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'v_to': '', 'vb_to_vbz': 'reports', 'vb_to_vbd': 'reported', 'vb_to_vbn': 'reported', 'vb_to_nn': 'reporter', 'vb_to_vbg': 'reporting', 'vbd_eq_vbn': ''},
 'reporter': {'nn_to_nns': 'reporters', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'report', 'nc_typical': ''},
 'republic': {'nn_to_nns': 'republics', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'republican': {'nn_to_nns': 'republicans', 'n_is_nc': '', 'n_is_sb': '0'},
 'reputation': {'nn_to_nns': 'reputations', 'n_is_nu': '', 'n_is_sth': '', 'n_is_nc': ''},
 'request': {'nn_to_nns': 'requests', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_of': '', 'vb_to_vbz': 'requests', 'vb_to_vbd': 'requested', 'vb_to_vbn': 'requested', 'vb_to_vbg': 'requesting', 'vbd_eq_vbn': '', 'nc_typical': '', 'v_that_n_vb': ''},
 'requirement': {'nn_to_nns': 'requirements', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'require', 'nc_typical': ''},
 'research': {'nn_to_nns': 'researches', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_for': '', 'vb_to_vbz': 'researches', 'vb_to_vbd': 'researched', 'vb_to_vbn': 'researched', 'vb_to_nn': 'researcher', 'vb_to_vbg': 'researching', 'vbd_eq_vbn': '', 'n_is_nu': ''},
 'researcher': {'nn_to_nns': 'researchers', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'research'},
 'reservation': {'nn_to_nns': 'reservations', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'reserve', 'nn_to_jj': 'reservations', 'nn_to_rb': 'reserves'},
 'reserve': {'nn_to_nns': 'reserves', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'reservations', 'nn_to_rb': 'reserves', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'reserves', 'vb_to_vbd': 'reserved', 'vb_to_vbn': 'reserved', 'vb_to_rb': 'reserves', 'vb_to_jj': 'reservations', 'vb_to_vbg': 'reserving', 'vt_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'residence': {'nn_to_nns': 'residences', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'reside', 'nn_to_jj': 'residential', 'n_is_nc': ''},
 'resident': {'nn_to_nns': 'residents', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'reside', 'nn_to_jj': 'residential'},
 'resignation': {'nn_to_nns': 'resignations', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'resign'},
 'resolution': {'nn_to_nns': 'resolutions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'resolve'},
 'resort': {'nn_to_nns': 'resorts', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'resorts', 'vb_to_vbd': 'resorted', 'vb_to_vbn': 'resorted', 'vb_to_vbg': 'resorting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'response': {'nn_to_nns': 'responses', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'respond', 'nn_to_jj': 'respondent'},
 'restaurant': {'nn_to_nns': 'restaurants', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'resume': {'nn_to_nns': 'resumes', 'n_is_nc': '', 'n_is_sth': '', 'v_vbg': '', 'v_to_vbg': '', 'v_n': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'retailer': {'nn_to_nns': 'retailers', 'n_is_nc': '', 'n_is_sb': '0'},
 'retreat': {'nn_to_nns': 'retreats', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'return': {'nn_to_nns': 'returns', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'v_n_to_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'returns', 'vb_to_vbd': 'returned', 'vb_to_vbn': 'returned', 'vb_to_vbg': 'returning', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'reunion': {'nn_to_nns': 'reunions', 'n_is_nu': '', 'n_is_sth': ''},
 'revenue': {'nn_to_nns': 'revenues', 'n_is_nu': '', 'n_is_sth': ''},
 'reverse': {'nn_to_nns': 'reverses', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'reverses', 'vb_to_vbd': 'reversed', 'vb_to_vbn': 'reversed', 'vb_to_nn': 'reversal', 'vb_to_jj': 'reversible', 'vb_to_vbg': 'reversing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'revival': {'nn_to_nns': 'revivals', 'n_is_nu': '', 'n_is_sth': ''},
 'reward': {'nn_to_nns': 'rewards', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'rewards', 'vb_to_vbd': 'rewarded', 'vb_to_vbn': 'rewarded', 'vb_to_vbg': 'rewarding', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'rhetoric': {'nn_to_nns': 'rhetorics', 'n_is_nu': '', 'n_is_sth': ''},
 'rhododendron': {'nn_to_nns': 'rhododendra', 'n_is_nc': '', 'n_is_sth': ''},
 'rhythm': {'nn_to_nns': 'rhythms', 'n_is_nu': '', 'n_is_sth': ''},
 'rice': {'nn_to_nns': 'rices', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nu_typical': ''},
 'ride': {'nn_to_nns': 'rides', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_in': '', 'v_from': '', 'vb_to_vbz': 'rides', 'vb_to_vbd': 'rode', 'vb_to_vbn': 'ridden', 'vb_to_vbg': 'riding', 'v_compcl_non': '', 'v_prprtcl_non': '', 'nc_typical': '', 'n_is_nc': ''},
 'rider': {'nn_to_nns': 'riders', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'riding': {'nn_to_nns': 'ridings', 'n_is_sth': '', 'vbg_to_vb': 'ride', 'vbg_to_vbn': 'ridden'},
 'right': {'nn_to_nns': 'rights', 'n_is_sth': '', 'vb_to_rb': 'rightfully', 'vb_to_nn': 'rightness', 'vb_to_jj': 'rightful', 'vbd_eq_vbn': '', 'be_jj_to_vb': ''},
 'ring': {'nn_to_nns': 'rings', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_for': '', 'vb_to_vbz': 'rings', 'vb_to_vbd': 'ringed', 'vb_to_vbn': 'ringed', 'vb_to_vbg': 'ringing', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'nc_typical': ''},
 'rip': {'nn_to_nns': 'rips', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'rips', 'vb_to_vbd': 'ripped', 'vb_to_vbn': 'ripped', 'vb_to_vbg': 'ripping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'ritual': {'nn_to_nns': 'rituals', 'n_is_nc': '', 'n_is_sth': ''},
 'rival': {'nn_to_nns': 'rivals', 'n_is_nc': '', 'n_is_sb': '0', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'rivals', 'vb_to_vbd': 'rivaled', 'vb_to_vbn': 'rivaled', 'vb_to_vbg': 'rivaling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'rivalry': {'nn_to_nns': 'rivalries', 'n_is_nc': '', 'n_is_sth': ''},
 'river': {'nn_to_nns': 'rivers', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'road': {'nn_to_nns': 'roads', 'n_is_nc': '', 'n_is_sth': ''},
 'robbery': {'nn_to_nns': 'robberies', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'rob'},
 'robert': {'nn_to_nns': 'roberts', 'n_is_nc': '', 'n_is_sb': '0'},
 'rock': {'nn_to_nns': 'rocks', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'rocky', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'rocks', 'vb_to_vbd': 'rocked', 'vb_to_vbn': 'rocked', 'vb_to_jj': 'rocky', 'vb_to_vbg': 'rocking', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'rocket': {'nn_to_nns': 'rockets', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'role': {'nn_to_nns': 'roles', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'roll': {'nn_to_nns': 'rolls', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'rolls', 'vb_to_vbd': 'rolled', 'vb_to_vbn': 'rolled', 'vb_to_vbg': 'rolling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'nc_typical': ''},
 'romance': {'nn_to_nns': 'romances', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'romantic': {'nn_to_nns': 'romantics', 'n_is_sth': '', 'n_is_sb': '0'},
 'roof': {'nn_to_nns': 'roofs', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'roofs', 'vb_to_vbd': 'roofed', 'vb_to_vbn': 'roofed', 'vb_to_vbg': 'roofing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'room': {'nn_to_nns': 'rooms', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_compcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'root': {'nn_to_nns': 'roots', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_for': '', 'vb_to_vbz': 'roots', 'vb_to_vbd': 'rooted', 'vb_to_vbn': 'rooted', 'vb_to_vbg': 'rooting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'nc_typical': ''},
 'rose': {'nn_to_nns': 'roses', 'n_is_nc': '', 'n_is_sth': '', 'vi_typical': ''},
 'roster': {'nn_to_nns': 'rosters', 'n_is_nc': '', 'n_is_sth': ''},
 'rotation': {'nn_to_nns': 'rotations', 'n_is_nu': '', 'n_is_sth': ''},
 'route': {'nn_to_nns': 'routes', 'n_is_nc': '', 'n_is_sth': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'routes', 'vb_to_vbd': 'routed', 'vb_to_vbn': 'routed', 'vb_to_vbg': 'routing', 'vbd_eq_vbn': ''},
 'routine': {'nn_to_nns': 'routines', 'n_is_nc': '', 'n_is_sth': ''},
 'row': {'nn_to_nns': 'rows', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'rows', 'vb_to_vbd': 'rowed', 'vb_to_vbn': 'rowed', 'vb_to_vbg': 'rowing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'rubber': {'nn_to_nns': 'rubbers', 'n_is_sth': ''},
 'rule': {'nn_to_nns': 'rules', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'rules', 'vb_to_vbd': 'ruled', 'vb_to_vbn': 'ruled', 'vb_to_vbg': 'ruling', 'vbd_eq_vbn': ''},
 'ruler': {'nn_to_nns': 'rulers', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '', 'nn_to_vb': 'rule', 'nc_typical': ''},
 'ruling': {'nn_to_nns': 'rulings', 'n_is_sth': '', 'vbg_to_vb': 'rule', 'vbg_to_vbn': 'ruled'},
 'runner': {'nn_to_nns': 'runners', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'run', 'nc_typical': ''},
 'running': {'nn_to_nns': 'runnings', 'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'runway': {'nn_to_nns': 'runways', 'n_is_nc': '', 'n_is_sth': ''},
 'sack': {'nn_to_nns': 'sacks', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'sacks', 'vb_to_vbd': 'sacked', 'vb_to_vbn': 'sacked', 'vb_to_vbg': 'sacking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'n_of_nns': '', 'n_of_nn': ''},
 'safeblower': {'nn_to_nns': 'safeblowers', 'n_is_nc': '', 'n_is_sb': '0'},
 'safecracker': {'nn_to_nns': 'safecrackers', 'n_is_nc': '', 'n_is_sb': '0'},
 'safeguard': {'nn_to_nns': 'safeguards', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'sail': {'nn_to_nns': 'sails', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'sails', 'vb_to_vbd': 'sailed', 'vb_to_vbn': 'sailed', 'vb_to_nn': 'sailing', 'vb_to_vbg': 'sailing', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'nc_typical': ''},
 'sailor': {'nn_to_nns': 'sailors', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'sail', 'nc_typical': ''},
 'salad': {'nn_to_nns': 'salads', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'salary': {'nn_to_nns': 'salaries', 'n_is_nu': '', 'n_is_sth': '', 'n_is_nc': ''},
 'sale': {'nn_to_nns': 'sales', 'n_is_nc': '', 'n_is_sth': ''},
 'sample': {'nn_to_nns': 'samples', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'samples', 'vb_to_vbd': 'sampled', 'vb_to_vbn': 'sampled', 'vb_to_vbg': 'sampling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'sand': {'nn_to_nns': 'sands', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'sandy', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'sands', 'vb_to_vbd': 'sanded', 'vb_to_vbn': 'sanded', 'vb_to_vbg': 'sanding', 'vbd_eq_vbn': ''},
 'satellite': {'nn_to_nns': 'satellites', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nc_typical': ''},
 'satisfaction': {'nn_to_nns': 'satisfactions', 'n_is_nu': '', 'n_is_sth': ''},
 'sauce': {'nn_to_nns': 'sauces', 'n_is_nu': '', 'n_is_sth': '', 'vb_to_vbz': 'sauces', 'vb_to_vbd': 'sauced', 'vb_to_vbn': 'sauced', 'vb_to_vbg': 'saucing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_nc': 'noun_attr'},
 'saver': {'nn_to_nns': 'savers', 'n_is_nc': '', 'n_is_sb': '0'},
 'savvy': {'nn_to_nns': 'savvys', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'jj_to_jjr': 'savvier', 'jj_to_jjs': 'savviest'},
 'saying': {'nn_to_nns': 'sayings', 'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'say', 'vbg_to_vbn': 'said', 'nc_typical': ''},
 'scare': {'nn_to_nns': 'scares', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'scenario': {'nn_to_nns': 'scenarios', 'n_is_nc': '', 'n_is_sth': ''},
 'scene': {'nn_to_nns': 'scenes', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'schedule': {'nn_to_nns': 'schedules', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'schedules', 'vb_to_vbd': 'scheduled', 'vb_to_vbn': 'scheduled', 'vb_to_vbg': 'scheduling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'vt_typical': ''},
 'scheme': {'nn_to_nns': 'schemes', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'schematic', 'nn_to_rb': 'schematically', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'v_against': '', 'vb_to_vbz': 'schemes', 'vb_to_vbd': 'schemed', 'vb_to_vbn': 'schemed', 'vb_to_rb': 'schematically', 'vb_to_jj': 'schematic', 'vb_to_vbg': 'scheming', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'scholar': {'nn_to_nns': 'scholars', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'scholarly', 'nc_typical': ''},
 'scholarship': {'nn_to_nns': 'scholarships', 'n_is_nu': '', 'n_is_sth': ''},
 'school': {'nn_to_nns': 'schools', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'scientist': {'nn_to_nns': 'scientists', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'scientific', 'nn_to_rb': 'scientifically', 'nc_typical': ''},
 'score': {'nn_to_nns': 'scores', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_of': '', 'v_against': '', 'vb_to_vbz': 'scores', 'vb_to_vbd': 'scored', 'vb_to_vbn': 'scored', 'vb_to_vbg': 'scoring', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'nc_typical': ''},
 'scorer': {'nn_to_nns': 'scorers', 'n_is_nc': '', 'n_is_sb': '0'},
 'scream': {'nn_to_nns': 'screams', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_at': '', 'v_in': '', 'v_with': '', 'v_for': '', 'vb_to_vbz': 'screams', 'vb_to_vbd': 'screamed', 'vb_to_vbn': 'screamed', 'vb_to_vbg': 'screaming', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_pass_non': '', 'nc_typical': '', 'n_is_nc': ''},
 'screen': {'nn_to_nns': 'screens', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'screens', 'vb_to_vbd': 'screened', 'vb_to_vbn': 'screened', 'vb_to_vbg': 'screening', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'screenplay': {'nn_to_nns': 'screenplays', 'n_is_nc': '', 'n_is_sth': ''},
 'screw': {'nn_to_nns': 'screws', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'screwball': {'nn_to_nns': 'screwballs', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'screwdriver': {'nn_to_nns': 'screwdrivers', 'n_is_nc': '', 'n_is_sth': ''},
 'script': {'nn_to_nns': 'scripts', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'scripts', 'vb_to_vbd': 'scripted', 'vb_to_vbn': 'scripted', 'vb_to_vbg': 'scripting', 'vbd_eq_vbn': ''},
 'sculptor': {'nn_to_nns': 'sculptors', 'n_is_nc': '', 'n_is_sb': '0'},
 'sculpture': {'nn_to_nns': 'sculptures', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'sea': {'nn_to_nns': 'seas', 'n_is_nu': '', 'n_is_sth': '', 'n_is_nc': ''},
 'seal': {'nn_to_nns': 'seals', 'n_is_nc': '', 'n_is_sb': '3', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'seals', 'vb_to_vbd': 'sealed', 'vb_to_vbn': 'sealed', 'vb_to_vbg': 'sealing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'nc_typical': '', 'n_is_sth': '3'},
 'season': {'nn_to_nns': 'seasons', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'seasons', 'vb_to_vbd': 'seasoned', 'vb_to_vbn': 'seasoned', 'vb_to_vbg': 'seasoning', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'seat': {'nn_to_nns': 'seats', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'seats', 'vb_to_vbd': 'seated', 'vb_to_vbn': 'seated', 'nn_to_vb': 'sit', 'vb_to_vbg': 'seating', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'nc_typical': ''},
 'secondary': {'nn_to_nns': 'secondaries', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'second', 'nn_to_jj': 'second', 'nn_to_rb': 'secondly'},
 'section': {'nn_to_nns': 'sections', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'sections', 'vb_to_vbd': 'sectioned', 'vb_to_vbn': 'sectioned', 'vb_to_vbg': 'sectioning', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'sector': {'nn_to_nns': 'sectors', 'n_is_nc': '', 'n_is_sth': ''},
 'security': {'nn_to_nns': 'securities', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'secure', 'nn_to_jj': 'secure', 'nn_to_rb': 'securely'},
 'segment': {'nn_to_nns': 'segments', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'seller': {'nn_to_nns': 'sellers', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'sell'},
 'semiconductor': {'nn_to_nns': 'semiconductors', 'n_is_nc': '', 'n_is_sth': ''},
 'senate': {'nn_to_nns': 'senates', 'n_is_nc': '', 'n_is_sth': ''},
 'senator': {'nn_to_nns': 'senators', 'n_is_nc': '', 'n_is_sb': '0'},
 'senior': {'nn_to_nns': 'seniors', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'sense': {'nn_to_nns': 'senses', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'sensible', 'nn_to_rb': 'sensibly', 'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'senses', 'vb_to_vbd': 'sensed', 'vb_to_vbn': 'sensed', 'vb_to_rb': 'sensibly', 'vb_to_jj': 'sensible', 'vb_to_vbg': 'sensing', 'vbd_eq_vbn': ''},
 'sentence': {'nn_to_nns': 'sentences', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'sentences', 'vb_to_vbd': 'sentenced', 'vb_to_vbn': 'sentenced', 'vb_to_vbg': 'sentencing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'sentiment': {'nn_to_nns': 'sentiments', 'n_is_nc': '', 'n_is_sth': ''},
 'sequence': {'nn_to_nns': 'sequences', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'sequential', 'nn_to_rb': 'sequentially', 'vb_to_vbz': 'sequences', 'vb_to_vbd': 'sequenced', 'vb_to_vbn': 'sequenced', 'vb_to_rb': 'sequentially', 'vb_to_jj': 'sequential', 'vb_to_vbg': 'sequencing', 'vbd_eq_vbn': ''},
 'servant': {'nn_to_nns': 'servants', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'serve', 'nc_typical': ''},
 'serve': {'nn_to_nns': 'serves', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'v_n_n': '', 'v_n_to_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'serves', 'vb_to_vbd': 'served', 'vb_to_vbn': 'served', 'vb_to_nn': 'serving', 'vb_to_vbg': 'serving', 'vt_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'server': {'nn_to_nns': 'servers', 'n_is_nc': '', 'n_is_sb': '0'},
 'service': {'nn_to_nns': 'services', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'services', 'vb_to_vbd': 'serviced', 'vb_to_vbn': 'serviced', 'vb_to_vbg': 'servicing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'session': {'nn_to_nns': 'sessions', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'set': {'nn_to_nns': 'sets', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'v_n_to_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'v_on': '', 'v_in': '', 'vb_to_vbz': 'sets', 'v_n_vbg': '', 'v_n_vb': '', 'vb_to_vbg': 'setting', 'vbn_to_vbg': 'setting', 'vt_typical': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'setback': {'nn_to_nns': 'setbacks', 'n_is_nc': '', 'n_is_sth': ''},
 'settler': {'nn_to_nns': 'settlers', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'settle', 'nc_typical': ''},
 'shadow': {'nn_to_nns': 'shadows', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'shadowy', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'shadows', 'vb_to_vbd': 'shadowed', 'vb_to_vbn': 'shadowed', 'vb_to_jj': 'shadowy', 'vb_to_vbg': 'shadowing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'n_is_nc': ''},
 'shake': {'nn_to_nns': 'shakes', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'shaky', 'nn_to_rb': 'shakily', 'v_to_vbg': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_with': '', 'vb_to_vbz': 'shakes', 'vb_to_vbd': 'shook', 'vb_to_vbn': 'shaken', 'vb_to_rb': 'shakily', 'vb_to_jj': 'shaky', 'vb_to_vbg': 'shaking', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'shame': {'nn_to_nns': 'shames', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'shameful', 'nn_to_rb': 'shamefully', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'shames', 'vb_to_vbd': 'shamed', 'vb_to_vbn': 'shamed', 'vb_to_rb': 'shamefully', 'vb_to_jj': 'shameful', 'vb_to_vbg': 'shaming', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'share': {'nn_to_nns': 'shares', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_with': '', 'vb_to_vbz': 'shares', 'vb_to_vbd': 'shared', 'vb_to_vbn': 'shared', 'vb_to_vbg': 'sharing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'shareholder': {'nn_to_nns': 'shareholders', 'n_is_nc': '', 'n_is_sb': '0'},
 'shave': {'nn_to_nns': 'shaves', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'shaves', 'vb_to_vbd': 'shaved', 'vb_to_vbn': 'shaved', 'vb_to_vbg': 'shaving', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'shed': {'nn_to_nns': 'sheds', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'vb_to_vbz': 'sheds', 'vb_to_vbd': 'shedded,shed', 'vb_to_vbn': 'shedded,shed', 'vb_to_vbg': 'sheding', 'v_prprtcl_non': ''},
 'sheet': {'nn_to_nns': 'sheets', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'shell': {'nn_to_nns': 'shells', 'n_is_nc': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'shells', 'vb_to_vbd': 'shelled', 'vb_to_vbn': 'shelled', 'vb_to_vbg': 'shelling', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'n_is_sth': '0'},
 'shelter': {'nn_to_nns': 'shelters', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'shelters', 'vb_to_vbd': 'sheltered', 'vb_to_vbn': 'sheltered', 'vb_to_vbg': 'sheltering', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'shift': {'nn_to_nns': 'shifts', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_from': '', 'vb_to_vbz': 'shifts', 'vb_to_vbd': 'shifted', 'vb_to_vbn': 'shifted', 'vb_to_vbg': 'shifting', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'ship': {'nn_to_nns': 'ships', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'ships', 'vb_to_vbd': 'shipped', 'vb_to_vbn': 'shipped', 'vb_to_nn': 'shipment', 'vb_to_vbg': 'shipping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'shirt': {'nn_to_nns': 'shirts', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'shock': {'nn_to_nns': 'shocks', 'n_is_nu': '', 'n_is_sth': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'shocks', 'vb_to_vbd': 'shocked', 'vb_to_vbn': 'shocked', 'vb_to_vbg': 'shocking', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'shoe': {'nn_to_nns': 'shoes', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'shoot': {'nn_to_nns': 'shoots', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_at': '', 'v_for': '', 'vb_to_vbz': 'shoots', 'vb_to_vbd': 'shot', 'vb_to_vbn': 'shot', 'vb_to_vbg': 'shooting', 'v_compcl_non': '', 'nc_typical': ''},
 'shop': {'nn_to_nns': 'shops', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_for': '', 'vb_to_vbz': 'shops', 'vb_to_vbd': 'shopped', 'vb_to_vbn': 'shopped', 'vb_to_vbg': 'shopping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'nc_typical': ''},
 'shopkeeper': {'nn_to_nns': 'shopkeepers', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'shore': {'nn_to_nns': 'shores', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'shortage': {'nn_to_nns': 'shortages', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'shorten', 'nn_to_jj': 'short', 'nn_to_rb': 'shortly'},
 'shoulder': {'nn_to_nns': 'shoulders', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'shoulders', 'vb_to_vbd': 'shouldered', 'vb_to_vbn': 'shouldered', 'vb_to_vbg': 'shouldering', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'shout': {'nn_to_nns': 'shouts', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_for': '', 'vb_to_vbz': 'shouts', 'vb_to_vbd': 'shouted', 'vb_to_vbn': 'shouted', 'vb_to_vbg': 'shouting', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'show': {'nn_to_nns': 'shows', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_n': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_to_vbz': 'shows', 'vb_to_vbd': 'showed', 'vb_to_vbn': 'shown', 'vb_to_vbg': 'showing'},
 'shower': {'nn_to_nns': 'showers', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'showers', 'vb_to_vbd': 'showered', 'vb_to_vbn': 'showered', 'vb_to_vbg': 'showering', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'showing': {'nn_to_nns': 'showings', 'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'show', 'vbg_to_vbn': 'shown'},
 'shrug': {'nn_to_nns': 'shrugs', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'shrugs', 'vb_to_vbd': 'shrugged', 'vb_to_vbn': 'shrugged', 'vb_to_vbg': 'shruging', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'shuttle': {'nn_to_nns': 'shuttles', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'side': {'nn_to_nns': 'sides', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'sideline': {'nn_to_nns': 'sidelines', 'n_is_nc': '', 'n_is_sth': ''},
 'sidewalk': {'nn_to_nns': 'sidewalks', 'n_is_nc': '', 'n_is_sth': ''},
 'sight': {'nn_to_nns': 'sights', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'sights', 'vb_to_vbd': 'sighted', 'vb_to_vbn': 'sighted', 'vb_to_vbg': 'sighting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'sign': {'nn_to_nns': 'signs', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'signs', 'vb_to_vbd': 'signed', 'vb_to_vbn': 'signed', 'vb_to_vbg': 'signing', 'vbd_eq_vbn': ''},
 'signal': {'nn_to_nns': 'signals', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_for': '', 'v_to': '', 'vb_to_vbz': 'signals', 'vb_to_vbd': 'signaled', 'vb_to_vbn': 'signaled', 'vb_to_vbg': 'signaling', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'signature': {'nn_to_nns': 'signatures', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'sign'},
 'silence': {'nn_to_nns': 'silences', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'silent', 'nn_to_rb': 'silently', 'vb_to_rb': 'silently', 'vb_to_jj': 'silent', 'vbd_eq_vbn': '', 'n_usu_singular': ''},
 'silly': {'nn_to_nns': 'sillies', 'n_is_nc': '', 'n_is_sb': '0', 'jj_to_jjr': 'sillier', 'jj_to_jjs': 'silliest'},
 'simon': {'nn_to_nns': 'simons', 'n_is_sb': '0'},
 'sing': {'nn_to_nns': 'sings', 'n_is_sth': '', 'nn_to_jj': 'singing', 'nn_to_rb': 'singingly', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'sings', 'vb_to_vbd': 'sang', 'vb_to_vbn': 'sung', 'vb_to_rb': 'singingly', 'vb_to_jj': 'singing', 'vb_to_vbg': 'singing', 'vt_typical': '', 'v_prprtcl_non': ''},
 'singer': {'nn_to_nns': 'singers', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'sing', 'nn_to_jj': 'singing', 'nn_to_rb': 'singingly', 'nc_typical': ''},
 'single': {'nn_to_nns': 'singles', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'sink': {'nn_to_nns': 'sinks', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'sunk', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'sinks', 'vb_to_vbd': 'sank', 'vb_to_vbn': 'sunk', 'vb_to_jj': 'sunk', 'vb_to_vbg': 'sinking', 'v_compcl_non': '', 'nc_typical': ''},
 'sister': {'nn_to_nns': 'sisters', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'sisterly', 'nc_typical': ''},
 'sitcom': {'nn_to_nns': 'sitcoms', 'n_is_sth': ''},
 'site': {'nn_to_nns': 'sites', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'sites', 'vb_to_vbd': 'sited', 'vb_to_vbn': 'sited', 'vb_to_vbg': 'siting', 'vbd_eq_vbn': ''},
 'situation': {'nn_to_nns': 'situations', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'situate', 'nn_to_jj': 'situated', 'nc_typical': ''},
 'size': {'nn_to_nns': 'sizes', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'sized', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'vb_to_vbz': 'sizes', 'vb_to_vbd': 'sized', 'vb_to_vbn': 'sized', 'vb_to_vbg': 'sizing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'skepticism': {'nn_to_nns': 'skepticisms', 'n_is_nu': '', 'n_is_sth': ''},
 'ski': {'nn_to_nns': 'skis', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_pass_non': '', 'nc_typical': ''},
 'skill': {'nn_to_nns': 'skills', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'skilled', 'nn_to_rb': 'skilfully'},
 'skirt': {'nn_to_nns': 'skirts', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'skirts', 'vb_to_vbd': 'skirted', 'vb_to_vbn': 'skirted', 'vb_to_vbg': 'skirting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'sky': {'nn_to_nns': 'skys', 'n_is_nu': '', 'n_is_sth': '', 'n_is_nc': ''},
 'slavery': {'nn_to_nns': 'slaveries', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'slave', 'nu_typical': ''},
 'sleeve': {'nn_to_nns': 'sleeves', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'slice': {'nn_to_nns': 'slices', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'slide': {'nn_to_nns': 'slides', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'sliding', 'v_to_vbg': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'slides', 'vb_to_vbd': 'slided', 'vb_to_vbn': 'slided', 'vb_to_jj': 'sliding', 'vb_to_vbg': 'sliding', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'slip': {'nn_to_nns': 'slips', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'slipping', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'slips', 'vb_to_vbd': 'slipped', 'vb_to_vbn': 'slipped', 'vb_to_jj': 'slipping', 'vb_to_vbg': 'slipping', 'vi_typical': '', 'vbd_eq_vbn': ''},
 'slot': {'nn_to_nns': 'slots', 'n_is_nu': '', 'n_is_sth': ''},
 'slowdown': {'nn_to_nns': 'slowdowns', 'n_is_nu': '', 'n_is_sth': ''},
 'slump': {'nn_to_nns': 'slumps', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'smell': {'nn_to_nns': 'smells', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'v_vbg': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vbe': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_to_vbz': 'smells', 'vb_to_vbd': 'smelled,smelt', 'vb_to_vbn': 'smelled,smelt', 'vb_to_vbg': 'smelling', 'vi_typical': '', 'v_infcl_non': '', 'n_is_nc': ''},
 'smile': {'nn_to_nns': 'smiles', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'smiling', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_at': '', 'vb_to_vbz': 'smiles', 'vb_to_vbd': 'smiled', 'vb_to_vbn': 'smiled', 'vb_to_jj': 'smiling', 'vb_to_vbg': 'smiling', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'snail': {'nn_to_nns': 'snails', 'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'snake': {'nn_to_nns': 'snakes', 'n_is_nc': '', 'n_is_sb': '3', 'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'nc_typical': '', 'n_is_sth': '3'},
 'soccer': {'nn_to_nns': 'soccers', 'n_is_nc': '', 'n_is_sth': '', 'nu_typical': ''},
 'society': {'nn_to_nns': 'societies', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'social'},
 'sock': {'nn_to_nns': 'socks', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'soil': {'nn_to_nns': 'soils', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'soiled', 'vb_to_jj': 'soiled', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'soldier': {'nn_to_nns': 'soldiers', 'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'solicitor': {'nn_to_nns': 'solicitors', 'n_is_nc': '', 'n_is_sb': '0'},
 'solid': {'nn_to_nns': 'solids', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'solidify', 'nn_to_jj': 'solidified', 'nn_to_rb': 'solidly', 'nc_typical': ''},
 'son': {'nn_to_nns': 'sons', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'song': {'nn_to_nns': 'songs', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'sore': {'nn_to_nns': 'sores', 'n_is_nu': '', 'n_is_sth': '', 'jj_to_jjr': 'sorer', 'jj_to_jjs': 'sorest'},
 'sort': {'nn_to_nns': 'sorts', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'sorted', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'sorts', 'vb_to_vbd': 'sorted', 'vb_to_vbn': 'sorted', 'vb_to_jj': 'sorted', 'vb_to_vbg': 'sorting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vt_typical': '', 'n_of_nn': ''},
 'soul': {'nn_to_nns': 'souls', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'sound': {'nn_to_nns': 'sounds', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'sounding', 'v_n': '', 'nsubjpass': '', 'vbe': '', 'vdo': '', 'vb_to_vbz': 'sounds', 'vb_to_vbd': 'sounded', 'vb_to_vbn': 'sounded', 'vb_to_jj': 'sounding', 'vb_to_vbg': 'sounding', 'vi_typical': '', 'vbd_eq_vbn': ''},
 'soup': {'nn_to_nns': 'soups', 'n_is_nu': '', 'n_is_sth': '', 'n_is_nc': ''},
 'source': {'nn_to_nns': 'sources', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'sourced', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'soviet': {'nn_to_nns': 'soviets', 'n_is_nu': '', 'n_is_sth': '', 'cap_word': 'Soviet'},
 'space': {'nn_to_nns': 'spaces', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'spaced', 'vb_to_jj': 'spaced', 'vbd_eq_vbn': '', 'v_whcl_non': '', 'vbg_non': ''},
 'span': {'nn_to_nns': 'spans', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'spare': {'nn_to_nns': 'spares', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'sparing', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'spares', 'vb_to_vbd': 'spared', 'vb_to_vbn': 'spared', 'vb_to_jj': 'sparing', 'vb_to_vbg': 'sparing', 'vt_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'spark': {'nn_to_nns': 'sparks', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'speaker': {'nn_to_nns': 'speakers', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'speak', 'nn_to_jj': 'speaking', 'nc_typical': ''},
 'special': {'nn_to_nns': 'specials', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'specialize', 'nn_to_jj': 'specialist', 'nn_to_rb': 'specially'},
 'specialty': {'nn_to_nns': 'specialties', 'n_is_nu': '', 'n_is_sth': '', 'n_is_nc': ''},
 'spectacular': {'nn_to_nns': 'spectaculars', 'n_is_sth': ''},
 'spectrum': {'nn_to_nns': 'spectrums', 'n_is_nc': '', 'n_is_sth': ''},
 'speech': {'nn_to_nns': 'speeches', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'speak', 'nn_to_jj': 'speaking'},
 'spell': {'nn_to_nns': 'spells', 'n_is_sth': '', 'v_n': '', 'v_n_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'spells', 'vb_to_vbd': 'spelled,spelt', 'vb_to_vbn': 'spelled,spelt', 'vb_to_vbg': 'spelling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'spider': {'nn_to_nns': 'spiders', 'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'spin': {'nn_to_nns': 'spins', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'spun', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'spins', 'vb_to_vbd': 'spun', 'vb_to_vbn': 'spun', 'vb_to_jj': 'spun', 'vb_to_vbg': 'spinning', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'split': {'nn_to_nns': 'splits', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'splitting', 'v_to_vbg': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'v_on': '', 'vb_to_vbz': 'splits', 'vb_to_jj': 'splitting', 'vb_to_vbg': 'spliting', 'vbn_to_vbg': 'spliting', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'sponsor': {'nn_to_nns': 'sponsors', 'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'spoon': {'nn_to_nns': 'spoons', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'sport': {'nn_to_nns': 'sports', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'sporting', 'vb_to_jj': 'sporting', 'vbd_eq_vbn': '', 'v_pass_non': ''},
 'spot': {'nn_to_nns': 'spots', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'spotted', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'spots', 'vb_to_vbd': 'spotted', 'vb_to_vbn': 'spotted', 'vb_to_jj': 'spotted', 'rb_to_jj': 'spotted', 'vb_to_vbg': 'spotting', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'nc_typical': ''},
 'spotlight': {'nn_to_nns': 'spotlights', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'spring': {'nn_to_nns': 'springs', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'sprung', 'vb_to_jj': 'sprung', 'vi_typical': '', 'v_compcl_non': '', 'v_whcl_non': '', 'n_is_nc': ''},
 'sprint': {'nn_to_nns': 'sprints', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'spur': {'nn_to_nns': 'spurs', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'spy': {'nn_to_nns': 'spies', 'n_is_nc': '', 'n_is_sb': '0', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'v_on': '', 'v_for': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'nc_typical': ''},
 'squad': {'nn_to_nns': 'squads', 'n_is_nc': '', 'n_is_sth': ''},
 'squeeze': {'nn_to_nns': 'squeezes', 'n_is_sth': '', 'n_is_sb': '2', 'v_to_vbg': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'squeezes', 'vb_to_vbd': 'squeezed', 'vb_to_vbn': 'squeezed', 'vb_to_vbg': 'squeezing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'nc_typical': ''},
 'stable': {'nn_to_nns': 'stables', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'stage': {'nn_to_nns': 'stages', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'staged', 'vb_to_jj': 'staged', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'nc_typical': ''},
 'stair': {'nn_to_nns': 'stairs', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'stall': {'nn_to_nns': 'stalls', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'stamp': {'nn_to_nns': 'stamps', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'stamped', 'v_to_vbg': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'vb_to_vbz': 'stamps', 'vb_to_vbd': 'stampped', 'vb_to_vbn': 'stampped', 'vb_to_jj': 'stamped', 'vb_to_vbg': 'stamping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'stance': {'nn_to_nns': 'stances', 'n_is_nu': '', 'n_is_sth': ''},
 'star': {'nn_to_nns': 'stars', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'stare': {'nn_to_nns': 'stares', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'vb_to_vbz': 'stares', 'vb_to_vbd': 'stared', 'vb_to_vbn': 'stared', 'vb_to_vbg': 'staring', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'start': {'nn_to_nns': 'starts', 'n_is_sth': '', 'v_vbg': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_in': '', 'vb_to_vbz': 'starts', 'vb_to_vbd': 'started', 'vb_to_vbn': 'started', 'v_n_vbg': '', 'vb_to_vbg': 'starting', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'starter': {'nn_to_nns': 'starters', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'state': {'nn_to_nns': 'states', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'states', 'vb_to_vbd': 'stated', 'vb_to_vbn': 'stated', 'vb_to_vbg': 'stating', 'vbd_eq_vbn': '', 'n_is_nc': ''},
 'statement': {'nn_to_nns': 'statements', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'state', 'nn_to_jj': 'state', 'n_is_nc': ''},
 'station': {'nn_to_nns': 'stations', 'n_is_nc': '', 'n_is_sth': ''},
 'statistic': {'nn_to_nns': 'statistics', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'statistical'},
 'statistician': {'nn_to_nns': 'statisticians', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'statistical'},
 'statue': {'nn_to_nns': 'statues', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'statute': {'nn_to_nns': 'statutes', 'n_is_nc': '', 'n_is_sth': ''},
 'stay': {'nn_to_nns': 'stays', 'n_is_sth': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'vbe': '', 'vdo': '', 'v_on': '', 'v_in': '', 'vb_to_vbz': 'stays', 'vb_to_vbd': 'stayed', 'vb_to_vbn': 'stayed', 'vb_to_vbg': 'staying', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'steal': {'nn_to_nns': 'steals', 'n_is_sth': '', 'nn_to_jj': 'stolen', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'steals', 'vb_to_vbd': 'stole', 'vb_to_vbn': 'stolen', 'vb_to_jj': 'stolen', 'vb_to_vbg': 'stealing', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'stealer': {'nn_to_nns': 'stealers', 'n_is_nc': '', 'n_is_sb': '0'},
 'steer': {'nn_to_nns': 'steers', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_jj': 'steerable', 'nn_to_rb': 'steered', 'vb_to_rb': 'steered', 'vb_to_jj': 'steerable', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'n_is_sth': '2'},
 'stem': {'nn_to_nns': 'stems', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'stemmed', 'vb_to_jj': 'stemmed', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'step': {'nn_to_nns': 'steps', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'steps', 'vb_to_vbd': 'stepped', 'vb_to_vbn': 'stepped', 'vb_to_vbg': 'steping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vi_typical': ''},
 'stern': {'nn_to_nns': 'sterns', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'jj_to_jjr': 'sterner', 'jj_to_jjs': 'sternest'},
 'stick': {'nn_to_nns': 'sticks', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'sticking', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_to': '', 'vb_to_vbz': 'sticks', 'vb_to_vbd': 'stuck', 'vb_to_vbn': 'stuck', 'vb_to_jj': 'sticking', 'vb_to_vbg': 'sticking', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'stiff': {'nn_to_nns': 'stiffs', 'n_is_sb': '0', 'jj_to_jjr': 'stiffer', 'jj_to_jjs': 'stiffest'},
 'still': {'nn_to_nns': 'stills', 'n_is_nu': '', 'n_is_sth': '', 'jj_to_jjr': 'stiller', 'jj_to_jjs': 'stillest'},
 'stir': {'nn_to_nns': 'stirs', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'stirring', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'stirs', 'vb_to_vbd': 'stirred', 'vb_to_vbn': 'stirred', 'vb_to_jj': 'stirring', 'vb_to_vbg': 'stiring', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'stock': {'nn_to_nns': 'stocks', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': ''},
 'stop': {'nn_to_nns': 'stops', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'stopped', 'v_vbg': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'stops', 'vb_to_vbd': 'stopped', 'vb_to_vbn': 'stopped', 'vb_to_jj': 'stopped', 'v_n_vbg': '', 'vb_to_vbg': 'stopping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'nc_typical': ''},
 'store': {'nn_to_nns': 'stores', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'storing', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'stores', 'vb_to_vbd': 'stored', 'vb_to_vbn': 'stored', 'vb_to_jj': 'storing', 'vb_to_vbg': 'storing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': '', 'nc_typical': ''},
 'storm': {'nn_to_nns': 'storms', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'stove': {'nn_to_nns': 'stoves', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': '', 'vbd_eq_vbn': ''},
 'strain': {'nn_to_nns': 'strains', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'stranger': {'nn_to_nns': 'strangers', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'strange', 'nc_typical': ''},
 'strategist': {'nn_to_nns': 'strategists', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'strategic', 'nn_to_rb': 'strategically'},
 'strategy': {'nn_to_nns': 'strategies', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'strategic', 'nn_to_rb': 'strategically'},
 'stream': {'nn_to_nns': 'streams', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'street': {'nn_to_nns': 'streets', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'strength': {'nn_to_nns': 'strengths', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'strengthen', 'nn_to_jj': 'strong'},
 'stress': {'nn_to_nns': 'stresses', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'stressful', 'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'stresses', 'vb_to_vbd': 'stressed', 'vb_to_vbn': 'stressed', 'vb_to_jj': 'stressful', 'vb_to_vbg': 'stressing', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vt_typical': ''},
 'strike': {'nn_to_nns': 'strikes', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'striking', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'vb_to_vbz': 'strikes', 'vb_to_vbd': 'struck', 'vb_to_vbn': 'struck', 'vb_to_jj': 'striking', 'vb_to_vbg': 'striking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'string': {'nn_to_nns': 'strings', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'stringed', 'vb_to_jj': 'stringed', 'n_is_nu': ''},
 'strip': {'nn_to_nns': 'strips', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'stripped', 'vb_to_jj': 'stripped', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'stripe': {'nn_to_nns': 'stripes', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'striped', 'vb_to_jj': 'striped'},
 'stroke': {'nn_to_nns': 'strokes', 'n_is_nc': '', 'nn_to_vb': 'strike', 'nn_to_jj': 'striking', 'vb_to_nn': 'strike', 'vb_to_jj': 'striking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'n_is_sth': '0'},
 'structure': {'nn_to_nns': 'structures', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'struggle': {'nn_to_nns': 'struggles', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'struggling', 'v_to_vb': '', 'v_to_vbg': '', 'vdo': '', 'v_on': '', 'v_with': '', 'v_for': '', 'v_against': '', 'v_to': '', 'vb_to_vbz': 'struggles', 'vb_to_vbd': 'struggled', 'vb_to_vbn': 'struggled', 'vb_to_jj': 'struggling', 'vb_to_vbg': 'struggling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': '', 'vi_typical': ''},
 'student': {'nn_to_nns': 'students', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'studio': {'nn_to_nns': 'studios', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'study': {'nn_to_nns': 'studies', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'studied', 'v_compcl': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'vb_to_vbz': 'studies', 'vb_to_vbd': 'studied', 'vb_to_vbn': 'studied', 'vb_to_jj': 'studied', 'vb_to_vbg': 'studying', 'vbd_eq_vbn': '', 'n_is_nc': ''},
 'style': {'nn_to_nns': 'styles', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'stylized', 'nn_to_rb': 'stylishly', 'vb_to_rb': 'stylishly', 'vb_to_jj': 'stylized', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'n_is_nu': ''},
 'subject': {'nn_to_nns': 'subjects', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'subsidiary': {'nn_to_nns': 'subsidiaries', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'substance': {'nn_to_nns': 'substances', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'substantial', 'nn_to_rb': 'substantially'},
 'substitute': {'nn_to_nns': 'substitutes', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_jj': 'substitutive', 'vb_to_jj': 'substitutive', 'v_compcl_non': '', 'n_is_sth': '2'},
 'suburb': {'nn_to_nns': 'suburbs', 'n_is_nu': '', 'n_is_sth': ''},
 'subway': {'nn_to_nns': 'subways', 'n_is_nc': '', 'n_is_sth': ''},
 'successor': {'nn_to_nns': 'successors', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_jj': 'successive', 'nn_to_rb': 'successively', 'n_is_sth': '2'},
 'suck': {'nn_to_nns': 'sucks', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'sucking', 'v_to_vbg': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_at': '', 'vb_to_vbz': 'sucks', 'vb_to_vbd': 'sucked', 'vb_to_vbn': 'sucked', 'vb_to_jj': 'sucking', 'vb_to_vbg': 'sucking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'suggestion': {'nn_to_nns': 'suggestions', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'suggest', 'nn_to_jj': 'suggested'},
 'suit': {'nn_to_nns': 'suits', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'suited', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'suits', 'vb_to_vbd': 'suited', 'vb_to_vbn': 'suited', 'vb_to_jj': 'suited', 'vb_to_vbg': 'suiting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': '', 'be_nn_in.nn_to_jj': ''},
 'suitcase': {'nn_to_nns': 'suitcases', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'suite': {'nn_to_nns': 'suites', 'n_is_nc': ''},
 'sum': {'nn_to_nns': 'sums', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'summing', 'vb_to_jj': 'summing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'summer': {'nn_to_nns': 'summers', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'superintendent': {'nn_to_nns': 'superintendents', 'n_is_nc': '', 'n_is_sb': '0'},
 'superior': {'nn_to_nns': 'superiors', 'n_is_nc': '', 'n_is_sb': '0', 'be_jj_to_vbg': '', 'nc_typical': ''},
 'supermarket': {'nn_to_nns': 'supermarkets', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'supervisor': {'nn_to_nns': 'supervisors', 'n_is_nc': '', 'n_is_sb': '0'},
 'supplier': {'nn_to_nns': 'suppliers', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'supply', 'nn_to_jj': 'supplied'},
 'supply': {'nn_to_nns': 'supplies', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'supplied', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'supplies', 'vb_to_vbd': 'supplied', 'vb_to_vbn': 'supplied', 'vb_to_jj': 'supplied', 'vb_to_vbg': 'supplying', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'support': {'nn_to_nns': 'supports', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'supported', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'supports', 'vb_to_vbd': 'supported', 'vb_to_vbn': 'supported', 'vb_to_jj': 'supported', 'vb_to_vbg': 'supporting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'supporter': {'nn_to_nns': 'supporters', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'support', 'nn_to_jj': 'supported'},
 'surge': {'nn_to_nns': 'surges', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'surgeon': {'nn_to_nns': 'surgeons', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'surgery': {'nn_to_nns': 'surgeries', 'n_is_nc': '', 'n_is_sth': ''},
 'surname': {'nn_to_nns': 'surnames', 'n_is_sth': ''},
 'survey': {'nn_to_nns': 'surveys', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'survival': {'nn_to_nns': 'survivals', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'survive', 'nn_to_jj': 'survived'},
 'survivor': {'nn_to_nns': 'survivors', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_vb': 'survive', 'nn_to_jj': 'survived', 'n_is_sth': '2'},
 'suspect': {'nn_to_nns': 'suspects', 'n_is_nc': '', 'n_is_sb': '0', 'v_compcl': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'suspects', 'vb_to_vbd': 'suspected', 'vb_to_vbn': 'suspected', 'vb_to_vbg': 'suspecting', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'suspension': {'nn_to_nns': 'suspensions', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'suspend', 'nn_to_jj': 'suspended'},
 'suspicion': {'nn_to_nns': 'suspicions', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'suspicious', 'nn_to_rb': 'suspiciously', 'vb_to_rb': 'suspiciously', 'vb_to_jj': 'suspicious'},
 'swallow': {'nn_to_nns': 'swallows', 'n_is_nc': '', 'n_is_sb': '2', 'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'n_is_sth': '2'},
 'sweater': {'nn_to_nns': 'sweaters', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_vb': 'sweat', 'nn_to_jj': 'sweated', 'nc_typical': '', 'n_is_sth': '2'},
 'sweep': {'nn_to_nns': 'sweeps', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'swept', 'v_to_vbg': '', 'v_n': '', 'v_n_jj': '', 'vb_to_vbz': 'sweeps', 'vb_to_vbd': 'swept', 'vb_to_vbn': 'swept', 'vb_to_jj': 'swept', 'vb_to_vbg': 'sweeping', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'swift': {'nn_to_nns': 'swifts', 'n_is_nc': '', 'n_is_sb': '2', 'be_jj_to_vb': '', 'n_is_sth': '2', 'jj_to_jjr': 'swifter', 'jj_to_jjs': 'swiftest'},
 'swimmer': {'nn_to_nns': 'swimmers', 'n_is_nc': '', 'n_is_sb': '0'},
 'symbol': {'nn_to_nns': 'symbols', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'symbolise', 'nn_to_jj': 'symbolic', 'nn_to_rb': 'symbolically', 'nc_typical': ''},
 'system': {'nn_to_nns': 'systems', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'systematic', 'nn_to_rb': 'systematically'},
 'table': {'nn_to_nns': 'tables', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'tablet': {'nn_to_nns': 'tablets', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'tail': {'nn_to_nns': 'tails', 'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': '', 'n_is_sth': '2'},
 'tailor': {'nn_to_nns': 'tailors', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'tailored', 'vb_to_jj': 'tailored', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'tale': {'nn_to_nns': 'tales', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'talk': {'nn_to_nns': 'talks', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'talking', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'v_n_jj': '', 'vdo': '', 'v_at': '', 'v_with': '', 'v_about': '', 'v_of': '', 'v_to': '', 'vb_to_vbz': 'talks', 'vb_to_vbd': 'talked', 'vb_to_vbn': 'talked', 'vb_to_jj': 'talking', 'vb_to_vbg': 'talking', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'tank': {'nn_to_nns': 'tanks', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'tap': {'nn_to_nns': 'taps', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'tapped', 'vb_to_jj': 'tapped', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'target': {'nn_to_nns': 'targets', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'targeted', 'vb_to_jj': 'targeted', 'v_compcl_non': '', 'vt_typical': '', 'nc_typical': ''},
 'task': {'nn_to_nns': 'tasks', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'tax': {'nn_to_nns': 'taxes', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'taxable', 'nn_to_rb': 'taxably', 'vb_to_rb': 'taxably', 'vb_to_jj': 'taxable', 'vbd_eq_vbn': '', 'n_is_nc': ''},
 'taxi': {'nn_to_nns': 'taxis', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'tea': {'nn_to_nns': 'teas', 'n_is_nu': '', 'n_is_sth': ''},
 'teacher': {'nn_to_nns': 'teachers', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'teach', 'nc_typical': ''},
 'teaching': {'nn_to_nns': 'teachings', 'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'teach', 'vbg_to_vbn': 'teached'},
 'team': {'nn_to_nns': 'teams', 'n_is_nc': '', 'n_is_sth': '', 'n_is_collective': '', 'vbd_eq_vbn': '', 'nc_typical': '', 'spell_err': 'term', 'n_of_nns': ''},
 'teammate': {'nn_to_nns': 'teammates', 'n_is_nc': '', 'n_is_sb': '0'},
 'tear': {'nn_to_nns': 'tears', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'tearing', 'v_to_vbg': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'vb_to_vbz': 'tears', 'vb_to_vbd': 'tore', 'vb_to_vbn': 'torn', 'vb_to_jj': 'tearing', 'vb_to_vbg': 'tearing', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'nc_typical': ''},
 'technique': {'nn_to_nns': 'techniques', 'n_is_nc': '', 'n_is_sth': ''},
 'technology': {'nn_to_nns': 'technologies', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'technological', 'nn_to_rb': 'technologically', 'nu_typical': '', 'n_is_nc': ''},
 'tee': {'nn_to_nns': 'tees', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'teen': {'nn_to_nns': 'teens', 'n_is_nc': ''},
 'telecom': {'nn_to_nns': 'telecoms', 'n_is_nu': '', 'n_is_sth': ''},
 'telephone': {'nn_to_nns': 'telephones', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_whcl_non': ''},
 'telescope': {'nn_to_nns': 'telescopes', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'television': {'nn_to_nns': 'televisions', 'n_is_nc': '', 'n_is_sth': ''},
 'temperature': {'nn_to_nns': 'temperatures', 'n_is_nu': '', 'n_is_sth': ''},
 'temple': {'nn_to_nns': 'temples', 'n_is_sth': '', 'nc_typical': ''},
 'tension': {'nn_to_nns': 'tensions', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'tense', 'nn_to_jj': 'tense', 'nn_to_rb': 'tensely', 'vb_to_rb': 'tensely', 'vb_to_nn': 'tense', 'vb_to_jj': 'tense'},
 'tent': {'nn_to_nns': 'tents', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'term': {'nn_to_nns': 'terms', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'territory': {'nn_to_nns': 'territories', 'n_is_nc': '', 'n_is_sth': ''},
 'terror': {'nn_to_nns': 'terrors', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_vb': 'terrify', 'n_is_sth': '2'},
 'terrorist': {'nn_to_nns': 'terrorists', 'n_is_nc': '', 'n_is_sb': '0'},
 'test': {'nn_to_nns': 'tests', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'tested', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'tests', 'vb_to_vbd': 'tested', 'vb_to_vbn': 'tested', 'vb_to_jj': 'tested', 'vb_to_vbg': 'testing', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'testimony': {'nn_to_nns': 'testimonies', 'n_is_nc': '', 'n_is_sth': ''},
 'text': {'nn_to_nns': 'texts', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'textual', 'nn_to_rb': 'textually', 'vb_to_vbz': 'texts', 'vb_to_vbd': 'texted', 'vb_to_vbn': 'texted', 'vb_to_rb': 'textually', 'vb_to_jj': 'textual', 'vb_to_vbg': 'texting', 'vbd_eq_vbn': ''},
 'thanksgiving': {'nn_to_nns': 'thanksgivings', 'n_is_sth': ''},
 'theater': {'nn_to_nns': 'theaters', 'n_is_nc': '', 'n_is_sth': ''},
 'theft': {'nn_to_nns': 'thefts', 'n_is_nu': '', 'n_is_sth': ''},
 'theory': {'nn_to_nns': 'theories', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'theoretical', 'nn_to_rb': 'theoretically'},
 'therapy': {'nn_to_nns': 'therapies', 'n_is_nc': '', 'n_is_sth': ''},
 'thing': {'nn_to_nns': 'things', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'thought': {'nn_to_nns': 'thoughts', 'n_is_sth': '', 'nn_to_vb': 'think', 'nn_to_jj': 'think', 'nn_to_rb': 'thoughtfully', 'vbd_to_vb': 'think', 'vbn_to_vb': 'think', 'vbn_to_vbg': 'thinking', 'vbd_eq_vbn': ''},
 'thousand': {'nn_to_nns': 'thousands', 'n_is_sth': '', 'nn_to_jj': 'thousandth'},
 'threat': {'nn_to_nns': 'threats', 'n_is_nu': '', 'nn_to_jj': 'threatened', 'vb_to_jj': 'threatened', 'n_is_sth': '2', 'n_is_nc': 'noun_attr'},
 'throat': {'nn_to_nns': 'throats', 'n_is_nc': '', 'n_is_sth': ''},
 'thumb': {'nn_to_nns': 'thumbs', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'ticket': {'nn_to_nns': 'tickets', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'tide': {'nn_to_nns': 'tides', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'tidal', 'vb_to_jj': 'tidal', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'tie': {'nn_to_nns': 'ties', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'untie', 'nn_to_jj': 'tieless', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_with': '', 'v_for': '', 'vb_to_vbz': 'ties', 'vb_to_vbd': 'tied', 'vb_to_vbn': 'tied', 'vb_to_jj': 'tieless', 'vb_to_vbg': 'tying', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'nc_typical': ''},
 'tiger': {'nn_to_nns': 'tigers', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'tile': {'nn_to_nns': 'tiles', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'timetable': {'nn_to_nns': 'timetables', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'tip': {'nn_to_nns': 'tips', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_n': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'tips', 'vb_to_vbd': 'tipped', 'vb_to_vbn': 'tipped', 'vb_to_vbg': 'tiping', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'tire': {'nn_to_nns': 'tires', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'tired', 'nn_to_rb': 'tiredly', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'v_of': '', 'vb_to_rb': 'tiredly', 'vb_to_jj': 'tired', 'v_whcl_non': '', 'nc_typical': ''},
 'tissue': {'nn_to_nns': 'tissues', 'n_is_nc': '', 'n_is_sth': ''},
 'title': {'nn_to_nns': 'titles', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'toe': {'nn_to_nns': 'toes', 'n_is_nc': '', 'n_is_sth': ''},
 'toll': {'nn_to_nns': 'tolls', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'ton': {'nn_to_nns': 'tons', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'tonne': {'nn_to_nns': 'tonnes', 'n_is_nc': '', 'n_is_sth': ''},
 'tool': {'nn_to_nns': 'tools', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'top': {'nn_to_nns': 'tops', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'nns_exp_exc': ''},
 'topic': {'nn_to_nns': 'topics', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'topical', 'nn_to_rb': 'topically', 'nc_typical': ''},
 'torture': {'nn_to_nns': 'tortures', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'touch': {'nn_to_nns': 'touchs', 'n_is_nu': '', 'nn_to_jj': 'touchable', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_at': '', 'vb_to_vbz': 'touches', 'vb_to_vbd': 'touched', 'vb_to_vbn': 'touched', 'vb_to_jj': 'touchable', 'vb_to_vbg': 'touching', 'vbd_eq_vbn': '', 'n_is_nc': ''},
 'tour': {'nn_to_nns': 'tours', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'tourist': {'nn_to_nns': 'tourists', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'tournament': {'nn_to_nns': 'tournaments', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'towel': {'nn_to_nns': 'towels', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'tower': {'nn_to_nns': 'towers', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'town': {'nn_to_nns': 'towns', 'n_is_nc': '', 'n_is_sth': ''},
 'toy': {'nn_to_nns': 'toys', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'trace': {'nn_to_nns': 'traces', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'traceless', 'vb_to_jj': 'traceless', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'track': {'nn_to_nns': 'tracks', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'tracking': {'nn_to_nns': 'trackings', 'n_is_nu': ''},
 'trademark': {'nn_to_nns': 'trademarks', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'trader': {'nn_to_nns': 'traders', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'trade', 'nn_to_jj': 'tradable'},
 'traffic': {'nn_to_nns': 'traffics', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'vbg_non': '', 'nu_typical': ''},
 'tragedy': {'nn_to_nns': 'tragedies', 'n_is_nc': '', 'n_is_sth': ''},
 'trail': {'nn_to_nns': 'trails', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'trailer': {'nn_to_nns': 'trailers', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'train': {'nn_to_nns': 'trains', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_n': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_for': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'trainer': {'nn_to_nns': 'trainers', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_vb': 'train', 'nc_typical': '', 'n_is_sth': '2'},
 'transformation': {'nn_to_nns': 'transformations', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'transform', 'nn_to_jj': 'transformational', 'nn_to_rb': 'transformationally'},
 'transition': {'nn_to_nns': 'transitions', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'transit', 'nn_to_jj': 'transitory', 'nn_to_rb': 'transitionally', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'transmission': {'nn_to_nns': 'transmissions', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'transmit', 'nn_to_jj': 'transmissive', 'nn_to_rb': 'transmissively'},
 'transplant': {'nn_to_nns': 'transplants', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'transport': {'nn_to_nns': 'transports', 'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'v_from': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'trap': {'nn_to_nns': 'traps', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': '', 'nc_typical': ''},
 'traveller': {'nn_to_nns': 'travellers', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'travel', 'nn_to_jj': 'travelled', 'nc_typical': ''},
 'tray': {'nn_to_nns': 'trays', 'n_is_nc': '', 'n_is_sth': ''},
 'treasury': {'nn_to_nns': 'treasuries', 'n_is_nc': '', 'n_is_sth': '0'},
 'treat': {'nn_to_nns': 'treats', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'treated', 'v_to_vbg': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_of': '', 'vb_to_vbz': 'treats', 'vb_to_vbd': 'treated', 'vb_to_vbn': 'treated', 'vb_to_jj': 'treated', 'vb_to_vbg': 'treating', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'treaty': {'nn_to_nns': 'treaties', 'n_is_nc': '', 'n_is_sth': ''},
 'tree': {'nn_to_nns': 'trees', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'trend': {'nn_to_nns': 'trends', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'triangle': {'nn_to_nns': 'triangles', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'tribe': {'nn_to_nns': 'tribes', 'n_is_nc': '', 'n_is_sth': ''},
 'tribunal': {'nn_to_nns': 'tribunals', 'n_is_nc': '', 'n_is_sth': ''},
 'tribute': {'nn_to_nns': 'tributes', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'trick': {'nn_to_nns': 'tricks', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'trickish', 'vb_to_jj': 'trickish', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'trigger': {'nn_to_nns': 'triggers', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'trim': {'nn_to_nns': 'trims', 'n_is_nu': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'jj_to_jjr': 'trimmer', 'jj_to_jjs': 'trimmest'},
 'trip': {'nn_to_nns': 'trips', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'nc_typical': ''},
 'triumph': {'nn_to_nns': 'triumphs', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'troop': {'nn_to_nns': 'troops', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'nsubjpass': '', 'v_compcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'trophy': {'nn_to_nns': 'trophies', 'n_is_nc': '', 'n_is_sth': ''},
 'trouble': {'nn_to_nns': 'troubles', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'troublesome', 'nn_to_rb': 'troublesomely', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'v_about': '', 'vb_to_rb': 'troublesomely', 'vb_to_jj': 'troublesome', 'n_is_nc': '', 'vbd_eq_vbn': '', 'v_whcl_non': ''},
 'truck': {'nn_to_nns': 'trucks', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'truth': {'nn_to_nns': 'truths', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'TRUE', 'nn_to_rb': 'truly', 'n_is_nc': ''},
 'tube': {'nn_to_nns': 'tubes', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'tuition': {'nn_to_nns': 'tuitions', 'n_is_nu': '', 'n_is_sth': ''},
 'tulip': {'nn_to_nns': 'tulips', 'n_is_nc': '', 'n_is_sth': ''},
 'tune': {'nn_to_nns': 'tunes', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'tuneless', 'nn_to_rb': 'tunelessly', 'vb_to_rb': 'tunelessly', 'vb_to_jj': 'tuneless', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'tunnel': {'nn_to_nns': 'tunnels', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'turf': {'nn_to_nns': 'turfs', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'turn': {'nn_to_nns': 'turns', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'turned', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vbe': '', 'vdo': '', 'v_on': '', 'v_in': '', 'v_about': '', 'v_to': '', 'vb_to_vbz': 'turns', 'vb_to_vbd': 'turned', 'vb_to_vbn': 'turned', 'vb_to_jj': 'turned', 'vb_to_vbg': 'turning', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'turner': {'nn_to_nns': 'turners', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'turnout': {'nn_to_nns': 'turnouts', 'n_is_nc': '', 'n_is_sth': ''},
 'turnover': {'nn_to_nns': 'turnovers', 'n_is_nc': '', 'n_is_sth': ''},
 'twin': {'nn_to_nns': 'twins', 'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'twist': {'nn_to_nns': 'twists', 'n_is_nc': '', 'n_is_sth': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'twists', 'vb_to_vbd': 'twisted', 'vb_to_vbn': 'twisted', 'vb_to_vbg': 'twisting', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'type': {'nn_to_nns': 'types', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_n': '', 'nsubjpass': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'typist': {'nn_to_nns': 'typists', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'tyre': {'nn_to_nns': 'tyres', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'umbrella': {'nn_to_nns': 'umbrellas', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'uncle': {'nn_to_nns': 'uncles', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nc_typical': ''},
 'underground': {'nn_to_nns': 'undergrounds', 'n_is_sth': '', 'art_an': ''},
 'understanding': {'nn_to_nns': 'understandings', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbg_to_vb': 'understand', 'vbg_to_vbn': 'understood', 'n_is_nc': '', 'n_usu_singular': ''},
 'union': {'nn_to_nns': 'unions', 'n_is_nc': '', 'n_is_sth': '', 'n_is_collective': ''},
 'unit': {'nn_to_nns': 'units', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'unity': {'nn_to_nns': 'unities', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'unite', 'nn_to_jj': 'unitive', 'nn_to_rb': 'unitively'},
 'universe': {'nn_to_nns': 'universes', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'universal', 'nn_to_rb': 'universally'},
 'university': {'nn_to_nns': 'universities', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'unknown': {'nn_to_nns': 'unknowns', 'n_is_nc': '', 'art_an': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'update': {'nn_to_nns': 'updates', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'vt_typical': '', 'nc_typical': ''},
 'upgrade': {'nn_to_nns': 'upgrades', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'upper': {'nn_to_nns': 'uppers', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'urge': {'nn_to_nns': 'urges', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'urgent', 'nn_to_rb': 'urgently', 'v_compcl': '', 'v_vbg': '', 'v_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'urges', 'vb_to_vbd': 'urged', 'vb_to_vbn': 'urged', 'vb_to_rb': 'urgently', 'vb_to_jj': 'urgent', 'vb_to_vbg': 'urging', 'vbd_eq_vbn': '', 'v_whcl_non': '', 'vt_typical': ''},
 'urgency': {'nn_to_nns': 'urgencies', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'urge', 'nn_to_jj': 'urgent', 'nn_to_rb': 'urgently'},
 'user': {'nn_to_nns': 'users', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'use', 'nn_to_jj': 'useful', 'nn_to_rb': 'usefully', 'nc_typical': ''},
 'utility': {'nn_to_nns': 'utilities', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'utilize', 'nn_to_jj': 'utilisable'},
 'vacation': {'nn_to_nns': 'vacations', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vb_to_vbz': 'vacations', 'vb_to_vbd': 'vacationed', 'vb_to_vbn': 'vacationed', 'vb_to_vbg': 'vacationing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'vaccine': {'nn_to_nns': 'vaccines', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'valentine': {'nn_to_nns': 'valentines', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'valley': {'nn_to_nns': 'valleys', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'value': {'nn_to_nns': 'values', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'valuable', 'nn_to_rb': 'valuably', 'vb_to_rb': 'valuably', 'vb_to_jj': 'valuable', 'nn_to_vbn': 'valued', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'van': {'nn_to_nns': 'vans', 'n_is_nc': '', 'n_is_sth': ''},
 'variety': {'nn_to_nns': 'varieties', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'various', 'n_of_nns': ''},
 'vehicle': {'nn_to_nns': 'vehicles', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'venture': {'nn_to_nns': 'ventures', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'verdict': {'nn_to_nns': 'verdicts', 'n_is_nc': '', 'n_is_sth': ''},
 'verge': {'nn_to_nns': 'verges', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'version': {'nn_to_nns': 'versions', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'vet': {'nn_to_nns': 'vets', 'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'veteran': {'nn_to_nns': 'veterans', 'n_is_nc': '', 'n_is_sb': '0'},
 'victim': {'nn_to_nns': 'victims', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'victory': {'nn_to_nns': 'victories', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'victorious', 'nn_to_rb': 'victoriously'},
 'video': {'nn_to_nns': 'videos', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'videotape': {'nn_to_nns': 'videotapes', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'view': {'nn_to_nns': 'views', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'village': {'nn_to_nns': 'villages', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'villagey', 'vb_to_jj': 'villagey', 'nc_typical': ''},
 'violation': {'nn_to_nns': 'violations', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'violate', 'nn_to_jj': 'violable', 'nn_to_rb': 'violably'},
 'violet': {'nn_to_nns': 'violets', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'visa': {'nn_to_nns': 'visas', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'vision': {'nn_to_nns': 'visions', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'visional', 'nn_to_rb': 'visionally', 'vb_to_rb': 'visionally', 'vb_to_jj': 'visional'},
 'visit': {'nn_to_nns': 'visits', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'visits', 'vb_to_vbd': 'visited', 'vb_to_vbn': 'visited', 'vb_to_vbg': 'visiting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'visitor': {'nn_to_nns': 'visitors', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'vocal': {'nn_to_nns': 'vocals', 'n_is_nc': '', 'n_is_sth': ''},
 'volleyball': {'nn_to_nns': 'volleyballs', 'n_is_nu': '', 'n_is_sth': ''},
 'volume': {'nn_to_nns': 'volumes', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'volunteer': {'nn_to_nns': 'volunteers', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'voluntary', 'nn_to_rb': 'voluntarily', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'v_for': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'vote': {'nn_to_nns': 'votes', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'votable', 'v_to_vb': '', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'v_n_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_for': '', 'v_against': '', 'vb_to_vbz': 'votes', 'vb_to_vbd': 'voted', 'vb_to_vbn': 'voted', 'vb_to_jj': 'votable', 'vb_to_vbg': 'voting', 'vbd_eq_vbn': ''},
 'voter': {'nn_to_nns': 'voters', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'vote', 'nn_to_jj': 'votable'},
 'wage': {'nn_to_nns': 'wages', 'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'waist': {'nn_to_nns': 'waists', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'waiter': {'nn_to_nns': 'waiters', 'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'wake': {'nn_to_nns': 'wakes', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'wakes', 'vb_to_vbd': 'woke', 'vb_to_vbn': 'waken', 'vb_to_vbg': 'waking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'walk': {'nn_to_nns': 'walks', 'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'walks', 'vb_to_vbd': 'walked', 'vb_to_vbn': 'walked', 'vb_to_vbg': 'walking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'walking': {'nn_to_nns': 'walkings', 'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'walk', 'vbg_to_vbn': 'walked'},
 'wall': {'nn_to_nns': 'walls', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'wallet': {'nn_to_nns': 'wallets', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'war': {'nn_to_nns': 'wars', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'ward': {'nn_to_nns': 'wards', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'wardrobe': {'nn_to_nns': 'wardrobes', 'n_is_nc': '', 'n_is_sth': ''},
 'warehouse': {'nn_to_nns': 'warehouses', 'n_is_nc': '', 'n_is_sth': ''},
 'warning': {'nn_to_nns': 'warnings', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'warn', 'vbg_to_vbn': 'warned'},
 'warrant': {'nn_to_nns': 'warrants', 'n_is_nc': '', 'n_is_sth': '', 'v_whcl_non': '', 'vbg_non': ''},
 'watermelon': {'nn_to_nns': 'watermelons', 'n_is_nc': '', 'n_is_sth': ''},
 'wave': {'nn_to_nns': 'waves', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'waveless', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_to': '', 'vb_to_vbz': 'waves', 'vb_to_vbd': 'waved', 'vb_to_vbn': 'waved', 'vb_to_jj': 'waveless', 'vb_to_vbg': 'waving', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'way': {'nn_to_nns': 'ways', 'n_is_nc': '', 'n_is_sth': ''},
 'weakness': {'nn_to_nns': 'weaknesses', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'weaken', 'nn_to_jj': 'weak', 'nn_to_rb': 'weakly'},
 'weapon': {'nn_to_nns': 'weapons', 'n_is_nc': '', 'n_is_sth': ''},
 'web': {'nn_to_nns': 'webs', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'website': {'nn_to_nns': 'websites', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'wedding': {'nn_to_nns': 'weddings', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'week': {'nn_to_nns': 'weeks', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'weekly', 'nn_to_rb': 'weekly', 'nc_typical': '', 'quantifier': ''},
 'weekend': {'nn_to_nns': 'weekends', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'weekly', 'nn_to_rb': 'weekly', 'nc_typical': ''},
 'weird': {'nn_to_nns': 'weirds', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2', 'jj_to_jjr': 'weirder', 'jj_to_jjs': 'weirdest'},
 'weld': {'nn_to_nns': 'welds', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'well': {'nn_to_nns': 'wells', 'n_is_nc': '', 'n_is_sth': '', 'rb_to_jj': 'good', 'vbd_eq_vbn': '', 'v_pass_non': ''},
 'western': {'nn_to_nns': 'westerns', 'n_is_nc': '', 'n_is_sth': ''},
 'wheel': {'nn_to_nns': 'wheels', 'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'widow': {'nn_to_nns': 'widows', 'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'willow': {'nn_to_nns': 'willows', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'win': {'nn_to_nns': 'wins', 'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'winnable', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_at': '', 'v_against': '', 'vb_to_vbz': 'wins', 'vb_to_vbd': 'won', 'vb_to_vbn': 'won', 'vb_to_jj': 'winnable', 'vb_to_vbg': 'winning', 'v_compcl_non': ''},
 'window': {'nn_to_nns': 'windows', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'wing': {'nn_to_nns': 'wings', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'winner': {'nn_to_nns': 'winners', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'win', 'nn_to_jj': 'winnable', 'nc_typical': ''},
 'wire': {'nn_to_nns': 'wires', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'wireless', 'nn_to_rb': 'wirelessly', 'v_compcl': '', 'vb_to_rb': 'wirelessly', 'vb_to_jj': 'wireless', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'wit': {'nn_to_nns': 'wits', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'withdrawal': {'nn_to_nns': 'withdrawals', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'wolf': {'nn_to_nns': 'wolves', 'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'wood': {'nn_to_nns': 'woods', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '2', 'nn_to_vb': 'wooden', 'nn_to_jj': 'woody', 'n_is_sth': '2'},
 'word': {'nn_to_nns': 'words', 'n_is_nc': '', 'n_is_sb': '2', 'nn_to_jj': 'wordless', 'nn_to_rb': 'wordlessly', 'vb_to_rb': 'wordlessly', 'vb_to_jj': 'wordless', 'vbd_eq_vbn': '', 'n_is_sth': '2'},
 'work': {'nn_to_nns': 'works', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'workless', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_at': '', 'v_in': '', 'v_for': '', 'v_against': '', 'vb_to_vbz': 'works', 'vb_to_vbd': 'worked', 'vb_to_vbn': 'worked', 'vb_to_jj': 'workless', 'vb_to_vbg': 'working', 'nn_to_vbg': 'working', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'worker': {'nn_to_nns': 'workers', 'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'work', 'nn_to_jj': 'workless', 'nc_typical': ''},
 'workplace': {'nn_to_nns': 'workplaces', 'n_is_nc': '', 'n_is_sth': ''},
 'workshop': {'nn_to_nns': 'workshops', 'n_is_nc': '', 'n_is_sth': ''},
 'wound': {'nn_to_nns': 'wounds', 'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'wounds', 'vb_to_vbd': 'wounded', 'vb_to_vbn': 'wounded', 'vb_to_vbg': 'wounding', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'vt_typical': ''},
 'wrap': {'nn_to_nns': 'wraps', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'wraps', 'vb_to_vbd': 'wraped', 'vb_to_vbn': 'wraped', 'vb_to_vbg': 'wrapping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'wrist': {'nn_to_nns': 'wrists', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'writer': {'nn_to_nns': 'writers', 'n_is_nc': '', 'n_is_sb': '0'},
 'writing': {'nn_to_nns': 'writings', 'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'write', 'vbg_to_vbn': 'written'},
 'wrongdoing': {'nn_to_nns': 'wrongdoings', 'n_is_nu': '', 'n_is_sth': ''},
 'yard': {'nn_to_nns': 'yards', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': '', 'quantifier': ''},
 'yawn': {'nn_to_nns': 'yawns', 'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'year': {'nn_to_nns': 'years', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': '', 'bit_to_seg': '_year', 'quantifier': ''},
 'yellow': {'nn_to_nns': 'yellows', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'yellowish', 'vbd_eq_vbn': ''},
 'youth': {'nn_to_nns': 'youths', 'n_is_nu': '', 'n_is_sb': '0', 'nn_to_vb': 'youthen', 'nn_to_jj': 'youthful', 'nn_to_rb': 'youthfully', 'n_is_collective': ''},
 'zone': {'nn_to_nns': 'zones', 'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'zoologist': {'nn_to_nns': 'zoologists', 'n_is_nc': '', 'n_is_sb': '0'},
 'heir': {'nn_to_nns': 'heirs', 'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'sightseeing': {'nn_to_nns': 'sightseeings', 'n_is_nu': '', 'nu_typical': ''},
 'adulthood': {'nn_to_nns': 'adulthoods', 'n_is_nu': '', 'art_an': ''},
 'benefit': {'nn_to_nns': 'benefits', 'n_is_nc': '', 'n_is_nu': '', 'nn_to_jj': 'beneficial', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'v_from': '', 'vb_to_jj': 'beneficial', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'paper': {'nn_to_nns': 'papers', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'sorrow': {'nn_to_nns': 'sorrows', 'n_is_nc': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_nu': ''},
 'abacuses': {'nns_to_nn': 'abacus'},
 'echoes': {'nns_to_nn': 'echo'},
 'embargoes': {'nns_to_nn': 'embargo'},
 'heroes': {'nns_to_nn': 'hero'},
 'negroes': {'nns_to_nn': 'negro'},
 'potatoes': {'nns_to_nn': 'potato'},
 'tomatoes': {'nns_to_nn': 'tomato'},
 'torpedoes': {'nns_to_nn': 'torpedo'},
 'vetoes': {'nns_to_nn': 'veto'},
 'actresses': {'nns_to_nn': 'actress'},
 'beaches': {'nns_to_nn': 'beach', 'vbz_to_vb': 'beach'},
 'bonuses': {'nns_to_nn': 'bonus'},
 'bosses': {'nns_to_nn': 'boss', 'vbz_to_vb': 'boss'},
 'boxes': {'nns_to_nn': 'box'},
 'branches': {'nns_to_nn': 'branch', 'vbz_to_vb': 'branch'},
 'bunches': {'nns_to_nn': 'bunch', 'vbz_to_vb': 'bunch'},
 'bushes': {'nns_to_nn': 'bush'},
 'classes': {'nns_to_nn': 'class'},
 'complexes': {'nns_to_nn': 'complex'},
 'crashes': {'nns_to_nn': 'crash', 'vbz_to_vb': 'crash'},
 'dishes': {'nns_to_nn': 'dish', 'vbz_to_vb': 'dish'},
 'fixes': {'nns_to_nn': 'fix'},
 'glasses': {'nns_to_nn': 'glass', 'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'glass'},
 'grosses': {'nns_to_nn': 'gross'},
 'guesses': {'nns_to_nn': 'guess', 'vbz_to_vb': 'guess'},
 'headmistresses': {'nns_to_nn': 'headmistress'},
 'inches': {'nns_to_nn': 'inch', 'vbz_to_vb': 'inch'},
 'indexes': {'nns_to_nn': 'index', 'vbz_to_vb': 'index'},
 'kisses': {'nns_to_nn': 'kiss', 'vbz_to_vb': 'kiss'},
 'launches': {'nns_to_nn': 'launch', 'vbz_to_vb': 'launch'},
 'matches': {'nns_to_nn': 'match', 'vbz_to_vb': 'match'},
 'passes': {'nns_to_nn': 'pass', 'vbz_to_vb': 'pass'},
 'peaches': {'nns_to_nn': 'peach'},
 'presses': {'nns_to_nn': 'press', 'vbz_to_vb': 'press'},
 'princesses': {'nns_to_nn': 'princess'},
 'processes': {'nns_to_nn': 'process'},
 'sandwiches': {'nns_to_nn': 'sandwich', 'vbz_to_vb': 'sandwich'},
 'scratches': {'nns_to_nn': 'scratch', 'vbz_to_vb': 'scratch'},
 'searches': {'nns_to_nn': 'search', 'vbz_to_vb': 'search'},
 'smashes': {'nns_to_nn': 'smash'},
 'stomaches': {'nns_to_nn': 'stomach'},
 'switches': {'nns_to_nn': 'switch', 'vbz_to_vb': 'switch'},
 'viruses': {'nns_to_nn': 'virus'},
 'waitresses': {'nns_to_nn': 'waitress'},
 'watches': {'nns_to_nn': 'watch', 'vbz_to_vb': 'watch'},
 'wishes': {'nns_to_nn': 'wish', 'vbz_to_vb': 'wish'},
 'chairmen': {'nns_to_nn': 'chairman', 'nc_typical': ''},
 'children': {'nns_to_nn': 'child', 'nc_typical': '', 'n_is_sb': '0'},
 'craftsmen': {'nns_to_nn': 'craftsman'},
 'crises': {'nns_to_nn': 'crisis'},
 'critera': {'nns_to_nn': 'criterion'},
 'data': {'nns_to_nn': 'datum', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_collective': ''},
 'fishermen': {'nns_to_nn': 'fisherman'},
 'feet': {'nns_to_nn': 'foot'},
 'gentlemen': {'nns_to_nn': 'gentleman'},
 'grandchildren': {'nns_to_nn': 'grandchild'},
 'mailmen': {'nns_to_nn': 'mailman'},
 'men': {'nns_to_nn': 'man', 'n_is_nc': '', 'n_is_sb': '0'},
 'maxima': {'nns_to_nn': 'maximum'},
 'media': {'nns_to_nn': 'medium', 'n_is_collective': ''},
 'mice': {'nns_to_nn': 'mouse'},
 'penaltiese': {'nns_to_nn': 'penalty'},
 'policemen': {'nns_to_nn': 'policeman'},
 'postmen': {'nns_to_nn': 'postman'},
 'salesmen': {'nns_to_nn': 'salesman'},
 'seamen': {'nns_to_nn': 'seaman'},
 'spokesmen': {'nns_to_nn': 'spokesman'},
 'sportmen': {'nns_to_nn': 'sportman'},
 'teeth': {'nns_to_nn': 'tooth', 'n_is_nc': '', 'n_is_sth': ''},
 'women': {'nns_to_nn': 'woman'},
 'addenda': {'nns_to_nn': 'addendum'},
 'agenda': {'nns_to_nn': 'agendum', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'algae': {'nns_to_nn': 'alga', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '3'},
 'alumnae': {'nns_to_nn': 'alumna'},
 'alumni': {'nns_to_nn': 'alumnus'},
 'amoebae': {'nns_to_nn': 'amoeba'},
 'analyses': {'nns_to_nn': 'analysis', 'vbz_to_vb': 'analyse'},
 'antennae': {'nns_to_nn': 'antenna'},
 'apexes': {'nns_to_nn': 'apex'},
 'appendixes': {'nns_to_nn': 'appendix'},
 'automata': {'nns_to_nn': 'automaton'},
 'axes': {'nns_to_nn': 'axis'},
 'bacilli': {'nns_to_nn': 'bacillus', 'n_is_sb': '3', 'n_is_sth': '3'},
 'bacteria': {'nns_to_nn': 'bacterium', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'n_is_collective': '', 'nc_typical': ''},
 'bases': {'nns_to_nn': 'basis', 'vbz_to_vb': 'base'},
 'beaux': {'nns_to_nn': 'beau'},
 'buffalos': {'nns_to_nn': 'buffalo'},
 'bureaus': {'nns_to_nn': 'bureau'},
 'cactuses': {'nns_to_nn': 'cactus'},
 'calves': {'nns_to_nn': 'calf'},
 'cargos': {'nns_to_nn': 'cargo'},
 'cervixes': {'nns_to_nn': 'cervix'},
 'cherubim': {'nns_to_nn': 'cherub'},
 'commandoes': {'nns_to_nn': 'commando'},
 'concerti': {'nns_to_nn': 'concerto'},
 'corpora': {'nns_to_nn': 'corpus'},
 'curricula': {'nns_to_nn': 'curriculum'},
 'diagnoses': {'nns_to_nn': 'diagnosis'},
 'dwarfs': {'nns_to_nn': 'dwarf'},
 'ellipses': {'nns_to_nn': 'ellipsis'},
 'emphases': {'nns_to_nn': 'emphasis'},
 'errata': {'nns_to_nn': 'erratum'},
 'firemen': {'nns_to_nn': 'fireman'},
 'fishes': {'nns_to_nn': 'fish'},
 'focuses': {'nns_to_nn': 'focus', 'vbz_to_vb': 'focus'},
 'formulas': {'nns_to_nn': 'formula'},
 'funguses': {'nns_to_nn': 'fungus'},
 'geniuses': {'nns_to_nn': 'genius'},
 'genera': {'nns_to_nn': 'genus'},
 'geese': {'nns_to_nn': 'goose'},
 'gymnasia': {'nns_to_nn': 'gymnasium'},
 'haloes': {'nns_to_nn': 'halo'},
 'hippopotami': {'nns_to_nn': 'hippopotamus'},
 'hoofs': {'nns_to_nn': 'hoof'},
 'kangaroos': {'nns_to_nn': 'kangaroo'},
 'larvae': {'nns_to_nn': 'larva'},
 'leaves': {'nns_to_nn': 'leaf', 'vbz_to_vb': 'leave'},
 'libretti': {'nns_to_nn': 'libretto'},
 'lives': {'nns_to_nn': 'life', 'vbz_to_vb': 'live'},
 'loaves': {'nns_to_nn': 'loaf'},
 'lookers-on': {'nns_to_nn': 'looker-on'},
 'lice': {'nns_to_nn': 'louse'},
 'men doctors': {'nns_to_nn': 'man doctor'},
 'man-days': {'nns_to_nn': 'man-day'},
 'menservants': {'nns_to_nn': 'manservant'},
 'men-times': {'nns_to_nn': 'man-time'},
 'matrixes': {'nns_to_nn': 'matrix'},
 'memoranda': {'nns_to_nn': 'memorandum', 'n_is_nc': '', 'n_is_sth': ''},
 'millenniums': {'nns_to_nn': 'millennium'},
 'minima': {'nns_to_nn': 'minimum'},
 'mosquitoes': {'nns_to_nn': 'mosquito'},
 'mottos': {'nns_to_nn': 'motto'},
 'nebulae': {'nns_to_nn': 'nebula'},
 'neuroses': {'nns_to_nn': 'neurosis'},
 'oases': {'nns_to_nn': 'oasis'},
 'octopuses': {'nns_to_nn': 'octopus'},
 'optima': {'nns_to_nn': 'optimum'},
 'ova': {'nns_to_nn': 'ovum'},
 'oxen': {'nns_to_nn': 'ox', 'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'paralyses': {'nns_to_nn': 'paralysis'},
 'parentheses': {'nns_to_nn': 'parenthesis'},
 'pence': {'nns_to_nn': 'penny'},
 'phenomena': {'nns_to_nn': 'phenomenon'},
 'plateaux': {'nns_to_nn': 'plateau'},
 'radiuses': {'nns_to_nn': 'radius'},
 'scarfs': {'nns_to_nn': 'scarf'},
 'schemata': {'nns_to_nn': 'schema'},
 'seeds': {'nns_to_nn': 'seed', 'vbz_to_vb': 'seed'},
 'seraphim': {'nns_to_nn': 'seraph'},
 'sheaves': {'nns_to_nn': 'sheaf'},
 'shelves': {'nns_to_nn': 'shelf'},
 'sisters-in-law': {'nns_to_nn': 'sister-in-law'},
 'soli': {'nns_to_nn': 'solo'},
 'stadiums': {'nns_to_nn': 'stadium'},
 'stigmata': {'nns_to_nn': 'stigma'},
 'still lifes': {'nns_to_nn': 'still life'},
 'stimuli': {'nns_to_nn': 'stimulus'},
 'stratums': {'nns_to_nn': 'stratum'},
 'syllabi': {'nns_to_nn': 'syllabus'},
 'symposiums': {'nns_to_nn': 'symposium'},
 'synopses': {'nns_to_nn': 'synopsis'},
 'syntheses': {'nns_to_nn': 'synthesis'},
 'tableaus': {'nns_to_nn': 'tableau'},
 'tempi': {'nns_to_nn': 'tempo'},
 'termini': {'nns_to_nn': 'terminus'},
 'theses': {'nns_to_nn': 'thesis'},
 'tornados': {'nns_to_nn': 'tornado'},
 'ultimata': {'nns_to_nn': 'ultimatum'},
 'vacua': {'nns_to_nn': 'vacuum'},
 'vertebrae': {'nns_to_nn': 'vertebra'},
 'virtuosi': {'nns_to_nn': 'virtuoso'},
 'vitae': {'nns_to_nn': 'vita'},
 'volcanos': {'nns_to_nn': 'volcano'},
 'vortices': {'nns_to_nn': 'vortex'},
 'zeroes': {'nns_to_nn': 'zero'},
 'elves': {'nns_to_nn': 'elf'},
 'halves': {'nns_to_nn': 'half'},
 'knives': {'nns_to_nn': 'knife'},
 'thieves': {'nns_to_nn': 'thief'},
 'wives': {'nns_to_nn': 'wife'},
 'attorneies': {'nns_to_nn': 'attorney'},
 'babies': {'nns_to_nn': 'baby'},
 'bodies': {'nns_to_nn': 'body'},
 'categories': {'nns_to_nn': 'category'},
 'centuries': {'nns_to_nn': 'century'},
 'cities': {'nns_to_nn': 'city'},
 'communities': {'nns_to_nn': 'community'},
 'contemporaries': {'nns_to_nn': 'contemporary', 'n_is_nc': '', 'n_is_sb': '0'},
 'countries': {'nns_to_nn': 'country'},
 'counties': {'nns_to_nn': 'county'},
 'cries': {'nns_to_nn': 'cry', 'vbz_to_vb': 'cry'},
 'dailies': {'nns_to_nn': 'daily'},
 'diaries': {'nns_to_nn': 'diary'},
 'dictionaries': {'nns_to_nn': 'dictionary'},
 'directories': {'nns_to_nn': 'directory'},
 'enemies': {'nns_to_nn': 'enemy'},
 'factories': {'nns_to_nn': 'factory'},
 'flies': {'nns_to_nn': 'fly', 'vbz_to_vb': 'fly'},
 'fries': {'nns_to_nn': 'fry', 'vbz_to_vb': 'fry'},
 'geographies': {'nns_to_nn': 'geography'},
 'grannies': {'nns_to_nn': 'granny'},
 'groceries': {'nns_to_nn': 'grocery'},
 'hobbies': {'nns_to_nn': 'hobby'},
 'juries': {'nns_to_nn': 'jury'},
 'laboratories': {'nns_to_nn': 'laboratory'},
 'ladies': {'nns_to_nn': 'lady'},
 'libraries': {'nns_to_nn': 'library'},
 'lorries': {'nns_to_nn': 'lorry'},
 'majorities': {'nns_to_nn': 'majority'},
 'ministries': {'nns_to_nn': 'ministry'},
 'mysteries': {'nns_to_nn': 'mystery'},
 'necessaries': {'nns_to_nn': 'necessary'},
 'parties': {'nns_to_nn': 'party'},
 'photocopies': {'nns_to_nn': 'photocopy', 'vbz_to_vb': 'photocopy'},
 'primaries': {'nns_to_nn': 'primary'},
 'replies': {'nns_to_nn': 'reply', 'vbz_to_vb': 'reply'},
 'secretaries': {'nns_to_nn': 'secretary'},
 'stories': {'nns_to_nn': 'story'},
 'strawberries': {'nns_to_nn': 'strawberry'},
 'summaries': {'nns_to_nn': 'summary'},
 'tendencies': {'nns_to_nn': 'tendency'},
 'qualities': {'nns_to_nn': 'quality'},
 'absences': {'nns_to_nn': 'absence'},
 'abstentions': {'nns_to_nn': 'abstention'},
 'abstracts': {'nns_to_nn': 'abstract'},
 'abstractions': {'nns_to_nn': 'abstraction'},
 'abuses': {'nns_to_nn': 'abuse', 'vbz_to_vb': 'abuse'},
 'academics': {'nns_to_nn': 'academic'},
 'academies': {'nns_to_nn': 'academy'},
 'accelerators': {'nns_to_nn': 'accelerator'},
 'accents': {'nns_to_nn': 'accent'},
 'acceptances': {'nns_to_nn': 'acceptance'},
 'accessions': {'nns_to_nn': 'accession'},
 'accessories': {'nns_to_nn': 'accessory'},
 'accidents': {'nns_to_nn': 'accident'},
 'acclamations': {'nns_to_nn': 'acclamation'},
 'accommodations': {'nns_to_nn': 'accommodation'},
 'accords': {'nns_to_nn': 'accord'},
 'accounts': {'nns_to_nn': 'account', 'vbz_to_vb': 'account'},
 'aces': {'nns_to_nn': 'ace'},
 'aches': {'nns_to_nn': 'ache'},
 'achievements': {'nns_to_nn': 'achievement'},
 'acids': {'nns_to_nn': 'acid'},
 'acoustics': {'nns_to_nn': 'acoustic', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acquaintances': {'nns_to_nn': 'acquaintance'},
 'acts': {'nns_to_nn': 'act', 'vbz_to_vb': 'act'},
 'actions': {'nns_to_nn': 'action'},
 'activists': {'nns_to_nn': 'activist'},
 'activities': {'nns_to_nn': 'activity'},
 'actors': {'nns_to_nn': 'actor'},
 'actualities': {'nns_to_nn': 'actuality'},
 'actuaries': {'nns_to_nn': 'actuary'},
 'adages': {'nns_to_nn': 'adage'},
 'adaptations': {'nns_to_nn': 'adaptation'},
 'adapters': {'nns_to_nn': 'adapter'},
 'addictions': {'nns_to_nn': 'addiction'},
 'additions': {'nns_to_nn': 'addition'},
 'additives': {'nns_to_nn': 'additive'},
 'addresses': {'nns_to_nn': 'address', 'vbz_to_vb': 'address'},
 'adepts': {'nns_to_nn': 'adept'},
 'adherents': {'nns_to_nn': 'adherent'},
 'adhesions': {'nns_to_nn': 'adhesion'},
 'adhesives': {'nns_to_nn': 'adhesive'},
 'adjectives': {'nns_to_nn': 'adjective'},
 'adjusters': {'nns_to_nn': 'adjuster'},
 'adjustments': {'nns_to_nn': 'adjustment'},
 'administrations': {'nns_to_nn': 'administration'},
 'administrators': {'nns_to_nn': 'administrator'},
 'admirers': {'nns_to_nn': 'admirer'},
 'admissions': {'nns_to_nn': 'admission'},
 'admonitions': {'nns_to_nn': 'admonition'},
 'adolescents': {'nns_to_nn': 'adolescent'},
 'adoptions': {'nns_to_nn': 'adoption'},
 'adornments': {'nns_to_nn': 'adornment'},
 'adults': {'nns_to_nn': 'adult'},
 'advancements': {'nns_to_nn': 'advancement'},
 'advantages': {'nns_to_nn': 'advantage', 'vbz_to_vb': 'advantage'},
 'adventures': {'nns_to_nn': 'adventure'},
 'adventurers': {'nns_to_nn': 'adventurer'},
 'adverbs': {'nns_to_nn': 'adverb'},
 'advertisements': {'nns_to_nn': 'advertisement'},
 'advisers': {'nns_to_nn': 'adviser'},
 'advisories': {'nns_to_nn': 'advisory'},
 'affects': {'nns_to_nn': 'affect'},
 'afternoons': {'nns_to_nn': 'afternoon'},
 'ages': {'nns_to_nn': 'age'},
 'agencies': {'nns_to_nn': 'agency'},
 'agents': {'nns_to_nn': 'agent'},
 'aggravations': {'nns_to_nn': 'aggravation'},
 'agonies': {'nns_to_nn': 'agony'},
 'agreements': {'nns_to_nn': 'agreement'},
 'aims': {'nns_to_nn': 'aim', 'vbz_to_vb': 'aim'},
 'airs': {'nns_to_nn': 'air', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbz_to_vb': 'air'},
 'airfields': {'nns_to_nn': 'airfield'},
 'airings': {'nns_to_nn': 'airing'},
 'airlines': {'nns_to_nn': 'airline'},
 'airliners': {'nns_to_nn': 'airliner'},
 'airmen': {'nns_to_nn': 'airman'},
 'airplanes': {'nns_to_nn': 'airplane'},
 'airports': {'nns_to_nn': 'airport'},
 'airships': {'nns_to_nn': 'airship'},
 'airstreams': {'nns_to_nn': 'airstream'},
 'airways': {'nns_to_nn': 'airway'},
 'albums': {'nns_to_nn': 'album'},
 'alchemists': {'nns_to_nn': 'alchemist'},
 'alexanders': {'nns_to_nn': 'alexander'},
 'alexandrias': {'nns_to_nn': 'alexandria'},
 'algebras': {'nns_to_nn': 'algebra'},
 'amounts': {'nns_to_nn': 'amount', 'vbz_to_vb': 'amount'},
 'amperes': {'nns_to_nn': 'ampere'},
 'ancestors': {'nns_to_nn': 'ancestor'},
 'anchors': {'nns_to_nn': 'anchor'},
 'angels': {'nns_to_nn': 'angel'},
 'angles': {'nns_to_nn': 'angle', 'vbz_to_vb': 'angle'},
 'angolas': {'nns_to_nn': 'angola'},
 'animals': {'nns_to_nn': 'animal'},
 'animations': {'nns_to_nn': 'animation'},
 'ankles': {'nns_to_nn': 'ankle'},
 'announcers': {'nns_to_nn': 'announcer'},
 'answers': {'nns_to_nn': 'answer', 'vbz_to_vb': 'answer'},
 'ants': {'nns_to_nn': 'ant'},
 'anticipations': {'nns_to_nn': 'anticipation'},
 'anxieties': {'nns_to_nn': 'anxiety'},
 'apartments': {'nns_to_nn': 'apartment'},
 'apparatuses': {'nns_to_nn': 'apparatus'},
 'apparels': {'nns_to_nn': 'apparel'},
 'appearances': {'nns_to_nn': 'appearance'},
 'appeasements': {'nns_to_nn': 'appeasement'},
 'appellations': {'nns_to_nn': 'appellation'},
 'appendages': {'nns_to_nn': 'appendage'},
 'appetites': {'nns_to_nn': 'appetite'},
 'applauses': {'nns_to_nn': 'applause'},
 'apples': {'nns_to_nn': 'apple'},
 'appliances': {'nns_to_nn': 'appliance'},
 'applicants': {'nns_to_nn': 'applicant'},
 'applications': {'nns_to_nn': 'application'},
 'appointments': {'nns_to_nn': 'appointment'},
 'apportionments': {'nns_to_nn': 'apportionment'},
 'appraisals': {'nns_to_nn': 'appraisal'},
 'appraisers': {'nns_to_nn': 'appraiser'},
 'appreciations': {'nns_to_nn': 'appreciation'},
 'apprehensions': {'nns_to_nn': 'apprehension'},
 'apprentices': {'nns_to_nn': 'apprentice'},
 'approaches': {'nns_to_nn': 'approach', 'vbz_to_vb': 'approach'},
 'appropriations': {'nns_to_nn': 'appropriation'},
 'approvals': {'nns_to_nn': 'approval'},
 'approximations': {'nns_to_nn': 'approximation'},
 'aprils': {'nns_to_nn': 'april'},
 'arbitrations': {'nns_to_nn': 'arbitration'},
 'arguments': {'nns_to_nn': 'argument', 'vbz_to_vb': 'argument'},
 'arrangements': {'nns_to_nn': 'arrangement'},
 'arraies': {'nns_to_nn': 'array'},
 'arrows': {'nns_to_nn': 'arrow'},
 'artists': {'nns_to_nn': 'artist'},
 'ashes': {'nns_to_nn': 'ash'},
 'aspects': {'nns_to_nn': 'aspect'},
 'assemblies': {'nns_to_nn': 'assembly'},
 'assistants': {'nns_to_nn': 'assistant'},
 'associations': {'nns_to_nn': 'association'},
 'astronauts': {'nns_to_nn': 'astronaut'},
 'athletes': {'nns_to_nn': 'athlete'},
 'atoms': {'nns_to_nn': 'atom'},
 'attempts': {'nns_to_nn': 'attempt'},
 'audiences': {'nns_to_nn': 'audience'},
 'authors': {'nns_to_nn': 'author'},
 'authorities': {'nns_to_nn': 'authority', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'automobiles': {'nns_to_nn': 'automobile'},
 'awards': {'nns_to_nn': 'award', 'vbz_to_vb': 'award'},
 'babylonians': {'nns_to_nn': 'babylonian'},
 'babysitters': {'nns_to_nn': 'babysitter'},
 'baby-sitters': {'nns_to_nn': 'baby-sitter'},
 'bachelors': {'nns_to_nn': 'bachelor'},
 'backs': {'nns_to_nn': 'back'},
 'backups': {'nns_to_nn': 'backup'},
 'backwaters': {'nns_to_nn': 'backwater'},
 'backyards': {'nns_to_nn': 'backyard'},
 'bads': {'nns_to_nn': 'bad'},
 'badmintons': {'nns_to_nn': 'badminton'},
 'bags': {'nns_to_nn': 'bag'},
 'balances': {'nns_to_nn': 'balance', 'vbz_to_vb': 'balance'},
 'balconies': {'nns_to_nn': 'balcony'},
 'balls': {'nns_to_nn': 'ball'},
 'ballets': {'nns_to_nn': 'ballet'},
 'bananas': {'nns_to_nn': 'banana'},
 'bands': {'nns_to_nn': 'band', 'vbz_to_vb': 'band'},
 'bandits': {'nns_to_nn': 'bandit'},
 'bangs': {'nns_to_nn': 'bang', 'vbz_to_vb': 'bang'},
 'bangers': {'nns_to_nn': 'banger'},
 'banisters': {'nns_to_nn': 'banister'},
 'banks': {'nns_to_nn': 'bank', 'n_is_sb': '2', 'n_is_sth': '2'},
 'bankers': {'nns_to_nn': 'banker'},
 'bankruptcies': {'nns_to_nn': 'bankruptcy'},
 'banners': {'nns_to_nn': 'banner'},
 'banquets': {'nns_to_nn': 'banquet'},
 'banquettes': {'nns_to_nn': 'banquette'},
 'barbadoses': {'nns_to_nn': 'barbados'},
 'barbarities': {'nns_to_nn': 'barbarity'},
 'barbecues': {'nns_to_nn': 'barbecue'},
 'barbells': {'nns_to_nn': 'barbell'},
 'barbers': {'nns_to_nn': 'barber'},
 'barbershops': {'nns_to_nn': 'barbershop'},
 'bards': {'nns_to_nn': 'bard'},
 'bargains': {'nns_to_nn': 'bargain'},
 'barges': {'nns_to_nn': 'barge'},
 'baritones': {'nns_to_nn': 'baritone'},
 'barks': {'nns_to_nn': 'bark'},
 'barkers': {'nns_to_nn': 'barker'},
 'barns': {'nns_to_nn': 'barn'},
 'barometers': {'nns_to_nn': 'barometer'},
 'barons': {'nns_to_nn': 'baron'},
 'barracudas': {'nns_to_nn': 'barracuda'},
 'barrages': {'nns_to_nn': 'barrage'},
 'barrels': {'nns_to_nn': 'barrel'},
 'barrens': {'nns_to_nn': 'barren'},
 'barricades': {'nns_to_nn': 'barricade'},
 'barriers': {'nns_to_nn': 'barrier'},
 'barrios': {'nns_to_nn': 'barrio'},
 'barristers': {'nns_to_nn': 'barrister'},
 'baseballs': {'nns_to_nn': 'baseball'},
 'baseboards': {'nns_to_nn': 'baseboard'},
 'baskets': {'nns_to_nn': 'basket'},
 'basketballs': {'nns_to_nn': 'basketball'},
 'basses': {'nns_to_nn': 'bass'},
 'bats': {'nns_to_nn': 'bat', 'vbz_to_vb': 'bat'},
 'batches': {'nns_to_nn': 'batch'},
 'baths': {'nns_to_nn': 'bath', 'vbz_to_vb': 'bath'},
 'bathrooms': {'nns_to_nn': 'bathroom'},
 'battles': {'nns_to_nn': 'battle', 'vbz_to_vb': 'battle'},
 'beans': {'nns_to_nn': 'bean'},
 'bears': {'nns_to_nn': 'bear', 'vbz_to_vb': 'bear'},
 'beards': {'nns_to_nn': 'beard', 'vbz_to_vb': 'beard'},
 'bearers': {'nns_to_nn': 'bearer'},
 'bearings': {'nns_to_nn': 'bearing'},
 'beasts': {'nns_to_nn': 'beast'},
 'beats': {'nns_to_nn': 'beat'},
 'beaters': {'nns_to_nn': 'beater'},
 'beatings': {'nns_to_nn': 'beating'},
 'beauticians': {'nns_to_nn': 'beautician'},
 'beautifications': {'nns_to_nn': 'beautification'},
 'beauties': {'nns_to_nn': 'beauty'},
 'beds': {'nns_to_nn': 'bed'},
 'bedouins': {'nns_to_nn': 'bedouin'},
 'bedrocks': {'nns_to_nn': 'bedrock'},
 'bedrooms': {'nns_to_nn': 'bedroom'},
 'bedsides': {'nns_to_nn': 'bedside'},
 'bedspreads': {'nns_to_nn': 'bedspread'},
 'bees': {'nns_to_nn': 'bee'},
 'beeches': {'nns_to_nn': 'beech'},
 'beefs': {'nns_to_nn': 'beef'},
 'beggars': {'nns_to_nn': 'beggar'},
 'beginners': {'nns_to_nn': 'beginner'},
 'beginnings': {'nns_to_nn': 'beginning'},
 'behalfs': {'nns_to_nn': 'behalf'},
 'behaviors': {'nns_to_nn': 'behavior'},
 'behinds': {'nns_to_nn': 'behind'},
 'belgiums': {'nns_to_nn': 'belgium'},
 'beliefs': {'nns_to_nn': 'belief'},
 'believers': {'nns_to_nn': 'believer'},
 'bells': {'nns_to_nn': 'bell'},
 'belles': {'nns_to_nn': 'belle'},
 'belts': {'nns_to_nn': 'belt'},
 'benches': {'nns_to_nn': 'bench'},
 'berries': {'nns_to_nn': 'berry'},
 'bikes': {'nns_to_nn': 'bike', 'vbz_to_vb': 'bike'},
 'bikinis': {'nns_to_nn': 'bikini'},
 'bills': {'nns_to_nn': 'bill', 'vbz_to_vb': 'bill'},
 'birds': {'nns_to_nn': 'bird'},
 'birdcages': {'nns_to_nn': 'birdcage'},
 'births': {'nns_to_nn': 'birth'},
 'birthdays': {'nns_to_nn': 'birthday'},
 'birthplaces': {'nns_to_nn': 'birthplace'},
 'birthrates': {'nns_to_nn': 'birthrate'},
 'biscuits': {'nns_to_nn': 'biscuit'},
 'bisexuals': {'nns_to_nn': 'bisexual'},
 'bits': {'nns_to_nn': 'bit'},
 'bitches': {'nns_to_nn': 'bitch'},
 'bites': {'nns_to_nn': 'bite', 'vbz_to_vb': 'bite'},
 'bitters': {'nns_to_nn': 'bitter'},
 'blacks': {'nns_to_nn': 'black'},
 'blackbirds': {'nns_to_nn': 'blackbird'},
 'blackboards': {'nns_to_nn': 'blackboard'},
 'blacklists': {'nns_to_nn': 'blacklist'},
 'blackouts': {'nns_to_nn': 'blackout'},
 'blacksmiths': {'nns_to_nn': 'blacksmith'},
 'blanks': {'nns_to_nn': 'blank'},
 'blankets': {'nns_to_nn': 'blanket'},
 'blocks': {'nns_to_nn': 'block', 'vbz_to_vb': 'block'},
 'blooms': {'nns_to_nn': 'bloom'},
 'bloomers': {'nns_to_nn': 'bloomer'},
 'blossoms': {'nns_to_nn': 'blossom'},
 'blots': {'nns_to_nn': 'blot'},
 'blotters': {'nns_to_nn': 'blotter'},
 'blouses': {'nns_to_nn': 'blouse'},
 'blues': {'nns_to_nn': 'blue', 'vbz_to_vb': 'blue'},
 'blueberries': {'nns_to_nn': 'blueberry'},
 'bluffs': {'nns_to_nn': 'bluff'},
 'boats': {'nns_to_nn': 'boat', 'vbz_to_vb': 'boat'},
 'bodyguards': {'nns_to_nn': 'bodyguard'},
 'bogs': {'nns_to_nn': 'bog'},
 'bombs': {'nns_to_nn': 'bomb', 'vbz_to_vb': 'bomb'},
 'bones': {'nns_to_nn': 'bone'},
 'books': {'nns_to_nn': 'book', 'vbz_to_vb': 'book', 'n_is_nns': ''},
 'bookmen': {'nns_to_nn': 'bookman'},
 'bookmarks': {'nns_to_nn': 'bookmark'},
 'booksellers': {'nns_to_nn': 'bookseller'},
 'bookshelves': {'nns_to_nn': 'bookshelf'},
 'bookshops': {'nns_to_nn': 'bookshop'},
 'bookstores': {'nns_to_nn': 'bookstore'},
 'bookworms': {'nns_to_nn': 'bookworm'},
 'booms': {'nns_to_nn': 'boom'},
 'boomers': {'nns_to_nn': 'boomer'},
 'boons': {'nns_to_nn': 'boon'},
 'boosts': {'nns_to_nn': 'boost'},
 'boosters': {'nns_to_nn': 'booster'},
 'boots': {'nns_to_nn': 'boot', 'vbz_to_vb': 'boot'},
 'borrowings': {'nns_to_nn': 'borrowing'},
 'bottoms': {'nns_to_nn': 'bottom'},
 'boundaries': {'nns_to_nn': 'boundary'},
 'bows': {'nns_to_nn': 'bow'},
 'bowls': {'nns_to_nn': 'bowl', 'vbz_to_vb': 'bowl'},
 'boys': {'nns_to_nn': 'boy'},
 'boyfriends': {'nns_to_nn': 'boyfriend'},
 'bracelets': {'nns_to_nn': 'bracelet'},
 'brackets': {'nns_to_nn': 'bracket'},
 'brains': {'nns_to_nn': 'brain'},
 'brands': {'nns_to_nn': 'brand'},
 'brandies': {'nns_to_nn': 'brandy'},
 'brasses': {'nns_to_nn': 'brass'},
 'brassieres': {'nns_to_nn': 'brassiere'},
 'brats': {'nns_to_nn': 'brat'},
 'braves': {'nns_to_nn': 'brave', 'vbz_to_vb': 'brave'},
 'breads': {'nns_to_nn': 'bread'},
 'breadbaskets': {'nns_to_nn': 'breadbasket'},
 'breadwinners': {'nns_to_nn': 'breadwinner'},
 'breaks': {'nns_to_nn': 'break', 'vbz_to_vb': 'break'},
 'brews': {'nns_to_nn': 'brew'},
 'brewers': {'nns_to_nn': 'brewer'},
 'breweries': {'nns_to_nn': 'brewery'},
 'bribes': {'nns_to_nn': 'bribe'},
 'bricks': {'nns_to_nn': 'brick', 'vbz_to_vb': 'brick'},
 'bricklayers': {'nns_to_nn': 'bricklayer'},
 'brickyards': {'nns_to_nn': 'brickyard'},
 'brides': {'nns_to_nn': 'bride'},
 'bridegrooms': {'nns_to_nn': 'bridegroom'},
 'bridesmaids': {'nns_to_nn': 'bridesmaid'},
 'bridges': {'nns_to_nn': 'bridge', 'n_is_sb': '2', 'vbz_to_vb': 'bridge', 'n_is_sth': '2'},
 'bridles': {'nns_to_nn': 'bridle'},
 'briefs': {'nns_to_nn': 'brief', 'n_is_nc': '', 'n_is_sth': ''},
 'briefcases': {'nns_to_nn': 'briefcase'},
 'briefings': {'nns_to_nn': 'briefing'},
 'brigs': {'nns_to_nn': 'brig'},
 'brigades': {'nns_to_nn': 'brigade'},
 'brims': {'nns_to_nn': 'brim'},
 'brinks': {'nns_to_nn': 'brink'},
 'brioches': {'nns_to_nn': 'brioche'},
 'bristles': {'nns_to_nn': 'bristle'},
 'broads': {'nns_to_nn': 'broad'},
 'broadcasts': {'nns_to_nn': 'broadcast'},
 'broadcasters': {'nns_to_nn': 'broadcaster'},
 'broadsides': {'nns_to_nn': 'broadside'},
 'brocades': {'nns_to_nn': 'brocade'},
 'brochures': {'nns_to_nn': 'brochure'},
 'broilers': {'nns_to_nn': 'broiler'},
 'brokers': {'nns_to_nn': 'broker'},
 'brokerages': {'nns_to_nn': 'brokerage'},
 'bromides': {'nns_to_nn': 'bromide'},
 'broncos': {'nns_to_nn': 'bronco'},
 'bronzes': {'nns_to_nn': 'bronze'},
 'brooms': {'nns_to_nn': 'broom'},
 'brows': {'nns_to_nn': 'brow'},
 'brushes': {'nns_to_nn': 'brush', 'vbz_to_vb': 'brush'},
 'buckets': {'nns_to_nn': 'bucket', 'vbz_to_vb': 'bucket'},
 'buildings': {'nns_to_nn': 'building'},
 'bulbs': {'nns_to_nn': 'bulb'},
 'bulls': {'nns_to_nn': 'bull'},
 'bullets': {'nns_to_nn': 'bullet'},
 'bundles': {'nns_to_nn': 'bundle'},
 'buses': {'nns_to_nn': 'bus'},
 'butterflies': {'nns_to_nn': 'butterfly'},
 'buttons': {'nns_to_nn': 'button', 'vbz_to_vb': 'button'},
 'buzzes': {'nns_to_nn': 'buzz'},
 'cabbages': {'nns_to_nn': 'cabbage'},
 'cabins': {'nns_to_nn': 'cabin'},
 'cabinets': {'nns_to_nn': 'cabinet'},
 'cables': {'nns_to_nn': 'cable', 'vbz_to_vb': 'cable'},
 'cafes': {'nns_to_nn': 'cafe'},
 'cafeterias': {'nns_to_nn': 'cafeteria'},
 'cages': {'nns_to_nn': 'cage'},
 'calculations': {'nns_to_nn': 'calculation'},
 'calculators': {'nns_to_nn': 'calculator'},
 'calendars': {'nns_to_nn': 'calendar', 'vbz_to_vb': 'calendar'},
 'calenders': {'nns_to_nn': 'calender'},
 'camels': {'nns_to_nn': 'camel'},
 'camps': {'nns_to_nn': 'camp', 'vbz_to_vb': 'camp'},
 'campuses': {'nns_to_nn': 'campus'},
 'canals': {'nns_to_nn': 'canal'},
 'candidates': {'nns_to_nn': 'candidate'},
 'candles': {'nns_to_nn': 'candle'},
 'candies': {'nns_to_nn': 'candy', 'vbz_to_vb': 'candy'},
 'canteens': {'nns_to_nn': 'canteen'},
 'capitals': {'nns_to_nn': 'capital'},
 'captains': {'nns_to_nn': 'captain', 'vbz_to_vb': 'captain'},
 'cars': {'nns_to_nn': 'car'},
 'cards': {'nns_to_nn': 'card'},
 'cardinals': {'nns_to_nn': 'cardinal'},
 'carrers': {'nns_to_nn': 'career'},
 'carnations': {'nns_to_nn': 'carnation'},
 'carpenters': {'nns_to_nn': 'carpenter'},
 'carpets': {'nns_to_nn': 'carpet', 'vbz_to_vb': 'carpet'},
 'carriages': {'nns_to_nn': 'carriage'},
 'carriers': {'nns_to_nn': 'carrier'},
 'carrots': {'nns_to_nn': 'carrot'},
 'carries': {'nns_to_nn': 'carry', 'vbz_to_vb': 'carry'},
 'carts': {'nns_to_nn': 'cart'},
 'carters': {'nns_to_nn': 'carter'},
 'cartoons': {'nns_to_nn': 'cartoon'},
 'cases': {'nns_to_nn': 'case'},
 'casinos': {'nns_to_nn': 'casino'},
 'cassettes': {'nns_to_nn': 'cassette'},
 'casts': {'nns_to_nn': 'cast', 'vbz_to_vb': 'cast'},
 'castles': {'nns_to_nn': 'castle'},
 'cats': {'nns_to_nn': 'cat'},
 'catalogs': {'nns_to_nn': 'catalog'},
 'catalogues': {'nns_to_nn': 'catalogue'},
 'catchers': {'nns_to_nn': 'catcher'},
 'catholics': {'nns_to_nn': 'catholic'},
 'causes': {'nns_to_nn': 'cause', 'vbz_to_vb': 'cause'},
 'cautions': {'nns_to_nn': 'caution'},
 'caves': {'nns_to_nn': 'cave'},
 'CDs': {'nns_to_nn': 'CD'},
 'cease-fires': {'nns_to_nn': 'cease-fire'},
 'ceilings': {'nns_to_nn': 'ceiling'},
 'celebrations': {'nns_to_nn': 'celebration'},
 'celebrities': {'nns_to_nn': 'celebrity'},
 'cells': {'nns_to_nn': 'cell'},
 'cellars': {'nns_to_nn': 'cellar'},
 'cellphones': {'nns_to_nn': 'cellphone'},
 'censuses': {'nns_to_nn': 'census'},
 'centers': {'nns_to_nn': 'center'},
 'centres': {'nns_to_nn': 'centre'},
 'ceremonies': {'nns_to_nn': 'ceremony'},
 'certi\x1dficates': {'nns_to_nn': 'certi\x1dficate'},
 'chains': {'nns_to_nn': 'chain', 'n_is_nc': '', 'n_is_sth': ''},
 'chairs': {'nns_to_nn': 'chair'},
 'challenges': {'nns_to_nn': 'challenge', 'vbz_to_vb': 'challenge'},
 'chambers': {'nns_to_nn': 'chamber', 'n_is_sb': '2', 'n_is_sth': '2'},
 'champagnes': {'nns_to_nn': 'champagne'},
 'champions': {'nns_to_nn': 'champion'},
 'chances': {'nns_to_nn': 'chance'},
 'chancellors': {'nns_to_nn': 'chancellor'},
 'channels': {'nns_to_nn': 'channel'},
 'chapters': {'nns_to_nn': 'chapter'},
 'characters': {'nns_to_nn': 'character'},
 'charges': {'nns_to_nn': 'charge', 'vbz_to_vb': 'charge'},
 'charities': {'nns_to_nn': 'charity'},
 'charms': {'nns_to_nn': 'charm'},
 'charts': {'nns_to_nn': 'chart'},
 'charters': {'nns_to_nn': 'charter'},
 'chases': {'nns_to_nn': 'chase', 'vbz_to_vb': 'chase'},
 'cheats': {'nns_to_nn': 'cheat', 'vbz_to_vb': 'cheat'},
 'cheeks': {'nns_to_nn': 'cheek'},
 'cheeses': {'nns_to_nn': 'cheese'},
 'chefs': {'nns_to_nn': 'chef'},
 'chemicals': {'nns_to_nn': 'chemical'},
 'chemists': {'nns_to_nn': 'chemist'},
 'chemistries': {'nns_to_nn': 'chemistry'},
 'cheques': {'nns_to_nn': 'cheque'},
 'cherries': {'nns_to_nn': 'cherry'},
 'chesses': {'nns_to_nn': 'chess'},
 'chests': {'nns_to_nn': 'chest'},
 'chickens': {'nns_to_nn': 'chicken'},
 'chiefs': {'nns_to_nn': 'chief'},
 'childhoods': {'nns_to_nn': 'childhood'},
 'chimneys': {'nns_to_nn': 'chimney'},
 'chins': {'nns_to_nn': 'chin'},
 'chocolates': {'nns_to_nn': 'chocolate'},
 'choices': {'nns_to_nn': 'choice'},
 'choruses': {'nns_to_nn': 'chorus'},
 'chronicles': {'nns_to_nn': 'chronicle'},
 'chrysanthemums': {'nns_to_nn': 'chrysanthemum'},
 'churches': {'nns_to_nn': 'church'},
 'cigars': {'nns_to_nn': 'cigar'},
 'cigarettes': {'nns_to_nn': 'cigarette'},
 'cinemas': {'nns_to_nn': 'cinema'},
 'circles': {'nns_to_nn': 'circle'},
 'circuits': {'nns_to_nn': 'circuit'},
 'circulations': {'nns_to_nn': 'circulation'},
 'circumstances': {'nns_to_nn': 'circumstance', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'circuses': {'nns_to_nn': 'circus'},
 'citizens': {'nns_to_nn': 'citizen'},
 'civilians': {'nns_to_nn': 'civilian'},
 'claims': {'nns_to_nn': 'claim', 'vbz_to_vb': 'claim'},
 'clashes': {'nns_to_nn': 'clash'},
 'classrooms': {'nns_to_nn': 'classroom'},
 'cleaners': {'nns_to_nn': 'cleaner'},
 'cleanings': {'nns_to_nn': 'cleaning'},
 'cleanups': {'nns_to_nn': 'cleanup'},
 'clerks': {'nns_to_nn': 'clerk', 'vbz_to_vb': 'clerk'},
 'clicks': {'nns_to_nn': 'click', 'vbz_to_vb': 'click'},
 'clients': {'nns_to_nn': 'client'},
 'cliffs': {'nns_to_nn': 'cliff'},
 'climates': {'nns_to_nn': 'climate'},
 'climbs': {'nns_to_nn': 'climb', 'vbz_to_vb': 'climb'},
 'clinics': {'nns_to_nn': 'clinic'},
 'clocks': {'nns_to_nn': 'clock', 'vbz_to_vb': 'clock'},
 'closes': {'nns_to_nn': 'close', 'vbz_to_vb': 'close'},
 'closets': {'nns_to_nn': 'closet', 'vbz_to_vb': 'closet'},
 'cloths': {'nns_to_nn': 'cloth'},
 'clouds': {'nns_to_nn': 'cloud', 'vbz_to_vb': 'cloud'},
 'clubs': {'nns_to_nn': 'club'},
 'clues': {'nns_to_nn': 'clue', 'vbz_to_vb': 'clue'},
 'coaches': {'nns_to_nn': 'coach', 'vbz_to_vb': 'coach'},
 'coals': {'nns_to_nn': 'coal', 'vbz_to_vb': 'coal'},
 'coasts': {'nns_to_nn': 'coast', 'vbz_to_vb': 'coast'},
 'coats': {'nns_to_nn': 'coat', 'vbz_to_vb': 'coat'},
 'codes': {'nns_to_nn': 'code', 'vbz_to_vb': 'code'},
 'coils': {'nns_to_nn': 'coil'},
 'coins': {'nns_to_nn': 'coin', 'vbz_to_vb': 'coin'},
 'collars': {'nns_to_nn': 'collar', 'vbz_to_vb': 'collar'},
 'colleagues': {'nns_to_nn': 'colleague'},
 'collects': {'nns_to_nn': 'collect', 'vbz_to_vb': 'collect'},
 'collectives': {'nns_to_nn': 'collective'},
 'colleges': {'nns_to_nn': 'college'},
 'colonies': {'nns_to_nn': 'colony'},
 'colorses': {'nns_to_nn': 'colors'},
 'columns': {'nns_to_nn': 'column'},
 'combs': {'nns_to_nn': 'comb'},
 'combats': {'nns_to_nn': 'combat'},
 'combines': {'nns_to_nn': 'combine', 'vbz_to_vb': 'combine'},
 'comebacks': {'nns_to_nn': 'comeback'},
 'comedies': {'nns_to_nn': 'comedy'},
 'comforts': {'nns_to_nn': 'comfort'},
 'comfortables': {'nns_to_nn': 'comfortable'},
 'commands': {'nns_to_nn': 'command', 'vbz_to_vb': 'command'},
 'commanders': {'nns_to_nn': 'commander'},
 'comments': {'nns_to_nn': 'comment', 'vbz_to_vb': 'comment'},
 'commentaries': {'nns_to_nn': 'commentary'},
 'commercials': {'nns_to_nn': 'commercial'},
 'commissions': {'nns_to_nn': 'commission', 'vbz_to_vb': 'commission'},
 'committees': {'nns_to_nn': 'committee'},
 'commodities': {'nns_to_nn': 'commodity'},
 'communications': {'nns_to_nn': 'communication', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'communists': {'nns_to_nn': 'communist'},
 'companions': {'nns_to_nn': 'companion'},
 'companies': {'nns_to_nn': 'company'},
 'comparisons': {'nns_to_nn': 'comparison'},
 'compasses': {'nns_to_nn': 'compass'},
 'compensations': {'nns_to_nn': 'compensation'},
 'competitions': {'nns_to_nn': 'competition'},
 'competitors': {'nns_to_nn': 'competitor'},
 'complaints': {'nns_to_nn': 'complaint'},
 'completions': {'nns_to_nn': 'completion'},
 'components': {'nns_to_nn': 'component'},
 'composers': {'nns_to_nn': 'composer'},
 'composites': {'nns_to_nn': 'composite'},
 'compositions': {'nns_to_nn': 'composition'},
 'compounds': {'nns_to_nn': 'compound'},
 'comprehensions': {'nns_to_nn': 'comprehension'},
 'computers': {'nns_to_nn': 'computer'},
 'comrades': {'nns_to_nn': 'comrade'},
 'cons': {'nns_to_nn': 'con'},
 'concentrates': {'nns_to_nn': 'concentrate', 'vbz_to_vb': 'concentrate'},
 'concentrations': {'nns_to_nn': 'concentration'},
 'concepts': {'nns_to_nn': 'concept'},
 'concerns': {'nns_to_nn': 'concern', 'vbz_to_vb': 'concern'},
 'concerts': {'nns_to_nn': 'concert', 'vbz_to_vb': 'concert'},
 'conclusions': {'nns_to_nn': 'conclusion'},
 'conditions': {'nns_to_nn': 'condition', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbz_to_vb': 'condition'},
 'conductors': {'nns_to_nn': 'conductor'},
 'cones': {'nns_to_nn': 'cone'},
 'conferences': {'nns_to_nn': 'conference'},
 'con\x1dfines': {'nns_to_nn': 'con\x1dfine', 'vbz_to_vb': 'con\x1dfine'},
 'confirmations': {'nns_to_nn': 'confirmation'},
 'conflicts': {'nns_to_nn': 'conflict', 'vbz_to_vb': 'conflict'},
 'confrontations': {'nns_to_nn': 'confrontation'},
 'confusions': {'nns_to_nn': 'confusion'},
 'congresses': {'nns_to_nn': 'congress'},
 'congressmen': {'nns_to_nn': 'congressman'},
 'sonsequences': {'nns_to_nn': 'consequence'},
 'conservations': {'nns_to_nn': 'conservation'},
 'conservatives': {'nns_to_nn': 'conservative'},
 'considerations': {'nns_to_nn': 'consideration'},
 'consolidations': {'nns_to_nn': 'consolidation'},
 'consortiums': {'nns_to_nn': 'consortium'},
 'conspiracies': {'nns_to_nn': 'conspiracy'},
 'constants': {'nns_to_nn': 'constant'},
 'constructs': {'nns_to_nn': 'construct', 'vbz_to_vb': 'construct'},
 'consultants': {'nns_to_nn': 'consultant'},
 'consumers': {'nns_to_nn': 'consumer'},
 'containers': {'nns_to_nn': 'container'},
 'contenders': {'nns_to_nn': 'contender'},
 'contentions': {'nns_to_nn': 'contention'},
 'contests': {'nns_to_nn': 'contest', 'vbz_to_vb': 'contest'},
 'contexts': {'nns_to_nn': 'context'},
 'continents': {'nns_to_nn': 'continent'},
 'contracts': {'nns_to_nn': 'contract', 'vbz_to_vb': 'contract'},
 'contractors': {'nns_to_nn': 'contractor'},
 'contrasts': {'nns_to_nn': 'contrast', 'vbz_to_vb': 'contrast'},
 'contributions': {'nns_to_nn': 'contribution'},
 'controls': {'nns_to_nn': 'control', 'vbz_to_vb': 'control'},
 'controversies': {'nns_to_nn': 'controversy'},
 'conversations': {'nns_to_nn': 'conversation'},
 'conversions': {'nns_to_nn': 'conversion'},
 'converts': {'nns_to_nn': 'convert', 'vbz_to_vb': 'convert'},
 'convictions': {'nns_to_nn': 'conviction'},
 'cooks': {'nns_to_nn': 'cook', 'vbz_to_vb': 'cook'},
 'cookers': {'nns_to_nn': 'cooker'},
 'cookies': {'nns_to_nn': 'cookie'},
 'cops': {'nns_to_nn': 'cop'},
 'copes': {'nns_to_nn': 'cope', 'vbz_to_vb': 'cope'},
 'coppers': {'nns_to_nn': 'copper'},
 'copies': {'nns_to_nn': 'copy', 'vbz_to_vb': 'copy'},
 'cores': {'nns_to_nn': 'core', 'vbz_to_vb': 'core'},
 'corners': {'nns_to_nn': 'corner', 'vbz_to_vb': 'corner'},
 'corporations': {'nns_to_nn': 'corporation'},
 'correspondents': {'nns_to_nn': 'correspondent'},
 'corridors': {'nns_to_nn': 'corridor'},
 'cottages': {'nns_to_nn': 'cottage'},
 'councils': {'nns_to_nn': 'council'},
 'counts': {'nns_to_nn': 'count', 'vbz_to_vb': 'count'},
 'counters': {'nns_to_nn': 'counter', 'vbz_to_vb': 'counter'},
 'coups': {'nns_to_nn': 'coup'},
 'couples': {'nns_to_nn': 'couple', 'vbz_to_vb': 'couple'},
 'courses': {'nns_to_nn': 'course', 'vbz_to_vb': 'course'},
 'courts': {'nns_to_nn': 'court', 'vbz_to_vb': 'court'},
 'courthouses': {'nns_to_nn': 'courthouse'},
 'courtrooms': {'nns_to_nn': 'courtroom'},
 'cousins': {'nns_to_nn': 'cousin'},
 'covers': {'nns_to_nn': 'cover', 'vbz_to_vb': 'cover'},
 'coverings': {'nns_to_nn': 'covering'},
 'cows': {'nns_to_nn': 'cow', 'n_is_sb': '2', 'vbz_to_vb': 'cow', 'n_is_sth': '2'},
 'coxes': {'nns_to_nn': 'cox'},
 'cracks': {'nns_to_nn': 'crack', 'vbz_to_vb': 'crack'},
 'crafts': {'nns_to_nn': 'craft'},
 'creams': {'nns_to_nn': 'cream'},
 'creations': {'nns_to_nn': 'creation'},
 'creators': {'nns_to_nn': 'creator'},
 'creatures': {'nns_to_nn': 'creature'},
 'credits': {'nns_to_nn': 'credit', 'vbz_to_vb': 'credit'},
 'creditcards': {'nns_to_nn': 'creditcard'},
 'crews': {'nns_to_nn': 'crew', 'vbz_to_vb': 'crew'},
 'crimes': {'nns_to_nn': 'crime'},
 'criminals': {'nns_to_nn': 'criminal'},
 'crisps': {'nns_to_nn': 'crisp'},
 'critics': {'nns_to_nn': 'critic'},
 'crops': {'nns_to_nn': 'crop', 'vbz_to_vb': 'crop'},
 'crowds': {'nns_to_nn': 'crowd', 'vbz_to_vb': 'crowd'},
 'crowns': {'nns_to_nn': 'crown', 'vbz_to_vb': 'crown'},
 'cruises': {'nns_to_nn': 'cruise'},
 'cults': {'nns_to_nn': 'cult'},
 'cups': {'nns_to_nn': 'cup'},
 'cupboards': {'nns_to_nn': 'cupboard'},
 'curators': {'nns_to_nn': 'curator'},
 'curbs': {'nns_to_nn': 'curb'},
 'cures': {'nns_to_nn': 'cure'},
 'currencies': {'nns_to_nn': 'currency'},
 'curtains': {'nns_to_nn': 'curtain', 'vbz_to_vb': 'curtain'},
 'curves': {'nns_to_nn': 'curve', 'vbz_to_vb': 'curve'},
 'cushions': {'nns_to_nn': 'cushion', 'vbz_to_vb': 'cushion'},
 'customers': {'nns_to_nn': 'customer'},
 'customs': {'nns_to_nn': 'custom', 'n_is_nc': '', 'n_is_sth': ''},
 'cuts': {'nns_to_nn': 'cut', 'vbz_to_vb': 'cut'},
 'cycles': {'nns_to_nn': 'cycle', 'vbz_to_vb': 'cycle'},
 'dads': {'nns_to_nn': 'dad'},
 'daffodils': {'nns_to_nn': 'daffodil'},
 'dances': {'nns_to_nn': 'dance', 'vbz_to_vb': 'dance'},
 'dancers': {'nns_to_nn': 'dancer'},
 'darlings': {'nns_to_nn': 'darling'},
 'databases': {'nns_to_nn': 'database'},
 'dates': {'nns_to_nn': 'date', 'vbz_to_vb': 'date'},
 'daughters': {'nns_to_nn': 'daughter'},
 'dawns': {'nns_to_nn': 'dawn'},
 'days': {'nns_to_nn': 'day', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'deadlines': {'nns_to_nn': 'deadline'},
 'dealers': {'nns_to_nn': 'dealer'},
 'dealings': {'nns_to_nn': 'dealing', 'n_is_nc': '', 'n_is_sth': ''},
 'deans': {'nns_to_nn': 'dean'},
 'dears': {'nns_to_nn': 'dear'},
 'deaths': {'nns_to_nn': 'death'},
 'debates': {'nns_to_nn': 'debate', 'vbz_to_vb': 'debate'},
 'debrises': {'nns_to_nn': 'debris'},
 'decades': {'nns_to_nn': 'decade'},
 'decisions': {'nns_to_nn': 'decision'},
 'decks': {'nns_to_nn': 'deck'},
 'declarations': {'nns_to_nn': 'declaration'},
 'declines': {'nns_to_nn': 'decline', 'vbz_to_vb': 'decline'},
 'defaults': {'nns_to_nn': 'default'},
 'defects': {'nns_to_nn': 'defect'},
 'defendants': {'nns_to_nn': 'defendant'},
 'defenders': {'nns_to_nn': 'defender'},
 'defenses': {'nns_to_nn': 'defense'},
 'deficits': {'nns_to_nn': 'deficit'},
 'definitions': {'nns_to_nn': 'definition'},
 'degrees': {'nns_to_nn': 'degree'},
 'delegations': {'nns_to_nn': 'delegation'},
 'deliveries': {'nns_to_nn': 'delivery'},
 'deltas': {'nns_to_nn': 'delta'},
 'demands': {'nns_to_nn': 'demand', 'vbz_to_vb': 'demand'},
 'democracies': {'nns_to_nn': 'democracy'},
 'demonstrations': {'nns_to_nn': 'demonstration'},
 'dentists': {'nns_to_nn': 'dentist'},
 'departments': {'nns_to_nn': 'department'},
 'departures': {'nns_to_nn': 'departure'},
 'dependents': {'nns_to_nn': 'dependent'},
 'deposits': {'nns_to_nn': 'deposit', 'vbz_to_vb': 'deposit'},
 'depressions': {'nns_to_nn': 'depression'},
 'depths': {'nns_to_nn': 'depth'},
 'deputies': {'nns_to_nn': 'deputy'},
 'descriptions': {'nns_to_nn': 'description'},
 'deserts': {'nns_to_nn': 'desert', 'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'desert'},
 'designs': {'nns_to_nn': 'design', 'vbz_to_vb': 'design'},
 'designers': {'nns_to_nn': 'designer'},
 'desks': {'nns_to_nn': 'desk'},
 'desktops': {'nns_to_nn': 'desktop'},
 'destinations': {'nns_to_nn': 'destination'},
 'details': {'nns_to_nn': 'detail', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbz_to_vb': 'detail'},
 'detectives': {'nns_to_nn': 'detective'},
 'developers': {'nns_to_nn': 'developer'},
 'developments': {'nns_to_nn': 'development'},
 'devices': {'nns_to_nn': 'device'},
 'devils': {'nns_to_nn': 'devil'},
 'diagrams': {'nns_to_nn': 'diagram', 'vbz_to_vb': 'diagram'},
 'dialogs': {'nns_to_nn': 'dialog'},
 'dialogues': {'nns_to_nn': 'dialogue'},
 'diamonds': {'nns_to_nn': 'diamond'},
 'diets': {'nns_to_nn': 'diet'},
 'differences': {'nns_to_nn': 'difference', 'nns_to_jj': 'different'},
 'difficulties': {'nns_to_nn': 'difficulty', 'nns_to_jj': 'difficult'},
 'digs': {'nns_to_nn': 'dig', 'vbz_to_vb': 'dig'},
 'dimensions': {'nns_to_nn': 'dimension'},
 'dinners': {'nns_to_nn': 'dinner'},
 'diplomats': {'nns_to_nn': 'diplomat'},
 'directions': {'nns_to_nn': 'direction'},
 'directors': {'nns_to_nn': 'director'},
 'disabilities': {'nns_to_nn': 'disability'},
 'disadvantages': {'nns_to_nn': 'disadvantage'},
 'disappointments': {'nns_to_nn': 'disappointment'},
 'disasters': {'nns_to_nn': 'disaster'},
 'discs': {'nns_to_nn': 'disc'},
 'disciplines': {'nns_to_nn': 'discipline', 'vbz_to_vb': 'discipline'},
 'disclosures': {'nns_to_nn': 'disclosure'},
 'discounts': {'nns_to_nn': 'discount', 'vbz_to_vb': 'discount'},
 'discoveries': {'nns_to_nn': 'discovery'},
 'discriminations': {'nns_to_nn': 'discrimination'},
 'disks': {'nns_to_nn': 'disk'},
 'distances': {'nns_to_nn': 'distance', 'vbz_to_vb': 'distance'},
 'distinctions': {'nns_to_nn': 'distinction'},
 'districts': {'nns_to_nn': 'district'},
 'diversities': {'nns_to_nn': 'diversity'},
 'divides': {'nns_to_nn': 'divide', 'vbz_to_vb': 'divide'},
 'dividends': {'nns_to_nn': 'dividend'},
 'divisions': {'nns_to_nn': 'division'},
 'divorces': {'nns_to_nn': 'divorce', 'vbz_to_vb': 'divorce'},
 'doctors': {'nns_to_nn': 'doctor', 'vbz_to_vb': 'doctor'},
 'documents': {'nns_to_nn': 'document', 'vbz_to_vb': 'document'},
 'documentaries': {'nns_to_nn': 'documentary'},
 'dogs': {'nns_to_nn': 'dog'},
 'dollars': {'nns_to_nn': 'dollar'},
 'domestics': {'nns_to_nn': 'domestic'},
 'dominants': {'nns_to_nn': 'dominant'},
 'donkeys': {'nns_to_nn': 'donkey'},
 'donors': {'nns_to_nn': 'donor'},
 'doors': {'nns_to_nn': 'door'},
 'dorms': {'nns_to_nn': 'dorm'},
 'dormitories': {'nns_to_nn': 'dormitory'},
 'doses': {'nns_to_nn': 'dose'},
 'dots': {'nns_to_nn': 'dot', 'vbz_to_vb': 'dot'},
 'doubts': {'nns_to_nn': 'doubt', 'vbz_to_vb': 'doubt'},
 'doughs': {'nns_to_nn': 'dough'},
 'downtowns': {'nns_to_nn': 'downtown'},
 'dozens': {'nns_to_nn': 'dozen'},
 'drafts': {'nns_to_nn': 'draft'},
 'dragons': {'nns_to_nn': 'dragon'},
 'drains': {'nns_to_nn': 'drain'},
 'dramas': {'nns_to_nn': 'drama'},
 'draws': {'nns_to_nn': 'draw', 'vbz_to_vb': 'draw'},
 'drawers': {'nns_to_nn': 'drawer', 'n_is_nc': '', 'n_is_sth': ''},
 'drawings': {'nns_to_nn': 'drawing', 'vbz_to_vb': 'drawing'},
 'dreams': {'nns_to_nn': 'dream', 'vbz_to_vb': 'dream'},
 'drinks': {'nns_to_nn': 'drink', 'vbz_to_vb': 'drink'},
 'drivers': {'nns_to_nn': 'driver', 'n_is_sb': '2', 'n_is_sth': '2'},
 'drops': {'nns_to_nn': 'drop', 'vbz_to_vb': 'drop'},
 'droughts': {'nns_to_nn': 'drought'},
 'drugs': {'nns_to_nn': 'drug', 'vbz_to_vb': 'drug'},
 'druggists': {'nns_to_nn': 'druggist'},
 'drugstores': {'nns_to_nn': 'drugstore'},
 'drums': {'nns_to_nn': 'drum'},
 'drunks': {'nns_to_nn': 'drunk'},
 'drys': {'nns_to_nn': 'dry'},
 'dudes': {'nns_to_nn': 'dude'},
 'dugouts': {'nns_to_nn': 'dugout'},
 'dukes': {'nns_to_nn': 'duke'},
 'dumps': {'nns_to_nn': 'dump', 'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'dump'},
 'duties': {'nns_to_nn': 'duty'},
 'dynamics': {'nns_to_nn': 'dynamic', 'n_is_nc': '', 'n_is_sth': ''},
 'ears': {'nns_to_nn': 'ear'},
 'earthquakes': {'nns_to_nn': 'earthquake'},
 'economists': {'nns_to_nn': 'economist'},
 'economies': {'nns_to_nn': 'economy'},
 'edges': {'nns_to_nn': 'edge', 'vbz_to_vb': 'edge'},
 'editions': {'nns_to_nn': 'edition'},
 'editors': {'nns_to_nn': 'editor'},
 'effects': {'nns_to_nn': 'effect'},
 'efficiencies': {'nns_to_nn': 'efficiency'},
 'efforts': {'nns_to_nn': 'effort'},
 'eggs': {'nns_to_nn': 'egg', 'vbz_to_vb': 'egg'},
 'egyptians': {'nns_to_nn': 'egyptian'},
 'elbows': {'nns_to_nn': 'elbow'},
 'elders': {'nns_to_nn': 'elder'},
 'electronicses': {'nns_to_nn': 'electronics'},
 'elements': {'nns_to_nn': 'element', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'elephants': {'nns_to_nn': 'elephant'},
 'elevators': {'nns_to_nn': 'elevator'},
 'elites': {'nns_to_nn': 'elite'},
 'embassies': {'nns_to_nn': 'embassy'},
 'embraces': {'nns_to_nn': 'embrace'},
 'emergencies': {'nns_to_nn': 'emergency'},
 'emotions': {'nns_to_nn': 'emotion'},
 'emperors': {'nns_to_nn': 'emperor'},
 'empires': {'nns_to_nn': 'empire'},
 'employees': {'nns_to_nn': 'employee'},
 'employers': {'nns_to_nn': 'employer'},
 'encounters': {'nns_to_nn': 'encounter', 'vbz_to_vb': 'encounter'},
 'ends': {'nns_to_nn': 'end'},
 'endorsements': {'nns_to_nn': 'endorsement'},
 'energies': {'nns_to_nn': 'energy'},
 'engines': {'nns_to_nn': 'engine'},
 'engineers': {'nns_to_nn': 'engineer', 'vbz_to_vb': 'engineer'},
 'enterprises': {'nns_to_nn': 'enterprise'},
 'entertainers': {'nns_to_nn': 'entertainer'},
 'enthusiasms': {'nns_to_nn': 'enthusiasm'},
 'entrances': {'nns_to_nn': 'entrance', 'vbz_to_vb': 'entrance'},
 'entries': {'nns_to_nn': 'entry'},
 'envelopes': {'nns_to_nn': 'envelope'},
 'environments': {'nns_to_nn': 'environment'},
 'epics': {'nns_to_nn': 'epic'},
 'epidemics': {'nns_to_nn': 'epidemic'},
 'equals': {'nns_to_nn': 'equal', 'vbz_to_vb': 'equal'},
 'equities': {'nns_to_nn': 'equity'},
 'equivalents': {'nns_to_nn': 'equivalent'},
 'eras': {'nns_to_nn': 'era'},
 'erasers': {'nns_to_nn': 'eraser'},
 'errors': {'nns_to_nn': 'error'},
 'essays': {'nns_to_nn': 'essay'},
 'essentials': {'nns_to_nn': 'essential'},
 'establishments': {'nns_to_nn': 'establishment'},
 'estates': {'nns_to_nn': 'estate'},
 'estimates': {'nns_to_nn': 'estimate', 'vbz_to_vb': 'estimate'},
 'euros': {'nns_to_nn': 'euro'},
 'eves': {'nns_to_nn': 'eve'},
 'events': {'nns_to_nn': 'event'},
 'evidences': {'nns_to_nn': 'evidence'},
 'evils': {'nns_to_nn': 'evil'},
 'evolutions': {'nns_to_nn': 'evolution'},
 'exams': {'nns_to_nn': 'exam'},
 'examinations': {'nns_to_nn': 'examination'},
 'examples': {'nns_to_nn': 'example'},
 'excesses': {'nns_to_nn': 'excess'},
 'excitements': {'nns_to_nn': 'excitement'},
 'excuses': {'nns_to_nn': 'excuse', 'vbz_to_vb': 'excuse'},
 'executions': {'nns_to_nn': 'execution'},
 'executives': {'nns_to_nn': 'executive'},
 'exercises': {'nns_to_nn': 'exercise'},
 'exhibits': {'nns_to_nn': 'exhibit'},
 'exiles': {'nns_to_nn': 'exile'},
 'existences': {'nns_to_nn': 'existence'},
 'exits': {'nns_to_nn': 'exit', 'vbz_to_vb': 'exit'},
 'expectations': {'nns_to_nn': 'expectation'},
 'expenses': {'nns_to_nn': 'expense'},
 'experiences': {'nns_to_nn': 'experience'},
 'experiments': {'nns_to_nn': 'experiment', 'vbz_to_vb': 'experiment'},
 'experts': {'nns_to_nn': 'expert'},
 'explanations': {'nns_to_nn': 'explanation'},
 'explorations': {'nns_to_nn': 'exploration'},
 'explorers': {'nns_to_nn': 'explorer'},
 'explosions': {'nns_to_nn': 'explosion'},
 'explosives': {'nns_to_nn': 'explosive'},
 'exports': {'nns_to_nn': 'export'},
 'exposes': {'nns_to_nn': 'expose', 'vbz_to_vb': 'expose'},
 'exposures': {'nns_to_nn': 'exposure'},
 'expresses': {'nns_to_nn': 'express', 'vbz_to_vb': 'express'},
 'expressions': {'nns_to_nn': 'expression'},
 'extensions': {'nns_to_nn': 'extension'},
 'extras': {'nns_to_nn': 'extra'},
 'extremes': {'nns_to_nn': 'extreme'},
 'eyes': {'nns_to_nn': 'eye', 'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'fabrics': {'nns_to_nn': 'fabric'},
 'faces': {'nns_to_nn': 'face', 'vbz_to_vb': 'face'},
 'facilities': {'nns_to_nn': 'facility'},
 'facings': {'nns_to_nn': 'facing'},
 'facts': {'nns_to_nn': 'fact'},
 'factors': {'nns_to_nn': 'factor', 'vbz_to_vb': 'factor'},
 'faculties': {'nns_to_nn': 'faculty'},
 'failings': {'nns_to_nn': 'failing'},
 'failures': {'nns_to_nn': 'failure'},
 'fairs': {'nns_to_nn': 'fair'},
 'fairytales': {'nns_to_nn': 'fairytale'},
 'fakes': {'nns_to_nn': 'fake'},
 'falls': {'nns_to_nn': 'fall', 'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'fall'},
 'familiars': {'nns_to_nn': 'familiar'},
 'families': {'nns_to_nn': 'family'},
 'fans': {'nns_to_nn': 'fan', 'vbz_to_vb': 'fan'},
 'fancies': {'nns_to_nn': 'fancy', 'vbz_to_vb': 'fancy'},
 'fantasies': {'nns_to_nn': 'fantasy'},
 'fares': {'nns_to_nn': 'fare'},
 'farms': {'nns_to_nn': 'farm', 'vbz_to_vb': 'farm'},
 'farmers': {'nns_to_nn': 'farmer'},
 'fates': {'nns_to_nn': 'fate', 'n_is_sb': '0'},
 'fathers': {'nns_to_nn': 'father'},
 'faucets': {'nns_to_nn': 'faucet'},
 'faults': {'nns_to_nn': 'fault', 'vbz_to_vb': 'fault'},
 'faxs': {'nns_to_nn': 'fax'},
 'feathers': {'nns_to_nn': 'feather'},
 'features': {'nns_to_nn': 'feature', 'vbz_to_vb': 'feature'},
 'federations': {'nns_to_nn': 'federation'},
 'fees': {'nns_to_nn': 'fee'},
 'feedbacks': {'nns_to_nn': 'feedback'},
 'feelings': {'nns_to_nn': 'feeling', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fellows': {'nns_to_nn': 'fellow'},
 'females': {'nns_to_nn': 'female'},
 'fences': {'nns_to_nn': 'fence', 'vbz_to_vb': 'fence'},
 'festivals': {'nns_to_nn': 'festival'},
 'fibers': {'nns_to_nn': 'fiber'},
 'fictions': {'nns_to_nn': 'fiction'},
 'fields': {'nns_to_nn': 'field', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'fights': {'nns_to_nn': 'fight'},
 'fighters': {'nns_to_nn': 'fighter'},
 'figures': {'nns_to_nn': 'figure'},
 'files': {'nns_to_nn': 'file'},
 'fillings': {'nns_to_nn': 'filling'},
 'films': {'nns_to_nn': 'film'},
 'finales': {'nns_to_nn': 'finale'},
 'finds': {'nns_to_nn': 'find'},
 'findings': {'nns_to_nn': 'finding', 'n_is_nc': '', 'n_is_sth': ''},
 'fingers': {'nns_to_nn': 'finger'},
 'firefighters': {'nns_to_nn': 'firefighter'},
 'firms': {'nns_to_nn': 'firm'},
 'fishers': {'nns_to_nn': 'fisher'},
 'fists': {'nns_to_nn': 'fist'},
 'fits': {'nns_to_nn': 'fit'},
 'flags': {'nns_to_nn': 'flag'},
 'flashes': {'nns_to_nn': 'flash', 'vbz_to_vb': 'flash'},
 'flats': {'nns_to_nn': 'flat'},
 'flavors': {'nns_to_nn': 'flavor'},
 'fleets': {'nns_to_nn': 'fleet'},
 'flights': {'nns_to_nn': 'flight'},
 'floats': {'nns_to_nn': 'float'},
 'flocks': {'nns_to_nn': 'flock'},
 'floods': {'nns_to_nn': 'flood', 'vbz_to_vb': 'flood'},
 'floors': {'nns_to_nn': 'floor', 'vbz_to_vb': 'floor'},
 'flowers': {'nns_to_nn': 'flower', 'vbz_to_vb': 'flower'},
 'flus': {'nns_to_nn': 'flu'},
 'folds': {'nns_to_nn': 'fold', 'vbz_to_vb': 'fold'},
 'folks': {'nns_to_nn': 'folk', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'followings': {'nns_to_nn': 'following'},
 'foods': {'nns_to_nn': 'food'},
 'footballs': {'nns_to_nn': 'football'},
 'forecasts': {'nns_to_nn': 'forecast'},
 'forests': {'nns_to_nn': 'forest', 'vbz_to_vb': 'forest'},
 'forks': {'nns_to_nn': 'fork', 'vbz_to_vb': 'fork'},
 'forms': {'nns_to_nn': 'form', 'vbz_to_vb': 'form'},
 'formats': {'nns_to_nn': 'format'},
 'formations': {'nns_to_nn': 'formation'},
 'fortnights': {'nns_to_nn': 'fortnight'},
 'fortunes': {'nns_to_nn': 'fortune'},
 'forums': {'nns_to_nn': 'forum'},
 'fouls': {'nns_to_nn': 'foul'},
 'founders': {'nns_to_nn': 'founder'},
 'foxes': {'nns_to_nn': 'fox'},
 'fractions': {'nns_to_nn': 'fraction'},
 'frames': {'nns_to_nn': 'frame'},
 'freeways': {'nns_to_nn': 'freeway'},
 'freezes': {'nns_to_nn': 'freeze', 'vbz_to_vb': 'freeze'},
 'freezers': {'nns_to_nn': 'freezer'},
 'freshmen': {'nns_to_nn': 'freshman'},
 'fridges': {'nns_to_nn': 'fridge'},
 'friends': {'nns_to_nn': 'friend'},
 'friendships': {'nns_to_nn': 'friendship'},
 'frogs': {'nns_to_nn': 'frog'},
 'fronts': {'nns_to_nn': 'front', 'vbz_to_vb': 'front'},
 'fruits': {'nns_to_nn': 'fruit', 'vbz_to_vb': 'fruit'},
 'frustrations': {'nns_to_nn': 'frustration'},
 'functions': {'nns_to_nn': 'function', 'vbz_to_vb': 'function'},
 'funds': {'nns_to_nn': 'fund', 'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'fund'},
 'fundamentals': {'nns_to_nn': 'fundamental', 'n_is_nc': '', 'n_is_sth': ''},
 'funerals': {'nns_to_nn': 'funeral'},
 'furnitures': {'nns_to_nn': 'furniture'},
 'futures': {'nns_to_nn': 'future'},
 'futurologists': {'nns_to_nn': 'futurologist'},
 'gains': {'nns_to_nn': 'gain', 'vbz_to_vb': 'gain'},
 'galleries': {'nns_to_nn': 'gallery'},
 'gallons': {'nns_to_nn': 'gallon'},
 'gambles': {'nns_to_nn': 'gamble'},
 'gamblings': {'nns_to_nn': 'gambling'},
 'games': {'nns_to_nn': 'game'},
 'gangs': {'nns_to_nn': 'gang', 'vbz_to_vb': 'gang'},
 'gaps': {'nns_to_nn': 'gap'},
 'garages': {'nns_to_nn': 'garage', 'vbz_to_vb': 'garage'},
 'garbages': {'nns_to_nn': 'garbage'},
 'gardens': {'nns_to_nn': 'garden', 'vbz_to_vb': 'garden'},
 'garlics': {'nns_to_nn': 'garlic'},
 'gates': {'nns_to_nn': 'gate', 'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'gathers': {'nns_to_nn': 'gather', 'vbz_to_vb': 'gather'},
 'gauges': {'nns_to_nn': 'gauge'},
 'gays': {'nns_to_nn': 'gay'},
 'gears': {'nns_to_nn': 'gear'},
 'genders': {'nns_to_nn': 'gender'},
 'genes': {'nns_to_nn': 'gene'},
 'generals': {'nns_to_nn': 'general'},
 'generations': {'nns_to_nn': 'generation'},
 'genres': {'nns_to_nn': 'genre'},
 'geographers': {'nns_to_nn': 'geographer'},
 'geologists': {'nns_to_nn': 'geologist'},
 'gestures': {'nns_to_nn': 'gesture'},
 'giants': {'nns_to_nn': 'giant'},
 'gifts': {'nns_to_nn': 'gift'},
 'girls': {'nns_to_nn': 'girl'},
 'girlfriends': {'nns_to_nn': 'girlfriend'},
 'glimpses': {'nns_to_nn': 'glimpse'},
 'globes': {'nns_to_nn': 'globe'},
 'glories': {'nns_to_nn': 'glory'},
 'gloves': {'nns_to_nn': 'glove', 'vbz_to_vb': 'glove'},
 'goals': {'nns_to_nn': 'goal'},
 'goalies': {'nns_to_nn': 'goalie'},
 'gods': {'nns_to_nn': 'god'},
 'golds': {'nns_to_nn': 'gold'},
 'governments': {'nns_to_nn': 'government'},
 'governors': {'nns_to_nn': 'governor'},
 'grabs': {'nns_to_nn': 'grab', 'vbz_to_vb': 'grab'},
 'graces': {'nns_to_nn': 'grace'},
 'grades': {'nns_to_nn': 'grade', 'vbz_to_vb': 'grade'},
 'graduates': {'nns_to_nn': 'graduate'},
 'grains': {'nns_to_nn': 'grain'},
 'grams': {'nns_to_nn': 'gram'},
 'grands': {'nns_to_nn': 'grand'},
 'grandads': {'nns_to_nn': 'grandad'},
 'granddaughters': {'nns_to_nn': 'granddaughter'},
 'grandfathers': {'nns_to_nn': 'grandfather'},
 'grandmas': {'nns_to_nn': 'grandma'},
 'grandmothers': {'nns_to_nn': 'grandmother'},
 'grandparents': {'nns_to_nn': 'grandparent', 'nc_typical': ''},
 'grandsons': {'nns_to_nn': 'grandson'},
 'grants': {'nns_to_nn': 'grant', 'vbz_to_vb': 'grant'},
 'grapes': {'nns_to_nn': 'grape'},
 'grapefruits': {'nns_to_nn': 'grapefruit'},
 'graphs': {'nns_to_nn': 'graph', 'vbz_to_vb': 'graph'},
 'grasses': {'nns_to_nn': 'grass'},
 'graves': {'nns_to_nn': 'grave', 'n_is_sb': '2', 'n_is_sth': '2'},
 'grays': {'nns_to_nn': 'gray'},
 'greeks': {'nns_to_nn': 'greek'},
 'greens': {'nns_to_nn': 'green', 'n_is_nc': '', 'n_is_sth': ''},
 'greys': {'nns_to_nn': 'grey'},
 'grills': {'nns_to_nn': 'grill'},
 'grips': {'nns_to_nn': 'grip'},
 'groups': {'nns_to_nn': 'group'},
 'growths': {'nns_to_nn': 'growth'},
 'guarantees': {'nns_to_nn': 'guarantee', 'vbz_to_vb': 'guarantee'},
 'guards': {'nns_to_nn': 'guard', 'vbz_to_vb': 'guard'},
 'guests': {'nns_to_nn': 'guest'},
 'guidances': {'nns_to_nn': 'guidance'},
 'guides': {'nns_to_nn': 'guide', 'vbz_to_vb': 'guide'},
 'guidebooks': {'nns_to_nn': 'guidebook'},
 'guiders': {'nns_to_nn': 'guider'},
 'guitars': {'nns_to_nn': 'guitar'},
 'gulfs': {'nns_to_nn': 'gulf'},
 'guns': {'nns_to_nn': 'gun'},
 'gunners': {'nns_to_nn': 'gunner'},
 'guys': {'nns_to_nn': 'guy'},
 'gyms': {'nns_to_nn': 'gym'},
 'habits': {'nns_to_nn': 'habit'},
 'hairdressers': {'nns_to_nn': 'hairdresser'},
 'halls': {'nns_to_nn': 'hall'},
 'halts': {'nns_to_nn': 'halt'},
 'hands': {'nns_to_nn': 'hand', 'vbz_to_vb': 'hand'},
 'handbags': {'nns_to_nn': 'handbag'},
 'handles': {'nns_to_nn': 'handle', 'vbz_to_vb': 'handle'},
 'hangings': {'nns_to_nn': 'hanging'},
 'harbors': {'nns_to_nn': 'harbor'},
 'hardwares': {'nns_to_nn': 'hardware'},
 'harvests': {'nns_to_nn': 'harvest'},
 'hats': {'nns_to_nn': 'hat', 'vbz_to_vb': 'hat'},
 'heads': {'nns_to_nn': 'head'},
 'headaches': {'nns_to_nn': 'headache'},
 'headings': {'nns_to_nn': 'heading'},
 'headlines': {'nns_to_nn': 'headline'},
 'headmasters': {'nns_to_nn': 'headmaster'},
 'headteachers': {'nns_to_nn': 'headteacher'},
 'hearings': {'nns_to_nn': 'hearing'},
 'hearts': {'nns_to_nn': 'heart'},
 'heaters': {'nns_to_nn': 'heater'},
 'heavens': {'nns_to_nn': 'heaven', 'n_is_nc': '', 'n_is_sth': ''},
 'heels': {'nns_to_nn': 'heel'},
 'heights': {'nns_to_nn': 'height'},
 'helicopters': {'nns_to_nn': 'helicopter'},
 'helps': {'nns_to_nn': 'help', 'vbz_to_vb': 'help'},
 'heritages': {'nns_to_nn': 'heritage'},
 'heroins': {'nns_to_nn': 'heroin'},
 'hides': {'nns_to_nn': 'hide', 'vbz_to_vb': 'hide'},
 'highlights': {'nns_to_nn': 'highlight', 'vbz_to_vb': 'highlight'},
 'highways': {'nns_to_nn': 'highway'},
 'hikes': {'nns_to_nn': 'hike'},
 'hills': {'nns_to_nn': 'hill'},
 'hints': {'nns_to_nn': 'hint'},
 'hips': {'nns_to_nn': 'hip'},
 'historians': {'nns_to_nn': 'historian'},
 'histories': {'nns_to_nn': 'history'},
 'hits': {'nns_to_nn': 'hit', 'vbz_to_vb': 'hit'},
 'hitlers': {'nns_to_nn': 'hitler'},
 'hockeys': {'nns_to_nn': 'hockey'},
 'holders': {'nns_to_nn': 'holder'},
 'holes': {'nns_to_nn': 'hole', 'vbz_to_vb': 'hole'},
 'holidays': {'nns_to_nn': 'holiday'},
 'hollows': {'nns_to_nn': 'hollow'},
 'holocausts': {'nns_to_nn': 'holocaust'},
 'homes': {'nns_to_nn': 'home'},
 'homelands': {'nns_to_nn': 'homeland'},
 'homers': {'nns_to_nn': 'homer'},
 'hometowns': {'nns_to_nn': 'hometown'},
 'hooks': {'nns_to_nn': 'hook', 'vbz_to_vb': 'hook'},
 'horizons': {'nns_to_nn': 'horizon'},
 'horizontals': {'nns_to_nn': 'horizontal'},
 'horrors': {'nns_to_nn': 'horror'},
 'horses': {'nns_to_nn': 'horse', 'vbz_to_vb': 'horse'},
 'hospitals': {'nns_to_nn': 'hospital'},
 'hosts': {'nns_to_nn': 'host', 'vbz_to_vb': 'host'},
 'hotels': {'nns_to_nn': 'hotel'},
 'hours': {'nns_to_nn': 'hour'},
 'houses': {'nns_to_nn': 'house', 'vbz_to_vb': 'house'},
 'households': {'nns_to_nn': 'household'},
 'housings': {'nns_to_nn': 'housing'},
 'humans': {'nns_to_nn': 'human'},
 'humanitarians': {'nns_to_nn': 'humanitarian'},
 'hundreds': {'nns_to_nn': 'hundred'},
 'hundredpercenters': {'nns_to_nn': 'hundredpercenter'},
 'hundredths': {'nns_to_nn': 'hundredth'},
 'hunts': {'nns_to_nn': 'hunt', 'vbz_to_vb': 'hunt'},
 'hunters': {'nns_to_nn': 'hunter'},
 'hurricanes': {'nns_to_nn': 'hurricane'},
 'husbands': {'nns_to_nn': 'husband'},
 'icons': {'nns_to_nn': 'icon'},
 'ideas': {'nns_to_nn': 'idea'},
 'ideals': {'nns_to_nn': 'ideal'},
 'identifications': {'nns_to_nn': 'identification'},
 'identities': {'nns_to_nn': 'identity'},
 'idiots': {'nns_to_nn': 'idiot'},
 'ills': {'nns_to_nn': 'ill'},
 'illegals': {'nns_to_nn': 'illegal'},
 'illnesses': {'nns_to_nn': 'illness'},
 'illustrations': {'nns_to_nn': 'illustration'},
 'images': {'nns_to_nn': 'image'},
 'imaginations': {'nns_to_nn': 'imagination'},
 'immigrants': {'nns_to_nn': 'immigrant'},
 'immunities': {'nns_to_nn': 'immunity'},
 'implements': {'nns_to_nn': 'implement', 'vbz_to_vb': 'implement'},
 'imports': {'nns_to_nn': 'import', 'vbz_to_vb': 'import'},
 'impressions': {'nns_to_nn': 'impression'},
 'improvements': {'nns_to_nn': 'improvement'},
 'incentives': {'nns_to_nn': 'incentive'},
 'incidents': {'nns_to_nn': 'incident'},
 'increases': {'nns_to_nn': 'increase', 'vbz_to_vb': 'increase'},
 'independents': {'nns_to_nn': 'independent'},
 'indications': {'nns_to_nn': 'indication'},
 'indictments': {'nns_to_nn': 'indictment'},
 'individuals': {'nns_to_nn': 'individual'},
 'industries': {'nns_to_nn': 'industry'},
 'infants': {'nns_to_nn': 'infant'},
 'infections': {'nns_to_nn': 'infection'},
 'ingredients': {'nns_to_nn': 'ingredient'},
 'initials': {'nns_to_nn': 'initial', 'vbz_to_vb': 'initial'},
 'initiatives': {'nns_to_nn': 'initiative'},
 'injuries': {'nns_to_nn': 'injury'},
 'innings': {'nns_to_nn': 'inning', 'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_eq_nns': ''},
 'innocents': {'nns_to_nn': 'innocent'},
 'innovations': {'nns_to_nn': 'innovation'},
 'inquiries': {'nns_to_nn': 'inquiry'},
 'insects': {'nns_to_nn': 'insect'},
 'inserts': {'nns_to_nn': 'insert'},
 'insides': {'nns_to_nn': 'inside'},
 'inspections': {'nns_to_nn': 'inspection'},
 'inspectors': {'nns_to_nn': 'inspector'},
 'inspirations': {'nns_to_nn': 'inspiration'},
 'installations': {'nns_to_nn': 'installation'},
 'instances': {'nns_to_nn': 'instance', 'vbz_to_vb': 'instance'},
 'instants': {'nns_to_nn': 'instant'},
 'institutes': {'nns_to_nn': 'institute', 'vbz_to_vb': 'institute'},
 'instruments': {'nns_to_nn': 'instrument'},
 'insults': {'nns_to_nn': 'insult'},
 'insurers': {'nns_to_nn': 'insurer'},
 'intellectuals': {'nns_to_nn': 'intellectual'},
 'intensities': {'nns_to_nn': 'intensity'},
 'intentions': {'nns_to_nn': 'intention'},
 'interceptions': {'nns_to_nn': 'interception'},
 'interests': {'nns_to_nn': 'interest', 'vbz_to_vb': 'interest'},
 'interiors': {'nns_to_nn': 'interior'},
 'internationals': {'nns_to_nn': 'international'},
 'interpreters': {'nns_to_nn': 'interpreter'},
 'intervals': {'nns_to_nn': 'interval'},
 'interventions': {'nns_to_nn': 'intervention'},
 'interviews': {'nns_to_nn': 'interview', 'vbz_to_vb': 'interview'},
 'intimates': {'nns_to_nn': 'intimate'},
 'introductions': {'nns_to_nn': 'introduction'},
 'invasions': {'nns_to_nn': 'invasion'},
 'inventories': {'nns_to_nn': 'inventory'},
 'investigators': {'nns_to_nn': 'investigator'},
 'investments': {'nns_to_nn': 'investment'},
 'investors': {'nns_to_nn': 'investor'},
 'invitations': {'nns_to_nn': 'invitation'},
 'involvements': {'nns_to_nn': 'involvement'},
 'irons': {'nns_to_nn': 'iron', 'vbz_to_vb': 'iron'},
 'ironies': {'nns_to_nn': 'irony'},
 'islands': {'nns_to_nn': 'island'},
 'issues': {'nns_to_nn': 'issue', 'vbz_to_vb': 'issue'},
 'items': {'nns_to_nn': 'item'},
 'jacks': {'nns_to_nn': 'jack'},
 'jackets': {'nns_to_nn': 'jacket'},
 'jails': {'nns_to_nn': 'jail'},
 'jasmines': {'nns_to_nn': 'jasmine'},
 'jeans': {'nns_to_nn': 'jean'},
 'jerseys': {'nns_to_nn': 'jersey'},
 'jets': {'nns_to_nn': 'jet'},
 'jobs': {'nns_to_nn': 'job'},
 'joins': {'nns_to_nn': 'join', 'vbz_to_vb': 'join'},
 'joinings': {'nns_to_nn': 'joining'},
 'joints': {'nns_to_nn': 'joint', 'vbz_to_vb': 'joint'},
 'jokes': {'nns_to_nn': 'joke', 'vbz_to_vb': 'joke'},
 'journals': {'nns_to_nn': 'journal'},
 'journalists': {'nns_to_nn': 'journalist'},
 'journeys': {'nns_to_nn': 'journey'},
 'joys': {'nns_to_nn': 'joy'},
 'judges': {'nns_to_nn': 'judge', 'vbz_to_vb': 'judge'},
 'judgments': {'nns_to_nn': 'judgment'},
 'juices': {'nns_to_nn': 'juice'},
 'jumps': {'nns_to_nn': 'jump', 'vbz_to_vb': 'jump'},
 'jumpers': {'nns_to_nn': 'jumper'},
 'juniors': {'nns_to_nn': 'junior'},
 'jurisdictions': {'nns_to_nn': 'jurisdiction'},
 'justices': {'nns_to_nn': 'justice'},
 'juveniles': {'nns_to_nn': 'juvenile'},
 'keeps': {'nns_to_nn': 'keep', 'vbz_to_vb': 'keep'},
 'keepers': {'nns_to_nn': 'keeper'},
 'keepsakes': {'nns_to_nn': 'keepsake'},
 'kettles': {'nns_to_nn': 'kettle'},
 'keys': {'nns_to_nn': 'key'},
 'keyboards': {'nns_to_nn': 'keyboard'},
 'kicks': {'nns_to_nn': 'kick', 'vbz_to_vb': 'kick'},
 'kids': {'nns_to_nn': 'kid'},
 'kills': {'nns_to_nn': 'kill', 'vbz_to_vb': 'kill'},
 'killers': {'nns_to_nn': 'killer'},
 'killings': {'nns_to_nn': 'killing'},
 'kilograms': {'nns_to_nn': 'kilogram'},
 'kilometers': {'nns_to_nn': 'kilometer'},
 'kilometres': {'nns_to_nn': 'kilometre'},
 'kinds': {'nns_to_nn': 'kind'},
 'kings': {'nns_to_nn': 'king'},
 'kitchens': {'nns_to_nn': 'kitchen'},
 'knees': {'nns_to_nn': 'knee', 'vbz_to_vb': 'knee'},
 'knights': {'nns_to_nn': 'knight'},
 'knocks': {'nns_to_nn': 'knock', 'vbz_to_vb': 'knock'},
 'knots': {'nns_to_nn': 'knot'},
 'koreans': {'nns_to_nn': 'korean'},
 'labs': {'nns_to_nn': 'lab'},
 'labels': {'nns_to_nn': 'label', 'vbz_to_vb': 'label'},
 'lads': {'nns_to_nn': 'lad'},
 'ladders': {'nns_to_nn': 'ladder', 'vbz_to_vb': 'ladder'},
 'lakes': {'nns_to_nn': 'lake'},
 'lamps': {'nns_to_nn': 'lamp'},
 'lands': {'nns_to_nn': 'land', 'vbz_to_vb': 'land'},
 'landlords': {'nns_to_nn': 'landlord'},
 'landmarks': {'nns_to_nn': 'landmark'},
 'landscapes': {'nns_to_nn': 'landscape', 'vbz_to_vb': 'landscape'},
 'lanes': {'nns_to_nn': 'lane'},
 'languages': {'nns_to_nn': 'language'},
 'laps': {'nns_to_nn': 'lap'},
 'lasers': {'nns_to_nn': 'laser'},
 'lasts': {'nns_to_nn': 'last', 'vbz_to_vb': 'last'},
 'laterns': {'nns_to_nn': 'latern'},
 'latins': {'nns_to_nn': 'latin'},
 'latters': {'nns_to_nn': 'latter'},
 'laughs': {'nns_to_nn': 'laugh', 'vbz_to_vb': 'laugh'},
 'laws': {'nns_to_nn': 'law'},
 'lawns': {'nns_to_nn': 'lawn'},
 'lawyers': {'nns_to_nn': 'lawyer'},
 'lays': {'nns_to_nn': 'lay', 'vbz_to_vb': 'lay'},
 'layers': {'nns_to_nn': 'layer', 'vbz_to_vb': 'layer'},
 'leaders': {'nns_to_nn': 'leader'},
 'leagues': {'nns_to_nn': 'league'},
 'leases': {'nns_to_nn': 'lease'},
 'leathers': {'nns_to_nn': 'leather'},
 'lectures': {'nns_to_nn': 'lecture'},
 'legs': {'nns_to_nn': 'leg', 'n_is_nc': '', 'n_is_sth': ''},
 'legacies': {'nns_to_nn': 'legacy'},
 'legends': {'nns_to_nn': 'legend'},
 'lemons': {'nns_to_nn': 'lemon'},
 'lengths': {'nns_to_nn': 'length'},
 'lessons': {'nns_to_nn': 'lesson'},
 'letters': {'nns_to_nn': 'letter', 'n_is_nc': '', 'n_is_sth': ''},
 'levels': {'nns_to_nn': 'level'},
 'leverages': {'nns_to_nn': 'leverage'},
 'liabilities': {'nns_to_nn': 'liability'},
 'librarians': {'nns_to_nn': 'librarian'},
 'licenses': {'nns_to_nn': 'license'},
 'lids': {'nns_to_nn': 'lid'},
 'lies': {'nns_to_nn': 'lie', 'vbz_to_vb': 'lie'},
 'lifetimes': {'nns_to_nn': 'lifetime'},
 'lifts': {'nns_to_nn': 'lift', 'vbz_to_vb': 'lift'},
 'likelihoods': {'nns_to_nn': 'likelihood'},
 'lilacs': {'nns_to_nn': 'lilac'},
 'lilies': {'nns_to_nn': 'lily'},
 'limits': {'nns_to_nn': 'limit', 'vbz_to_vb': 'limit'},
 'lines': {'nns_to_nn': 'line'},
 'linguists': {'nns_to_nn': 'linguist'},
 'links': {'nns_to_nn': 'link', 'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'link'},
 'lions': {'nns_to_nn': 'lion'},
 'liquids': {'nns_to_nn': 'liquid'},
 'lists': {'nns_to_nn': 'list', 'vbz_to_vb': 'list'},
 'litres': {'nns_to_nn': 'litre'},
 'livers': {'nns_to_nn': 'liver'},
 'livings': {'nns_to_nn': 'living'},
 'loads': {'nns_to_nn': 'load'},
 'loans': {'nns_to_nn': 'loan'},
 'lobbies': {'nns_to_nn': 'lobby'},
 'locations': {'nns_to_nn': 'location'},
 'locators': {'nns_to_nn': 'locator'},
 'locks': {'nns_to_nn': 'lock', 'vbz_to_vb': 'lock'},
 'logs': {'nns_to_nn': 'log'},
 'logics': {'nns_to_nn': 'logic'},
 'logos': {'nns_to_nn': 'logo', 'n_is_nc': '', 'n_is_sth': ''},
 'lords': {'nns_to_nn': 'lord'},
 'losers': {'nns_to_nn': 'loser'},
 'losses': {'nns_to_nn': 'loss'},
 'lotteries': {'nns_to_nn': 'lottery'},
 'lotuses': {'nns_to_nn': 'lotus'},
 'lounges': {'nns_to_nn': 'lounge'},
 'loves': {'nns_to_nn': 'love', 'vbz_to_vb': 'love'},
 'lovers': {'nns_to_nn': 'lover'},
 'lows': {'nns_to_nn': 'low'},
 'loyalties': {'nns_to_nn': 'loyalty'},
 'lumps': {'nns_to_nn': 'lump'},
 'lunches': {'nns_to_nn': 'lunch'},
 'lungs': {'nns_to_nn': 'lung'},
 'lures': {'nns_to_nn': 'lure'},
 'luxuries': {'nns_to_nn': 'luxury'},
 'macs': {'nns_to_nn': 'mac'},
 'machines': {'nns_to_nn': 'machine'},
 'machineries': {'nns_to_nn': 'machinery'},
 'madams': {'nns_to_nn': 'madam'},
 'magazines': {'nns_to_nn': 'magazine'},
 'magnolias': {'nns_to_nn': 'magnolia'},
 'mails': {'nns_to_nn': 'mail', 'vbz_to_vb': 'mail'},
 'majors': {'nns_to_nn': 'major'},
 'makes': {'nns_to_nn': 'make', 'vbz_to_vb': 'make'},
 'males': {'nns_to_nn': 'male'},
 'malls': {'nns_to_nn': 'mall'},
 'managers': {'nns_to_nn': 'manager'},
 'mandates': {'nns_to_nn': 'mandate'},
 'manners': {'nns_to_nn': 'manner', 'n_is_nc': '', 'n_is_sth': ''},
 'mansions': {'nns_to_nn': 'mansion'},
 'manuals': {'nns_to_nn': 'manual'},
 'manufacturers': {'nns_to_nn': 'manufacturer'},
 'maps': {'nns_to_nn': 'map'},
 'margins': {'nns_to_nn': 'margin'},
 'marines': {'nns_to_nn': 'marine'},
 'marks': {'nns_to_nn': 'mark', 'n_is_sb': '2', 'vbz_to_vb': 'mark', 'n_is_sth': '2'},
 'markets': {'nns_to_nn': 'market'},
 'marketplaces': {'nns_to_nn': 'marketplace'},
 'marriages': {'nns_to_nn': 'marriage'},
 'masters': {'nns_to_nn': 'master', 'n_is_sb': '0'},
 'materials': {'nns_to_nn': 'material'},
 'mathematicians': {'nns_to_nn': 'mathematician'},
 'mayors': {'nns_to_nn': 'mayor'},
 'meals': {'nns_to_nn': 'meal'},
 'meanings': {'nns_to_nn': 'meaning'},
 'measures': {'nns_to_nn': 'measure', 'vbz_to_vb': 'measure'},
 'medals': {'nns_to_nn': 'medal'},
 'medicals': {'nns_to_nn': 'medical'},
 'medications': {'nns_to_nn': 'medication'},
 'meetings': {'nns_to_nn': 'meeting'},
 'melons': {'nns_to_nn': 'melon'},
 'members': {'nns_to_nn': 'member'},
 'memberships': {'nns_to_nn': 'membership'},
 'memos': {'nns_to_nn': 'memo'},
 'memorials': {'nns_to_nn': 'memorial'},
 'memories': {'nns_to_nn': 'memory'},
 'menus': {'nns_to_nn': 'menu'},
 'merchants': {'nns_to_nn': 'merchant'},
 'meres': {'nns_to_nn': 'mere'},
 'messes': {'nns_to_nn': 'mess', 'vbz_to_vb': 'mess'},
 'messages': {'nns_to_nn': 'message'},
 'methods': {'nns_to_nn': 'method'},
 'metros': {'nns_to_nn': 'metro'},
 'middles': {'nns_to_nn': 'middle'},
 'midways': {'nns_to_nn': 'midway'},
 'mikes': {'nns_to_nn': 'mike'},
 'miles': {'nns_to_nn': 'mile'},
 'militants': {'nns_to_nn': 'militant'},
 'millers': {'nns_to_nn': 'miller'},
 'milligrams': {'nns_to_nn': 'milligram'},
 'millimetres': {'nns_to_nn': 'millimetre'},
 'millions': {'nns_to_nn': 'million'},
 'millionaires': {'nns_to_nn': 'millionaire'},
 'mines': {'nns_to_nn': 'mine'},
 'minerals': {'nns_to_nn': 'mineral'},
 'ministers': {'nns_to_nn': 'minister'},
 'minors': {'nns_to_nn': 'minor'},
 'minorities': {'nns_to_nn': 'minority'},
 'minutes': {'nns_to_nn': 'minute'},
 'minuteses': {'nns_to_nn': 'minutes'},
 'miracles': {'nns_to_nn': 'miracle'},
 'mirrors': {'nns_to_nn': 'mirror'},
 'misconducts': {'nns_to_nn': 'misconduct'},
 'missiles': {'nns_to_nn': 'missile'},
 'missions': {'nns_to_nn': 'mission'},
 'mistakes': {'nns_to_nn': 'mistake'},
 'mixtures': {'nns_to_nn': 'mixture'},
 'mobs': {'nns_to_nn': 'mob'},
 'mobiles': {'nns_to_nn': 'mobile'},
 'mobilephones': {'nns_to_nn': 'mobilephone'},
 'modes': {'nns_to_nn': 'mode'},
 'models': {'nns_to_nn': 'model'},
 'moments': {'nns_to_nn': 'moment'},
 'monitors': {'nns_to_nn': 'monitor', 'vbz_to_vb': 'monitor'},
 'monopolies': {'nns_to_nn': 'monopoly'},
 'monsters': {'nns_to_nn': 'monster'},
 'months': {'nns_to_nn': 'month'},
 'moods': {'nns_to_nn': 'mood'},
 'moons': {'nns_to_nn': 'moon'},
 'morals': {'nns_to_nn': 'moral', 'n_is_nc': '', 'n_is_sth': ''},
 'mornings': {'nns_to_nn': 'morning'},
 'mortgages': {'nns_to_nn': 'mortgage'},
 'mothers': {'nns_to_nn': 'mother'},
 'motions': {'nns_to_nn': 'motion'},
 'motors': {'nns_to_nn': 'motor'},
 'motorbikes': {'nns_to_nn': 'motorbike'},
 'motorways': {'nns_to_nn': 'motorway'},
 'mounds': {'nns_to_nn': 'mound'},
 'mounts': {'nns_to_nn': 'mount'},
 'mountains': {'nns_to_nn': 'mountain'},
 'mouths': {'nns_to_nn': 'mouth'},
 'moves': {'nns_to_nn': 'move', 'vbz_to_vb': 'move'},
 'movements': {'nns_to_nn': 'movement'},
 'movies': {'nns_to_nn': 'movie'},
 'muds': {'nns_to_nn': 'mud'},
 'multiples': {'nns_to_nn': 'multiple'},
 'murphies': {'nns_to_nn': 'murphy'},
 'muscles': {'nns_to_nn': 'muscle'},
 'museums': {'nns_to_nn': 'museum'},
 'mushrooms': {'nns_to_nn': 'mushroom'},
 'musicians': {'nns_to_nn': 'musician'},
 'muslims': {'nns_to_nn': 'muslim'},
 'nails': {'nns_to_nn': 'nail'},
 'names': {'nns_to_nn': 'name', 'vbz_to_vb': 'name'},
 'narcissi': {'nns_to_nn': 'narcissus'},
 'narratives': {'nns_to_nn': 'narrative'},
 'nations': {'nns_to_nn': 'nation'},
 'nationals': {'nns_to_nn': 'national'},
 'naturals': {'nns_to_nn': 'natural'},
 'navies': {'nns_to_nn': 'navy'},
 'nazis': {'nns_to_nn': 'nazi'},
 'necks': {'nns_to_nn': 'neck'},
 'needles': {'nns_to_nn': 'needle'},
 'negatives': {'nns_to_nn': 'negative'},
 'neighbors': {'nns_to_nn': 'neighbor'},
 'neighbours': {'nns_to_nn': 'neighbour'},
 'neighbourhoods': {'nns_to_nn': 'neighbourhood'},
 'nephews': {'nns_to_nn': 'nephew'},
 'nests': {'nns_to_nn': 'nest'},
 'networks': {'nns_to_nn': 'network'},
 'neutrals': {'nns_to_nn': 'neutral'},
 'newsletters': {'nns_to_nn': 'newsletter'},
 'newspapers': {'nns_to_nn': 'newspaper'},
 'niches': {'nns_to_nn': 'niche'},
 'nicknames': {'nns_to_nn': 'nickname'},
 'nieces': {'nns_to_nn': 'niece'},
 'nights': {'nns_to_nn': 'night'},
 'nightmares': {'nns_to_nn': 'nightmare'},
 'nobles': {'nns_to_nn': 'noble'},
 'noises': {'nns_to_nn': 'noise'},
 'northeasts': {'nns_to_nn': 'northeast'},
 'noses': {'nns_to_nn': 'nose'},
 'notables': {'nns_to_nn': 'notable'},
 'notes': {'nns_to_nn': 'note', 'vbz_to_vb': 'note'},
 'notebooks': {'nns_to_nn': 'notebook'},
 'notices': {'nns_to_nn': 'notice', 'vbz_to_vb': 'notice'},
 'notions': {'nns_to_nn': 'notion'},
 'novels': {'nns_to_nn': 'novel'},
 'novelists': {'nns_to_nn': 'novelist'},
 'nuisances': {'nns_to_nn': 'nuisance'},
 'nurses': {'nns_to_nn': 'nurse'},
 'nuts': {'nns_to_nn': 'nut'},
 'objects': {'nns_to_nn': 'object', 'vbz_to_vb': 'object'},
 'objections': {'nns_to_nn': 'objection'},
 'objectives': {'nns_to_nn': 'objective'},
 'obligations': {'nns_to_nn': 'obligation'},
 'occasions': {'nns_to_nn': 'occasion'},
 'occupations': {'nns_to_nn': 'occupation'},
 'oceans': {'nns_to_nn': 'ocean'},
 'offers': {'nns_to_nn': 'offer', 'vbz_to_vb': 'offer'},
 'offices': {'nns_to_nn': 'office'},
 'officers': {'nns_to_nn': 'officer'},
 'officials': {'nns_to_nn': 'official'},
 'onions': {'nns_to_nn': 'onion'},
 'openers': {'nns_to_nn': 'opener'},
 'operas': {'nns_to_nn': 'opera'},
 'operators': {'nns_to_nn': 'operator'},
 'opinions': {'nns_to_nn': 'opinion'},
 'opponents': {'nns_to_nn': 'opponent'},
 'opportunities': {'nns_to_nn': 'opportunity'},
 'options': {'nns_to_nn': 'option'},
 'oranges': {'nns_to_nn': 'orange'},
 'orchestras': {'nns_to_nn': 'orchestra'},
 'orders': {'nns_to_nn': 'order', 'vbz_to_vb': 'order'},
 'organs': {'nns_to_nn': 'organ'},
 'organics': {'nns_to_nn': 'organic'},
 'organizations': {'nns_to_nn': 'organization'},
 'origins': {'nns_to_nn': 'origin'},
 'originals': {'nns_to_nn': 'original'},
 'orphans': {'nns_to_nn': 'orphan'},
 'ounces': {'nns_to_nn': 'ounce'},
 'outs': {'nns_to_nn': 'out'},
 'outcomes': {'nns_to_nn': 'outcome'},
 'outputs': {'nns_to_nn': 'output'},
 'ovens': {'nns_to_nn': 'oven'},
 'overalls': {'nns_to_nn': 'overall'},
 'overhauls': {'nns_to_nn': 'overhaul'},
 'overheads': {'nns_to_nn': 'overhead'},
 'owners': {'nns_to_nn': 'owner'},
 'paces': {'nns_to_nn': 'pace'},
 'packs': {'nns_to_nn': 'pack', 'vbz_to_vb': 'pack'},
 'packages': {'nns_to_nn': 'package'},
 'packets': {'nns_to_nn': 'packet'},
 'pacts': {'nns_to_nn': 'pact'},
 'pads': {'nns_to_nn': 'pad'},
 'pages': {'nns_to_nn': 'page'},
 'pains': {'nns_to_nn': 'pain', 'n_is_nc': '', 'n_is_sth': ''},
 'painters': {'nns_to_nn': 'painter'},
 'pairs': {'nns_to_nn': 'pair'},
 'palaces': {'nns_to_nn': 'palace'},
 'pales': {'nns_to_nn': 'pale'},
 'palms': {'nns_to_nn': 'palm'},
 'pans': {'nns_to_nn': 'pan'},
 'panels': {'nns_to_nn': 'panel'},
 'panics': {'nns_to_nn': 'panic'},
 'parades': {'nns_to_nn': 'parade'},
 'parallels': {'nns_to_nn': 'parallel'},
 'parcels': {'nns_to_nn': 'parcel'},
 'parents': {'nns_to_nn': 'parent'},
 'parks': {'nns_to_nn': 'park', 'n_is_sb': '0', 'vbz_to_vb': 'park'},
 'parliaments': {'nns_to_nn': 'parliament'},
 'paroles': {'nns_to_nn': 'parole'},
 'parts': {'nns_to_nn': 'part', 'n_is_nc': '', 'n_is_sth': ''},
 'partisans': {'nns_to_nn': 'partisan'},
 'partners': {'nns_to_nn': 'partner'},
 'partnerships': {'nns_to_nn': 'partnership'},
 'passages': {'nns_to_nn': 'passage'},
 'passengers': {'nns_to_nn': 'passenger'},
 'passers': {'nns_to_nn': 'passer'},
 'passions': {'nns_to_nn': 'passion'},
 'passports': {'nns_to_nn': 'passport'},
 'pasts': {'nns_to_nn': 'past'},
 'pastas': {'nns_to_nn': 'pasta'},
 'pastors': {'nns_to_nn': 'pastor'},
 'pats': {'nns_to_nn': 'pat'},
 'patents': {'nns_to_nn': 'patent'},
 'paths': {'nns_to_nn': 'path'},
 'patients': {'nns_to_nn': 'patient'},
 'patrols': {'nns_to_nn': 'patrol'},
 'patterns': {'nns_to_nn': 'pattern'},
 'pauses': {'nns_to_nn': 'pause', 'vbz_to_vb': 'pause'},
 'payments': {'nns_to_nn': 'payment'},
 'peaks': {'nns_to_nn': 'peak'},
 'pears': {'nns_to_nn': 'pear'},
 'pens': {'nns_to_nn': 'pen'},
 'pencils': {'nns_to_nn': 'pencil'},
 'pensions': {'nns_to_nn': 'pension'},
 'peonies': {'nns_to_nn': 'peony'},
 'peppers': {'nns_to_nn': 'pepper'},
 'percents': {'nns_to_nn': 'percent'},
 'percentages': {'nns_to_nn': 'percentage'},
 'perceptions': {'nns_to_nn': 'perception'},
 'performances': {'nns_to_nn': 'performance'},
 'performers': {'nns_to_nn': 'performer'},
 'periods': {'nns_to_nn': 'period'},
 'permanents': {'nns_to_nn': 'permanent'},
 'permissions': {'nns_to_nn': 'permission'},
 'permits': {'nns_to_nn': 'permit', 'vbz_to_vb': 'permit'},
 'persons': {'nns_to_nn': 'person', 'nn_to_jj': 'personality'},
 'personalities': {'nns_to_nn': 'personality'},
 'perspectives': {'nns_to_nn': 'perspective'},
 'pesos': {'nns_to_nn': 'peso'},
 'pets': {'nns_to_nn': 'pet'},
 'petitions': {'nns_to_nn': 'petition'},
 'pharmaceuticals': {'nns_to_nn': 'pharmaceutical'},
 'phases': {'nns_to_nn': 'phase'},
 'philosophers': {'nns_to_nn': 'philosopher'},
 'philosophies': {'nns_to_nn': 'philosophy'},
 'phones': {'nns_to_nn': 'phone', 'vbz_to_vb': 'phone'},
 'photos': {'nns_to_nn': 'photo'},
 'photographs': {'nns_to_nn': 'photograph'},
 'photographers': {'nns_to_nn': 'photographer'},
 'phrases': {'nns_to_nn': 'phrase'},
 'physicals': {'nns_to_nn': 'physical'},
 'physicians': {'nns_to_nn': 'physician'},
 'physicists': {'nns_to_nn': 'physicist'},
 'physiologists': {'nns_to_nn': 'physiologist'},
 'pianists': {'nns_to_nn': 'pianist'},
 'pianos': {'nns_to_nn': 'piano'},
 'piazzas': {'nns_to_nn': 'piazza'},
 'pickups': {'nns_to_nn': 'pickup'},
 'pictures': {'nns_to_nn': 'picture'},
 'pies': {'nns_to_nn': 'pie'},
 'pieces': {'nns_to_nn': 'piece'},
 'pigs': {'nns_to_nn': 'pig'},
 'piles': {'nns_to_nn': 'pile', 'n_is_nc': '', 'n_is_sth': ''},
 'pills': {'nns_to_nn': 'pill'},
 'pilots': {'nns_to_nn': 'pilot'},
 'pins': {'nns_to_nn': 'pin'},
 'pines': {'nns_to_nn': 'pine'},
 'pineapples': {'nns_to_nn': 'pineapple'},
 'pinks': {'nns_to_nn': 'pink'},
 'pints': {'nns_to_nn': 'pint'},
 'pioneers': {'nns_to_nn': 'pioneer'},
 'pipes': {'nns_to_nn': 'pipe'},
 'pipelines': {'nns_to_nn': 'pipeline'},
 'pits': {'nns_to_nn': 'pit'},
 'pitches': {'nns_to_nn': 'pitch'},
 'places': {'nns_to_nn': 'place', 'vbz_to_vb': 'place'},
 'plains': {'nns_to_nn': 'plain'},
 'plans': {'nns_to_nn': 'plan', 'vbz_to_vb': 'plan'},
 'planes': {'nns_to_nn': 'plane'},
 'planets': {'nns_to_nn': 'planet'},
 'plants': {'nns_to_nn': 'plant'},
 'plates': {'nns_to_nn': 'plate'},
 'platforms': {'nns_to_nn': 'platform'},
 'players': {'nns_to_nn': 'player'},
 'playwrights': {'nns_to_nn': 'playwright'},
 'pleas': {'nns_to_nn': 'plea'},
 'pleasures': {'nns_to_nn': 'pleasure'},
 'pledges': {'nns_to_nn': 'pledge'},
 'plots': {'nns_to_nn': 'plot'},
 'plugs': {'nns_to_nn': 'plug'},
 'plums': {'nns_to_nn': 'plum'},
 'plunges': {'nns_to_nn': 'plunge'},
 'pockets': {'nns_to_nn': 'pocket'},
 'poems': {'nns_to_nn': 'poem'},
 'poets': {'nns_to_nn': 'poet'},
 'points': {'nns_to_nn': 'point', 'vbz_to_vb': 'point'},
 'poles': {'nns_to_nn': 'pole'},
 'policies': {'nns_to_nn': 'policy'},
 'politicians': {'nns_to_nn': 'politician'},
 'polls': {'nns_to_nn': 'poll'},
 'pomegranates': {'nns_to_nn': 'pomegranate'},
 'ponds': {'nns_to_nn': 'pond'},
 'pools': {'nns_to_nn': 'pool'},
 'pops': {'nns_to_nn': 'pop', 'vbz_to_vb': 'pop'},
 'popes': {'nns_to_nn': 'pope'},
 'populations': {'nns_to_nn': 'population'},
 'ports': {'nns_to_nn': 'port'},
 'porters': {'nns_to_nn': 'porter'},
 'portfolios': {'nns_to_nn': 'portfolio'},
 'portions': {'nns_to_nn': 'portion'},
 'portraits': {'nns_to_nn': 'portrait'},
 'poses': {'nns_to_nn': 'pose', 'vbz_to_vb': 'pose'},
 'positions': {'nns_to_nn': 'position'},
 'positives': {'nns_to_nn': 'positive'},
 'possessions': {'nns_to_nn': 'possession'},
 'possibilities': {'nns_to_nn': 'possibility'},
 'posts': {'nns_to_nn': 'post', 'vbz_to_vb': 'post'},
 'posters': {'nns_to_nn': 'poster'},
 'pots': {'nns_to_nn': 'pot'},
 'pounds': {'nns_to_nn': 'pound'},
 'praises': {'nns_to_nn': 'praise'},
 'prayers': {'nns_to_nn': 'prayer'},
 'predecessors': {'nns_to_nn': 'predecessor'},
 'pregnancies': {'nns_to_nn': 'pregnancy'},
 'preliminaries': {'nns_to_nn': 'preliminary'},
 'premiers': {'nns_to_nn': 'premier'},
 'premises': {'nns_to_nn': 'premise', 'n_is_nc': '', 'n_is_sth': ''},
 'premiums': {'nns_to_nn': 'premium'},
 'preparations': {'nns_to_nn': 'preparation'},
 'prescriptions': {'nns_to_nn': 'prescription'},
 'presents': {'nns_to_nn': 'present', 'vbz_to_vb': 'present'},
 'presentations': {'nns_to_nn': 'presentation'},
 'preserves': {'nns_to_nn': 'preserve', 'vbz_to_vb': 'preserve'},
 'presidencies': {'nns_to_nn': 'presidency'},
 'presidents': {'nns_to_nn': 'president'},
 'pressings': {'nns_to_nn': 'pressing'},
 'prices': {'nns_to_nn': 'price'},
 'priests': {'nns_to_nn': 'priest'},
 'princes': {'nns_to_nn': 'prince'},
 'principles': {'nns_to_nn': 'principle'},
 'prints': {'nns_to_nn': 'print', 'vbz_to_vb': 'print'},
 'printers': {'nns_to_nn': 'printer'},
 'priors': {'nns_to_nn': 'prior'},
 'prisons': {'nns_to_nn': 'prison'},
 'prisoners': {'nns_to_nn': 'prisoner'},
 'privates': {'nns_to_nn': 'private', 'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'privileges': {'nns_to_nn': 'privilege'},
 'prizes': {'nns_to_nn': 'prize'},
 'pros': {'nns_to_nn': 'pro'},
 'probes': {'nns_to_nn': 'probe'},
 'problems': {'nns_to_nn': 'problem'},
 'procedures': {'nns_to_nn': 'procedure'},
 'proceedings': {'nns_to_nn': 'proceeding'},
 'producers': {'nns_to_nn': 'producer'},
 'products': {'nns_to_nn': 'product'},
 'professions': {'nns_to_nn': 'profession'},
 'professionals': {'nns_to_nn': 'professional'},
 'professors': {'nns_to_nn': 'professor'},
 'profiles': {'nns_to_nn': 'profile'},
 'programs': {'nns_to_nn': 'program'},
 'programmes': {'nns_to_nn': 'programme'},
 'projects': {'nns_to_nn': 'project'},
 'promotions': {'nns_to_nn': 'promotion'},
 'prompts': {'nns_to_nn': 'prompt'},
 'proofs': {'nns_to_nn': 'proof'},
 'properties': {'nns_to_nn': 'property'},
 'proportions': {'nns_to_nn': 'proportion'},
 'proposals': {'nns_to_nn': 'proposal'},
 'prosecutions': {'nns_to_nn': 'prosecution'},
 'prosecutors': {'nns_to_nn': 'prosecutor'},
 'prospects': {'nns_to_nn': 'prospect'},
 'prosperities': {'nns_to_nn': 'prosperity'},
 'proteins': {'nns_to_nn': 'protein'},
 'provinces': {'nns_to_nn': 'province'},
 'provisionses': {'nns_to_nn': 'provisions'},
 'psychologies': {'nns_to_nn': 'psychology'},
 'pubs': {'nns_to_nn': 'pub'},
 'publics': {'nns_to_nn': 'public'},
 'publications': {'nns_to_nn': 'publication'},
 'pucks': {'nns_to_nn': 'puck'},
 'pumps': {'nns_to_nn': 'pump'},
 'punches': {'nns_to_nn': 'punch', 'vbz_to_vb': 'punch'},
 'punishments': {'nns_to_nn': 'punishment'},
 'pupils': {'nns_to_nn': 'pupil'},
 'purples': {'nns_to_nn': 'purple'},
 'purposes': {'nns_to_nn': 'purpose'},
 'purses': {'nns_to_nn': 'purse'},
 'pursuits': {'nns_to_nn': 'pursuit'},
 'quarters': {'nns_to_nn': 'quarter', 'n_is_nc': '', 'n_is_sth': ''},
 'quarterlies': {'nns_to_nn': 'quarterly'},
 'queens': {'nns_to_nn': 'queen'},
 'quests': {'nns_to_nn': 'quest'},
 'questions': {'nns_to_nn': 'question', 'vbz_to_vb': 'question'},
 'queues': {'nns_to_nn': 'queue'},
 'quids': {'nns_to_nn': 'quid'},
 'quotes': {'nns_to_nn': 'quote', 'vbz_to_vb': 'quote'},
 'races': {'nns_to_nn': 'race', 'vbz_to_vb': 'race'},
 'radars': {'nns_to_nn': 'radar'},
 'radiations': {'nns_to_nn': 'radiation'},
 'radicals': {'nns_to_nn': 'radical'},
 'radios': {'nns_to_nn': 'radio'},
 'rages': {'nns_to_nn': 'rage'},
 'rails': {'nns_to_nn': 'rail', 'vbz_to_vb': 'rail'},
 'railroads': {'nns_to_nn': 'railroad'},
 'railways': {'nns_to_nn': 'railway'},
 'raises': {'nns_to_nn': 'raise', 'vbz_to_vb': 'raise'},
 'rallies': {'nns_to_nn': 'rally'},
 'ranks': {'nns_to_nn': 'rank', 'vbz_to_vb': 'rank'},
 'raps': {'nns_to_nn': 'rap'},
 'rapes': {'nns_to_nn': 'rape'},
 'rapids': {'nns_to_nn': 'rapid'},
 'rates': {'nns_to_nn': 'rate', 'vbz_to_vb': 'rate'},
 'ratings': {'nns_to_nn': 'rating'},
 'ratios': {'nns_to_nn': 'ratio'},
 'rays': {'nns_to_nn': 'ray'},
 'readers': {'nns_to_nn': 'reader'},
 'readings': {'nns_to_nn': 'reading'},
 'realities': {'nns_to_nn': 'reality'},
 'rears': {'nns_to_nn': 'rear'},
 'reasons': {'nns_to_nn': 'reason', 'vbz_to_vb': 'reason'},
 'rebels': {'nns_to_nn': 'rebel'},
 'recalls': {'nns_to_nn': 'recall', 'vbz_to_vb': 'recall'},
 'receivers': {'nns_to_nn': 'receiver'},
 'receptions': {'nns_to_nn': 'reception'},
 'receptionists': {'nns_to_nn': 'receptionist'},
 'recipes': {'nns_to_nn': 'recipe'},
 'recommendations': {'nns_to_nn': 'recommendation'},
 'records': {'nns_to_nn': 'record', 'vbz_to_vb': 'record'},
 'recordings': {'nns_to_nn': 'recording'},
 'recounts': {'nns_to_nn': 'recount'},
 'recoveries': {'nns_to_nn': 'recovery'},
 'reds': {'nns_to_nn': 'red'},
 'reductions': {'nns_to_nn': 'reduction'},
 'reeds': {'nns_to_nn': 'reed'},
 'references': {'nns_to_nn': 'reference'},
 'referendums': {'nns_to_nn': 'referendum'},
 'refrigerators': {'nns_to_nn': 'refrigerator'},
 'refuges': {'nns_to_nn': 'refuge'},
 'refugees': {'nns_to_nn': 'refugee'},
 'regards': {'nns_to_nn': 'regard', 'vbz_to_vb': 'regard'},
 'regimes': {'nns_to_nn': 'regime'},
 'regions': {'nns_to_nn': 'region'},
 'registrations': {'nns_to_nn': 'registration'},
 'regulations': {'nns_to_nn': 'regulation'},
 'rejects': {'nns_to_nn': 'reject', 'vbz_to_vb': 'reject'},
 'relationships': {'nns_to_nn': 'relationship'},
 'relatives': {'nns_to_nn': 'relative'},
 'releases': {'nns_to_nn': 'release', 'vbz_to_vb': 'release'},
 'reliefs': {'nns_to_nn': 'relief'},
 'remainders': {'nns_to_nn': 'remainder'},
 'reminders': {'nns_to_nn': 'reminder'},
 'removes': {'nns_to_nn': 'remove', 'vbz_to_vb': 'remove'},
 'rents': {'nns_to_nn': 'rent', 'vbz_to_vb': 'rent'},
 'rentals': {'nns_to_nn': 'rental'},
 'reorganizations': {'nns_to_nn': 'reorganization'},
 'repairs': {'nns_to_nn': 'repair', 'vbz_to_vb': 'repair'},
 'repeats': {'nns_to_nn': 'repeat', 'vbz_to_vb': 'repeat'},
 'replacements': {'nns_to_nn': 'replacement'},
 'reports': {'nns_to_nn': 'report', 'vbz_to_vb': 'report'},
 'reporters': {'nns_to_nn': 'reporter'},
 'representatives': {'nns_to_nn': 'representative'},
 'republics': {'nns_to_nn': 'republic'},
 'republicans': {'nns_to_nn': 'republican'},
 'reputations': {'nns_to_nn': 'reputation'},
 'requests': {'nns_to_nn': 'request', 'vbz_to_vb': 'request'},
 'requirements': {'nns_to_nn': 'requirement'},
 'researches': {'nns_to_nn': 'research', 'vbz_to_vb': 'research'},
 'researchers': {'nns_to_nn': 'researcher'},
 'reserves': {'nns_to_nn': 'reserve', 'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'reserve', 'rb_to_nn': 'reserve', 'rb_to_jj': 'reservations', 'rb_to_vb': 'reserve'},
 'residences': {'nns_to_nn': 'residence'},
 'residents': {'nns_to_nn': 'resident'},
 'resignations': {'nns_to_nn': 'resignation'},
 'resolutions': {'nns_to_nn': 'resolution'},
 'resorts': {'nns_to_nn': 'resort', 'vbz_to_vb': 'resort'},
 'responses': {'nns_to_nn': 'response'},
 'restaurants': {'nns_to_nn': 'restaurant'},
 'resumes': {'nns_to_nn': 'resume'},
 'retailers': {'nns_to_nn': 'retailer'},
 'retreats': {'nns_to_nn': 'retreat'},
 'returns': {'nns_to_nn': 'return', 'vbz_to_vb': 'return'},
 'reunions': {'nns_to_nn': 'reunion'},
 'revenues': {'nns_to_nn': 'revenue'},
 'reverses': {'nns_to_nn': 'reverse', 'vbz_to_vb': 'reverse'},
 'revivals': {'nns_to_nn': 'revival'},
 'revolutionaries': {'nns_to_nn': 'revolutionary'},
 'rewards': {'nns_to_nn': 'reward', 'vbz_to_vb': 'reward'},
 'rhetorics': {'nns_to_nn': 'rhetoric'},
 'rhododendra': {'nns_to_nn': 'rhododendron'},
 'rhythms': {'nns_to_nn': 'rhythm'},
 'rices': {'nns_to_nn': 'rice'},
 'rides': {'nns_to_nn': 'ride', 'vbz_to_vb': 'ride'},
 'riders': {'nns_to_nn': 'rider'},
 'ridings': {'nns_to_nn': 'riding'},
 'rights': {'nns_to_nn': 'right'},
 'rings': {'nns_to_nn': 'ring', 'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'ring'},
 'rips': {'nns_to_nn': 'rip', 'vbz_to_vb': 'rip'},
 'rituals': {'nns_to_nn': 'ritual'},
 'rivals': {'nns_to_nn': 'rival', 'vbz_to_vb': 'rival'},
 'rivalries': {'nns_to_nn': 'rivalry'},
 'rivers': {'nns_to_nn': 'river'},
 'roads': {'nns_to_nn': 'road'},
 'robberies': {'nns_to_nn': 'robbery'},
 'roberts': {'nns_to_nn': 'robert', 'n_is_sb': '0'},
 'rocks': {'nns_to_nn': 'rock', 'vbz_to_vb': 'rock'},
 'rockets': {'nns_to_nn': 'rocket'},
 'roles': {'nns_to_nn': 'role'},
 'rolls': {'nns_to_nn': 'roll', 'vbz_to_vb': 'roll'},
 'romances': {'nns_to_nn': 'romance'},
 'romantics': {'nns_to_nn': 'romantic'},
 'roofs': {'nns_to_nn': 'roof', 'vbz_to_vb': 'roof'},
 'rooms': {'nns_to_nn': 'room'},
 'roots': {'nns_to_nn': 'root', 'vbz_to_vb': 'root'},
 'roses': {'nns_to_nn': 'rose'},
 'rosters': {'nns_to_nn': 'roster'},
 'rotations': {'nns_to_nn': 'rotation'},
 'roughs': {'nns_to_nn': 'rough'},
 'routes': {'nns_to_nn': 'route', 'vbz_to_vb': 'route'},
 'routines': {'nns_to_nn': 'routine'},
 'rows': {'nns_to_nn': 'row', 'vbz_to_vb': 'row'},
 'royals': {'nns_to_nn': 'royal'},
 'rubbers': {'nns_to_nn': 'rubber'},
 'rules': {'nns_to_nn': 'rule', 'vbz_to_vb': 'rule'},
 'rulers': {'nns_to_nn': 'ruler'},
 'rulings': {'nns_to_nn': 'ruling'},
 'runners': {'nns_to_nn': 'runner'},
 'runnings': {'nns_to_nn': 'running'},
 'runways': {'nns_to_nn': 'runway'},
 'sacks': {'nns_to_nn': 'sack', 'vbz_to_vb': 'sack'},
 'safeblowers': {'nns_to_nn': 'safeblower'},
 'safecrackers': {'nns_to_nn': 'safecracker'},
 'safeguards': {'nns_to_nn': 'safeguard'},
 'sails': {'nns_to_nn': 'sail', 'vbz_to_vb': 'sail'},
 'sailors': {'nns_to_nn': 'sailor'},
 'salads': {'nns_to_nn': 'salad'},
 'salaries': {'nns_to_nn': 'salary'},
 'sales': {'nns_to_nn': 'sale', 'n_is_sth': ''},
 'samples': {'nns_to_nn': 'sample', 'vbz_to_vb': 'sample'},
 'sands': {'nns_to_nn': 'sand', 'vbz_to_vb': 'sand'},
 'satellites': {'nns_to_nn': 'satellite'},
 'satisfactions': {'nns_to_nn': 'satisfaction'},
 'sauces': {'nns_to_nn': 'sauce', 'vbz_to_vb': 'sauce'},
 'savers': {'nns_to_nn': 'saver'},
 'savvys': {'nns_to_nn': 'savvy'},
 'sayings': {'nns_to_nn': 'saying'},
 'scares': {'nns_to_nn': 'scare'},
 'scenarios': {'nns_to_nn': 'scenario'},
 'scenes': {'nns_to_nn': 'scene'},
 'schedules': {'nns_to_nn': 'schedule', 'vbz_to_vb': 'schedule'},
 'schemes': {'nns_to_nn': 'scheme', 'vbz_to_vb': 'scheme'},
 'scholars': {'nns_to_nn': 'scholar'},
 'scholarships': {'nns_to_nn': 'scholarship'},
 'schools': {'nns_to_nn': 'school'},
 'scientists': {'nns_to_nn': 'scientist'},
 'scores': {'nns_to_nn': 'score', 'vbz_to_vb': 'score'},
 'scorers': {'nns_to_nn': 'scorer'},
 'screams': {'nns_to_nn': 'scream', 'vbz_to_vb': 'scream'},
 'screens': {'nns_to_nn': 'screen', 'vbz_to_vb': 'screen'},
 'screenplays': {'nns_to_nn': 'screenplay'},
 'screws': {'nns_to_nn': 'screw'},
 'screwballs': {'nns_to_nn': 'screwball'},
 'screwdrivers': {'nns_to_nn': 'screwdriver'},
 'scripts': {'nns_to_nn': 'script', 'vbz_to_vb': 'script'},
 'sculptors': {'nns_to_nn': 'sculptor'},
 'sculptures': {'nns_to_nn': 'sculpture'},
 'seas': {'nns_to_nn': 'sea'},
 'seals': {'nns_to_nn': 'seal', 'vbz_to_vb': 'seal'},
 'seasons': {'nns_to_nn': 'season', 'vbz_to_vb': 'season'},
 'seats': {'nns_to_nn': 'seat', 'vbz_to_vb': 'seat'},
 'seconds': {'nns_to_nn': 'second', 'vbz_to_vb': 'second'},
 'secondaries': {'nns_to_nn': 'secondary'},
 'secrets': {'nns_to_nn': 'secret'},
 'sections': {'nns_to_nn': 'section', 'vbz_to_vb': 'section'},
 'sectors': {'nns_to_nn': 'sector'},
 'securities': {'nns_to_nn': 'security'},
 'segments': {'nns_to_nn': 'segment'},
 'sellers': {'nns_to_nn': 'seller', 'n_is_sb': '2', 'n_is_sth': '2'},
 'semiconductors': {'nns_to_nn': 'semiconductor'},
 'senates': {'nns_to_nn': 'senate'},
 'senators': {'nns_to_nn': 'senator'},
 'seniors': {'nns_to_nn': 'senior'},
 'senses': {'nns_to_nn': 'sense', 'vbz_to_vb': 'sense'},
 'sentences': {'nns_to_nn': 'sentence', 'vbz_to_vb': 'sentence'},
 'sentiments': {'nns_to_nn': 'sentiment'},
 'sequences': {'nns_to_nn': 'sequence', 'vbz_to_vb': 'sequence'},
 'servants': {'nns_to_nn': 'servant'},
 'serves': {'nns_to_nn': 'serve', 'vbz_to_vb': 'serve'},
 'servers': {'nns_to_nn': 'server'},
 'services': {'nns_to_nn': 'service', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbz_to_vb': 'service'},
 'sessions': {'nns_to_nn': 'session', 'n_is_sb': '2', 'n_is_sth': '2'},
 'sets': {'nns_to_nn': 'set', 'vbz_to_vb': 'set'},
 'setbacks': {'nns_to_nn': 'setback'},
 'settlers': {'nns_to_nn': 'settler'},
 'shadows': {'nns_to_nn': 'shadow', 'vbz_to_vb': 'shadow'},
 'shakes': {'nns_to_nn': 'shake', 'vbz_to_vb': 'shake'},
 'shames': {'nns_to_nn': 'shame', 'vbz_to_vb': 'shame'},
 'shares': {'nns_to_nn': 'share', 'vbz_to_vb': 'share'},
 'shareholders': {'nns_to_nn': 'shareholder'},
 'shaves': {'nns_to_nn': 'shave', 'vbz_to_vb': 'shave'},
 'sheds': {'nns_to_nn': 'shed', 'vbz_to_vb': 'shed'},
 'sheets': {'nns_to_nn': 'sheet'},
 'shells': {'nns_to_nn': 'shell', 'vbz_to_vb': 'shell'},
 'shelters': {'nns_to_nn': 'shelter', 'vbz_to_vb': 'shelter'},
 'shifts': {'nns_to_nn': 'shift', 'vbz_to_vb': 'shift'},
 'ships': {'nns_to_nn': 'ship', 'vbz_to_vb': 'ship'},
 'shirts': {'nns_to_nn': 'shirt'},
 'shocks': {'nns_to_nn': 'shock', 'vbz_to_vb': 'shock'},
 'shoes': {'nns_to_nn': 'shoe', 'n_is_nc': '', 'n_is_sth': ''},
 'shoots': {'nns_to_nn': 'shoot', 'vbz_to_vb': 'shoot'},
 'shops': {'nns_to_nn': 'shop', 'vbz_to_vb': 'shop'},
 'shopkeepers': {'nns_to_nn': 'shopkeeper'},
 'shores': {'nns_to_nn': 'shore'},
 'shorts': {'nns_to_nn': 'short', 'n_is_nc': '', 'n_is_sth': ''},
 'shortages': {'nns_to_nn': 'shortage'},
 'shoulders': {'nns_to_nn': 'shoulder', 'vbz_to_vb': 'shoulder'},
 'shouts': {'nns_to_nn': 'shout', 'vbz_to_vb': 'shout'},
 'shows': {'nns_to_nn': 'show', 'vbz_to_vb': 'show'},
 'showers': {'nns_to_nn': 'shower', 'vbz_to_vb': 'shower'},
 'showings': {'nns_to_nn': 'showing'},
 'shrugs': {'nns_to_nn': 'shrug', 'vbz_to_vb': 'shrug'},
 'shuttles': {'nns_to_nn': 'shuttle'},
 'sides': {'nns_to_nn': 'side'},
 'sidelines': {'nns_to_nn': 'sideline'},
 'sidewalks': {'nns_to_nn': 'sidewalk'},
 'sights': {'nns_to_nn': 'sight', 'vbz_to_vb': 'sight'},
 'signs': {'nns_to_nn': 'sign', 'vbz_to_vb': 'sign'},
 'signals': {'nns_to_nn': 'signal', 'vbz_to_vb': 'signal'},
 'signatures': {'nns_to_nn': 'signature'},
 'silences': {'nns_to_nn': 'silence'},
 'sillies': {'nns_to_nn': 'silly'},
 'simons': {'nns_to_nn': 'simon'},
 'sings': {'nns_to_nn': 'sing', 'vbz_to_vb': 'sing'},
 'singers': {'nns_to_nn': 'singer'},
 'singles': {'nns_to_nn': 'single', 'n_is_nc': '', 'n_is_sth': ''},
 'sinks': {'nns_to_nn': 'sink', 'vbz_to_vb': 'sink'},
 'sisters': {'nns_to_nn': 'sister'},
 'sitcoms': {'nns_to_nn': 'sitcom'},
 'sites': {'nns_to_nn': 'site', 'vbz_to_vb': 'site'},
 'sittings': {'nns_to_nn': 'sitting'},
 'situations': {'nns_to_nn': 'situation'},
 'sizes': {'nns_to_nn': 'size', 'vbz_to_vb': 'size'},
 'skepticisms': {'nns_to_nn': 'skepticism'},
 'skis': {'nns_to_nn': 'ski'},
 'skills': {'nns_to_nn': 'skill'},
 'skirts': {'nns_to_nn': 'skirt', 'vbz_to_vb': 'skirt'},
 'skys': {'nns_to_nn': 'sky'},
 'slaveries': {'nns_to_nn': 'slavery'},
 'sleeves': {'nns_to_nn': 'sleeve'},
 'slices': {'nns_to_nn': 'slice'},
 'slides': {'nns_to_nn': 'slide', 'vbz_to_vb': 'slide'},
 'slights': {'nns_to_nn': 'slight'},
 'slips': {'nns_to_nn': 'slip', 'vbz_to_vb': 'slip'},
 'slots': {'nns_to_nn': 'slot'},
 'slowdowns': {'nns_to_nn': 'slowdown'},
 'slumps': {'nns_to_nn': 'slump'},
 'smells': {'nns_to_nn': 'smell', 'vbz_to_vb': 'smell'},
 'smiles': {'nns_to_nn': 'smile', 'vbz_to_vb': 'smile'},
 'snails': {'nns_to_nn': 'snail'},
 'snakes': {'nns_to_nn': 'snake'},
 'soccers': {'nns_to_nn': 'soccer'},
 'societies': {'nns_to_nn': 'society'},
 'socks': {'nns_to_nn': 'sock'},
 'soils': {'nns_to_nn': 'soil'},
 'soldiers': {'nns_to_nn': 'soldier'},
 'soles': {'nns_to_nn': 'sole'},
 'solicitors': {'nns_to_nn': 'solicitor'},
 'solids': {'nns_to_nn': 'solid'},
 'sons': {'nns_to_nn': 'son'},
 'songs': {'nns_to_nn': 'song'},
 'sores': {'nns_to_nn': 'sore'},
 'sorts': {'nns_to_nn': 'sort', 'vbz_to_vb': 'sort'},
 'souls': {'nns_to_nn': 'soul'},
 'sounds': {'nns_to_nn': 'sound', 'vbz_to_vb': 'sound'},
 'soups': {'nns_to_nn': 'soup'},
 'sources': {'nns_to_nn': 'source'},
 'soviets': {'nns_to_nn': 'soviet'},
 'spaces': {'nns_to_nn': 'space'},
 'spans': {'nns_to_nn': 'span'},
 'spares': {'nns_to_nn': 'spare', 'vbz_to_vb': 'spare'},
 'sparks': {'nns_to_nn': 'spark'},
 'speakers': {'nns_to_nn': 'speaker'},
 'specials': {'nns_to_nn': 'special'},
 'specialists': {'nns_to_nn': 'specialist'},
 'specialties': {'nns_to_nn': 'specialty'},
 'specifics': {'nns_to_nn': 'specific'},
 'spectaculars': {'nns_to_nn': 'spectacular'},
 'spectrums': {'nns_to_nn': 'spectrum'},
 'speeches': {'nns_to_nn': 'speech'},
 'spells': {'nns_to_nn': 'spell', 'vbz_to_vb': 'spell'},
 'spiders': {'nns_to_nn': 'spider'},
 'spins': {'nns_to_nn': 'spin', 'vbz_to_vb': 'spin'},
 'spirituals': {'nns_to_nn': 'spiritual'},
 'splits': {'nns_to_nn': 'split', 'vbz_to_vb': 'split'},
 'sponsors': {'nns_to_nn': 'sponsor'},
 'spoons': {'nns_to_nn': 'spoon'},
 'sports': {'nns_to_nn': 'sport'},
 'spots': {'nns_to_nn': 'spot', 'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'spot'},
 'spotlights': {'nns_to_nn': 'spotlight'},
 'springs': {'nns_to_nn': 'spring'},
 'sprints': {'nns_to_nn': 'sprint'},
 'spurs': {'nns_to_nn': 'spur'},
 'spies': {'nns_to_nn': 'spy'},
 'squads': {'nns_to_nn': 'squad'},
 'squares': {'nns_to_nn': 'square'},
 'squeezes': {'nns_to_nn': 'squeeze', 'vbz_to_vb': 'squeeze'},
 'stables': {'nns_to_nn': 'stable'},
 'stages': {'nns_to_nn': 'stage'},
 'stairs': {'nns_to_nn': 'stair', 'n_is_nc': '', 'n_is_sth': ''},
 'stalls': {'nns_to_nn': 'stall', 'n_is_nc': '', 'n_is_sth': ''},
 'stamps': {'nns_to_nn': 'stamp', 'vbz_to_vb': 'stamp'},
 'stances': {'nns_to_nn': 'stance'},
 'stars': {'nns_to_nn': 'star'},
 'stares': {'nns_to_nn': 'stare', 'vbz_to_vb': 'stare'},
 'starts': {'nns_to_nn': 'start', 'vbz_to_vb': 'start'},
 'starters': {'nns_to_nn': 'starter'},
 'states': {'nns_to_nn': 'state', 'vbz_to_vb': 'state'},
 'statements': {'nns_to_nn': 'statement'},
 'stations': {'nns_to_nn': 'station'},
 'statistics': {'nns_to_nn': 'statistic', 'n_is_nc': '', 'n_is_sth': '', 'nn_eq_nns': ''},
 'statisticians': {'nns_to_nn': 'statistician'},
 'statues': {'nns_to_nn': 'statue'},
 'statutes': {'nns_to_nn': 'statute'},
 'stays': {'nns_to_nn': 'stay', 'vbz_to_vb': 'stay'},
 'steals': {'nns_to_nn': 'steal', 'vbz_to_vb': 'steal'},
 'stealers': {'nns_to_nn': 'stealer'},
 'steams': {'nns_to_nn': 'steam'},
 'steers': {'nns_to_nn': 'steer'},
 'stems': {'nns_to_nn': 'stem'},
 'steps': {'nns_to_nn': 'step', 'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'step'},
 'sterns': {'nns_to_nn': 'stern'},
 'sticks': {'nns_to_nn': 'stick', 'vbz_to_vb': 'stick'},
 'stiffs': {'nns_to_nn': 'stiff'},
 'stills': {'nns_to_nn': 'still'},
 'stirs': {'nns_to_nn': 'stir', 'vbz_to_vb': 'stir'},
 'stocks': {'nns_to_nn': 'stock'},
 'stops': {'nns_to_nn': 'stop', 'vbz_to_vb': 'stop'},
 'stores': {'nns_to_nn': 'store', 'vbz_to_vb': 'store'},
 'storms': {'nns_to_nn': 'storm'},
 'stoves': {'nns_to_nn': 'stove'},
 'straights': {'nns_to_nn': 'straight'},
 'strains': {'nns_to_nn': 'strain'},
 'strangers': {'nns_to_nn': 'stranger'},
 'strategists': {'nns_to_nn': 'strategist'},
 'strategies': {'nns_to_nn': 'strategy'},
 'streams': {'nns_to_nn': 'stream'},
 'streets': {'nns_to_nn': 'street'},
 'strengths': {'nns_to_nn': 'strength'},
 'stresses': {'nns_to_nn': 'stress', 'vbz_to_vb': 'stress'},
 'strikes': {'nns_to_nn': 'strike', 'vbz_to_vb': 'strike'},
 'strings': {'nns_to_nn': 'string'},
 'strips': {'nns_to_nn': 'strip'},
 'stripes': {'nns_to_nn': 'stripe'},
 'strokes': {'nns_to_nn': 'stroke'},
 'structures': {'nns_to_nn': 'structure'},
 'struggles': {'nns_to_nn': 'struggle', 'vbz_to_vb': 'struggle'},
 'students': {'nns_to_nn': 'student'},
 'studios': {'nns_to_nn': 'studio'},
 'studies': {'nns_to_nn': 'study', 'vbz_to_vb': 'study'},
 'stupids': {'nns_to_nn': 'stupid'},
 'styles': {'nns_to_nn': 'style'},
 'subjects': {'nns_to_nn': 'subject'},
 'subsidiaries': {'nns_to_nn': 'subsidiary'},
 'substances': {'nns_to_nn': 'substance'},
 'substitutes': {'nns_to_nn': 'substitute'},
 'suburbs': {'nns_to_nn': 'suburb'},
 'subways': {'nns_to_nn': 'subway'},
 'successors': {'nns_to_nn': 'successor'},
 'sucks': {'nns_to_nn': 'suck', 'vbz_to_vb': 'suck'},
 'sufferings': {'nns_to_nn': 'suffering'},
 'suggestions': {'nns_to_nn': 'suggestion'},
 'suits': {'nns_to_nn': 'suit', 'vbz_to_vb': 'suit'},
 'suitcases': {'nns_to_nn': 'suitcase'},
 'suites': {'nns_to_nn': 'suite'},
 'sums': {'nns_to_nn': 'sum'},
 'summers': {'nns_to_nn': 'summer'},
 'superintendents': {'nns_to_nn': 'superintendent'},
 'superiors': {'nns_to_nn': 'superior'},
 'supermarkets': {'nns_to_nn': 'supermarket'},
 'supervisors': {'nns_to_nn': 'supervisor'},
 'suppliers': {'nns_to_nn': 'supplier'},
 'supplies': {'nns_to_nn': 'supply', 'vbz_to_vb': 'supply'},
 'supports': {'nns_to_nn': 'support', 'vbz_to_vb': 'support'},
 'supporters': {'nns_to_nn': 'supporter'},
 'surfaces': {'nns_to_nn': 'surface'},
 'surges': {'nns_to_nn': 'surge'},
 'surgeons': {'nns_to_nn': 'surgeon'},
 'surgeries': {'nns_to_nn': 'surgery'},
 'surnames': {'nns_to_nn': 'surname'},
 'surveys': {'nns_to_nn': 'survey'},
 'survivals': {'nns_to_nn': 'survival'},
 'survivors': {'nns_to_nn': 'survivor'},
 'suspects': {'nns_to_nn': 'suspect', 'vbz_to_vb': 'suspect'},
 'suspensions': {'nns_to_nn': 'suspension'},
 'suspicions': {'nns_to_nn': 'suspicion'},
 'swallows': {'nns_to_nn': 'swallow'},
 'sweaters': {'nns_to_nn': 'sweater'},
 'sweeps': {'nns_to_nn': 'sweep', 'vbz_to_vb': 'sweep'},
 'sweets': {'nns_to_nn': 'sweet'},
 'swifts': {'nns_to_nn': 'swift'},
 'swimmers': {'nns_to_nn': 'swimmer'},
 'symbols': {'nns_to_nn': 'symbol'},
 'systems': {'nns_to_nn': 'system'},
 'tables': {'nns_to_nn': 'table'},
 'tablets': {'nns_to_nn': 'tablet'},
 'tails': {'nns_to_nn': 'tail'},
 'tailors': {'nns_to_nn': 'tailor'},
 'tales': {'nns_to_nn': 'tale'},
 'talks': {'nns_to_nn': 'talk', 'vbz_to_vb': 'talk'},
 'tanks': {'nns_to_nn': 'tank'},
 'taps': {'nns_to_nn': 'tap'},
 'targets': {'nns_to_nn': 'target'},
 'tasks': {'nns_to_nn': 'task'},
 'taxes': {'nns_to_nn': 'tax'},
 'taxis': {'nns_to_nn': 'taxi', 'n_is_nc': '', 'n_is_sth': ''},
 'teas': {'nns_to_nn': 'tea'},
 'teachers': {'nns_to_nn': 'teacher'},
 'teachings': {'nns_to_nn': 'teaching'},
 'teams': {'nns_to_nn': 'team'},
 'teammates': {'nns_to_nn': 'teammate'},
 'tears': {'nns_to_nn': 'tear', 'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'tear'},
 'techniques': {'nns_to_nn': 'technique'},
 'technologies': {'nns_to_nn': 'technology'},
 'tees': {'nns_to_nn': 'tee'},
 'teens': {'nns_to_nn': 'teen'},
 'telecoms': {'nns_to_nn': 'telecom'},
 'telephones': {'nns_to_nn': 'telephone'},
 'telescopes': {'nns_to_nn': 'telescope'},
 'televisions': {'nns_to_nn': 'television'},
 'temperatures': {'nns_to_nn': 'temperature'},
 'temples': {'nns_to_nn': 'temple'},
 'tenders': {'nns_to_nn': 'tender'},
 'tensions': {'nns_to_nn': 'tension'},
 'tents': {'nns_to_nn': 'tent'},
 'terms': {'nns_to_nn': 'term', 'n_is_nc': '', 'n_is_sth': ''},
 'terminals': {'nns_to_nn': 'terminal'},
 'territories': {'nns_to_nn': 'territory'},
 'terrors': {'nns_to_nn': 'terror'},
 'terrorists': {'nns_to_nn': 'terrorist'},
 'tests': {'nns_to_nn': 'test', 'vbz_to_vb': 'test'},
 'testimonies': {'nns_to_nn': 'testimony'},
 'texts': {'nns_to_nn': 'text', 'vbz_to_vb': 'text'},
 'thanksgivings': {'nns_to_nn': 'thanksgiving'},
 'theaters': {'nns_to_nn': 'theater'},
 'thefts': {'nns_to_nn': 'theft'},
 'themes': {'nns_to_nn': 'theme'},
 'theories': {'nns_to_nn': 'theory'},
 'therapies': {'nns_to_nn': 'therapy'},
 'things': {'nns_to_nn': 'thing', 'n_is_nc': '', 'n_is_sth': ''},
 'thirds': {'nns_to_nn': 'third'},
 'thoughts': {'nns_to_nn': 'thought'},
 'thousands': {'nns_to_nn': 'thousand'},
 'threats': {'nns_to_nn': 'threat'},
 'throats': {'nns_to_nn': 'throat'},
 'thumbs': {'nns_to_nn': 'thumb'},
 'tickets': {'nns_to_nn': 'ticket'},
 'tides': {'nns_to_nn': 'tide'},
 'ties': {'nns_to_nn': 'tie', 'vbz_to_vb': 'tie'},
 'tigers': {'nns_to_nn': 'tiger'},
 'tiles': {'nns_to_nn': 'tile'},
 'timetables': {'nns_to_nn': 'timetable'},
 'tips': {'nns_to_nn': 'tip', 'vbz_to_vb': 'tip'},
 'tires': {'nns_to_nn': 'tire'},
 'tissues': {'nns_to_nn': 'tissue'},
 'titles': {'nns_to_nn': 'title'},
 'toes': {'nns_to_nn': 'toe'},
 'tolls': {'nns_to_nn': 'toll'},
 'tons': {'nns_to_nn': 'ton'},
 'tonnes': {'nns_to_nn': 'tonne'},
 'tools': {'nns_to_nn': 'tool'},
 'tops': {'nns_to_nn': 'top'},
 'topics': {'nns_to_nn': 'topic'},
 'tortures': {'nns_to_nn': 'torture'},
 'totals': {'nns_to_nn': 'total'},
 'touchs': {'nns_to_nn': 'touch'},
 'tours': {'nns_to_nn': 'tour'},
 'tourists': {'nns_to_nn': 'tourist'},
 'tournaments': {'nns_to_nn': 'tournament'},
 'towels': {'nns_to_nn': 'towel'},
 'towers': {'nns_to_nn': 'tower'},
 'towns': {'nns_to_nn': 'town'},
 'toys': {'nns_to_nn': 'toy'},
 'traces': {'nns_to_nn': 'trace'},
 'tracks': {'nns_to_nn': 'track'},
 'trackings': {'nns_to_nn': 'tracking'},
 'trademarks': {'nns_to_nn': 'trademark'},
 'traders': {'nns_to_nn': 'trader'},
 'traffics': {'nns_to_nn': 'traffic'},
 'tragedies': {'nns_to_nn': 'tragedy'},
 'trails': {'nns_to_nn': 'trail'},
 'trailers': {'nns_to_nn': 'trailer'},
 'trains': {'nns_to_nn': 'train'},
 'trainers': {'nns_to_nn': 'trainer'},
 'transformations': {'nns_to_nn': 'transformation'},
 'transitions': {'nns_to_nn': 'transition'},
 'transmissions': {'nns_to_nn': 'transmission'},
 'transplants': {'nns_to_nn': 'transplant'},
 'transports': {'nns_to_nn': 'transport'},
 'traps': {'nns_to_nn': 'trap'},
 'travellers': {'nns_to_nn': 'traveller'},
 'trays': {'nns_to_nn': 'tray'},
 'treasuries': {'nns_to_nn': 'treasury'},
 'treats': {'nns_to_nn': 'treat', 'vbz_to_vb': 'treat'},
 'treaties': {'nns_to_nn': 'treaty'},
 'trees': {'nns_to_nn': 'tree'},
 'trends': {'nns_to_nn': 'trend'},
 'triangles': {'nns_to_nn': 'triangle'},
 'tribes': {'nns_to_nn': 'tribe'},
 'tribunals': {'nns_to_nn': 'tribunal'},
 'tributes': {'nns_to_nn': 'tribute'},
 'tricks': {'nns_to_nn': 'trick'},
 'triggers': {'nns_to_nn': 'trigger'},
 'trims': {'nns_to_nn': 'trim'},
 'trips': {'nns_to_nn': 'trip'},
 'triumphs': {'nns_to_nn': 'triumph'},
 'troops': {'nns_to_nn': 'troop', 'n_is_nc': '', 'n_is_sth': ''},
 'trophies': {'nns_to_nn': 'trophy'},
 'troubles': {'nns_to_nn': 'trouble'},
 'trucks': {'nns_to_nn': 'truck'},
 'truths': {'nns_to_nn': 'truth'},
 'tubes': {'nns_to_nn': 'tube'},
 'tuitions': {'nns_to_nn': 'tuition'},
 'tulips': {'nns_to_nn': 'tulip'},
 'tunes': {'nns_to_nn': 'tune'},
 'tunnels': {'nns_to_nn': 'tunnel'},
 'turfs': {'nns_to_nn': 'turf'},
 'turns': {'nns_to_nn': 'turn', 'vbz_to_vb': 'turn'},
 'turners': {'nns_to_nn': 'turner'},
 'turnouts': {'nns_to_nn': 'turnout'},
 'turnovers': {'nns_to_nn': 'turnover'},
 'twins': {'nns_to_nn': 'twin', 'n_is_nc': '', 'n_is_sb': '0'},
 'twists': {'nns_to_nn': 'twist', 'vbz_to_vb': 'twist'},
 'types': {'nns_to_nn': 'type'},
 'typists': {'nns_to_nn': 'typist'},
 'tyres': {'nns_to_nn': 'tyre'},
 'umbrellas': {'nns_to_nn': 'umbrella'},
 'uncles': {'nns_to_nn': 'uncle'},
 'undergrounds': {'nns_to_nn': 'underground'},
 'understandings': {'nns_to_nn': 'understanding'},
 'uniforms': {'nns_to_nn': 'uniform'},
 'unions': {'nns_to_nn': 'union'},
 'units': {'nns_to_nn': 'unit'},
 'unities': {'nns_to_nn': 'unity'},
 'universes': {'nns_to_nn': 'universe'},
 'universities': {'nns_to_nn': 'university'},
 'unknowns': {'nns_to_nn': 'unknown'},
 'updates': {'nns_to_nn': 'update'},
 'upgrades': {'nns_to_nn': 'upgrade'},
 'uppers': {'nns_to_nn': 'upper'},
 'urges': {'nns_to_nn': 'urge', 'vbz_to_vb': 'urge'},
 'urgencies': {'nns_to_nn': 'urgency'},
 'users': {'nns_to_nn': 'user'},
 'utilities': {'nns_to_nn': 'utility'},
 'vacations': {'nns_to_nn': 'vacation', 'vbz_to_vb': 'vacation'},
 'vaccines': {'nns_to_nn': 'vaccine'},
 'valentines': {'nns_to_nn': 'valentine'},
 'valleys': {'nns_to_nn': 'valley'},
 'values': {'nns_to_nn': 'value'},
 'vans': {'nns_to_nn': 'van'},
 'varieties': {'nns_to_nn': 'variety'},
 'vehicles': {'nns_to_nn': 'vehicle'},
 'ventures': {'nns_to_nn': 'venture'},
 'verdicts': {'nns_to_nn': 'verdict'},
 'verges': {'nns_to_nn': 'verge'},
 'versions': {'nns_to_nn': 'version'},
 'vets': {'nns_to_nn': 'vet'},
 'veterans': {'nns_to_nn': 'veteran'},
 'vices': {'nns_to_nn': 'vice'},
 'victims': {'nns_to_nn': 'victim'},
 'victories': {'nns_to_nn': 'victory'},
 'videos': {'nns_to_nn': 'video'},
 'videotapes': {'nns_to_nn': 'videotape'},
 'views': {'nns_to_nn': 'view'},
 'villages': {'nns_to_nn': 'village'},
 'violations': {'nns_to_nn': 'violation'},
 'violets': {'nns_to_nn': 'violet'},
 'visas': {'nns_to_nn': 'visa'},
 'visions': {'nns_to_nn': 'vision'},
 'visits': {'nns_to_nn': 'visit', 'vbz_to_vb': 'visit'},
 'visitors': {'nns_to_nn': 'visitor'},
 'vocals': {'nns_to_nn': 'vocal'},
 'volleyballs': {'nns_to_nn': 'volleyball'},
 'volumes': {'nns_to_nn': 'volume'},
 'volunteers': {'nns_to_nn': 'volunteer'},
 'votes': {'nns_to_nn': 'vote', 'vbz_to_vb': 'vote'},
 'voters': {'nns_to_nn': 'voter'},
 'wages': {'nns_to_nn': 'wage', 'n_is_nc': '', 'n_is_sth': ''},
 'waists': {'nns_to_nn': 'waist'},
 'waiters': {'nns_to_nn': 'waiter'},
 'wakes': {'nns_to_nn': 'wake', 'vbz_to_vb': 'wake'},
 'walks': {'nns_to_nn': 'walk', 'vbz_to_vb': 'walk'},
 'walkings': {'nns_to_nn': 'walking'},
 'walls': {'nns_to_nn': 'wall'},
 'wallets': {'nns_to_nn': 'wallet'},
 'wars': {'nns_to_nn': 'war'},
 'wards': {'nns_to_nn': 'ward'},
 'wardrobes': {'nns_to_nn': 'wardrobe'},
 'warehouses': {'nns_to_nn': 'warehouse'},
 'warnings': {'nns_to_nn': 'warning'},
 'warrants': {'nns_to_nn': 'warrant'},
 'watermelons': {'nns_to_nn': 'watermelon'},
 'waves': {'nns_to_nn': 'wave', 'vbz_to_vb': 'wave'},
 'ways': {'nns_to_nn': 'way', 'n_is_nc': '', 'n_is_sth': ''},
 'weaknesses': {'nns_to_nn': 'weakness'},
 'weapons': {'nns_to_nn': 'weapon'},
 'webs': {'nns_to_nn': 'web'},
 'websites': {'nns_to_nn': 'website'},
 'weddings': {'nns_to_nn': 'wedding'},
 'weeks': {'nns_to_nn': 'week'},
 'weekends': {'nns_to_nn': 'weekend'},
 'weirds': {'nns_to_nn': 'weird'},
 'welds': {'nns_to_nn': 'weld'},
 'wells': {'nns_to_nn': 'well', 'n_is_sb': '0'},
 'westerns': {'nns_to_nn': 'western'},
 'wets': {'nns_to_nn': 'wet'},
 'wheels': {'nns_to_nn': 'wheel'},
 'whiles': {'nns_to_nn': 'while'},
 'whites': {'nns_to_nn': 'white'},
 'wholes': {'nns_to_nn': 'whole'},
 'widows': {'nns_to_nn': 'widow'},
 'willows': {'nns_to_nn': 'willow'},
 'wins': {'nns_to_nn': 'win', 'vbz_to_vb': 'win'},
 'windows': {'nns_to_nn': 'window'},
 'wings': {'nns_to_nn': 'wing'},
 'winners': {'nns_to_nn': 'winner'},
 'wires': {'nns_to_nn': 'wire'},
 'wits': {'nns_to_nn': 'wit'},
 'withdrawals': {'nns_to_nn': 'withdrawal'},
 'wolves': {'nns_to_nn': 'wolf'},
 'woods': {'nns_to_nn': 'wood', 'n_is_nc': '', 'n_is_sth': ''},
 'words': {'nns_to_nn': 'word', 'n_is_nc': '', 'n_is_sth': ''},
 'works': {'nns_to_nn': 'work', 'vbz_to_vb': 'work'},
 'workers': {'nns_to_nn': 'worker'},
 'workplaces': {'nns_to_nn': 'workplace'},
 'workshops': {'nns_to_nn': 'workshop'},
 'worthies': {'nns_to_nn': 'worthy'},
 'wounds': {'nns_to_nn': 'wound', 'vbz_to_vb': 'wound'},
 'wraps': {'nns_to_nn': 'wrap', 'vbz_to_vb': 'wrap'},
 'wrists': {'nns_to_nn': 'wrist'},
 'writers': {'nns_to_nn': 'writer'},
 'writings': {'nns_to_nn': 'writing', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'wrongdoings': {'nns_to_nn': 'wrongdoing'},
 'yards': {'nns_to_nn': 'yard'},
 'yawns': {'nns_to_nn': 'yawn'},
 'years': {'nns_to_nn': 'year', 'n_is_nc': '', 'n_is_sth': ''},
 'yellows': {'nns_to_nn': 'yellow'},
 'youths': {'nns_to_nn': 'youth'},
 'zones': {'nns_to_nn': 'zone'},
 'zoologists': {'nns_to_nn': 'zoologist'},
 'heirs': {'nns_to_nn': 'heir'},
 'sightseeings': {'nns_to_nn': 'sightseeing'},
 '': {'nns_to_nn': 'it'},
 'adulthoods': {'nns_to_nn': 'adulthood'},
 'benefits': {'nns_to_nn': 'benefit'},
 'papers': {'nns_to_nn': 'paper', 'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'classics': {'nns_to_nn': 'classic', 'n_is_nc': '', 'n_is_sth': ''},
 'sorrows': {'nns_to_nn': 'sorrow'},
 'ambulance': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_eq_nns': '', 'nc_typical': ''},
 'ax': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'vbg_non': ''},
 'baggage': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_eq_nns': '', 'nu_typical': ''},
 'bamboo': {'n_is_nc': '', 'n_is_sth': '', 'nn_eq_nns': ''},
 'brace': {'n_is_nc': '', 'n_is_sth': '', 'nn_eq_nns': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'cattle': {'n_is_nc': '', 'n_is_sb': '0', 'nn_eq_nns': ''},
 'chat': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_to_vbg': '', 'nsubjpass': '', 'v_with': '', 'v_about': '', 'nn_eq_nns': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': '', 'vi_typical': ''},
 'cleaning': {'n_is_nu': '', 'n_is_sth': ''},
 'eagle': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'nn_eq_nns': '', 'nc_typical': '', 'n_is_sth': '3'},
 'earnings': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_eq_nns': ''},
 'furniture': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'means': {'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'mean', 'nn_eq_nns': ''},
 'pants': {'n_is_nc': '', 'n_is_sth': '', 'nn_eq_nns': ''},
 'people': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '0', 'nn_eq_nns': '', 'vbd_eq_vbn': ''},
 'police': {'n_is_nc': '', 'n_is_sb': '0', 'n_is_collective': '', 'nn_eq_nns': '', 'vbd_eq_vbn': ''},
 'salmon': {'n_is_nc': '', 'n_is_sb': '3', 'nn_eq_nns': '', 'n_is_sth': '3'},
 'shrimp': {'n_is_nc': '', 'n_is_sb': '3', 'nn_eq_nns': '', 'n_is_sth': '3'},
 'specie': {'n_is_nc': '', 'n_is_sth': ''},
 'area': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'a-bomb': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'abalone': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '3'},
 'abandonment': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'abandon', 'nn_to_jj': 'abandoned', 'nn_to_rb': 'abandonedly'},
 'abatement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abbe': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'abbey': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'abbot': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'abbreviation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abdication': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abdomen': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'abduction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abductor': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '', 'art_an': ''},
 'aberration': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ability': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'able', 'nn_to_jj': 'able', 'nn_to_rb': 'ably'},
 'abo': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'abode': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': ''},
 'abomination': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'aboriginal': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'aborigine': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'abortion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abrasion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abrasive': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abridgement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abrogation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abscess': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'absorber': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'absurdity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abutment': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'abyss': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'acacia': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'academician': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'accelerometer': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'accentuation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acclimation': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'accolade': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'accompaniment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'accompany'},
 'accompanist': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'accomplice': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'accomplishment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'accordion': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'accountant': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nc_typical': ''},
 'accouterment': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'accretion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'accrual': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'accumulation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'accumulate', 'nn_to_jj': 'accumulative'},
 'accumulator': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'accusation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'accuse'},
 'accuser': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'acknowledgement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'acknowledge'},
 'acme': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'acolyte': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'acorn': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'acoustician': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'acquisition': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'acquire', 'nn_to_jj': 'acquisitive'},
 'acquittal': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acre': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'acrylic': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'activator': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'actuator': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ad': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'adaptor': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'adder': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '3'},
 'addressee': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'adieu': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'adjournment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'adjunct': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'adjutant': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'adjuvant': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'admiral': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'admixture': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'adulterer': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'adulteress': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'advance': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_from': '', 'vb_to_vbz': 'advances', 'vb_to_vbd': 'advanced', 'vb_to_vbn': 'advanced', 'vb_to_jj': 'advanced', 'nn_to_jj': 'advanced', 'vb_to_vbg': 'advancing', 'vbd_eq_vbn': ''},
 'adventurism': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'adversary': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'adversity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'advocate': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'v_compcl': '', 'vb_to_nn': 'advocacy', 'v_vbg': '', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'adze': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aerialist': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'aerie': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aerodrome': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aeroplane': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'advance', 'nn_to_jj': 'advanced', 'nc_typical': ''},
 'affair': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'advantage', 'nn_to_jj': 'advantaged', 'nc_typical': ''},
 'affairs': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'affectation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'affidavit': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'affiliate': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'affiliation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'affirmation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'affix': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'affliction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aficionado': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'aftereffect': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'afterglow': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'afterimage': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'afterlife': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aftermath': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aftershock': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aftertaste': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aga': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'agate': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'agave': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'agglomeration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aggregate': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vb_to_nn': 'aggregation', 'vb_to_jj': 'aggregative', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'aggressor': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'agitation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'agitator': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'agon': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'agronomist': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'aid': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'aided', 'vbd_eq_vbn': '', 'v_whcl_non': '', 'vt_typical': ''},
 'aide': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'aide-de-camp': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'aileron': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ailment': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'airbrush': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'airbus': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aircraft': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_eq_nns': '', 'nc_typical': ''},
 'aircrew': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'airdrop': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'airfoil': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'airframe': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aisle': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ala': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'alamo': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'alarm': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_with': '', 'v_about': '', 'vb_to_vbz': 'alarms', 'vb_to_vbd': 'alarmed', 'vb_to_vbn': 'alarmed', 'vb_to_vbg': 'alarming', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vt_typical': '', 'nc_typical': ''},
 'alb': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'albatross': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'albino': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'alcalde': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'alcazar': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'alcohol': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nu_typical': ''},
 'alcove': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'alder': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'alert': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'algorithm': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'alias': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'alibi': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'alien': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'alignment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'alkali': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'alkaloid': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'allegation': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'allegiance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'allegory': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'allegretto': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'allegro': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'allergen': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'allergy': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'alleviation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'alley': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'alleyway': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'alliance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'allies': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'alligator': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'allocation': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'allocate', 'nn_to_jj': 'allocative'},
 'allotment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'allowance': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'allow', 'nn_to_jj': 'allowable', 'nn_to_rb': 'allowably', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'alloy': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'allusion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ally': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'almanac': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'almond': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'alms': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'alp': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'alpha': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'alphabet': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'altar': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'alteration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'alter', 'nn_to_jj': 'alterable', 'nn_to_rb': 'alterably'},
 'altercation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'alternate': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'vb_to_nn': 'alternative', 'vb_to_jj': 'alternative', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'n_is_sth': '2'},
 'alternation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'alternator': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'altimeter': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'altitude': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'alto': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'alumina': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'alyssum': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'amanuensis': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'amateur': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'ambassador': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nc_typical': ''},
 'amber': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ambiance': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ambience': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ambiguity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'ambiguous'},
 'ambit': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ambition': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'ambitious', 'nc_typical': ''},
 'amble': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'ambulatory': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ambush': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'ameer': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'amendment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'amend', 'nn_to_jj': 'amenable'},
 'amends': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'amenity': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'amicability': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'amigo': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'ammo': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'amnesty': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'amontillado': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'amour': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'amphibian': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'amplifier': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'amputation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'amulet': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'amusement': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'amuse', 'nn_to_jj': 'amusing'},
 'ana': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'anaesthesia': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'anaesthetic': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'analogy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'analogize', 'nn_to_jj': 'analogous'},
 'analyst': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'analyzer': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'anathema': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'anatomy': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ancestry': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '0', 'art_an': ''},
 'anchovy': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'ancient': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'androgyne': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'androgyny': {'n_is_nc': '', 'art_an': '', 'n_is_sth': '0'},
 'android': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'anecdote': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'anemometer': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'anemone': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '3'},
 'anesthetic': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'anesthetist': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'angelfish': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'angstrom': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'angularity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'anima': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'animosity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'anklet': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'annals': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'annex': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'annexation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'annihilator': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'anniversary': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'annotation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'announcement': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'annuity': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'annulment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'annunciation': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'anode': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'anodyne': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'anomaly': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'anopheles': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'anorak': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'antagonist': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'ante': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'anteater': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '3'},
 'antecedent': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'antechamber': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'antelope': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'anteroom': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'anthem': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'anther': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'anthology': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'antiaircraft': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'antibody': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'anticlimax': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'antidote': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'antigen': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'antiparticle': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'antiproton': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'antique': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'antiquity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'antiseptic': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'antithesis': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'antitoxin': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'antler': {'n_is_nc': '', 'art_an': '', 'n_is_sth': '0'},
 'antonym': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'anus': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'anvil': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aorta': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ape': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'ape-man': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'aperture': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aphid': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'aphis': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '3'},
 'aphorism': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aphrodisiac': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'apocalypse': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'apogee': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'apologia': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'apologist': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'apology': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'apologize', 'nn_to_jj': 'apologetical', 'nn_to_rb': 'apologetically', 'nc_typical': ''},
 'apostle': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'apothecary': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'apotheosis': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'apparition': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'appeal': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_against': '', 'v_to': '', 'vb_to_vbz': 'appeals', 'vb_to_vbd': 'appealed', 'vb_to_vbn': 'appealed', 'vb_to_vbg': 'appealing', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'applique': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'apricot': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'apron': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aptitude': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aqua': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aquarium': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aquatic': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aqueduct': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'arabian': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'cap_word': 'Arabian'},
 'arachnid': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'arbiter': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'arbor': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'arboretum': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'arborvitae': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'arbour': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'arc': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': ''},
 'arcanum': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'archaeopteryx': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'archaism': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'archbishop': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'archer': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'archetype': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'archipelago': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'architect': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'architecture': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nu_typical': ''},
 'archive': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'archives': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'archway': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'arena': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'argali': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'argentine': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'argot': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aria': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aristocracy': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_collective': ''},
 'aristocrat': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'ark': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'arm': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'armed', 'v_n': '', 'nsubjpass': '', 'vb_to_jj': 'armed', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'nc_typical': ''},
 'armadillo': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'armament': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'armature': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'armband': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'armchair': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'armful': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'armistice': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'armoire': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'armorer': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'armory': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'armpit': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'armrest': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'arms': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'arras': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'arrears': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'arrest': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'arresting', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'arrests', 'vb_to_vbd': 'arrested', 'vb_to_vbn': 'arrested', 'vb_to_jj': 'arresting', 'vb_to_vbg': 'arresting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'arrival': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2', 'nn_to_vb': 'arrive', 'nn_to_jj': 'arrived', 'nu_typical': ''},
 'arriviste': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'arrowhead': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'arroyo': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'arse': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'arsenal': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'arson': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'arsonist': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'art': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'artery': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'artichoke': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'article': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'articled', 'vb_to_vbz': 'articles', 'vb_to_vbd': 'articled', 'vb_to_vbn': 'articled', 'vb_to_jj': 'articled', 'vb_to_vbg': 'articling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'articulation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'artifice': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'artificiality': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'artificialize', 'nn_to_jj': 'artificial'},
 'artillery': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'artilleryman': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'artisan': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'artiste': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'artwork': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ascendant': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'ascent': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'asgard': {'n_is_nc': '', 'art_an': '', 'n_is_sth': '0'},
 'ashcan': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ashtray': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aside': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'adv_after_v': ''},
 'aspen': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'asperity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aspersion': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aspic': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aspidistra': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aspirant': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'aspiration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aspirin': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ass': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'assailant': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'assassin': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'assassination': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'assault': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'assay': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'assemblage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'assembler': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'assemblyman': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'assertion': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'assessment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'assess', 'nn_to_jj': 'assessable'},
 'assessor': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'asset': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'assets': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'asshole': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2', 'dirtyword': ''},
 'assignation': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'assignment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'assign', 'nn_to_jj': 'assigned'},
 'assist': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'assistant', 'v_to_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_with': '', 'vb_to_vbz': 'assists', 'vb_to_vbd': 'assisted', 'vb_to_vbn': 'assisted', 'vb_to_nn': 'assistance', 'vb_to_jj': 'assistant', 'vb_to_vbg': 'assisting', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'assortment': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'assumption': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'assume', 'nn_to_jj': 'assumed'},
 'assurance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'assure', 'nn_to_jj': 'assured'},
 'aster': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'asterisk': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': ''},
 'asteroid': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'astrodome': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'astrologer': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'atelier': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'athletics': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'atlas': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'atmosphere': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'atmospherics': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'atomizer': {'n_is_nc': '', 'art_an': '', 'n_is_sth': '0'},
 'atonement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'atrium': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'attachment': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'attach', 'nn_to_jj': 'attaching'},
 'attack': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'attacking', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_for': '', 'v_of': '', 'v_against': '', 'vb_to_vbz': 'attacks', 'vb_to_vbd': 'attacked', 'vb_to_vbn': 'attacked', 'vb_to_jj': 'attacking', 'vb_to_vbg': 'attacking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'attainment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'attain', 'nn_to_jj': 'attainable'},
 'attendance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'attend', 'nn_to_jj': 'attendant'},
 'attendee': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'attention': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'attentive', 'nn_to_rb': 'attentively', 'nu_typical': ''},
 'attic': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'attitude': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_to_n': '', 'n_towards_n': ''},
 'attraction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2', 'nn_to_vb': 'attract', 'nn_to_jj': 'attractive', 'nn_to_rb': 'attractively'},
 'attribute': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vb_to_nn': 'attribution', 'vb_to_jj': 'attributable', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'aubergine': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'auction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'auctioneer': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'audio': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'audit': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'audition': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'auditor': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'auditorium': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'auger': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'augmentation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'augury': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aunt': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nc_typical': ''},
 'auntie': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'aura': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'aureole': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'auspices': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'autarky': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'auto': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'autobiography': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'autobus': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'autoclave': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'autocracy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'autocrat': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'autograph': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'autopsy': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'autumn': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'auxiliary': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '', 'art_an': ''},
 'avalanche': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'avant-garde': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'avatar': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'avenue': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'average': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'averaged', 'vb_to_jj': 'averaged', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'aviator': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'avocado': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'avocation': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'avowal': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'awakening': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'awl': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'awning': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'axe': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'axiom': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'axle': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'azalea': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'azimuth': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'baal': {'n_is_nc': '', 'n_is_sb': '0'},
 'babbler': {'n_is_nc': '', 'n_is_sb': '0'},
 'babe': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'baboon': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'babushka': {'n_is_nc': '', 'n_is_sth': ''},
 'bacchanal': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'backboard': {'n_is_nc': '', 'n_is_sth': ''},
 'backbone': {'n_is_nc': '', 'n_is_sth': ''},
 'backdrop': {'n_is_nc': '', 'n_is_sth': ''},
 'backer': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'background': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'backhand': {'n_is_nc': '', 'n_is_sth': ''},
 'backhander': {'n_is_nc': '', 'n_is_sth': ''},
 'backing': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'backlash': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'backlog': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'backrest': {'n_is_nc': '', 'n_is_sth': ''},
 'backseat': {'n_is_nc': '', 'n_is_sth': ''},
 'backside': {'n_is_nc': '', 'n_is_sth': ''},
 'backstay': {'n_is_nc': '', 'n_is_sth': ''},
 'backstop': {'n_is_nc': '', 'n_is_sth': ''},
 'backstroke': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bacteriophage': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'badge': {'n_is_nc': '', 'n_is_sth': ''},
 'badger': {'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'n_is_sth': '2'},
 'badlands': {'n_is_nc': '', 'n_is_sth': ''},
 'baffle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'bagatelle': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'bagman': {'n_is_nc': '', 'n_is_sb': '0'},
 'bagpipe': {'n_is_nc': '', 'n_is_sth': ''},
 'bailey': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'bailiff': {'n_is_nc': '', 'n_is_sb': '0'},
 'bailiwick': {'n_is_nc': '', 'n_is_sth': ''},
 'bait': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'baker': {'n_is_nc': '', 'n_is_sb': '0'},
 'balata': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'baldy': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'bale': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'balk': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'ballad': {'n_is_nc': '', 'n_is_sth': ''},
 'balloon': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'ballot': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'ballpark': {'n_is_nc': '', 'n_is_sth': ''},
 'ballpoint': {'n_is_nc': '', 'n_is_sth': ''},
 'ballroom': {'n_is_nc': '', 'n_is_sth': ''},
 'balm': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'baloney': {'n_is_nc': '', 'n_is_sth': ''},
 'balsa': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'balsam': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'baluster': {'n_is_nc': '', 'n_is_sth': ''},
 'balustrade': {'n_is_nc': '', 'n_is_sth': ''},
 'bambino': {'n_is_nc': '', 'n_is_sb': '0'},
 'ban': {'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'bans', 'vb_to_vbd': 'banned', 'vb_to_vbn': 'banned', 'vb_to_vbg': 'banning', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'nc_typical': ''},
 'banality': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'bandage': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'bane': {'n_is_nc': '', 'n_is_sth': ''},
 'bangle': {'n_is_nc': '', 'n_is_sth': ''},
 'banknote': {'n_is_nc': '', 'n_is_sth': ''},
 'bankroll': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'banshee': {'n_is_nc': '', 'n_is_sb': '0'},
 'bantam': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'banyan': {'n_is_nc': '', 'n_is_sth': ''},
 'banzai': {'n_is_nc': '', 'n_is_sth': ''},
 'barb': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'barbican': {'n_is_nc': '', 'n_is_sth': ''},
 'bargainer': {'n_is_nc': '', 'n_is_sb': '0'},
 'barkeeper': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'barony': {'n_is_nc': '', 'n_is_sth': ''},
 'barrack': {'n_is_nc': '', 'n_is_sth': ''},
 'barrette': {'n_is_nc': '', 'n_is_sth': ''},
 'barroom': {'n_is_nc': '', 'n_is_sth': ''},
 'barrow': {'n_is_nc': '', 'n_is_sth': ''},
 'bartender': {'n_is_nc': '', 'n_is_sb': '0'},
 'baseline': {'n_is_nc': '', 'n_is_sth': ''},
 'basement': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'bash': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'basilica': {'n_is_nc': '', 'n_is_sth': ''},
 'basin': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'basketful': {'n_is_nc': '', 'n_is_sth': ''},
 'basset': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'bassinet': {'n_is_nc': '', 'n_is_sth': ''},
 'basso': {'n_is_nc': '', 'n_is_sb': '0', 'n_is_sth': ''},
 'bastard': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2', 'dirtyword': ''},
 'baster': {'n_is_nc': '', 'n_is_sb': '0'},
 'bastion': {'n_is_nc': '', 'n_is_sth': ''},
 'bathe': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'bathed', 'nsubjpass': '', 'vb_to_jj': 'bathed', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'bathhouse': {'n_is_nc': '', 'n_is_sth': ''},
 'bathrobe': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'bathtub': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'batman': {'n_is_nc': '', 'n_is_sb': '0'},
 'baton': {'n_is_nc': '', 'n_is_sth': ''},
 'battalion': {'n_is_nc': '', 'n_is_sth': ''},
 'batten': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'batter': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'battery': {'n_is_nc': '', 'n_is_sth': ''},
 'battlefield': {'n_is_nc': '', 'n_is_sth': ''},
 'battlefront': {'n_is_nc': '', 'n_is_sth': ''},
 'battleground': {'n_is_nc': '', 'n_is_sth': ''},
 'battleship': {'n_is_nc': '', 'n_is_sth': ''},
 'bauble': {'n_is_nc': '', 'n_is_sth': ''},
 'bawd': {'n_is_nc': '', 'n_is_sb': '0'},
 'bay': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'bayonet': {'n_is_nc': '', 'n_is_sth': ''},
 'bazaar': {'n_is_nc': '', 'n_is_sth': ''},
 'bazar': {'n_is_nc': '', 'n_is_sth': ''},
 'bazooka': {'n_is_nc': '', 'n_is_sth': ''},
 'beachhead': {'n_is_nc': '', 'n_is_sth': ''},
 'beacon': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bead': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'beadle': {'n_is_nc': '', 'n_is_sb': '0'},
 'beads': {'n_is_nc': '', 'n_is_sth': ''},
 'beagle': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'beak': {'n_is_nc': '', 'n_is_sb': '2', 'nn_to_jj': 'beaked', 'n_is_sth': '2'},
 'beaker': {'n_is_nc': '', 'n_is_sth': ''},
 'beam': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'beamed', 'vb_to_jj': 'beamed', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'beanstalk': {'n_is_nc': '', 'n_is_sth': ''},
 'bearcat': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'beaver': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'beck': {'n_is_nc': '', 'n_is_sth': ''},
 'bedbug': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'bedchamber': {'n_is_nc': '', 'n_is_sth': ''},
 'bedclothes': {'n_is_nc': '', 'n_is_sth': ''},
 'bedfellow': {'n_is_nc': '', 'n_is_sb': '0'},
 'bedlam': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'bedpan': {'n_is_nc': '', 'n_is_sth': ''},
 'bedroll': {'n_is_nc': '', 'n_is_sth': ''},
 'bedsore': {'n_is_nc': '', 'n_is_sth': ''},
 'bedstead': {'n_is_nc': '', 'n_is_sth': ''},
 'beefeater': {'n_is_nc': '', 'n_is_sb': '0'},
 'beefsteak': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'beehive': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'beeline': {'n_is_nc': '', 'n_is_sth': ''},
 'beep': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'beer': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'beetle': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'beetroot': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'begonia': {'n_is_nc': '', 'n_is_sth': ''},
 'begum': {'n_is_nc': '', 'n_is_sb': '0'},
 'behaviour': {'n_is_nc': '', 'nn_to_vb': 'behave', 'nn_to_jj': 'behavioural', 'nu_typical': '', 'n_is_sth': '0'},
 'behemoth': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'behest': {'n_is_nc': '', 'n_is_sth': ''},
 'belch': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'beldame': {'n_is_nc': '', 'n_is_sb': '0'},
 'belfry': {'n_is_nc': '', 'n_is_sth': ''},
 'bellboy': {'n_is_nc': '', 'n_is_sb': '0'},
 'bellhop': {'n_is_nc': '', 'n_is_sb': '0'},
 'belligerent': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'bellman': {'n_is_nc': '', 'n_is_sb': '0'},
 'bellow': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'bellwether': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'belly': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nc_typical': ''},
 'bellyache': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bellyful': {'n_is_nc': '', 'n_is_sth': ''},
 'belongings': {'n_is_nc': '', 'n_is_sth': ''},
 'belting': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'belt', 'nn_to_jj': 'belted'},
 'beluga': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'belvedere': {'n_is_nc': '', 'n_is_sth': ''},
 'bema': {'n_is_nc': '', 'n_is_sth': ''},
 'benchmark': {'n_is_nc': '', 'n_is_sth': ''},
 'bend': {'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'vb_to_vbz': 'bends', 'vb_to_vbd': 'bent', 'vb_to_vbn': 'bent', 'vb_to_vbg': 'bending', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'bender': {'n_is_nc': '', 'n_is_sb': '0'},
 'bends': {'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'bend'},
 'benediction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'benefactor': {'n_is_nc': '', 'n_is_sb': '0'},
 'bennet': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'bent': {'n_is_nc': '', 'n_is_sth': '', 'vbd_to_vb': 'bend', 'vbn_to_vb': 'bend', 'vbn_to_vbg': 'bending', 'vbd_eq_vbn': ''},
 'benthos': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'bequest': {'n_is_nc': '', 'n_is_sth': ''},
 'bereavement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'beret': {'n_is_nc': '', 'n_is_sth': ''},
 'berg': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'berm': {'n_is_nc': '', 'n_is_sth': ''},
 'berth': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'bet': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'v_against': '', 'vb_to_vbz': 'bets', 'vb_to_vbg': 'betting', 'vbn_to_vbg': 'betting', 'v_prprtcl_non': ''},
 'bethel': {'n_is_nc': '', 'n_is_sth': ''},
 'betrayal': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'betrayer': {'n_is_nc': '', 'n_is_sb': '0'},
 'betrothal': {'n_is_nc': '', 'n_is_sth': ''},
 'betrothed': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'betterment': {'n_is_nc': '', 'n_is_sth': ''},
 'bevel': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'beverage': {'n_is_nc': '', 'n_is_sth': ''},
 'bevy': {'n_is_nc': '', 'n_is_sth': ''},
 'bezel': {'n_is_nc': '', 'n_is_sth': ''},
 'bib': {'n_is_nc': '', 'n_is_sth': ''},
 'bible': {'n_is_nc': '', 'n_is_sth': ''},
 'bibliography': {'n_is_nc': '', 'n_is_sth': ''},
 'biceps': {'n_is_nc': '', 'n_is_sth': ''},
 'bicker': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'bicycle': {'n_is_nc': '', 'n_is_sth': '', 'vb_to_vbz': 'bicycles', 'vb_to_vbd': 'bicycled', 'vb_to_vbn': 'bicycled', 'vb_to_vbg': 'bicycling', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'bid': {'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'vb_to_vbz': 'bids', 'vb_to_vbd': 'bid/bidden', 'vb_to_vbn': 'bid/bidden', 'vb_to_vbg': 'bidding', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'bidder': {'n_is_nc': '', 'n_is_sb': '0'},
 'biddy': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'bidet': {'n_is_nc': '', 'n_is_sth': ''},
 'biennial': {'n_is_nc': '', 'n_is_sth': ''},
 'bier': {'n_is_nc': '', 'n_is_sth': ''},
 'bifurcation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'bight': {'n_is_nc': '', 'n_is_sth': ''},
 'bigot': {'n_is_nc': '', 'n_is_sb': '0'},
 'bigwig': {'n_is_nc': '', 'n_is_sb': '0'},
 'bijou': {'n_is_nc': '', 'n_is_sth': ''},
 'bilge': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'billabong': {'n_is_nc': '', 'n_is_sth': ''},
 'billboard': {'n_is_nc': '', 'n_is_sth': ''},
 'billet': {'n_is_nc': '', 'n_is_sth': ''},
 'billfish': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'billfold': {'n_is_nc': '', 'n_is_sth': ''},
 'billion': {'n_is_nc': '', 'n_is_sth': ''},
 'billionaire': {'n_is_nc': '', 'n_is_sb': '0'},
 'billow': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'billy': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'bimbo': {'n_is_nc': '', 'n_is_sb': '0'},
 'bimonthly': {'n_is_nc': '', 'n_is_sth': ''},
 'bin': {'n_is_nc': '', 'n_is_sth': ''},
 'binary': {'n_is_nc': '', 'n_is_sth': ''},
 'binder': {'n_is_nc': '', 'n_is_sth': ''},
 'bionomics': {'n_is_nc': '', 'n_is_sth': ''},
 'bioscope': {'n_is_nc': '', 'n_is_sth': ''},
 'biosphere': {'n_is_nc': '', 'n_is_sth': ''},
 'birch': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'birdbrain': {'n_is_nc': '', 'n_is_sb': '0'},
 'birdie': {'n_is_nc': '', 'n_is_sb': '3', 'vbd_eq_vbn': '', 'n_is_sth': '3'},
 'birthmark': {'n_is_nc': '', 'n_is_sth': ''},
 'bishop': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nc_typical': ''},
 'bison': {'n_is_nc': '', 'n_is_sb': '3', 'nn_eq_nns': '', 'n_is_sth': '3'},
 'bivalve': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'bivouac': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'vb_to_vbz': 'bivouacs', 'vb_to_vbg': 'bivouacking', 'vb_to_vbd': 'bivouacked', 'vb_to_vbn': 'bivouacked', 'vbd_eq_vbn': ''},
 'biweekly': {'n_is_nc': '', 'n_is_sth': ''},
 'blabbermouth': {'n_is_nc': '', 'n_is_sb': '0'},
 'blackball': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'blackguard': {'n_is_nc': '', 'n_is_sb': '0'},
 'bladder': {'n_is_nc': '', 'n_is_sth': ''},
 'blade': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'blain': {'n_is_nc': '', 'n_is_sth': ''},
 'blast': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'blather': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'blaze': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'bleacher': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'bleat': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bleeder': {'n_is_nc': '', 'n_is_sb': '0'},
 'blemish': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'blend': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'blender': {'n_is_nc': '', 'n_is_sth': ''},
 'blight': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'blimp': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'blinder': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'blindfold': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'blink': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'blinker': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'blip': {'n_is_nc': '', 'n_is_sth': ''},
 'blister': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'blitz': {'n_is_nc': '', 'n_is_sth': ''},
 'blizzard': {'n_is_nc': '', 'n_is_sth': ''},
 'blob': {'n_is_nc': '', 'n_is_sth': ''},
 'bloc': {'n_is_nc': '', 'n_is_sth': ''},
 'blockade': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'blockage': {'n_is_nc': '', 'n_is_sth': ''},
 'blockhead': {'n_is_nc': '', 'n_is_sb': '0'},
 'blockhouse': {'n_is_nc': '', 'n_is_sth': ''},
 'bloke': {'n_is_nc': '', 'n_is_sb': '0'},
 'blood': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'bloody', 'nn_to_rb': 'bloodily', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'bloods', 'vb_to_vbd': 'blooded', 'vb_to_vbn': 'blooded', 'vb_to_rb': 'bloodily', 'vb_to_jj': 'bloody', 'vb_to_vbg': 'blooding', 'vbd_eq_vbn': '', 'nu_typical': ''},
 'bloodbath': {'n_is_nc': '', 'n_is_sth': ''},
 'bloodhound': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'bloodline': {'n_is_nc': '', 'n_is_sth': ''},
 'bloodstain': {'n_is_nc': '', 'n_is_sth': ''},
 'bloodsucker': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'blooper': {'n_is_nc': '', 'n_is_sth': ''},
 'blotch': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'blow': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'blown', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_of': '', 'v_from': '', 'vb_to_vbz': 'blows', 'vb_to_vbd': 'blew', 'vb_to_vbn': 'blown', 'vb_to_jj': 'blown', 'vb_to_vbg': 'blowing', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'blower': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'blowhole': {'n_is_nc': '', 'n_is_sth': ''},
 'blowout': {'n_is_nc': '', 'n_is_sth': ''},
 'blowtorch': {'n_is_nc': '', 'n_is_sth': ''},
 'blowup': {'n_is_nc': '', 'n_is_sth': ''},
 'bludgeon': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'bluebeard': {'n_is_nc': '', 'n_is_sb': '0'},
 'bluebonnet': {'n_is_nc': '', 'n_is_sth': ''},
 'blueness': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'blue', 'nn_to_jj': 'blue'},
 'blueprint': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'blunder': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'blur': {'n_is_nc': '', 'n_is_sth': '', 'v_prprtcl_non': ''},
 'blush': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'boa': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'boar': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'board': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'boards', 'vb_to_vbd': 'boarded', 'vb_to_vbn': 'boarded', 'vb_to_vbg': 'boarding', 'vbd_eq_vbn': ''},
 'boarder': {'n_is_nc': '', 'n_is_sb': '0'},
 'boardroom': {'n_is_nc': '', 'n_is_sth': ''},
 'boast': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'boastful', 'v_compcl': '', 'vb_to_jj': 'boastful', 'vbd_eq_vbn': '', 'v_pass_non': ''},
 'boater': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'boatman': {'n_is_nc': '', 'n_is_sb': '0'},
 'bob': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'bobbin': {'n_is_nc': '', 'n_is_sth': ''},
 'bobby': {'n_is_nc': '', 'n_is_sb': '0'},
 'bobsled': {'n_is_nc': '', 'n_is_sth': ''},
 'bodega': {'n_is_nc': '', 'n_is_sth': ''},
 'bodkin': {'n_is_nc': '', 'n_is_sth': ''},
 'boffin': {'n_is_nc': '', 'n_is_sb': '0'},
 'bogey': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'bogeyman': {'n_is_nc': '', 'n_is_sb': '0'},
 'bogie': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'bohemian': {'n_is_nc': '', 'n_is_sb': '0'},
 'boil': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'boiling', 'nn_to_rb': 'boiling', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_with': '', 'vb_to_vbz': 'boils', 'vb_to_vbd': 'boiled', 'vb_to_vbn': 'boiled', 'vb_to_rb': 'boiling', 'vb_to_jj': 'boiling', 'vb_to_vbg': 'boiling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'boiler': {'n_is_nc': '', 'n_is_sth': ''},
 'boll': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'bolo': {'n_is_nc': '', 'n_is_sth': ''},
 'bolster': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'bolt': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'bolus': {'n_is_nc': '', 'n_is_sth': ''},
 'bombardier': {'n_is_nc': '', 'n_is_sb': '0'},
 'bombardment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'bomber': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'bombshell': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'bonanza': {'n_is_nc': '', 'n_is_sth': ''},
 'bonbon': {'n_is_nc': '', 'n_is_sth': ''},
 'bond': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'bonding', 'v_n': '', 'nsubjpass': '', 'vb_to_jj': 'bonding', 'v_compcl_non': '', 'v_whcl_non': ''},
 'bondsman': {'n_is_nc': '', 'n_is_sb': '0'},
 'bonehead': {'n_is_nc': '', 'n_is_sb': '0'},
 'bonnet': {'n_is_nc': '', 'n_is_sth': ''},
 'bonsai': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'boo': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'boo-boo': {'n_is_nc': '', 'n_is_sth': ''},
 'boob': {'n_is_nc': '', 'n_is_sb': '0'},
 'booby': {'n_is_nc': '', 'n_is_sb': '0'},
 'bookcase': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'booking': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'book', 'vbg_to_vbn': 'booked'},
 'bookkeeper': {'n_is_nc': '', 'n_is_sb': '0'},
 'booklet': {'n_is_nc': '', 'n_is_sth': ''},
 'boondocks': {'n_is_nc': '', 'n_is_sth': ''},
 'boor': {'n_is_nc': '', 'n_is_sb': '0'},
 'booth': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nc_typical': ''},
 'bootlegger': {'n_is_nc': '', 'n_is_sb': '0'},
 'booty': {'n_is_nc': '', 'n_is_sth': ''},
 'bop': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bordello': {'n_is_nc': '', 'n_is_sth': ''},
 'border': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'bordered', 'vb_to_jj': 'bordered', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'borderland': {'n_is_nc': '', 'n_is_sth': ''},
 'borderline': {'n_is_nc': '', 'n_is_sth': ''},
 'bore': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_through_n': '', 'v_into_n': '', 'v_n_through_n': '', 'v_n_into_n': '', 'v_n_in_n': ''},
 'borer': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'borough': {'n_is_nc': '', 'n_is_sth': ''},
 'bosom': {'n_is_nc': '', 'n_is_sth': ''},
 'bot': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'botch': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'bother': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_vbg': '', 'v_to_vb': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_about': '', 'vb_to_vbz': 'bothers', 'vb_to_vbd': 'bothered', 'vb_to_vbn': 'bothered', 'vb_to_vbg': 'bothering', 'vbd_eq_vbn': ''},
 'bottle': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'bottled', 'vb_to_jj': 'bottled', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'nc_typical': ''},
 'bottlebrush': {'n_is_nc': '', 'n_is_sth': ''},
 'bottleneck': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'bottlenose': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'boudoir': {'n_is_nc': '', 'n_is_sth': ''},
 'bough': {'n_is_nc': '', 'n_is_sth': ''},
 'boulder': {'n_is_nc': '', 'n_is_sth': ''},
 'boulevard': {'n_is_nc': '', 'n_is_sth': ''},
 'boulevardier': {'n_is_nc': '', 'n_is_sb': '0'},
 'bounce': {'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_against': '', 'vb_to_vbz': 'bounces', 'vb_to_vbd': 'bounced', 'vb_to_vbn': 'bounced', 'vb_to_vbg': 'bouncing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'bouncer': {'n_is_nc': '', 'n_is_sb': '0'},
 'bound': {'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'bounds', 'vb_to_vbd': 'bounded', 'vb_to_vbn': 'bounded', 'vb_to_vbg': 'bounding', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'bounds': {'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'bound'},
 'bounty': {'n_is_nc': '', 'n_is_sth': ''},
 'bouquet': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'bourgeois': {'n_is_nc': '', 'n_is_sb': '0'},
 'bourne': {'n_is_nc': '', 'n_is_sth': ''},
 'bout': {'n_is_nc': '', 'n_is_sth': ''},
 'bowel': {'n_is_nc': '', 'n_is_sth': ''},
 'bowels': {'n_is_nc': '', 'n_is_sth': ''},
 'bower': {'n_is_nc': '', 'n_is_sth': ''},
 'bowler': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'boxcar': {'n_is_nc': '', 'n_is_sth': ''},
 'boxer': {'n_is_nc': '', 'n_is_sb': '0'},
 'bozo': {'n_is_nc': '', 'n_is_sb': '0'},
 'bra': {'n_is_nc': '', 'n_is_sth': ''},
 'bracing': {'n_is_nc': '', 'n_is_sth': ''},
 'brad': {'n_is_nc': '', 'n_is_sth': ''},
 'brag': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'braggadocio': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'brahmin': {'n_is_nc': '', 'n_is_sb': '0'},
 'braid': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'braiding': {'n_is_nc': '', 'n_is_sth': ''},
 'brainpan': {'n_is_nc': '', 'n_is_sth': ''},
 'brake': {'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bramble': {'n_is_nc': '', 'n_is_sth': ''},
 'brassard': {'n_is_nc': '', 'n_is_sth': ''},
 'bravo': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'brawl': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'bray': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'brazier': {'n_is_nc': '', 'n_is_sth': ''},
 'breach': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'breakage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'breakaway': {'n_is_nc': '', 'n_is_sth': ''},
 'breakdown': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'breaker': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'breakfast': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'breaking': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'break', 'vbg_to_vbn': 'broken'},
 'breakout': {'n_is_nc': '', 'n_is_sth': ''},
 'breakthrough': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'breakup': {'n_is_nc': '', 'n_is_sth': ''},
 'breakwater': {'n_is_nc': '', 'n_is_sth': ''},
 'bream': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'breast': {'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'breasts', 'vb_to_vbd': 'breasted', 'vb_to_vbn': 'breasted', 'vb_to_vbg': 'breasting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'breastbone': {'n_is_nc': '', 'n_is_sth': ''},
 'breastplate': {'n_is_nc': '', 'n_is_sth': ''},
 'breath': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'breathe'},
 'breather': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'breech': {'n_is_nc': '', 'n_is_sth': ''},
 'breeches': {'n_is_nc': '', 'n_is_sth': ''},
 'breed': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'breeder': {'n_is_nc': '', 'n_is_sb': '0', 'nn_to_nns': 'breeders'},
 'breeze': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'breve': {'n_is_nc': '', 'n_is_sth': ''},
 'brickbat': {'n_is_nc': '', 'n_is_sth': ''},
 'brickfield': {'n_is_nc': '', 'n_is_sth': ''},
 'bridal': {'n_is_nc': '', 'n_is_sth': ''},
 'bridgehead': {'n_is_nc': '', 'n_is_sth': ''},
 'brigadier': {'n_is_nc': '', 'n_is_sb': '0'},
 'brigand': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'briny': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'briquette': {'n_is_nc': '', 'n_is_sth': ''},
 'broach': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'broadsword': {'n_is_nc': '', 'n_is_sth': ''},
 'broil': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'brooch': {'n_is_nc': '', 'n_is_sth': ''},
 'brood': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'brooder': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'brook': {'n_is_nc': '', 'n_is_sth': '', 'v_vbg': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'broth': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'brothel': {'n_is_nc': ''},
 'brother': {'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'brotherly', 'nn_to_rb': 'brotherly', 'nc_typical': ''},
 'brother-in-law': {'n_is_nc': '', 'n_is_sb': '0'},
 'brotherhood': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'brown': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'jj_to_jjr': 'browner', 'jj_to_jjs': 'brownest'},
 'brownie': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'browning': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'brownness': {'n_is_nc': '', 'n_is_sth': ''},
 'bruise': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'bruiser': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'brunt': {'n_is_nc': '', 'n_is_sth': ''},
 'brush-off': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'brushing': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'brush', 'vbg_to_vbn': 'brushed'},
 'brutality': {'n_is_nc': '', 'n_is_sth': ''},
 'brute': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'bubble': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'buccaneer': {'n_is_nc': '', 'n_is_sb': '0'},
 'buck': {'n_is_nc': '', 'n_is_sb': '3', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'v_against': '', 'vb_to_vbz': 'bucks', 'vb_to_vbd': 'bucked', 'vb_to_vbn': 'bucked', 'vb_to_vbg': 'bucking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'n_is_sth': '3'},
 'buckaroo': {'n_is_nc': '', 'n_is_sb': '0'},
 'buckeye': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'buckle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'buckler': {'n_is_nc': '', 'n_is_sth': ''},
 'bucolic': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'bud': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'buddha': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'buddhist': {'n_is_nc': '', 'n_is_sb': '0'},
 'buddy': {'n_is_nc': '', 'n_is_sb': '0'},
 'budget': {'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_to_n': '', 'vdo': '', 'vb_to_vbz': 'budgets', 'vb_to_vbd': 'budgeted', 'vb_to_vbn': 'budgeted', 'vb_to_vbg': 'budgeting', 'vbd_eq_vbn': '', 'v_whcl_non': '', 'nc_typical': ''},
 'buffer': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'buffet': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'buffoon': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'bug': {'n_is_nc': '', 'n_is_sb': '3', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'bugs', 'vb_to_vbd': 'bugged', 'vb_to_vbn': 'bugged', 'vb_to_vbg': 'bugging', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'n_is_sth': '3'},
 'bugaboo': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'bugbear': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'bugger': {'n_is_nc': '', 'n_is_sb': '0'},
 'bugle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bugler': {'n_is_nc': '', 'n_is_sb': '0'},
 'build': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_to_vbz': 'builds', 'vb_to_vbd': 'built', 'vb_to_vbn': 'built', 'vb_to_vbg': 'building', 'vt_typical': '', 'v_compcl_non': ''},
 'builder': {'n_is_nc': '', 'n_is_sb': '0'},
 'bulge': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'bulk': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'bulky', 'nn_to_rb': 'bulkily', 'vb_to_rb': 'bulkily', 'vb_to_jj': 'bulky', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'bulkhead': {'n_is_nc': '', 'n_is_sth': ''},
 "bull's-eye": {'n_is_nc': '', 'n_is_sth': ''},
 'bulla': {'n_is_nc': '', 'n_is_sth': ''},
 'bulldog': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'bulldozer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'bulletin': {'n_is_nc': '', 'n_is_sth': ''},
 'bullfight': {'n_is_nc': '', 'n_is_sth': ''},
 'bullfrog': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'bullhead': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'bullhorn': {'n_is_nc': '', 'n_is_sth': ''},
 'bullock': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'bullpen': {'n_is_nc': '', 'n_is_sth': ''},
 'bully': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'bulwark': {'n_is_nc': '', 'n_is_sth': ''},
 'bum': {'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'n_is_sth': '2'},
 'bumblebee': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'bummer': {'n_is_nc': '', 'n_is_sth': ''},
 'bump': {'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_against': '', 'vb_to_vbz': 'bumps', 'vb_to_vbd': 'bumped', 'vb_to_vbn': 'bumped', 'vb_to_vbg': 'bumping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'bumper': {'n_is_nc': '', 'n_is_sth': ''},
 'bumpkin': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'bun': {'n_is_nc': '', 'n_is_sth': ''},
 'bungalow': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'bungle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'bunker': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'bunny': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'bunt': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'buoy': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'bur': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'burden': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'burdock': {'n_is_nc': '', 'n_is_sth': ''},
 'bureaucracy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'bureaucrat': {'n_is_nc': '', 'n_is_sb': '0'},
 'burg': {'n_is_nc': '', 'n_is_sth': ''},
 'burger': {'n_is_nc': '', 'n_is_sth': ''},
 'burgess': {'n_is_nc': '', 'n_is_sb': '0'},
 'burgher': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'burglar': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'burglary': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'burgomaster': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'burial': {'n_is_nc': '', 'n_is_sth': ''},
 'burl': {'n_is_nc': '', 'n_is_sth': ''},
 'burlesque': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'burn': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'burning', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_with': '', 'vb_to_vbz': 'burns', 'vb_to_vbd': 'burned', 'vb_to_vbn': 'burned', 'vb_to_jj': 'burning', 'vb_to_vbg': 'burning'},
 'burner': {'n_is_nc': '', 'n_is_sth': ''},
 'burns': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'vbz_to_vb': 'burn'},
 'burp': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'burr': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'burro': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'burrow': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'burst': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'bursting', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'v_with': '', 'vb_to_vbz': 'bursts', 'vb_to_vbd': 'bursted', 'vb_to_vbn': 'bursted', 'vb_to_jj': 'bursting', 'vb_to_vbg': 'bursting', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'business': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'businessman': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'businessmen': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'buss': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'bust': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbd_eq_vbn': ''},
 'bust-up': {'n_is_nc': '', 'n_is_sth': ''},
 'bustard': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'buster': {'n_is_nc': '', 'n_is_sb': '0'},
 'bustle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'butadiene': {'n_is_nc': '', 'n_is_sth': ''},
 'butch': {'n_is_nc': '', 'n_is_sb': '0'},
 'butcher': {'n_is_nc': '', 'n_is_sb': '0', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'butchers', 'vb_to_vbd': 'butchered', 'vb_to_vbn': 'butchered', 'vb_to_vbg': 'butchering', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'vt_typical': '', 'nc_typical': ''},
 'butchery': {'n_is_nc': '', 'n_is_sth': ''},
 'butler': {'n_is_nc': '', 'n_is_sb': '0'},
 'butt': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'butterball': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'buttercup': {'n_is_nc': '', 'n_is_sth': ''},
 'buttock': {'n_is_nc': '', 'n_is_sth': ''},
 'buttocks': {'n_is_nc': '', 'n_is_sth': ''},
 'buttonhole': {'n_is_nc': '', 'n_is_sth': ''},
 'buttress': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'buy': {'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_to_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_for': '', 'v_from': '', 'vb_to_vbz': 'buys', 'vb_to_vbd': 'bought', 'vb_to_vbn': 'bought', 'vb_to_vbg': 'buying', 'vt_typical': '', 'v_compcl_non': ''},
 'buyer': {'n_is_nc': '', 'n_is_sb': '0'},
 'buzzard': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'buzzer': {'n_is_nc': '', 'n_is_sth': ''},
 'buzzword': {'n_is_nc': '', 'n_is_sth': ''},
 'by-product': {'n_is_nc': '', 'n_is_sth': ''},
 'bye': {'n_is_nc': '', 'n_is_sth': ''},
 'bygone': {'n_is_nc': '', 'n_is_sth': ''},
 'bylaw': {'n_is_nc': '', 'n_is_sth': ''},
 'bypass': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'byproduct': {'n_is_nc': '', 'n_is_sth': ''},
 'bystander': {'n_is_nc': '', 'n_is_sb': '0'},
 'byte': {'n_is_nc': '', 'n_is_sth': ''},
 'byway': {'n_is_nc': '', 'n_is_sth': ''},
 'byword': {'n_is_nc': '', 'n_is_sth': ''},
 'cab': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'cabal': {'n_is_nc': '', 'n_is_sth': ''},
 'cabala': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'cabana': {'n_is_nc': '', 'n_is_sth': ''},
 'cabaret': {'n_is_nc': '', 'n_is_sth': ''},
 'caboodle': {'n_is_nc': '', 'n_is_sth': ''},
 'caboose': {'n_is_nc': '', 'n_is_sth': ''},
 'cache': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cackle': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'cacophony': {'n_is_nc': '', 'n_is_sth': ''},
 'cadaver': {'n_is_nc': '', 'n_is_sth': ''},
 'caddy': {'n_is_nc': '', 'n_is_sth': ''},
 'cadence': {'n_is_nc': '', 'n_is_sth': ''},
 'cadenza': {'n_is_nc': '', 'n_is_sth': ''},
 'cadet': {'n_is_nc': '', 'n_is_sb': '0'},
 'cadre': {'n_is_nc': '', 'n_is_sth': ''},
 'caisson': {'n_is_nc': '', 'n_is_sth': ''},
 'cake': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'calabash': {'n_is_nc': '', 'n_is_sth': ''},
 'caladium': {'n_is_nc': '', 'n_is_sth': ''},
 'calculus': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'caldron': {'n_is_nc': '', 'n_is_sth': ''},
 'calendula': {'n_is_nc': '', 'n_is_sth': ''},
 'caliber': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'calibration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'calibre': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'calico': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'caliper': {'n_is_nc': '', 'n_is_sth': ''},
 'caliph': {'n_is_nc': '', 'n_is_sb': '0'},
 'call': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'called', 'v_to_vbg': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'calls', 'vb_to_vbd': 'called', 'vb_to_vbn': 'called', 'vb_to_jj': 'called', 'vb_to_vbg': 'calling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'caller': {'n_is_nc': '', 'n_is_sb': '0'},
 'calligrapher': {'n_is_nc': '', 'n_is_sb': '0'},
 'calling': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'call', 'vbg_to_vbn': 'called'},
 'callus': {'n_is_nc': '', 'n_is_sth': ''},
 'calm': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'calms', 'vb_to_vbd': 'calmed', 'vb_to_vbn': 'calmed', 'vb_to_vbg': 'calming', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'jj_to_jjr': 'calmer', 'jj_to_jjs': 'calmest'},
 'calorie': {'n_is_nc': '', 'n_is_sth': ''},
 'calumny': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'calyx': {'n_is_nc': '', 'n_is_sth': ''},
 'cam': {'n_is_nc': '', 'n_is_sth': ''},
 'camber': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'cambium': {'n_is_nc': '', 'n_is_sth': ''},
 'cambrian': {'n_is_nc': '', 'n_is_sb': '0'},
 'camcorder': {'n_is_nc': '', 'n_is_sth': ''},
 'camellia': {'n_is_nc': '', 'n_is_sth': ''},
 'cameo': {'n_is_nc': '', 'n_is_sth': ''},
 'camera': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'cameraman': {'n_is_nc': '', 'n_is_sb': '0'},
 'campaign': {'n_is_nc': '', 'n_is_sth': '', 'v_to_vb': '', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_for': '', 'v_against': '', 'vb_to_vbz': 'campaigns', 'vb_to_vbd': 'campaigned', 'vb_to_vbn': 'campaigned', 'vb_to_vbg': 'campaigning', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'campaigner': {'n_is_nc': '', 'n_is_sb': '0'},
 'campanile': {'n_is_nc': '', 'n_is_sth': ''},
 'campfire': {'n_is_nc': '', 'n_is_sth': ''},
 'campsite': {'n_is_nc': '', 'n_is_sth': ''},
 'canard': {'n_is_nc': '', 'n_is_sth': ''},
 'canary': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'cancellation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'cancer': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'candelabrum': {'n_is_nc': '', 'n_is_sth': ''},
 'candlestick': {'n_is_nc': '', 'n_is_sth': ''},
 'cane': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'canine': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'canister': {'n_is_nc': '', 'n_is_sth': ''},
 'canker': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'canna': {'n_is_nc': '', 'n_is_sth': ''},
 'cannon': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cannonball': {'n_is_nc': '', 'n_is_sth': ''},
 'cannula': {'n_is_nc': '', 'n_is_sth': ''},
 'canoe': {'n_is_nc': '', 'n_is_sth': ''},
 'canon': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'canopy': {'n_is_nc': '', 'n_is_sth': ''},
 'cant': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cantaloupe': {'n_is_nc': '', 'n_is_sth': ''},
 'cantata': {'n_is_nc': '', 'n_is_sth': ''},
 'canter': {'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'cantilever': {'n_is_nc': '', 'n_is_sth': ''},
 'canto': {'n_is_nc': '', 'n_is_sth': ''},
 'canton': {'n_is_nc': '', 'n_is_sth': ''},
 'cantonese': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '0'},
 'canvas': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'canvass': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'canvasser': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'cap': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'capped', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'caps', 'vb_to_vbd': 'capped', 'vb_to_vbn': 'capped', 'vb_to_jj': 'capped', 'vb_to_vbg': 'capping', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'nc_typical': ''},
 'capability': {'n_is_nc': '', 'n_is_sth': ''},
 'capacitor': {'n_is_nc': '', 'n_is_sth': ''},
 'capacity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'capacitate', 'nn_to_jj': 'capable', 'nn_to_rb': 'capably'},
 'cape': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'caped'},
 'capitalist': {'n_is_nc': '', 'n_is_sb': '0'},
 'capitulation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'capo': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'capon': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'capriccio': {'n_is_nc': '', 'n_is_sth': ''},
 'caprice': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'capsicum': {'n_is_nc': '', 'n_is_sth': ''},
 'capstone': {'n_is_nc': '', 'n_is_sth': ''},
 'capsule': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'caption': {'n_is_nc': '', 'n_is_sth': ''},
 'captive': {'n_is_nc': '', 'n_is_sb': '0'},
 'capuchin': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'carafe': {'n_is_nc': '', 'n_is_sth': ''},
 'carambola': {'n_is_nc': '', 'n_is_sth': ''},
 'caramel': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'carapace': {'n_is_nc': '', 'n_is_sth': ''},
 'carat': {'n_is_nc': '', 'n_is_sth': ''},
 'caravan': {'n_is_nc': '', 'n_is_sth': ''},
 'caraway': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'carbine': {'n_is_nc': '', 'n_is_sth': ''},
 'carbonate': {'n_is_nc': '', 'n_is_sth': ''},
 'carbuncle': {'n_is_nc': '', 'n_is_sth': ''},
 'carburetor': {'n_is_nc': '', 'n_is_sth': ''},
 'carcass': {'n_is_nc': '', 'n_is_sth': '0'},
 'carcinogen': {'n_is_nc': '', 'n_is_sth': ''},
 'carcinoma': {'n_is_nc': '', 'n_is_sth': ''},
 'cardigan': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'careerist': {'n_is_nc': '', 'n_is_sb': '0'},
 'caress': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'caretaker': {'n_is_nc': '', 'n_is_sb': '0'},
 'caribou': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'caricature': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'caricaturist': {'n_is_nc': '', 'n_is_sb': '0'},
 'carillon': {'n_is_nc': '', 'n_is_sth': ''},
 'carina': {'n_is_nc': '', 'n_is_sth': ''},
 'carnelian': {'n_is_nc': '', 'n_is_sth': ''},
 'carnival': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'carol': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'carp': {'n_is_nc': '', 'n_is_sb': '3', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'n_is_sth': '3'},
 'carpal': {'n_is_nc': '', 'n_is_sth': ''},
 'carport': {'n_is_nc': '', 'n_is_sth': ''},
 'carry-over': {'n_is_nc': '', 'n_is_sth': ''},
 'carryall': {'n_is_nc': '', 'n_is_sth': ''},
 'cartel': {'n_is_nc': '', 'n_is_sth': ''},
 'cartilage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'cartload': {'n_is_nc': '', 'n_is_sth': ''},
 'cartographer': {'n_is_nc': '', 'n_is_sb': '0'},
 'carton': {'n_is_nc': '', 'n_is_sth': ''},
 'cartoonist': {'n_is_nc': '', 'n_is_sb': '0'},
 'cartridge': {'n_is_nc': '', 'n_is_sth': ''},
 'cartwheel': {'n_is_nc': '', 'n_is_sth': ''},
 'carver': {'n_is_nc': '', 'n_is_sb': '0'},
 'casaba': {'n_is_nc': '', 'n_is_sth': ''},
 'casbah': {'n_is_nc': '', 'n_is_sth': ''},
 'cascabel': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'cascade': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'casebook': {'n_is_nc': '', 'n_is_sth': ''},
 'casement': {'n_is_nc': '', 'n_is_sth': ''},
 'cashew': {'n_is_nc': '', 'n_is_sth': ''},
 'cashier': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'casing': {'n_is_nc': '', 'n_is_sth': ''},
 'cask': {'n_is_nc': '', 'n_is_sth': ''},
 'casket': {'n_is_nc': '', 'n_is_sth': ''},
 'cassava': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'casserole': {'n_is_nc': '', 'n_is_sth': ''},
 'cassock': {'n_is_nc': '', 'n_is_sth': ''},
 'cassowary': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'castaway': {'n_is_nc': '', 'n_is_sb': '0'},
 'caste': {'n_is_nc': '', 'n_is_sth': ''},
 'caster': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'casting': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'cast', 'vbg_to_vbn': 'casted'},
 'castor': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'casualty': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'cataclysm': {'n_is_nc': '', 'n_is_sth': ''},
 'catacomb': {'n_is_nc': '', 'n_is_sth': ''},
 'catalpa': {'n_is_nc': '', 'n_is_sth': ''},
 'catalyst': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'catamaran': {'n_is_nc': '', 'n_is_sth': ''},
 'catamount': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'catapult': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'cataract': {'n_is_nc': '', 'n_is_sth': ''},
 'catastrophe': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'catcall': {'n_is_nc': '', 'n_is_sth': ''},
 'catch': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'nn_to_jj': 'catching', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_on': '', 'v_at': '', 'vb_to_vbz': 'catches', 'vb_to_vbd': 'caught', 'vb_to_vbn': 'caught', 'vb_to_jj': 'catching', 'v_n_vbg': '', 'vb_to_vbg': 'catching', 'v_compcl_non': '', 'v_infcl_non': ''},
 'catchall': {'n_is_nc': '', 'n_is_sth': ''},
 'catchment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'catchword': {'n_is_nc': '', 'n_is_sth': ''},
 'catechism': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'catena': {'n_is_nc': '', 'n_is_sth': ''},
 'caterpillar': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'catfish': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'cathartic': {'n_is_nc': '', 'n_is_sth': ''},
 'cathedra': {'n_is_nc': '', 'n_is_sth': ''},
 'cathedral': {'n_is_nc': '', 'n_is_sth': ''},
 'catheter': {'n_is_nc': '', 'n_is_sth': ''},
 'cathode': {'n_is_nc': '', 'n_is_sth': ''},
 'cation': {'n_is_nc': '', 'n_is_sth': ''},
 'catnap': {'n_is_nc': '', 'n_is_sth': ''},
 'cattail': {'n_is_nc': '', 'n_is_sth': ''},
 'caucasian': {'n_is_nc': '', 'n_is_sb': '0'},
 'caul': {'n_is_nc': '', 'n_is_sth': ''},
 'cauldron': {'n_is_nc': '', 'n_is_sth': ''},
 'cauliflower': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'causeway': {'n_is_nc': '', 'n_is_sth': ''},
 'cavalcade': {'n_is_nc': '', 'n_is_sth': ''},
 'cavalier': {'n_is_nc': '', 'n_is_sb': '0'},
 'cavalry': {'n_is_nc': '', 'n_is_sth': ''},
 'cavalryman': {'n_is_nc': '', 'n_is_sb': '0'},
 'caveat': {'n_is_nc': '', 'n_is_sth': ''},
 'cavern': {'n_is_nc': '', 'n_is_sth': ''},
 'cavil': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cavity': {'n_is_nc': '', 'n_is_sth': ''},
 'caw': {'n_is_nc': '', 'n_is_sth': ''},
 'cay': {'n_is_nc': '', 'n_is_sth': ''},
 'cedar': {'n_is_nc': '', 'n_is_sth': ''},
 'ceiba': {'n_is_nc': '', 'n_is_sth': ''},
 'cello': {'n_is_nc': '', 'n_is_sth': ''},
 'cemetery': {'n_is_nc': '', 'n_is_sth': ''},
 'cenotaph': {'n_is_nc': '', 'n_is_sth': ''},
 'censor': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'cent': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'centavo': {'n_is_nc': '', 'n_is_sth': ''},
 'centimeter': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': '', 'quantifier': ''},
 'centipede': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'centrifuge': {'n_is_nc': '', 'n_is_sth': ''},
 'centrist': {'n_is_nc': '', 'n_is_sb': '0'},
 'centrum': {'n_is_nc': '', 'n_is_sth': ''},
 'ceramic': {'n_is_nc': '', 'n_is_sth': ''},
 'cereal': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'cerebellum': {'n_is_nc': '', 'n_is_sth': ''},
 'cerebrum': {'n_is_nc': '', 'n_is_sth': ''},
 'cero': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'certificate': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'certification': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'cessation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'cesspool': {'n_is_nc': '', 'n_is_sth': ''},
 'cetacean': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'chairperson': {'n_is_nc': '', 'n_is_sb': '0'},
 'chalet': {'n_is_nc': '', 'n_is_sth': ''},
 'chalice': {'n_is_nc': '', 'n_is_sth': ''},
 'chalk': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'chalkboard': {'n_is_nc': '', 'n_is_sth': ''},
 'chamberlain': {'n_is_nc': '', 'n_is_sb': '0'},
 'chambermaid': {'n_is_nc': '', 'n_is_sb': '0'},
 'chameleon': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'chamois': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'champ': {'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'championship': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'chancel': {'n_is_nc': '', 'n_is_sth': ''},
 'chancellery': {'n_is_nc': '', 'n_is_sth': ''},
 'chandler': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'change': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'changeable', 'nn_to_rb': 'changeably', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'changes', 'vb_to_vbd': 'changed', 'vb_to_vbn': 'changed', 'vb_to_rb': 'changeably', 'vb_to_jj': 'changeable', 'vb_to_vbg': 'changing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'changeling': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'chant': {'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'v_to': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'nc_typical': ''},
 'chantey': {'n_is_nc': '', 'n_is_sth': ''},
 'chap': {'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'n_is_sth': '2'},
 'chapel': {'n_is_nc': '', 'n_is_sth': ''},
 'chaperone': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'chaplain': {'n_is_nc': '', 'n_is_sb': '0'},
 'char': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'charcoal': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'charger': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'chariot': {'n_is_nc': '', 'n_is_sth': ''},
 'charlatan': {'n_is_nc': '', 'n_is_sb': '0'},
 'charmer': {'n_is_nc': '', 'n_is_sb': '0'},
 'chaser': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'chasm': {'n_is_nc': '', 'n_is_sth': ''},
 'chassis': {'n_is_nc': '', 'n_is_sth': ''},
 'chastisement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'chastity': {'n_is_nc': '', 'n_is_sth': ''},
 'chateau': {'n_is_nc': '', 'n_is_sth': ''},
 'chattel': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'chatterbox': {'n_is_nc': '', 'n_is_sb': '0'},
 'chauffeur': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'cheapskate': {'n_is_nc': '', 'n_is_sb': '0'},
 'cheater': {'n_is_nc': '', 'n_is_sb': '0'},
 'check': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'checked', 'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_for': '', 'v_against': '', 'vb_to_vbz': 'checks', 'vb_to_vbd': 'checked', 'vb_to_vbn': 'checked', 'vb_to_jj': 'checked', 'vb_to_vbg': 'checking', 'vbd_eq_vbn': ''},
 'checkbook': {'n_is_nc': '', 'n_is_sth': ''},
 'checkerboard': {'n_is_nc': '', 'n_is_sth': ''},
 'checklist': {'n_is_nc': '', 'n_is_sth': ''},
 'checkout': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'checkpoint': {'n_is_nc': '', 'n_is_sth': ''},
 'checkup': {'n_is_nc': '', 'n_is_sth': ''},
 'cheekbone': {'n_is_nc': '', 'n_is_sth': ''},
 'cheer': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'cheerful', 'v_n': '', 'nsubjpass': '', 'v_with': '', 'v_for': '', 'vb_to_jj': 'cheerful', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'cheetah': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'chela': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'chessboard': {'n_is_nc': '', 'n_is_sth': ''},
 'chessman': {'n_is_nc': '', 'n_is_sth': '0'},
 'chesterfield': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'chestnut': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'chevalier': {'n_is_nc': '', 'n_is_sb': '0'},
 'chevron': {'n_is_nc': '', 'n_is_sth': ''},
 'chew': {'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'v_on': '', 'v_at': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'chic': {'n_is_nc': '', 'n_is_sth': ''},
 'chicanery': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'chick': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'nc_typical': ''},
 'chickadee': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'chieftain': {'n_is_nc': '', 'n_is_sb': '0'},
 'chigger': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'chignon': {'n_is_nc': '', 'n_is_sth': ''},
 'chill': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'chiller': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'chilli': {'n_is_nc': '', 'n_is_sth': ''},
 'chime': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'chimera': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'chimp': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'chimpanzee': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'chinaberry': {'n_is_nc': '', 'n_is_sth': ''},
 'chinchilla': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'chine': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'chink': {'n_is_nc': '', 'vbd_eq_vbn': '', 'n_is_sth': '0'},
 'chip': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'chipping': {'n_is_nc': '', 'n_is_sth': ''},
 'chirp': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'chisel': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'chit': {'n_is_nc': '', 'n_is_sth': ''},
 'chivalry': {'n_is_nc': '', 'n_is_sth': ''},
 'chive': {'n_is_nc': '', 'n_is_sth': ''},
 'chloramphenicol': {'n_is_nc': '', 'n_is_sth': ''},
 'chloride': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'chloroplast': {'n_is_nc': '', 'n_is_sth': ''},
 'chock': {'n_is_nc': '', 'n_is_sth': ''},
 'choir': {'n_is_nc': '', 'n_is_sth': ''},
 'choke': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'choker': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'chop': {'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'vb_to_vbz': 'chops', 'vb_to_vbd': 'choopped', 'vb_to_vbn': 'choopped', 'vb_to_vbg': 'chopping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'chophouse': {'n_is_nc': '', 'n_is_sth': ''},
 'chopper': {'n_is_nc': '', 'n_is_sth': ''},
 'chopstick': {'n_is_nc': '', 'n_is_sth': ''},
 'chorale': {'n_is_nc': '', 'n_is_sth': ''},
 'chord': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'chore': {'n_is_nc': '', 'n_is_sth': ''},
 'chortle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'chow': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'christ': {'n_is_nc': '', 'n_is_sb': '0'},
 'christian': {'n_is_nc': '', 'n_is_sb': '0', 'cap_word': 'Christian'},
 'christmas': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'chromosome': {'n_is_nc': '', 'n_is_sth': ''},
 'chronograph': {'n_is_nc': '', 'n_is_sth': ''},
 'chronology': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'chronometer': {'n_is_nc': '', 'n_is_sth': ''},
 'chrysalis': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'chuck': {'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_of': '', 'vb_to_vbz': 'chucks', 'vb_to_vbd': 'chucked', 'vb_to_vbn': 'chucked', 'vb_to_vbg': 'chucking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'chum': {'n_is_nc': '', 'n_is_sb': '0'},
 'chump': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'chunk': {'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'chunnel': {'n_is_nc': '', 'n_is_sth': ''},
 'churchman': {'n_is_nc': '', 'n_is_sb': '0'},
 'churchyard': {'n_is_nc': '', 'n_is_sth': ''},
 'churl': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'churn': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'chute': {'n_is_nc': '', 'n_is_sth': ''},
 'cicada': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'cicerone': {'n_is_nc': '', 'n_is_sb': '0'},
 'cigarillo': {'n_is_nc': '', 'n_is_sth': ''},
 'cinch': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'cinder': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'cineraria': {'n_is_nc': '', 'n_is_sth': ''},
 'cinque': {'n_is_nc': '', 'n_is_sth': ''},
 'cipher': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'circe': {'n_is_nc': '', 'n_is_sb': '0'},
 'circumcision': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'circumference': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'circumlocution': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'circumnavigation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'cirque': {'n_is_nc': '', 'n_is_sth': ''},
 'cistern': {'n_is_nc': '', 'n_is_sth': ''},
 'citadel': {'n_is_nc': '', 'n_is_sth': ''},
 'citation': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'cite'},
 'citron': {'n_is_nc': '', 'n_is_sth': ''},
 'citrus': {'n_is_nc': '', 'n_is_sth': ''},
 'cityscape': {'n_is_nc': '', 'n_is_sth': ''},
 'civilisation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'civilize', 'nn_to_jj': 'civilized'},
 'civilization': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'cladding': {'n_is_nc': '', 'n_is_sth': ''},
 'claimant': {'n_is_nc': '', 'n_is_sb': '0'},
 'clairvoyant': {'n_is_nc': '', 'n_is_sb': '0'},
 'clam': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'clamp': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'clampdown': {'n_is_nc': '', 'n_is_sth': ''},
 'clamshell': {'n_is_nc': '', 'n_is_sth': ''},
 'clan': {'n_is_nc': '', 'n_is_sth': ''},
 'clang': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'clank': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'clapboard': {'n_is_nc': '', 'n_is_sth': ''},
 'clapper': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'clappers': {'n_is_nc': '', 'n_is_sth': ''},
 'claret': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'clarification': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'clarify', 'nn_to_jj': 'clarified'},
 'clarinet': {'n_is_nc': '', 'n_is_sth': ''},
 'clarion': {'n_is_nc': '', 'n_is_sth': ''},
 'clasp': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'classical': {'n_is_nc': '', 'n_is_sth': ''},
 'classification': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'classmate': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'clause': {'n_is_nc': '', 'n_is_sth': ''},
 'clavicle': {'n_is_nc': '', 'n_is_sth': ''},
 'clavier': {'n_is_nc': '', 'n_is_sth': ''},
 'claw': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'claymore': {'n_is_nc': '', 'n_is_sth': ''},
 'cleanser': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'clearance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'clearing': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'clear', 'vbg_to_vbn': 'cleared'},
 'cleat': {'n_is_nc': '', 'n_is_sth': ''},
 'cleaver': {'n_is_nc': '', 'n_is_sth': ''},
 'clef': {'n_is_nc': '', 'n_is_sth': ''},
 'cleft': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'clerestory': {'n_is_nc': '', 'n_is_sth': ''},
 'clergy': {'n_is_nc': '', 'n_is_sb': '0'},
 'clergyman': {'n_is_nc': '', 'n_is_sb': '0'},
 'cleric': {'n_is_nc': '', 'n_is_sb': '0'},
 'clerkship': {'n_is_nc': '', 'n_is_sb': '0', 'n_is_sth': ''},
 'cliche': {'n_is_nc': '', 'n_is_sth': ''},
 'climax': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'clime': {'n_is_nc': '', 'n_is_sth': ''},
 'clinch': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'clincher': {'n_is_nc': '', 'n_is_sth': ''},
 'cline': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'clink': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'clinker': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'clip': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'clipboard': {'n_is_nc': '', 'n_is_sth': ''},
 'clipper': {'n_is_nc': '', 'n_is_sth': ''},
 'clipping': {'n_is_nc': '', 'n_is_sth': ''},
 'clique': {'n_is_nc': '', 'n_is_sth': ''},
 'clitoris': {'n_is_nc': '', 'n_is_sth': ''},
 'cloaca': {'n_is_nc': '', 'n_is_sth': ''},
 'cloak': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'cloakroom': {'n_is_nc': '', 'n_is_sth': ''},
 'cloche': {'n_is_nc': '', 'n_is_sth': ''},
 'clod': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'clog': {'n_is_nc': '', 'n_is_sth': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'cloister': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'closure': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'clot': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'clothes': {'n_is_nc': '', 'n_is_sth': ''},
 'clothespin': {'n_is_nc': '', 'n_is_sth': ''},
 'clothier': {'n_is_nc': '', 'n_is_sb': '0'},
 'cloudburst': {'n_is_nc': '', 'n_is_sth': ''},
 'clout': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'clown': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'cluck': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'clump': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cluster': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'clutch': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'co-ed': {'n_is_nc': '', 'n_is_sb': '0', 'jj_ed': ''},
 'co-op': {'n_is_nc': '', 'n_is_sth': ''},
 'co-pilot': {'n_is_nc': '', 'n_is_sb': '0'},
 'co-star': {'n_is_nc': '', 'n_is_sb': '0'},
 'co-worker': {'n_is_nc': '', 'n_is_sb': '0'},
 'coachman': {'n_is_nc': '', 'n_is_sb': '0'},
 'coadjutor': {'n_is_nc': '', 'n_is_sb': '0'},
 'coalition': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'coaster': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'coastline': {'n_is_nc': '', 'n_is_sth': ''},
 'coating': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'coat', 'vbg_to_vbn': 'coated'},
 'coattail': {'n_is_nc': '', 'n_is_sth': ''},
 'coauthor': {'n_is_nc': '', 'n_is_sb': '0'},
 'cob': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'cobble': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'cobbler': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'cobblestone': {'n_is_nc': '', 'n_is_sth': ''},
 'cobra': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'cobweb': {'n_is_nc': '', 'n_is_sth': ''},
 'cochlea': {'n_is_nc': '', 'n_is_sth': ''},
 'cock': {'n_is_nc': '', 'n_is_sb': '3', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'n_is_sth': '3'},
 'cockfight': {'n_is_nc': '', 'n_is_sth': ''},
 'cockpit': {'n_is_nc': '', 'n_is_sth': ''},
 'cockroach': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'cockscomb': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'cocktail': {'n_is_nc': '', 'n_is_sth': ''},
 'coco': {'n_is_nc': '', 'n_is_sth': ''},
 'coconut': {'n_is_nc': '', 'n_is_sth': ''},
 'cocoon': {'n_is_nc': '', 'n_is_sth': ''},
 'cod': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'nn_eq_nns': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'coda': {'n_is_nc': '', 'n_is_sth': ''},
 'coder': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'codex': {'n_is_nc': '', 'n_is_sth': ''},
 'codfish': {'n_is_nc': '', 'n_is_sb': '0'},
 'codger': {'n_is_nc': '', 'n_is_sb': '0'},
 'codicil': {'n_is_nc': '', 'n_is_sth': ''},
 'coefficient': {'n_is_nc': '', 'n_is_sth': ''},
 'coffee': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'coffeehouse': {'n_is_nc': '', 'n_is_sth': ''},
 'coffer': {'n_is_nc': '', 'n_is_sth': ''},
 'cofferdam': {'n_is_nc': '', 'n_is_sth': ''},
 'coffin': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cohort': {'n_is_nc': '', 'n_is_sth': ''},
 'coif': {'n_is_nc': '', 'n_is_sth': ''},
 'coiffure': {'n_is_nc': '', 'n_is_sth': ''},
 'coinage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'coincidence': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'col': {'n_is_nc': '', 'n_is_sth': ''},
 'colander': {'n_is_nc': '', 'n_is_sth': ''},
 'cole': {'n_is_nc': '', 'n_is_sth': ''},
 'coliseum': {'n_is_nc': '', 'n_is_sth': ''},
 'collaboration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'collaborationist': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'collaborator': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'collage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'collarbone': {'n_is_nc': '', 'n_is_sth': ''},
 'collection': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'collect', 'nn_to_jj': 'collective'},
 'collector': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'colleen': {'n_is_nc': '', 'n_is_sb': '0'},
 'collider': {'n_is_nc': '', 'n_is_sth': ''},
 'collier': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'colliery': {'n_is_nc': '', 'n_is_sth': ''},
 'collision': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'colloquialism': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'colloquium': {'n_is_nc': '', 'n_is_sth': ''},
 'colloquy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'collusion': {'n_is_nc': '', 'n_is_sth': ''},
 'colon': {'n_is_nc': '', 'n_is_sth': ''},
 'colonel': {'n_is_nc': '', 'n_is_sb': '0'},
 'coloratura': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'colossus': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'colour': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'colorful', 'v_n': '', 'v_n_jj': '', 'vb_to_vbz': 'colours', 'vb_to_vbd': 'coloured', 'vb_to_vbn': 'coloured', 'vb_to_jj': 'colorful', 'vb_to_vbg': 'colouring', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'colours': {'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'colour'},
 'colt': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'colter': {'n_is_nc': '', 'n_is_sth': ''},
 'coma': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'combatant': {'n_is_nc': '', 'n_is_sb': '0'},
 'combination': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'combine', 'nn_to_jj': 'combined'},
 'come-on': {'n_is_nc': '', 'n_is_sth': ''},
 'comedian': {'n_is_nc': '', 'n_is_sb': '0'},
 'comedown': {'n_is_nc': '', 'n_is_sth': ''},
 'comet': {'n_is_nc': '', 'n_is_sth': ''},
 'comeuppance': {'n_is_nc': '', 'n_is_sth': ''},
 'comforter': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'comity': {'n_is_nc': '', 'n_is_sth': ''},
 'comma': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nc_typical': ''},
 'commandant': {'n_is_nc': '', 'n_is_sb': '0'},
 'commandment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'commemorative': {'n_is_nc': '', 'n_is_sth': ''},
 'commencement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'commence'},
 'commendation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'commentator': {'n_is_nc': '', 'n_is_sb': '0'},
 'commie': {'n_is_nc': '', 'n_is_sb': '0'},
 'commissar': {'n_is_nc': '', 'n_is_sb': '0'},
 'commissary': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'commissioner': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'commitment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'commit', 'nn_to_jj': 'committed'},
 'committeeman': {'n_is_nc': '', 'n_is_sb': '0'},
 'commode': {'n_is_nc': '', 'n_is_sth': ''},
 'commoner': {'n_is_nc': '', 'n_is_sb': '0'},
 'commonplace': {'n_is_nc': '', 'n_is_sth': ''},
 'commons': {'n_is_nc': '', 'n_is_sb': '0'},
 'commotion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'commune': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'communicator': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'communion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'communique': {'n_is_nc': '', 'n_is_sth': ''},
 'commutation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'compact': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'compaction': {'n_is_nc': '', 'n_is_sth': ''},
 'compartment': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'compatriot': {'n_is_nc': '', 'n_is_sb': '0'},
 'compendium': {'n_is_nc': '', 'n_is_sth': ''},
 'competency': {'n_is_nc': '', 'n_is_sth': ''},
 'compilation': {'n_is_nc': '', 'n_is_nu': '', 'nn_to_vb': 'compile', 'nn_to_jj': 'compiled'},
 'compiler': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'complainant': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'complement': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'complementary', 'vb_to_jj': 'complementary', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'complexion': {'n_is_nc': '', 'n_is_sth': ''},
 'complexity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'complex', 'nn_to_rb': 'complexly'},
 'complication': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'complicate', 'nn_to_jj': 'complicated'},
 'compliment': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'compost': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'compote': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'compress': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'compression': {'n_is_nc': '', 'n_is_sth': ''},
 'compressor': {'n_is_nc': '', 'n_is_sth': '0'},
 'compromise': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'comptroller': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'compulsion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'computation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'compute', 'nn_to_jj': 'computational'},
 'concatenation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'conception': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'conceive', 'nn_to_jj': 'conceivable'},
 'concession': {'n_is_nc': '', 'n_is_sth': ''},
 'conch': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'concha': {'n_is_nc': '', 'n_is_sth': ''},
 'concierge': {'n_is_nc': '', 'n_is_sb': '0'},
 'concoction': {'n_is_nc': '', 'n_is_sth': ''},
 'concordance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'concordat': {'n_is_nc': '', 'n_is_sth': ''},
 'concourse': {'n_is_nc': '', 'n_is_sth': ''},
 'concubine': {'n_is_nc': '', 'n_is_sb': '0'},
 'concurrence': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'concussion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'condemnation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'condensate': {'n_is_nc': '', 'n_is_sth': ''},
 'condensation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'condenser': {'n_is_nc': '', 'n_is_sth': ''},
 'conditioner': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'condolence': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'condom': {'n_is_nc': '', 'n_is_sth': ''},
 'condominium': {'n_is_nc': '', 'n_is_sth': ''},
 'condor': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'conduct': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'conductive', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'conducts', 'vb_to_vbd': 'conducted', 'vb_to_vbn': 'conducted', 'vb_to_jj': 'conductive', 'vb_to_vbg': 'conducting', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'conduit': {'n_is_nc': '', 'n_is_sth': ''},
 'coney': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '3', 'n_is_sth': ''},
 'confabulation': {'n_is_nc': '', 'n_is_sth': ''},
 'confection': {'n_is_nc': '', 'n_is_sth': ''},
 'confederacy': {'n_is_nc': '', 'n_is_sth': ''},
 'confederate': {'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'confederation': {'n_is_nc': '', 'n_is_sth': ''},
 'confession': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'confess', 'nn_to_jj': 'confessed'},
 'confidant': {'n_is_nc': '', 'n_is_sb': '0'},
 'confidence': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'confident', 'nn_to_rb': 'confidently'},
 'configuration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'confiscation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'conflagration': {'n_is_nc': '', 'n_is_sth': ''},
 'confluence': {'n_is_nc': '', 'n_is_sth': ''},
 'conformation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'conform', 'nn_to_jj': 'conform'},
 'conger': {'n_is_nc': '', 'n_is_sb': '0'},
 'conglomerate': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'conglomeration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'congratulations': {'n_is_nc': '', 'n_is_sth': ''},
 'congregation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'congruity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'conifer': {'n_is_nc': '', 'n_is_sth': ''},
 'conjecture': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'conjunction': {'n_is_nc': '', 'n_is_sth': ''},
 'conjurer': {'n_is_nc': '', 'n_is_sb': '0'},
 'conjuror': {'n_is_nc': '', 'n_is_sb': '0'},
 'connection': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_vb': 'connect', 'nn_to_jj': 'connected'},
 'connector': {'n_is_nc': '', 'n_is_sth': ''},
 'conniption': {'n_is_nc': '', 'n_is_sth': ''},
 'connoisseur': {'n_is_nc': '', 'n_is_sb': '0'},
 'connotation': {'n_is_nc': '', 'n_is_sth': ''},
 'conqueror': {'n_is_nc': '', 'n_is_sb': '0'},
 'conquest': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'conquer'},
 'conscience': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'conscientious', 'nn_to_rb': 'conscientiously'},
 'consensus': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'consent', 'nn_to_jj': 'consenting'},
 'conservator': {'n_is_nc': '', 'n_is_sb': '0'},
 'conservatory': {'n_is_nc': '', 'n_is_sth': ''},
 'conserve': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'consistency': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'consist', 'nn_to_jj': 'consistent'},
 'consistory': {'n_is_nc': '', 'n_is_sth': ''},
 'console': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'consonant': {'n_is_nc': '', 'n_is_sth': ''},
 'consort': {'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'conspirator': {'n_is_nc': '', 'n_is_sb': '0'},
 'constable': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'constabulary': {'n_is_nc': '', 'n_is_sb': '0'},
 'constellation': {'n_is_nc': '', 'n_is_sth': ''},
 'constituency': {'n_is_nc': '', 'n_is_sth': ''},
 'constituent': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'constitution': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'constitute', 'nn_to_jj': 'constitutive'},
 'constitutionalist': {'n_is_nc': '', 'n_is_sb': '0'},
 'constraint': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'constrain', 'nn_to_jj': 'constrained'},
 'constriction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'constrictor': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'construction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'construct', 'nn_to_jj': 'constructive'},
 'constructor': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'consul': {'n_is_nc': '', 'n_is_sb': '0'},
 'consulate': {'n_is_nc': '', 'n_is_sth': ''},
 'consultation': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'consult', 'nn_to_jj': 'consultative'},
 'contact': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'contactable', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'contacts', 'vb_to_vbd': 'contacted', 'vb_to_vbn': 'contacted', 'vb_to_jj': 'contactable', 'vb_to_vbg': 'contacting', 'vt_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'contagion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'contaminant': {'n_is_nc': '', 'n_is_sth': ''},
 'contents': {'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'content'},
 'contestant': {'n_is_nc': '', 'n_is_sb': '0'},
 'contingency': {'n_is_nc': '', 'n_is_sth': ''},
 'contingent': {'n_is_nc': '', 'n_is_sth': ''},
 'continuance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'continuation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'continuum': {'n_is_nc': '', 'n_is_sth': ''},
 'contortion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'contour': {'n_is_nc': '', 'n_is_sth': ''},
 'contraceptive': {'n_is_nc': '', 'n_is_sth': ''},
 'contraction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'contradiction': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'contradict', 'nn_to_jj': 'contradictory'},
 'contradistinction': {'n_is_nc': '', 'n_is_sth': ''},
 'contralto': {'n_is_nc': '', 'n_is_sb': '0'},
 'contravention': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'contrivance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'controller': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'contusion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'conundrum': {'n_is_nc': '', 'n_is_sth': ''},
 'convener': {'n_is_nc': '', 'n_is_sb': '0'},
 'convent': {'n_is_nc': '', 'n_is_sth': ''},
 'convention': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'convene', 'nn_to_jj': 'conventional'},
 'conventioneer': {'n_is_nc': '', 'n_is_sb': '0'},
 'converter': {'n_is_nc': '', 'n_is_sth': ''},
 'convertor': {'n_is_nc': '', 'n_is_sth': ''},
 'convexity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'conveyance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'conveyor': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'convict': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'convolution': {'n_is_nc': '', 'n_is_sth': ''},
 'convoy': {'n_is_nc': '', 'n_is_sth': ''},
 'convulsion': {'n_is_nc': '', 'n_is_sth': ''},
 'coo': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cookbook': {'n_is_nc': '', 'n_is_sth': ''},
 'cookhouse': {'n_is_nc': '', 'n_is_sth': ''},
 'coolant': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'cooler': {'n_is_nc': '', 'n_is_sth': ''},
 'coolie': {'n_is_nc': '', 'n_is_sb': '0'},
 'coon': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'coop': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'coot': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'cootie': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'copier': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'coping': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'cope', 'vbg_to_vbn': 'coped'},
 'coppersmith': {'n_is_nc': '', 'n_is_sb': '0'},
 'copse': {'n_is_nc': '', 'n_is_sth': ''},
 'copyist': {'n_is_nc': '', 'n_is_sb': '0'},
 'copyright': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'coquetry': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'coquette': {'n_is_nc': '', 'n_is_sb': '0'},
 'coral': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'n_is_nu': ''},
 'cord': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cordon': {'n_is_nc': '', 'n_is_sth': ''},
 'corgi': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'cork': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'corked', 'vb_to_jj': 'corked', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'corker': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'corm': {'n_is_nc': '', 'n_is_sth': ''},
 'cormorant': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'corncob': {'n_is_nc': '', 'n_is_sth': ''},
 'cornea': {'n_is_nc': '', 'n_is_sth': ''},
 'cornel': {'n_is_nc': '', 'n_is_sth': ''},
 'cornerstone': {'n_is_nc': '', 'n_is_sth': ''},
 'cornet': {'n_is_nc': '', 'n_is_sth': ''},
 'cornfield': {'n_is_nc': '', 'n_is_sth': ''},
 'cornflower': {'n_is_nc': '', 'n_is_sth': ''},
 'cornice': {'n_is_nc': '', 'n_is_sth': ''},
 'cornstalk': {'n_is_nc': '', 'n_is_sth': ''},
 'cornu': {'n_is_nc': '', 'n_is_sth': ''},
 'cornucopia': {'n_is_nc': '', 'n_is_sth': ''},
 'corolla': {'n_is_nc': '', 'n_is_sth': ''},
 'corollary': {'n_is_nc': '', 'n_is_sth': ''},
 'corona': {'n_is_nc': '', 'n_is_sth': ''},
 'coronation': {'n_is_nc': '', 'n_is_sth': ''},
 'coronet': {'n_is_nc': '', 'n_is_sth': ''},
 'corporal': {'n_is_nc': '', 'n_is_sb': '0'},
 'corps': {'n_is_nc': '', 'n_is_sth': '', 'nn_eq_nns': ''},
 'corpse': {'n_is_nc': '', 'n_is_sth': ''},
 'corral': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'correction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'correct', 'nn_to_jj': 'correct'},
 'correlation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'correlative': {'n_is_nc': '', 'n_is_sth': ''},
 'corrida': {'n_is_nc': '', 'n_is_sth': '0'},
 'corrosive': {'n_is_nc': '', 'n_is_sth': ''},
 'corruption': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'corsage': {'n_is_nc': '', 'n_is_sth': ''},
 'corsair': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'corselet': {'n_is_nc': '', 'n_is_sth': ''},
 'cortege': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'cortex': {'n_is_nc': '', 'n_is_sth': ''},
 'cosmetic': {'n_is_nc': '', 'n_is_sth': ''},
 'cosmonaut': {'n_is_nc': '', 'n_is_sb': '0'},
 'cossack': {'n_is_nc': '', 'n_is_sb': '0', 'n_is_sth': ''},
 'cost': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'costly', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'v_at': '', 'vb_to_vbz': 'costs', 'vb_to_jj': 'costly', 'vb_to_vbg': 'costing', 'vbn_to_vbg': 'costing', 'v_compcl_non': ''},
 'costa': {'n_is_nc': '', 'n_is_sth': ''},
 'costs': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbz_to_vb': 'cost'},
 'costume': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'cot': {'n_is_nc': '', 'n_is_sth': ''},
 'cote': {'n_is_nc': '', 'n_is_sth': ''},
 'coterie': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'cotter': {'n_is_nc': '', 'n_is_sb': '0'},
 'cottier': {'n_is_nc': '', 'n_is_sb': '0'},
 'couch': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'cougar': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'cough': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'coulter': {'n_is_nc': '', 'n_is_sth': ''},
 'councillor': {'n_is_nc': '', 'n_is_sb': '0'},
 'councilman': {'n_is_nc': '', 'n_is_sb': '0'},
 'counsel': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0', 'vbd_eq_vbn': ''},
 'counsellor': {'n_is_nc': '', 'n_is_sb': '0'},
 'counselor': {'n_is_nc': '', 'n_is_sb': '0'},
 'countdown': {'n_is_nc': '', 'n_is_sth': ''},
 'counterargument': {'n_is_nc': '', 'n_is_sth': ''},
 'counterattack': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'counterbalance': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'countercharge': {'n_is_nc': '', 'n_is_sth': ''},
 'counterclaim': {'n_is_nc': '', 'n_is_sth': ''},
 'counterfeit': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'countermeasure': {'n_is_nc': '', 'n_is_sth': ''},
 'countermove': {'n_is_nc': '', 'n_is_sth': ''},
 'counteroffensive': {'n_is_nc': '', 'n_is_sth': ''},
 'counterpane': {'n_is_nc': '', 'n_is_sth': ''},
 'counterpart': {'n_is_nc': '', 'n_is_sth': ''},
 'counterpoint': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'counterrevolutionary': {'n_is_nc': '', 'n_is_sb': '0'},
 'countryman': {'n_is_nc': '', 'n_is_sb': '0'},
 'coupler': {'n_is_nc': '', 'n_is_sth': '0'},
 'couplet': {'n_is_nc': '', 'n_is_sth': ''},
 'coupling': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'couple', 'vbg_to_vbn': 'coupled'},
 'coupon': {'n_is_nc': '', 'n_is_sth': ''},
 'courier': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'court-martial': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'courtesan': {'n_is_nc': '', 'n_is_sb': '0'},
 'courtesy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'courtyard': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'cove': {'n_is_nc': '', 'n_is_sth': ''},
 'coven': {'n_is_nc': '', 'n_is_sth': ''},
 'covenant': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cover-up': {'n_is_nc': '', 'n_is_sth': ''},
 'coverall': {'n_is_nc': '', 'n_is_sth': ''},
 'coverlet': {'n_is_nc': '', 'n_is_sth': ''},
 'cowboy': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'cowherd': {'n_is_nc': '', 'n_is_sb': '0'},
 'cowhide': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'cowl': {'n_is_nc': '', 'n_is_sth': ''},
 'cowling': {'n_is_nc': '', 'n_is_sth': ''},
 'cowpuncher': {'n_is_nc': '', 'n_is_sb': '0'},
 'cowrie': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'cowshed': {'n_is_nc': '', 'n_is_sth': ''},
 'coxswain': {'n_is_nc': '', 'n_is_sb': '0'},
 'coyote': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'coziness': {'n_is_nc': '', 'n_is_sth': '0'},
 'crab': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'crabapple': {'n_is_nc': '', 'n_is_sth': ''},
 'crack-up': {'n_is_nc': '', 'n_is_sth': ''},
 'crackdown': {'n_is_nc': '', 'n_is_sth': ''},
 'cracker': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'crackle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'crackpot': {'n_is_nc': '', 'n_is_sb': '0'},
 'cradle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'crag': {'n_is_nc': '', 'n_is_sth': ''},
 'cramp': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'crane': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'cranium': {'n_is_nc': '', 'n_is_sth': ''},
 'crank': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': ''},
 'crankshaft': {'n_is_nc': '', 'n_is_sth': ''},
 'cranny': {'n_is_nc': '', 'n_is_sth': ''},
 'crasher': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'crate': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'crater': {'n_is_nc': '', 'n_is_sth': ''},
 'cravat': {'n_is_nc': '', 'n_is_sth': ''},
 'craving': {'n_is_nc': '', 'n_is_sth': ''},
 'craw': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'crawfish': {'n_is_nc': '', 'n_is_sb': '3', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_sth': '3'},
 'crawl': {'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'crawler': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'crayfish': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'crayon': {'n_is_nc': '', 'n_is_sth': ''},
 'craze': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'crease': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'credential': {'n_is_nc': '', 'n_is_sth': ''},
 'credentials': {'n_is_nc': '', 'n_is_sth': ''},
 'creditor': {'n_is_nc': '', 'n_is_sb': '0'},
 'credo': {'n_is_nc': '', 'n_is_sth': ''},
 'creed': {'n_is_nc': '', 'n_is_sth': ''},
 'creek': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'creep': {'n_is_nc': '', 'n_is_sb': '2', 'nn_to_jj': 'creeping', 'vb_to_jj': 'creeping', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'creeper': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'cremains': {'n_is_nc': '', 'n_is_sth': ''},
 'crematory': {'n_is_nc': '', 'n_is_sth': ''},
 'crepe': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'crescent': {'n_is_nc': '', 'n_is_sth': ''},
 'crest': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'crevasse': {'n_is_nc': '', 'n_is_sth': ''},
 'crevice': {'n_is_nc': '', 'n_is_sth': ''},
 'crewman': {'n_is_nc': '', 'n_is_sb': '0'},
 'crib': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cricket': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'crier': {'n_is_nc': '', 'n_is_sb': '0'},
 'criminality': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'crimp': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'crinkle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cripple': {'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_infcl_non': '', 'n_is_sth': '2'},
 'crisscross': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'criticism': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'critique': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'croak': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'croaker': {'n_is_nc': '', 'n_is_sb': '0'},
 'crock': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'crocodile': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'crocus': {'n_is_nc': '', 'n_is_sth': ''},
 'croft': {'n_is_nc': '', 'n_is_sth': ''},
 'crone': {'n_is_nc': '', 'n_is_sb': '0'},
 'crony': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'crook': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cropper': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'cross-examination': {'n_is_nc': '', 'n_is_sth': ''},
 'crossbar': {'n_is_nc': '', 'n_is_sth': ''},
 'crossbeam': {'n_is_nc': '', 'n_is_sth': ''},
 'crossbow': {'n_is_nc': '', 'n_is_sth': ''},
 'crossbreed': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'crosscurrent': {'n_is_nc': '', 'n_is_sth': ''},
 'crosscut': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'crossing': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'cross', 'vbg_to_vbn': 'crossed'},
 'crossover': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'crosspiece': {'n_is_nc': '', 'n_is_sth': ''},
 'crossroad': {'n_is_nc': '', 'n_is_sth': ''},
 'crossroads': {'n_is_nc': '', 'n_is_sth': '', 'nn_eq_nns': ''},
 'crosswalk': {'n_is_nc': '', 'n_is_sth': ''},
 'crotch': {'n_is_nc': '', 'n_is_sth': ''},
 'croton': {'n_is_nc': '', 'n_is_sth': ''},
 'crouch': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'crow': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'crowbar': {'n_is_nc': '', 'n_is_sth': ''},
 'crozier': {'n_is_nc': '', 'n_is_sth': ''},
 'crucible': {'n_is_nc': '', 'n_is_sth': ''},
 'crucifix': {'n_is_nc': '', 'n_is_sth': ''},
 'crucifixion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'crudity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'cruelty': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'cruel', 'nn_to_rb': 'cruelly'},
 'cruiser': {'n_is_nc': '', 'n_is_sth': ''},
 'crumb': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'crunch': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'crus': {'n_is_nc': '', 'n_is_sth': ''},
 'crusade': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'cruse': {'n_is_nc': '', 'n_is_sth': ''},
 'crush': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'crushed', 'vb_to_jj': 'crushed', 'v_prprtcl_non': ''},
 'crusher': {'n_is_nc': '', 'n_is_sth': ''},
 'crust': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'crustacean': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'crutch': {'n_is_nc': '', 'n_is_sth': ''},
 'crux': {'n_is_nc': '', 'n_is_sth': ''},
 'crypt': {'n_is_nc': '', 'n_is_sth': ''},
 'cryptogram': {'n_is_nc': '', 'n_is_sth': ''},
 'cryptographer': {'n_is_nc': '', 'n_is_sb': '0'},
 'cryptomeria': {'n_is_nc': '', 'n_is_sth': ''},
 'crystal': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'crystallization': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'cub': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'cube': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'cubicle': {'n_is_nc': '', 'n_is_sth': ''},
 'cuckold': {'n_is_nc': '', 'n_is_sb': '0'},
 'cuckoo': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'cucumber': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'cuddle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'cuddy': {'n_is_nc': '', 'n_is_sth': ''},
 'cudgel': {'n_is_nc': '', 'n_is_sth': ''},
 'cue': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'cuff': {'n_is_nc': '', 'n_is_sth': ''},
 'culex': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'cull': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'culprit': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'culturati': {'n_is_nc': '', 'n_is_sth': ''},
 'culture': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'cultural', 'vb_to_jj': 'cultural', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'culvert': {'n_is_nc': '', 'n_is_sth': ''},
 'cummerbund': {'n_is_nc': '', 'n_is_sth': ''},
 'cumulus': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'cupola': {'n_is_nc': '', 'n_is_sth': ''},
 'cur': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'curative': {'n_is_nc': '', 'n_is_sth': ''},
 'curbside': {'n_is_nc': '', 'n_is_sth': ''},
 'curfew': {'n_is_nc': '', 'n_is_sth': ''},
 'curie': {'n_is_nc': '', 'n_is_sb': '0', 'n_is_sth': ''},
 'curio': {'n_is_nc': '', 'n_is_sth': ''},
 'curiosity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'curious', 'nn_to_rb': 'curiously'},
 'curl': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'curly', 'vb_to_jj': 'curly', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'curler': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'curlicue': {'n_is_nc': '', 'n_is_sth': ''},
 'curry': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'curse': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'cursed', 'vb_to_jj': 'cursed', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'cursive': {'n_is_nc': '', 'n_is_sth': ''},
 'cursor': {'n_is_nc': '', 'n_is_sth': ''},
 'curtailment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'cusp': {'n_is_nc': '', 'n_is_sth': ''},
 'cuss': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'custard': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'custodian': {'n_is_nc': '', 'n_is_sb': '0'},
 'cutback': {'n_is_nc': '', 'n_is_sth': ''},
 'cuticle': {'n_is_nc': '', 'n_is_sth': ''},
 'cutlass': {'n_is_nc': '', 'n_is_sth': ''},
 'cutlet': {'n_is_nc': '', 'n_is_sth': ''},
 'cutoff': {'n_is_nc': '', 'n_is_sth': ''},
 'cutout': {'n_is_nc': '', 'n_is_sth': ''},
 'cutter': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'cutthroat': {'n_is_nc': '', 'n_is_sb': '0'},
 'cuttlefish': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'cyclamen': {'n_is_nc': '', 'n_is_sth': ''},
 'cyclone': {'n_is_nc': '', 'n_is_sth': ''},
 'cylinder': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'cypher': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'cypress': {'n_is_nc': '', 'n_is_sth': ''},
 'cyst': {'n_is_nc': '', 'n_is_sth': ''},
 'czar': {'n_is_nc': '', 'n_is_sb': '0'},
 'dab': {'n_is_nc': '', 'n_is_sb': '3', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'n_is_sth': '3'},
 'dabbler': {'n_is_nc': '', 'n_is_sb': '0'},
 'dace': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'dada': {'n_is_nc': '', 'n_is_sb': '0'},
 'daddy': {'n_is_nc': '', 'n_is_sb': '0'},
 'dado': {'n_is_nc': '', 'n_is_sth': ''},
 'dagger': {'n_is_nc': '', 'n_is_sth': ''},
 'dah': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'dahlia': {'n_is_nc': '', 'n_is_sth': ''},
 'daintiness': {'n_is_nc': '', 'n_is_sth': ''},
 'dainty': {'n_is_nc': '', 'n_is_sth': ''},
 'dairy': {'n_is_nc': '', 'n_is_sth': ''},
 'dais': {'n_is_nc': '', 'n_is_sth': ''},
 'daisy': {'n_is_nc': '', 'n_is_sth': ''},
 'dale': {'n_is_nc': '', 'n_is_sth': ''},
 'dalliance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'dam': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'damages': {'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'damage'},
 'dame': {'n_is_nc': '', 'n_is_sb': '0'},
 'damn': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'dirtyword': ''},
 'damper': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'damsel': {'n_is_nc': '', 'n_is_sb': '0'},
 'dancing': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'dance', 'vbg_to_vbn': 'danced'},
 'dandelion': {'n_is_nc': '', 'n_is_sth': ''},
 'dandy': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'danger': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'dangerous', 'nn_to_rb': 'dangerously'},
 'dare': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'daring', 'v_to_vb': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'dares', 'vb_to_vbd': 'dared', 'vb_to_vbn': 'dared', 'vb_to_jj': 'daring', 'vb_to_vbg': 'daring', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'daredevil': {'n_is_nc': '', 'n_is_sb': '0'},
 'darkroom': {'n_is_nc': '', 'n_is_sth': ''},
 'dart': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'darts': {'n_is_nc': '', 'n_is_sth': ''},
 'dash': {'n_is_nc': '', 'n_is_sth': '', 'v_prprtcl_non': ''},
 'dashboard': {'n_is_nc': '', 'n_is_sth': ''},
 'daub': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'dauber': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'daughter-in-law': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'davenport': {'n_is_nc': '', 'n_is_sth': ''},
 'daybook': {'n_is_nc': '', 'n_is_sth': ''},
 'daydream': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'daydreamer': {'n_is_nc': '', 'n_is_sb': '0'},
 'daystar': {'n_is_nc': '', 'n_is_sth': ''},
 'daze': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'deacon': {'n_is_nc': '', 'n_is_sb': '0'},
 'deadeye': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'deadwood': {'n_is_nc': '', 'n_is_sth': ''},
 'deaf-mute': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'dealership': {'n_is_nc': '', 'n_is_sth': ''},
 'dearth': {'n_is_nc': '', 'n_is_sth': ''},
 'deathbed': {'n_is_nc': '', 'n_is_sth': ''},
 'deathtrap': {'n_is_nc': '', 'n_is_sth': ''},
 'debacle': {'n_is_nc': '', 'n_is_sth': ''},
 'debasement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'debauch': {'n_is_nc': '', 'n_is_sth': ''},
 'debenture': {'n_is_nc': '', 'n_is_sth': ''},
 'debility': {'n_is_nc': '', 'n_is_sth': ''},
 'debit': {'n_is_nc': '', 'n_is_sth': ''},
 'debt': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'debtor': {'n_is_nc': '', 'n_is_sb': '0'},
 'decadent': {'n_is_nc': '', 'n_is_sb': '0'},
 'decapitation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'decedent': {'n_is_nc': '', 'n_is_sb': '0'},
 'deceit': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'deceiver': {'n_is_nc': '', 'n_is_sb': '0'},
 'decibel': {'n_is_nc': '', 'n_is_sth': ''},
 'decimal': {'n_is_nc': '', 'n_is_sth': ''},
 'declamation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'declination': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'decline', 'nn_to_jj': 'declining'},
 'decoder': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'decor': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'decoration': {'n_is_nc': '', 'n_is_sth': ''},
 'decoy': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'decree': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'dedication': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'deduction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'deduce', 'nn_to_jj': 'deducible'},
 'deed': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'deer': {'n_is_nc': '', 'n_is_sb': '3', 'nn_eq_nns': '', 'n_is_sth': '3'},
 'deerskin': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'defeat': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'defeated', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'defeats', 'vb_to_vbd': 'defeated', 'vb_to_vbn': 'defeated', 'vb_to_jj': 'defeated', 'vb_to_vbg': 'defeating', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'defection': {'n_is_nc': '', 'n_is_sth': ''},
 'defector': {'n_is_nc': '', 'n_is_sb': '0'},
 'deficiency': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'deflector': {'n_is_nc': '', 'n_is_sth': ''},
 'deformation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'degenerate': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'degradation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'delay': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'delayed', 'v_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'delays', 'vb_to_vbd': 'delayed', 'vb_to_vbn': 'delayed', 'vb_to_jj': 'delayed', 'vb_to_vbg': 'delaying', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'delegate': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'deletion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'deliberation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'delicacy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'delicate', 'nn_to_rb': 'delicately'},
 'delicatessen': {'n_is_nc': '', 'n_is_sth': ''},
 'deliverer': {'n_is_nc': '', 'n_is_sb': '0'},
 'deliveryman': {'n_is_nc': '', 'n_is_sb': '0'},
 'delusion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'demarche': {'n_is_nc': '', 'n_is_sth': ''},
 'demerit': {'n_is_nc': '', 'n_is_sth': ''},
 'demo': {'n_is_nc': '', 'n_is_sth': ''},
 'demoiselle': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'demolition': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'demon': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'demotion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'den': {'n_is_nc': '', 'n_is_sth': ''},
 'denial': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'deny', 'nn_to_jj': 'deniable'},
 'denizen': {'n_is_nc': '', 'n_is_sb': '0'},
 'denomination': {'n_is_nc': '', 'n_is_sth': ''},
 'denominator': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'denouement': {'n_is_nc': '', 'n_is_sth': ''},
 'dent': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'dental': {'n_is_nc': '', 'n_is_sth': ''},
 'denture': {'n_is_nc': '', 'n_is_sth': ''},
 'denunciation': {'n_is_nc': '', 'n_is_sth': ''},
 'dependant': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'depiction': {'n_is_nc': '', 'n_is_sth': ''},
 'deployment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'deponent': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'deportation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'depositary': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'deposition': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'depositor': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'depository': {'n_is_nc': '', 'n_is_sth': ''},
 'depot': {'n_is_nc': '', 'n_is_sth': ''},
 'depravity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'depredation': {'n_is_nc': '', 'n_is_sth': ''},
 'depressant': {'n_is_nc': '', 'n_is_sth': ''},
 'deprivation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'derangement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'derivation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'derive', 'nn_to_jj': 'derivative'},
 'derrick': {'n_is_nc': '', 'n_is_sth': ''},
 'derriere': {'n_is_nc': '', 'n_is_sth': ''},
 'descendant': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'descendants': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'descent': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'descend', 'nn_to_jj': 'descending', 'vb_to_jj': 'descending'},
 'deserter': {'n_is_nc': '', 'n_is_sb': '0'},
 'designation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'desire': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'desirable', 'v_compcl': '', 'v_to_vb': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'desires', 'vb_to_vbd': 'desired', 'vb_to_vbn': 'desired', 'vb_to_jj': 'desirable', 'vb_to_vbg': 'desiring', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'vt_typical': '', 'n_for_n': '', 'n_to_v_n': ''},
 'desperado': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'despot': {'n_is_nc': '', 'n_is_sb': '0'},
 'dessert': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'destiny': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'destroyer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'destruction': {'n_is_nc': '', 'n_is_sth': ''},
 'detachment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'detainment': {'n_is_nc': '', 'n_is_sth': ''},
 'detector': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'detention': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'detergent': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'determinant': {'n_is_nc': '', 'n_is_sth': ''},
 'determination': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'determine', 'nn_to_jj': 'determinate'},
 'detonator': {'n_is_nc': '', 'n_is_sth': ''},
 'detour': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'deuce': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'deviation': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'deviate'},
 'deviltry': {'n_is_nc': '', 'n_is_sth': ''},
 'devotee': {'n_is_nc': '', 'n_is_sb': '0'},
 'dewdrop': {'n_is_nc': '', 'n_is_sth': ''},
 'diadem': {'n_is_nc': '', 'n_is_sth': ''},
 'diagonal': {'n_is_nc': '', 'n_is_sth': ''},
 'dial': {'n_is_nc': '', 'n_is_sth': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'dialect': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'diameter': {'n_is_nc': '', 'n_is_sth': ''},
 'diaper': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'diaphragm': {'n_is_nc': '', 'n_is_sth': ''},
 'diaspora': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'dibble': {'n_is_nc': '', 'n_is_sth': ''},
 'dice': {'n_is_nc': '', 'n_is_sth': '', 'nn_eq_nns': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'dichotomy': {'n_is_nc': '', 'n_is_sth': ''},
 'dick': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'dickey': {'n_is_nc': '', 'n_is_sth': ''},
 'dictaphone': {'n_is_nc': '', 'n_is_sth': ''},
 'dictate': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'dictation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'dictator': {'n_is_nc': '', 'n_is_sb': '0'},
 'dictatorship': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'dictum': {'n_is_nc': '', 'n_is_sth': ''},
 'dido': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'diehard': {'n_is_nc': '', 'n_is_sb': '0'},
 'diesel': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'dietary': {'n_is_nc': '', 'n_is_sth': ''},
 'differential': {'n_is_nc': '', 'n_is_sth': ''},
 'digest': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'digestion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'digger': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'diggings': {'n_is_nc': '', 'n_is_sth': ''},
 'digitalis': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'dignitary': {'n_is_nc': '', 'n_is_sb': '0'},
 'digression': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'dike': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'dilator': {'n_is_nc': '', 'n_is_sth': ''},
 'dilemma': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'dilution': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'dime': {'n_is_nc': '', 'n_is_sth': ''},
 'dimensionality': {'n_is_nc': '', 'n_is_sth': ''},
 'diminution': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'diminish', 'nn_to_jj': 'diminished'},
 'diminutive': {'n_is_nc': '', 'n_is_sth': ''},
 'dimple': {'n_is_nc': '', 'n_is_sth': ''},
 'dimwit': {'n_is_nc': '', 'n_is_sb': '0'},
 'diner': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'dinero': {'n_is_nc': '', 'n_is_sth': ''},
 'ding': {'n_is_nc': '', 'n_is_sth': ''},
 'dingbat': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'dinghy': {'n_is_nc': '', 'n_is_sth': ''},
 'dingle': {'n_is_nc': '', 'n_is_sth': ''},
 'dinosaur': {'n_is_nc': '', 'n_is_sb': '3', 'nc_typical': '', 'n_is_sth': '3'},
 'dint': {'n_is_nc': '', 'n_is_sth': ''},
 'diocesan': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'diocese': {'n_is_nc': '', 'n_is_sth': ''},
 'diode': {'n_is_nc': '', 'n_is_sth': ''},
 'diorama': {'n_is_nc': '', 'n_is_sth': ''},
 'dip': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'dipping', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'v_in': '', 'vb_to_jj': 'dipping', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'diploma': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'dipper': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'directive': {'n_is_nc': '', 'n_is_sth': ''},
 'directorate': {'n_is_nc': '', 'n_is_sth': ''},
 'dirge': {'n_is_nc': '', 'n_is_sth': ''},
 'dirigible': {'n_is_nc': '', 'n_is_sth': ''},
 'dirk': {'n_is_nc': '', 'n_is_sth': ''},
 'disablement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'disagreement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'disappearance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'disapproval': {'n_is_nc': '', 'n_is_sth': ''},
 'disavowal': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'disbursement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'discard': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': ''},
 'discharge': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'disciple': {'n_is_nc': '', 'n_is_sb': '0'},
 'disclaimer': {'n_is_nc': '', 'n_is_sth': ''},
 'disco': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'disconnection': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'discontent': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'discontinuity': {'n_is_nc': '', 'n_is_sth': ''},
 'discord': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'discotheque': {'n_is_nc': '', 'n_is_sth': ''},
 'discouragement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'discourse': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'discourtesy': {'n_is_nc': '', 'n_is_sth': ''},
 'discus': {'n_is_nc': '', 'n_is_sth': ''},
 'discussion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'discuss', 'nn_to_vbg': 'discussing'},
 'disease': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'diseased', 'vb_to_jj': 'diseased', 'vbd_eq_vbn': ''},
 'disfigurement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'disguise': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'dishcloth': {'n_is_nc': '', 'n_is_sth': '0'},
 'dishwasher': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'disinfectant': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'diskette': {'n_is_nc': '', 'n_is_sth': ''},
 'dislocation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'disorder': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'disparagement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'disparity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'dispatch': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'dispatcher': {'n_is_nc': '', 'n_is_sb': '0'},
 'dispensary': {'n_is_nc': '', 'n_is_sth': ''},
 'dispensation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'dispenser': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'dispersal': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'display': {'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'displaies', 'vb_to_vbd': 'displayed', 'vb_to_vbn': 'displayed', 'vb_to_vbg': 'displaying', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'disposition': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'disproportion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'disputation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'dispute': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'disputes', 'vb_to_vbd': 'disputed', 'vb_to_vbn': 'disputed', 'vb_to_vbg': 'disputing', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'disquisition': {'n_is_nc': '', 'n_is_sth': ''},
 'disruption': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'dissection': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'dissembler': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'dissension': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'dissertation': {'n_is_nc': '', 'n_is_sth': ''},
 'disservice': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'dissident': {'n_is_nc': '', 'n_is_sb': '0'},
 'dissimilarity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'dissolution': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'dissonance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'distaff': {'n_is_nc': '', 'n_is_sth': ''},
 'distillate': {'n_is_nc': '', 'n_is_sth': ''},
 'distiller': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'distillery': {'n_is_nc': '', 'n_is_sth': ''},
 'distortion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'distort', 'nn_to_jj': 'distorted'},
 'distraction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'distribution': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'distribute', 'nn_to_jj': 'distributive'},
 'distributor': {'n_is_nc': '', 'n_is_sb': '0'},
 'disturbance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'disturb', 'nn_to_jj': 'disturbing'},
 'ditch': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'dither': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'ditto': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'ditty': {'n_is_nc': '', 'n_is_sth': ''},
 'diuretic': {'n_is_nc': '', 'n_is_sth': ''},
 'divan': {'n_is_nc': '', 'n_is_sth': ''},
 'dive': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'diving', 'v_to_vbg': '', 'nsubjpass': '', 'v_for': '', 'v_from': '', 'vb_to_jj': 'diving', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': '', 'vi_typical': ''},
 'diver': {'n_is_nc': '', 'n_is_sb': '0'},
 'divergence': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'diversion': {'n_is_nc': '', 'n_is_nu': ''},
 'divertimento': {'n_is_nc': '', 'n_is_sth': ''},
 'divider': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'divine': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'divisor': {'n_is_nc': '', 'n_is_sth': ''},
 'divot': {'n_is_nc': '', 'n_is_sth': ''},
 'divvy': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'dobbin': {'n_is_nc': '', 'n_is_sb': '0'},
 'dobson': {'n_is_nc': '', 'n_is_sb': '0'},
 'doc': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'docent': {'n_is_nc': '', 'n_is_sb': '0'},
 'dock': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'docket': {'n_is_nc': '', 'n_is_sth': ''},
 'dockyard': {'n_is_nc': '', 'n_is_sth': ''},
 'doctrine': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'documentation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'document', 'nn_to_jj': 'documented'},
 'dodge': {'n_is_nc': '', 'n_is_sth': '', 'v_vbg': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'dodger': {'n_is_nc': '', 'n_is_sb': '0'},
 'doer': {'n_is_nc': '', 'n_is_sb': '0'},
 'dogleg': {'n_is_nc': '', 'n_is_sth': ''},
 'dogma': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'dogwood': {'n_is_nc': '', 'n_is_sth': ''},
 'doings': {'n_is_nc': '', 'n_is_sth': ''},
 'dol': {'n_is_nc': '', 'n_is_sth': ''},
 'doldrums': {'n_is_nc': '', 'n_is_sth': ''},
 'doll': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nc_typical': ''},
 'dollop': {'n_is_nc': '', 'n_is_sth': ''},
 'dolly': {'n_is_nc': '', 'n_is_sth': ''},
 'dolphin': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'dolt': {'n_is_nc': '', 'n_is_sb': '0'},
 'domain': {'n_is_nc': '', 'n_is_sth': ''},
 'dome': {'n_is_nc': '', 'n_is_sth': ''},
 'domicile': {'n_is_nc': '', 'n_is_sth': ''},
 'dominion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'dominoes': {'n_is_nc': '', 'n_is_sth': ''},
 'dona': {'n_is_nc': '', 'n_is_sb': '0'},
 'donation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'dong': {'n_is_nc': '', 'n_is_sth': ''},
 'doodad': {'n_is_nc': '', 'n_is_sth': ''},
 'doodle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'doodlebug': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'doohickey': {'n_is_nc': '', 'n_is_sth': ''},
 'doorbell': {'n_is_nc': '', 'n_is_sth': ''},
 'doorjamb': {'n_is_nc': '', 'n_is_sth': ''},
 'doorkeeper': {'n_is_nc': '', 'n_is_sb': '0'},
 'doorman': {'n_is_nc': '', 'n_is_sb': '0'},
 'doorway': {'n_is_nc': '', 'n_is_sth': ''},
 'dope': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'dormer': {'n_is_nc': '', 'n_is_sth': ''},
 'dory': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'dosage': {'n_is_nc': '', 'n_is_sth': ''},
 'dossier': {'n_is_nc': '', 'n_is_sth': ''},
 'double': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_to_vbg': '', 'v_n': '', 'v_in': '', 'v_to': '', 'vb_to_vbz': 'doubles', 'vb_to_vbd': 'doubled', 'vb_to_vbn': 'doubled', 'vb_to_vbg': 'doubling', 'vbd_eq_vbn': ''},
 'double-decker': {'n_is_nc': '', 'n_is_sth': ''},
 'doubles': {'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'double'},
 'doublespeak': {'n_is_nc': '', 'n_is_sth': ''},
 'doublet': {'n_is_nc': '', 'n_is_sth': ''},
 'douche': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'doughboy': {'n_is_nc': '', 'n_is_sb': '0'},
 'dove': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'dovetail': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'dowager': {'n_is_nc': '', 'n_is_sb': '0'},
 'dowel': {'n_is_nc': '', 'n_is_sth': ''},
 'dower': {'n_is_nc': '', 'n_is_sth': ''},
 'downbeat': {'n_is_nc': '', 'n_is_sth': ''},
 'downdraft': {'n_is_nc': '', 'n_is_sth': ''},
 'downer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'downfall': {'n_is_nc': '', 'n_is_sth': ''},
 'downpour': {'n_is_nc': '', 'n_is_sth': ''},
 'downturn': {'n_is_nc': '', 'n_is_sth': ''},
 'dowry': {'n_is_nc': '', 'n_is_sth': ''},
 'doxy': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'doyen': {'n_is_nc': '', 'n_is_sb': '0'},
 'doze': {'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'dozer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'draftsman': {'n_is_nc': '', 'n_is_sb': '0'},
 'drag': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'dragging', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'drags', 'vb_to_vbd': 'dragged', 'vb_to_vbn': 'dragged', 'vb_to_jj': 'dragging', 'vb_to_vbg': 'draging', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'dragnet': {'n_is_nc': '', 'n_is_sth': ''},
 'dragonfly': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'dragoon': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'vbd_eq_vbn': ''},
 'drainpipe': {'n_is_nc': '', 'n_is_sth': ''},
 'dram': {'n_is_nc': '', 'n_is_sth': ''},
 'dramatics': {'n_is_nc': '', 'n_is_sth': ''},
 'dramatist': {'n_is_nc': '', 'n_is_sb': '0'},
 'dramatization': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'drape': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'draper': {'n_is_nc': '', 'n_is_sb': '0'},
 'draught': {'n_is_nc': '', 'n_is_sth': ''},
 'drawback': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'drawbar': {'n_is_nc': '', 'n_is_sth': ''},
 'drawbridge': {'n_is_nc': '', 'n_is_sth': ''},
 'drawknife': {'n_is_nc': '', 'n_is_sth': ''},
 'dray': {'n_is_nc': '', 'n_is_sth': ''},
 'dreamer': {'n_is_nc': '', 'n_is_sb': '0'},
 'dreamland': {'n_is_nc': '', 'n_is_sth': ''},
 'dreamworld': {'n_is_nc': '', 'n_is_sth': ''},
 'dredge': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'dregs': {'n_is_nc': '', 'n_is_sth': ''},
 'dress': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'dressed', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_for': '', 'vb_to_vbz': 'dresses', 'vb_to_vbd': 'dressed', 'vb_to_vbn': 'dressed', 'vb_to_jj': 'dressed', 'vb_to_vbg': 'dressing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'dresser': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'dressing': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'dress', 'vbg_to_vbn': 'dressed'},
 'dressmaker': {'n_is_nc': '', 'n_is_sb': '0'},
 'dribble': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'drier': {'n_is_nc': '', 'n_is_sth': ''},
 'drift': {'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'drifter': {'n_is_nc': '', 'n_is_sb': '0'},
 'drill': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_to_vbg': '', 'v_n': '', 'v_for': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'drinker': {'n_is_nc': '', 'n_is_sb': '0'},
 'drip': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'drive': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'driven', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'drives', 'vb_to_vbd': 'drived', 'vb_to_vbn': 'drived', 'vb_to_jj': 'driven', 'vb_to_vbg': 'driving', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_n_jj': ''},
 'drivel': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'driveway': {'n_is_nc': '', 'n_is_sth': ''},
 'drizzle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'drollery': {'n_is_nc': '', 'n_is_sth': ''},
 'dromedary': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'drone': {'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'drop-off': {'n_is_nc': '', 'n_is_sth': ''},
 'droplet': {'n_is_nc': '', 'n_is_sth': ''},
 'dropper': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'droppings': {'n_is_nc': '', 'n_is_sth': ''},
 'drosophila': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'drove': {'n_is_nc': '', 'n_is_sth': ''},
 'drubbing': {'n_is_nc': '', 'n_is_sth': ''},
 'drudge': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'druid': {'n_is_nc': '', 'n_is_sb': '0'},
 'drumbeat': {'n_is_nc': '', 'n_is_sth': ''},
 'drumhead': {'n_is_nc': '', 'n_is_sth': ''},
 'drummer': {'n_is_nc': '', 'n_is_sb': '0'},
 'drumstick': {'n_is_nc': '', 'n_is_sth': ''},
 'drunkard': {'n_is_nc': '', 'n_is_sb': '0'},
 'dryer': {'n_is_nc': '', 'n_is_sth': ''},
 'duce': {'n_is_nc': '', 'n_is_sb': '0'},
 'duchy': {'n_is_nc': '', 'n_is_sth': ''},
 'duck': {'n_is_nc': '', 'n_is_sb': '3', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'ducks', 'vb_to_vbd': 'ducked', 'vb_to_vbn': 'ducked', 'vb_to_vbg': 'ducking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': '', 'n_is_sth': '3'},
 'duckbill': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'duckling': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'ducky': {'n_is_nc': '', 'n_is_sb': '0'},
 'dud': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'due': {'n_is_nc': '', 'n_is_sth': '', 'be_jj_to_vbg': ''},
 'duel': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'duet': {'n_is_nc': '', 'n_is_sth': ''},
 'duff': {'n_is_nc': '', 'n_is_sth': ''},
 'duffer': {'n_is_nc': '', 'n_is_sb': '0'},
 'dukedom': {'n_is_nc': '', 'n_is_sth': ''},
 'dulcimer': {'n_is_nc': '', 'n_is_sth': ''},
 'dullard': {'n_is_nc': '', 'n_is_sb': '0'},
 'dumbbell': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'dummy': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'dumpling': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'dunce': {'n_is_nc': '', 'n_is_sb': '0'},
 'dunderhead': {'n_is_nc': '', 'n_is_sb': '0'},
 'dune': {'n_is_nc': '', 'n_is_sth': ''},
 'dungeon': {'n_is_nc': '', 'n_is_sth': ''},
 'dunker': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'duo': {'n_is_nc': '', 'n_is_sth': ''},
 'duodenum': {'n_is_nc': '', 'n_is_sth': ''},
 'duplicate': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'durian': {'n_is_nc': '', 'n_is_sth': ''},
 'dusk': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nu_typical': ''},
 'dustbin': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'duster': {'n_is_nc': '', 'n_is_sth': ''},
 'dustpan': {'n_is_nc': '', 'n_is_sth': ''},
 'dustup': {'n_is_nc': '', 'n_is_sth': ''},
 'duvet': {'n_is_nc': '', 'n_is_sth': ''},
 'dweller': {'n_is_nc': '', 'n_is_sb': '0'},
 'dwelling': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'dyad': {'n_is_nc': '', 'n_is_sth': ''},
 'dye': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'dyke': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'dynamo': {'n_is_nc': '', 'n_is_sth': ''},
 'dynamometer': {'n_is_nc': '', 'n_is_sth': ''},
 'dynasty': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'eardrum': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'earful': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'earl': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'earlobe': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'earmark': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'earphone': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'earplug': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'earring': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'earth': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'earthy', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'earths', 'vb_to_vbd': 'earthed', 'vb_to_vbn': 'earthed', 'vb_to_jj': 'earthy', 'vb_to_vbg': 'earthing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'earthenware': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'earthling': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'earthwork': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'earthworm': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'easel': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'easement': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'easterly': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'eatery': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'eats': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbz_to_vb': 'eat'},
 'eaves': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ebb': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'eccentric': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'echelon': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'echidna': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'eclipse': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'ecliptic': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ecstasy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ecuadorian': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'eddy': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'edema': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'edging': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'edge', 'vbg_to_vb': 'edge', 'vbg_to_vbn': 'edged'},
 'edible': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'edict': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'edifice': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'educator': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nc_typical': ''},
 'eel': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'effigy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'effluent': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'effusion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'egghead': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'eggplant': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'eggshell': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ego': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'egress': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'egret': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'eiderdown': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ejection': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ejector': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'elaboration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'election': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'elect', 'nn_to_jj': 'elect'},
 'elector': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'electorate': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'electrician': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'electrocardiogram': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'electrode': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'electroencephalogram': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'electrolyte': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'electromagnet': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'electron': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'elegy': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'elevation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'elision': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'elixir': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'elizabethan': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'cap_word': 'Elizabethan'},
 'elk': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '3'},
 'ellipse': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'elm': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'elongation': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'elopement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'elucidation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'emanation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'emancipator': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'embankment': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'embarkation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'embarrassment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'embellishment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ember': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'embezzler': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'emblem': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'embodiment': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'embolism': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'embolus': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'embroiderer': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'embryo': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'emcee': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'emerald': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'emigrant': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'emigration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'emigre': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'eminence': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'emir': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'emissary': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'emission': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'emitter': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'emmet': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'empiricist': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'emplacement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'emporium': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'empress': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'emu': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '3'},
 'emulator': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'emulsion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'enactment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'encampment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'encapsulation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'encaustic': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'enchantment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'enchantress': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'enclave': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'enclosure': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'enclose', 'nn_to_jj': 'enclosed'},
 'encomium': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'encore': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'encroachment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'encumbrance': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'encyclical': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'encyclopaedia': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'encyclopedia': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'endearment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'endicott': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'ending': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'endive': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'endocrine': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'endoscope': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'endowment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'enema': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'engagement': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'engraver': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'engraving': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'enhancement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'enhance', 'nn_to_jj': 'enhanced'},
 'enigma': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'enjoyment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'enjoy', 'nn_to_jj': 'enjoyable'},
 'enlargement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'enlarger': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'enlistment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'enmity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'enquiry': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'enrollment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ensemble': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ensign': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'entablature': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'entanglement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'entente': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'enteron': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'entertainment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'entertain', 'nn_to_jj': 'entertaining'},
 'enthronement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'enthusiast': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'enticement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'entirety': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'entitlement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'entity': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'entourage': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'entrails': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'entrant': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'entreaty': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'entrenchment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'entrepot': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'entrepreneur': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'enumeration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'environs': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'envoy': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'eon': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'epaulet': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ephemerality': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'epicenter': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'epicure': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'epicurean': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'epidermis': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'epiglottis': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'epigram': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'epigraph': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'epilogue': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'episode': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'epistle': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'epitaph': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'epithelium': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'epithet': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'epitome': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'epoch': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'equation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'equate', 'nn_to_jj': 'equational'},
 'equestrian': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'equine': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'equinox': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'equivocation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'erection': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'erg': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'erie': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'ermine': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '3'},
 'errand': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ersatz': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'eruption': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'erythromycin': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'escapade': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'escape': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'escaped', 'v_vbg': '', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'escapes', 'vb_to_vbd': 'escaped', 'vb_to_vbn': 'escaped', 'vb_to_jj': 'escaped', 'vb_to_vbg': 'escaping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'escapee': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'escapement': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'escarpment': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'escort': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'esophagus': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'espalier': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'esplanade': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'essayist': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'essence': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'essential', 'nn_to_rb': 'essentially'},
 'ester': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'esthete': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'esthetician': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'estimation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'estimate', 'nn_to_jj': 'estimated'},
 'estrangement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'estuary': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ethos': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'etiology': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'etude': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'eucalyptus': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'eulogist': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'eulogy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'eunuch': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'euphemism': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'euphony': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'evacuation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'evasion': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'evening': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'eventuality': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'eventual', 'nn_to_rb': 'eventually'},
 'evergreen': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'everyman': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'eviction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'evildoer': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'ex-husband': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'ex-wife': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'exaggeration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'examiner': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'excavation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'excavator': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '', 'art_an': ''},
 'excellency': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '', 'art_an': ''},
 'excerpt': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'exchange': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'exchanging', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'exchanges', 'vb_to_vbd': 'exchanged', 'vb_to_vbn': 'exchanged', 'vb_to_jj': 'exchanging', 'vb_to_vbg': 'exchanging', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'exchequer': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'excise': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'excision': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exclamation': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'excommunication': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'excrescence': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'excretion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'excursion': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'exec': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'executioner': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'executor': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'exegesis': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exemplar': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'exemption': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exertion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exhalation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exhaust': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'exhibition': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'exhibit', 'nn_to_jj': 'exhibited'},
 'exhortation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exhumation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exigency': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exorcism': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exoskeleton': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'expanse': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'expansion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'expand', 'nn_to_jj': 'expansive'},
 'expediency': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'expedient': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'expedition': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'expenditure': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'expletive': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'explication': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exploit': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'exploitive', 'vb_to_nn': 'exploitation', 'vb_to_jj': 'exploitive', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'exploiter': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'expo': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'exponent': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'exportation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exposition': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'expositor': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'expressway': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'expropriation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'expulsion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'extent': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exterior': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'exterminator': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'externality': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'externalise', 'nn_to_jj': 'external', 'nn_to_rb': 'externally'},
 'extinguisher': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'extortion': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'extraction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'extract', 'nn_to_jj': 'extract'},
 'extractor': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'extrapolation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'extraterrestrial': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'extravaganza': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'extremist': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'extremity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'extrusion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'eyeball': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'eyebrow': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'eyeful': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'eyeglass': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'eyeglasses': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'eyelash': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'eyelet': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'eyelid': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'eyepiece': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'eyeshade': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'eyesore': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'eyewitness': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'fabian': {'n_is_nc': '', 'n_is_sb': '0'},
 'fable': {'n_is_nc': '', 'n_is_sth': ''},
 'fabrication': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'facade': {'n_is_nc': '', 'n_is_sth': ''},
 'face-off': {'n_is_nc': '', 'n_is_sth': ''},
 'faceplate': {'n_is_nc': '', 'n_is_sth': ''},
 'facial': {'n_is_nc': '', 'n_is_sth': ''},
 'faction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fad': {'n_is_nc': '', 'n_is_sth': ''},
 'fag': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'faggot': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'fahrenheit': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'cap_word': 'Fahrenheit'},
 'faille': {'n_is_nc': '', 'n_is_sth': ''},
 'fairway': {'n_is_nc': '', 'n_is_sth': ''},
 'fairy': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'fairyland': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'faith': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'faithful', 'nn_to_rb': 'faithfully'},
 'faker': {'n_is_nc': '', 'n_is_sb': '0'},
 'fakery': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fakir': {'n_is_nc': '', 'n_is_sb': '0'},
 'falcon': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'fallacy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fallback': {'n_is_nc': '', 'n_is_sth': ''},
 'faller': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'falsehood': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'FALSE', 'nn_to_rb': 'falsely'},
 'falsetto': {'n_is_nc': '', 'n_is_sth': ''},
 'falsification': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'falsity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'falter': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'fame': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'famine': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fancier': {'n_is_nc': '', 'n_is_sb': '0'},
 'fandango': {'n_is_nc': '', 'n_is_sth': ''},
 'fanfare': {'n_is_nc': '', 'n_is_sth': ''},
 'fang': {'n_is_nc': '', 'n_is_sth': ''},
 'fanny': {'n_is_nc': '', 'n_is_sth': ''},
 'fantasia': {'n_is_nc': '', 'n_is_sth': ''},
 'farce': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fare-thee-well': {'n_is_nc': '', 'n_is_sth': ''},
 'farewell': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'farmhand': {'n_is_nc': '', 'n_is_sb': '0'},
 'farmhouse': {'n_is_nc': '', 'n_is_sth': ''},
 'farmland': {'n_is_nc': '', 'n_is_sth': ''},
 'farmstead': {'n_is_nc': '', 'n_is_sth': ''},
 'farrago': {'n_is_nc': '', 'n_is_sth': ''},
 'farrier': {'n_is_nc': '', 'n_is_sb': '0'},
 'fart': {'n_is_nc': '', 'n_is_sth': ''},
 'fascia': {'n_is_nc': '', 'n_is_sth': ''},
 'fascination': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fascist': {'n_is_nc': '', 'n_is_sb': '0'},
 'fashion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'fashionable', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'fashions', 'vb_to_vbd': 'fashioned', 'vb_to_vbn': 'fashioned', 'vb_to_jj': 'fashionable', 'vb_to_vbg': 'fashioning', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'fastener': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_vb': 'fasten'},
 'fastness': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'fast', 'nn_to_jj': 'fast', 'nn_to_rb': 'fast'},
 'fatality': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fathead': {'n_is_nc': '', 'n_is_sb': '0'},
 'father-in-law': {'n_is_nc': '', 'n_is_sb': '0'},
 'fatherland': {'n_is_nc': '', 'n_is_sth': ''},
 'fatness': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fatso': {'n_is_nc': '', 'n_is_sb': '0'},
 'fatuity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'favor': {'n_is_nc': '', 'n_is_sth': '', 'v_vbg': '', 'v_n': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'n_is_nu': ''},
 'favorite': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'favour': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'favourable', 'nn_to_rb': 'favourably', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'favours', 'vb_to_vbd': 'favoured', 'vb_to_vbn': 'favoured', 'vb_to_rb': 'favourably', 'vb_to_jj': 'favourable', 'v_vbg': '', 'vb_to_vbg': 'favouring', 'vbd_eq_vbn': ''},
 'fawn': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'fay': {'n_is_nc': '', 'n_is_sb': '0'},
 'feast': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'feat': {'n_is_nc': '', 'n_is_sth': ''},
 'feathering': {'n_is_nc': '', 'n_is_sth': ''},
 'feces': {'n_is_nc': '', 'n_is_sth': ''},
 'feed': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_on': '', 'v_with': '', 'v_to': '', 'vb_to_vbz': 'feeds', 'vb_to_vbd': 'fed', 'vb_to_vbn': 'fed', 'vb_to_vbg': 'feeding', 'v_compcl_non': ''},
 'feeder': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'feedlot': {'n_is_nc': '', 'n_is_sth': ''},
 'feel': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_vbg': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'vbe': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_about': '', 'v_vb': '', 'vb_to_vbz': 'feels', 'vb_to_vbd': 'felt', 'vb_to_vbn': 'felt', 'v_n_vb': '', 'v_n_vbg': '', 'vb_to_vbg': 'feeling'},
 'feeler': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'feint': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'felicity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fella': {'n_is_nc': '', 'n_is_sb': '0'},
 'feller': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'felon': {'n_is_nc': '', 'n_is_sb': '0'},
 'felony': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'femur': {'n_is_nc': '', 'n_is_sth': ''},
 'fen': {'n_is_nc': '', 'n_is_sth': ''},
 'fencing': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'fence', 'vbg_to_vbn': 'fenced'},
 'fender': {'n_is_nc': '', 'n_is_sth': ''},
 'feria': {'n_is_nc': '', 'n_is_sth': ''},
 'ferment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'fern': {'n_is_nc': '', 'n_is_sth': ''},
 'ferocity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'ferret': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'ferry': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'ferryboat': {'n_is_nc': '', 'n_is_sth': ''},
 'fertilizer': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fescue': {'n_is_nc': '', 'n_is_sth': ''},
 'fess': {'n_is_nc': '', 'n_is_sth': ''},
 'fester': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'festivity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fete': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'fetish': {'n_is_nc': '', 'n_is_sth': ''},
 'fetter': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'fettle': {'n_is_nc': '', 'n_is_sth': ''},
 'fetus': {'n_is_nc': '', 'n_is_sb': '0'},
 'feud': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'fever': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'feverish', 'vb_to_jj': 'feverish', 'vbd_eq_vbn': ''},
 'feverfew': {'n_is_nc': '', 'n_is_sth': ''},
 'fiance': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'fiancee': {'n_is_nc': '', 'n_is_sb': '0'},
 'fiasco': {'n_is_nc': '', 'n_is_sth': ''},
 'fiat': {'n_is_nc': '', 'n_is_sth': ''},
 'fiberglass': {'n_is_nc': '', 'n_is_sth': ''},
 'fibre': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fibula': {'n_is_nc': '', 'n_is_sth': ''},
 'fiddle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'fiddlehead': {'n_is_nc': '', 'n_is_sth': ''},
 'fiddler': {'n_is_nc': '', 'n_is_sb': '0'},
 'fidget': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'fief': {'n_is_nc': '', 'n_is_sth': ''},
 'fiefdom': {'n_is_nc': '', 'n_is_sth': ''},
 'fiend': {'n_is_nc': '', 'n_is_sb': '0'},
 'fiesta': {'n_is_nc': '', 'n_is_sth': ''},
 'fife': {'n_is_nc': '', 'n_is_sth': ''},
 'fig': {'n_is_nc': '', 'n_is_sth': ''},
 'figment': {'n_is_nc': '', 'n_is_sth': ''},
 'figuration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'figurehead': {'n_is_nc': '', 'n_is_sb': '0'},
 'figurine': {'n_is_nc': '', 'n_is_sth': ''},
 'filament': {'n_is_nc': '', 'n_is_sth': ''},
 'filbert': {'n_is_nc': '', 'n_is_sth': ''},
 'filename': {'n_is_nc': '', 'n_is_sth': ''},
 'filibuster': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'filigree': {'n_is_nc': '', 'n_is_sth': ''},
 'fill': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'filled', 'v_to_vbg': '', 'v_n': '', 'v_n_to_n': '', 'v_n_jj': '', 'nsubjpass': '', 'v_in': '', 'v_with': '', 'vb_to_jj': 'filled', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'fill-in': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'fille': {'n_is_nc': '', 'n_is_sb': '0'},
 'filler': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fillet': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'fillip': {'n_is_nc': '', 'n_is_sth': ''},
 'filter': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'fin': {'n_is_nc': '', 'n_is_sth': '0'},
 'financier': {'n_is_nc': '', 'n_is_sb': '0'},
 'finback': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'finch': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'finder': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'fingerboard': {'n_is_nc': '', 'n_is_sth': ''},
 'fingernail': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'fingerpost': {'n_is_nc': '', 'n_is_sth': ''},
 'fingerprint': {'n_is_nc': '', 'n_is_sth': ''},
 'fingertip': {'n_is_nc': '', 'n_is_sth': ''},
 'finish': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'finished', 'v_vbg': '', 'v_n': '', 'nsubjpass': '', 'v_with': '', 'vb_to_jj': 'finished', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'finisher': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'fink': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'fir': {'n_is_nc': '', 'n_is_sth': ''},
 'fire': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'firearm': {'n_is_nc': '', 'n_is_sth': ''},
 'fireball': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'fireboat': {'n_is_nc': '', 'n_is_sth': ''},
 'firebomb': {'n_is_nc': '', 'n_is_sth': ''},
 'firebox': {'n_is_nc': '', 'n_is_sth': ''},
 'firebrand': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'firebug': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'firecracker': {'n_is_nc': '', 'n_is_sth': ''},
 'firefly': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'firehouse': {'n_is_nc': '', 'n_is_sth': ''},
 'fireplace': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'fireplug': {'n_is_nc': '', 'n_is_sth': ''},
 'fireside': {'n_is_nc': '', 'n_is_sth': ''},
 'firestone': {'n_is_nc': '', 'n_is_sth': ''},
 'firewall': {'n_is_nc': '', 'n_is_sth': ''},
 'firework': {'n_is_nc': '', 'n_is_sth': ''},
 'firmament': {'n_is_nc': '', 'n_is_sth': ''},
 'firstborn': {'n_is_nc': '', 'n_is_sb': '0'},
 'fisc': {'n_is_nc': '', 'n_is_sth': ''},
 'fishbone': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fishbowl': {'n_is_nc': '', 'n_is_sth': ''},
 'fishery': {'n_is_nc': '', 'n_is_sth': ''},
 'fishhook': {'n_is_nc': '', 'n_is_sth': ''},
 'fishmonger': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'fishpond': {'n_is_nc': '', 'n_is_sth': ''},
 'fissure': {'n_is_nc': '', 'n_is_sth': ''},
 'fistfight': {'n_is_nc': '', 'n_is_sth': ''},
 'fisticuffs': {'n_is_nc': '', 'n_is_sth': ''},
 'fitter': {'n_is_nc': '', 'n_is_sb': '0'},
 'fitting': {'n_is_nc': '', 'n_is_sth': ''},
 'fixation': {'n_is_nc': '', 'n_is_sth': ''},
 'fixative': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fixer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'fixture': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'fjord': {'n_is_nc': '', 'n_is_sth': ''},
 'flack': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'flagging': {'n_is_nc': '', 'n_is_sth': ''},
 'flagon': {'n_is_nc': '', 'n_is_sth': ''},
 'flagpole': {'n_is_nc': '', 'n_is_sth': ''},
 'flagship': {'n_is_nc': '', 'n_is_sth': ''},
 'flagstaff': {'n_is_nc': '', 'n_is_sth': ''},
 'flagstone': {'n_is_nc': '', 'n_is_sth': ''},
 'flail': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'flak': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'flake': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'flame': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'flamethrower': {'n_is_nc': '', 'n_is_sth': ''},
 'flamingo': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'flan': {'n_is_nc': '', 'n_is_sth': ''},
 'flank': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'vbd_eq_vbn': ''},
 'flannel': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'flap': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'flapjack': {'n_is_nc': '', 'n_is_sth': ''},
 'flapper': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'flare': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'flashback': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'flashbulb': {'n_is_nc': '', 'n_is_sth': ''},
 'flask': {'n_is_nc': '', 'n_is_sth': ''},
 'flatbed': {'n_is_nc': '', 'n_is_sth': '', 'jj_ed': ''},
 'flatcar': {'n_is_nc': '', 'n_is_sth': ''},
 'flatfish': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'flatfoot': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'flathead': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'flatiron': {'n_is_nc': '', 'n_is_sth': ''},
 'flattop': {'n_is_nc': '', 'n_is_sth': ''},
 'flaw': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'flaxseed': {'n_is_nc': '', 'n_is_sth': ''},
 'flea': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'fleck': {'n_is_nc': '', 'n_is_sth': ''},
 'fledgeling': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'fledgling': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'fleece': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'fleer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'flex': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'flick': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'flicker': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'flier': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'flimsy': {'n_is_nc': '', 'n_is_sth': '', 'jj_to_jjr': 'flimsier', 'jj_to_jjs': 'flimsiest'},
 'flinch': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'flinders': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'fling': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'flint': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'flintlock': {'n_is_nc': '', 'n_is_sth': ''},
 'flip': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'flipper': {'n_is_nc': '', 'n_is_sth': ''},
 'flirtation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'floater': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'floe': {'n_is_nc': '', 'n_is_sth': ''},
 'flogging': {'n_is_nc': '', 'n_is_sth': ''},
 'floodgate': {'n_is_nc': '', 'n_is_sth': ''},
 'floodlight': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'floorboard': {'n_is_nc': '', 'n_is_sth': ''},
 'flop': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'flophouse': {'n_is_nc': '', 'n_is_sth': ''},
 'flora': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'florist': {'n_is_nc': '', 'n_is_sb': '0'},
 'flotation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'flotilla': {'n_is_nc': '', 'n_is_sth': ''},
 'flounder': {'n_is_nc': '', 'n_is_sb': '3', 'vbd_eq_vbn': '', 'n_is_sth': '3'},
 'flourish': {'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'flow': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'flowing', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'flows', 'vb_to_vbd': 'flew', 'vb_to_vbn': 'flown', 'vb_to_jj': 'flowing', 'vb_to_vbg': 'flowing', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'flowchart': {'n_is_nc': '', 'n_is_sth': ''},
 'flowering': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'flower', 'vbg_to_vbn': 'flowered'},
 'flowerpot': {'n_is_nc': '', 'n_is_sth': ''},
 'flub': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'fluctuation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'fluctuate', 'nn_to_jj': 'fluctuating'},
 'flue': {'n_is_nc': '', 'n_is_sth': ''},
 'fluke': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'flume': {'n_is_nc': '', 'n_is_sth': ''},
 'flummery': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'flunk': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'flunky': {'n_is_nc': '', 'n_is_sb': '0'},
 'flurry': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'flush': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'flute': {'n_is_nc': '', 'n_is_sth': ''},
 'flutter': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'flux': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fly-by-night': {'n_is_nc': '', 'n_is_sb': '0'},
 'flycatcher': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'flyer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'flyleaf': {'n_is_nc': '', 'n_is_sth': ''},
 'flyover': {'n_is_nc': '', 'n_is_sth': ''},
 'flypaper': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'flyswatter': {'n_is_nc': '', 'n_is_sth': ''},
 'flytrap': {'n_is_nc': '', 'n_is_sth': ''},
 'flywheel': {'n_is_nc': '', 'n_is_sth': ''},
 'foal': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'fob': {'n_is_nc': '', 'n_is_sth': ''},
 'foe': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'foible': {'n_is_nc': '', 'n_is_sth': ''},
 'foil': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'folder': {'n_is_nc': '', 'n_is_sth': ''},
 'foldout': {'n_is_nc': '', 'n_is_sth': ''},
 'folio': {'n_is_nc': '', 'n_is_sth': ''},
 'follicle': {'n_is_nc': '', 'n_is_sth': ''},
 'follies': {'n_is_nc': '', 'n_is_sth': ''},
 'follow-up': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'follower': {'n_is_nc': '', 'n_is_sb': '0'},
 'folly': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'font': {'n_is_nc': '', 'n_is_sth': ''},
 'foodstuff': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'footboard': {'n_is_nc': '', 'n_is_sth': ''},
 'footfall': {'n_is_nc': '', 'n_is_sth': ''},
 'foothold': {'n_is_nc': '', 'n_is_sth': ''},
 'footing': {'n_is_nc': '', 'n_is_sth': ''},
 'footlights': {'n_is_nc': '', 'n_is_sth': ''},
 'footman': {'n_is_nc': '', 'n_is_sb': '0'},
 'footnote': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'footpath': {'n_is_nc': '', 'n_is_sth': ''},
 'footprint': {'n_is_nc': '', 'n_is_sth': ''},
 'footstep': {'n_is_nc': '', 'n_is_sth': ''},
 'footstool': {'n_is_nc': '', 'n_is_sth': ''},
 'fop': {'n_is_nc': '', 'n_is_sb': '0'},
 'foray': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'force': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0', 'nn_to_jj': 'forceful', 'v_n': '', 'v_n_to_vb': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'forces', 'vb_to_vbd': 'forced', 'vb_to_vbn': 'forced', 'vb_to_jj': 'forceful', 'vb_to_vbg': 'forcing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'force-out': {'n_is_nc': '', 'n_is_sth': ''},
 'forceps': {'n_is_nc': '', 'n_is_sth': ''},
 'ford': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'forearm': {'n_is_nc': '', 'n_is_sth': ''},
 'forebear': {'n_is_nc': '', 'n_is_sb': '0'},
 'forebrain': {'n_is_nc': '', 'n_is_sth': ''},
 'forecaster': {'n_is_nc': '', 'n_is_sb': '0'},
 'foreclosure': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'forecourt': {'n_is_nc': '', 'n_is_sth': ''},
 'forefather': {'n_is_nc': '', 'n_is_sb': '0'},
 'forefinger': {'n_is_nc': '', 'n_is_sth': ''},
 'forefoot': {'n_is_nc': '', 'n_is_sth': ''},
 'foreground': {'n_is_nc': '', 'n_is_sth': ''},
 'forehead': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'foreigner': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'foreleg': {'n_is_nc': '', 'n_is_sth': ''},
 'foreman': {'n_is_nc': '', 'n_is_sb': '0'},
 'forerunner': {'n_is_nc': '', 'n_is_sb': '0'},
 'foreskin': {'n_is_nc': '', 'n_is_sth': ''},
 'foretaste': {'n_is_nc': '', 'n_is_sth': ''},
 'foreword': {'n_is_nc': '', 'n_is_sth': ''},
 'forfeit': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'forfeiture': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'forge': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'forger': {'n_is_nc': '', 'n_is_sb': '0'},
 'forgery': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'forging': {'n_is_nc': '', 'n_is_sth': ''},
 'forklift': {'n_is_nc': '', 'n_is_sth': ''},
 'formalities': {'n_is_nc': '', 'n_is_sth': ''},
 'formality': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'formal', 'nn_to_rb': 'formally'},
 'formulary': {'n_is_nc': '', 'n_is_sth': ''},
 'formulation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fort': {'n_is_nc': '', 'n_is_sth': ''},
 'forte': {'n_is_nc': '', 'n_is_sth': ''},
 'fortification': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fortress': {'n_is_nc': '', 'n_is_sth': ''},
 'fortuity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'forward': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'forwards', 'vb_to_vbd': 'forwarded', 'vb_to_vbn': 'forwarded', 'vb_to_vbg': 'forwarding', 'vbd_eq_vbn': ''},
 'fossa': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'fosse': {'n_is_nc': '', 'n_is_sth': ''},
 'fossil': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'foul-up': {'n_is_nc': '', 'n_is_sth': ''},
 'foundation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'foundational', 'nn_to_rb': 'foundationally'},
 'foundling': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'foundry': {'n_is_nc': '', 'n_is_sth': ''},
 'fount': {'n_is_nc': '', 'n_is_sth': ''},
 'fountain': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'fountainhead': {'n_is_nc': '', 'n_is_sth': ''},
 'foursome': {'n_is_nc': '', 'n_is_sth': ''},
 'fowl': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'foxglove': {'n_is_nc': '', 'n_is_sth': ''},
 'foxhole': {'n_is_nc': '', 'n_is_sth': ''},
 'foxtail': {'n_is_nc': '', 'n_is_sth': ''},
 'foyer': {'n_is_nc': '', 'n_is_sth': ''},
 'fracas': {'n_is_nc': '', 'n_is_sth': ''},
 'fracture': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'fragment': {'n_is_nc': '', 'n_is_sth': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'frail': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2', 'jj_to_jjr': 'frailer', 'jj_to_jjs': 'frailest'},
 'frailty': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fraise': {'n_is_nc': '', 'n_is_sth': ''},
 'frame-up': {'n_is_nc': '', 'n_is_sth': ''},
 'framework': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'framing': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'franc': {'n_is_nc': '', 'n_is_sth': ''},
 'franchise': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'frank': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'jj_to_jjr': 'franker', 'jj_to_jjs': 'frankest'},
 'fraternity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fratricide': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '0'},
 'frau': {'n_is_nc': '', 'n_is_sb': '0'},
 'fraud': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'frazzle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'freak': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'freckle': {'n_is_nc': '', 'n_is_sth': ''},
 'free-for-all': {'n_is_nc': '', 'n_is_sth': ''},
 'freebie': {'n_is_nc': '', 'n_is_sth': ''},
 'freedman': {'n_is_nc': '', 'n_is_sb': '0'},
 'freedom': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'free', 'nn_to_jj': 'free', 'nn_to_rb': 'free'},
 'freeman': {'n_is_nc': '', 'n_is_sb': '0'},
 'freestyle': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'freight': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'freighter': {'n_is_nc': '', 'n_is_sth': ''},
 'frenzy': {'n_is_nc': '', 'n_is_nu': '', 'vbd_eq_vbn': ''},
 'frequency': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'frequent', 'nn_to_jj': 'frequent'},
 'fresco': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'freshener': {'n_is_nc': '', 'n_is_sth': ''},
 'fret': {'n_is_nc': '', 'n_is_sth': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'friar': {'n_is_nc': '', 'n_is_sb': '0'},
 'friary': {'n_is_nc': '', 'n_is_sth': ''},
 'friction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'frier': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'frigate': {'n_is_nc': '', 'n_is_sth': ''},
 'frill': {'n_is_nc': '', 'n_is_sth': ''},
 'fringe': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'frisk': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'fritillary': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'fritter': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'frivolity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'frock': {'n_is_nc': '', 'n_is_sth': ''},
 'frogman': {'n_is_nc': '', 'n_is_sb': '0'},
 'frolic': {'n_is_nc': '', 'n_is_nu': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'frond': {'n_is_nc': '', 'n_is_sth': ''},
 'frontage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'frontal': {'n_is_nc': '', 'n_is_sth': ''},
 'frontier': {'n_is_nc': '', 'n_is_sth': ''},
 'frontispiece': {'n_is_nc': '', 'n_is_sth': ''},
 'frost': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'frown': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'frump': {'n_is_nc': '', 'n_is_sb': '0'},
 'fryer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'fuddy-duddy': {'n_is_nc': '', 'n_is_sb': '0'},
 'fuel': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'fuels', 'vb_to_vbd': 'fueled', 'vb_to_vbn': 'fueled', 'vb_to_vbg': 'fueling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'fugitive': {'n_is_nc': '', 'n_is_sb': '0'},
 'fulcrum': {'n_is_nc': '', 'n_is_sth': ''},
 'fullback': {'n_is_nc': '', 'n_is_sb': '0'},
 'fulmination': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'fumble': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': ''},
 'fume': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'functionality': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'functionary': {'n_is_nc': '', 'n_is_sb': '0'},
 'funk': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0', 'v_vbg': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'funnel': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'fur': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'furlong': {'n_is_nc': '', 'n_is_sth': ''},
 'furlough': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'furnace': {'n_is_nc': '', 'n_is_sth': ''},
 'furore': {'n_is_nc': '', 'n_is_sth': ''},
 'furrow': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'fury': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'fuse': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'fuselage': {'n_is_nc': '', 'n_is_sth': ''},
 'fusion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'futurity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'g-man': {'n_is_nc': '', 'n_is_sb': '0'},
 'gabardine': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'gable': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'gad': {'n_is_nc': '', 'n_is_sth': ''},
 'gadfly': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'gadget': {'n_is_nc': '', 'n_is_sth': ''},
 'gaff': {'n_is_nc': '', 'n_is_sth': ''},
 'gaffe': {'n_is_nc': '', 'n_is_sth': ''},
 'gaffer': {'n_is_nc': '', 'n_is_sb': '0'},
 'gag': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'gage': {'n_is_nc': '', 'n_is_sth': ''},
 'gainer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'gait': {'n_is_nc': '', 'n_is_sth': ''},
 'gaiter': {'n_is_nc': '', 'n_is_sth': ''},
 'gal': {'n_is_nc': '', 'n_is_sb': '0'},
 'galaxy': {'n_is_nc': '', 'n_is_sth': ''},
 'gale': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'galen': {'n_is_nc': '', 'n_is_sb': '0'},
 'gall': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'gallant': {'n_is_nc': '', 'n_is_sb': '0'},
 'gallantry': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'gallbladder': {'n_is_nc': '', 'n_is_sth': ''},
 'galley': {'n_is_nc': '', 'n_is_sth': ''},
 'gallop': {'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'gallows': {'n_is_nc': '', 'n_is_sth': '', 'nn_eq_nns': ''},
 'galoot': {'n_is_nc': '', 'n_is_sb': '0'},
 'gam': {'n_is_nc': '', 'n_is_sth': ''},
 'gambit': {'n_is_nc': '', 'n_is_sth': ''},
 'gambler': {'n_is_nc': '', 'n_is_sb': '0'},
 'gambol': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'gamecock': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'gamete': {'n_is_nc': '', 'n_is_sth': ''},
 'gamin': {'n_is_nc': '', 'n_is_sb': '0'},
 'gamut': {'n_is_nc': '', 'n_is_sth': ''},
 'gander': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'ganglion': {'n_is_nc': '', 'n_is_sth': ''},
 'gangplank': {'n_is_nc': '', 'n_is_sth': ''},
 'gangster': {'n_is_nc': '', 'n_is_sb': '0'},
 'gangway': {'n_is_nc': '', 'n_is_sth': ''},
 'gape': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'garb': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'gardener': {'n_is_nc': '', 'n_is_sb': '0'},
 'gardenia': {'n_is_nc': '', 'n_is_sth': ''},
 'gargle': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'garland': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': ''},
 'garment': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'garner': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'garnet': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'garnish': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'garnishment': {'n_is_nc': '', 'n_is_sth': ''},
 'garret': {'n_is_nc': '', 'n_is_sth': ''},
 'garrison': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'garter': {'n_is_nc': '', 'n_is_sth': ''},
 'gas': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'gases', 'vb_to_vbd': 'gassed', 'vb_to_vbn': 'gassed', 'vb_to_vbg': 'gasing', 'vbd_eq_vbn': ''},
 'gasbag': {'n_is_nc': '', 'n_is_sb': '0'},
 'gash': {'n_is_nc': '', 'n_is_sth': ''},
 'gasket': {'n_is_nc': '', 'n_is_sth': ''},
 'gasp': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'gastronome': {'n_is_nc': '', 'n_is_sb': '0'},
 'gatefold': {'n_is_nc': '', 'n_is_sth': ''},
 'gatehouse': {'n_is_nc': '', 'n_is_sth': ''},
 'gatekeeper': {'n_is_nc': '', 'n_is_sb': '0'},
 'gateway': {'n_is_nc': '', 'n_is_sth': ''},
 'gathering': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'gather', 'vbg_to_vbn': 'gathered'},
 'gauntlet': {'n_is_nc': '', 'n_is_sth': ''},
 'gaur': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'gaze': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'gazebo': {'n_is_nc': '', 'n_is_sth': ''},
 'gazelle': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'gazette': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'gearbox': {'n_is_nc': '', 'n_is_sth': ''},
 'gecko': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'geek': {'n_is_nc': '', 'n_is_sb': '0'},
 'geezer': {'n_is_nc': '', 'n_is_sb': '0'},
 'geisha': {'n_is_nc': '', 'n_is_sb': '0'},
 'gel': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'gelding': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'gem': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'gemini': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'gemma': {'n_is_nc': '', 'n_is_sth': ''},
 'gemstone': {'n_is_nc': '', 'n_is_sth': ''},
 'gen': {'n_is_nc': '', 'n_is_sth': ''},
 'gendarme': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'genealogy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'generalissimo': {'n_is_nc': '', 'n_is_sb': '0'},
 'generalist': {'n_is_nc': '', 'n_is_sb': '0'},
 'generality': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'generalise', 'nn_to_jj': 'general'},
 'generalization': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'generalship': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'generator': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'genie': {'n_is_nc': '', 'n_is_sb': '0'},
 'genitalia': {'n_is_nc': '', 'n_is_sth': ''},
 'genitals': {'n_is_nc': '', 'n_is_sth': ''},
 'gens': {'n_is_nc': '', 'n_is_sth': ''},
 'gent': {'n_is_nc': '', 'n_is_sb': '0'},
 'gentian': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'gentile': {'n_is_nc': '', 'n_is_sb': '0'},
 'gentlefolk': {'n_is_nc': '', 'n_is_sth': ''},
 'gentlewoman': {'n_is_nc': '', 'n_is_sb': '0'},
 'gentry': {'n_is_nc': '', 'n_is_sth': ''},
 'genuflection': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'geometer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'germ': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'gerund': {'n_is_nc': '', 'n_is_sth': ''},
 'gesso': {'n_is_nc': '', 'n_is_sth': ''},
 'gestapo': {'n_is_nc': '', 'n_is_sb': '0', 'cap_word': 'Gestapo'},
 'gesticulation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'getaway': {'n_is_nc': '', 'n_is_sth': ''},
 'getup': {'n_is_nc': '', 'n_is_sth': ''},
 'geyser': {'n_is_nc': '', 'n_is_sth': ''},
 'ghost': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'gi': {'n_is_nc': '', 'n_is_sth': ''},
 'gibbon': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'gibe': {'n_is_nc': '', 'n_is_sth': ''},
 'giblets': {'n_is_nc': '', 'n_is_sth': ''},
 'gig': {'n_is_nc': '', 'n_is_sth': ''},
 'giggle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'gild': {'n_is_nc': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'n_is_sth': '0'},
 'gill': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'gilt': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'gimlet': {'n_is_nc': '', 'n_is_sth': ''},
 'gimmick': {'n_is_nc': '', 'n_is_sth': ''},
 'gimp': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'gin': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'gingko': {'n_is_nc': '', 'n_is_sth': ''},
 'ginkgo': {'n_is_nc': '', 'n_is_sth': ''},
 'giraffe': {'n_is_nc': '', 'n_is_sb': '3', 'nc_typical': '', 'n_is_sth': '3'},
 'girder': {'n_is_nc': '', 'n_is_sth': ''},
 'girdle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'girth': {'n_is_nc': '', 'n_is_sth': ''},
 'gist': {'n_is_nc': '', 'n_is_sth': ''},
 'giveaway': {'n_is_nc': '', 'n_is_sth': ''},
 'gizzard': {'n_is_nc': '', 'n_is_sth': ''},
 'glaciation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'glacier': {'n_is_nc': '', 'n_is_sth': ''},
 'glade': {'n_is_nc': '', 'n_is_sth': ''},
 'gladiolus': {'n_is_nc': '', 'n_is_sth': ''},
 'glance': {'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_about': '', 'vb_to_vbz': 'glances', 'vb_to_vbd': 'glanced', 'vb_to_vbn': 'glanced', 'vb_to_vbg': 'glancing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'gland': {'n_is_nc': '', 'n_is_sth': ''},
 'glans': {'n_is_nc': '', 'n_is_sth': ''},
 'glare': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'vi_typical': ''},
 'glasshouse': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'glaze': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'glazer': {'n_is_nc': '', 'n_is_sb': '0'},
 'gleam': {'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'glen': {'n_is_nc': '', 'n_is_sth': ''},
 'glide': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'glider': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'glimmer': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'glint': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'glisten': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'glitch': {'n_is_nc': '', 'n_is_sth': ''},
 'glockenspiel': {'n_is_nc': '', 'n_is_sth': ''},
 'glossary': {'n_is_nc': '', 'n_is_sth': ''},
 'glow': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'glower': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'glut': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'glutton': {'n_is_nc': '', 'n_is_sb': '0'},
 'glycogen': {'n_is_nc': '', 'n_is_sth': ''},
 'glyph': {'n_is_nc': '', 'n_is_sth': ''},
 'gnat': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'gnome': {'n_is_nc': '', 'n_is_sb': '0'},
 'go-ahead': {'n_is_nc': '', 'n_is_sth': ''},
 'go-around': {'n_is_nc': '', 'n_is_sth': ''},
 'go-between': {'n_is_nc': '', 'n_is_sb': '0'},
 'go-cart': {'n_is_nc': '', 'n_is_sth': ''},
 'goalkeeper': {'n_is_nc': '', 'n_is_sb': '0'},
 'goat': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nc_typical': ''},
 'goatherd': {'n_is_nc': '', 'n_is_sb': '0'},
 'goatskin': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'goatsucker': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'gob': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'gobi': {'n_is_nc': '', 'n_is_sth': ''},
 'goblet': {'n_is_nc': '', 'n_is_sth': ''},
 'goblin': {'n_is_nc': '', 'n_is_sb': '0'},
 'goddess': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'godfather': {'n_is_nc': '', 'n_is_sb': '0'},
 'godparent': {'n_is_nc': '', 'n_is_sb': '0'},
 'goer': {'n_is_nc': '', 'n_is_sb': '0'},
 'gofer': {'n_is_nc': '', 'n_is_sb': '0'},
 'goggles': {'n_is_nc': '', 'n_is_sth': ''},
 'going-over': {'n_is_nc': '', 'n_is_sth': ''},
 'goldfinch': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'goldfish': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'golem': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'gondola': {'n_is_nc': '', 'n_is_sth': ''},
 'gong': {'n_is_nc': '', 'n_is_sth': ''},
 'goober': {'n_is_nc': '', 'n_is_sth': ''},
 'goodman': {'n_is_nc': '', 'n_is_sb': '0'},
 'goof': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'goofball': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'gook': {'n_is_nc': '', 'n_is_sb': '0'},
 'goon': {'n_is_nc': '', 'n_is_sb': '0'},
 'gooseberry': {'n_is_nc': '', 'n_is_sth': ''},
 'gopher': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'gorge': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'gorilla': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'goshawk': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'gosling': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'gospel': {'n_is_nc': '', 'n_is_sth': ''},
 'gossip': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'gouge': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'gourd': {'n_is_nc': '', 'n_is_sth': ''},
 'gourmand': {'n_is_nc': '', 'n_is_sb': '0'},
 'gown': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'goy': {'n_is_nc': '', 'n_is_sb': '0'},
 'grad': {'n_is_nc': '', 'n_is_sb': '0'},
 'gradation': {'n_is_nc': '', 'n_is_sth': ''},
 'gradient': {'n_is_nc': '', 'n_is_sth': ''},
 'graduation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'graffito': {'n_is_nc': '', 'n_is_sth': ''},
 'graft': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'grail': {'n_is_nc': '', 'n_is_sth': ''},
 'grammar': {'n_is_nc': '', 'n_is_sth': '', 'n_is_nu': ''},
 'gramophone': {'n_is_nc': '', 'n_is_sth': ''},
 'granada': {'n_is_nc': '', 'n_is_sth': ''},
 'granary': {'n_is_nc': '', 'n_is_sth': ''},
 'granddad': {'n_is_nc': '', 'n_is_sb': '0'},
 'grandee': {'n_is_nc': '', 'n_is_sb': '0'},
 'grandnephew': {'n_is_nc': '', 'n_is_sb': '0'},
 'grandniece': {'n_is_nc': '', 'n_is_sb': '0'},
 'grandpa': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'grandstand': {'n_is_nc': '', 'n_is_sth': ''},
 'grange': {'n_is_nc': '', 'n_is_sth': ''},
 'granger': {'n_is_nc': '', 'n_is_sb': '0'},
 'grant-in-aid': {'n_is_nc': '', 'n_is_sth': ''},
 'granule': {'n_is_nc': '', 'n_is_sth': ''},
 'grapevine': {'n_is_nc': '', 'n_is_sth': ''},
 'graphic': {'n_is_nc': '', 'n_is_sth': ''},
 'graphics': {'n_is_nc': '', 'n_is_sth': ''},
 'grasshopper': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'grate': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'grater': {'n_is_nc': '', 'n_is_sth': ''},
 'gratification': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'grating': {'n_is_nc': '', 'n_is_sth': ''},
 'gratuity': {'n_is_nc': '', 'n_is_sth': ''},
 'gravel': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'graver': {'n_is_nc': '', 'n_is_sb': '0', 'n_is_sth': ''},
 'gravestone': {'n_is_nc': '', 'n_is_sth': ''},
 'graveyard': {'n_is_nc': '', 'n_is_sth': ''},
 'gravure': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'graybeard': {'n_is_nc': '', 'n_is_sb': '0'},
 'graze': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'greaser': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'great-aunt': {'n_is_nc': '', 'n_is_sb': '0'},
 'great-nephew': {'n_is_nc': '', 'n_is_sb': '0'},
 'greaves': {'n_is_nc': '', 'n_is_sth': ''},
 'greenback': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'greenhorn': {'n_is_nc': '', 'n_is_sb': '0'},
 'greenhouse': {'n_is_nc': '', 'n_is_sth': ''},
 'greening': {'n_is_nc': '', 'n_is_sth': ''},
 'greenroom': {'n_is_nc': '', 'n_is_sth': ''},
 'greeting': {'n_is_nc': '', 'n_is_sth': ''},
 'gremlin': {'n_is_nc': '', 'n_is_sb': '0'},
 'grenade': {'n_is_nc': '', 'n_is_sth': ''},
 'grid': {'n_is_nc': '', 'n_is_sth': ''},
 'griddle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'gridiron': {'n_is_nc': '', 'n_is_sth': ''},
 'grievance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'griffin': {'n_is_nc': '', 'n_is_sb': '0'},
 'grifter': {'n_is_nc': '', 'n_is_sb': '0'},
 'grille': {'n_is_nc': '', 'n_is_sth': ''},
 'grimace': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'grind': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'grinding', 'vb_to_jj': 'grinding', 'vbd_eq_vbn': ''},
 'grinder': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'grindstone': {'n_is_nc': '', 'n_is_sth': ''},
 'gripe': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'grits': {'n_is_nc': '', 'n_is_sth': ''},
 'groan': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'groat': {'n_is_nc': '', 'n_is_sth': ''},
 'groin': {'n_is_nc': '', 'n_is_sth': ''},
 'groom': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'groomsman': {'n_is_nc': '', 'n_is_sb': '0'},
 'groove': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'groover': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'grope': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'grosgrain': {'n_is_nc': '', 'n_is_sth': ''},
 'grotesque': {'n_is_nc': '', 'n_is_sth': ''},
 'grotto': {'n_is_nc': '', 'n_is_sth': ''},
 'grouch': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'ground': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'groundball': {'n_is_nc': '', 'n_is_sth': ''},
 'grounder': {'n_is_nc': '', 'n_is_sth': ''},
 'groundhog': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'grounds': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'grouper': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'grouping': {'n_is_nc': '', 'n_is_sth': ''},
 'grouse': {'n_is_nc': '', 'n_is_sb': '3', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'n_is_sth': '3'},
 'grout': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'grove': {'n_is_nc': '', 'n_is_sth': ''},
 'grower': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'growl': {'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'grub': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'grumble': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'grump': {'n_is_nc': '', 'n_is_sb': '0'},
 'grunt': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'guan': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'guarantor': {'n_is_nc': '', 'n_is_sb': '0'},
 'guaranty': {'n_is_nc': '', 'n_is_sth': ''},
 'guardhouse': {'n_is_nc': '', 'n_is_sth': ''},
 'guardian': {'n_is_nc': '', 'n_is_sb': '0'},
 'guardrail': {'n_is_nc': '', 'n_is_sth': ''},
 'guardsman': {'n_is_nc': '', 'n_is_sb': '0'},
 'guesthouse': {'n_is_nc': '', 'n_is_sth': ''},
 'guffaw': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'guideline': {'n_is_nc': '', 'n_is_sth': ''},
 'guidepost': {'n_is_nc': '', 'n_is_sth': ''},
 'guild': {'n_is_nc': '', 'n_is_sth': ''},
 'guildhall': {'n_is_nc': '', 'n_is_sth': ''},
 'guillotine': {'n_is_nc': '', 'n_is_sth': ''},
 'guilt': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'guilty', 'nn_to_rb': 'guiltily'},
 'guise': {'n_is_nc': '', 'n_is_sth': ''},
 'gulch': {'n_is_nc': '', 'n_is_sth': ''},
 'gulden': {'n_is_nc': '', 'n_is_sth': ''},
 'gull': {'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'n_is_sth': '2'},
 'gullet': {'n_is_nc': '', 'n_is_sth': ''},
 'gully': {'n_is_nc': '', 'n_is_sth': ''},
 'gulp': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'gum': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'gumdrop': {'n_is_nc': '', 'n_is_sth': ''},
 'gumshoe': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'gunboat': {'n_is_nc': '', 'n_is_sth': ''},
 'gunfight': {'n_is_nc': '', 'n_is_sth': ''},
 'gunny': {'n_is_nc': '', 'n_is_sth': ''},
 'gunnysack': {'n_is_nc': '', 'n_is_sth': ''},
 'gunpoint': {'n_is_nc': '', 'n_is_sth': ''},
 'gunshot': {'n_is_nc': '', 'n_is_sth': ''},
 'gunslinger': {'n_is_nc': '', 'n_is_sb': '0'},
 'gunstock': {'n_is_nc': '', 'n_is_sth': ''},
 'gunwale': {'n_is_nc': '', 'n_is_sth': ''},
 'guru': {'n_is_nc': '', 'n_is_sb': '0'},
 'gush': {'n_is_nc': '', 'n_is_sth': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'gust': {'n_is_nc': '', 'n_is_sth': ''},
 'gut': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vbg_non': ''},
 'guts': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'gutter': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'guzzler': {'n_is_nc': '', 'n_is_sb': '0'},
 'gypsy': {'n_is_nc': '', 'n_is_sb': '0'},
 'gyration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'gyre': {'n_is_nc': '', 'n_is_sth': ''},
 'gyro': {'n_is_nc': '', 'n_is_sth': ''},
 'gyroscope': {'n_is_nc': '', 'n_is_sth': ''},
 'h-bomb': {'n_is_nc': '', 'n_is_sth': ''},
 'habitat': {'n_is_nc': '', 'n_is_sth': ''},
 'habitation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'habitue': {'n_is_nc': '', 'n_is_sb': '0'},
 'hacienda': {'n_is_nc': '', 'n_is_sth': ''},
 'hack': {'n_is_nc': '', 'n_is_sb': '3', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'n_is_sth': '3'},
 'hacker': {'n_is_nc': '', 'n_is_sb': '0'},
 'hackney': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'hacksaw': {'n_is_nc': '', 'n_is_sth': ''},
 'haft': {'n_is_nc': '', 'n_is_sth': ''},
 'hag': {'n_is_nc': '', 'n_is_sb': '0'},
 'hail': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'hailstone': {'n_is_nc': '', 'n_is_sth': ''},
 'haircut': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'hairdo': {'n_is_nc': '', 'n_is_sth': ''},
 'hairnet': {'n_is_nc': '', 'n_is_sth': ''},
 'hairpiece': {'n_is_nc': '', 'n_is_sth': ''},
 'hairpin': {'n_is_nc': '', 'n_is_sth': ''},
 'hairstyle': {'n_is_nc': '', 'n_is_sth': ''},
 'hakim': {'n_is_nc': '', 'n_is_sb': '0'},
 'halcyon': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'half-breed': {'n_is_nc': '', 'n_is_sb': '0', 'jj_ed': ''},
 'half-length': {'n_is_nc': '', 'n_is_sth': ''},
 'half-life': {'n_is_nc': '', 'n_is_sth': ''},
 'half-moon': {'n_is_nc': '', 'n_is_sth': ''},
 'half-wit': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'halfback': {'n_is_nc': '', 'n_is_sb': '0'},
 'halide': {'n_is_nc': '', 'n_is_sth': ''},
 'hallmark': {'n_is_nc': '', 'n_is_sth': ''},
 'hallucination': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'hallucinogen': {'n_is_nc': '', 'n_is_sth': ''},
 'hallway': {'n_is_nc': '', 'n_is_sth': ''},
 'halter': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'ham': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'hamburg': {'n_is_nc': '', 'n_is_sth': ''},
 'hamburger': {'n_is_nc': '', 'n_is_sth': ''},
 'hamlet': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'cap_word': 'Hamlet'},
 'hammer': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'hammered', 'vb_to_jj': 'hammered', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'hammerhead': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'hammock': {'n_is_nc': '', 'n_is_sth': ''},
 'hamster': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'hamstring': {'n_is_nc': '', 'n_is_sth': ''},
 'handball': {'n_is_nc': '', 'n_is_sth': ''},
 'handbill': {'n_is_nc': '', 'n_is_sth': ''},
 'handbook': {'n_is_nc': '', 'n_is_sth': ''},
 'handcart': {'n_is_nc': '', 'n_is_sth': ''},
 'handcuff': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'handful': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'handgrip': {'n_is_nc': '', 'n_is_sth': ''},
 'handgun': {'n_is_nc': '', 'n_is_sth': ''},
 'handhold': {'n_is_nc': '', 'n_is_sth': ''},
 'handicap': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'handicapped': {'n_is_nc': '', 'n_is_sb': '0', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'handicraft': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'handkerchief': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'handlebar': {'n_is_nc': '', 'n_is_sth': '0'},
 'handler': {'n_is_nc': '', 'n_is_sb': '0'},
 'handmaid': {'n_is_nc': '', 'n_is_sb': '0'},
 'handout': {'n_is_nc': '', 'n_is_sth': ''},
 'handrail': {'n_is_nc': '', 'n_is_sth': ''},
 'handsaw': {'n_is_nc': '', 'n_is_sth': ''},
 'handset': {'n_is_nc': '', 'n_is_sth': ''},
 'handshake': {'n_is_nc': '', 'n_is_sth': ''},
 'handspring': {'n_is_nc': '', 'n_is_sth': ''},
 'handstand': {'n_is_nc': '', 'n_is_sth': ''},
 'handwork': {'n_is_nc': '', 'n_is_sth': ''},
 'handwriting': {'n_is_nc': '', 'n_is_sth': '', 'nu_typical': ''},
 'handyman': {'n_is_nc': '', 'n_is_sb': '0'},
 'hang': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'hanging', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_from': '', 'vb_to_vbz': 'hangs', 'vb_to_vbd': 'hung', 'vb_to_vbn': 'hung', 'vb_to_jj': 'hanging', 'vb_to_vbg': 'hanging', 'vt_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'hang-up': {'n_is_nc': '', 'n_is_sth': ''},
 'hangar': {'n_is_nc': '', 'n_is_sth': ''},
 'hanger': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'hanger-on': {'n_is_nc': '', 'n_is_sb': '0'},
 'hangman': {'n_is_nc': '', 'n_is_sb': '0'},
 'hangnail': {'n_is_nc': '', 'n_is_sth': ''},
 'hangout': {'n_is_nc': '', 'n_is_sth': ''},
 'hangover': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'hank': {'n_is_nc': '', 'n_is_sth': ''},
 'hankie': {'n_is_nc': '', 'n_is_sth': ''},
 'hanky': {'n_is_nc': '', 'n_is_sth': ''},
 'hao': {'n_is_nc': '', 'n_is_sth': ''},
 'hap': {'n_is_nc': '', 'n_is_sth': ''},
 'happening': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'happen', 'vbg_to_vbn': 'happened'},
 'harangue': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'harbinger': {'n_is_nc': '', 'n_is_sth': ''},
 'harbour': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'hardback': {'n_is_nc': '', 'n_is_sth': ''},
 'hardliner': {'n_is_nc': '', 'n_is_sb': '0'},
 'hardwood': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'hare': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'harelip': {'n_is_nc': '', 'n_is_sth': ''},
 'harem': {'n_is_nc': '', 'n_is_sb': '0'},
 'harlequin': {'n_is_nc': '', 'n_is_sb': '0'},
 'harlot': {'n_is_nc': '', 'n_is_sb': '0'},
 'harmonic': {'n_is_nc': '', 'n_is_sth': ''},
 'harmonica': {'n_is_nc': '', 'n_is_sth': ''},
 'harmony': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'harmonious', 'confu_pair': 'harmonious'},
 'harness': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'harp': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'harpoon': {'n_is_nc': '', 'n_is_sth': ''},
 'harrier': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'harrow': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'harvester': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'hash': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'haslet': {'n_is_nc': '', 'n_is_sth': ''},
 'hassle': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'hassock': {'n_is_nc': '', 'n_is_sth': ''},
 'hatband': {'n_is_nc': '', 'n_is_sth': ''},
 'hatch': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'hatchet': {'n_is_nc': '', 'n_is_sth': ''},
 'hatching': {'n_is_nc': '', 'n_is_sth': ''},
 'hatchway': {'n_is_nc': '', 'n_is_sth': ''},
 'hate': {'n_is_nc': '', 'n_is_sth': '', 'v_vbg': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'hates', 'vb_to_vbd': 'hated', 'vb_to_vbn': 'hated', 'vb_to_vbg': 'hating', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'hatter': {'n_is_nc': '', 'n_is_sb': '0'},
 'hauler': {'n_is_nc': '', 'n_is_sb': '0'},
 'haunch': {'n_is_nc': '', 'n_is_sth': ''},
 'haunt': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'have-not': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'haw': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'hawk': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'hawker': {'n_is_nc': '', 'n_is_sb': '0'},
 'hawksbill': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'hawser': {'n_is_nc': '', 'n_is_sth': ''},
 'hawthorn': {'n_is_nc': '', 'n_is_sth': ''},
 'haycock': {'n_is_nc': '', 'n_is_sth': ''},
 'haystack': {'n_is_nc': '', 'n_is_sth': ''},
 'hazard': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'hazel': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'hazelnut': {'n_is_nc': '', 'n_is_sth': ''},
 'he-man': {'n_is_nc': '', 'n_is_sb': '0'},
 'headband': {'n_is_nc': '', 'n_is_sth': ''},
 'headdress': {'n_is_nc': '', 'n_is_sth': ''},
 'header': {'n_is_nc': '', 'n_is_sth': ''},
 'headgear': {'n_is_nc': '', 'n_is_sth': ''},
 'headlamp': {'n_is_nc': '', 'n_is_sth': ''},
 'headland': {'n_is_nc': '', 'n_is_sth': ''},
 'headlight': {'n_is_nc': '', 'n_is_sth': ''},
 'headman': {'n_is_nc': '', 'n_is_sb': '0'},
 'headphone': {'n_is_nc': '', 'n_is_sth': ''},
 'headpiece': {'n_is_nc': '', 'n_is_sth': ''},
 'headquarters': {'n_is_nc': '', 'n_is_sth': '', 'nn_eq_nns': ''},
 'headset': {'n_is_nc': '', 'n_is_sth': ''},
 'headstand': {'n_is_nc': '', 'n_is_sth': ''},
 'headwaiter': {'n_is_nc': '', 'n_is_sb': '0'},
 'headway': {'n_is_nc': '', 'n_is_sth': ''},
 'headwind': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'heap': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'heaping', 'vb_to_jj': 'heaping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'heaps': {'n_is_nc': '', 'n_is_sth': ''},
 'hearer': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'hearse': {'n_is_nc': '', 'n_is_sth': ''},
 'heartbeat': {'n_is_nc': '', 'n_is_sth': ''},
 'hearth': {'n_is_nc': '', 'n_is_sth': ''},
 'hearthstone': {'n_is_nc': '', 'n_is_sth': ''},
 'heartstrings': {'n_is_nc': '', 'n_is_sth': ''},
 'heat': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'heated', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'heats', 'vb_to_vbd': 'heated', 'vb_to_vbn': 'heated', 'vb_to_jj': 'heated', 'vb_to_vbg': 'heating', 'vbd_eq_vbn': ''},
 'heath': {'n_is_nc': '', 'n_is_sth': '', 'confu_pair': 'health'},
 'heathen': {'n_is_nc': '', 'n_is_sb': '0'},
 'heave': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'heaves': {'n_is_nc': '', 'n_is_sth': ''},
 'heavy': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'jj_to_jjr': 'heavier', 'jj_to_jjs': 'heaviest'},
 'hectare': {'n_is_nc': '', 'n_is_sth': ''},
 'hedge': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'hedgehog': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'hedgerow': {'n_is_nc': '', 'n_is_sth': ''},
 'heifer': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'heirloom': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'heist': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'helianthus': {'n_is_nc': '', 'n_is_sth': ''},
 'heliotrope': {'n_is_nc': '', 'n_is_sth': ''},
 'helix': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'hell': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'hellcat': {'n_is_nc': '', 'n_is_sb': '0'},
 'hellhound': {'n_is_nc': '', 'n_is_sb': '0'},
 'hellion': {'n_is_nc': '', 'n_is_sb': '0'},
 'helm': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'helmet': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'helmsman': {'n_is_nc': '', 'n_is_sb': '0'},
 'helper': {'n_is_nc': '', 'n_is_sb': '0'},
 'helping': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'help', 'vbg_to_vbn': 'helped'},
 'helpmate': {'n_is_nc': '', 'n_is_sb': '0'},
 'helpmeet': {'n_is_nc': '', 'n_is_sb': '0'},
 'hem': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'hematoma': {'n_is_nc': '', 'n_is_sth': ''},
 'hemisphere': {'n_is_nc': '', 'n_is_sth': ''},
 'hemline': {'n_is_nc': '', 'n_is_sth': ''},
 'hemlock': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'hemorrhage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'hen': {'n_is_nc': '', 'n_is_sb': '3', 'nc_typical': '', 'n_is_sth': '3'},
 'henchman': {'n_is_nc': '', 'n_is_sb': '0'},
 'henhouse': {'n_is_nc': '', 'n_is_sth': ''},
 'hepatica': {'n_is_nc': '', 'n_is_sth': ''},
 'herald': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'herb': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'herbalist': {'n_is_nc': '', 'n_is_sb': '0'},
 'herbivore': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'herd': {'n_is_nc': '', 'n_is_sth': '', 'n_is_collective': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'n_of_nns': ''},
 'herdsman': {'n_is_nc': '', 'n_is_sb': '0'},
 'heresy': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'heretic': {'n_is_nc': '', 'n_is_sb': '0'},
 'hermaphrodite': {'n_is_nc': '', 'n_is_sb': '0'},
 'hermit': {'n_is_nc': '', 'n_is_sb': '0'},
 'hermitage': {'n_is_nc': '', 'n_is_sth': ''},
 'heroine': {'n_is_nc': '', 'n_is_sb': '0'},
 'heron': {'n_is_nc': '', 'n_is_sb': '0'},
 'herring': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'hertz': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'hex': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'hexagon': {'n_is_nc': '', 'n_is_sth': ''},
 'heyday': {'n_is_nc': '', 'n_is_sth': ''},
 'hi-fi': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'hiatus': {'n_is_nc': '', 'n_is_sth': ''},
 'hibachi': {'n_is_nc': '', 'n_is_sth': ''},
 'hiccup': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'hickey': {'n_is_nc': '', 'n_is_sth': ''},
 'hickory': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'hideaway': {'n_is_nc': '', 'n_is_sth': ''},
 'hideout': {'n_is_nc': '', 'n_is_sth': ''},
 'hierarchy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'hierarchical'},
 'high-five': {'n_is_nc': '', 'n_is_sth': ''},
 'highball': {'n_is_nc': '', 'n_is_sth': ''},
 'highbrow': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'higher-up': {'n_is_nc': '', 'n_is_sb': '0'},
 'highland': {'n_is_nc': '', 'n_is_sth': ''},
 'highwayman': {'n_is_nc': '', 'n_is_sb': '0'},
 'hijacker': {'n_is_nc': '', 'n_is_sb': '0'},
 'hillbilly': {'n_is_nc': '', 'n_is_sb': '0'},
 'hillock': {'n_is_nc': '', 'n_is_sth': ''},
 'hillside': {'n_is_nc': '', 'n_is_sth': ''},
 'hilltop': {'n_is_nc': '', 'n_is_sth': ''},
 'hilt': {'n_is_nc': '', 'n_is_sth': ''},
 'hind': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'hindquarter': {'n_is_nc': '', 'n_is_sth': ''},
 'hindquarters': {'n_is_nc': '', 'n_is_sth': ''},
 'hindrance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'hinge': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'hinterland': {'n_is_nc': '', 'n_is_sth': ''},
 'hipbone': {'n_is_nc': '', 'n_is_sth': ''},
 'hippie': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'hippo': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'hippocampus': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'hippy': {'n_is_nc': '', 'n_is_sb': '0'},
 'hipster': {'n_is_nc': '', 'n_is_sb': '0'},
 'hireling': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'histrionics': {'n_is_nc': '', 'n_is_sth': ''},
 'hive': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'hoard': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'hoarding': {'n_is_nc': '', 'n_is_sth': ''},
 'hoax': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'hob': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'hobbyhorse': {'n_is_nc': '', 'n_is_sth': ''},
 'hobbyist': {'n_is_nc': '', 'n_is_sb': '0'},
 'hobgoblin': {'n_is_nc': '', 'n_is_sb': '0'},
 'hobnail': {'n_is_nc': '', 'n_is_sth': ''},
 'hobo': {'n_is_nc': '', 'n_is_sb': '0'},
 'hock': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'hod': {'n_is_nc': '', 'n_is_sth': ''},
 'hodgepodge': {'n_is_nc': '', 'n_is_sth': ''},
 'hoe': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'hog': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'hoist': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'hold': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_to_n': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_on': '', 'v_with': '', 'v_to': '', 'vb_to_vbz': 'holds', 'vb_to_vbd': 'held', 'vb_to_vbn': 'held', 'vb_to_vbg': 'holding', 'v_whcl_non': ''},
 'holding': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'hold', 'vbg_to_vbn': 'held'},
 'holdout': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'holdover': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'holdup': {'n_is_nc': '', 'n_is_sth': ''},
 'holler': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'holly': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'hollyhock': {'n_is_nc': '', 'n_is_sth': ''},
 'hologram': {'n_is_nc': '', 'n_is_sth': ''},
 'homecoming': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'homemaker': {'n_is_nc': '', 'n_is_sb': '0'},
 'homestead': {'n_is_nc': '', 'n_is_sth': ''},
 'homicide': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'homily': {'n_is_nc': '', 'n_is_sth': ''},
 'hominid': {'n_is_nc': '', 'n_is_sb': '0'},
 'homonym': {'n_is_nc': '', 'n_is_sth': ''},
 'homunculus': {'n_is_nc': '', 'n_is_sb': '0'},
 'honcho': {'n_is_nc': '', 'n_is_sb': '0'},
 'hone': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'honeybee': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'honeycomb': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'honeymoon': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'honeysuckle': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'honky': {'n_is_nc': '', 'n_is_sb': '0'},
 'honor': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_n': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'honorarium': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'honorific': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'honour': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'honourable', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'honours', 'vb_to_vbd': 'honoured', 'vb_to_vbn': 'honoured', 'vb_to_jj': 'honourable', 'vb_to_vbg': 'honouring', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'hoo-ha': {'n_is_nc': '', 'n_is_sth': ''},
 'hood': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'hoodlum': {'n_is_nc': '', 'n_is_sb': '0'},
 'hoodoo': {'n_is_nc': '', 'n_is_sb': '0'},
 'hooey': {'n_is_nc': '', 'n_is_sth': ''},
 'hoofer': {'n_is_nc': '', 'n_is_sb': '0'},
 'hookah': {'n_is_nc': '', 'n_is_sth': ''},
 'hooker': {'n_is_nc': '', 'n_is_sb': '0'},
 'hookworm': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'hooky': {'n_is_nc': '', 'n_is_sb': '0'},
 'hooligan': {'n_is_nc': '', 'n_is_sb': '0'},
 'hoop': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'hoosegow': {'n_is_nc': '', 'n_is_sth': ''},
 'hoot': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'hooter': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'hop': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'hope': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'hopeful', 'nn_to_rb': 'hopefully', 'v_compcl': '', 'v_to_vb': '', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'hopes', 'vb_to_vbd': 'hoped', 'vb_to_vbn': 'hoped', 'vb_to_rb': 'hopefully', 'vb_to_jj': 'hopeful', 'vb_to_vbg': 'hoping', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_n_jj_non': ''},
 'hopper': {'n_is_nc': '', 'n_is_sb': '0'},
 'horde': {'n_is_nc': '', 'n_is_sth': ''},
 'hormone': {'n_is_nc': '', 'n_is_sth': ''},
 'horn': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'hornbill': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'hornet': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'horoscope': {'n_is_nc': '', 'n_is_sth': ''},
 'horseback': {'n_is_nc': '', 'n_is_sth': ''},
 'horsefly': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'horseman': {'n_is_nc': '', 'n_is_sb': '0'},
 'horseplay': {'n_is_nc': '', 'n_is_sth': ''},
 'horsepower': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'horseshoe': {'n_is_nc': '', 'n_is_sth': ''},
 'horsetail': {'n_is_nc': '', 'n_is_sth': ''},
 'horticulturist': {'n_is_nc': '', 'n_is_sb': '0'},
 'hose': {'n_is_nc': '', 'n_is_sth': ''},
 'hospice': {'n_is_nc': '', 'n_is_sth': ''},
 'hostage': {'n_is_nc': '', 'n_is_sb': '0'},
 'hostel': {'n_is_nc': '', 'n_is_sth': ''},
 'hostelry': {'n_is_nc': '', 'n_is_sth': ''},
 'hostess': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'hostilities': {'n_is_nc': '', 'n_is_sth': ''},
 'hotbed': {'n_is_nc': '', 'n_is_sth': ''},
 'hotdog': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nc_typical': ''},
 'hothead': {'n_is_nc': '', 'n_is_sb': '0'},
 'hothouse': {'n_is_nc': '', 'n_is_sth': ''},
 'hotshot': {'n_is_nc': '', 'n_is_sb': '0'},
 'hotspot': {'n_is_nc': '', 'n_is_sth': ''},
 'hound': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'hourglass': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'houseboat': {'n_is_nc': '', 'n_is_sth': ''},
 'housecoat': {'n_is_nc': '', 'n_is_sth': ''},
 'housefly': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'householder': {'n_is_nc': '', 'n_is_sb': '0'},
 'housekeeper': {'n_is_nc': '', 'n_is_sb': '0'},
 'housemaid': {'n_is_nc': '', 'n_is_sb': '0'},
 'houseman': {'n_is_nc': '', 'n_is_sb': '0'},
 'housemaster': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'housewife': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'hovel': {'n_is_nc': '', 'n_is_sth': ''},
 'hovercraft': {'n_is_nc': '', 'n_is_sth': ''},
 'howitzer': {'n_is_nc': '', 'n_is_sth': ''},
 'howl': {'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'v_in': '', 'v_with': '', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'hub': {'n_is_nc': '', 'n_is_sth': ''},
 'hubby': {'n_is_nc': '', 'n_is_sb': '0'},
 'huckleberry': {'n_is_nc': '', 'n_is_sth': ''},
 'huckster': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'huddle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'hue': {'n_is_nc': '', 'n_is_sth': ''},
 'huff': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'hug': {'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'hula': {'n_is_nc': '', 'n_is_sth': ''},
 'hull': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'hullabaloo': {'n_is_nc': '', 'n_is_sth': ''},
 'hum': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'humanities': {'n_is_nc': '', 'n_is_sth': ''},
 'humbug': {'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'humerus': {'n_is_nc': '', 'n_is_sth': ''},
 'hummer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'hummingbird': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'humour': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'hump': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'humpback': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'hun': {'n_is_nc': '', 'n_is_sb': '0'},
 'hunch': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'hunchback': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'hunk': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'huntsman': {'n_is_nc': '', 'n_is_sb': '0'},
 'hurdle': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'hurler': {'n_is_nc': '', 'n_is_sb': '0'},
 'hurrah': {'n_is_nc': '', 'n_is_sth': ''},
 'hurt': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'vb_to_vbz': 'hurts', 'vb_to_vbg': 'hurting', 'vbn_to_vbg': 'hurting'},
 'husk': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'husky': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2', 'jj_to_jjr': 'huskier', 'jj_to_jjs': 'huskiest'},
 'hussar': {'n_is_nc': '', 'n_is_sb': '0'},
 'hussy': {'n_is_nc': '', 'n_is_sb': '0'},
 'hustler': {'n_is_nc': '', 'n_is_sb': '0'},
 'hut': {'n_is_nc': '', 'n_is_sth': ''},
 'hutch': {'n_is_nc': '', 'n_is_sth': ''},
 'hyacinth': {'n_is_nc': '', 'n_is_sth': ''},
 'hybrid': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'hydra': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'hydrant': {'n_is_nc': '', 'n_is_sth': ''},
 'hydride': {'n_is_nc': '', 'n_is_sth': ''},
 'hydrofoil': {'n_is_nc': '', 'n_is_sth': ''},
 'hydroplane': {'n_is_nc': '', 'n_is_sth': ''},
 'hydroxide': {'n_is_nc': '', 'n_is_sth': ''},
 'hyena': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'hymn': {'n_is_nc': '', 'n_is_sth': ''},
 'hyperbole': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'hyperlink': {'n_is_nc': '', 'n_is_sth': ''},
 'hyphen': {'n_is_nc': '', 'n_is_sth': ''},
 'hypnotic': {'n_is_nc': '', 'n_is_sth': ''},
 'hypo': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'hypocrite': {'n_is_nc': '', 'n_is_sb': '0'},
 'hypotenuse': {'n_is_nc': '', 'n_is_sth': ''},
 'hypothesis': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'hypothesize', 'nn_to_jj': 'hypothetical', 'nn_to_nns': 'hypotheses'},
 'hysteric': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'ibex': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '3'},
 'ibis': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'iceberg': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'icebox': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'icebreaker': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'icecap': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'icehouse': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'icicle': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'idealist': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'idealization': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'identifier': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'ideologist': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'ideologue': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'idiocy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'idiom': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'idiosyncrasy': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'idler': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'idol': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'idyll': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'igniter': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ignition': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ignoramus': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'ilk': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'illiterate': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'illumination': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'illusion': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'illusionist': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'imago': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'imam': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'imbecile': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'imbecility': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'imbroglio': {'n_is_nc': '', 'art_an': '', 'n_is_sth': '0'},
 'imitator': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'immersion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'immortal': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'immunization': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'imp': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'impact': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'impacted', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'vb_to_vbz': 'impacts', 'vb_to_vbd': 'impacted', 'vb_to_vbn': 'impacted', 'vb_to_jj': 'impacted', 'vb_to_vbg': 'impacting', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'impairment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'impalement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'impasse': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'impeachment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'impediment': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'imperative': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'imperfect': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'imperfection': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'imperial': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'imperium': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'impersonator': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'impertinence': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'impiety': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'impingement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'implementation': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'implement', 'nn_to_jj': 'implemented'},
 'implication': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'implicate', 'nn_to_jj': 'implicated'},
 'importation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'importer': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'imposition': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'impose', 'nn_to_jj': 'imposed'},
 'impostor': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'impresario': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'impress': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'impresses', 'vb_to_vbd': 'impressed', 'vb_to_vbn': 'impressed', 'vb_to_vbg': 'impressing', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vbg_non': '', 'vt_typical': ''},
 'imprimatur': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'imprint': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'improvisation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'imprudence': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'impulse': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'impunity': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'impurity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'imputation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inadvertence': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inanity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inauguration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'incantation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'incarnation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'incendiary': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'inception': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'inchworm': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '3'},
 'incidental': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'incinerator': {'n_is_nc': '', 'art_an': '', 'n_is_sth': '0'},
 'incision': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'incisor': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'incitement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'incivility': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inclination': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'incline', 'nn_to_jj': 'inclining'},
 'incline': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'inclining', 'vb_to_nn': 'inclination', 'vb_to_jj': 'inclining', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'inclusion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'include', 'nn_to_jj': 'inclusive'},
 'income': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'incoming': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inconstancy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'increment': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'incubator': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'incubus': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'incumbency': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'incursion': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'indemnity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'indentation': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'indenture': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': ''},
 'indexer': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'indicator': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'indignity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'indirection': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'indiscretion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inducement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'induction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'induce', 'nn_to_jj': 'inducing'},
 'indulgence': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'industrialist': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'infanticide': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'infantryman': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'inference': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'infer', 'nn_to_jj': 'inferred'},
 'inferior': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'inferno': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'infestation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'infidel': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'infidelity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'infield': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'infinitesimal': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'infirmary': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'infirmity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inflammation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inflection': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inflow': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'influence': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2', 'nn_to_jj': 'influential', 'v_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'influences', 'vb_to_vbd': 'influenced', 'vb_to_vbn': 'influenced', 'vb_to_jj': 'influential', 'vb_to_vbg': 'influencing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'influx': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'informant': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'informer': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'infraction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'infringement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'infusion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ingot': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'inhabitant': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'inheritance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'inherit'},
 'inheritor': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'iniquity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'initiation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'initiate', 'nn_to_jj': 'initiate'},
 'initiator': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'injection': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'injector': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'injunction': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ink': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'inky', 'vb_to_jj': 'inky', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'inkwell': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'inlet': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'inmate': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'inn': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'innards': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'innuendo': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inoculation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'input': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'inputs', 'vb_to_vbg': 'inputting', 'vbn_to_vbg': 'inputting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'inquest': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'inquisitor': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'inroad': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'inscription': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'insertion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'insert', 'nn_to_jj': 'inserted'},
 'inset': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'vbd_eq_vbn': ''},
 'insight': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'insightful'},
 'insignia': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'insipidity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'insole': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'insolvency': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'instability': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'installment': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'instep': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'instinct': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'institution': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'institute', 'nn_to_jj': 'institutional'},
 'instruction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'instruct', 'nn_to_jj': 'instructive'},
 'instructions': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'instructor': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'instrumentality': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'insufficiency': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'insulator': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'insurance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'insure', 'nn_to_jj': 'insured'},
 'insurgency': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'insurrection': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'intaglio': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'intake': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'integer': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'integrator': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'intellect': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'intelligentsia': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'interaction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'interact', 'nn_to_jj': 'interactive'},
 'interceptor': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'intercession': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'interchange': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'intercom': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'interconnection': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'interdiction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'interface': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'interim': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'interjection': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'interlock': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'interlude': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'intermediary': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'interment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'intermezzo': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'intermission': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'internship': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'interpolation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'interpretation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'interpret', 'nn_to_jj': 'interpretive'},
 'interregnum': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'interrogation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'interrogator': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'interrogatory': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'interrupter': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'interruption': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'intersection': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'intersex': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'interviewer': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'intestine': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'intimation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'intonation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'intoxicant': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'intricacy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'intrigue': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'intriguer': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'intruder': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'intrusion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'intuition': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inundation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'invader': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'invalid': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'invalidation': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'invention': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'invent', 'nn_to_jj': 'invented'},
 'inventor': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'nc_typical': ''},
 'inversion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'investigation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'investigate', 'nn_to_jj': 'investigative'},
 'investiture': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'invocation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'invoice': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ion': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'iou': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'iq': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'iraqi': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': '', 'art_an': '', 'cap_word': 'Iraqi'},
 'iris': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'irish': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'cap_word': 'Irish', 'n_is_sth': '2'},
 'ironworker': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'irregular': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'irritant': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'irritation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'isle': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_nns': 'isles'},
 'islet': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'isotope': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'israelite': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'issuance': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'issuer': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'isthmus': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'itch': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_with': '', 'v_for': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'itinerary': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ivory': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ivy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'jab': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 "jack-o'-lantern": {'n_is_nc': '', 'n_is_sth': ''},
 'jackal': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'jackass': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'jackhammer': {'n_is_nc': '', 'n_is_sth': ''},
 'jackpot': {'n_is_nc': '', 'n_is_sth': ''},
 'jade': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'jaeger': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'jag': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'jaguar': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'jailer': {'n_is_nc': '', 'n_is_sb': '0'},
 'jailhouse': {'n_is_nc': '', 'n_is_sth': ''},
 'jalopy': {'n_is_nc': '', 'n_is_sth': ''},
 'jalousie': {'n_is_nc': '', 'n_is_sth': ''},
 'jam': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'jams', 'vb_to_vbd': 'jammed', 'vb_to_vbn': 'jammed', 'vb_to_vbg': 'jamming', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'jamb': {'n_is_nc': '', 'n_is_sth': ''},
 'jambalaya': {'n_is_nc': '', 'n_is_sth': ''},
 'jangle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'janitor': {'n_is_nc': '', 'n_is_sb': '0'},
 'jar': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'javelin': {'n_is_nc': '', 'n_is_sth': ''},
 'jaw': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'jawbone': {'n_is_nc': '', 'n_is_sth': ''},
 'jay': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'jealousy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'jealous', 'nn_to_rb': 'jealously'},
 'jeep': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'jeer': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'jelly': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'jellyfish': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'jerk': {'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'n_is_sth': '2'},
 'jest': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'jetty': {'n_is_nc': '', 'n_is_sth': ''},
 'jew': {'n_is_nc': '', 'n_is_sb': '0'},
 'jeweler': {'n_is_nc': '', 'n_is_sb': '0'},
 'jeweller': {'n_is_nc': '', 'n_is_sb': '0'},
 'jewess': {'n_is_nc': '', 'n_is_sb': '0'},
 'jezebel': {'n_is_nc': '', 'n_is_sb': '0'},
 'jiao': {'n_is_nc': '', 'n_is_sth': ''},
 'jib': {'n_is_nc': '', 'n_is_sth': ''},
 'jiffy': {'n_is_nc': '', 'n_is_sth': ''},
 'jig': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'jigger': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'jigsaw': {'n_is_nc': '', 'n_is_sth': ''},
 'jimmy': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'jingle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'jinks': {'n_is_nc': '', 'n_is_sth': ''},
 'jinx': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'jitney': {'n_is_nc': '', 'n_is_sth': ''},
 'jitters': {'n_is_nc': '', 'n_is_sth': ''},
 'jobber': {'n_is_nc': '', 'n_is_sb': '0'},
 'jock': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'jockey': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'jog': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'joiner': {'n_is_nc': '', 'n_is_sb': '0'},
 'jointer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'joist': {'n_is_nc': '', 'n_is_sth': ''},
 'joker': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'jollity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'jolly': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'jj_to_jjr': 'jollier', 'jj_to_jjs': 'jolliest'},
 'jolt': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'jonquil': {'n_is_nc': '', 'n_is_sth': ''},
 'jostle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'jot': {'n_is_nc': '', 'n_is_sth': ''},
 'joule': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'journeyman': {'n_is_nc': '', 'n_is_sb': '0'},
 'joust': {'n_is_nc': '', 'n_is_sth': ''},
 'joviality': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'jowl': {'n_is_nc': '', 'n_is_sth': ''},
 'joystick': {'n_is_nc': '', 'n_is_sth': ''},
 'judgement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'judge'},
 'judiciary': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'jug': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'juggle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'juggler': {'n_is_nc': '', 'n_is_sb': '0'},
 'juicer': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'juju': {'n_is_nc': '', 'n_is_sth': ''},
 'julep': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'jumble': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'junction': {'n_is_nc': '', 'n_is_sth': ''},
 'juncture': {'n_is_nc': '', 'n_is_sth': ''},
 'jungle': {'n_is_nc': '', 'n_is_sth': ''},
 'juniper': {'n_is_nc': '', 'n_is_sth': ''},
 'junk': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'junket': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'junta': {'n_is_nc': '', 'n_is_sth': ''},
 'jurist': {'n_is_nc': '', 'n_is_sb': '0'},
 'juror': {'n_is_nc': '', 'n_is_sb': '0'},
 'justification': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'justify', 'nn_to_jj': 'justifiable'},
 'jut': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'kaki': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'kale': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'kaleidoscope': {'n_is_nc': '', 'n_is_sth': ''},
 'karat': {'n_is_nc': '', 'n_is_sth': ''},
 'katydid': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'kayak': {'n_is_nc': '', 'n_is_sth': ''},
 'kayo': {'n_is_nc': '', 'n_is_sth': ''},
 'kazak': {'n_is_nc': '', 'n_is_sb': '0'},
 'kebab': {'n_is_nc': '', 'n_is_sth': ''},
 'keel': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'keenness': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'keeping': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'keep', 'vbg_to_vbn': 'kept'},
 'keg': {'n_is_nc': '', 'n_is_sth': ''},
 'keister': {'n_is_nc': '', 'n_is_sth': ''},
 'kelly': {'n_is_nc': '', 'n_is_sb': '0'},
 'ken': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl': ''},
 'kennel': {'n_is_nc': '', 'n_is_sth': ''},
 'kerchief': {'n_is_nc': '', 'n_is_sth': ''},
 'kern': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'kernel': {'n_is_nc': '', 'n_is_sth': ''},
 'keyhole': {'n_is_nc': '', 'n_is_sth': ''},
 'keynote': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'keypad': {'n_is_nc': '', 'n_is_sth': ''},
 'keystone': {'n_is_nc': '', 'n_is_sth': ''},
 'kg': {'n_is_nc': '', 'n_is_sth': ''},
 'khan': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'kickback': {'n_is_nc': '', 'n_is_sth': ''},
 'kickoff': {'n_is_nc': '', 'n_is_sth': ''},
 'kiddy': {'n_is_nc': '', 'n_is_sb': '0'},
 'kidnapper': {'n_is_nc': '', 'n_is_sb': '0'},
 'kidney': {'n_is_nc': '', 'n_is_sth': ''},
 'kiln': {'n_is_nc': '', 'n_is_sth': ''},
 'kilo': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'kilowatt': {'n_is_nc': '', 'n_is_sth': ''},
 'kilt': {'n_is_nc': '', 'n_is_sth': ''},
 'kimono': {'n_is_nc': '', 'n_is_sth': ''},
 'kin': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'kinase': {'n_is_nc': '', 'n_is_sth': ''},
 'kindergarten': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'kinescope': {'n_is_nc': '', 'n_is_sth': ''},
 'kinfolk': {'n_is_nc': '', 'n_is_sb': '0'},
 'kingdom': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'kingfisher': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'kingpin': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'kink': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'kino': {'n_is_nc': '', 'n_is_sth': ''},
 'kinsman': {'n_is_nc': '', 'n_is_sb': '0'},
 'kiosk': {'n_is_nc': '', 'n_is_sth': ''},
 'kip': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'kipper': {'n_is_nc': '', 'n_is_sth': ''},
 'kisser': {'n_is_nc': '', 'n_is_sb': '0'},
 'kit': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'vb_to_vbz': 'kits', 'vb_to_vbd': 'kitted', 'vb_to_vbn': 'kitted', 'vb_to_vbg': 'kitting', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'kitchener': {'n_is_nc': '', 'n_is_sb': '0'},
 'kitchenware': {'n_is_nc': '', 'n_is_sth': ''},
 'kite': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'kitten': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'kitty': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'kiwi': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'klutz': {'n_is_nc': '', 'n_is_sb': '0'},
 'knapsack': {'n_is_nc': '', 'n_is_sth': ''},
 'knave': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'kneecap': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'knell': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'knickerbockers': {'n_is_nc': '', 'n_is_sth': ''},
 'knickers': {'n_is_nc': '', 'n_is_sth': ''},
 'knighthood': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'knit': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbd_eq_vbn': ''},
 'knitter': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'knob': {'n_is_nc': '', 'n_is_sth': ''},
 'knockdown': {'n_is_nc': '', 'n_is_sth': ''},
 'knocker': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'knockout': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'knoll': {'n_is_nc': '', 'n_is_sth': ''},
 'knuckle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'knucklehead': {'n_is_nc': '', 'n_is_sb': '0'},
 'kola': {'n_is_nc': '', 'n_is_sth': ''},
 'kook': {'n_is_nc': '', 'n_is_sb': '0'},
 'koruna': {'n_is_nc': '', 'n_is_sth': ''},
 'kowtow': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'kraal': {'n_is_nc': '', 'n_is_sth': ''},
 'kraft': {'n_is_nc': '', 'n_is_sth': ''},
 'kraut': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'krill': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'krona': {'n_is_nc': '', 'n_is_sth': ''},
 'krone': {'n_is_nc': '', 'n_is_sth': ''},
 'kumquat': {'n_is_nc': '', 'n_is_sth': ''},
 'laborer': {'n_is_nc': '', 'n_is_sb': '0'},
 'labour': {'n_is_nc': '', 'n_is_sb': '2', 'v_to_vb': '', 'v_to_vbg': '', 'vdo': '', 'v_on': '', 'v_at': '', 'vb_to_vbz': 'labours', 'vb_to_vbd': 'laboured', 'vb_to_vbn': 'laboured', 'vb_to_vbg': 'labouring', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'labyrinth': {'n_is_nc': '', 'n_is_sth': ''},
 'lace': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'laceration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'lacewing': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'lackey': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'lacquerware': {'n_is_nc': '', 'n_is_sth': ''},
 'lactobacillus': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'laddie': {'n_is_nc': '', 'n_is_sb': '0'},
 'ladle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'lady-in-waiting': {'n_is_nc': '', 'n_is_sb': '0'},
 'lady-slipper': {'n_is_nc': '', 'n_is_sth': ''},
 'ladybird': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'ladybug': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'ladyship': {'n_is_nc': '', 'n_is_sth': ''},
 'lag': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'laggard': {'n_is_nc': '', 'n_is_sb': '0'},
 'lagoon': {'n_is_nc': '', 'n_is_sth': ''},
 'lair': {'n_is_nc': '', 'n_is_sth': ''},
 'laird': {'n_is_nc': '', 'n_is_sb': '0'},
 'laity': {'n_is_nc': '', 'n_is_sb': '0'},
 'lakefront': {'n_is_nc': '', 'n_is_sth': ''},
 'lakeside': {'n_is_nc': '', 'n_is_sth': ''},
 'lama': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'lamb': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'vb_to_vbz': 'lambs', 'vb_to_vbd': 'lambed', 'vb_to_vbn': 'lambed', 'vb_to_vbg': 'lambing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'lambskin': {'n_is_nc': '', 'n_is_sth': ''},
 'lament': {'n_is_nc': '', 'n_is_sth': '', 'v_infcl_non': ''},
 'lamentation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'lamination': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'lampshade': {'n_is_nc': '', 'n_is_sth': ''},
 'lan': {'n_is_nc': '', 'n_is_sth': ''},
 'lanai': {'n_is_nc': '', 'n_is_sth': ''},
 'lance': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'landau': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'landholder': {'n_is_nc': '', 'n_is_sb': '0'},
 'landing': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'land', 'vbg_to_vbn': 'landed'},
 'landlady': {'n_is_nc': '', 'n_is_sb': '0'},
 'landmass': {'n_is_nc': '', 'n_is_sth': ''},
 'landowner': {'n_is_nc': '', 'n_is_sb': '0'},
 'landslide': {'n_is_nc': '', 'n_is_sth': ''},
 'landsman': {'n_is_nc': '', 'n_is_sb': '0'},
 'langoustine': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'lantern': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'lapdog': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'lapel': {'n_is_nc': '', 'n_is_sth': ''},
 'lapse': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'larceny': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'larch': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'lariat': {'n_is_nc': '', 'n_is_sth': ''},
 'lark': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'larynx': {'n_is_nc': '', 'n_is_sth': ''},
 'lash': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'lasher': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'lashing': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'lashings': {'n_is_nc': '', 'n_is_sth': ''},
 'lassie': {'n_is_nc': '', 'n_is_sb': '0'},
 'lasso': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'latch': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'lathe': {'n_is_nc': '', 'n_is_sth': ''},
 'latitude': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'latke': {'n_is_nc': '', 'n_is_sth': ''},
 'latrine': {'n_is_nc': '', 'n_is_sth': ''},
 'lattice': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'laughingstock': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'laughter': {'n_is_nc': '', 'n_is_sth': '', 'nu_typical': ''},
 'launcher': {'n_is_nc': '', 'n_is_sth': ''},
 'launching': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'launch', 'vbg_to_vbn': 'launched'},
 'laundry': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'laurel': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'lav': {'n_is_nc': '', 'n_is_sth': ''},
 'lava': {'n_is_nc': '', 'n_is_sth': ''},
 'lavatory': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'lawsuit': {'n_is_nc': '', 'n_is_sth': ''},
 'laxative': {'n_is_nc': '', 'n_is_sth': ''},
 'layette': {'n_is_nc': '', 'n_is_sth': ''},
 'layman': {'n_is_nc': '', 'n_is_sb': '0'},
 'layoff': {'n_is_nc': '', 'n_is_sth': ''},
 'layout': {'n_is_nc': '', 'n_is_sth': ''},
 'lazybones': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'leadership': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'leaflet': {'n_is_nc': '', 'n_is_sth': ''},
 'leak': {'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'leakage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'leap': {'n_is_nc': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': '', 'n_is_sth': '0'},
 'learner': {'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'learn'},
 'leaseholder': {'n_is_nc': '', 'n_is_sb': '0'},
 'leash': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'leave': {'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_for': '', 'vb_to_vbz': 'leaves', 'vb_to_vbd': 'left', 'vb_to_vbn': 'left', 'vb_to_vbg': 'leaving', 'vt_typical': '', 'v_compcl_non': ''},
 'leave-taking': {'n_is_nc': '', 'n_is_sth': ''},
 'lech': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'lechery': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'lector': {'n_is_nc': '', 'n_is_sb': '0'},
 'lecturer': {'n_is_nc': '', 'n_is_sb': '0'},
 'ledge': {'n_is_nc': '', 'n_is_sth': ''},
 'ledger': {'n_is_nc': '', 'n_is_sth': ''},
 'lee': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'leech': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'leek': {'n_is_nc': '', 'n_is_sth': ''},
 'leer': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'lees': {'n_is_nc': '', 'n_is_sth': ''},
 'left-hander': {'n_is_nc': '', 'n_is_sb': '0'},
 'leftist': {'n_is_nc': '', 'n_is_sb': '0'},
 'leftover': {'n_is_nc': '', 'n_is_sth': ''},
 'leftovers': {'n_is_nc': '', 'n_is_sth': ''},
 'lefty': {'n_is_nc': '', 'n_is_sb': '0'},
 'legate': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'legation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'legging': {'n_is_nc': '', 'n_is_sth': ''},
 'leghorn': {'n_is_nc': '', 'n_is_sth': ''},
 'legion': {'n_is_nc': '', 'n_is_sth': ''},
 'legislator': {'n_is_nc': '', 'n_is_sb': '0'},
 'legislature': {'n_is_nc': '', 'n_is_sth': ''},
 'legume': {'n_is_nc': '', 'n_is_sth': ''},
 'lei': {'n_is_nc': '', 'n_is_sth': ''},
 'lemma': {'n_is_nc': '', 'n_is_sth': ''},
 'lemonade': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'lender': {'n_is_nc': '', 'n_is_sb': '0'},
 'lenity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'lens': {'n_is_nc': '', 'n_is_sth': ''},
 'lentil': {'n_is_nc': '', 'n_is_sth': ''},
 'leopard': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'leotard': {'n_is_nc': '', 'n_is_sth': ''},
 'leprechaun': {'n_is_nc': '', 'n_is_sb': '0'},
 'lesion': {'n_is_nc': '', 'n_is_sth': ''},
 'lessee': {'n_is_nc': '', 'n_is_sb': '0'},
 'lessor': {'n_is_nc': '', 'n_is_sb': '0'},
 'let': {'n_is_nc': '', 'n_is_sth': '', 'v_n_vb': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'v_on': '', 'v_about': '', 'v_vb': '', 'vb_to_vbz': 'lets', 'vb_to_vbg': 'leting', 'vbn_to_vbg': 'leting', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'letdown': {'n_is_nc': '', 'n_is_sth': ''},
 'letterpress': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'leu': {'n_is_nc': '', 'n_is_sth': ''},
 'leukocyte': {'n_is_nc': '', 'n_is_sth': ''},
 'levee': {'n_is_nc': '', 'n_is_sth': ''},
 'lever': {'n_is_nc': '', 'n_is_sth': ''},
 'leviathan': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'levy': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vbg_non': ''},
 'lexicon': {'n_is_nc': '', 'n_is_sth': ''},
 'liana': {'n_is_nc': '', 'n_is_sth': ''},
 'libation': {'n_is_nc': '', 'n_is_sth': ''},
 'libel': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'liberator': {'n_is_nc': '', 'n_is_sb': '0'},
 'libertine': {'n_is_nc': '', 'n_is_sb': '0'},
 'liberty': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'liberalize', 'nn_to_jj': 'liberal'},
 'libido': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'librettist': {'n_is_nc': '', 'n_is_sb': '0'},
 'licence': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'licensed', 'vb_to_jj': 'licensed'},
 'lick': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_of': '', 'vb_to_vbz': 'licks', 'vb_to_vbd': 'licked', 'vb_to_vbn': 'licked', 'vb_to_vbg': 'licking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'liege': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'lien': {'n_is_nc': '', 'n_is_sth': ''},
 'lieutenant': {'n_is_nc': '', 'n_is_sb': '0'},
 'lifeboat': {'n_is_nc': '', 'n_is_sth': ''},
 'lifeguard': {'n_is_nc': '', 'n_is_sb': '0'},
 'lifeline': {'n_is_nc': '', 'n_is_sth': ''},
 'lifer': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'lifter': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'ligament': {'n_is_nc': '', 'n_is_sth': ''},
 'light': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_to_vbz': 'lights', 'vb_to_vbd': 'lighted', 'vb_to_vbn': 'lighted', 'vb_to_vbg': 'lighting', 'jj_to_jjr': 'lighter', 'jj_to_jjs': 'lightest'},
 'light-year': {'n_is_nc': '', 'n_is_sth': ''},
 'lighter': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'lighthouse': {'n_is_nc': '', 'n_is_sth': ''},
 'likeness': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'lilliputian': {'n_is_nc': '', 'n_is_sb': '0'},
 'lilt': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'liman': {'n_is_nc': '', 'n_is_sth': ''},
 'limb': {'n_is_nc': '', 'n_is_sth': ''},
 'limber': {'n_is_nc': '', 'n_is_sth': ''},
 'limeade': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'limestone': {'n_is_nc': '', 'n_is_sth': ''},
 'limitation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'limit', 'nn_to_jj': 'limited'},
 'limousine': {'n_is_nc': '', 'n_is_sth': ''},
 'linchpin': {'n_is_nc': '', 'n_is_sth': ''},
 'linden': {'n_is_nc': '', 'n_is_sth': ''},
 'lineage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'liner': {'n_is_nc': '', 'n_is_sth': ''},
 'linesman': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'lingo': {'n_is_nc': '', 'n_is_sth': ''},
 'lingua': {'n_is_nc': '', 'n_is_sth': ''},
 'linguistics': {'n_is_nc': '', 'n_is_sth': '0'},
 'lining': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'linkage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'linkup': {'n_is_nc': '', 'n_is_sth': ''},
 'linseed': {'n_is_nc': '', 'n_is_sth': ''},
 'lintel': {'n_is_nc': '', 'n_is_sth': ''},
 'lioness': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'lip': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'lipstick': {'n_is_nc': '', 'n_is_sth': ''},
 'liquidation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'lira': {'n_is_nc': '', 'n_is_sth': ''},
 'lisp': {'n_is_nc': '', 'n_is_sth': ''},
 'listener': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'listing': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'list', 'vbg_to_vbn': 'listed'},
 'litchi': {'n_is_nc': '', 'n_is_sth': ''},
 'liter': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'literal': {'n_is_nc': '', 'n_is_sth': ''},
 'literati': {'n_is_nc': '', 'n_is_sb': '0'},
 'litigant': {'n_is_nc': '', 'n_is_sb': '0'},
 'litter': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': ''},
 'littoral': {'n_is_nc': '', 'n_is_sth': ''},
 'livery': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'livestock': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'lizard': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'loach': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'loafer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'loaner': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'lobbyist': {'n_is_nc': '', 'n_is_sb': '0'},
 'lobe': {'n_is_nc': '', 'n_is_sth': ''},
 'lobelia': {'n_is_nc': '', 'n_is_sth': ''},
 'loblolly': {'n_is_nc': '', 'n_is_sth': ''},
 'lobster': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'locale': {'n_is_nc': '', 'n_is_sth': ''},
 'locality': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'loch': {'n_is_nc': '', 'n_is_sth': ''},
 'locker': {'n_is_nc': '', 'n_is_sth': ''},
 'lockout': {'n_is_nc': '', 'n_is_sth': ''},
 'locksmith': {'n_is_nc': '', 'n_is_sb': '0'},
 'lockup': {'n_is_nc': '', 'n_is_sth': ''},
 'locomotive': {'n_is_nc': '', 'n_is_sth': ''},
 'locus': {'n_is_nc': '', 'n_is_sth': ''},
 'locust': {'n_is_nc': '', 'n_is_sb': '3', 'nc_typical': '', 'n_is_sth': '3'},
 'locution': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'lode': {'n_is_nc': '', 'n_is_sth': ''},
 'lodestone': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'lodge': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'lodger': {'n_is_nc': '', 'n_is_sb': '0'},
 'lodging': {'n_is_nc': '', 'n_is_sth': ''},
 'lodgings': {'n_is_nc': '', 'n_is_sth': ''},
 'loft': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'logbook': {'n_is_nc': '', 'n_is_sth': ''},
 'loge': {'n_is_nc': '', 'n_is_sth': ''},
 'logger': {'n_is_nc': '', 'n_is_sb': '0'},
 'loggerhead': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': ''},
 'logistics': {'n_is_nc': '', 'n_is_sth': ''},
 'logjam': {'n_is_nc': '', 'n_is_sth': ''},
 'logotype': {'n_is_nc': '', 'n_is_sth': ''},
 'lohan': {'n_is_nc': '', 'n_is_sb': '0'},
 'loin': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'loins': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'lollipop': {'n_is_nc': '', 'n_is_sth': ''},
 'lombard': {'n_is_nc': '', 'n_is_sb': '0'},
 'longitude': {'n_is_nc': '', 'n_is_sth': ''},
 'look': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'looking', 'v_compcl': '', 'v_to_vbg': '', 'nsubjpass': '', 'vbe': '', 'vdo': '', 'v_on': '', 'v_at': '', 'v_in': '', 'v_about': '', 'v_for': '', 'vb_to_vbz': 'looks', 'vb_to_vbd': 'looked', 'vb_to_vbn': 'looked', 'vb_to_jj': 'looking', 'vb_to_vbg': 'looking', 'vi_typical': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'looker': {'n_is_nc': '', 'n_is_sb': '0'},
 'lookout': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'loom': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'loon': {'n_is_nc': '', 'n_is_sb': '0'},
 'loop': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'loophole': {'n_is_nc': '', 'n_is_sth': ''},
 'loquat': {'n_is_nc': '', 'n_is_sth': ''},
 'lordship': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'lot': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_of_nn': '', 'n_of_nns': ''},
 'loudspeaker': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'lough': {'n_is_nc': '', 'n_is_sth': ''},
 'lout': {'n_is_nc': '', 'n_is_sb': '0'},
 'lovelace': {'n_is_nc': '', 'n_is_sb': '0'},
 'lovely': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2', 'jj_to_jjr': 'lovelier', 'jj_to_jjs': 'loveliest'},
 'lowland': {'n_is_nc': '', 'n_is_sth': ''},
 'lowness': {'n_is_nc': '', 'n_is_sth': ''},
 'loyalist': {'n_is_nc': '', 'n_is_sb': '0'},
 'lozenge': {'n_is_nc': '', 'n_is_sth': ''},
 'lp': {'n_is_nc': '', 'n_is_sth': ''},
 'lubricant': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'lucifer': {'n_is_nc': '', 'n_is_sb': '0'},
 'lug': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'luge': {'n_is_nc': '', 'n_is_sth': ''},
 'lull': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'lullaby': {'n_is_nc': '', 'n_is_sth': ''},
 'lumber': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'luminary': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'luminosity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'lummox': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'lunatic': {'n_is_nc': '', 'n_is_sb': '0'},
 'luncheon': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'lunge': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'lungfish': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'lunkhead': {'n_is_nc': '', 'n_is_sb': '0'},
 'lunt': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'luo': {'n_is_nc': '', 'n_is_sb': '0', 'n_is_sth': ''},
 'lurch': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'lush': {'n_is_nc': '', 'n_is_sb': '0', 'jj_to_jjr': 'lusher', 'jj_to_jjs': 'lushest'},
 'lust': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'lute': {'n_is_nc': '', 'n_is_sth': ''},
 'lyceum': {'n_is_nc': '', 'n_is_sth': ''},
 'lymphocyte': {'n_is_nc': '', 'n_is_sth': ''},
 'lymphoma': {'n_is_nc': '', 'n_is_sth': ''},
 'lynchpin': {'n_is_nc': '', 'n_is_sth': ''},
 'lynx': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'lyre': {'n_is_nc': '', 'n_is_sth': ''},
 'lyric': {'n_is_nc': '', 'n_is_sth': ''},
 'ma': {'n_is_nc': '', 'n_is_sb': '0'},
 'macaque': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'macedonian': {'n_is_nc': '', 'n_is_sb': '0'},
 'machination': {'n_is_nc': '', 'n_is_sth': ''},
 'machinist': {'n_is_nc': '', 'n_is_sb': '0'},
 'mack': {'n_is_nc': '', 'n_is_sth': ''},
 'mackerel': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'mackintosh': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'macrocosm': {'n_is_nc': '', 'n_is_sth': ''},
 'macula': {'n_is_nc': '', 'n_is_sth': ''},
 'madame': {'n_is_nc': '', 'n_is_sb': '0'},
 'mademoiselle': {'n_is_nc': '', 'n_is_sb': '0'},
 'madhouse': {'n_is_nc': '', 'n_is_sth': ''},
 'madman': {'n_is_nc': '', 'n_is_sb': '0'},
 'madrigal': {'n_is_nc': '', 'n_is_sth': ''},
 'maelstrom': {'n_is_nc': '', 'n_is_sth': ''},
 'mafia': {'n_is_nc': '', 'n_is_sb': '0', 'nn_eq_nns': ''},
 'maggot': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'magician': {'n_is_nc': '', 'n_is_sb': '0'},
 'magistrate': {'n_is_nc': '', 'n_is_sb': '0'},
 'magnate': {'n_is_nc': '', 'n_is_sb': '0'},
 'magnet': {'n_is_nc': '', 'n_is_sth': ''},
 'magnetometer': {'n_is_nc': '', 'n_is_sth': ''},
 'magnificat': {'n_is_nc': '', 'n_is_sth': ''},
 'magnification': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'magnifico': {'n_is_nc': '', 'n_is_sb': '0'},
 'magnifier': {'n_is_nc': '', 'n_is_sth': ''},
 'magnitude': {'n_is_nc': '', 'n_is_sth': ''},
 'magpie': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': ''},
 'maharani': {'n_is_nc': '', 'n_is_sb': '0'},
 'mahatma': {'n_is_nc': '', 'n_is_sb': '0'},
 'mahdi': {'n_is_nc': '', 'n_is_sb': '0'},
 'mahogany': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'maid': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'maiden': {'n_is_nc': '', 'n_is_sb': '0'},
 'maidservant': {'n_is_nc': '', 'n_is_sb': '0'},
 'mailbag': {'n_is_nc': '', 'n_is_sth': ''},
 'mailbox': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'mailer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'mailing': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'mail', 'vbg_to_vbn': 'mailed'},
 'maillot': {'n_is_nc': '', 'n_is_sth': ''},
 'mainframe': {'n_is_nc': '', 'n_is_sth': ''},
 'mainland': {'n_is_nc': '', 'n_is_sth': ''},
 'mainstream': {'n_is_nc': '', 'n_is_sth': ''},
 'major-domo': {'n_is_nc': '', 'n_is_sb': '0'},
 'makeover': {'n_is_nc': '', 'n_is_sth': ''},
 'maker': {'n_is_nc': '', 'n_is_sb': '0'},
 'makeshift': {'n_is_nc': '', 'n_is_sth': ''},
 'malady': {'n_is_nc': '', 'n_is_sth': ''},
 'malcontent': {'n_is_nc': '', 'n_is_sb': '0'},
 'malefactor': {'n_is_nc': '', 'n_is_sb': '0'},
 'malformation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'malfunction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'malignancy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'malignity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'mallard': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'mallet': {'n_is_nc': '', 'n_is_sth': ''},
 'mallow': {'n_is_nc': '', 'n_is_sth': ''},
 'malpractice': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'mama': {'n_is_nc': '', 'n_is_sb': '0'},
 'mamma': {'n_is_nc': '', 'n_is_sb': '0'},
 'mammal': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'mammoth': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'mammy': {'n_is_nc': '', 'n_is_sb': '0'},
 'man-of-war': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'manatee': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'manchu': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'mandamus': {'n_is_nc': '', 'n_is_sth': ''},
 'mandatory': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'mandible': {'n_is_nc': '', 'n_is_sth': ''},
 'mandolin': {'n_is_nc': '', 'n_is_sth': ''},
 'mandrill': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'mane': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'maneuver': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'manger': {'n_is_nc': '', 'n_is_sth': ''},
 'mango': {'n_is_nc': '', 'n_is_sth': ''},
 'mangrove': {'n_is_nc': '', 'n_is_sth': ''},
 'manhole': {'n_is_nc': '', 'n_is_sth': ''},
 'manhunt': {'n_is_nc': '', 'n_is_sth': ''},
 'maniac': {'n_is_nc': '', 'n_is_sb': '0'},
 'manifest': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'manifestation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'manifold': {'n_is_nc': '', 'n_is_sth': ''},
 'manipulator': {'n_is_nc': '', 'n_is_sb': '0'},
 'mankind': {'n_is_nu': '', 'n_is_sb': '0', 'nu_typical': ''},
 'mannerism': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'manor': {'n_is_nc': '', 'n_is_sth': ''},
 'mansard': {'n_is_nc': '', 'n_is_sth': ''},
 'manta': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'mantel': {'n_is_nc': '', 'n_is_sth': ''},
 'mantelpiece': {'n_is_nc': '', 'n_is_sth': ''},
 'mantis': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'mantle': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'mantra': {'n_is_nc': '', 'n_is_sth': ''},
 'manufactory': {'n_is_nc': '', 'n_is_sth': ''},
 'manufacture': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'manufacturing', 'vb_to_jj': 'manufacturing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'manus': {'n_is_nc': '', 'n_is_sth': ''},
 'manuscript': {'n_is_nc': '', 'n_is_sth': ''},
 'maple': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'mapping': {'n_is_nc': '', 'n_is_sth': ''},
 'marathon': {'n_is_nc': '', 'n_is_sth': ''},
 'marble': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'marbles': {'n_is_nc': '', 'n_is_sth': ''},
 'march': {'n_is_nc': '', 'n_is_nu': '', 'nn_to_jj': 'marching', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'vb_to_vbz': 'marches', 'vb_to_vbd': 'marched', 'vb_to_vbn': 'marched', 'vb_to_jj': 'marching', 'vb_to_vbg': 'marching', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'mare': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'marginalia': {'n_is_nc': '', 'n_is_sth': ''},
 'margrave': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'marigold': {'n_is_nc': '', 'n_is_sth': ''},
 'mariner': {'n_is_nc': '', 'n_is_sb': '0'},
 'marionette': {'n_is_nc': '', 'n_is_sth': ''},
 'marker': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'marking': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'mark', 'vbg_to_vbn': 'marked'},
 'markka': {'n_is_nc': '', 'n_is_sth': ''},
 'marksman': {'n_is_nc': '', 'n_is_sb': '0'},
 'markup': {'n_is_nc': '', 'n_is_sth': ''},
 'marmite': {'n_is_nc': '', 'n_is_sth': ''},
 'marmot': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'marquess': {'n_is_nc': '', 'n_is_sb': '0'},
 'marquis': {'n_is_nc': '', 'n_is_sb': '0'},
 'marquise': {'n_is_nc': '', 'n_is_sb': '0'},
 'marrow': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'marsh': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'marshal': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'mart': {'n_is_nc': '', 'n_is_sth': ''},
 'marten': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '3', 'n_is_sth': ''},
 'martin': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'martingale': {'n_is_nc': '', 'n_is_sth': ''},
 'martyr': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'mascot': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'mask': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'vt_typical': '', 'nc_typical': ''},
 'mason': {'n_is_nc': '', 'n_is_sb': '0'},
 'masque': {'n_is_nc': '', 'n_is_sth': ''},
 'masquerade': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'massacre': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'massage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'masses': {'n_is_nc': '', 'n_is_sth': ''},
 'masseur': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'massif': {'n_is_nc': '', 'n_is_sth': ''},
 'mast': {'n_is_nc': '', 'n_is_sth': ''},
 'mastermind': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'masterpiece': {'n_is_nc': '', 'n_is_sth': ''},
 'masthead': {'n_is_nc': '', 'n_is_sth': ''},
 'mastiff': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'mastodon': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'mat': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'matchmaker': {'n_is_nc': '', 'n_is_sb': '0'},
 'matchstick': {'n_is_nc': '', 'n_is_sth': ''},
 'mate': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'mater': {'n_is_nc': '', 'n_is_sb': '0'},
 'materiality': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'maternity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'math': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'matinee': {'n_is_nc': '', 'n_is_sth': ''},
 'matriarchy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'matron': {'n_is_nc': '', 'n_is_sb': '0'},
 'matter': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'matters', 'vb_to_vbd': 'mattered', 'vb_to_vbn': 'mattered', 'vb_to_vbg': 'mattering', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'vi_typical': ''},
 'mattress': {'n_is_nc': '', 'n_is_sth': ''},
 'mauser': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'mausoleum': {'n_is_nc': '', 'n_is_sth': ''},
 'maven': {'n_is_nc': '', 'n_is_sb': '0'},
 'mavin': {'n_is_nc': '', 'n_is_sb': '0'},
 'maw': {'n_is_nc': '', 'n_is_sth': ''},
 'max': {'n_is_nc': '', 'n_is_sth': ''},
 'maxilla': {'n_is_nc': '', 'n_is_sth': ''},
 'maxim': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'mayfly': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'maze': {'n_is_nc': '', 'n_is_sth': ''},
 'meadow': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'meander': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'meany': {'n_is_nc': '', 'n_is_sb': '0'},
 'measurement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'measure', 'nn_to_jj': 'measurable'},
 'measuring': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'measure', 'vbg_to_vbn': 'measured'},
 'meatball': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'mechanism': {'n_is_nc': '', 'n_is_sth': ''},
 'med': {'n_is_nc': '', 'n_is_sth': '', 'jj_ed': ''},
 'median': {'n_is_nc': '', 'n_is_sth': ''},
 'mediastinum': {'n_is_nc': '', 'n_is_sth': ''},
 'mediator': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'medic': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'medicine': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'medico': {'n_is_nc': '', 'n_is_sb': '0'},
 'medlar': {'n_is_nc': '', 'n_is_sth': ''},
 'medley': {'n_is_nc': '', 'n_is_sth': ''},
 'medusa': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'meed': {'n_is_nc': '', 'n_is_sth': ''},
 'meet': {'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_with': '', 'vb_to_vbz': 'meets', 'vb_to_vbd': 'met', 'vb_to_vbn': 'met', 'vb_to_vbg': 'meeting', 'v_compcl_non': '', 'v_prprtcl_non': '', 'nc_typical': ''},
 'meetinghouse': {'n_is_nc': '', 'n_is_sth': ''},
 'megahertz': {'n_is_nc': '', 'n_is_sth': ''},
 'megaphone': {'n_is_nc': '', 'n_is_sth': ''},
 'megawatt': {'n_is_nc': '', 'n_is_sth': ''},
 'meld': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'melee': {'n_is_nc': '', 'n_is_sth': ''},
 'melody': {'n_is_nc': '', 'n_is_sth': ''},
 'meltdown': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'membrane': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'memento': {'n_is_nc': '', 'n_is_sth': ''},
 'memoir': {'n_is_nc': '', 'n_is_sth': ''},
 'memorabilia': {'n_is_nc': '', 'n_is_sth': ''},
 'menace': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'menagerie': {'n_is_nc': '', 'n_is_sth': ''},
 'mend': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'menial': {'n_is_nc': '', 'n_is_sb': '0'},
 'meninges': {'n_is_nc': '', 'n_is_sth': ''},
 'menses': {'n_is_nc': '', 'n_is_sth': ''},
 'menstruation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'mentality': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'mental', 'nn_to_rb': 'mentally'},
 'mention': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'mentioned', 'v_compcl': '', 'v_vbg': '', 'v_n': '', 'v_n_n': '', 'v_n_to_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'mentions', 'vb_to_vbd': 'mentioned', 'vb_to_vbn': 'mentioned', 'vb_to_jj': 'mentioned', 'vb_to_vbg': 'mentioning', 'vt_typical': '', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'mentor': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'merchandiser': {'n_is_nc': '', 'n_is_sb': '0'},
 'mercurochrome': {'n_is_nc': '', 'n_is_sth': ''},
 'mercy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'merciful', 'nn_to_rb': 'mercifully'},
 'merger': {'n_is_nc': '', 'n_is_sth': ''},
 'meridian': {'n_is_nc': '', 'n_is_sth': ''},
 'merit': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'mermaid': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'merry-go-round': {'n_is_nc': '', 'n_is_sth': ''},
 'mesa': {'n_is_nc': '', 'n_is_sth': ''},
 'mesh': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'meson': {'n_is_nc': '', 'n_is_sth': ''},
 'mess-up': {'n_is_nc': '', 'n_is_sth': ''},
 'messenger': {'n_is_nc': '', 'n_is_sb': '0'},
 'mestizo': {'n_is_nc': '', 'n_is_sb': '0'},
 'metabolism': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'metacarpal': {'n_is_nc': '', 'n_is_sth': ''},
 'metal': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'metaphor': {'n_is_nc': '', 'n_is_sth': ''},
 'metasequoia': {'n_is_nc': '', 'n_is_sth': ''},
 'metastasis': {'n_is_nc': '', 'n_is_sth': ''},
 'mete': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'meteor': {'n_is_nc': '', 'n_is_sth': ''},
 'meteorite': {'n_is_nc': '', 'n_is_sth': ''},
 'meter': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': '', 'n_is_unit': 'length', 'quantifier': ''},
 'methodology': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'metronome': {'n_is_nc': '', 'n_is_sth': ''},
 'metropolis': {'n_is_nc': '', 'n_is_sth': ''},
 'mew': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'mews': {'n_is_nc': '', 'n_is_sth': ''},
 'mezzanine': {'n_is_nc': '', 'n_is_sth': ''},
 'mezzo': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'mezzo-soprano': {'n_is_nc': '', 'n_is_sb': '0'},
 'miao': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'miasma': {'n_is_nc': '', 'n_is_sth': ''},
 'microbe': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'microcomputer': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'microcosm': {'n_is_nc': '', 'n_is_sth': ''},
 'microfiche': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'micrometer': {'n_is_nc': '', 'n_is_sth': '', 'quantifier': ''},
 'micron': {'n_is_nc': '', 'n_is_sth': ''},
 'microorganism': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': ''},
 'microphone': {'n_is_nc': '', 'n_is_sth': ''},
 'microprocessor': {'n_is_nc': '', 'n_is_sth': ''},
 'microscope': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'microsecond': {'n_is_nc': '', 'n_is_sth': ''},
 'microwave': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'midden': {'n_is_nc': '', 'n_is_sth': ''},
 'middleman': {'n_is_nc': '', 'n_is_sb': '0'},
 'midge': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'midget': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'midline': {'n_is_nc': '', 'n_is_sth': ''},
 'midpoint': {'n_is_nc': '', 'n_is_sth': ''},
 'midriff': {'n_is_nc': '', 'n_is_sth': ''},
 'midterm': {'n_is_nc': '', 'n_is_sth': ''},
 'midwife': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'mien': {'n_is_nc': '', 'n_is_sth': ''},
 'migraine': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'migration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'migrate', 'nn_to_jj': 'migrant'},
 'mikado': {'n_is_nc': '', 'n_is_sb': '0'},
 'milady': {'n_is_nc': '', 'n_is_sb': '0'},
 'mileage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'milepost': {'n_is_nc': '', 'n_is_sth': ''},
 'milestone': {'n_is_nc': '', 'n_is_sth': ''},
 'milieu': {'n_is_nc': '', 'n_is_sth': ''},
 'militarist': {'n_is_nc': '', 'n_is_sb': '0'},
 'militia': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_collective': '', 'n_is_sth': '2'},
 'militiaman': {'n_is_nc': '', 'n_is_sb': '0'},
 'milk': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'milky', 'v_n': '', 'nsubjpass': '', 'vb_to_jj': 'milky', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'nu_typical': ''},
 'milker': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'mill': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'milled', 'vb_to_jj': 'milled', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'milliliter': {'n_is_nc': '', 'n_is_sth': ''},
 'millimeter': {'n_is_nc': '', 'n_is_sth': '', 'quantifier': ''},
 'millisecond': {'n_is_nc': '', 'n_is_sth': ''},
 'millstone': {'n_is_nc': '', 'n_is_sth': ''},
 'milord': {'n_is_nc': '', 'n_is_sb': '0'},
 'mime': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'mimeograph': {'n_is_nc': '', 'n_is_sth': ''},
 'mimic': {'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_infcl_non': '', 'n_is_sth': '2'},
 'mincer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'mind': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'minded', 'v_compcl': '', 'v_vbg': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'minds', 'vb_to_vbd': 'minded', 'vb_to_vbn': 'minded', 'vb_to_jj': 'minded', 'vb_to_vbg': 'minding', 'vbd_eq_vbn': ''},
 'minefield': {'n_is_nc': '', 'n_is_sth': ''},
 'miner': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'mini': {'n_is_nc': '', 'n_is_sth': ''},
 'miniature': {'n_is_nc': '', 'n_is_sth': ''},
 'minibus': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'minicomputer': {'n_is_nc': '', 'n_is_sth': ''},
 'minion': {'n_is_nc': '', 'n_is_sb': '0'},
 'miniskirt': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'mink': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'minstrel': {'n_is_nc': '', 'n_is_sb': '0'},
 'mint': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'minuteman': {'n_is_nc': '', 'n_is_sb': '0'},
 'minutia': {'n_is_nc': '', 'n_is_sth': ''},
 'mirage': {'n_is_nc': '', 'n_is_sth': ''},
 'misadventure': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'misapprehension': {'n_is_nc': '', 'n_is_sth': ''},
 'misbehavior': {'n_is_nc': '', 'n_is_sth': ''},
 'miscalculation': {'n_is_nc': '', 'n_is_sth': ''},
 'miscarriage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'miscellany': {'n_is_nc': '', 'n_is_sth': ''},
 'mischief': {'n_is_nc': '', 'n_is_sth': ''},
 'misconception': {'n_is_nc': '', 'n_is_sth': ''},
 'miscreant': {'n_is_nc': '', 'n_is_sb': '0'},
 'misdeed': {'n_is_nc': '', 'n_is_sth': ''},
 'misdemeanor': {'n_is_nc': '', 'n_is_sth': ''},
 'miser': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'misery': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'miserable', 'nn_to_rb': 'miserably'},
 'misfortune': {'n_is_nc': '', 'n_is_sth': ''},
 'mishap': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'misplay': {'n_is_nc': '', 'n_is_sth': ''},
 'misprint': {'n_is_nc': '', 'n_is_sth': ''},
 'miss': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'v_compcl': '', 'v_vbg': '', 'v_to_vbg': '', 'v_n': '', 'vdo': '', 'vb_to_vbz': 'misses', 'vb_to_vbd': 'missed', 'vb_to_vbn': 'missed', 'vb_to_nn': 'missing', 'vb_to_jj': 'missing', 'vb_to_vbg': 'missing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'nc_typical': ''},
 'missionary': {'n_is_nc': '', 'n_is_sb': '0'},
 'missive': {'n_is_nc': '', 'n_is_sth': ''},
 'misspelling': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'misstep': {'n_is_nc': '', 'n_is_sth': ''},
 'missus': {'n_is_nc': '', 'n_is_sb': '0'},
 'missy': {'n_is_nc': '', 'n_is_sb': '0'},
 'mist': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'mistress': {'n_is_nc': '', 'n_is_sb': '0'},
 'misunderstanding': {'n_is_nc': '', 'n_is_sth': ''},
 'misuse': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vb_to_rb': 'usefully', 'vb_to_jj': 'useful', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'mite': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'miter': {'n_is_nc': '', 'n_is_sth': ''},
 'mitt': {'n_is_nc': '', 'n_is_sth': ''},
 'mitten': {'n_is_nc': '', 'n_is_sth': ''},
 'mitzvah': {'n_is_nc': '', 'n_is_sth': ''},
 'mix': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'mixed', 'v_to_vbg': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'mixes', 'vb_to_vbd': 'mixed', 'vb_to_vbn': 'mixed', 'vb_to_nn': 'mixture', 'vb_to_jj': 'mixed', 'vb_to_vbg': 'mixing', 'vt_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'mixer': {'n_is_nc': '', 'n_is_sth': ''},
 'ml': {'n_is_nc': '', 'n_is_sth': ''},
 'mnemonic': {'n_is_nc': '', 'n_is_sth': ''},
 'moan': {'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'moat': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'mobster': {'n_is_nc': '', 'n_is_sb': '0'},
 'mock': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'moderator': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'modification': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'modify', 'nn_to_jj': 'modified'},
 'modifier': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'modulation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'module': {'n_is_nc': '', 'n_is_sth': ''},
 'mogul': {'n_is_nc': '', 'n_is_sb': '0'},
 'mola': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'molar': {'n_is_nc': '', 'n_is_sth': ''},
 'mold': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'mole': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'molecule': {'n_is_nc': '', 'n_is_sth': ''},
 'mollusk': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'moloch': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'mom': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'nc_typical': ''},
 'monarch': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'moneybag': {'n_is_nc': '', 'n_is_sth': ''},
 'monger': {'n_is_nc': '', 'n_is_sb': '0'},
 'mongol': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'mongoloid': {'n_is_nc': '', 'n_is_sb': '0'},
 'mongoose': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'mongrel': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'moniker': {'n_is_nc': '', 'n_is_sth': ''},
 'monk': {'n_is_nc': '', 'n_is_sb': '0'},
 'monkey': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'monkfish': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'monograph': {'n_is_nc': '', 'n_is_sth': ''},
 'monolith': {'n_is_nc': '', 'n_is_sth': ''},
 'monologue': {'n_is_nc': '', 'n_is_sth': ''},
 'monomer': {'n_is_nc': '', 'n_is_sth': ''},
 'monorail': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'monotone': {'n_is_nc': '', 'n_is_sth': ''},
 'monsieur': {'n_is_nc': '', 'n_is_sb': '0'},
 'monsoon': {'n_is_nc': '', 'n_is_sth': ''},
 'monstrosity': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'montage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'monument': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'moo': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'moocher': {'n_is_nc': '', 'n_is_sb': '0'},
 'moonbeam': {'n_is_nc': '', 'n_is_sth': ''},
 'moonflower': {'n_is_nc': '', 'n_is_sth': ''},
 'moor': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'moose': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'nn_eq_nns': ''},
 'mop': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'mope': {'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'moped': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'moppet': {'n_is_nc': '', 'n_is_sb': '0'},
 'moraine': {'n_is_nc': '', 'n_is_sth': ''},
 'morass': {'n_is_nc': '', 'n_is_sth': ''},
 'moratorium': {'n_is_nc': '', 'n_is_sth': ''},
 'moray': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'morel': {'n_is_nc': '', 'n_is_sth': ''},
 'mores': {'n_is_nc': '', 'n_is_sth': ''},
 'morn': {'n_is_nc': '', 'n_is_sth': ''},
 'moron': {'n_is_nc': '', 'n_is_sb': '0'},
 'morphology': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'morsel': {'n_is_nc': '', 'n_is_sth': ''},
 'mortal': {'n_is_nc': '', 'n_is_sb': '0'},
 'mortality': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'mortar': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'mortification': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'mortise': {'n_is_nc': '', 'n_is_sth': ''},
 'mortuary': {'n_is_nc': '', 'n_is_sth': ''},
 'mosaic': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'moslem': {'n_is_nc': '', 'n_is_sb': '0', 'n_is_sth': ''},
 'mosque': {'n_is_nc': '', 'n_is_sth': ''},
 'moss': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'mossback': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'mot': {'n_is_nc': '', 'n_is_sth': ''},
 'mote': {'n_is_nc': '', 'n_is_sth': ''},
 'moth': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'mothball': {'n_is_nc': '', 'n_is_sth': ''},
 'mother-in-law': {'n_is_nc': '', 'n_is_sb': '0'},
 'motherland': {'n_is_nc': '', 'n_is_sth': ''},
 'motif': {'n_is_nc': '', 'n_is_sth': ''},
 'motivation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'motivate', 'nn_to_jj': 'motive'},
 'motorboat': {'n_is_nc': '', 'n_is_sth': ''},
 'motorcade': {'n_is_nc': '', 'n_is_sth': ''},
 'motorcar': {'n_is_nc': '', 'n_is_sth': ''},
 'motorcycle': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'mountainside': {'n_is_nc': '', 'n_is_sth': ''},
 'mountie': {'n_is_nc': '', 'n_is_sb': '0'},
 'mounting': {'n_is_nc': '', 'n_is_sth': ''},
 'mourning': {'n_is_nc': '', 'n_is_sth': ''},
 'mousetrap': {'n_is_nc': '', 'n_is_sth': ''},
 'moustache': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'mouthpiece': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'movable': {'n_is_nc': '', 'n_is_sth': ''},
 'mow': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'mower': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'mp': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'muckraker': {'n_is_nc': '', 'n_is_sb': '0'},
 'mucosa': {'n_is_nc': '', 'n_is_sth': ''},
 'mudder': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'muddle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'muff': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'muffle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'muffler': {'n_is_nc': '', 'n_is_sth': ''},
 'mufti': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'mug': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': ''},
 'mugging': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'mugwort': {'n_is_nc': '', 'n_is_sth': ''},
 'mulatto': {'n_is_nc': '', 'n_is_sb': '0'},
 'mulberry': {'n_is_nc': '', 'n_is_sth': ''},
 'mule': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'mullet': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'multimedia': {'n_is_nc': '', 'n_is_sth': ''},
 'multiplier': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'mumble': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'mummy': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'municipality': {'n_is_nc': '', 'n_is_sth': ''},
 'munition': {'n_is_nc': '', 'n_is_sth': ''},
 'mural': {'n_is_nc': '', 'n_is_sth': ''},
 'murder': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'murderer': {'n_is_nc': '', 'n_is_sb': '0'},
 'murk': {'n_is_nc': '', 'n_is_sth': ''},
 'murmur': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'muscleman': {'n_is_nc': '', 'n_is_sb': '0'},
 'mush': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'musketeer': {'n_is_nc': '', 'n_is_sb': '0'},
 'muskmelon': {'n_is_nc': '', 'n_is_sth': ''},
 'muskrat': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'mussel': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'mustang': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'muster': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'mutant': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'mutation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'mute': {'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'n_is_sth': '2'},
 'mutiny': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'mutt': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'mutter': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'muzzle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'myth': {'n_is_nc': '', 'n_is_sth': ''},
 'mythology': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'nadir': {'n_is_nc': '', 'n_is_sth': ''},
 'nag': {'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'n_is_sth': '2'},
 'nameplate': {'n_is_nc': '', 'n_is_sth': ''},
 'nanny': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'nanometer': {'n_is_nc': '', 'n_is_sth': '', 'quantifier': ''},
 'nanosecond': {'n_is_nc': '', 'n_is_sth': ''},
 'nap': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'nape': {'n_is_nc': '', 'n_is_sth': ''},
 'napkin': {'n_is_nc': '', 'n_is_sth': ''},
 'nappy': {'n_is_nc': '', 'n_is_sth': ''},
 'narc': {'n_is_nc': '', 'n_is_sb': '0'},
 'narcissist': {'n_is_nc': '', 'n_is_sb': '0'},
 'narcotic': {'n_is_nc': '', 'n_is_sth': ''},
 'narration': {'n_is_nc': '', 'n_is_sth': ''},
 'narrator': {'n_is_nc': '', 'n_is_sb': '0'},
 'nasal': {'n_is_nc': '', 'n_is_sth': ''},
 'natatorium': {'n_is_nc': '', 'n_is_sth': ''},
 'nationalization': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'nativity': {'n_is_nc': '', 'n_is_sth': ''},
 'nature': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'natural', 'nn_to_rb': 'naturally'},
 'naught': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'naughty'},
 'nautilus': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'nave': {'n_is_nc': '', 'n_is_sth': ''},
 'navel': {'n_is_nc': '', 'n_is_sth': ''},
 'navigator': {'n_is_nc': '', 'n_is_sb': '0'},
 'nay': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'nazarene': {'n_is_nc': '', 'n_is_sb': '0'},
 'nebulizer': {'n_is_nc': '', 'n_is_sth': ''},
 'necessity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'necessary', 'nn_to_rb': 'necessarily'},
 'neckerchief': {'n_is_nc': '', 'n_is_sth': ''},
 'necklace': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'neckline': {'n_is_nc': '', 'n_is_sth': ''},
 'necktie': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'neckwear': {'n_is_nc': '', 'n_is_sth': ''},
 'necromancer': {'n_is_nc': '', 'n_is_sb': '0'},
 'necropolis': {'n_is_nc': '', 'n_is_sth': ''},
 'necropsy': {'n_is_nc': '', 'n_is_sth': ''},
 'necrosis': {'n_is_nc': '', 'n_is_sth': ''},
 'nectarine': {'n_is_nc': '', 'n_is_sth': ''},
 'negotiation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'neigh': {'n_is_nc': '', 'n_is_sth': ''},
 'neighborhood': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'nemesis': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'neologism': {'n_is_nc': '', 'n_is_sth': ''},
 'neophyte': {'n_is_nc': '', 'n_is_sb': '0'},
 'nepenthes': {'n_is_nc': '', 'n_is_sth': ''},
 'nerd': {'n_is_nc': '', 'n_is_sb': '0'},
 'nerve': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'ness': {'n_is_nc': '', 'n_is_sth': ''},
 'nestling': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'nestor': {'n_is_nc': '', 'n_is_sb': '0'},
 'net': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'netherworld': {'n_is_nc': '', 'n_is_sth': ''},
 'nettle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'neuron': {'n_is_nc': '', 'n_is_sth': ''},
 'neutrino': {'n_is_nc': '', 'n_is_sth': ''},
 'neutron': {'n_is_nc': '', 'n_is_sth': ''},
 'newbie': {'n_is_nc': '', 'n_is_sb': '0'},
 'newborn': {'n_is_nc': '', 'n_is_sb': '0'},
 'newcomer': {'n_is_nc': '', 'n_is_sb': '0'},
 'newlywed': {'n_is_nc': '', 'n_is_sb': '0', 'jj_ed': ''},
 'newsboy': {'n_is_nc': '', 'n_is_sb': '0'},
 'newsman': {'n_is_nc': '', 'n_is_sb': '0'},
 'newspaperman': {'n_is_nc': '', 'n_is_sb': '0'},
 'newsperson': {'n_is_nc': '', 'n_is_sb': '0'},
 'newsprint': {'n_is_nc': '', 'n_is_sth': ''},
 'newsreel': {'n_is_nc': '', 'n_is_sth': ''},
 'newsroom': {'n_is_nc': '', 'n_is_sth': ''},
 'newsstand': {'n_is_nc': '', 'n_is_sth': ''},
 'newt': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'nexus': {'n_is_nc': '', 'n_is_sth': ''},
 'nib': {'n_is_nc': '', 'n_is_sth': ''},
 'nibble': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'nicety': {'n_is_nc': '', 'n_is_sth': ''},
 'nick': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'nickel': {'n_is_nc': '', 'n_is_sth': ''},
 'nigger': {'n_is_nc': '', 'n_is_sb': '0'},
 'nightcap': {'n_is_nc': '', 'n_is_sth': ''},
 'nightclothes': {'n_is_nc': '', 'n_is_sth': ''},
 'nightgown': {'n_is_nc': '', 'n_is_sth': ''},
 'nighthawk': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'nightie': {'n_is_nc': '', 'n_is_sth': ''},
 'nightingale': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'nimbus': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'nincompoop': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'ninny': {'n_is_nc': '', 'n_is_sb': '0'},
 'nip': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'nipper': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'nipple': {'n_is_nc': '', 'n_is_sth': ''},
 'nisus': {'n_is_nc': '', 'n_is_sth': ''},
 'nit': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'nitride': {'n_is_nc': '', 'n_is_sth': ''},
 'nitwit': {'n_is_nc': '', 'n_is_sb': '0'},
 'nob': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'nobleman': {'n_is_nc': '', 'n_is_sb': '0'},
 'nocturne': {'n_is_nc': '', 'n_is_sth': ''},
 'nod': {'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_in': '', 'v_with': '', 'v_to': '', 'vb_to_vbz': 'nods', 'vb_to_vbd': 'nodded', 'vb_to_vbn': 'nodded', 'vb_to_vbg': 'nodding', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'node': {'n_is_nc': '', 'n_is_sth': ''},
 'nodule': {'n_is_nc': '', 'n_is_sth': ''},
 'nog': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'noggin': {'n_is_nc': '', 'n_is_sth': ''},
 'nomad': {'n_is_nc': '', 'n_is_sb': '0'},
 'nomination': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'nondescript': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'nonentity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'nonesuch': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'nonresident': {'n_is_nc': '', 'n_is_sb': '0'},
 'noodle': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'nook': {'n_is_nc': '', 'n_is_sth': ''},
 'noose': {'n_is_nc': '', 'n_is_sth': ''},
 'norm': {'n_is_nc': '', 'n_is_sth': ''},
 'northeaster': {'n_is_nc': '', 'n_is_sth': ''},
 'norther': {'n_is_nc': '', 'n_is_sth': ''},
 'northland': {'n_is_nc': '', 'n_is_sth': ''},
 'nosebleed': {'n_is_nc': '', 'n_is_sth': ''},
 'nosegay': {'n_is_nc': '', 'n_is_sth': ''},
 'nostril': {'n_is_nc': '', 'n_is_sth': ''},
 'nostrum': {'n_is_nc': '', 'n_is_sth': ''},
 'notary': {'n_is_nc': '', 'n_is_sb': '0'},
 'notation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'notch': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'notepad': {'n_is_nc': '', 'n_is_sth': ''},
 'notification': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'nought': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'noun': {'n_is_nc': '', 'n_is_sth': ''},
 'nova': {'n_is_nc': '', 'n_is_sth': ''},
 'novation': {'n_is_nc': '', 'n_is_sth': ''},
 'novelette': {'n_is_nc': '', 'n_is_sth': ''},
 'novella': {'n_is_nc': '', 'n_is_sth': ''},
 'novelty': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'novice': {'n_is_nc': '', 'n_is_sb': '0'},
 'novitiate': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'nozzle': {'n_is_nc': '', 'n_is_sth': ''},
 'nuance': {'n_is_nc': '', 'n_is_sth': ''},
 'nub': {'n_is_nc': '', 'n_is_sth': ''},
 'nucleus': {'n_is_nc': '', 'n_is_sth': '', 'nn_eq_nns': ''},
 'nugget': {'n_is_nc': '', 'n_is_sth': ''},
 'nuke': {'n_is_nc': '', 'n_is_sth': ''},
 'null': {'n_is_nc': '', 'n_is_sth': ''},
 'number': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'numbered', 'vb_to_jj': 'numbered', 'n_of_nns': ''},
 'numeral': {'n_is_nc': '', 'n_is_sth': ''},
 'nun': {'n_is_nc': '', 'n_is_sb': '0'},
 'nuncio': {'n_is_nc': '', 'n_is_sb': '0'},
 'nunnery': {'n_is_nc': '', 'n_is_sth': ''},
 'nutcracker': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'nutmeg': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'nutria': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'nutrient': {'n_is_nc': '', 'n_is_sth': ''},
 'nutshell': {'n_is_nc': '', 'n_is_sth': ''},
 'nymph': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'oaf': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'oak': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'oar': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'oat': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'oath': {'n_is_nc': '', 'art_an': '', 'n_is_sth': '0'},
 'obit': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'obituary': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'objectivity': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'observe'},
 'obliquity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'oblong': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'oboe': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'obscenity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'observation': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'observatory': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'observer': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'obsession': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'obstacle': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'obstruction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'obverse': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'occidental': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'ocelot': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'octave': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'octet': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'oculus': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'oddball': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'oddity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'odds': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ode': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'odometer': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'off-season': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'offence': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'offender': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'offense': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'offering': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbg_to_vb': 'offer', 'vbg_to_vbn': 'offered'},
 'offertory': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'officeholder': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'officiant': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'offshoot': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'offspring': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2', 'nn_eq_nns': ''},
 'ohm': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'oil': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'vt_typical': ''},
 'oilcloth': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'oiler': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'oilfield': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nc_typical': ''},
 'oilskin': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ointment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'old-timer': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'oldster': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'oleander': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'oligarch': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'oligarchy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'olive': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'olympiad': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'omen': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'omission': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'omit'},
 'omnibus': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'omnivore': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'onlooker': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'onrush': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'onset': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'onslaught': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'oodles': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'opening': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbg_to_vb': 'open', 'vbg_to_vbn': 'opened'},
 'operation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'operate', 'nn_to_jj': 'operational'},
 'operative': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'operetta': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'opiate': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'opium': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'opposition': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2', 'nn_to_vb': 'opposite', 'nn_to_jj': 'oppositional', 'n_is_collective': ''},
 'oppressor': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'optic': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'opus': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'oracle': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'oral': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'orangutan': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'oration': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'orator': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'oratorio': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'oratory': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'orb': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'orbit': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'orchard': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'orchid': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ordeal': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'orderly': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'ordinance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ordination': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ore': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'organisation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'organize', 'nn_to_jj': 'organisational'},
 'organon': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'orifice': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'originator': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'oriole': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'ornament': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'ornamental', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'orthodoxy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'oryx': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'os': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'oscillation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'oscillator': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'oscilloscope': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'osier': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'osprey': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '3'},
 'ossification': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ostler': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'ostrich': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'otter': {'n_is_nc': '', 'n_is_sb': '3', 'art_an': '', 'n_is_sth': '3'},
 'outage': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'outbreak': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'outburst': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'outcast': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'outcrop': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'outcropping': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'outcry': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'outfall': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'outfield': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'outfit': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'outflow': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'outgo': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'outgrowth': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'outing': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'outlander': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'outlaw': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vbg_non': ''},
 'outlay': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'outlet': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'outlier': {'n_is_nc': '', 'n_is_sb': '2', 'art_an': '', 'n_is_sth': '2'},
 'outline': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'outlook': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'outpost': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'outpouring': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'outrage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'outrigger': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'outskirts': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'outtake': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'oval': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ovary': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ovation': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'overabundance': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'overage': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'overcoat': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'overdraft': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'overflow': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'overgrowth': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'overhang': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'overlap': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'overload': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'overlord': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'overpass': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'overrun': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'overseer': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'overshoot': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'oversight': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'overstatement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'overthrow': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'overtone': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'overture': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'overturn': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'overview': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'owl': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'oxbow': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'oxford': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'oxidant': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'oxide': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'oxidizer': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'oyster': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'pa': {'n_is_nc': '', 'n_is_sb': '0'},
 'paca': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'pacemaker': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'pacesetter': {'n_is_nc': '', 'n_is_sb': '0'},
 'packer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'padding': {'n_is_nc': '', 'n_is_sth': ''},
 'paddle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'paddock': {'n_is_nc': '', 'n_is_sth': ''},
 'paddy': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'padlock': {'n_is_nc': '', 'n_is_sth': ''},
 'padre': {'n_is_nc': '', 'n_is_sb': '0'},
 'padrone': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'paean': {'n_is_nc': '', 'n_is_sth': ''},
 'pagan': {'n_is_nc': '', 'n_is_sb': '0'},
 'pageant': {'n_is_nc': '', 'n_is_sth': ''},
 'pager': {'n_is_nc': '', 'n_is_sth': ''},
 'pagoda': {'n_is_nc': '', 'n_is_sth': ''},
 'pail': {'n_is_nc': '', 'n_is_sth': ''},
 'paintbrush': {'n_is_nc': '', 'n_is_sth': ''},
 'painting': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'paint', 'vbg_to_vbn': 'painted'},
 'pairing': {'n_is_nc': '', 'n_is_sth': ''},
 'pajama': {'n_is_nc': '', 'n_is_sth': ''},
 'pal': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'paladin': {'n_is_nc': '', 'n_is_sb': '0'},
 'palate': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'paleface': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'palestra': {'n_is_nc': '', 'n_is_sth': ''},
 'palette': {'n_is_nc': '', 'n_is_sth': ''},
 'palimpsest': {'n_is_nc': '', 'n_is_sth': ''},
 'palisade': {'n_is_nc': '', 'n_is_sth': ''},
 'pall': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'pallet': {'n_is_nc': '', 'n_is_sth': ''},
 'palliative': {'n_is_nc': '', 'n_is_sth': ''},
 'palooka': {'n_is_nc': '', 'n_is_sb': '0'},
 'pamphlet': {'n_is_nc': '', 'n_is_sth': ''},
 'panacea': {'n_is_nc': '', 'n_is_sth': ''},
 'pancake': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'pancreas': {'n_is_nc': '', 'n_is_sth': ''},
 'pancreatitis': {'n_is_nc': '', 'n_is_sth': ''},
 'panda': {'n_is_nc': '', 'n_is_sb': '3', 'nc_typical': '', 'n_is_sth': '3'},
 'pandemic': {'n_is_nc': '', 'n_is_sth': ''},
 'pandemonium': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'pane': {'n_is_nc': '', 'n_is_sth': ''},
 'panhandler': {'n_is_nc': '', 'n_is_sb': '0'},
 'panoply': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'panorama': {'n_is_nc': '', 'n_is_sth': ''},
 'pansy': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'pant': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'panther': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'pantomime': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'pantry': {'n_is_nc': '', 'n_is_sth': ''},
 'panty': {'n_is_nc': '', 'n_is_sth': ''},
 'pantyhose': {'n_is_nc': '', 'n_is_sth': ''},
 'panzer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'papa': {'n_is_nc': '', 'n_is_sb': '0'},
 'papaya': {'n_is_nc': '', 'n_is_sth': ''},
 'paperback': {'n_is_nc': '', 'n_is_sth': ''},
 'paperboy': {'n_is_nc': '', 'n_is_sb': '0'},
 'paperclip': {'n_is_nc': '', 'n_is_sth': ''},
 'paperweight': {'n_is_nc': '', 'n_is_sth': ''},
 'papyrus': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'parable': {'n_is_nc': '', 'n_is_sth': ''},
 'parabola': {'n_is_nc': '', 'n_is_sth': ''},
 'parachute': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'parachutist': {'n_is_nc': '', 'n_is_sb': '0'},
 'paraclete': {'n_is_nc': '', 'n_is_sb': '0'},
 'paradigm': {'n_is_nc': '', 'n_is_sth': ''},
 'paradox': {'n_is_nc': '', 'n_is_sth': ''},
 'paragon': {'n_is_nc': '', 'n_is_sb': '0'},
 'paragraph': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'parallax': {'n_is_nc': '', 'n_is_sth': ''},
 'parallelism': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'parameter': {'n_is_nc': '', 'n_is_sth': ''},
 'paramour': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'parapet': {'n_is_nc': '', 'n_is_sth': ''},
 'paraphrase': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'parasite': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'parasol': {'n_is_nc': '', 'n_is_sth': ''},
 'paratrooper': {'n_is_nc': '', 'n_is_sb': '0'},
 'paratroops': {'n_is_nc': '', 'n_is_sb': '0'},
 'parchment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'pardon': {'n_is_nc': '', 'n_is_sth': '', 'v_vbg': '', 'v_n': '', 'v_for': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'pariah': {'n_is_nc': '', 'n_is_sb': '0'},
 'paring': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'parish': {'n_is_nc': '', 'n_is_sth': ''},
 'parka': {'n_is_nc': '', 'n_is_sth': ''},
 'parley': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'parliamentarian': {'n_is_nc': '', 'n_is_sb': '0'},
 'parlor': {'n_is_nc': '', 'n_is_sth': ''},
 'parlour': {'n_is_nc': '', 'n_is_sth': ''},
 'paroxysm': {'n_is_nc': '', 'n_is_sth': ''},
 'parrot': {'n_is_nc': '', 'n_is_sb': '3', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': '', 'nc_typical': '', 'n_is_sth': '3'},
 'parry': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'parson': {'n_is_nc': '', 'n_is_sb': '0'},
 'part-timer': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'parterre': {'n_is_nc': '', 'n_is_sth': ''},
 'participant': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'nn_to_vb': 'participate', 'nn_to_jj': 'participatory'},
 'participle': {'n_is_nc': '', 'n_is_sth': ''},
 'particle': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'part', 'nn_to_jj': 'partial', 'nn_to_rb': 'partially'},
 'particularity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'particular', 'nn_to_rb': 'particularly'},
 'particulate': {'n_is_nc': '', 'n_is_sth': ''},
 'parting': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'partition': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'partridge': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'parvenu': {'n_is_nc': '', 'n_is_sb': '0'},
 'pas': {'n_is_nc': '', 'n_is_sth': ''},
 'paseo': {'n_is_nc': '', 'n_is_sth': ''},
 'passageway': {'n_is_nc': '', 'n_is_sth': ''},
 'passbook': {'n_is_nc': '', 'n_is_sth': ''},
 'passer-by': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'passerby': {'n_is_nc': '', 'n_is_sb': '0'},
 'passionflower': {'n_is_nc': '', 'n_is_sth': ''},
 'password': {'n_is_nc': '', 'n_is_sth': ''},
 'paste': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'pastel': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'paster': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'pastoral': {'n_is_nc': '', 'n_is_sth': ''},
 'pastry': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'pasture': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'pasty': {'n_is_nc': '', 'n_is_sth': '', 'jj_to_jjr': 'pastier', 'jj_to_jjs': 'pastiest'},
 'patch': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'pate': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'patella': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'pater': {'n_is_nc': '', 'n_is_sb': '0'},
 'pathogen': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'pathway': {'n_is_nc': '', 'n_is_sth': ''},
 'patio': {'n_is_nc': '', 'n_is_sth': ''},
 'patois': {'n_is_nc': '', 'n_is_sth': ''},
 'patriarch': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'patriarchy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'patriot': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'patron': {'n_is_nc': '', 'n_is_sb': '0'},
 'patsy': {'n_is_nc': '', 'n_is_sb': '0'},
 'paunch': {'n_is_nc': '', 'n_is_sth': ''},
 'pauper': {'n_is_nc': '', 'n_is_sb': '0'},
 'pavement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'pavilion': {'n_is_nc': '', 'n_is_sth': ''},
 'paving': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'paw': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'pawn': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'pawnshop': {'n_is_nc': '', 'n_is_sth': ''},
 'pawpaw': {'n_is_nc': '', 'n_is_sth': ''},
 'payer': {'n_is_nc': '', 'n_is_sb': '0'},
 'paymaster': {'n_is_nc': '', 'n_is_sb': '0'},
 'payoff': {'n_is_nc': '', 'n_is_sth': ''},
 'pea': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'peacemaker': {'n_is_nc': '', 'n_is_sb': '0'},
 'peacock': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'peafowl': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'peal': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'peanut': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'pearl': {'n_is_nc': '', 'n_is_sth': ''},
 'peasant': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'nc_typical': ''},
 'pebble': {'n_is_nc': '', 'n_is_sth': ''},
 'pecan': {'n_is_nc': '', 'n_is_sth': ''},
 'peck': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'pecker': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'pectoral': {'n_is_nc': '', 'n_is_sth': ''},
 'peculiarity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'peculiar', 'nn_to_rb': 'peculiarly'},
 'pedagogue': {'n_is_nc': '', 'n_is_sb': '0'},
 'pedal': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'pedant': {'n_is_nc': '', 'n_is_sb': '0'},
 'peddler': {'n_is_nc': '', 'n_is_sb': '0'},
 'pedestal': {'n_is_nc': '', 'n_is_sth': ''},
 'pedestrian': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'pedicab': {'n_is_nc': '', 'n_is_sth': ''},
 'pedicure': {'n_is_nc': '', 'n_is_sth': ''},
 'pedigree': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'pediment': {'n_is_nc': '', 'n_is_sth': ''},
 'pedometer': {'n_is_nc': '', 'n_is_sth': ''},
 'peek': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'peel': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'peen': {'n_is_nc': '', 'n_is_sth': ''},
 'peep': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'peeper': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'peephole': {'n_is_nc': '', 'n_is_sth': ''},
 'peer': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'peerage': {'n_is_nc': '', 'n_is_sb': '0'},
 'peeve': {'n_is_nc': '', 'n_is_sth': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'peewee': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'peg': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'peignoir': {'n_is_nc': '', 'n_is_sth': ''},
 'pekinese': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'pekingese': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'pelican': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'pellet': {'n_is_nc': '', 'n_is_sth': ''},
 'pelt': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'pelvis': {'n_is_nc': '', 'n_is_sth': ''},
 'penance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'penchant': {'n_is_nc': '', 'n_is_sth': ''},
 'pendant': {'n_is_nc': '', 'n_is_sth': ''},
 'pendulum': {'n_is_nc': '', 'n_is_sth': ''},
 'penetration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'penguin': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'peninsula': {'n_is_nc': '', 'n_is_sth': ''},
 'penis': {'n_is_nc': '', 'n_is_sth': ''},
 'penitentiary': {'n_is_nc': '', 'n_is_sth': ''},
 'penknife': {'n_is_nc': '', 'n_is_sth': ''},
 'penman': {'n_is_nc': '', 'n_is_sb': '0'},
 'pennant': {'n_is_nc': '', 'n_is_sth': ''},
 'pennyroyal': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'pensioner': {'n_is_nc': '', 'n_is_sb': '0'},
 'pentagon': {'n_is_nc': '', 'n_is_sth': ''},
 'penthouse': {'n_is_nc': '', 'n_is_sth': ''},
 'penumbra': {'n_is_nc': '', 'n_is_sth': ''},
 'peon': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'peoples': {'n_is_nc': '', 'n_is_sb': '0'},
 'peppermint': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'percale': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'perch': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_eq_nns': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'percolator': {'n_is_nc': '', 'n_is_sth': ''},
 'peregrination': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'peregrine': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'perennial': {'n_is_nc': '', 'n_is_sth': ''},
 'perforation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'perfumery': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'pergola': {'n_is_nc': '', 'n_is_sth': ''},
 'peri': {'n_is_nc': '', 'n_is_sb': '0'},
 'pericardium': {'n_is_nc': '', 'n_is_sth': ''},
 'perihelion': {'n_is_nc': '', 'n_is_sth': ''},
 'peril': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'perimeter': {'n_is_nc': '', 'n_is_sth': ''},
 'perineum': {'n_is_nc': '', 'n_is_sth': ''},
 'peripatetic': {'n_is_nc': '', 'n_is_sb': '0'},
 'peripheral': {'n_is_nc': '', 'n_is_sth': ''},
 'periphery': {'n_is_nc': '', 'n_is_sth': ''},
 'periscope': {'n_is_nc': '', 'n_is_sth': ''},
 'periwinkle': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'perk': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'permanency': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'permutation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'perpendicular': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'perplexity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'perquisite': {'n_is_nc': '', 'n_is_sth': ''},
 'persecution': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'persimmon': {'n_is_nc': '', 'n_is_sth': ''},
 'persona': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'personage': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'personal': {'n_is_nc': '', 'n_is_sth': ''},
 'personification': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'personnel': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'persuader': {'n_is_nc': '', 'n_is_sb': '0', 'n_is_sth': ''},
 'persuasion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'persuade', 'nn_to_jj': 'persuasive', 'nn_to_rb': 'persuasively'},
 'perturbation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'perusal': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'pes': {'n_is_nc': '', 'n_is_sth': ''},
 'pest': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'pesticide': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'pestilence': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'pestle': {'n_is_nc': '', 'n_is_sth': ''},
 'petal': {'n_is_nc': '', 'n_is_sth': ''},
 'petard': {'n_is_nc': '', 'n_is_sth': ''},
 'peter': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'vbd_eq_vbn': ''},
 'petitioner': {'n_is_nc': '', 'n_is_sb': '0'},
 'petticoat': {'n_is_nc': '', 'n_is_sth': ''},
 'pew': {'n_is_nc': '', 'n_is_sth': ''},
 'phage': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'phalanx': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'phallus': {'n_is_nc': '', 'n_is_sth': ''},
 'phantasm': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'phantom': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'pharaoh': {'n_is_nc': '', 'n_is_sb': '0'},
 'pharisee': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'pharmacist': {'n_is_nc': '', 'n_is_sb': '0'},
 'pharmacopeia': {'n_is_nc': '', 'n_is_sth': ''},
 'pharmacopoeia': {'n_is_nc': '', 'n_is_sth': ''},
 'pharmacy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'pharos': {'n_is_nc': '', 'n_is_sth': ''},
 'pharynx': {'n_is_nc': '', 'n_is_sth': ''},
 'pheasant': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'phenotype': {'n_is_nc': '', 'n_is_sth': ''},
 'philanthropist': {'n_is_nc': '', 'n_is_sb': '0'},
 'philistine': {'n_is_nc': '', 'n_is_sb': '0'},
 'phobia': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'phoneme': {'n_is_nc': '', 'n_is_sth': ''},
 'phoney': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'jj_to_jjr': 'phoneier', 'jj_to_jjs': 'phoneiest'},
 'phonograph': {'n_is_nc': '', 'n_is_sth': ''},
 'phony': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2', 'jj_to_jjr': 'phonier', 'jj_to_jjs': 'phoniest'},
 'phosphate': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'photogravure': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'photon': {'n_is_nc': '', 'n_is_sth': ''},
 'phylum': {'n_is_nc': '', 'n_is_sth': ''},
 'physiognomy': {'n_is_nc': '', 'n_is_sth': ''},
 'physique': {'n_is_nc': '', 'n_is_sth': ''},
 'pianoforte': {'n_is_nc': '', 'n_is_sth': ''},
 'pic': {'n_is_nc': '', 'n_is_sth': ''},
 'piccolo': {'n_is_nc': '', 'n_is_sth': ''},
 'pick': {'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_at': '', 'vb_to_vbz': 'picks', 'vb_to_vbd': 'picked', 'vb_to_vbn': 'picked', 'vb_to_vbg': 'picking', 'vt_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'pick-off': {'n_is_nc': '', 'n_is_sth': ''},
 'pickax': {'n_is_nc': '', 'n_is_sth': ''},
 'picker': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'picket': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'picking': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'pick', 'vbg_to_vbn': 'picked'},
 'pickle': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'pickpocket': {'n_is_nc': '', 'n_is_sb': '0'},
 'picnic': {'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'pictograph': {'n_is_nc': '', 'n_is_sth': ''},
 'pictorial': {'n_is_nc': '', 'n_is_sth': ''},
 'piedmont': {'n_is_nc': '', 'n_is_sth': ''},
 'pier': {'n_is_nc': '', 'n_is_sth': ''},
 'piety': {'n_is_nc': '', 'n_is_sth': ''},
 'pigeon': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'piggery': {'n_is_nc': '', 'n_is_sth': ''},
 'piglet': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'pigpen': {'n_is_nc': '', 'n_is_sth': ''},
 'pigsty': {'n_is_nc': '', 'n_is_sth': ''},
 'pigtail': {'n_is_nc': '', 'n_is_sth': ''},
 'pigweed': {'n_is_nc': '', 'n_is_sth': ''},
 'pike': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'pilgrim': {'n_is_nc': '', 'n_is_sb': '0'},
 'pilgrimage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'piling': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'pillar': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'pillbox': {'n_is_nc': '', 'n_is_sth': ''},
 'pillory': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'pillow': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'pillowcase': {'n_is_nc': '', 'n_is_sth': ''},
 'pilothouse': {'n_is_nc': '', 'n_is_sth': ''},
 'piloting': {'n_is_nc': '', 'n_is_sth': '0'},
 'pimiento': {'n_is_nc': '', 'n_is_sth': ''},
 'pimp': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'pimple': {'n_is_nc': '', 'n_is_sth': ''},
 'pinafore': {'n_is_nc': '', 'n_is_sth': ''},
 'pinch': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': ''},
 'ping': {'n_is_nc': '', 'n_is_sth': ''},
 'pinger': {'n_is_nc': '', 'n_is_sth': ''},
 'pinhead': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'pinhole': {'n_is_nc': '', 'n_is_sth': ''},
 'pinna': {'n_is_nc': '', 'n_is_sth': ''},
 'pinnacle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'pinner': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'pinpoint': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'pinprick': {'n_is_nc': '', 'n_is_sth': ''},
 'pinstripe': {'n_is_nc': '', 'n_is_sth': ''},
 'pinto': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'pinwheel': {'n_is_nc': '', 'n_is_sth': ''},
 'pip': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'pipette': {'n_is_nc': '', 'n_is_sth': ''},
 'pippin': {'n_is_nc': '', 'n_is_sth': ''},
 'pirate': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'pistil': {'n_is_nc': '', 'n_is_sth': ''},
 'pistol': {'n_is_nc': '', 'n_is_sth': ''},
 'piston': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'pitcher': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'pitchfork': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'pitchman': {'n_is_nc': '', 'n_is_sb': '0'},
 'pitfall': {'n_is_nc': '', 'n_is_sth': ''},
 'pitman': {'n_is_nc': '', 'n_is_sb': '0'},
 'pituitary': {'n_is_nc': '', 'n_is_sth': ''},
 'pivot': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'pix': {'n_is_nc': '', 'n_is_sth': ''},
 'pizza': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'placard': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'placement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'placenta': {'n_is_nc': '', 'n_is_sth': ''},
 'placer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'placket': {'n_is_nc': '', 'n_is_sth': ''},
 'plagiarist': {'n_is_nc': '', 'n_is_sb': '0'},
 'plague': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'plaid': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'plaint': {'n_is_nc': '', 'n_is_sth': ''},
 'plaintiff': {'n_is_nc': '', 'n_is_sb': '0'},
 'plait': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'planer': {'n_is_nc': '', 'n_is_sth': ''},
 'planetarium': {'n_is_nc': '', 'n_is_sth': ''},
 'plank': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'planner': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'plantain': {'n_is_nc': '', 'n_is_sth': ''},
 'plantation': {'n_is_nc': '', 'n_is_sth': ''},
 'planter': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'plaque': {'n_is_nc': '', 'n_is_sth': ''},
 'plasmodium': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'plasterer': {'n_is_nc': '', 'n_is_sb': '0'},
 'plastic': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'plastique': {'n_is_nc': '', 'n_is_sth': ''},
 'plat': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'platelet': {'n_is_nc': '', 'n_is_sth': ''},
 'platitude': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'platoon': {'n_is_nc': '', 'n_is_sth': ''},
 'platter': {'n_is_nc': '', 'n_is_sth': ''},
 'platypus': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'play': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_n': '', 'v_on': '', 'v_at': '', 'v_in': '', 'v_with': '', 'v_for': '', 'vb_to_vbz': 'plays', 'vb_to_vbd': 'played', 'vb_to_vbn': 'played', 'nn_to_vbg': 'playing', 'v_vbg': '', 'vb_to_vbg': 'playing', 'vt_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'playback': {'n_is_nc': '', 'n_is_sth': ''},
 'playbill': {'n_is_nc': '', 'n_is_sth': ''},
 'playbook': {'n_is_nc': '', 'n_is_sth': ''},
 'playboy': {'n_is_nc': '', 'n_is_sb': '0'},
 'playgoer': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '0'},
 'playground': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'playhouse': {'n_is_nc': '', 'n_is_sth': ''},
 'playlet': {'n_is_nc': '', 'n_is_sth': ''},
 'playmaker': {'n_is_nc': '', 'n_is_sb': '0'},
 'playmate': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'plaything': {'n_is_nc': '', 'n_is_sth': ''},
 'plaza': {'n_is_nc': '', 'n_is_sth': ''},
 'pleader': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'pleat': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'plenum': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'plethora': {'n_is_nc': '', 'n_is_sth': ''},
 'plexus': {'n_is_nc': '', 'n_is_sth': ''},
 'pliers': {'n_is_nc': '', 'n_is_sth': ''},
 'plight': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'plinth': {'n_is_nc': '', 'n_is_sth': ''},
 'plod': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'plotter': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'plough': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'ploughman': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'plover': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'plow': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'plowman': {'n_is_nc': '', 'n_is_sb': '0'},
 'plowshare': {'n_is_nc': '', 'n_is_sth': ''},
 'ploy': {'n_is_nc': '', 'n_is_sth': ''},
 'pluck': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'plugger': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'plumb': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'plumber': {'n_is_nc': '', 'n_is_sb': '0'},
 'plumbing': {'n_is_nc': '', 'n_is_sth': ''},
 'plume': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': ''},
 'plummet': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'plump': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'plunger': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'plural': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'plurality': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'plutocrat': {'n_is_nc': '', 'n_is_sb': '0'},
 'pm': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nns_exp_exc': ''},
 'pock': {'n_is_nc': '', 'n_is_sth': ''},
 'pocketbook': {'n_is_nc': '', 'n_is_sth': ''},
 'pocketknife': {'n_is_nc': '', 'n_is_sth': ''},
 'pod': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'podium': {'n_is_nc': '', 'n_is_sth': ''},
 'pogrom': {'n_is_nc': '', 'n_is_sth': ''},
 'poinsettia': {'n_is_nc': '', 'n_is_sth': ''},
 'pointer': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'poison': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'poisonous', 'nn_to_rb': 'poisonously', 'vb_to_rb': 'poisonously', 'vb_to_nn': 'poisoner', 'vb_to_jj': 'poisonous', 'vbd_eq_vbn': ''},
 'poke': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'poker': {'n_is_nc': '', 'n_is_sth': ''},
 'pokey': {'n_is_nc': '', 'n_is_sth': ''},
 'polaris': {'n_is_nc': '', 'n_is_sth': ''},
 'polarity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'polder': {'n_is_nc': '', 'n_is_sth': ''},
 'polecat': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'polemic': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'polemicist': {'n_is_nc': '', 'n_is_sb': '0'},
 'polemics': {'n_is_nc': '', 'n_is_sth': ''},
 'polestar': {'n_is_nc': '', 'n_is_sth': ''},
 'policyholder': {'n_is_nc': '', 'n_is_sb': '0'},
 'polish': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vb_to_rb': 'politest', 'vb_to_nn': 'polisher', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'polisher': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'polish', 'nn_to_rb': 'politest'},
 'politico': {'n_is_nc': '', 'n_is_sb': '0'},
 'polity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'polka': {'n_is_nc': '', 'n_is_sth': ''},
 'pollard': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'poltroon': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'polygon': {'n_is_nc': '', 'n_is_sth': ''},
 'polymer': {'n_is_nc': '', 'n_is_sth': ''},
 'polyp': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'pomelo': {'n_is_nc': '', 'n_is_sth': ''},
 'pomfret': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'pompon': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'poncho': {'n_is_nc': '', 'n_is_sth': ''},
 'pong': {'n_is_nc': '', 'n_is_sth': ''},
 'pongo': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'pons': {'n_is_nc': '', 'n_is_sth': ''},
 'pontiff': {'n_is_nc': '', 'n_is_sb': '0'},
 'pontificate': {'n_is_nc': '', 'n_is_sth': ''},
 'pontoon': {'n_is_nc': '', 'n_is_sth': ''},
 'pony': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'vbd_eq_vbn': ''},
 'pooch': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'popinjay': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'poplar': {'n_is_nc': '', 'n_is_sth': ''},
 'popper': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'poppy': {'n_is_nc': '', 'n_is_sth': ''},
 'popsicle': {'n_is_nc': '', 'n_is_sth': ''},
 'porch': {'n_is_nc': '', 'n_is_sth': ''},
 'porcupine': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'pore': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'porgy': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'porpoise': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'portage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'portal': {'n_is_nc': '', 'n_is_sth': ''},
 'portent': {'n_is_nc': '', 'n_is_sth': ''},
 'porterhouse': {'n_is_nc': '', 'n_is_sth': ''},
 'porthole': {'n_is_nc': '', 'n_is_sth': ''},
 'portico': {'n_is_nc': '', 'n_is_sth': ''},
 'portraiture': {'n_is_nc': '', 'n_is_sth': ''},
 'portrayal': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'poseidon': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'poser': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'positioning': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'positron': {'n_is_nc': '', 'n_is_sth': ''},
 'posse': {'n_is_nc': '', 'n_is_sth': ''},
 'possessive': {'n_is_nc': '', 'n_is_sth': ''},
 'possessor': {'n_is_nc': '', 'n_is_sb': '0'},
 'postbox': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'postcard': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'posterior': {'n_is_nc': '', 'n_is_sth': ''},
 'posterity': {'n_is_nc': '', 'n_is_sb': '0'},
 'postgraduate': {'n_is_nc': '', 'n_is_sb': '0'},
 'postmark': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'postponement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'postscript': {'n_is_nc': '', 'n_is_sth': ''},
 'postulate': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'posture': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'posy': {'n_is_nc': '', 'n_is_sth': ''},
 'potbelly': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'potentate': {'n_is_nc': '', 'n_is_sb': '0'},
 'potentiality': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'pothole': {'n_is_nc': '', 'n_is_sth': ''},
 'potion': {'n_is_nc': '', 'n_is_sth': ''},
 'potpie': {'n_is_nc': '', 'n_is_sth': ''},
 'potshot': {'n_is_nc': '', 'n_is_sth': ''},
 'potter': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'potty': {'n_is_nc': '', 'n_is_sth': '', 'jj_to_jjr': 'pottier', 'jj_to_jjs': 'pottiest'},
 'pouch': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'pounce': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'pout': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'power': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'powerful', 'vb_to_jj': 'powerful', 'v_compcl_non': ''},
 'powerboat': {'n_is_nc': '', 'n_is_sth': ''},
 'powerhouse': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'powwow': {'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'practicality': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'practice': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'practise', 'nn_to_vbg': 'practising', 'v_vbg': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'practitioner': {'n_is_nc': '', 'n_is_sb': '0'},
 'prairie': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'pram': {'n_is_nc': '', 'n_is_sth': ''},
 'prance': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'prang': {'n_is_nc': '', 'n_is_sth': ''},
 'prank': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'prawn': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'praxis': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'preacher': {'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'preach'},
 'preamble': {'n_is_nc': '', 'n_is_sth': ''},
 'precaution': {'n_is_nc': '', 'n_is_sth': ''},
 'precept': {'n_is_nc': '', 'n_is_sth': ''},
 'precinct': {'n_is_nc': '', 'n_is_sth': ''},
 'precipice': {'n_is_nc': '', 'n_is_sth': ''},
 'precipitate': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'precipitation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'preclusion': {'n_is_nc': '', 'n_is_sth': ''},
 'preconception': {'n_is_nc': '', 'n_is_sth': ''},
 'precondition': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'precursor': {'n_is_nc': '', 'n_is_sb': '0'},
 'predicament': {'n_is_nc': '', 'n_is_sth': ''},
 'predicate': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'prediction': {'n_is_nc': '', 'n_is_sth': ''},
 'predilection': {'n_is_nc': '', 'n_is_sth': ''},
 'predisposition': {'n_is_nc': '', 'n_is_sth': ''},
 'preemie': {'n_is_nc': '', 'n_is_sb': '0'},
 'prefab': {'n_is_nc': '', 'n_is_sth': ''},
 'preface': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'prefect': {'n_is_nc': '', 'n_is_sb': '0', 'confu_pair': 'perfect'},
 'prefecture': {'n_is_nc': '', 'n_is_sth': ''},
 'preference': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'prefer', 'nn_to_jj': 'preferable', 'nn_to_rb': 'preferably'},
 'prefix': {'n_is_nc': '', 'n_is_sth': ''},
 'prejudgment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'prejudice': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'prelate': {'n_is_nc': '', 'n_is_sb': '0'},
 'prelude': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'prematurity': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'premonition': {'n_is_nc': '', 'n_is_sth': ''},
 'prentice': {'n_is_nc': '', 'n_is_sb': '0'},
 'preoccupation': {'n_is_nc': '', 'n_is_sth': ''},
 'preposition': {'n_is_nc': '', 'n_is_sth': ''},
 'prerequisite': {'n_is_nc': '', 'n_is_sth': ''},
 'prerogative': {'n_is_nc': '', 'n_is_sth': ''},
 'presage': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'presbytery': {'n_is_nc': '', 'n_is_sth': ''},
 'preschool': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'presence': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_vb': 'present', 'nn_to_jj': 'present', 'nn_to_rb': 'presently'},
 'preservative': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'presidio': {'n_is_nc': '', 'n_is_sth': ''},
 'presidium': {'n_is_nc': '', 'n_is_sth': ''},
 'pressman': {'n_is_nc': '', 'n_is_sb': '0'},
 'pressure': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'pressured', 'nn_to_vbg': 'pressing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'presumption': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'presume', 'nn_to_jj': 'presumable', 'nn_to_rb': 'presumably'},
 'pretence': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'pretend'},
 'pretender': {'n_is_nc': '', 'n_is_sb': '0'},
 'pretension': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'pretext': {'n_is_nc': '', 'n_is_sth': ''},
 'preventive': {'n_is_nc': '', 'n_is_sth': ''},
 'preview': {'n_is_nc': '', 'n_is_sth': '', 'vt_typical': ''},
 'prevue': {'n_is_nc': '', 'n_is_sth': ''},
 'prexy': {'n_is_nc': '', 'n_is_sb': '0'},
 'prick': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'priestess': {'n_is_nc': '', 'n_is_sb': '0'},
 'primate': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'primer': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'prime'},
 'priming': {'n_is_nc': '', 'n_is_sth': ''},
 'primitive': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'primrose': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'principal': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'principality': {'n_is_nc': '', 'n_is_sth': ''},
 'printing': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'print', 'vbg_to_vbn': 'printed'},
 'priority': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'prism': {'n_is_nc': '', 'n_is_sth': ''},
 'privation': {'n_is_nc': '', 'n_is_sth': ''},
 'privy': {'n_is_nc': '', 'n_is_sth': ''},
 'probationer': {'n_is_nc': '', 'n_is_sb': '0'},
 'proboscis': {'n_is_nc': '', 'n_is_sth': ''},
 'proceeds': {'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'proceed'},
 'procession': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'processor': {'n_is_nc': '', 'n_is_sb': '0'},
 'proclamation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'proclivity': {'n_is_nc': '', 'n_is_sth': ''},
 'proctor': {'n_is_nc': '', 'n_is_sb': '0'},
 'procurator': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'prod': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'prodigal': {'n_is_nc': '', 'n_is_sb': '0'},
 'prodigy': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'production': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'productive', 'nn_to_rb': 'productively'},
 'prof': {'n_is_nc': '', 'n_is_sb': '0'},
 'profanity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'proffer': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'profit': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'profitable', 'vb_to_jj': 'profitable', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'profiteer': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'profligate': {'n_is_nc': '', 'n_is_sb': '0'},
 'profundity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'progenitor': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'progeny': {'n_is_nc': '', 'n_is_sb': '0'},
 'prognosis': {'n_is_nc': '', 'n_is_sth': ''},
 'prognostication': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'programmer': {'n_is_nc': '', 'n_is_sb': '0'},
 'progress': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'progressive', 'nn_to_rb': 'progressively', 'v_n': '', 'nsubjpass': '', 'v_in': '', 'v_with': '', 'v_from': '', 'vb_to_rb': 'progressively', 'vb_to_jj': 'progressive', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'nu_typical': ''},
 'prohibition': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'prohibit', 'nn_to_jj': 'prohibitive', 'nn_to_rb': 'prohibitively'},
 'projectile': {'n_is_nc': '', 'n_is_sth': ''},
 'projection': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'project'},
 'projector': {'n_is_nc': '', 'n_is_sth': ''},
 'prole': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'proletarian': {'n_is_nc': '', 'n_is_sb': '0'},
 'proletariat': {'n_is_nc': '', 'n_is_sb': '0', 'n_is_collective': ''},
 'prologue': {'n_is_nc': '', 'n_is_sth': ''},
 'prolongation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'prom': {'n_is_nc': '', 'n_is_sth': ''},
 'promenade': {'n_is_nc': '', 'n_is_sth': ''},
 'prominence': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'promise': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'promises', 'vb_to_vbd': 'promised', 'vb_to_vbn': 'promised', 'vb_to_vbg': 'promising', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'promontory': {'n_is_nc': '', 'n_is_sth': ''},
 'prong': {'n_is_nc': '', 'n_is_sth': ''},
 'pronoun': {'n_is_nc': '', 'n_is_sth': ''},
 'pronouncement': {'n_is_nc': '', 'n_is_sth': ''},
 'proofreader': {'n_is_nc': '', 'n_is_sb': '0'},
 'prop': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'propagandist': {'n_is_nc': '', 'n_is_sb': '0'},
 'propeller': {'n_is_nc': '', 'n_is_sth': ''},
 'propensity': {'n_is_nc': '', 'n_is_sth': ''},
 'prophecy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'prophet': {'n_is_nc': '', 'n_is_sb': '0'},
 'prophylactic': {'n_is_nc': '', 'n_is_sth': ''},
 'prophylaxis': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'proposition': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'proprietary': {'n_is_nc': '', 'n_is_sb': '0'},
 'proprietor': {'n_is_nc': '', 'n_is_sb': '0'},
 'proscenium': {'n_is_nc': '', 'n_is_sth': ''},
 'proselytism': {'n_is_nc': '', 'n_is_sth': ''},
 'prospectus': {'n_is_nc': '', 'n_is_sth': ''},
 'prostate': {'n_is_nc': '', 'n_is_sth': ''},
 'prosthesis': {'n_is_nc': '', 'n_is_sth': ''},
 'prostitute': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'protagonist': {'n_is_nc': '', 'n_is_sb': '0'},
 'protection': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'protect', 'nn_to_jj': 'protective', 'nn_to_rb': 'protectively'},
 'protector': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'protectorate': {'n_is_nc': '', 'n_is_sth': ''},
 'protege': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'protest': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'vbd_eq_vbn': '', 'v_pass_non': ''},
 'protestation': {'n_is_nc': '', 'n_is_sth': ''},
 'protocol': {'n_is_nc': '', 'n_is_sth': ''},
 'proton': {'n_is_nc': '', 'n_is_sth': ''},
 'prototype': {'n_is_nc': '', 'n_is_sth': ''},
 'protozoan': {'n_is_nc': '', 'n_is_sb': '0'},
 'protractor': {'n_is_nc': '', 'n_is_sth': ''},
 'protrusion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'protuberance': {'n_is_nc': '', 'n_is_sth': ''},
 'proverb': {'n_is_nc': '', 'n_is_sth': ''},
 'provincial': {'n_is_nc': '', 'n_is_sb': '0'},
 'proviso': {'n_is_nc': '', 'n_is_sth': ''},
 'provocateur': {'n_is_nc': '', 'n_is_sb': '0'},
 'provocation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'provost': {'n_is_nc': '', 'n_is_sb': '0'},
 'prow': {'n_is_nc': '', 'n_is_sth': ''},
 'prowler': {'n_is_nc': '', 'n_is_sb': '0'},
 'proxy': {'n_is_nc': '', 'n_is_sb': '0'},
 'prune': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'pry': {'n_is_nc': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'psalm': {'n_is_nc': '', 'n_is_sth': ''},
 'psalmist': {'n_is_nc': '', 'n_is_sb': '0'},
 'pseudonym': {'n_is_nc': '', 'n_is_sth': ''},
 'psyche': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'psychic': {'n_is_nc': '', 'n_is_sb': '0'},
 'ptarmigan': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'pterodactyl': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'publisher': {'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'publish'},
 'pucker': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'pud': {'n_is_nc': '', 'n_is_sth': ''},
 'pudding': {'n_is_nc': '', 'n_is_sth': ''},
 'puddle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'puff': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'puffer': {'n_is_nc': '', 'n_is_sb': '0'},
 'puffery': {'n_is_nc': '', 'n_is_sth': ''},
 'pug': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'pugilist': {'n_is_nc': '', 'n_is_sb': '0'},
 'puissance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'pull': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_at': '', 'v_in': '', 'v_for': '', 'vb_to_vbz': 'pulls', 'vb_to_vbd': 'pulled', 'vb_to_vbn': 'pulled', 'vb_to_vbg': 'pulling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'pull-up': {'n_is_nc': '', 'n_is_sth': ''},
 'pullback': {'n_is_nc': '', 'n_is_sth': ''},
 'pulley': {'n_is_nc': '', 'n_is_sth': ''},
 'pullover': {'n_is_nc': '', 'n_is_sth': ''},
 'pulpit': {'n_is_nc': '', 'n_is_sth': ''},
 'pulsar': {'n_is_nc': '', 'n_is_sth': ''},
 'pulsation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'pulse': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'puma': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'pumpkin': {'n_is_nc': '', 'n_is_sth': ''},
 'pun': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'punch-up': {'n_is_nc': '', 'n_is_sth': ''},
 'puncher': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'punctuation': {'n_is_nc': '', 'n_is_sth': '', 'nu_typical': ''},
 'puncture': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'pundit': {'n_is_nc': '', 'n_is_sb': '0'},
 'punk': {'n_is_nc': '', 'n_is_sb': '0'},
 'punter': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'pup': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'pupa': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'puppet': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'puppy': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'purchase': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'purchases', 'vb_to_vbd': 'purchased', 'vb_to_vbn': 'purchased', 'vb_to_nn': 'purchaser', 'vb_to_vbg': 'purchasing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'purchaser': {'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'purchase'},
 'purebred': {'n_is_nc': '', 'n_is_sb': '0', 'jj_ed': ''},
 'puree': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'purgative': {'n_is_nc': '', 'n_is_sth': ''},
 'purge': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'purifier': {'n_is_nc': '', 'n_is_sb': '0'},
 'puritan': {'n_is_nc': '', 'n_is_sb': '0'},
 'purr': {'n_is_nc': '', 'n_is_sth': ''},
 'purser': {'n_is_nc': '', 'n_is_sb': '0'},
 'pursuer': {'n_is_nc': '', 'n_is_sb': '0'},
 'purview': {'n_is_nc': '', 'n_is_sth': ''},
 'push': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'pushy', 'v_to_vbg': '', 'v_n': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_in': '', 'v_with': '', 'v_for': '', 'v_from': '', 'vb_to_vbz': 'pushes', 'vb_to_vbd': 'pushed', 'vb_to_vbn': 'pushed', 'vb_to_vbg': 'pushing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'pushcart': {'n_is_nc': '', 'n_is_sth': ''},
 'pusher': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'pushpin': {'n_is_nc': '', 'n_is_sth': ''},
 'puss': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'pussy': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3', 'dirtyword': ''},
 'put': {'n_is_nc': '', 'n_is_sb': '2', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'vb_to_vbz': 'puts', 'v_to_n': '', 'vb_to_vbg': 'putting', 'vbn_to_vbg': 'putting', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vt_typical': '', 'n_is_sth': '2'},
 'putsch': {'n_is_nc': '', 'n_is_sth': ''},
 'puzzle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'nc_typical': ''},
 'puzzler': {'n_is_nc': '', 'n_is_sb': '0'},
 'pygmy': {'n_is_nc': '', 'n_is_sb': '0'},
 'pylon': {'n_is_nc': '', 'n_is_sth': ''},
 'pyramid': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'pyrethrum': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'pyrite': {'n_is_nc': '', 'n_is_sth': ''},
 'python': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'quack': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'quadrangle': {'n_is_nc': '', 'n_is_sth': ''},
 'quadrant': {'n_is_nc': '', 'n_is_sth': ''},
 'quadrilateral': {'n_is_nc': '', 'n_is_sth': '0'},
 'quadroon': {'n_is_nc': '', 'n_is_sb': '0'},
 'quadruped': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'quagmire': {'n_is_nc': '', 'n_is_sth': ''},
 'quail': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'quake': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'vi_typical': ''},
 'qualification': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'qualify'},
 'qualm': {'n_is_nc': '', 'n_is_sth': ''},
 'quandary': {'n_is_nc': '', 'n_is_sth': ''},
 'quantification': {'n_is_nc': '', 'n_is_sth': ''},
 'quantity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'quantum': {'n_is_nc': '', 'n_is_sth': ''},
 'quarrel': {'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_with': '', 'v_about': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'quarry': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'quart': {'n_is_nc': '', 'n_is_sth': ''},
 'quarterfinal': {'n_is_nc': '', 'n_is_sth': ''},
 'quartermaster': {'n_is_nc': '', 'n_is_sb': '0'},
 'quartile': {'n_is_nc': '', 'n_is_sth': ''},
 'quasar': {'n_is_nc': '', 'n_is_sth': ''},
 'quaver': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'quay': {'n_is_nc': '', 'n_is_sth': ''},
 'query': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'questioner': {'n_is_nc': '', 'n_is_sb': '0'},
 'questionnaire': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'question', 'nn_to_rb': 'questionably', 'nc_typical': ''},
 'quibble': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'quicksand': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'quickstep': {'n_is_nc': '', 'n_is_sth': ''},
 'quill': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'quilt': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'quintal': {'n_is_nc': '', 'n_is_sth': ''},
 'quip': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'quirk': {'n_is_nc': '', 'n_is_sth': ''},
 'quisling': {'n_is_nc': '', 'n_is_sb': '0'},
 'quitter': {'n_is_nc': '', 'n_is_sb': '0'},
 'quiver': {'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'quiz': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'quorum': {'n_is_nc': '', 'n_is_sth': ''},
 'quota': {'n_is_nc': '', 'n_is_sth': ''},
 'quotation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'quote'},
 'quotient': {'n_is_nc': '', 'n_is_sth': ''},
 'rabbet': {'n_is_nc': '', 'n_is_sth': ''},
 'rabbi': {'n_is_nc': '', 'n_is_sb': '0'},
 'rabbit': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'rabble': {'n_is_nc': '', 'n_is_sb': '0'},
 'raccoon': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'racecourse': {'n_is_nc': '', 'n_is_sth': ''},
 'racehorse': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'racer': {'n_is_nc': '', 'n_is_sb': '0'},
 'racetrack': {'n_is_nc': '', 'n_is_sth': ''},
 'raceway': {'n_is_nc': '', 'n_is_sth': ''},
 'rack': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'racket': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'racketeer': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'racquet': {'n_is_nc': '', 'n_is_sth': ''},
 'radial': {'n_is_nc': '', 'n_is_sth': ''},
 'radiator': {'n_is_nc': '', 'n_is_sth': ''},
 'radiometer': {'n_is_nc': '', 'n_is_sth': ''},
 'radish': {'n_is_nc': '', 'n_is_sth': ''},
 'raffle': {'n_is_nc': '', 'n_is_sth': ''},
 'raft': {'n_is_nc': '', 'n_is_sth': ''},
 'rafter': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'rag': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'ragamuffin': {'n_is_nc': '', 'n_is_sb': '0'},
 'raid': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'railing': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'rail', 'vbg_to_vbn': 'railed'},
 'rainbow': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'raincoat': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'raindrop': {'n_is_nc': '', 'n_is_sth': '0'},
 'rainfall': {'n_is_nc': '', 'n_is_sth': ''},
 'rainforest': {'n_is_nc': '', 'n_is_sth': ''},
 'rainstorm': {'n_is_nc': '', 'n_is_sth': ''},
 'raiser': {'n_is_nc': '', 'n_is_sb': '0'},
 'raisin': {'n_is_nc': '', 'n_is_sth': ''},
 'raja': {'n_is_nc': '', 'n_is_sb': '0'},
 'rajah': {'n_is_nc': '', 'n_is_sb': '0'},
 'rake': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'ram': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'ramble': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'rambler': {'n_is_nc': '', 'n_is_sb': '0'},
 'ramification': {'n_is_nc': '', 'n_is_sth': ''},
 'ramp': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'rampart': {'n_is_nc': '', 'n_is_sth': ''},
 'ramrod': {'n_is_nc': '', 'n_is_sb': '0'},
 'ramus': {'n_is_nc': '', 'n_is_sth': ''},
 'rand': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'range': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'ranges', 'vb_to_vbd': 'ranged', 'vb_to_vbn': 'ranged', 'vb_to_vbg': 'ranging', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'rani': {'n_is_nc': '', 'n_is_sb': '0'},
 'ranking': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'rank', 'vbg_to_vbn': 'ranked'},
 'ransom': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'rapeseed': {'n_is_nc': '', 'n_is_sth': ''},
 'rapist': {'n_is_nc': '', 'n_is_sb': '0'},
 'rapper': {'n_is_nc': '', 'n_is_sb': '0'},
 'rapporteur': {'n_is_nc': '', 'n_is_sb': '0'},
 'rapprochement': {'n_is_nc': '', 'n_is_sth': ''},
 'rapscallion': {'n_is_nc': '', 'n_is_sb': '0'},
 'raptor': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'rascal': {'n_is_nc': '', 'n_is_sb': '0'},
 'rash': {'n_is_nc': '', 'n_is_sth': '', 'jj_to_jjr': 'rasher', 'jj_to_jjs': 'rashest'},
 'rasp': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'raspberry': {'n_is_nc': '', 'n_is_sth': ''},
 'rat': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'ratchet': {'n_is_nc': '', 'n_is_sth': ''},
 'rathole': {'n_is_nc': '', 'n_is_sth': ''},
 'ration': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'rationale': {'n_is_nc': '', 'n_is_sth': ''},
 'rationalization': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'rattle': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'rattler': {'n_is_nc': '', 'n_is_sb': '0'},
 'rattlesnake': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'ravage': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'ravel': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'raveling': {'n_is_nc': '', 'n_is_sth': ''},
 'raven': {'n_is_nc': '', 'n_is_sb': '3', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_sth': '3'},
 'ravine': {'n_is_nc': '', 'n_is_sth': ''},
 'raving': {'n_is_nc': '', 'n_is_sth': ''},
 'razor': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'razorback': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': ''},
 'reach': {'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'v_to': '', 'vb_to_vbz': 'reaches', 'vb_to_vbd': 'reached', 'vb_to_vbn': 'reached', 'vb_to_vbg': 'reaching', 'nn_to_vbg': 'reaching', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'reaction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'reactivate', 'nn_to_jj': 'reactive', 'nn_to_rb': 'reactively'},
 'reactionary': {'n_is_nc': '', 'n_is_sb': '0'},
 'reactor': {'n_is_nc': '', 'n_is_sth': ''},
 'readjustment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'reagent': {'n_is_nc': '', 'n_is_sth': ''},
 'realm': {'n_is_nc': '', 'n_is_sth': ''},
 'realty': {'n_is_nc': '', 'n_is_sth': ''},
 'ream': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'reamer': {'n_is_nc': '', 'n_is_sth': ''},
 'reaper': {'n_is_nc': '', 'n_is_sb': '0'},
 'reappearance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'rearguard': {'n_is_nc': '', 'n_is_sb': '0'},
 'rearrangement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'reassurance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'rebate': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'rebellion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'rebound': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'rebroadcast': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'rebuff': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'rebuke': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'rebus': {'n_is_nc': '', 'n_is_sth': ''},
 'rebuttal': {'n_is_nc': '', 'n_is_sth': ''},
 'recantation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'recapitulation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'receipt': {'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'receipts', 'vb_to_vbd': 'receipted', 'vb_to_vbn': 'receipted', 'vb_to_vbg': 'receipting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'receipts': {'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'receipt'},
 'receptacle': {'n_is_nc': '', 'n_is_sth': ''},
 'receptor': {'n_is_nc': '', 'n_is_sth': '0'},
 'recess': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'recession': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'recessional': {'n_is_nc': '', 'n_is_sth': ''},
 'recidivist': {'n_is_nc': '', 'n_is_sb': '0'},
 'recipient': {'n_is_nc': '', 'n_is_sb': '0'},
 'reciprocal': {'n_is_nc': '', 'n_is_sth': ''},
 'recital': {'n_is_nc': '', 'n_is_sth': ''},
 'recitation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'recitative': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'reckoning': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'reckon', 'vbg_to_vbn': 'reckoned'},
 'reclamation': {'n_is_nc': '', 'n_is_sth': ''},
 'recluse': {'n_is_nc': '', 'n_is_sb': '0'},
 'recollection': {'n_is_nc': '', 'n_is_sth': ''},
 'reconstruction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'recorder': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nc_typical': ''},
 'recreation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'recruit': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'rectangle': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'rectification': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'rector': {'n_is_nc': '', 'n_is_sb': '0'},
 'rectum': {'n_is_nc': '', 'n_is_sth': ''},
 'recurrence': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'redbud': {'n_is_nc': '', 'n_is_sth': ''},
 'redneck': {'n_is_nc': '', 'n_is_sb': '0'},
 'reducer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'redundancy': {'n_is_nc': '', 'n_is_nu': ''},
 'redwood': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'reef': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'reefer': {'n_is_nc': '', 'n_is_sb': '0'},
 'reel': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'refectory': {'n_is_nc': '', 'n_is_sth': ''},
 'referee': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'referral': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'refill': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'refinement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'refine'},
 'refinery': {'n_is_nc': '', 'n_is_sth': ''},
 'refit': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'reflection': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'reflect', 'nn_to_jj': 'reflective', 'nn_to_rb': 'reflectively'},
 'reflectivity': {'n_is_nc': '', 'n_is_sth': ''},
 'reflector': {'n_is_nc': '', 'n_is_sth': ''},
 'reflex': {'n_is_nc': '', 'n_is_sth': ''},
 'reform': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'reforms', 'vb_to_vbd': 'reformed', 'vb_to_vbn': 'reformed', 'vb_to_vbg': 'reforming', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'reformist': {'n_is_nc': '', 'n_is_sb': '0'},
 'refresher': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'refresh'},
 'refrigerant': {'n_is_nc': '', 'n_is_sth': ''},
 'refund': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'refusal': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'refuse'},
 'refutation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'regency': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'regent': {'n_is_nc': '', 'n_is_sb': '0'},
 'regicide': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'regimen': {'n_is_nc': '', 'n_is_sth': ''},
 'regiment': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'register': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_with': '', 'v_for': '', 'vb_to_vbz': 'registers', 'vb_to_vbd': 'registered', 'vb_to_vbn': 'registered', 'vb_to_nn': 'registration', 'vb_to_vbg': 'registering', 'vbd_eq_vbn': ''},
 'registrar': {'n_is_nc': '', 'n_is_sb': '0'},
 'registry': {'n_is_nc': '', 'n_is_sth': ''},
 'regression': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'regret': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'regretful', 'nn_to_rb': 'regretfully', 'v_compcl': '', 'v_vbg': '', 'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'regrets', 'vb_to_vbd': 'regretted', 'vb_to_vbn': 'regretted', 'vb_to_rb': 'regretfully', 'vb_to_jj': 'regretful', 'vb_to_vbg': 'regreting', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'regularity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'regular', 'nn_to_rb': 'regularly'},
 'regulator': {'n_is_nc': '', 'n_is_sb': '0'},
 'rehash': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'rehearsal': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'reign': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'rein': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'reincarnation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'reindeer': {'n_is_nc': '', 'n_is_sb': '0'},
 'reinforcement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'reinforce'},
 'reinstatement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'reissue': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'reiteration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'rejection': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'reject', 'nn_to_jj': 'rejective'},
 'rejoicing': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'rejoinder': {'n_is_nc': '', 'n_is_sth': ''},
 'relapse': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'relation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_vb': 'relate'},
 'relaxation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'relax'},
 'relay': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'vt_typical': ''},
 'relic': {'n_is_nc': '', 'n_is_sth': ''},
 'religion': {'n_is_nc': '', 'n_is_nu': '', 'nn_to_jj': 'religious', 'nn_to_rb': 'religiously'},
 'relish': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_vbg': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'remains': {'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'remain'},
 'remake': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'remark': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'remarkable', 'nn_to_rb': 'remarkably', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'vb_to_vbz': 'remarks', 'vb_to_vbd': 'remarked', 'vb_to_vbn': 'remarked', 'vb_to_vbg': 'remarking', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'remarriage': {'n_is_nc': '', 'n_is_sth': ''},
 'rematch': {'n_is_nc': '', 'n_is_sth': ''},
 'remedy': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'remembrance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'reminiscence': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'remission': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'remittance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'remnant': {'n_is_nc': '', 'n_is_sth': ''},
 'remonstrance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'removal': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'remove', 'nn_to_jj': 'removable'},
 'remover': {'n_is_nc': '', 'n_is_sb': '0'},
 'remuneration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'renaissance': {'n_is_nc': '', 'n_is_sth': ''},
 'renascence': {'n_is_nc': '', 'n_is_sth': ''},
 'rendering': {'n_is_nc': '', 'n_is_sth': ''},
 'rendezvous': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'rendition': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'renegade': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'renovation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'renter': {'n_is_nc': '', 'n_is_sb': '0'},
 'renunciation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'repairman': {'n_is_nc': '', 'n_is_sb': '0'},
 'reparation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'repast': {'n_is_nc': '', 'n_is_sth': ''},
 'repayment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'repeater': {'n_is_nc': '', 'n_is_sb': '0'},
 'repellent': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'repercussion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'repertoire': {'n_is_nc': '', 'n_is_sth': ''},
 'repertory': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'repetition': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'repeat', 'nn_to_jj': 'repeated', 'nn_to_rb': 'repeatedly'},
 'replay': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'replica': {'n_is_nc': '', 'n_is_sth': ''},
 'replication': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'repository': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'repossession': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'representation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'represent', 'nn_to_jj': 'representative', 'nn_to_rb': 'representively'},
 'repression': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'reprieve': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'reprimand': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'reprint': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'reprisal': {'n_is_nc': '', 'n_is_sth': ''},
 'reproach': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'reprobate': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'reproduction': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'reproduce'},
 'reproof': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'reproval': {'n_is_nc': '', 'n_is_sth': ''},
 'reptile': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'reptilian': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'republication': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'requiem': {'n_is_nc': '', 'n_is_sth': ''},
 'requisite': {'n_is_nc': '', 'n_is_sth': ''},
 'requisition': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'rescue': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'rescues', 'vb_to_vbd': 'rescued', 'vb_to_vbn': 'rescued', 'vb_to_vbg': 'rescuing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'rescuer': {'n_is_nc': '', 'n_is_sb': '0'},
 'resemblance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'reservoir': {'n_is_nc': '', 'n_is_sth': ''},
 'residency': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'residual': {'n_is_nc': '', 'n_is_sth': ''},
 'residue': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'resistor': {'n_is_nc': '', 'n_is_sth': '0'},
 'resolve': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_against': '', 'vb_to_vbz': 'resolves', 'vb_to_vbd': 'resolved', 'vb_to_vbn': 'resolved', 'vb_to_vbg': 'resolving', 'vbd_eq_vbn': ''},
 'resonance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'resonator': {'n_is_nc': '', 'n_is_sth': ''},
 'resource': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'resourceful'},
 'respiration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'respirator': {'n_is_nc': '', 'n_is_sth': ''},
 'responsibility': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'responsible', 'n_to_v': ''},
 'rest': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vbe': '', 'vdo': '', 'v_on': '', 'v_with': '', 'v_against': '', 'v_from': '', 'vb_to_vbz': 'rests', 'vb_to_vbd': 'rested', 'vb_to_vbn': 'rested', 'vb_to_vbg': 'resting', 'vi_typical': '', 'vbd_eq_vbn': ''},
 'restatement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'restoration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'restore'},
 'restorative': {'n_is_nc': '', 'n_is_sth': ''},
 'restraint': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'restrain'},
 'restriction': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'restrict', 'nn_to_jj': 'restrictive', 'nn_to_rb': 'restrictively'},
 'restroom': {'n_is_nc': '', 'n_is_sth': ''},
 'result': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_from': '', 'vb_to_vbz': 'results', 'vb_to_vbd': 'resulted', 'vb_to_vbn': 'resulted', 'vb_to_vbg': 'resulting', 'vbd_eq_vbn': '', 'vi_typical': '', 'nn_to_nns': 'results'},
 'resultant': {'n_is_nc': '', 'n_is_sth': ''},
 'resumption': {'n_is_nc': '', 'n_is_sth': ''},
 'retainer': {'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'retain'},
 'retard': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'retina': {'n_is_nc': '', 'n_is_sth': ''},
 'retinue': {'n_is_nc': '', 'n_is_sb': '0'},
 'retirement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'retire'},
 'retraction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'retrenchment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'retrial': {'n_is_nc': '', 'n_is_sth': ''},
 'retro': {'n_is_nc': '', 'n_is_sth': ''},
 'rev': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'revel': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'revelation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'reverberation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'reverend': {'n_is_nc': '', 'n_is_sb': '0'},
 'reverie': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'reversal': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'reverse', 'nn_to_jj': 'reversible'},
 'reversion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'review': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'reviews', 'vb_to_vbd': 'reviewed', 'vb_to_vbn': 'reviewed', 'vb_to_vbg': 'reviewing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'reviewer': {'n_is_nc': '', 'n_is_sb': '0'},
 'revise': {'n_is_nc': '', 'n_is_sth': '', 'vb_to_nn': 'revision', 'v_compcl_non': ''},
 'reviser': {'n_is_nc': '', 'n_is_sb': '0'},
 'revision': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'revise'},
 'revocation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'revoke': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'vbg_non': ''},
 'revolt': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'revolution': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'revolutionise', 'nn_to_jj': 'revolutionary'},
 'revolver': {'n_is_nc': '', 'n_is_sth': ''},
 'revue': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'rhapsody': {'n_is_nc': '', 'n_is_sth': ''},
 'rhea': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'rheostat': {'n_is_nc': '', 'n_is_sth': ''},
 'rhesus': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'rhinestone': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'rhino': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'rhinoceros': {'n_is_nc': '', 'n_is_sb': '3', 'nn_eq_nns': '', 'n_is_sth': '3'},
 'rhizome': {'n_is_nc': '', 'n_is_sth': ''},
 'rhyme': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'rib': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'ribbon': {'n_is_nc': '', 'n_is_sth': ''},
 'riches': {'n_is_nc': '', 'n_is_sth': ''},
 'rickshaw': {'n_is_nc': '', 'n_is_sth': ''},
 'rictus': {'n_is_nc': '', 'n_is_sth': ''},
 'riddle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'ridge': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'riff': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'riffle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'riffraff': {'n_is_nc': '', 'n_is_sb': '0'},
 'rifle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'rifleman': {'n_is_nc': '', 'n_is_sb': '0'},
 'rift': {'n_is_nc': '', 'n_is_sth': ''},
 'rig': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'rigger': {'n_is_nc': '', 'n_is_sb': '0'},
 'rill': {'n_is_nc': '', 'n_is_sth': ''},
 'rim': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'ringer': {'n_is_nc': '', 'n_is_sb': '0'},
 'ringleader': {'n_is_nc': '', 'n_is_sb': '0'},
 'rink': {'n_is_nc': '', 'n_is_sth': ''},
 'rinse': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'riot': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_pass_non': ''},
 'ripper': {'n_is_nc': '', 'n_is_sb': '0'},
 'ripple': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'riptide': {'n_is_nc': '', 'n_is_sth': ''},
 'rise': {'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'rises', 'vb_to_vbd': 'rised', 'vb_to_vbn': 'rised', 'vb_to_vbg': 'rising', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_pass_non': ''},
 'rising': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'rise', 'vbg_to_vbn': 'rised'},
 'risk': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'risky', 'nn_to_rb': 'riskily', 'v_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'risks', 'vb_to_vbd': 'risked', 'vb_to_vbn': 'risked', 'vb_to_rb': 'riskily', 'vb_to_jj': 'risky', 'vb_to_vbg': 'risking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': '', 'vt_typical': ''},
 'rite': {'n_is_nc': '', 'n_is_sth': ''},
 'riverbank': {'n_is_nc': '', 'n_is_sth': ''},
 'riverbed': {'n_is_nc': '', 'n_is_sth': ''},
 'riverside': {'n_is_nc': ''},
 'rivet': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'riveter': {'n_is_nc': '', 'n_is_sb': '0'},
 'rivulet': {'n_is_nc': '', 'n_is_sth': ''},
 'roach': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'roadbed': {'n_is_nc': '', 'n_is_sth': ''},
 'roadblock': {'n_is_nc': '', 'n_is_sth': ''},
 'roadhouse': {'n_is_nc': '', 'n_is_sth': ''},
 'roadside': {'n_is_nc': '', 'n_is_sth': ''},
 'roadster': {'n_is_nc': '', 'n_is_sth': ''},
 'roadway': {'n_is_nc': '', 'n_is_sth': ''},
 'roamer': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'roar': {'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'v_prprtcl_non': ''},
 'roast': {'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'roaster': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'robber': {'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'rob'},
 'robe': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'robin': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'robot': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'roc': {'n_is_nc': '', 'n_is_sb': '0'},
 'rocker': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'rod': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'roe': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'roebuck': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'roentgen': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'rogue': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'rollback': {'n_is_nc': '', 'n_is_sth': ''},
 'roller': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_vb': 'roll', 'nc_typical': ''},
 'rollover': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'roly-poly': {'n_is_nc': '', 'n_is_sb': '0'},
 'roman': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '0', 'n_is_sth': ''},
 'romany': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '0'},
 'romp': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'rondeau': {'n_is_nc': '', 'n_is_sth': ''},
 'rood': {'n_is_nc': '', 'n_is_sth': ''},
 'roofer': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'rooftop': {'n_is_nc': '', 'n_is_sth': ''},
 'rook': {'n_is_nc': '', 'n_is_sb': '0'},
 'rookery': {'n_is_nc': '', 'n_is_sth': ''},
 'rookie': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'roomful': {'n_is_nc': '', 'n_is_sb': '0'},
 'roomie': {'n_is_nc': '', 'n_is_sb': '0'},
 'roommate': {'n_is_nc': '', 'n_is_sb': '0'},
 'roost': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'rooster': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'rooter': {'n_is_nc': '', 'n_is_sb': '0'},
 'rootstock': {'n_is_nc': '', 'n_is_sth': ''},
 'rope': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'ropes', 'vb_to_vbd': 'roped', 'vb_to_vbn': 'roped', 'vb_to_vbg': 'roping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'rosary': {'n_is_nc': '', 'n_is_sth': ''},
 'rosebush': {'n_is_nc': '', 'n_is_sth': ''},
 'rosette': {'n_is_nc': '', 'n_is_sth': ''},
 'rosewood': {'n_is_nc': '', 'n_is_sth': ''},
 'rostrum': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'rota': {'n_is_nc': '', 'n_is_sth': ''},
 'rotor': {'n_is_nc': '', 'n_is_sth': ''},
 'rotter': {'n_is_nc': '', 'n_is_sb': '0'},
 'roughneck': {'n_is_nc': '', 'n_is_sb': '0'},
 'roulade': {'n_is_nc': '', 'n_is_sth': ''},
 'roundelay': {'n_is_nc': '', 'n_is_sth': ''},
 'roundworm': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'rout': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'rover': {'n_is_nc': '', 'n_is_sb': '0'},
 'rowboat': {'n_is_nc': '', 'n_is_sth': ''},
 'rowdy': {'n_is_nc': '', 'n_is_sb': '0', 'jj_to_jjr': 'rowdier', 'jj_to_jjs': 'rowdiest'},
 'royalist': {'n_is_nc': '', 'n_is_sb': '0'},
 'royalty': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'royal', 'nn_to_rb': 'royally'},
 'rub': {'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_at': '', 'v_against': '', 'vb_to_vbz': 'rubs', 'vb_to_vbd': 'rubbed', 'vb_to_vbn': 'rubbed', 'vb_to_vbg': 'rubbing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'rubberneck': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'rubbing': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'rub', 'vbg_to_vbn': 'rubbed'},
 'rubdown': {'n_is_nc': '', 'n_is_sth': ''},
 'rube': {'n_is_nc': '', 'n_is_sb': '0'},
 'rubric': {'n_is_nc': '', 'n_is_sth': ''},
 'ruby': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'ruck': {'n_is_nc': '', 'n_is_sth': ''},
 'rucksack': {'n_is_nc': '', 'n_is_sth': ''},
 'rudder': {'n_is_nc': '', 'n_is_sth': ''},
 'ruffian': {'n_is_nc': '', 'n_is_sb': '0'},
 'ruffle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'rug': {'n_is_nc': '', 'n_is_sth': ''},
 'ruin': {'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'ruins', 'vb_to_vbd': 'ruined', 'vb_to_vbn': 'ruined', 'vb_to_vbg': 'ruining', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vt_typical': ''},
 'rumba': {'n_is_nc': '', 'n_is_sth': ''},
 'rumble': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'rumination': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'rummage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'rummy': {'n_is_nc': '', 'n_is_sb': '0'},
 'rumor': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'rumour': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'rump': {'n_is_nc': '', 'n_is_sth': ''},
 'rumpus': {'n_is_nc': '', 'n_is_sth': ''},
 'run-in': {'n_is_nc': '', 'n_is_sth': ''},
 'run-through': {'n_is_nc': '', 'n_is_sth': ''},
 'run-up': {'n_is_nc': '', 'n_is_sth': ''},
 'runabout': {'n_is_nc': '', 'n_is_sb': '0', 'n_is_sth': ''},
 'runaway': {'n_is_nc': '', 'n_is_sb': '0'},
 'rundown': {'n_is_nc': '', 'n_is_sth': ''},
 'rune': {'n_is_nc': '', 'n_is_sth': ''},
 'rung': {'n_is_nc': '', 'n_is_sth': ''},
 'runner-up': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'runoff': {'n_is_nc': '', 'n_is_sth': ''},
 'rupee': {'n_is_nc': '', 'n_is_sth': ''},
 'rupiah': {'n_is_nc': '', 'n_is_sth': ''},
 'rupture': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'ruse': {'n_is_nc': '', 'n_is_sth': ''},
 'rush': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'rushes', 'vb_to_vbd': 'rushed', 'vb_to_vbn': 'rushed', 'vb_to_vbg': 'rushing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'rusk': {'n_is_nc': '', 'n_is_sth': ''},
 'russet': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'rustic': {'n_is_nc': '', 'n_is_sb': '0'},
 'rustler': {'n_is_nc': '', 'n_is_sb': '0'},
 'rut': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'rutabaga': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'rye': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'saber': {'n_is_nc': '', 'n_is_sth': ''},
 'sable': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'sabre': {'n_is_nc': '', 'n_is_sb': '0'},
 'sac': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'sachem': {'n_is_nc': '', 'n_is_sb': '0'},
 'sachet': {'n_is_nc': '', 'n_is_sth': ''},
 'sacrament': {'n_is_nc': '', 'n_is_sth': ''},
 'sacrifice': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'sacrificial', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'sacrilege': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'sacrum': {'n_is_nc': '', 'n_is_sth': ''},
 'saddle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'saddlebag': {'n_is_nc': '', 'n_is_sth': ''},
 'safari': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'safflower': {'n_is_nc': '', 'n_is_sth': ''},
 'sage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '0'},
 'sago': {'n_is_nc': '', 'n_is_sth': ''},
 'saguaro': {'n_is_nc': '', 'n_is_sth': ''},
 'sahib': {'n_is_nc': '', 'n_is_sb': '0'},
 'sailboat': {'n_is_nc': '', 'n_is_sth': ''},
 'sailfish': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'sailing': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'sail', 'vbg_to_vb': 'sail', 'vbg_to_vbn': 'sailed'},
 'sailplane': {'n_is_nc': '', 'n_is_sth': ''},
 'saint': {'n_is_nc': '', 'n_is_sb': '0'},
 'salamander': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'salesclerk': {'n_is_nc': '', 'n_is_sb': '0'},
 'salesperson': {'n_is_nc': '', 'n_is_sb': '0'},
 'salience': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'salina': {'n_is_nc': '', 'n_is_sth': ''},
 'sally': {'n_is_nc': '', 'n_is_sth': ''},
 'salon': {'n_is_nc': '', 'n_is_sth': ''},
 'saloon': {'n_is_nc': '', 'n_is_sth': ''},
 'salter': {'n_is_nc': '', 'n_is_sb': '0'},
 'salutation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'salute': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'salve': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'salvo': {'n_is_nc': '', 'n_is_sth': ''},
 'samara': {'n_is_nc': '', 'n_is_sth': ''},
 'samovar': {'n_is_nc': '', 'n_is_sth': ''},
 'sampan': {'n_is_nc': '', 'n_is_sth': ''},
 'sampler': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'samurai': {'n_is_nc': '', 'n_is_sb': '0'},
 'sanatorium': {'n_is_nc': '', 'n_is_sth': ''},
 'sanction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_vbg': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'sanctuary': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'sanctum': {'n_is_nc': '', 'n_is_sth': ''},
 'sandal': {'n_is_nc': '', 'n_is_sth': ''},
 'sandbag': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'sandbar': {'n_is_nc': '', 'n_is_sth': ''},
 'sandblast': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'sandlot': {'n_is_nc': '', 'n_is_sth': ''},
 'sandpiper': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'sandpit': {'n_is_nc': '', 'n_is_sth': ''},
 'sandstorm': {'n_is_nc': '', 'n_is_sth': ''},
 'sang': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'sing', 'nn_to_jj': 'singing', 'nn_to_rb': 'singingly', 'vbd_to_vb': 'sing', 'vbd_to_vbn': 'sung'},
 'sanitarium': {'n_is_nc': '', 'n_is_sth': ''},
 'sap': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'sapling': {'n_is_nc': '', 'n_is_sth': ''},
 'sarcoma': {'n_is_nc': '', 'n_is_sth': ''},
 'sardine': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'sarong': {'n_is_nc': '', 'n_is_sth': ''},
 'sartor': {'n_is_nc': '', 'n_is_sb': '0'},
 'sash': {'n_is_nc': '', 'n_is_sth': ''},
 'sasquatch': {'n_is_nc': '', 'n_is_sb': '0'},
 'sass': {'n_is_nc': '', 'n_is_sth': ''},
 'sassafras': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'satchel': {'n_is_nc': '', 'n_is_sth': ''},
 'satire': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'satrap': {'n_is_nc': '', 'n_is_sb': '0'},
 'saucepan': {'n_is_nc': '', 'n_is_sth': ''},
 'saucer': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'sausage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'savage': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'savagery': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'savant': {'n_is_nc': '', 'n_is_sb': '0'},
 'savior': {'n_is_nc': '', 'n_is_sb': '0'},
 'saviour': {'n_is_nc': '', 'n_is_sb': '0'},
 'savor': {'n_is_nc': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'n_is_sth': '0'},
 'savory': {'n_is_nc': '', 'n_is_sth': ''},
 'saw': {'n_is_nc': '', 'n_is_sth': '', 'vbd_to_vb': 'see', 'vbd_to_vbn': 'seen', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'saxophone': {'n_is_nc': '', 'n_is_sth': ''},
 'scab': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'scabbard': {'n_is_nc': '', 'n_is_sth': ''},
 'scad': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'scaffold': {'n_is_nc': '', 'n_is_sth': ''},
 'scalawag': {'n_is_nc': '', 'n_is_sb': '0'},
 'scale': {'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'scales', 'vb_to_vbd': 'scaled', 'vb_to_vbn': 'scaled', 'vb_to_vbg': 'scaling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'scallion': {'n_is_nc': '', 'n_is_sth': ''},
 'scallop': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'scalp': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'scalpel': {'n_is_nc': '', 'n_is_sth': ''},
 'scalper': {'n_is_nc': '', 'n_is_sb': '0'},
 'scam': {'n_is_nc': '', 'n_is_sth': ''},
 'scamp': {'n_is_nc': '', 'n_is_sb': '0'},
 'scamper': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'scan': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'scandal': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'scanner': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'scape': {'n_is_nc': '', 'n_is_sth': ''},
 'scapegoat': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'scapula': {'n_is_nc': '', 'n_is_sth': ''},
 'scapular': {'n_is_nc': '', 'n_is_sth': ''},
 'scar': {'n_is_nc': '', 'n_is_sth': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'scarab': {'n_is_nc': '', 'n_is_sb': '0'},
 'scarecrow': {'n_is_nc': '', 'n_is_sth': ''},
 'scatter': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'scattering': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'scavenger': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'scenarist': {'n_is_nc': '', 'n_is_sb': '0'},
 'scent': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'scepter': {'n_is_nc': '', 'n_is_sth': ''},
 'schemer': {'n_is_nc': '', 'n_is_sb': '0'},
 'schilling': {'n_is_nc': '', 'n_is_sth': ''},
 'schism': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'schlock': {'n_is_nc': '', 'n_is_sth': ''},
 'schmo': {'n_is_nc': '', 'n_is_sb': '0'},
 'schmooze': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'schmuck': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'schnitzel': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'schnook': {'n_is_nc': '', 'n_is_sb': '0'},
 'schoolbook': {'n_is_nc': '', 'n_is_sth': ''},
 'schoolboy': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'schoolchild': {'n_is_nc': '', 'n_is_sb': '0'},
 'schoolgirl': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'schoolhouse': {'n_is_nc': '', 'n_is_sth': ''},
 'schoolmaster': {'n_is_nc': '', 'n_is_sb': '0'},
 'schoolmate': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'schoolroom': {'n_is_nc': '', 'n_is_sth': ''},
 'schoolteacher': {'n_is_nc': '', 'n_is_sb': '0'},
 'schoolyard': {'n_is_nc': '', 'n_is_sth': ''},
 'schooner': {'n_is_nc': '', 'n_is_sth': ''},
 'science': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'scientific', 'nn_to_rb': 'scientifically'},
 'scintilla': {'n_is_nc': '', 'n_is_sth': ''},
 'scion': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'scissors': {'n_is_nc': '', 'n_is_sth': '', 'nn_eq_nns': ''},
 'scoff': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'scold': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'scolding': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'sconce': {'n_is_nc': '', 'n_is_sth': ''},
 'scone': {'n_is_nc': '', 'n_is_sth': ''},
 'scoop': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'scope': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'scorcher': {'n_is_nc': '', 'n_is_sth': ''},
 'scoreboard': {'n_is_nc': '', 'n_is_sth': ''},
 'scorpio': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'scorpion': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'scotch': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'scoundrel': {'n_is_nc': '', 'n_is_sb': '0'},
 'scourge': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'scout': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'scow': {'n_is_nc': '', 'n_is_sth': ''},
 'scowl': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'scrabble': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'scramble': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'scrap': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'scrape': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'scraper': {'n_is_nc': '', 'n_is_sth': ''},
 'scrapper': {'n_is_nc': '', 'n_is_sb': '0'},
 'scraps': {'n_is_nc': '', 'n_is_sth': ''},
 'scree': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'screech': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'screed': {'n_is_nc': '', 'n_is_sth': ''},
 'screening': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'screen', 'vbg_to_vbn': 'screened'},
 'screenwriter': {'n_is_nc': '', 'n_is_sb': '0'},
 'scribe': {'n_is_nc': '', 'n_is_sb': '0'},
 'scrimmage': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'scrip': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'scripture': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'scriptwriter': {'n_is_nc': '', 'n_is_sb': '0'},
 'scrivener': {'n_is_nc': '', 'n_is_sb': '0'},
 'scrod': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'scroll': {'n_is_nc': '', 'n_is_sth': ''},
 'scrooge': {'n_is_nc': '', 'n_is_sb': '0'},
 'scrotum': {'n_is_nc': '', 'n_is_sth': ''},
 'scrubber': {'n_is_nc': '', 'n_is_sb': '0'},
 'scruff': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'scruple': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'scud': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'scuff': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'scuffle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'scupper': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'scut': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'scuttle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'seabed': {'n_is_nc': '', 'n_is_sth': ''},
 'seabird': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'seaboard': {'n_is_nc': '', 'n_is_sth': ''},
 'seacoast': {'n_is_nc': '', 'n_is_sth': ''},
 'seafarer': {'n_is_nc': '', 'n_is_sb': '0'},
 'seagull': {'n_is_nc': '', 'n_is_sb': '3', 'nc_typical': '', 'n_is_sth': '3'},
 'sealer': {'n_is_nc': '', 'n_is_sb': '0'},
 'seam': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'seance': {'n_is_nc': '', 'n_is_sth': ''},
 'seaplane': {'n_is_nc': '', 'n_is_sth': ''},
 'seaport': {'n_is_nc': '', 'n_is_sth': ''},
 'searcher': {'n_is_nc': '', 'n_is_sb': '0', 'n_is_sth': ''},
 'searchlight': {'n_is_nc': '', 'n_is_sth': ''},
 'seascape': {'n_is_nc': '', 'n_is_sth': ''},
 'seashell': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'nc_typical': ''},
 'seashore': {'n_is_nc': '', 'n_is_sth': ''},
 'seaside': {'n_is_nc': '', 'n_is_sth': ''},
 'seasoning': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'season', 'vbg_to_vbn': 'seasoned'},
 'seawall': {'n_is_nc': '', 'n_is_sth': ''},
 'seaway': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'secession': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'secretariat': {'n_is_nc': '', 'n_is_sb': '0'},
 'secretion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'sect': {'n_is_nc': '', 'n_is_sth': ''},
 'secular': {'n_is_nc': '', 'n_is_sb': '0'},
 'sedan': {'n_is_nc': '', 'n_is_sth': ''},
 'sedative': {'n_is_nc': '', 'n_is_sth': ''},
 'sediment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'seduction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'seedbed': {'n_is_nc': '', 'n_is_sth': ''},
 'seedling': {'n_is_nc': '', 'n_is_sth': ''},
 'seeker': {'n_is_nc': '', 'n_is_sb': '0'},
 'seepage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'seer': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'seesaw': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'seigneur': {'n_is_nc': '', 'n_is_sb': '0'},
 'seine': {'n_is_nc': '', 'n_is_sth': ''},
 'seismograph': {'n_is_nc': '', 'n_is_sth': ''},
 'seizure': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'selection': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'select', 'nn_to_jj': 'selective', 'nn_to_rb': 'selectively'},
 'self-contradiction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'self-interest': {'n_is_nc': '', 'n_is_sth': ''},
 'sell': {'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_at': '', 'v_for': '', 'vb_to_vbz': 'sells', 'vb_to_vbd': 'sold', 'vb_to_vbn': 'sold', 'vb_to_vbg': 'selling', 'v_compcl_non': ''},
 'selvage': {'n_is_nc': '', 'n_is_sth': ''},
 'semester': {'n_is_nc': '', 'n_is_sth': ''},
 'semicircle': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'semicolon': {'n_is_nc': '', 'n_is_sth': ''},
 'semifinal': {'n_is_nc': '', 'n_is_sth': ''},
 'seminar': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'seminary': {'n_is_nc': '', 'n_is_sth': ''},
 'semitrailer': {'n_is_nc': '', 'n_is_sth': ''},
 'send-off': {'n_is_nc': '', 'n_is_sth': ''},
 'sender': {'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'send'},
 'senor': {'n_is_nc': '', 'n_is_sb': '0'},
 'senora': {'n_is_nc': '', 'n_is_sb': '0'},
 'senorita': {'n_is_nc': '', 'n_is_sb': '0'},
 'sensation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'sensibility': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'sensing': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'sense', 'vbg_to_vbn': 'sensed'},
 'sensor': {'n_is_nc': '', 'n_is_sth': ''},
 'sentinel': {'n_is_nc': '', 'n_is_sb': '0'},
 'separation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'separator': {'n_is_nc': '', 'n_is_sth': ''},
 'septum': {'n_is_nc': '', 'n_is_sth': ''},
 'sepulcher': {'n_is_nc': '', 'n_is_sth': ''},
 'sequel': {'n_is_nc': '', 'n_is_sth': ''},
 'sequestration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'seraglio': {'n_is_nc': '', 'n_is_sth': ''},
 'serenade': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'serf': {'n_is_nc': '', 'n_is_sb': '0'},
 'sergeant': {'n_is_nc': '', 'n_is_sb': '0'},
 'serial': {'n_is_nc': '', 'n_is_sth': ''},
 'series': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_eq_nns': ''},
 'sermon': {'n_is_nc': '', 'n_is_sth': ''},
 'serpent': {'n_is_nc': '', 'n_is_sb': '0'},
 'serum': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'serviceman': {'n_is_nc': '', 'n_is_sb': '0'},
 'serving': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'serve', 'vbg_to_vb': 'serve', 'vbg_to_vbn': 'served'},
 'servo': {'n_is_nc': '', 'n_is_sth': ''},
 'seta': {'n_is_nc': '', 'n_is_sth': ''},
 'setoff': {'n_is_nc': '', 'n_is_sth': ''},
 'settee': {'n_is_nc': '', 'n_is_sth': ''},
 'setter': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'setting': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'set', 'vbg_to_vbn': 'set'},
 'settlement': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'settle'},
 'sewer': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'sextant': {'n_is_nc': '', 'n_is_sth': ''},
 'shack': {'n_is_nc': '', 'n_is_sth': ''},
 'shackle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'shade': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'shades': {'n_is_nc': '', 'n_is_sth': ''},
 'shading': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'shade'},
 'shaft': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'shakedown': {'n_is_nc': '', 'n_is_sth': ''},
 'shakeout': {'n_is_nc': '', 'n_is_sth': ''},
 'shaker': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'shakeup': {'n_is_nc': '', 'n_is_sth': ''},
 'shallot': {'n_is_nc': '', 'n_is_sth': ''},
 'sham': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'shaman': {'n_is_nc': '', 'n_is_sb': '0'},
 'shambles': {'n_is_nc': '', 'n_is_sth': ''},
 'shampoo': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'shamrock': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'shamus': {'n_is_nc': '', 'n_is_sb': '0'},
 'shank': {'n_is_nc': '', 'n_is_sth': ''},
 'shanty': {'n_is_nc': '', 'n_is_sth': ''},
 'shantytown': {'n_is_nc': '', 'n_is_sth': ''},
 'shape': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'shapes', 'vb_to_vbd': 'shaped', 'vb_to_vbn': 'shaped', 'vb_to_vbg': 'shaping', 'vbd_eq_vbn': ''},
 'shaper': {'n_is_nc': '', 'n_is_sb': '0'},
 'shard': {'n_is_nc': '', 'n_is_sth': ''},
 'shareholding': {'n_is_nc': '', 'n_is_sth': ''},
 'shareowner': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'shark': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'sharpener': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'sharpie': {'n_is_nc': '', 'n_is_sb': '0'},
 'sharpshooter': {'n_is_nc': '', 'n_is_sb': '0'},
 'shaver': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'shaving': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'shave', 'vbg_to_vbn': 'shaved'},
 'shawl': {'n_is_nc': '', 'n_is_sth': ''},
 'shearing': {'n_is_nc': '', 'n_is_sth': ''},
 'shears': {'n_is_nc': '', 'n_is_sth': ''},
 'shearwater': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'sheath': {'n_is_nc': '', 'n_is_sth': ''},
 'sheathing': {'n_is_nc': '', 'n_is_sth': ''},
 'shebang': {'n_is_nc': '', 'n_is_sth': ''},
 'sheep': {'n_is_nc': '', 'n_is_sb': '3', 'nn_eq_nns': '', 'n_is_sth': '3'},
 'sheepherder': {'n_is_nc': '', 'n_is_sb': '0'},
 'sheepskin': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'sheik': {'n_is_nc': '', 'n_is_sb': '0'},
 'sheikh': {'n_is_nc': '', 'n_is_sb': '0'},
 'shellfish': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'shenanigan': {'n_is_nc': '', 'n_is_sth': ''},
 'shepherd': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'sherry': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'shibboleth': {'n_is_nc': '', 'n_is_sth': ''},
 'shield': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'shifter': {'n_is_nc': '', 'n_is_sb': '0'},
 'shifting': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'shift', 'vbg_to_vbn': 'shifted'},
 'shill': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'shilling': {'n_is_nc': '', 'n_is_sth': ''},
 'shim': {'n_is_nc': '', 'n_is_sth': ''},
 'shimmy': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'shin': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'shine': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'shiny', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_at': '', 'v_in': '', 'v_with': '', 'vb_to_vbz': 'shines', 'vb_to_vbd': 'shone', 'vb_to_vbn': 'shone', 'vb_to_jj': 'shiny', 'vb_to_vbg': 'shining', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'shiner': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'shingle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'shipment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'ship'},
 'shipowner': {'n_is_nc': '', 'n_is_sb': '0'},
 'shipper': {'n_is_nc': '', 'n_is_sb': '0'},
 'shipwreck': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'shipyard': {'n_is_nc': '', 'n_is_sth': ''},
 'shire': {'n_is_nc': '', 'n_is_sth': ''},
 'shit': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': ''},
 'shiv': {'n_is_nc': '', 'n_is_sth': ''},
 'shiver': {'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'shoal': {'n_is_nc': '', 'n_is_sth': ''},
 'shocker': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'shoehorn': {'n_is_nc': '', 'n_is_sth': ''},
 'shoelace': {'n_is_nc': '', 'n_is_sth': ''},
 'shoemaker': {'n_is_nc': '', 'n_is_sb': '0'},
 'shoestring': {'n_is_nc': '', 'n_is_sth': ''},
 'shooter': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'shooting': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'shoot', 'vbg_to_vbn': 'shot'},
 'shoplifter': {'n_is_nc': '', 'n_is_sb': '0'},
 'shopper': {'n_is_nc': '', 'n_is_sb': '0'},
 'shoreline': {'n_is_nc': '', 'n_is_sth': ''},
 'shortbread': {'n_is_nc': '', 'n_is_sth': ''},
 'shortcoming': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'shortcut': {'n_is_nc': '', 'n_is_sth': ''},
 'shortfall': {'n_is_nc': '', 'n_is_sth': ''},
 'shorthorn': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'shot': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_to_vb': 'shoot', 'vbn_to_vb': 'shoot', 'vbn_to_vbg': 'shooting', 'vbd_eq_vbn': ''},
 'shotgun': {'n_is_nc': '', 'n_is_sth': ''},
 'shove': {'n_is_nc': '', 'n_is_sth': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'shoves', 'vb_to_vbd': 'shoved', 'vb_to_vbn': 'shoved', 'vb_to_vbg': 'shoving', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'shovel': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'show-off': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'showcase': {'n_is_nc': '', 'n_is_sth': ''},
 'showdown': {'n_is_nc': '', 'n_is_sth': ''},
 'showpiece': {'n_is_nc': '', 'n_is_sth': ''},
 'showroom': {'n_is_nc': '', 'n_is_sth': ''},
 'shred': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'shredder': {'n_is_nc': '', 'n_is_sth': ''},
 'shrew': {'n_is_nc': '', 'n_is_sb': '0'},
 'shriek': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'shrike': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'shrine': {'n_is_nc': '', 'n_is_sth': ''},
 'shrink': {'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'n_is_sth': '2'},
 'shroud': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'shrub': {'n_is_nc': '', 'n_is_sth': ''},
 'shrubbery': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'shuck': {'n_is_nc': '', 'n_is_sth': ''},
 'shudder': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'shuffle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'shunt': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'shutout': {'n_is_nc': '', 'n_is_sth': ''},
 'shutter': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'shuttlecock': {'n_is_nc': '', 'n_is_sth': ''},
 'shy': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'jj_to_jjr': 'shyer', 'jj_to_jjs': 'shyest'},
 'shyster': {'n_is_nc': '', 'n_is_sb': '0'},
 'siamese': {'n_is_nc': '', 'n_is_sb': '0', 'n_is_sth': ''},
 'sib': {'n_is_nc': '', 'n_is_sb': '0'},
 'sibling': {'n_is_nc': '', 'n_is_sb': '0'},
 'sickbed': {'n_is_nc': '', 'n_is_sth': ''},
 'sickle': {'n_is_nc': '', 'n_is_sth': ''},
 'sickness': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'sick', 'nn_to_rb': 'sickly'},
 'sickroom': {'n_is_nc': '', 'n_is_sth': ''},
 'sideboard': {'n_is_nc': '', 'n_is_sth': ''},
 'sidekick': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'sidelight': {'n_is_nc': '', 'n_is_sth': ''},
 'sideshow': {'n_is_nc': '', 'n_is_sth': ''},
 'sidetrack': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'sidewinder': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'siding': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'siege': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'sierra': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'siesta': {'n_is_nc': '', 'n_is_sth': ''},
 'sieve': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'sifter': {'n_is_nc': '', 'n_is_sth': ''},
 'sigh': {'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'v_with': '', 'v_for': '', 'vi_typical': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'sightseer': {'n_is_nc': '', 'n_is_sb': '0'},
 'signalman': {'n_is_nc': '', 'n_is_sb': '0'},
 'signboard': {'n_is_nc': '', 'n_is_sth': ''},
 'signet': {'n_is_nc': '', 'n_is_sth': ''},
 'signor': {'n_is_nc': '', 'n_is_sb': '0'},
 'signora': {'n_is_nc': '', 'n_is_sb': '0'},
 'signore': {'n_is_nc': '', 'n_is_sb': '0'},
 'signpost': {'n_is_nc': '', 'n_is_sth': ''},
 'silencer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'silhouette': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'silk': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'silks': {'n_is_nc': '', 'n_is_sth': ''},
 'silkworm': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'sill': {'n_is_nc': '', 'n_is_sth': ''},
 'silo': {'n_is_nc': '', 'n_is_sth': ''},
 'silverfish': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'silversmith': {'n_is_nc': '', 'n_is_sb': '0'},
 'silverware': {'n_is_nc': '', 'n_is_sth': ''},
 'simian': {'n_is_nc': '', 'n_is_sb': '0'},
 'similarity': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'similar', 'nn_to_rb': 'similarly'},
 'simile': {'n_is_nc': '', 'n_is_sth': ''},
 'simpleton': {'n_is_nc': '', 'n_is_sb': '0'},
 'simplification': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'simplify', 'nn_to_jj': 'simple', 'nn_to_rb': 'simply'},
 'simulacrum': {'n_is_nc': '', 'n_is_sth': ''},
 'simulation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'simulate', 'nn_to_jj': 'simulate', 'nn_to_rb': 'simulatedly'},
 'simulator': {'n_is_nc': '', 'n_is_sth': ''},
 'sin': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_to_vbg': '', 'vdo': '', 'v_against': '', 'vb_to_vbz': 'sins', 'vb_to_vbd': 'sinned', 'vb_to_vbn': 'sinned', 'vb_to_vbg': 'sining', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'sine': {'n_is_nc': '', 'n_is_sth': ''},
 'sinecure': {'n_is_nc': '', 'n_is_sth': ''},
 'sinew': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'singlet': {'n_is_nc': '', 'n_is_sth': ''},
 'singsong': {'n_is_nc': '', 'n_is_sth': ''},
 'singular': {'n_is_nc': '', 'n_is_sth': ''},
 'singularity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'sinker': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'sinner': {'n_is_nc': '', 'n_is_sb': '0'},
 'sinus': {'n_is_nc': '', 'n_is_sth': ''},
 'siphon': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'sire': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'siren': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'siskin': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'sissy': {'n_is_nc': '', 'n_is_sb': '0'},
 'sit-down': {'n_is_nc': '', 'n_is_sth': ''},
 'sizing': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'sized', 'vbg_to_vb': 'size', 'vbg_to_vbn': 'sized'},
 'skate': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'skateboard': {'n_is_nc': '', 'n_is_sth': ''},
 'skein': {'n_is_nc': '', 'n_is_sth': ''},
 'skeleton': {'n_is_nc': '', 'n_is_sth': ''},
 'sketch': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'sketchbook': {'n_is_nc': '', 'n_is_sth': ''},
 'skewer': {'n_is_nc': '', 'n_is_sth': ''},
 'skid': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'skiff': {'n_is_nc': '', 'n_is_sth': ''},
 'skimmer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'skin': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'skinned', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'skins', 'vb_to_vbd': 'skinned', 'vb_to_vbn': 'skinned', 'vb_to_jj': 'skinned', 'vb_to_vbg': 'skinning', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'skinflint': {'n_is_nc': '', 'n_is_sb': '0'},
 'skink': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'skip': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'skipper': {'n_is_nc': '', 'n_is_sb': '0'},
 'skirmish': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'skit': {'n_is_nc': '', 'n_is_sth': ''},
 'skull': {'n_is_nc': '', 'n_is_sth': ''},
 'skullcap': {'n_is_nc': '', 'n_is_sth': ''},
 'skunk': {'n_is_nc': '', 'n_is_sb': '3', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'n_is_sth': '3'},
 'skylark': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'skylight': {'n_is_nc': '', 'n_is_sth': ''},
 'skyline': {'n_is_nc': '', 'n_is_sth': ''},
 'skyscraper': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'skyway': {'n_is_nc': '', 'n_is_sth': ''},
 'slab': {'n_is_nc': '', 'n_is_sth': ''},
 'slack': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'jj_to_jjr': 'slacker', 'jj_to_jjs': 'slackest'},
 'slacker': {'n_is_nc': '', 'n_is_sb': '0'},
 'slacks': {'n_is_nc': '', 'n_is_sth': ''},
 'slag': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'slam': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'slammer': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'slander': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'slant': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'slap': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'slash': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'slate': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'slaughterer': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'slaughterhouse': {'n_is_nc': '', 'n_is_sth': ''},
 'slav': {'n_is_nc': '', 'n_is_sb': '0'},
 'slave': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'slaveholder': {'n_is_nc': '', 'n_is_sb': '0'},
 'slayer': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'sled': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'sledge': {'n_is_nc': '', 'n_is_sth': ''},
 'sleep': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'sleeping', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_in': '', 'v_with': '', 'vb_to_vbz': 'sleeps', 'vb_to_vbd': 'slept', 'vb_to_vbn': 'slept', 'vb_to_jj': 'sleeping', 'vb_to_vbg': 'sleeping', 'v_compcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'sleeper': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'sleigh': {'n_is_nc': '', 'n_is_sth': ''},
 'sleuth': {'n_is_nc': '', 'n_is_sb': '0'},
 'slew': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'slicker': {'n_is_nc': '', 'n_is_sb': '0'},
 'slightness': {'n_is_nc': '', 'n_is_sth': ''},
 'sling': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'slinger': {'n_is_nc': '', 'n_is_sb': '0'},
 'slingshot': {'n_is_nc': '', 'n_is_sth': ''},
 'slipcover': {'n_is_nc': '', 'n_is_sth': ''},
 'slipknot': {'n_is_nc': '', 'n_is_sth': ''},
 'slippage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'slipper': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'slit': {'n_is_nc': '', 'n_is_sth': '', 'vb_eq_vbd': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'vbd_eq_vbn': ''},
 'sliver': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'slob': {'n_is_nc': '', 'n_is_sb': '0'},
 'slogan': {'n_is_nc': '', 'n_is_sth': ''},
 'slop': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'slope': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'sloped', 'vb_to_jj': 'sloped', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'slouch': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'slough': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'slowpoke': {'n_is_nc': '', 'n_is_sb': '0'},
 'slug': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'slugfest': {'n_is_nc': '', 'n_is_sth': ''},
 'sluice': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'slum': {'n_is_nc': '', 'n_is_sth': ''},
 'slumber': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'slur': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'slut': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'dirtyword': ''},
 'smack': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'small': {'n_is_nc': '', 'n_is_sth': '', 'jj_to_jjr': 'smaller', 'jj_to_jjs': 'smallest'},
 'smear': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'smelter': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'smithereens': {'n_is_nc': '', 'n_is_sth': ''},
 'smithy': {'n_is_nc': '', 'n_is_sth': ''},
 'smock': {'n_is_nc': '', 'n_is_sth': ''},
 'smog': {'n_is_nc': '', 'n_is_sth': ''},
 'smoke': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'smoking', 'nn_to_rb': 'smoking', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'smokes', 'vb_to_vbd': 'smoked', 'vb_to_vbn': 'smoked', 'vb_to_rb': 'smoking', 'vb_to_jj': 'smoking', 'vb_to_vbg': 'smoking', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'smoker': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'smokescreen': {'n_is_nc': '', 'n_is_sth': ''},
 'smokestack': {'n_is_nc': '', 'n_is_sth': ''},
 'smooch': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'smother': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'smudge': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'smuggler': {'n_is_nc': '', 'n_is_sb': '0'},
 'snack': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'nc_typical': ''},
 'snag': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'snakehead': {'n_is_nc': '', 'n_is_sth': ''},
 'snap': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_at': '', 'vb_to_vbz': 'snapps', 'vb_to_vbd': 'snaped', 'vb_to_vbn': 'snaped', 'vb_to_vbg': 'snapping', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'snapdragon': {'n_is_nc': '', 'n_is_sth': ''},
 'snapper': {'n_is_nc': '', 'n_is_sb': '0'},
 'snapshot': {'n_is_nc': '', 'n_is_sth': ''},
 'snare': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'snarl': {'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'snatch': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'sneak': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'sneer': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'sneeze': {'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'sniff': {'n_is_nc': '', 'n_is_sth': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'snifter': {'n_is_nc': '', 'n_is_sth': ''},
 'snip': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'snipe': {'n_is_nc': '', 'n_is_sb': '3', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'n_is_sth': '3'},
 'sniper': {'n_is_nc': '', 'n_is_sb': '0'},
 'snippet': {'n_is_nc': '', 'n_is_sth': ''},
 'snitch': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'snob': {'n_is_nc': '', 'n_is_sb': '0'},
 'snoot': {'n_is_nc': '', 'n_is_sth': ''},
 'snooze': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'snore': {'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'snort': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'snout': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'snow': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'snowball': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'snowdrift': {'n_is_nc': '', 'n_is_sth': ''},
 'snowfall': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'snowfield': {'n_is_nc': '', 'n_is_sth': ''},
 'snowflake': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'snowman': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'snowstorm': {'n_is_nc': '', 'n_is_sth': ''},
 'snowsuit': {'n_is_nc': '', 'n_is_sth': ''},
 'snub': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'snuff': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'snuffbox': {'n_is_nc': '', 'n_is_sth': ''},
 'snuffle': {'n_is_nc': '', 'n_is_sth': ''},
 'snug': {'n_is_nc': '', 'n_is_sth': '', 'jj_to_jjr': 'snugger', 'jj_to_jjs': 'snuggest'},
 'so-and-so': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'soak': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'soaker': {'n_is_nc': '', 'n_is_sb': '0', 'n_is_sth': ''},
 'soap': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'sob': {'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'sobriquet': {'n_is_nc': '', 'n_is_sth': ''},
 'sociable': {'n_is_nc': '', 'n_is_sth': ''},
 'social': {'n_is_nc': '', 'n_is_sth': '', 'jj_to_nn': 'society'},
 'socialite': {'n_is_nc': '', 'n_is_sb': '0'},
 'sociality': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'sod': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'soda': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'sofa': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'softball': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'softwood': {'n_is_nc': '', 'n_is_sth': ''},
 'sojourn': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'soldiery': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '0'},
 'solenoid': {'n_is_nc': '', 'n_is_sth': ''},
 'solicitation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'solicitude': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'solitary': {'n_is_nc': '', 'n_is_sb': '0'},
 'solon': {'n_is_nc': '', 'n_is_sb': '0'},
 'solstice': {'n_is_nc': '', 'n_is_sth': ''},
 'solution': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'solve', 'nn_to_jj': 'solved'},
 'solvent': {'n_is_nc': '', 'n_is_sth': ''},
 'soma': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'somersault': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'somerset': {'n_is_nc': '', 'n_is_sth': ''},
 'son-in-law': {'n_is_nc': '', 'n_is_sb': '0'},
 'sonata': {'n_is_nc': '', 'n_is_sth': ''},
 'songbird': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'songbook': {'n_is_nc': '', 'n_is_sth': ''},
 'songster': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'sonnet': {'n_is_nc': '', 'n_is_sth': ''},
 'sonny': {'n_is_nc': '', 'n_is_sb': '0'},
 'sop': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'sophistry': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'soprano': {'n_is_nc': '', 'n_is_sb': '0'},
 'sorcerer': {'n_is_nc': '', 'n_is_sb': '0'},
 'sorceress': {'n_is_nc': '', 'n_is_sb': '0'},
 'sorter': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'sortie': {'n_is_nc': '', 'n_is_sth': ''},
 'sorting': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'sort', 'nn_to_jj': 'sorted', 'vbg_to_vb': 'sort', 'vbg_to_vbn': 'sorted'},
 'sot': {'n_is_nc': '', 'n_is_sb': '0'},
 'soubrette': {'n_is_nc': '', 'n_is_sb': '0'},
 'souffle': {'n_is_nc': '', 'n_is_sth': ''},
 'sounder': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'soundtrack': {'n_is_nc': '', 'n_is_sth': ''},
 'soupcon': {'n_is_nc': '', 'n_is_sth': ''},
 'souther': {'n_is_nc': '', 'n_is_sth': ''},
 'southerly': {'n_is_nc': '', 'n_is_sth': ''},
 'southpaw': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'souvenir': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'sovereign': {'n_is_nc': '', 'n_is_sb': '0'},
 'sower': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'soybean': {'n_is_nc': '', 'n_is_sth': ''},
 'spa': {'n_is_nc': '', 'n_is_sth': ''},
 'spacecraft': {'n_is_nc': '', 'n_is_sth': '', 'nn_eq_nns': ''},
 'spaceman': {'n_is_nc': '', 'n_is_sb': '0'},
 'spaceship': {'n_is_nc': '', 'n_is_sth': ''},
 'spade': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'spall': {'n_is_nc': '', 'n_is_sth': ''},
 'spaniel': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'spanking': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'spanner': {'n_is_nc': '', 'n_is_sth': ''},
 'spar': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'spareribs': {'n_is_nc': '', 'n_is_sth': ''},
 'sparkle': {'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'sparkler': {'n_is_nc': '', 'n_is_sth': ''},
 'sparrow': {'n_is_nc': '', 'n_is_sb': '3', 'nc_typical': '', 'n_is_sth': '3'},
 'spasm': {'n_is_nc': '', 'n_is_sth': ''},
 'spat': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'nn_to_vb': 'spit', 'nn_to_jj': 'spitting', 'vb_to_jj': 'spitting', 'vbd_eq_vbn': ''},
 'spatter': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'spatula': {'n_is_nc': '', 'n_is_sth': ''},
 'spear': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'spearhead': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'specialization': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'specialize', 'nn_to_jj': 'specialist', 'nn_to_rb': 'specially'},
 'species': {'n_is_nc': '', 'n_is_sth': '', 'nn_eq_nns': ''},
 'specification': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'specific', 'nn_to_rb': 'specifically'},
 'specimen': {'n_is_nc': '', 'n_is_sth': ''},
 'speck': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'specs': {'n_is_nc': '', 'n_is_sth': ''},
 'spectacle': {'n_is_nc': '', 'n_is_sth': ''},
 'spectacles': {'n_is_nc': '', 'n_is_sth': ''},
 'spectator': {'n_is_nc': '', 'n_is_sb': '0'},
 'specter': {'n_is_nc': '', 'n_is_sb': '0'},
 'spectre': {'n_is_nc': '', 'n_is_sb': '0'},
 'spectrograph': {'n_is_nc': '', 'n_is_sth': ''},
 'spectrometer': {'n_is_nc': '', 'n_is_sth': ''},
 'speculation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'speculum': {'n_is_nc': '', 'n_is_sth': ''},
 'speed': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'speeding', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vb_to_jj': 'speeding', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'speedboat': {'n_is_nc': '', 'n_is_sth': ''},
 'speeder': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'speedometer': {'n_is_nc': '', 'n_is_sth': ''},
 'speedup': {'n_is_nc': '', 'n_is_sth': ''},
 'spelling': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'spell', 'vbg_to_vb': 'spell', 'vbg_to_vbn': 'spelled,spelt'},
 'spendthrift': {'n_is_nc': '', 'n_is_sb': '0'},
 'sperm': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_eq_nns': ''},
 'spheroid': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'sphere', 'nn_to_jj': 'spherical', 'nn_to_rb': 'spherically'},
 'sphincter': {'n_is_nc': '', 'n_is_sth': ''},
 'sphinx': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'spiel': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'spigot': {'n_is_nc': '', 'n_is_sth': ''},
 'spike': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'spill': {'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'spills', 'vb_to_vbd': 'spilled,spilt', 'vb_to_vbn': 'spilled,spilt', 'vb_to_vbg': 'spilling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'spillage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'spillover': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'spillway': {'n_is_nc': '', 'n_is_sth': ''},
 'spin-off': {'n_is_nc': '', 'n_is_sth': ''},
 'spindle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'spine': {'n_is_nc': '', 'n_is_sth': ''},
 'spinner': {'n_is_nc': '', 'n_is_sb': '0'},
 'spinney': {'n_is_nc': '', 'n_is_sth': ''},
 'spinster': {'n_is_nc': '', 'n_is_sb': '0'},
 'spiral': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'spire': {'n_is_nc': '', 'n_is_sth': ''},
 'spirit': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3', 'nn_to_jj': 'spiritual', 'vb_to_jj': 'spiritual', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'spirits': {'n_is_nc': '', 'n_is_sth': ''},
 'spirochete': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'spit': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'spitting', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'vb_to_jj': 'spitting', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'spittoon': {'n_is_nc': '', 'n_is_sth': ''},
 'spiv': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'splash': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'spleen': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'splice': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'spline': {'n_is_nc': '', 'n_is_sth': ''},
 'splint': {'n_is_nc': '', 'n_is_sth': ''},
 'splinter': {'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'n_is_sth': '2'},
 'splitter': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'splotch': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'splurge': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'spoil': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'spoiled', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'spoils', 'vb_to_vbd': 'spoiled', 'vb_to_vbn': 'spoiled', 'vb_to_jj': 'spoiled', 'vb_to_vbg': 'spoiling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'spoke': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'speak', 'nn_to_jj': 'speaking', 'vbd_to_vb': 'speak', 'vbd_to_vbn': 'spoken'},
 'spokesperson': {'n_is_nc': '', 'n_is_sb': '0'},
 'sponge': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '3', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_sth': '3'},
 'spoof': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'spook': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'spool': {'n_is_nc': '', 'n_is_sth': ''},
 'spoonful': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'spoon', 'nc_typical': ''},
 'spore': {'n_is_nc': '', 'n_is_sth': ''},
 'sportsman': {'n_is_nc': '', 'n_is_sb': '0'},
 'sportswoman': {'n_is_nc': '', 'n_is_sb': '0'},
 'spotter': {'n_is_nc': '', 'n_is_sb': '0'},
 'spouse': {'n_is_nc': '', 'n_is_sb': '0'},
 'spout': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'sprain': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'sprawl': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'spray': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'sprays', 'vb_to_vbd': 'sprayed', 'vb_to_vbn': 'sprayed', 'vb_to_vbg': 'spraying', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'sprayer': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'spread': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'vb_to_vbz': 'spreads', 'vb_to_vbg': 'spreading', 'vbn_to_vbg': 'spreading'},
 'spreader': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'spree': {'n_is_nc': '', 'n_is_sth': ''},
 'sprig': {'n_is_nc': '', 'n_is_sth': ''},
 'springboard': {'n_is_nc': '', 'n_is_sth': ''},
 'springbok': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'sprinkle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'sprinkler': {'n_is_nc': '', 'n_is_sth': ''},
 'sprinkling': {'n_is_nc': '', 'n_is_sth': ''},
 'sprite': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'spritz': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'sprocket': {'n_is_nc': '', 'n_is_sth': ''},
 'sprout': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'spruce': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'spurt': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'sputter': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'squab': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': ''},
 'squabble': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'squadron': {'n_is_nc': '', 'n_is_sth': ''},
 'squall': {'n_is_nc': '', 'n_is_sth': ''},
 'squawk': {'n_is_nc': '', 'n_is_sth': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'squeak': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'squeal': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'squeezer': {'n_is_nc': '', 'n_is_sth': ''},
 'squelch': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'squib': {'n_is_nc': '', 'n_is_sth': ''},
 'squid': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'squint': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'squire': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'squirm': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'squirrel': {'n_is_nc': '', 'n_is_sb': '3', 'vbd_eq_vbn': '', 'n_is_sth': '3'},
 'squirt': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'stab': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'stabber': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'stabilizer': {'n_is_nc': '', 'n_is_sth': ''},
 'stack': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'staff': {'n_is_nc': '', 'n_is_sth': '', 'n_is_collective': '', 'vbd_eq_vbn': '', 'nn_eq_nns': ''},
 'staffer': {'n_is_nc': '', 'n_is_sb': '0'},
 'stager': {'n_is_nc': '', 'n_is_sb': '0'},
 'stagger': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'staging': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'stage', 'nn_to_jj': 'staged'},
 'stain': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'stained', 'vb_to_jj': 'stained', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'staircase': {'n_is_nc': '', 'n_is_sth': ''},
 'stairway': {'n_is_nc': '', 'n_is_sth': ''},
 'stake': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'stalactite': {'n_is_nc': '', 'n_is_sth': ''},
 'stalagmite': {'n_is_nc': '', 'n_is_sth': ''},
 'stalemate': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'stalk': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'stalking-horse': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'stallion': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'stamen': {'n_is_nc': '', 'n_is_sth': ''},
 'stammer': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'stampede': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'stamper': {'n_is_nc': '', 'n_is_sb': '0'},
 'stanchion': {'n_is_nc': '', 'n_is_sth': ''},
 'stand-in': {'n_is_nc': '', 'n_is_sb': '0'},
 'standard': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'standard-bearer': {'n_is_nc': '', 'n_is_sb': '0'},
 'standby': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'standoff': {'n_is_nc': '', 'n_is_sth': ''},
 'standpipe': {'n_is_nc': '', 'n_is_sth': ''},
 'standpoint': {'n_is_nc': '', 'n_is_sth': ''},
 'stanza': {'n_is_nc': '', 'n_is_sth': ''},
 'staphylococcus': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'staple': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'stapler': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'starch': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'starfish': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'stargazer': {'n_is_nc': '', 'n_is_sb': '0'},
 'startle': {'n_is_nc': '', 'n_is_sth': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'startup': {'n_is_nc': '', 'n_is_sth': ''},
 'stasis': {'n_is_nc': '', 'n_is_sth': ''},
 'stateroom': {'n_is_nc': '', 'n_is_sth': ''},
 'statesman': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'stationer': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'stationmaster': {'n_is_nc': '', 'n_is_sb': '0'},
 'statuary': {'n_is_nc': '', 'n_is_sth': ''},
 'stave': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'std': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'steak': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'steamboat': {'n_is_nc': '', 'n_is_sth': ''},
 'steamer': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'steamship': {'n_is_nc': '', 'n_is_sth': ''},
 'steed': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'steel': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'steeple': {'n_is_nc': '', 'n_is_sth': ''},
 'steeplechase': {'n_is_nc': '', 'n_is_sth': ''},
 'steersman': {'n_is_nc': '', 'n_is_sb': '0'},
 'stela': {'n_is_nc': '', 'n_is_sth': ''},
 'stele': {'n_is_nc': '', 'n_is_sth': ''},
 'stench': {'n_is_nc': '', 'n_is_sth': ''},
 'stencil': {'n_is_nc': '', 'n_is_sth': ''},
 'stenographer': {'n_is_nc': '', 'n_is_sb': '0'},
 'stepchild': {'n_is_nc': '', 'n_is_sb': '0', 'nn_to_nns': 'stepchildren'},
 'stepfather': {'n_is_nc': '', 'n_is_sb': '0'},
 'stepladder': {'n_is_nc': '', 'n_is_sth': ''},
 'stepmother': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'steppe': {'n_is_nc': '', 'n_is_sth': ''},
 'stepson': {'n_is_nc': '', 'n_is_sb': '0'},
 'stereo': {'n_is_nc': '', 'n_is_sth': ''},
 'stereotype': {'n_is_nc': '', 'n_is_sth': ''},
 'sternum': {'n_is_nc': '', 'n_is_sth': ''},
 'stethoscope': {'n_is_nc': '', 'n_is_sth': ''},
 'steward': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'sticker': {'n_is_nc': '', 'n_is_sth': ''},
 'stickpin': {'n_is_nc': '', 'n_is_sth': ''},
 'stickup': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'stiffener': {'n_is_nc': '', 'n_is_sth': ''},
 'stiletto': {'n_is_nc': '', 'n_is_sth': ''},
 'stillbirth': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'stilt': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'stimulant': {'n_is_nc': '', 'n_is_sth': ''},
 'sting': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'stinging', 'nn_to_rb': 'stingingly', 'vb_to_rb': 'stingingly', 'vb_to_jj': 'stinging', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'stinger': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'stink': {'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'stinker': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'stint': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'stipe': {'n_is_nc': '', 'n_is_sth': ''},
 'stipend': {'n_is_nc': ''},
 'stipulation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'stirrer': {'n_is_nc': '', 'n_is_sb': '0'},
 'stirrup': {'n_is_nc': '', 'n_is_sth': ''},
 'stitch': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'stitcher': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'stockade': {'n_is_nc': '', 'n_is_sth': ''},
 'stockholder': {'n_is_nc': '', 'n_is_sb': '0'},
 'stocking': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'stockman': {'n_is_nc': '', 'n_is_sb': '0'},
 'stockpile': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'stockpot': {'n_is_nc': '', 'n_is_sth': ''},
 'stoker': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'stomp': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'stonecutter': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'stonemason': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'stooge': {'n_is_nc': '', 'n_is_sb': '0'},
 'stool': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'stoop': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'stopgap': {'n_is_nc': '', 'n_is_sth': ''},
 'stoplight': {'n_is_nc': '', 'n_is_sth': ''},
 'stopover': {'n_is_nc': '', 'n_is_sth': ''},
 'stoppage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'stopper': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'stopping': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'stop', 'nn_to_jj': 'stopped', 'vbg_to_vb': 'stop', 'vbg_to_vbn': 'stopped'},
 'stopwatch': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'storefront': {'n_is_nc': '', 'n_is_sth': ''},
 'storehouse': {'n_is_nc': '', 'n_is_sth': ''},
 'storekeeper': {'n_is_nc': '', 'n_is_sb': '0'},
 'storeroom': {'n_is_nc': '', 'n_is_sth': ''},
 'storey': {'n_is_nc': '', 'n_is_sth': ''},
 'stork': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'stovepipe': {'n_is_nc': '', 'n_is_sth': ''},
 'straddle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'straightedge': {'n_is_nc': '', 'n_is_sth': ''},
 'strainer': {'n_is_nc': '', 'n_is_sth': ''},
 'strait': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'straits': {'n_is_nc': '', 'n_is_sth': ''},
 'strand': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'stranglehold': {'n_is_nc': '', 'n_is_sth': ''},
 'strap': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'strapping', 'vb_to_jj': 'strapping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'stratagem': {'n_is_nc': '', 'n_is_sth': ''},
 'stratosphere': {'n_is_nc': '', 'n_is_sth': ''},
 'straw': {'n_is_nc': '', 'n_is_sth': ''},
 'stray': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'streak': {'n_is_nc': '', 'n_is_sth': ''},
 'streamer': {'n_is_nc': '', 'n_is_sth': ''},
 'streetcar': {'n_is_nc': '', 'n_is_sth': ''},
 'streetlight': {'n_is_nc': '', 'n_is_sth': ''},
 'streetwalker': {'n_is_nc': '', 'n_is_sb': '0'},
 'streptococcus': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'stretch': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'stretches', 'vb_to_vbd': 'stretched', 'vb_to_vbn': 'stretched', 'vb_to_vbg': 'stretching', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'stretcher': {'n_is_nc': '', 'n_is_sth': ''},
 'stricture': {'n_is_nc': '', 'n_is_sth': ''},
 'stride': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'strife': {'n_is_nc': '', 'n_is_sth': ''},
 'striker': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'striping': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'stripe', 'nn_to_jj': 'striped'},
 'stripling': {'n_is_nc': '', 'n_is_sb': '0'},
 'striptease': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'striver': {'n_is_nc': '', 'n_is_sb': '0'},
 'strobe': {'n_is_nc': '', 'n_is_sth': ''},
 'stroll': {'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'stroller': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'strongbox': {'n_is_nc': '', 'n_is_sth': ''},
 'stronghold': {'n_is_nc': '', 'n_is_sth': ''},
 'strongman': {'n_is_nc': '', 'n_is_sb': '0'},
 'strontium': {'n_is_nc': '', 'n_is_sth': ''},
 'struma': {'n_is_nc': '', 'n_is_sth': ''},
 'strut': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'stub': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'stud': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'stuffer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'stump': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'stumper': {'n_is_nc': '', 'n_is_sb': '0'},
 'stunt': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'stupa': {'n_is_nc': '', 'n_is_sth': ''},
 'stupidity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'stupid', 'nn_to_rb': 'stupidly'},
 'sturgeon': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'stutter': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'sty': {'n_is_nc': '', 'n_is_sth': ''},
 'stylist': {'n_is_nc': '', 'n_is_sb': '0'},
 'stylus': {'n_is_nc': '', 'n_is_sth': ''},
 'stymie': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'sub': {'n_is_nc': '', 'n_is_sth': ''},
 'subaltern': {'n_is_nc': '', 'n_is_sb': '0'},
 'subclass': {'n_is_nc': '', 'n_is_sth': ''},
 'subconsciousness': {'n_is_nc': '', 'n_is_sth': ''},
 'subcontinent': {'n_is_nc': '', 'n_is_sth': ''},
 'subdirectory': {'n_is_nc': '', 'n_is_sth': ''},
 'subdivision': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'subgroup': {'n_is_nc': '', 'n_is_sth': ''},
 'subhead': {'n_is_nc': '', 'n_is_sth': ''},
 'subheading': {'n_is_nc': '', 'n_is_sth': ''},
 'sublet': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'vbd_eq_vbn': ''},
 'submarine': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'submission': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'submit'},
 'subordinate': {'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'n_is_sth': '2'},
 'subpoena': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'subscriber': {'n_is_nc': '', 'n_is_sb': '0'},
 'subscription': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'subsection': {'n_is_nc': '', 'n_is_sth': ''},
 'subset': {'n_is_nc': '', 'n_is_sth': ''},
 'subsidence': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'subsidy': {'n_is_nc': '', 'nn_to_vb': 'subsidise', 'nn_to_jj': 'subsidized'},
 'substation': {'n_is_nc': '', 'n_is_sth': ''},
 'substitution': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'substantial', 'nn_to_rb': 'substantially'},
 'substrate': {'n_is_nc': '', 'n_is_sth': ''},
 'substratum': {'n_is_nc': '', 'n_is_sth': ''},
 'substructure': {'n_is_nc': '', 'n_is_sth': ''},
 'subsystem': {'n_is_nc': '', 'n_is_sth': ''},
 'subterfuge': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'subtitle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'subtlety': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'subtraction': {'n_is_nc': '', 'n_is_sth': ''},
 'subtropics': {'n_is_nc': '', 'n_is_sth': ''},
 'success': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'succeed', 'nn_to_jj': 'successful', 'nn_to_rb': 'successfully'},
 'succession': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'successive', 'nn_to_rb': 'successively'},
 'succor': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'succubus': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'sucker': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'suckling': {'n_is_nc': '', 'n_is_sb': '0'},
 'suds': {'n_is_nc': '', 'n_is_sth': ''},
 'sufferer': {'n_is_nc': '', 'n_is_sb': '0'},
 'suffix': {'n_is_nc': '', 'n_is_sth': ''},
 'sugar': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'sugary', 'vb_to_jj': 'sugary', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'sugarloaf': {'n_is_nc': '', 'n_is_sth': ''},
 'sugarplum': {'n_is_nc': '', 'n_is_sth': ''},
 'suicide': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'suitor': {'n_is_nc': '', 'n_is_sb': '0'},
 'sulk': {'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'sulphate': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'sultana': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'sultanate': {'n_is_nc': '', 'n_is_sth': ''},
 'sumac': {'n_is_nc': '', 'n_is_sth': ''},
 'summation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'sum', 'nn_to_jj': 'summing'},
 'summerhouse': {'n_is_nc': '', 'n_is_sth': ''},
 'summit': {'n_is_nc': '', 'n_is_sth': ''},
 'summons': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'sump': {'n_is_nc': '', 'n_is_sth': ''},
 'sumpter': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'sun': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'sunny', 'nn_to_rb': 'sunnily', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'sunbeam': {'n_is_nc': '', 'n_is_sth': ''},
 'sundial': {'n_is_nc': '', 'n_is_sth': ''},
 'sundowner': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'sunfish': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'sunflower': {'n_is_nc': '', 'n_is_sth': ''},
 'sunglasses': {'n_is_nc': '', 'n_is_sth': ''},
 'sunlamp': {'n_is_nc': '', 'n_is_sth': ''},
 'sunrise': {'n_is_nc': '', 'n_is_sth': ''},
 'sunset': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'sunshade': {'n_is_nc': '', 'n_is_sth': ''},
 'sunspot': {'n_is_nc': '', 'n_is_sth': ''},
 'sunup': {'n_is_nc': '', 'n_is_sth': ''},
 'superficiality': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'superfluity': {'n_is_nc': '', 'n_is_sth': ''},
 'superhighway': {'n_is_nc': '', 'n_is_sth': ''},
 'superman': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'supernova': {'n_is_nc': '', 'n_is_sth': ''},
 'supernumerary': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'superstar': {'n_is_nc': '', 'n_is_sb': '0'},
 'superstition': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'superstructure': {'n_is_nc': '', 'n_is_sth': ''},
 'supper': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'supplement': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'supplementary', 'vb_to_jj': 'supplementary', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'supposition': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'suppose', 'nn_to_jj': 'supposed', 'nn_to_rb': 'supposedly'},
 'suppository': {'n_is_nc': '', 'n_is_sth': ''},
 'suppressor': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'supremo': {'n_is_nc': '', 'n_is_sb': '0'},
 'sura': {'n_is_nc': '', 'n_is_sth': ''},
 'surcharge': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'surety': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'surfeit': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'surplus': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'surrender': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'surrogate': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'surround': {'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'surrounds', 'vb_to_vbd': 'surrounded', 'vb_to_vbn': 'surrounded', 'vb_to_vbg': 'surrounding', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'surroundings': {'n_is_nc': '', 'n_is_sth': ''},
 'surveyor': {'n_is_nc': '', 'n_is_sb': '0'},
 'susceptibility': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'suspender': {'n_is_nc': '', 'n_is_sth': ''},
 'sutra': {'n_is_nc': '', 'n_is_sth': ''},
 'suture': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'swab': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'swag': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'swagman': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'swale': {'n_is_nc': '', 'n_is_sth': ''},
 'swallowtail': {'n_is_nc': '', 'n_is_sth': ''},
 'swami': {'n_is_nc': '', 'n_is_sb': '0'},
 'swamp': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'swan': {'n_is_nc': '', 'n_is_sb': '3', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_sth': '3'},
 'swank': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'swarm': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'swash': {'n_is_nc': '', 'n_is_sth': ''},
 'swashbuckler': {'n_is_nc': '', 'n_is_sb': '0'},
 'swat': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'swatch': {'n_is_nc': '', 'n_is_sth': ''},
 'swatter': {'n_is_nc': '', 'n_is_sth': ''},
 'sway': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'sweat': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'sweated', 'vb_to_jj': 'sweated', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'sweatbox': {'n_is_nc': '', 'n_is_sth': ''},
 'sweatshirt': {'n_is_nc': '', 'n_is_sth': ''},
 'sweeper': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'sweetbread': {'n_is_nc': '', 'n_is_sth': ''},
 'sweetheart': {'n_is_nc': '', 'n_is_sb': '0'},
 'sweetie': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'swell': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'swellish', 'v_to_vbg': '', 'v_n': '', 'v_with': '', 'vb_to_jj': 'swellish', 'vbd_eq_vbn': ''},
 'swelling': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'swell', 'nn_to_jj': 'swellish'},
 'swerve': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'swig': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'swill': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'swimsuit': {'n_is_nc': '', 'n_is_sth': ''},
 'swindle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'swindler': {'n_is_nc': '', 'n_is_sb': '0'},
 'swine': {'n_is_nc': '', 'n_is_sb': '0'},
 'swipe': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'swirl': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'swish': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'switchboard': {'n_is_nc': '', 'n_is_sth': ''},
 'swivel': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'swoon': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'sword': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'swordfish': {'n_is_nc': '', 'n_is_sb': '0'},
 'swordsman': {'n_is_nc': '', 'n_is_sb': '0'},
 'sycophant': {'n_is_nc': '', 'n_is_sb': '0'},
 'syllable': {'n_is_nc': '', 'n_is_sth': ''},
 'syllogism': {'n_is_nc': '', 'n_is_sth': ''},
 'sylva': {'n_is_nc': '', 'n_is_sth': ''},
 'symphony': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'symptom': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'synagogue': {'n_is_nc': '', 'n_is_sth': ''},
 'synchro': {'n_is_nc': '', 'n_is_sth': ''},
 'synchrony': {'n_is_nc': '', 'n_is_sth': ''},
 'syncope': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'syndicate': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'synod': {'n_is_nc': '', 'n_is_sth': ''},
 'syringa': {'n_is_nc': '', 'n_is_sth': ''},
 'syringe': {'n_is_nc': '', 'n_is_sth': ''},
 'syrinx': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 't-shirt': {'n_is_nc': '', 'n_is_sth': ''},
 't-square': {'n_is_nc': '', 'n_is_sth': ''},
 'tab': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'tabernacle': {'n_is_nc': '', 'n_is_sth': ''},
 'tablecloth': {'n_is_nc': '', 'n_is_sth': ''},
 'tablespoon': {'n_is_nc': '', 'n_is_sth': ''},
 'tabloid': {'n_is_nc': '', 'n_is_sth': ''},
 'taboo': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'tabor': {'n_is_nc': '', 'n_is_sth': ''},
 'tabulation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'tach': {'n_is_nc': '', 'n_is_sth': ''},
 'tachometer': {'n_is_nc': '', 'n_is_sth': ''},
 'tack': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'tackle': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'tackles', 'vb_to_vbd': 'tackled', 'vb_to_vbn': 'tackled', 'vb_to_vbg': 'tackling', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'tactician': {'n_is_nc': '', 'n_is_sb': '0'},
 'tactics': {'n_is_nc': '', 'n_is_sth': ''},
 'tad': {'n_is_nc': '', 'n_is_sb': '0'},
 'tadpole': {'n_is_nc': '', 'n_is_sb': '0'},
 'tag': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'tailcoat': {'n_is_nc': '', 'n_is_sth': ''},
 'taillight': {'n_is_nc': '', 'n_is_sth': ''},
 'tailpiece': {'n_is_nc': '', 'n_is_sth': ''},
 'tailpipe': {'n_is_nc': '', 'n_is_sth': ''},
 'tailspin': {'n_is_nc': '', 'n_is_sth': ''},
 'tailwind': {'n_is_nc': '', 'n_is_sth': ''},
 'takeover': {'n_is_nc': '', 'n_is_sth': ''},
 'takings': {'n_is_nc': '', 'n_is_sth': ''},
 'talbot': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'talent': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'talented', 'be_nn_in.nn_to_jj': ''},
 'talisman': {'n_is_nc': '', 'n_is_sth': ''},
 'talker': {'n_is_nc': '', 'n_is_sb': '0'},
 'talkie': {'n_is_nc': '', 'n_is_sth': ''},
 'tally': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'talon': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'talus': {'n_is_nc': '', 'n_is_sth': ''},
 'tamarack': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'tambourine': {'n_is_nc': '', 'n_is_sth': ''},
 'tamper': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'tampon': {'n_is_nc': '', 'n_is_sth': ''},
 'tan': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'tandem': {'n_is_nc': '', 'n_is_sth': ''},
 'tang': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'tangent': {'n_is_nc': '', 'n_is_sth': ''},
 'tangerine': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'tangle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'tango': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'tanker': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nc_typical': ''},
 'tanner': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'tanning': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'tantrum': {'n_is_nc': '', 'n_is_sth': ''},
 'taoist': {'n_is_nc': '', 'n_is_sb': '0'},
 'tape': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'taped', 'vb_to_jj': 'taped', 'vbd_eq_vbn': ''},
 'taper': {'n_is_nc': '', 'n_is_sth': ''},
 'tapestry': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'tapeworm': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'tapir': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'tapis': {'n_is_nc': '', 'n_is_sth': ''},
 'tapper': {'n_is_nc': '', 'n_is_sb': '2', 'nn_to_vb': 'tap', 'nn_to_jj': 'tapped', 'n_is_sth': '2'},
 'taproom': {'n_is_nc': '', 'n_is_sth': ''},
 'taproot': {'n_is_nc': '', 'n_is_sth': ''},
 'tarantula': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'tare': {'n_is_nc': '', 'n_is_sth': ''},
 'tariff': {'n_is_nc': '', 'n_is_sth': ''},
 'taro': {'n_is_nc': '', 'n_is_sth': ''},
 'tarpaulin': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'tart': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'tartar': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'taskmaster': {'n_is_nc': '', 'n_is_sb': '0'},
 'tassel': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'taste': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'tasteless', 'v_vbg': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vbe': '', 'vdo': '', 'v_of': '', 'vb_to_vbz': 'tastes', 'vb_to_vbd': 'tasted', 'vb_to_vbn': 'tasted', 'vb_to_jj': 'tasteless', 'vb_to_vbg': 'tasting', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'taster': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'tat': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'tatar': {'n_is_nc': '', 'n_is_sb': '0'},
 'tattletale': {'n_is_nc': '', 'n_is_sb': '0'},
 'taunt': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'tautology': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'tavern': {'n_is_nc': '', 'n_is_sth': ''},
 'taxicab': {'n_is_nc': '', 'n_is_sth': ''},
 'taxiway': {'n_is_nc': '', 'n_is_sth': ''},
 'teacup': {'n_is_nc': '', 'n_is_sth': ''},
 'teahouse': {'n_is_nc': '', 'n_is_sth': ''},
 'teakwood': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'teapot': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'teardrop': {'n_is_nc': '', 'n_is_sth': ''},
 'tearoom': {'n_is_nc': '', 'n_is_sth': ''},
 'tease': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'teaser': {'n_is_nc': '', 'n_is_sb': '0'},
 'teaspoon': {'n_is_nc': '', 'n_is_sth': ''},
 'teaspoonful': {'n_is_nc': '', 'n_is_sth': ''},
 'teat': {'n_is_nc': '', 'n_is_sth': ''},
 'technician': {'n_is_nc': '', 'n_is_sb': '0'},
 'technocracy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'technologist': {'n_is_nc': '', 'n_is_sb': '0'},
 'teenager': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'teeter': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'telecast': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'teleconference': {'n_is_nc': '', 'n_is_sth': ''},
 'telefilm': {'n_is_nc': '', 'n_is_sth': ''},
 'telegram': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'telegraph': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'telegraphic', 'nn_to_rb': 'telegraphically', 'vb_to_rb': 'telegraphically', 'vb_to_jj': 'telegraphic', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'telegrapher': {'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'telegraph', 'nn_to_jj': 'telegraphic', 'nn_to_rb': 'telegraphically'},
 'telex': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl': ''},
 'teller': {'n_is_nc': '', 'n_is_sb': '0'},
 'telltale': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'telly': {'n_is_nc': '', 'n_is_sth': ''},
 'temblor': {'n_is_nc': '', 'n_is_sth': ''},
 'temp': {'n_is_nc': '', 'n_is_sb': '0'},
 'temper': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'temperament': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'tempest': {'n_is_nc': '', 'n_is_sth': ''},
 'templar': {'n_is_nc': '', 'n_is_sb': '0'},
 'template': {'n_is_nc': '', 'n_is_sth': ''},
 'temptation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'tempt', 'nn_to_jj': 'tempting'},
 'tenancy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'tenant': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'tench': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'tenderfoot': {'n_is_nc': '', 'n_is_sb': '0'},
 'tendril': {'n_is_nc': '', 'n_is_sth': ''},
 'tenement': {'n_is_nc': '', 'n_is_sth': ''},
 'tenet': {'n_is_nc': '', 'n_is_sth': ''},
 'tenor': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'tentacle': {'n_is_nc': '', 'n_is_sth': ''},
 'tercel': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'termagant': {'n_is_nc': '', 'n_is_sb': '0'},
 'terminator': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'terminology': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'termite': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'terrace': {'n_is_nc': '', 'n_is_sth': ''},
 'terrain': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'terrier': {'n_is_nc': '', 'n_is_sb': '0'},
 'terrine': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'testa': {'n_is_nc': '', 'n_is_sth': ''},
 'testament': {'n_is_nc': '', 'n_is_sth': ''},
 'tester': {'n_is_nc': '', 'n_is_sb': '2', 'nn_to_vb': 'test', 'nn_to_jj': 'tested', 'n_is_sth': '2'},
 'testicle': {'n_is_nc': '', 'n_is_sth': ''},
 'testimonial': {'n_is_nc': '', 'n_is_sth': ''},
 'testis': {'n_is_nc': '', 'n_is_sth': ''},
 'tether': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'tetrahedron': {'n_is_nc': '', 'n_is_sth': ''},
 'textbook': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'textile': {'n_is_nc': '', 'n_is_sth': ''},
 'texture': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'text', 'nn_to_jj': 'textual', 'nn_to_rb': 'textually'},
 'thalamus': {'n_is_nc': '', 'n_is_sth': ''},
 'thanks': {'n_is_nc': '', 'n_is_sth': '', 'vbz_to_vb': 'thank', 'nns_to_vb': 'thank'},
 'thatch': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'thaw': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'theatre': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'theatricalize', 'nn_to_jj': 'theatrical', 'nn_to_rb': 'theatrically'},
 'theca': {'n_is_nc': '', 'n_is_sth': ''},
 'theocracy': {'n_is_nc': '', 'n_is_sth': ''},
 'theologian': {'n_is_nc': '', 'n_is_sb': '0'},
 'theology': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'theorem': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'theoretical', 'nn_to_rb': 'theoretically'},
 'theoretician': {'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'theoretical', 'nn_to_rb': 'theoretically'},
 'theorist': {'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'theoretical', 'nn_to_rb': 'theoretically'},
 'therm': {'n_is_nc': '', 'n_is_sth': ''},
 'thermometer': {'n_is_nc': '', 'n_is_sth': ''},
 'thermos': {'n_is_nc': '', 'n_is_sth': ''},
 'thermostat': {'n_is_nc': '', 'n_is_sth': ''},
 'thesaurus': {'n_is_nc': '', 'n_is_sth': ''},
 'thickener': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'thicket': {'n_is_nc': '', 'n_is_sth': ''},
 'thigh': {'n_is_nc': '', 'n_is_sth': ''},
 'thighbone': {'n_is_nc': '', 'n_is_sth': ''},
 'thill': {'n_is_nc': '', 'n_is_sth': ''},
 'thimble': {'n_is_nc': '', 'n_is_sth': ''},
 'thimbleful': {'n_is_nc': '', 'n_is_sth': ''},
 'thinker': {'n_is_nc': '', 'n_is_sb': '0'},
 'thirst': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_to_vb': '', 'nsubjpass': '', 'v_for': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'thirty': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'thirtieth', 'nn_to_rb': 'thirstily'},
 'thistle': {'n_is_nc': '', 'n_is_sth': ''},
 'thong': {'n_is_nc': '', 'n_is_sth': ''},
 'thorax': {'n_is_nc': '', 'n_is_sth': ''},
 'thorn': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'thronlike'},
 'thoroughfare': {'n_is_nc': '', 'n_is_sth': ''},
 'thorpe': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'thrall': {'n_is_nc': '', 'n_is_sb': '0'},
 'thrasher': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'thrashing': {'n_is_nc': '', 'n_is_sth': ''},
 'thread': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'threaded', 'nn_to_rb': 'threadbare', 'vb_to_rb': 'threadbare', 'vb_to_jj': 'threaded', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'threnody': {'n_is_nc': '', 'n_is_sth': ''},
 'thresher': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'threshold': {'n_is_nc': '', 'n_is_sth': ''},
 'thrill': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'throb': {'n_is_nc': '', 'n_is_sth': '', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'thrombin': {'n_is_nc': '', 'n_is_sth': ''},
 'throne': {'n_is_nc': '', 'n_is_sth': ''},
 'throng': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'throttle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'throwback': {'n_is_nc': '', 'n_is_sth': ''},
 'thrower': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'thrum': {'n_is_nc': '', 'n_is_sth': ''},
 'thrush': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '3', 'n_is_sth': ''},
 'thrust': {'n_is_nc': '', 'n_is_sth': '', 'vb_eq_vbd': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbd_eq_vbn': ''},
 'thruster': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'thruway': {'n_is_nc': '', 'n_is_sth': ''},
 'thud': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'thug': {'n_is_nc': '', 'n_is_sb': '0'},
 'thule': {'n_is_nc': '', 'n_is_sth': ''},
 'thumbprint': {'n_is_nc': '', 'n_is_sth': ''},
 'thump': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'thunder': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'thunderous', 'nn_to_rb': 'thunderously', 'v_to_vbg': '', 'nsubjpass': '', 'v_at': '', 'v_against': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'thunderbolt': {'n_is_nc': '', 'n_is_sth': ''},
 'thunderclap': {'n_is_nc': '', 'n_is_sth': ''},
 'thundercloud': {'n_is_nc': '', 'n_is_sth': ''},
 'thundershower': {'n_is_nc': '', 'n_is_sth': ''},
 'thunderstorm': {'n_is_nc': '', 'n_is_sth': '', 'nu_typical': ''},
 'thyroid': {'n_is_nc': '', 'n_is_sth': ''},
 'tibia': {'n_is_nc': '', 'n_is_sth': ''},
 'tic': {'n_is_nc': '', 'n_is_sth': ''},
 'tick': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'ticker': {'n_is_nc': '', 'n_is_sth': ''},
 'ticking': {'n_is_nc': '', 'n_is_sth': ''},
 'tickler': {'n_is_nc': '', 'n_is_sth': ''},
 'tidbit': {'n_is_nc': '', 'n_is_sth': ''},
 'tidings': {'n_is_nc': '', 'n_is_sth': ''},
 'tie-up': {'n_is_nc': '', 'n_is_sth': ''},
 'tier': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': ''},
 'tiff': {'n_is_nc': '', 'n_is_sth': ''},
 'tights': {'n_is_nc': '', 'n_is_sth': ''},
 'tightwad': {'n_is_nc': '', 'n_is_sb': '0'},
 'tigress': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'tiler': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'tiller': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'tilt': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'timber': {'n_is_nc': '', 'n_is_sth': ''},
 'timberland': {'n_is_nc': '', 'n_is_sth': ''},
 'time': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'timeless', 'nn_to_rb': 'timely', 'v_compcl': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vb_to_rb': 'timely', 'vb_to_jj': 'timeless', 'vbd_eq_vbn': '', 'vt_typical': '', 'quantifier': ''},
 'time-out': {'n_is_nc': '', 'n_is_sth': ''},
 'timekeeper': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'timepiece': {'n_is_nc': '', 'n_is_sth': ''},
 'timer': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_vb': 'time', 'nn_to_jj': 'timeless', 'nn_to_rb': 'timely'},
 'timing': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'timpani': {'n_is_nc': '', 'n_is_sth': ''},
 'tin': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'tincture': {'n_is_nc': '', 'n_is_sth': ''},
 'tine': {'n_is_nc': '', 'n_is_sth': ''},
 'ting': {'n_is_nc': '', 'n_is_sth': ''},
 'tinge': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'tingle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'tinker': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'tint': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'tippet': {'n_is_nc': '', 'n_is_sth': ''},
 'tipple': {'n_is_nc': '', 'n_is_sth': ''},
 'tippler': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'tirade': {'n_is_nc': '', 'n_is_sth': ''},
 'tit': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'titan': {'n_is_nc': '', 'n_is_sb': '0'},
 'titter': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'tittle': {'n_is_nc': '', 'n_is_sth': ''},
 'to-do': {'n_is_nc': '', 'n_is_sth': ''},
 'toad': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'toadstool': {'n_is_nc': '', 'n_is_sth': ''},
 'toady': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'toast': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'toaster': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'toastmaster': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'tobacco': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'tod': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'toddy': {'n_is_nc': '', 'n_is_sth': ''},
 'toehold': {'n_is_nc': '', 'n_is_sth': ''},
 'toenail': {'n_is_nc': '', 'n_is_sth': ''},
 'toff': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'toffee': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'toga': {'n_is_nc': '', 'n_is_sth': ''},
 'toggle': {'n_is_nc': '', 'n_is_sth': ''},
 'toilet': {'n_is_nc': '', 'n_is_sth': ''},
 'toiletry': {'n_is_nc': '', 'n_is_sth': ''},
 'token': {'n_is_nc': '', 'n_is_sth': ''},
 'tolerance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'tomb': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'tombstone': {'n_is_nc': '', 'n_is_sth': ''},
 'tomfoolery': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'tonality': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'tone': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'tongs': {'n_is_nc': '', 'n_is_sth': ''},
 'tongue': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'tongueless', 'vb_to_jj': 'tongueless', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'tongue-lashing': {'n_is_nc': '', 'n_is_sth': ''},
 'tonic': {'n_is_nc': '', 'n_is_sth': ''},
 'tonnage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'tonsil': {'n_is_nc': '', 'n_is_sth': ''},
 'toolmaker': {'n_is_nc': '', 'n_is_sb': '0'},
 'toon': {'n_is_nc': '', 'n_is_sth': ''},
 'toot': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'toothache': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'toothbrush': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'toothpaste': {'n_is_nc': '', 'n_is_sth': '', 'nu_typical': ''},
 'toothpick': {'n_is_nc': '', 'n_is_sth': ''},
 'topaz': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '3', 'n_is_sth': ''},
 'topcoat': {'n_is_nc': '', 'n_is_sth': ''},
 'tope': {'n_is_nc': '', 'n_is_sth': ''},
 'topknot': {'n_is_nc': '', 'n_is_sth': ''},
 'topology': {'n_is_nc': '', 'n_is_sth': ''},
 'topping': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'tor': {'n_is_nc': '', 'n_is_sth': ''},
 'torch': {'n_is_nc': '', 'n_is_sth': ''},
 'torment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'torrent': {'n_is_nc': '', 'n_is_sth': ''},
 'torso': {'n_is_nc': '', 'n_is_sth': ''},
 'tort': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'tortoise': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'tortoiseshell': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'torus': {'n_is_nc': '', 'n_is_sth': ''},
 'tory': {'n_is_nc': '', 'n_is_sb': '0', 'cap_word': 'Tory'},
 'toss': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'tot': {'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'totalitarian': {'n_is_nc': '', 'n_is_sb': '0'},
 'tote': {'n_is_nc': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'n_is_sth': '0'},
 'totem': {'n_is_nc': '', 'n_is_sth': ''},
 'toucan': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'touchdown': {'n_is_nc': '', 'n_is_sth': ''},
 'touchstone': {'n_is_nc': '', 'n_is_sth': ''},
 'toughie': {'n_is_nc': '', 'n_is_sb': '0'},
 'toupee': {'n_is_nc': '', 'n_is_sth': ''},
 'tourer': {'n_is_nc': '', 'n_is_sb': '0'},
 'tourney': {'n_is_nc': '', 'n_is_sth': ''},
 'tout': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'tow': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'towboat': {'n_is_nc': '', 'n_is_sth': ''},
 'townie': {'n_is_nc': '', 'n_is_sb': '0'},
 'townsfolk': {'n_is_nc': '', 'n_is_sb': '0'},
 'township': {'n_is_nc': '', 'n_is_sth': ''},
 'townsman': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'townspeople': {'n_is_nc': '', 'n_is_sb': '0'},
 'toxin': {'n_is_nc': '', 'n_is_sth': ''},
 'tracer': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_vb': 'trace', 'nn_to_jj': 'traceless'},
 'trachea': {'n_is_nc': '', 'n_is_sth': ''},
 'tracker': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'tract': {'n_is_nc': '', 'n_is_sth': ''},
 'tractor': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'trade': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'tradable', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_in': '', 'v_with': '', 'vb_to_vbz': 'trades', 'vb_to_vbd': 'traded', 'vb_to_vbn': 'traded', 'vb_to_jj': 'tradable', 'vb_to_vbg': 'trading', 'vbd_eq_vbn': ''},
 'trade-off': {'n_is_nc': '', 'n_is_sth': ''},
 'tradesman': {'n_is_nc': '', 'n_is_sb': '0'},
 'tradespeople': {'n_is_nc': '', 'n_is_sb': '0'},
 'tradition': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'traditional', 'nn_to_rb': 'traditionally'},
 'trafficker': {'n_is_nc': '', 'n_is_sb': '0'},
 'tragicomedy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'trailblazer': {'n_is_nc': '', 'n_is_sb': '0'},
 'trainee': {'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'train'},
 'trait': {'n_is_nc': '', 'n_is_sth': ''},
 'traitor': {'n_is_nc': '', 'n_is_sb': '0'},
 'trajectory': {'n_is_nc': '', 'n_is_sth': ''},
 'tram': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'trammel': {'n_is_nc': '', 'n_is_sth': ''},
 'tramp': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'trample': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'tramway': {'n_is_nc': '', 'n_is_sth': ''},
 'trance': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'tranquilizer': {'n_is_nc': '', 'n_is_sth': ''},
 'transaction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'transcript': {'n_is_nc': '', 'n_is_sth': ''},
 'transcription': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'transducer': {'n_is_nc': '', 'n_is_sth': ''},
 'transfer': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'transferable', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'transfers', 'vb_to_vbd': 'transfered', 'vb_to_vbn': 'transfered', 'vb_to_jj': 'transferable', 'vb_to_vbg': 'transfering', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'transformer': {'n_is_nc': '', 'n_is_sth': ''},
 'transfusion': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'transgression': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'transgressor': {'n_is_nc': '', 'n_is_sb': '0'},
 'transient': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'transistor': {'n_is_nc': '', 'n_is_sth': ''},
 'translation': {'n_is_nc': '', 'n_is_sth': ''},
 'translator': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'transliteration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'transmittal': {'n_is_nc': '', 'n_is_sth': ''},
 'transmitter': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'transmutation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'transom': {'n_is_nc': '', 'n_is_sth': ''},
 'transponder': {'n_is_nc': '', 'n_is_sth': ''},
 'transporter': {'n_is_nc': '', 'n_is_sth': ''},
 'transposition': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'trapeze': {'n_is_nc': '', 'n_is_sth': ''},
 'trapezoid': {'n_is_nc': '', 'n_is_sth': ''},
 'trappings': {'n_is_nc': '', 'n_is_sth': ''},
 'trauma': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'travail': {'n_is_nc': '', 'n_is_sth': ''},
 'travel': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'travelled', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_for': '', 'v_to': '', 'vb_to_vbz': 'travels', 'vb_to_vbd': 'travelled', 'vb_to_vbn': 'travelled', 'vb_to_jj': 'travelled', 'vb_to_vbg': 'traveling', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'traveler': {'n_is_nc': '', 'n_is_sb': '0', 'nc_typical': ''},
 'traversal': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'traverse': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'travesty': {'n_is_nc': '', 'n_is_sth': ''},
 'trawl': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'treachery': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'tread': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'treasure': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'treasurer': {'n_is_nc': '', 'n_is_sb': '0'},
 'treatise': {'n_is_nc': '', 'n_is_sth': ''},
 'treatment': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'treat', 'nn_to_jj': 'treated'},
 'treetop': {'n_is_nc': '', 'n_is_sth': ''},
 'trek': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'trellis': {'n_is_nc': '', 'n_is_sth': ''},
 'tremble': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': '', 'vi_typical': ''},
 'trembler': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'tremolo': {'n_is_nc': '', 'n_is_sth': ''},
 'tremor': {'n_is_nc': '', 'n_is_sth': ''},
 'trench': {'n_is_nc': '', 'n_is_sth': ''},
 'trencherman': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'trespass': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'tress': {'n_is_nc': '', 'n_is_sth': ''},
 'trestle': {'n_is_nc': '', 'n_is_sth': ''},
 'trial': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'try', 'nn_to_jj': 'tried'},
 'tribulation': {'n_is_nc': '', 'n_is_sth': ''},
 'tribune': {'n_is_nc': '', 'n_is_sth': ''},
 'tributary': {'n_is_nc': '', 'n_is_sth': ''},
 'trice': {'n_is_nc': '', 'n_is_sth': ''},
 'tricker': {'n_is_nc': '', 'n_is_sb': '0'},
 'trickle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'trickster': {'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'trick', 'nn_to_jj': 'trickish'},
 'tricolor': {'n_is_nc': '', 'n_is_sth': ''},
 'tricycle': {'n_is_nc': '', 'n_is_sth': ''},
 'trident': {'n_is_nc': '', 'n_is_sth': ''},
 'trier': {'n_is_nc': '', 'n_is_sb': '0', 'n_is_sth': ''},
 'trifle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'triggerman': {'n_is_nc': '', 'n_is_sb': '0'},
 'trigon': {'n_is_nc': '', 'n_is_sth': ''},
 'trike': {'n_is_nc': '', 'n_is_sth': ''},
 'trill': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'trillion': {'n_is_nc': '', 'n_is_sth': ''},
 'trilobite': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'trilogy': {'n_is_nc': '', 'n_is_sth': ''},
 'trimester': {'n_is_nc': '', 'n_is_sth': ''},
 'trinket': {'n_is_nc': '', 'n_is_sth': ''},
 'triplet': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'tripod': {'n_is_nc': '', 'n_is_sth': ''},
 'trivet': {'n_is_nc': '', 'n_is_sth': ''},
 'trivia': {'n_is_nc': '', 'n_is_sth': ''},
 'triviality': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'troche': {'n_is_nc': '', 'n_is_sth': ''},
 'troglodyte': {'n_is_nc': '', 'n_is_sb': '0'},
 'troll': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'trolley': {'n_is_nc': '', 'n_is_sth': ''},
 'trollop': {'n_is_nc': '', 'n_is_sb': '0'},
 'trombone': {'n_is_nc': '', 'n_is_sth': ''},
 'trooper': {'n_is_nc': '', 'n_is_sb': '0'},
 'trope': {'n_is_nc': '', 'n_is_sth': ''},
 'tropic': {'n_is_nc': '', 'n_is_sth': ''},
 'tropics': {'n_is_nc': '', 'n_is_sth': ''},
 'trot': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'troublemaker': {'n_is_nc': '', 'n_is_sb': '0'},
 'trough': {'n_is_nc': '', 'n_is_sth': ''},
 'troupe': {'n_is_nc': '', 'n_is_sth': ''},
 'trouper': {'n_is_nc': '', 'n_is_sb': '0'},
 'trouser': {'n_is_nc': '', 'n_is_sth': ''},
 'trousseau': {'n_is_nc': '', 'n_is_sth': ''},
 'trout': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_eq_nns': ''},
 'trowel': {'n_is_nc': '', 'n_is_sth': ''},
 'truce': {'n_is_nc': '', 'n_is_sth': ''},
 'trucker': {'n_is_nc': '', 'n_is_sb': '0'},
 'truelove': {'n_is_nc': '', 'n_is_sb': '0', 'n_is_sth': ''},
 'trump': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'trumpet': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'trumpeter': {'n_is_nc': '', 'n_is_sb': '0'},
 'truncheon': {'n_is_nc': '', 'n_is_sth': ''},
 'trundle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'trunk': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'nc_typical': ''},
 'trunks': {'n_is_nc': '', 'n_is_sth': ''},
 'truss': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'trust': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'trustable', 'v_compcl': '', 'v_to_vb': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_to': '', 'vb_to_vbz': 'trusts', 'vb_to_vbd': 'trusted', 'vb_to_vbn': 'trusted', 'vb_to_jj': 'trustable', 'vb_to_vbg': 'trusting', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'trustee': {'n_is_nc': '', 'n_is_sb': '0'},
 'trusteeship': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'try': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'tried', 'v_vbg': '', 'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'tries', 'vb_to_vbd': 'tried', 'vb_to_vbn': 'tried', 'vb_to_jj': 'tried', 'v_n_to_vb': '', 'vb_to_vbg': 'trying', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'tryout': {'n_is_nc': '', 'n_is_sth': ''},
 'tryst': {'n_is_nc': '', 'n_is_sth': ''},
 'tsar': {'n_is_nc': '', 'n_is_sb': '0'},
 'tsunami': {'n_is_nc': '', 'n_is_sth': ''},
 'tub': {'n_is_nc': '', 'n_is_sth': ''},
 'tuba': {'n_is_nc': '', 'n_is_sth': ''},
 'tuber': {'n_is_nc': '', 'n_is_sth': ''},
 'tuberose': {'n_is_nc': '', 'n_is_sth': ''},
 'tuck': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'tuckahoe': {'n_is_nc': '', 'n_is_sth': ''},
 'tucker': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'tuft': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'tug': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'tugboat': {'n_is_nc': '', 'n_is_sth': ''},
 'tum': {'n_is_nc': '', 'n_is_sth': ''},
 'tumble': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'tumbler': {'n_is_nc': '', 'n_is_sb': '0'},
 'tummy': {'n_is_nc': '', 'n_is_sth': ''},
 'tumor': {'n_is_nc': '', 'n_is_sth': ''},
 'tumult': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'tuna': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'tune-up': {'n_is_nc': '', 'n_is_sth': ''},
 'tunic': {'n_is_nc': '', 'n_is_sth': ''},
 'tunica': {'n_is_nc': '', 'n_is_sth': ''},
 'tupelo': {'n_is_nc': '', 'n_is_sth': ''},
 'turban': {'n_is_nc': '', 'n_is_sth': ''},
 'turbine': {'n_is_nc': '', 'n_is_sth': ''},
 'tureen': {'n_is_nc': '', 'n_is_sth': ''},
 'turk': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'turkey': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'turn-on': {'n_is_nc': '', 'n_is_sth': ''},
 'turnabout': {'n_is_nc': '', 'n_is_sth': ''},
 'turnaround': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'turnbuckle': {'n_is_nc': '', 'n_is_sth': ''},
 'turncoat': {'n_is_nc': '', 'n_is_sb': '0'},
 'turndown': {'n_is_nc': '', 'n_is_sth': ''},
 'turning': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'turn', 'vbg_to_vbn': 'turned', 'nc_typical': ''},
 'turnip': {'n_is_nc': '', 'n_is_sth': ''},
 'turnkey': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'turnoff': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'turn', 'nn_to_jj': 'turned'},
 'turnstile': {'n_is_nc': '', 'n_is_sth': ''},
 'turntable': {'n_is_nc': '', 'n_is_sth': ''},
 'turret': {'n_is_nc': '', 'n_is_sth': ''},
 'turtle': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'tusk': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'tusker': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'tussle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'tutor': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nc_typical': ''},
 'tutorial': {'n_is_nc': '', 'n_is_sth': ''},
 'tv': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'cap_word': 'TV'},
 'twain': {'n_is_nc': '', 'n_is_sth': ''},
 'twang': {'n_is_nc': '', 'n_is_sth': ''},
 'twig': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'twilight': {'n_is_nc': '', 'n_is_sth': ''},
 'twinge': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'twinkle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'twirl': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'twister': {'n_is_nc': '', 'n_is_sth': ''},
 'twit': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'twitch': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'twitter': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'two-seater': {'n_is_nc': '', 'n_is_sth': ''},
 'two-timer': {'n_is_nc': '', 'n_is_sb': '0'},
 'twofer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'tycoon': {'n_is_nc': '', 'n_is_sb': '0'},
 'tyke': {'n_is_nc': '', 'n_is_sb': '0'},
 'tympani': {'n_is_nc': '', 'n_is_sth': ''},
 'tympanum': {'n_is_nc': '', 'n_is_sth': ''},
 'typeface': {'n_is_nc': '', 'n_is_sth': ''},
 'typewriter': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'typhoon': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'typology': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'tyrannosaur': {'n_is_nc': '', 'n_is_sb': '0'},
 'tyranny': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'tyrant': {'n_is_nc': '', 'n_is_sb': '0'},
 'tyro': {'n_is_nc': '', 'n_is_sb': '0'},
 'u-boat': {'n_is_nc': '', 'n_is_sth': ''},
 'ubermensch': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'udder': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ufo': {'n_is_nc': '', 'n_is_sth': ''},
 'ulcer': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ulna': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ultimate': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ultrasound': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'umbra': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ump': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'umpire': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'unbeliever': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'underbelly': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'underboss': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'undercarriage': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'underclothes': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'undercoat': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'undercurrent': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'undercut': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbd_eq_vbn': ''},
 'undergarment': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'undergraduate': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'underling': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'underpants': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'underpass': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'undersecretary': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'undershirt': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'underside': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'understatement': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'understudy': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'undertaking': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'vbg_to_vb': 'undertake', 'vbg_to_vbn': 'undertaken'},
 'undertone': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'underworld': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'undies': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'undress': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'undulation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'unicorn': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'unio': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'unmentionable': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'untruth': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'upheaval': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'upland': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'uprising': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'upset': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'upsetting', 'nn_to_rb': 'upsettingly', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'vb_to_vbz': 'upsets', 'vb_to_rb': 'upsettingly', 'vb_to_jj': 'upsetting', 'vb_to_vbg': 'upseting', 'vbn_to_vbg': 'upseting', 'sb_be_jj': ''},
 'upstairs': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'upstart': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'upsurge': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'uptake': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'upturn': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'urchin': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': ''},
 'ureter': {'n_is_nc': '', 'n_is_sth': ''},
 'urethra': {'n_is_nc': '', 'n_is_sth': ''},
 'urinal': {'n_is_nc': '', 'n_is_sth': ''},
 'urn': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'urus': {'n_is_nc': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'usage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'use': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'useful', 'nn_to_rb': 'usefully', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'uses', 'vb_to_vbd': 'used', 'vb_to_vbn': 'used', 'vb_to_rb': 'usefully', 'vb_to_jj': 'useful', 'vb_to_vbg': 'using', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'usher': {'n_is_nc': '', 'n_is_sb': '0', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'utensil': {'n_is_nc': '', 'n_is_sth': ''},
 'uterus': {'n_is_nc': '', 'n_is_sth': ''},
 'utterance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'uvula': {'n_is_nc': '', 'n_is_sth': ''},
 'vaccination': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'vaccinia': {'n_is_nc': '', 'n_is_sth': ''},
 'vacillation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'vagabond': {'n_is_nc': '', 'n_is_sb': '0'},
 'vagary': {'n_is_nc': '', 'n_is_sth': ''},
 'vagina': {'n_is_nc': '', 'n_is_sth': ''},
 'vagrant': {'n_is_nc': '', 'n_is_sb': '0'},
 'vale': {'n_is_nc': '', 'n_is_sth': ''},
 'valediction': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'valence': {'n_is_nc': '', 'n_is_sth': ''},
 'valet': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'validation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'validate', 'nn_to_jj': 'valid', 'nn_to_rb': 'validly'},
 'valise': {'n_is_nc': '', 'n_is_sth': ''},
 'valuation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'value', 'nn_to_jj': 'valuable', 'nn_to_rb': 'valuably'},
 'valve': {'n_is_nc': '', 'n_is_sth': ''},
 'vamp': {'n_is_nc': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'vampire': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'vane': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'vanguard': {'n_is_nc': '', 'n_is_sth': ''},
 'vanquisher': {'n_is_nc': '', 'n_is_sb': '0'},
 'vantage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'vapidity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'vapor': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'vaporizer': {'n_is_nc': '', 'n_is_sth': ''},
 'vapors': {'n_is_nc': '', 'n_is_sth': ''},
 'variance': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'vary', 'nn_to_jj': 'various', 'nn_to_rb': 'variously'},
 'variant': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'vary', 'nn_to_jj': 'variable', 'nn_to_rb': 'variably'},
 'variation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'vary', 'nn_to_jj': 'variable', 'nn_to_rb': 'variably'},
 'varicella': {'n_is_nc': '', 'n_is_sth': ''},
 'varlet': {'n_is_nc': '', 'n_is_sb': '0'},
 'varmint': {'n_is_nc': '', 'n_is_sb': '0'},
 'varnish': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'vas': {'n_is_nc': '', 'n_is_sth': ''},
 'vase': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'vassal': {'n_is_nc': '', 'n_is_sb': '0'},
 'vat': {'n_is_nc': '', 'n_is_sth': ''},
 'vaudeville': {'n_is_nc': '', 'n_is_sth': ''},
 'vault': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'vcr': {'n_is_nc': '', 'n_is_sth': ''},
 'vector': {'n_is_nc': '', 'n_is_sth': ''},
 'veg': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'vegetable': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_nns': 'vegetables', 'nc_typical': ''},
 'vegetarian': {'n_is_nc': '', 'n_is_sb': '0'},
 'veggie': {'n_is_nc': '', 'n_is_sb': '0'},
 'veil': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'vein': {'n_is_nc': '', 'n_is_sth': ''},
 'veld': {'n_is_nc': '', 'n_is_sth': ''},
 'velocity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'velour': {'n_is_nc': '', 'n_is_sth': ''},
 'vendee': {'n_is_nc': '', 'n_is_sb': '0'},
 'vender': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'vendor': {'n_is_nc': '', 'n_is_sb': '0'},
 'veneer': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'venetian': {'n_is_nc': '', 'n_is_sb': '0', 'cap_word': 'Venetian'},
 'vent': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'venter': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'ventilation': {'n_is_nc': '', 'n_is_sth': ''},
 'ventilator': {'n_is_nc': '', 'n_is_sth': ''},
 'ventricle': {'n_is_nc': '', 'n_is_sth': ''},
 'venue': {'n_is_nc': '', 'n_is_sth': ''},
 'veranda': {'n_is_nc': '', 'n_is_sth': ''},
 'verandah': {'n_is_nc': '', 'n_is_sth': ''},
 'verb': {'n_is_nc': '', 'n_is_sth': ''},
 'verification': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'verity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'vermin': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'n_is_collective': ''},
 'vernacular': {'n_is_nc': '', 'n_is_sth': ''},
 'verse': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'verso': {'n_is_nc': '', 'n_is_sth': ''},
 'vertebrate': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'vertex': {'n_is_nc': '', 'n_is_sth': ''},
 'vertical': {'n_is_nc': '', 'n_is_sth': ''},
 'vesper': {'n_is_nc': '', 'n_is_sth': ''},
 'vessel': {'n_is_nc': '', 'n_is_sth': ''},
 'vest': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'vestal': {'n_is_nc': '', 'n_is_sb': '0'},
 'vestibule': {'n_is_nc': '', 'n_is_sth': ''},
 'vestige': {'n_is_nc': '', 'n_is_sth': ''},
 'vestment': {'n_is_nc': '', 'n_is_sth': ''},
 'veterinarian': {'n_is_nc': '', 'n_is_sb': '0'},
 'veterinary': {'n_is_nc': '', 'n_is_sb': '0'},
 'vexation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'viaduct': {'n_is_nc': '', 'n_is_sth': ''},
 'vial': {'n_is_nc': '', 'n_is_sth': ''},
 'vibes': {'n_is_nc': '', 'n_is_sth': ''},
 'vibration': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'vibrator': {'n_is_nc': '', 'n_is_sth': ''},
 'vibrio': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'vicar': {'n_is_nc': '', 'n_is_sb': '0'},
 'viceroy': {'n_is_nc': '', 'n_is_sb': '0'},
 'vicinity': {'n_is_nc': '', 'n_is_sth': ''},
 'victor': {'n_is_nc': '', 'n_is_sb': '0'},
 'victuals': {'n_is_nc': '', 'n_is_sth': ''},
 'videodisc': {'n_is_nc': '', 'n_is_sth': ''},
 'videodisk': {'n_is_nc': '', 'n_is_sth': ''},
 'viewer': {'n_is_nc': '', 'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'viewfinder': {'n_is_nc': '', 'n_is_sth': ''},
 'viewpoint': {'n_is_nc': '', 'n_is_sth': ''},
 'vigil': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'vignette': {'n_is_nc': '', 'n_is_sth': ''},
 'villa': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'villager': {'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'village', 'nn_to_jj': 'villagey', 'nc_typical': ''},
 'villain': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'vine': {'n_is_nc': '', 'n_is_sth': ''},
 'vineyard': {'n_is_nc': '', 'n_is_sth': ''},
 'vintage': {'n_is_nc': '', 'n_is_sth': ''},
 'viola': {'n_is_nc': '', 'n_is_sth': ''},
 'violin': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'vip': {'n_is_nc': '', 'n_is_sb': '0'},
 'viper': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'virago': {'n_is_nc': '', 'n_is_sb': '0'},
 'virgin': {'n_is_nc': '', 'n_is_sb': '0'},
 'virtue': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'virtuous', 'nn_to_rb': 'virtuously', 'vb_to_rb': 'virtuously', 'vb_to_jj': 'virtuous'},
 'visage': {'n_is_nc': '', 'n_is_sth': ''},
 'viscera': {'n_is_nc': '', 'n_is_sth': ''},
 'viscount': {'n_is_nc': '', 'n_is_sb': '0'},
 'vise': {'n_is_nc': '', 'n_is_sth': ''},
 'visionary': {'n_is_nc': '', 'n_is_sb': '0'},
 'visitation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'visor': {'n_is_nc': '', 'n_is_sth': ''},
 'vista': {'n_is_nc': '', 'n_is_sth': ''},
 'vitals': {'n_is_nc': '', 'n_is_sth': ''},
 'viva': {'n_is_nc': '', 'n_is_sth': ''},
 'vixen': {'n_is_nc': '', 'n_is_sb': '0'},
 'vizier': {'n_is_nc': '', 'n_is_sb': '0'},
 'vocabulary': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'vocalist': {'n_is_nc': '', 'n_is_sb': '0'},
 'vocalization': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'vocation': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'vodka': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'vogue': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'voice': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'voiced', 'nn_to_rb': 'voicelessly', 'vb_to_rb': 'voicelessly', 'vb_to_jj': 'voiced', 'v_compcl_non': '', 'v_infcl_non': ''},
 'vole': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': ''},
 'volt': {'n_is_nc': '', 'n_is_sth': ''},
 'voltage': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'voodoo': {'n_is_nc': '', 'n_is_sb': '0'},
 'voting': {'n_is_nc': '', 'n_is_sth': '', 'vbg_to_vb': 'vote', 'vbg_to_vbn': 'voted'},
 'voucher': {'n_is_nc': '', 'n_is_sb': '0'},
 'vow': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_to_vb': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'vowel': {'n_is_nc': '', 'n_is_sth': ''},
 'vox': {'n_is_nc': '', 'n_is_sth': ''},
 'voyage': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'voyageable', 'vb_to_jj': 'voyageable', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'vulgarian': {'n_is_nc': '', 'n_is_sb': '0'},
 'vulgarism': {'n_is_nc': '', 'n_is_sth': ''},
 'vulgarity': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'vulture': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'vulva': {'n_is_nc': '', 'n_is_sth': ''},
 'wad': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'wade': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'wadi': {'n_is_nc': '', 'n_is_sth': ''},
 'wafer': {'n_is_nc': '', 'n_is_sth': ''},
 'waft': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'wag': {'n_is_nc': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'wager': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'wagon': {'n_is_nc': '', 'n_is_sth': ''},
 'wagoner': {'n_is_nc': '', 'n_is_sb': '0'},
 'waif': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'wail': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'waistband': {'n_is_nc': '', 'n_is_sth': ''},
 'waistcoat': {'n_is_nc': '', 'n_is_sth': ''},
 'waistline': {'n_is_nc': '', 'n_is_sth': ''},
 'wait': {'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'v_to_vb': '', 'vb_to_vbz': 'waits', 'vb_to_vbd': 'waited', 'vb_to_vbn': 'waited', 'vb_to_vbg': 'waiting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'waiver': {'n_is_nc': '', 'n_is_sth': ''},
 'walkie-talkie': {'n_is_nc': '', 'n_is_sth': ''},
 'walkway': {'n_is_nc': '', 'n_is_sth': ''},
 'wallaby': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'wallboard': {'n_is_nc': '', 'n_is_sth': ''},
 'walloping': {'n_is_nc': '', 'n_is_sth': ''},
 'wallow': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'wally': {'n_is_nc': '', 'n_is_sb': '0'},
 'walnut': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'walrus': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'wand': {'n_is_nc': '', 'n_is_sth': ''},
 'wanderer': {'n_is_nc': '', 'n_is_sb': '0'},
 'want': {'n_is_nc': '', 'n_is_sth': '', 'v_vbg': '', 'v_to_vb': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'wants', 'vb_to_vbd': 'wanted', 'vb_to_vbn': 'wanted', 'vb_to_vbg': 'wanting', 'vbd_eq_vbn': '', 'vbg_non': ''},
 'wanton': {'n_is_nc': '', 'n_is_sb': '0'},
 'wapiti': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'warble': {'n_is_nc': '', 'n_is_sth': ''},
 'warbler': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'warden': {'n_is_nc': '', 'n_is_sb': '0'},
 'ware': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'warehouseman': {'n_is_nc': '', 'n_is_sb': '0'},
 'warhead': {'n_is_nc': '', 'n_is_sth': ''},
 'warlock': {'n_is_nc': '', 'n_is_sb': '0'},
 'warlord': {'n_is_nc': '', 'n_is_sb': '0'},
 'warm-up': {'n_is_nc': '', 'n_is_sth': ''},
 'warmer': {'n_is_nc': '', 'n_is_sth': ''},
 'warmonger': {'n_is_nc': '', 'n_is_sb': '0'},
 'warp': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'warranty': {'n_is_nc': '', 'n_is_sth': ''},
 'warren': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'warrior': {'n_is_nc': '', 'n_is_sb': '0'},
 'warship': {'n_is_nc': '', 'n_is_sth': ''},
 'wart': {'n_is_nc': '', 'n_is_sth': ''},
 'wash': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'washed', 'v_to_vbg': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_against': '', 'vb_to_vbz': 'washes', 'vb_to_vbd': 'washed', 'vb_to_vbn': 'washed', 'vb_to_jj': 'washed', 'vb_to_vbg': 'washing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'washboard': {'n_is_nc': '', 'n_is_sth': ''},
 'washcloth': {'n_is_nc': '', 'n_is_sth': ''},
 'washer': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'washout': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'washroom': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_vb': 'wash', 'nn_to_jj': 'washed', 'nc_typical': ''},
 'washstand': {'n_is_nc': '', 'n_is_sth': ''},
 'wasp': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'wassail': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'waste': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'wast', 'nn_to_jj': 'wasteful', 'nn_to_rb': 'wastefully', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'wastes', 'vb_to_vbd': 'wasted', 'vb_to_vbn': 'wasted', 'vb_to_vbg': 'wasting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'wasteland': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'waster': {'n_is_nc': '', 'n_is_sb': '0'},
 'wastrel': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'watchband': {'n_is_nc': '', 'n_is_sth': ''},
 'watchdog': {'n_is_nc': '', 'n_is_sb': '0'},
 'watcher': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'watchman': {'n_is_nc': '', 'n_is_sb': '0'},
 'watchtower': {'n_is_nc': '', 'n_is_sth': ''},
 'watchword': {'n_is_nc': '', 'n_is_sth': ''},
 'watercolor': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'watercourse': {'n_is_nc': '', 'n_is_sth': ''},
 'watercraft': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'waterfall': {'n_is_nc': '', 'n_is_sth': ''},
 'waterfowl': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'waterfront': {'n_is_nc': '', 'n_is_sth': ''},
 'waterline': {'n_is_nc': '', 'n_is_sth': ''},
 'waterman': {'n_is_nc': '', 'n_is_sb': '0'},
 'watermark': {'n_is_nc': '', 'n_is_sth': ''},
 'waterproof': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'water', 'nn_to_jj': 'waterless', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'waters': {'n_is_nc': '', 'n_is_sth': ''},
 'watershed': {'n_is_nc': '', 'n_is_sth': ''},
 'waterside': {'n_is_nc': '', 'n_is_sth': ''},
 'waterspout': {'n_is_nc': '', 'n_is_sth': ''},
 'waterway': {'n_is_nc': '', 'n_is_sth': ''},
 'watt': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'wattle': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'wavelength': {'n_is_nc': '', 'n_is_sth': ''},
 'wavelet': {'n_is_nc': '', 'n_is_sth': ''},
 'waver': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '', 'nn_to_vb': 'wave', 'nn_to_jj': 'waveless', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'waxwork': {'n_is_nc': '', 'n_is_sth': ''},
 'wayfarer': {'n_is_nc': '', 'n_is_sb': '0'},
 'wayside': {'n_is_nc': '', 'n_is_sth': ''},
 'weakling': {'n_is_nc': '', 'n_is_sb': '0'},
 'weasel': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'webbing': {'n_is_nc': '', 'n_is_sth': ''},
 'wedge': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'weed': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'weedless', 'vb_to_jj': 'weedless', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbd_eq_vbn': ''},
 'weeds': {'n_is_nc': '', 'n_is_sth': ''},
 'weekday': {'n_is_nc': '', 'n_is_sth': '', 'nc_typical': ''},
 'weevil': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'weigher': {'n_is_nc': '', 'n_is_sb': '0'},
 'weight': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'weigh', 'nn_to_jj': 'weighable', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'weir': {'n_is_nc': '', 'n_is_sth': ''},
 'weirdo': {'n_is_nc': '', 'n_is_sb': '0'},
 'welder': {'n_is_nc': '', 'n_is_sb': '0'},
 'wellhead': {'n_is_nc': '', 'n_is_sth': ''},
 'wellspring': {'n_is_nc': '', 'n_is_sth': ''},
 'welt': {'n_is_nc': '', 'n_is_sth': ''},
 'welter': {'n_is_nc': '', 'n_is_sth': ''},
 'wen': {'n_is_nc': '', 'n_is_sth': ''},
 'wench': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'werewolf': {'n_is_nc': '', 'n_is_sb': '0'},
 'westerly': {'n_is_nc': '', 'n_is_sth': ''},
 'wether': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'wetting': {'n_is_nc': '', 'n_is_sth': ''},
 'whack': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'whacking': {'n_is_nc': '', 'n_is_sth': ''},
 'whale': {'n_is_nc': '', 'n_is_sb': '3', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': '', 'n_is_sth': '3'},
 'whammy': {'n_is_nc': '', 'n_is_sth': ''},
 'wharf': {'n_is_nc': '', 'n_is_sth': ''},
 'wheelbarrow': {'n_is_nc': '', 'n_is_sth': ''},
 'wheelbase': {'n_is_nc': '', 'n_is_sth': ''},
 'wheelchair': {'n_is_nc': '', 'n_is_sth': ''},
 'wheelhouse': {'n_is_nc': '', 'n_is_sth': ''},
 'wheeze': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'whelk': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'whereabouts': {'n_is_nc': '', 'n_is_sth': ''},
 'wherry': {'n_is_nc': '', 'n_is_sth': ''},
 'whetstone': {'n_is_nc': '', 'n_is_sth': ''},
 'whim': {'n_is_nc': '', 'n_is_sth': ''},
 'whimper': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'whimsicality': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'whimsy': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'whine': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'whip': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'whipped', 'vb_to_jj': 'whipped', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'whiplash': {'n_is_nc': '', 'n_is_sth': ''},
 'whipping': {'n_is_nc': '', 'n_is_sth': ''},
 'whippoorwill': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'whir': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'whirl': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'whirligig': {'n_is_nc': '', 'n_is_sth': ''},
 'whirlpool': {'n_is_nc': '', 'n_is_sth': ''},
 'whirlwind': {'n_is_nc': '', 'n_is_sth': ''},
 'whirlybird': {'n_is_nc': '', 'n_is_sth': ''},
 'whisk': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'whisker': {'n_is_nc': '', 'n_is_sth': ''},
 'whiskers': {'n_is_nc': '', 'n_is_sth': ''},
 'whisper': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'whisppery', 'v_compcl': '', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_about': '', 'v_to': '', 'vb_to_vbz': 'whispers', 'vb_to_vbd': 'whispered', 'vb_to_vbn': 'whispered', 'vb_to_jj': 'whisppery', 'vb_to_vbg': 'whispering', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'whistle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'whit': {'n_is_nc': '', 'n_is_sth': ''},
 'whitefish': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'whitener': {'n_is_nc': '', 'n_is_sth': ''},
 'whitewash': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'whiting': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'whitlow': {'n_is_nc': '', 'n_is_sth': ''},
 'whiz': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'whodunit': {'n_is_nc': '', 'n_is_sth': ''},
 'wholesaler': {'n_is_nc': '', 'n_is_sb': '0'},
 'whoop': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'whopper': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'whore': {'n_is_nc': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'dirtyword': ''},
 'whorehouse': {'n_is_nc': '', 'n_is_sth': ''},
 'whorl': {'n_is_nc': '', 'n_is_sth': ''},
 'wick': {'n_is_nc': '', 'n_is_sth': ''},
 'wicket': {'n_is_nc': '', 'n_is_sth': ''},
 'widower': {'n_is_nc': '', 'n_is_sb': '0'},
 'wig': {'n_is_nc': '', 'n_is_sth': ''},
 'wiggle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'wight': {'n_is_nc': '', 'n_is_sb': '0'},
 'wildcat': {'n_is_nc': '', 'n_is_sb': '0'},
 'wildebeest': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'wildfire': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'wildflower': {'n_is_nc': '', 'n_is_sth': ''},
 'wilding': {'n_is_nc': '', 'n_is_sth': ''},
 'wile': {'n_is_nc': '', 'n_is_sth': ''},
 'wimp': {'n_is_nc': '', 'n_is_sb': '0'},
 'wince': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'winch': {'n_is_nc': '', 'n_is_sth': ''},
 'wind': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'windy', 'nn_to_rb': 'windily', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'winds', 'vb_to_vbd': 'winded,wound', 'vb_to_vbn': 'winded,wound', 'vb_to_rb': 'windily', 'vb_to_jj': 'windy', 'vb_to_vbg': 'winding', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'windbag': {'n_is_nc': '', 'n_is_sb': '0'},
 'windbreak': {'n_is_nc': '', 'n_is_sth': ''},
 'winder': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'windfall': {'n_is_nc': '', 'n_is_sth': ''},
 'windjammer': {'n_is_nc': '', 'n_is_sb': '0'},
 'windlass': {'n_is_nc': '', 'n_is_sth': ''},
 'windmill': {'n_is_nc': '', 'n_is_sth': ''},
 'windowpane': {'n_is_nc': '', 'n_is_sth': ''},
 'windowsill': {'n_is_nc': '', 'n_is_sth': ''},
 'windpipe': {'n_is_nc': '', 'n_is_sth': ''},
 'windscreen': {'n_is_nc': '', 'n_is_sth': ''},
 'windshield': {'n_is_nc': '', 'n_is_sth': ''},
 'windstorm': {'n_is_nc': '', 'n_is_sth': ''},
 'wine': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'wineglass': {'n_is_nc': '', 'n_is_sth': ''},
 'winery': {'n_is_nc': '', 'n_is_sth': ''},
 'wingman': {'n_is_nc': '', 'n_is_sb': '0'},
 'wingspan': {'n_is_nc': '', 'n_is_sth': ''},
 'wink': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'winning': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'win', 'vbg_to_vbn': 'won'},
 'wino': {'n_is_nc': '', 'n_is_sth': ''},
 'winter': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'wintry', 'nn_to_rb': 'wintrily', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'winterberry': {'n_is_nc': '', 'n_is_sth': ''},
 'wiper': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'wiretap': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'wisecrack': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'wisp': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'wisteria': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'witch': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'withe': {'n_is_nc': '', 'n_is_sth': ''},
 'witness': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'witticism': {'n_is_nc': '', 'n_is_sth': ''},
 'wiz': {'n_is_nc': '', 'n_is_sb': '0'},
 'wizard': {'n_is_nc': '', 'n_is_sb': '0'},
 'wobble': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'woe': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'wok': {'n_is_nc': '', 'n_is_sth': ''},
 'wold': {'n_is_nc': '', 'n_is_sth': ''},
 'wolverine': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'womb': {'n_is_nc': '', 'n_is_sth': ''},
 'wonder': {'n_is_nc': '', 'n_is_sth': '', 'nn_to_jj': 'wonderful', 'nn_to_rb': 'wonderfully', 'v_compcl': '', 'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_about': '', 'vb_to_vbz': 'wonders', 'vb_to_vbd': 'wondered', 'vb_to_vbn': 'wondered', 'vb_to_rb': 'wonderfully', 'vb_to_jj': 'wonderful', 'vb_to_vbg': 'wondering', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'wonderland': {'n_is_nc': '', 'n_is_sth': ''},
 'wonk': {'n_is_nc': '', 'n_is_sb': '0'},
 'woodbine': {'n_is_nc': '', 'n_is_sth': ''},
 'woodcarving': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'woodchuck': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'woodcock': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'woodcut': {'n_is_nc': '', 'n_is_sth': ''},
 'woodcutter': {'n_is_nc': '', 'n_is_sb': '0'},
 'woodman': {'n_is_nc': '', 'n_is_sb': '0'},
 'woodpecker': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'woodwind': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'woodworker': {'n_is_nc': '', 'n_is_sb': '0'},
 'woof': {'n_is_nc': '', 'n_is_sth': ''},
 'workaholic': {'n_is_nc': '', 'n_is_sb': '0'},
 'workbench': {'n_is_nc': '', 'n_is_sth': ''},
 'workbook': {'n_is_nc': '', 'n_is_sth': ''},
 'workday': {'n_is_nc': '', 'n_is_sth': ''},
 'workforce': {'n_is_nc': '', 'n_is_sth': ''},
 'workhorse': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'workhouse': {'n_is_nc': '', 'n_is_sth': ''},
 'workings': {'n_is_nc': '', 'n_is_sth': ''},
 'workload': {'n_is_nc': '', 'n_is_sth': ''},
 'workman': {'n_is_nc': '', 'n_is_sb': '0', 'nn_to_vb': 'work', 'nn_to_jj': 'workless'},
 'workmate': {'n_is_nc': '', 'n_is_sb': '0'},
 'workout': {'n_is_nc': '', 'n_is_sth': ''},
 'workpiece': {'n_is_nc': '', 'n_is_sth': ''},
 'workroom': {'n_is_nc': '', 'n_is_sth': ''},
 'worksheet': {'n_is_nc': '', 'n_is_sth': ''},
 'workstation': {'n_is_nc': '', 'n_is_sth': ''},
 'worktable': {'n_is_nc': '', 'n_is_sth': ''},
 'world': {'n_is_nc': '', 'n_is_sth': '', 'n_is_place': ''},
 'worm': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'worry': {'n_is_nc': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_about': '', 'vb_to_vbz': 'worries', 'vb_to_vbd': 'worried', 'vb_to_vbn': 'worried', 'vb_to_vbg': 'worrying', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'sb_be_nn.nn_to_jj': 'worried'},
 'wrack': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'wraith': {'n_is_nc': '', 'n_is_sb': '0'},
 'wrangle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'wrapper': {'n_is_nc': '', 'n_is_sth': ''},
 'wrapping': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'wrap', 'vbg_to_vbn': 'wraped'},
 'wreath': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'wreck': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'wren': {'n_is_nc': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'wrench': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'wrestle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'wretch': {'n_is_nc': '', 'n_is_sb': '0'},
 'wriggle': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'wright': {'n_is_nc': '', 'n_is_sb': '0'},
 'wring': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'wrinkle': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'nc_typical': ''},
 'wristband': {'n_is_nc': '', 'n_is_sth': ''},
 'wristwatch': {'n_is_nc': '', 'n_is_sth': ''},
 'writ': {'n_is_nc': '', 'n_is_sth': ''},
 'write-off': {'n_is_nc': '', 'n_is_sth': ''},
 'wrong': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': '', 'be_jj_to_vb': ''},
 'wrongdoer': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sb': '0'},
 'x-ray': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'cap_word': 'X-ray'},
 'xylophone': {'n_is_nc': '', 'n_is_sth': ''},
 'yacht': {'n_is_nc': '', 'n_is_sth': ''},
 'yak': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'yam': {'n_is_nc': '', 'n_is_sth': ''},
 'yama': {'n_is_nc': '', 'n_is_sb': '0'},
 'yap': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'yardage': {'n_is_nc': '', 'n_is_sth': ''},
 'yardstick': {'n_is_nc': '', 'n_is_sth': ''},
 'yarn': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'yea': {'n_is_nc': '', 'n_is_sth': ''},
 'year-end': {'n_is_nc': '', 'n_is_sth': ''},
 'yearbook': {'n_is_nc': '', 'n_is_sth': ''},
 'yearling': {'n_is_nc': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'yearly': {'n_is_nc': '', 'n_is_sth': ''},
 'yearning': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'yell': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'yellowbird': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'yen': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'yenta': {'n_is_nc': '', 'n_is_sb': '0'},
 'yeoman': {'n_is_nc': '', 'n_is_sb': '0'},
 'yes-man': {'n_is_nc': '', 'n_is_sb': '0'},
 'yeti': {'n_is_nc': '', 'n_is_sb': '0'},
 'yew': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'yi': {'n_is_nc': '', 'n_is_sb': '0'},
 'yield': {'n_is_nc': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'yip': {'n_is_nc': '', 'n_is_sth': ''},
 'yoghurt': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'yogurt': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'yoke': {'n_is_nc': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'yokel': {'n_is_nc': '', 'n_is_sb': '0'},
 'youngster': {'n_is_nc': '', 'n_is_sb': '0', 'nn_to_jj': 'young'},
 'yowl': {'n_is_nc': '', 'n_is_sth': ''},
 'yule': {'n_is_nc': '', 'n_is_nu': '', 'n_is_sth': ''},
 'yuppie': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'yurt': {'n_is_nc': '', 'n_is_sth': ''},
 'zag': {'n_is_nc': '', 'n_is_sth': ''},
 'zany': {'n_is_nc': '', 'n_is_sb': '0', 'jj_to_jjr': 'zanier', 'jj_to_jjs': 'zaniest'},
 'zapper': {'n_is_nc': '', 'n_is_sth': ''},
 'zebra': {'n_is_nc': '', 'n_is_sb': '3', 'nc_typical': '', 'n_is_sth': '3'},
 'zenith': {'n_is_nc': '', 'n_is_sth': ''},
 'zephyr': {'n_is_nc': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'zig': {'n_is_nc': '', 'n_is_sth': ''},
 'zip': {'n_is_nc': '', 'n_is_sth': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'iphone': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'ipad': {'n_is_nc': '', 'n_is_sth': '', 'art_an': ''},
 'start-up': {'n_is_nc': '', 'n_is_sth': ''},
 'addict': {'n_is_nc': '', 'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'confu_pair': 'addicted'},
 'grief': {'n_is_nu': '', 'n_is_sth': '', 'nn_eq_nns': ''},
 'meat': {'n_is_nu': '', 'n_is_sth': '', 'nn_eq_nns': ''},
 'aaron': {'n_is_nu': '', 'art_an': '', 'n_is_sb': '0'},
 'abandon': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_compcl': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'abandons', 'vb_to_vbd': 'abandoned', 'vb_to_vbn': 'abandoned', 'vb_to_rb': 'abandonedly', 'vb_to_nn': 'abandonment', 'vb_to_jj': 'abandoned', 'vb_to_vbg': 'abandoning', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'abasement': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abele': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abeyance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abhorrence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abjection': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ablation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abnegation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abnormality': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abolishment': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abolition': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abracadabra': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abrasiveness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'absenteeism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'absolution': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'absolute', 'nn_to_jj': 'absolute', 'nn_to_rb': 'absolutely'},
 'absorbent': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'absorption': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abstinence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abstractness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abundance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'abyssinia': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ac': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'academe': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'academia': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acceleration': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acceptability': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'access': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'accessible', 'nn_to_rb': 'accessibly', 'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'accesses', 'vb_to_vbd': 'accessed', 'vb_to_vbn': 'accessed', 'vb_to_rb': 'accessibly', 'vb_to_jj': 'accessible', 'vb_to_vbg': 'accessing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'accessibility': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acclaim': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'acclimatization': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'accordance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'accord', 'nn_to_jj': 'according', 'nn_to_rb': 'accordingly'},
 'accountability': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'account', 'nn_to_jj': 'accountable'},
 'accountancy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'accounting': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbg_to_vb': 'account', 'vbg_to_vbn': 'accounted'},
 'accoutrement': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'accuracy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'accurate', 'nn_to_rb': 'accurately', 'nu_typical': ''},
 'acerbity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acetaldehyde': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acetaminophen': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acetone': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acetyl': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acetylcholine': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acetylene': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acidification': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acidity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ack-ack': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acne': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acquaintanceship': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acquiescence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acreage': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acrimony': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acting': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbg_to_vb': 'act', 'vbg_to_vbn': 'acted'},
 'actinolite': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'activation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'activism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acuity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acumen': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acupuncture': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'acuteness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'adam': {'n_is_nu': '', 'n_is_sb': '0', 'art_an': ''},
 'adamant': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'adaptability': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'adaption': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'add-in': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'adequacy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'adequate', 'nn_to_jj': 'adequate', 'nn_to_rb': 'adequately'},
 'adherence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'adjudication': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'admiralty': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'admiration': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'admire', 'nn_to_jj': 'admirable'},
 'admissibility': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'admittance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ado': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'adobe': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'adolescence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nu_typical': ''},
 'adonis': {'n_is_nu': '', 'n_is_sb': '0', 'art_an': ''},
 'adoration': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'adrenalin': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'adrenaline': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'adulteration': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'adultery': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'advent': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'advice': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_vbg': '', 'nu_typical': ''},
 'advisability': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'advisement': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'advocacy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'advocate'},
 'aegean': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aegis': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aeration': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aerobics': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aeronautics': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aerospace': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aesthetics': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aether': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'affability': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'affection': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'affinity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_nc': ''},
 'affirmative': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'affluence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'afterbirth': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'agar': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'agar-agar': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ageing': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ageratum': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aggrandizement': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aggregation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'aggregate', 'nn_to_jj': 'aggregative'},
 'aggression': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'agha': {'n_is_nu': '', 'n_is_sb': '0', 'art_an': ''},
 'agility': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aging': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'agnosticism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'agonist': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'agriculture': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'agricultural', 'nu_typical': ''},
 'agronomy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ai': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'aids': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'airflow': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'airiness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'airsickness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'airspace': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nu_typical': ''},
 'airwave': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'alacrity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'alarmism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'albinism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'albumen': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'albumin': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'alchemy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'alcoholism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'alertness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'alfalfa': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'alienation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'alimony': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'alkalinity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'alliteration': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'allure': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'aloofness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'alopecia': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'alsace': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'altair': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'alum': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'aluminum': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'amalgam': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'amalgamation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'amazement': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'amazon': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'ambassadorship': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ambergris': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'amblyopia': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'amelioration': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'amen': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'amenorrhea': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ament': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'americium': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'amethyst': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'amiability': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'amine': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'amity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ammonia': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ammonium': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ammunition': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'amnesia': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'amplification': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'amplitude': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'amygdala': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'analgesia': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'analgesic': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'anaphylaxis': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'anarchism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'anarchy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'andersen': {'n_is_nu': '', 'n_is_sb': '0', 'art_an': ''},
 'anemia': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'anesthesia': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'angelica': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'angelus': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'anger': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'angry', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'vbg_non': '', 'nu_typical': ''},
 'angina': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'angling': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbg_to_vb': 'angle', 'vbg_to_vbn': 'angled'},
 'angst': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'anguish': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'anil': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'animus': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'anise': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'annihilation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'annoyance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2', 'nn_to_jj': 'annoying'},
 'anomie': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'anonymity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'anorexia': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'antagonism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'antarctic': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'cap_word': 'Antarctic'},
 'anthracite': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'anthrax': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'anthropology': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'antifreeze': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'antimatter': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'antimony': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'antipathy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'antwerp': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'apartheid': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'apathy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aphasia': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aphrodisia': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'apiary': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aplomb': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'apnea': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'apoplexy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'apostasy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'appendicitis': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'applesauce': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'applicability': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'approbation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'appropriateness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'appropriate', 'nn_to_jj': 'appropriate', 'nn_to_rb': 'appropriately'},
 'apr': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aptness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aquavit': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aquila': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'arbitrage': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'arbitrariness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'arbitrate', 'nn_to_jj': 'arbitrary', 'nn_to_rb': 'arbitrarily'},
 'archaeology': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'archeology': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'archness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ardor': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'arduousness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'argent': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'argon': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'argumentation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aridity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'arista': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'arithmetic': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'armada': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'armor': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'armour': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'army': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_collective': '', 'nc_typical': '', 'n_is_nc': ''},
 'aroma': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'arousal': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'arrogance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'arrowroot': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'arsenic': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'artemisia': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'arteriosclerosis': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'artfulness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'arthritis': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'artistry': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'artlessness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'asbestos': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ascendance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ascendancy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ascendency': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ascension': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'asceticism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ascus': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'asparagus': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'asphalt': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'asphyxia': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'asphyxiation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'assent': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'assimilation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'assistance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'assist', 'nn_to_jj': 'assistant', 'nu_typical': ''},
 'assuredness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'assyria': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'asthma': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'astigmatism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'astonishment': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'astonish', 'nn_to_jj': 'astonishing'},
 'astrakhan': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'astringency': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'astringent': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'astrolabe': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'astrology': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'astronomy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'astuteness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'asylum': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'atavism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ataxia': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'atheism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'atlantic': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'atomization': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'atrocity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'atrophy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'atropine': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'attar': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'attentiveness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'attenuation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'attica': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'attire': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'attribution': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'attribute', 'nn_to_jj': 'attributable'},
 'attrition': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'auckland': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'audacity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aug': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'austen': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'austerity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'authentication': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'authenticity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'authoritarianism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'authorization': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'authorship': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'author'},
 'automation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'automate', 'nn_to_jj': 'automatic', 'nn_to_rb': 'automatic'},
 'automatism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'autonomy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'avail': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vb_to_nn': 'availability', 'vb_to_jj': 'available', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'availability': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'avail', 'nn_to_jj': 'available'},
 'avarice': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aversion': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'aviation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'avidity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'avoidance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'avoid', 'nn_to_jj': 'avoidable'},
 'avoirdupois': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'awareness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'aware'},
 'awe': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'awfulness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'awkwardness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'awkward', 'nn_to_rb': 'awkwardly'},
 'azure': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'babble': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'babel': {'n_is_nu': '', 'n_is_sth': ''},
 'babyhood': {'n_is_nu': '', 'n_is_sth': ''},
 'babylon': {'n_is_nu': '', 'n_is_sth': ''},
 'backdown': {'n_is_nu': '', 'n_is_sth': ''},
 'backwardness': {'n_is_nu': '', 'n_is_sth': ''},
 'backwash': {'n_is_nu': '', 'n_is_sth': ''},
 'bacon': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nu_typical': ''},
 'bacteriology': {'n_is_nu': '', 'n_is_sth': ''},
 'badinage': {'n_is_nu': '', 'n_is_sth': ''},
 'badness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'bad', 'nn_to_rb': 'badly'},
 'bagdad': {'n_is_nu': '', 'n_is_sth': ''},
 'bai': {'n_is_nu': '', 'n_is_sth': ''},
 'bail': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'bakelite': {'n_is_nu': '', 'n_is_sth': ''},
 'baksheesh': {'n_is_nu': '', 'n_is_sth': ''},
 'balderdash': {'n_is_nu': '', 'n_is_sth': ''},
 'baldness': {'n_is_nu': '', 'n_is_sth': ''},
 'baleen': {'n_is_nu': '', 'n_is_sth': ''},
 'ballast': {'n_is_nu': '', 'n_is_sth': ''},
 'ballyhoo': {'n_is_nu': '', 'n_is_sth': ''},
 'baltimore': {'n_is_nu': '', 'n_is_sth': ''},
 'balzac': {'n_is_nu': '', 'n_is_sb': '0'},
 'bandicoot': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'banditry': {'n_is_nu': '', 'n_is_sth': ''},
 'bandung': {'n_is_nu': '', 'n_is_sth': ''},
 'bandwidth': {'n_is_nu': '', 'n_is_sth': ''},
 'banishment': {'n_is_nu': '', 'n_is_sth': ''},
 'banking': {'n_is_nu': '', 'n_is_sth': ''},
 'banter': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'baptism': {'n_is_nu': '', 'n_is_sth': ''},
 'barbarism': {'n_is_nu': '', 'n_is_sth': ''},
 'bareness': {'n_is_nu': '', 'n_is_sth': ''},
 'barilla': {'n_is_nu': '', 'n_is_sth': ''},
 'barite': {'n_is_nu': '', 'n_is_sth': ''},
 'barium': {'n_is_nu': '', 'n_is_sth': ''},
 'barley': {'n_is_nu': '', 'n_is_sth': ''},
 'barter': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'basalt': {'n_is_nu': '', 'n_is_sth': ''},
 'basketry': {'n_is_nu': '', 'n_is_sth': ''},
 'bast': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'bathing': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'bath', 'vbg_to_vbn': 'bathed'},
 'bathos': {'n_is_nu': '', 'n_is_sth': ''},
 'batiste': {'n_is_nu': '', 'n_is_sth': ''},
 'batting': {'n_is_nu': '', 'n_is_sth': ''},
 'bauxite': {'n_is_nu': '', 'n_is_sth': ''},
 'beading': {'n_is_nu': '', 'n_is_sth': ''},
 'beastliness': {'n_is_nu': '', 'n_is_sth': ''},
 'bed-wetting': {'n_is_nu': '', 'n_is_sth': ''},
 'beelzebub': {'n_is_nu': '', 'n_is_sb': '0'},
 'beeswax': {'n_is_nu': '', 'n_is_sth': ''},
 'beet': {'n_is_nu': '', 'n_is_sth': ''},
 'beethoven': {'n_is_nu': '', 'n_is_sb': '0'},
 'beige': {'n_is_nu': '', 'n_is_sth': ''},
 'bellicosity': {'n_is_nu': '', 'n_is_sth': ''},
 'belligerence': {'n_is_nu': '', 'n_is_sth': ''},
 'belonging': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'belong', 'vbg_to_vbn': 'belonged'},
 'ben': {'n_is_nu': '', 'n_is_sth': ''},
 'beneficence': {'n_is_nu': '', 'n_is_sth': ''},
 'benevolence': {'n_is_nu': '', 'n_is_sth': ''},
 'benzene': {'n_is_nu': '', 'n_is_sth': ''},
 'benzine': {'n_is_nu': '', 'n_is_sth': ''},
 'beriberi': {'n_is_nu': '', 'n_is_sth': ''},
 'bering': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'berkeley': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'beryl': {'n_is_nu': '', 'n_is_sth': ''},
 'beryllium': {'n_is_nu': '', 'n_is_sth': ''},
 'best': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'be_jj_to_vb': ''},
 'bestiality': {'n_is_nu': '', 'n_is_sth': ''},
 'bestowal': {'n_is_nu': '', 'n_is_sth': ''},
 'bethlehem': {'n_is_nu': '', 'n_is_sth': ''},
 'better': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'betters', 'vb_to_vbd': 'bettered', 'vb_to_vbn': 'bettered', 'vb_to_vbg': 'bettering', 'vbd_eq_vbn': ''},
 'bewilderment': {'n_is_nu': '', 'n_is_sth': ''},
 'bias': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'bicarbonate': {'n_is_nu': '', 'n_is_sth': ''},
 'bidding': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'bid', 'vbg_to_vbn': 'bid/bidden'},
 'bigamy': {'n_is_nu': '', 'n_is_sth': ''},
 'bigness': {'n_is_nu': '', 'n_is_sth': ''},
 'bigotry': {'n_is_nu': '', 'n_is_sth': ''},
 'bile': {'n_is_nu': '', 'n_is_sth': ''},
 'bilingualism': {'n_is_nu': '', 'n_is_sth': ''},
 'bilirubin': {'n_is_nu': '', 'n_is_sth': ''},
 'billiards': {'n_is_nu': '', 'n_is_sth': ''},
 'billing': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'bill', 'vbg_to_vbn': 'billed'},
 'bingo': {'n_is_nu': '', 'n_is_sth': ''},
 'biochemistry': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'biography': {'n_is_nu': '', 'n_is_sth': '', 'n_is_nc': '', 'nn_to_nns': 'biographies'},
 'biology': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'bionics': {'n_is_nu': '', 'n_is_sth': ''},
 'biotin': {'n_is_nu': '', 'n_is_sth': ''},
 'birmingham': {'n_is_nu': '', 'n_is_sth': ''},
 'birr': {'n_is_nu': '', 'n_is_sth': ''},
 'bisque': {'n_is_nu': '', 'n_is_sth': ''},
 'bitterness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'bitter', 'nn_to_jj': 'bitter', 'nn_to_rb': 'bitterly'},
 'bitumen': {'n_is_nu': '', 'n_is_sth': ''},
 'bizarreness': {'n_is_nu': '', 'n_is_sth': ''},
 'blackmail': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'blackness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'black', 'nn_to_jj': 'black', 'nn_to_rb': 'blackly'},
 'blah': {'n_is_nu': '', 'n_is_sth': ''},
 'blame': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'blamed', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_for': '', 'vb_to_vbz': 'blames', 'vb_to_vbd': 'blamed', 'vb_to_vbn': 'blamed', 'vb_to_jj': 'blamed', 'vb_to_vbg': 'blaming', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'nu_typical': ''},
 'blandness': {'n_is_nu': '', 'n_is_sth': ''},
 'blankness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'blank'},
 'blare': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'blarney': {'n_is_nu': '', 'n_is_sth': ''},
 'blasphemy': {'n_is_nu': '', 'n_is_sth': ''},
 'blatancy': {'n_is_nu': '', 'n_is_sth': ''},
 'bleach': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'bleachers': {'n_is_nu': '', 'n_is_sth': ''},
 'blessedness': {'n_is_nu': '', 'n_is_sth': ''},
 'blessing': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'bless', 'nn_to_jj': 'blessed', 'vbg_to_vb': 'bless', 'vbg_to_vbn': 'blessed', 'n_usu_singular': ''},
 'blindness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'blind', 'nn_to_jj': 'blind', 'nn_to_rb': 'blind'},
 'bliss': {'n_is_nu': '', 'n_is_sth': ''},
 'bloodiness': {'n_is_nu': '', 'n_is_sth': ''},
 'bloodletting': {'n_is_nu': '', 'n_is_sth': ''},
 'bloodshed': {'n_is_nu': '', 'n_is_sth': ''},
 'blowback': {'n_is_nu': '', 'n_is_sth': ''},
 'blubber': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bluestone': {'n_is_nu': '', 'n_is_sth': ''},
 'bluntness': {'n_is_nu': '', 'n_is_sth': ''},
 'blusher': {'n_is_nu': '', 'n_is_sth': ''},
 'bluster': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'boarding': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'board', 'vbg_to_vbn': 'boarded'},
 'bobtail': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'boche': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'bodhisattva': {'n_is_nu': '', 'n_is_sb': '0'},
 'bodywork': {'n_is_nu': '', 'n_is_sth': ''},
 'bohemianism': {'n_is_nu': '', 'n_is_sth': ''},
 'boldface': {'n_is_nu': '', 'n_is_sth': ''},
 'boldness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'bold', 'nn_to_rb': 'boldly'},
 'bolide': {'n_is_nu': '', 'n_is_sth': ''},
 'bombast': {'n_is_nu': '', 'n_is_sth': ''},
 'bondage': {'n_is_nu': '', 'n_is_sth': ''},
 'bonfire': {'n_is_nu': '', 'n_is_sth': ''},
 'bonhomie': {'n_is_nu': '', 'n_is_sth': ''},
 'bookbinding': {'n_is_nu': '', 'n_is_sth': ''},
 'bookishness': {'n_is_nu': '', 'n_is_sth': ''},
 'bookkeeping': {'n_is_nu': '', 'n_is_sth': ''},
 'booze': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'borax': {'n_is_nu': '', 'n_is_sth': ''},
 'boredom': {'n_is_nu': '', 'n_is_sth': ''},
 'boring': {'n_is_nu': '', 'n_is_sth': '', 'be_jj_to_vb': ''},
 'borneo': {'n_is_nu': '', 'n_is_sth': ''},
 'boron': {'n_is_nu': '', 'n_is_sth': ''},
 'bosh': {'n_is_nu': '', 'n_is_sth': ''},
 'botany': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'bouillon': {'n_is_nu': '', 'n_is_sth': ''},
 'boule': {'n_is_nu': '', 'n_is_sth': ''},
 'bourgeoisie': {'n_is_nu': '', 'n_is_sb': '0'},
 'bowling': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'bowl', 'vbg_to_vbn': 'bowled', 'nu_typical': ''},
 'boxing': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'boyishness': {'n_is_nu': '', 'n_is_sth': ''},
 'bracken': {'n_is_nu': '', 'n_is_sth': ''},
 'bragg': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'braille': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'braincase': {'n_is_nu': '', 'n_is_sth': ''},
 'brainpower': {'n_is_nu': '', 'n_is_sth': ''},
 'bran': {'n_is_nu': '', 'n_is_sth': ''},
 'branding': {'n_is_nu': '', 'n_is_sth': ''},
 'brandish': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'bravado': {'n_is_nu': '', 'n_is_sth': ''},
 'bravery': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'brave', 'nn_to_jj': 'brave', 'nn_to_rb': 'bravely', 'nu_typical': ''},
 'brawn': {'n_is_nu': '', 'n_is_sth': ''},
 'breadcrumb': {'n_is_nu': '', 'n_is_sth': ''},
 'breadth': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'broaden', 'nn_to_jj': 'broad', 'nn_to_rb': 'broad'},
 'break-in': {'n_is_nu': '', 'n_is_sth': ''},
 'breakstone': {'n_is_nu': '', 'n_is_sth': ''},
 'breaststroke': {'n_is_nu': '', 'n_is_sth': ''},
 'breeding': {'n_is_nu': '', 'n_is_sth': ''},
 'breeziness': {'n_is_nu': '', 'n_is_sth': ''},
 'brevity': {'n_is_nu': '', 'n_is_sth': ''},
 'bribery': {'n_is_nu': '', 'n_is_sth': ''},
 'bricklaying': {'n_is_nu': '', 'n_is_sth': ''},
 'brickwork': {'n_is_nu': '', 'n_is_sth': ''},
 'brightness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'brighten', 'nn_to_jj': 'bright', 'nn_to_rb': 'brightly'},
 'brilliance': {'n_is_nu': '', 'n_is_sth': ''},
 'brine': {'n_is_nu': '', 'n_is_sth': ''},
 'brio': {'n_is_nu': '', 'n_is_sth': ''},
 'briquet': {'n_is_nu': '', 'n_is_sth': ''},
 'brisket': {'n_is_nu': '', 'n_is_sth': ''},
 'briskness': {'n_is_nu': '', 'n_is_sth': ''},
 'britain': {'n_is_nu': '', 'n_is_sth': ''},
 'brittleness': {'n_is_nu': '', 'n_is_sth': ''},
 'broadcasting': {'n_is_nu': '', 'n_is_sth': ''},
 'broadness': {'n_is_nu': '', 'n_is_sth': ''},
 'broccoli': {'n_is_nu': '', 'n_is_sth': ''},
 'brome': {'n_is_nu': '', 'n_is_sth': ''},
 'bromine': {'n_is_nu': '', 'n_is_sth': ''},
 'bronchitis': {'n_is_nu': '', 'n_is_sth': ''},
 'brouhaha': {'n_is_nu': '', 'n_is_sth': ''},
 'brownout': {'n_is_nu': '', 'n_is_sth': ''},
 'browse': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'brushwork': {'n_is_nu': '', 'n_is_sth': ''},
 'buckskin': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'buckwheat': {'n_is_nu': '', 'n_is_sth': ''},
 'budding': {'n_is_nu': '', 'n_is_sth': ''},
 'buff': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'buffoonery': {'n_is_nu': '', 'n_is_sth': ''},
 'buildup': {'n_is_nu': '', 'n_is_sth': ''},
 'bulimia': {'n_is_nu': '', 'n_is_sth': ''},
 'bullion': {'n_is_nu': '', 'n_is_sth': ''},
 'bullshit': {'n_is_nu': '', 'n_is_sth': ''},
 'buna': {'n_is_nu': '', 'n_is_sth': ''},
 'bungee': {'n_is_nu': '', 'n_is_sth': ''},
 'bunting': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'buoyancy': {'n_is_nu': '', 'n_is_sth': ''},
 'burlap': {'n_is_nu': '', 'n_is_sth': ''},
 'burnish': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'burster': {'n_is_nu': '', 'n_is_sth': ''},
 'bushel': {'n_is_nu': '', 'n_is_sth': ''},
 'busyness': {'n_is_nu': '', 'n_is_sth': ''},
 'butane': {'n_is_nu': '', 'n_is_sth': ''},
 'butter': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'buttered', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'butters', 'vb_to_vbd': 'buttered', 'vb_to_vbn': 'buttered', 'vb_to_jj': 'buttered', 'vb_to_vbg': 'buttering', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nu_typical': ''},
 'butterfat': {'n_is_nu': '', 'n_is_sth': ''},
 'byelorussia': {'n_is_nu': '', 'n_is_sth': ''},
 'byrd': {'n_is_nu': '', 'n_is_sb': '0'},
 'cacao': {'n_is_nu': '', 'n_is_sth': ''},
 'cachet': {'n_is_nu': '', 'n_is_sth': ''},
 'cacique': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'cadmium': {'n_is_nu': '', 'n_is_sth': ''},
 'caffeine': {'n_is_nu': '', 'n_is_sth': ''},
 'cajolery': {'n_is_nu': '', 'n_is_sth': ''},
 'calais': {'n_is_nu': '', 'n_is_sth': ''},
 'calcification': {'n_is_nu': '', 'n_is_sth': ''},
 'calcite': {'n_is_nu': '', 'n_is_sth': ''},
 'calcium': {'n_is_nu': '', 'n_is_sth': ''},
 'calisthenics': {'n_is_nu': '', 'n_is_sth': ''},
 'call-back': {'n_is_nu': '', 'n_is_sth': ''},
 'calligraphy': {'n_is_nu': '', 'n_is_sth': ''},
 'calmness': {'n_is_nu': '', 'n_is_sth': ''},
 'calvary': {'n_is_nu': '', 'n_is_sth': ''},
 'camaraderie': {'n_is_nu': '', 'n_is_sth': ''},
 'cambridge': {'n_is_nu': '', 'n_is_sth': ''},
 'camouflage': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'camphor': {'n_is_nu': '', 'n_is_sth': ''},
 'camshaft': {'n_is_nu': '', 'n_is_sth': ''},
 'canaan': {'n_is_nu': '', 'n_is_sth': ''},
 'candela': {'n_is_nu': '', 'n_is_sth': ''},
 'candlelight': {'n_is_nu': '', 'n_is_sth': ''},
 'candlepower': {'n_is_nu': '', 'n_is_sth': ''},
 'candor': {'n_is_nu': '', 'n_is_sth': ''},
 'cannabis': {'n_is_nu': '', 'n_is_sth': ''},
 'cannibalism': {'n_is_nu': '', 'n_is_sth': ''},
 'canterbury': {'n_is_nu': '', 'cap_word': 'Canterbury', 'n_is_sth': '0'},
 'cantonment': {'n_is_nu': '', 'n_is_sth': ''},
 'canyon': {'n_is_nu': '', 'n_is_sth': ''},
 'capillary': {'n_is_nu': '', 'n_is_sth': '', 'n_is_nc': ''},
 'capitalism': {'n_is_nu': '', 'n_is_sth': ''},
 'capitalization': {'n_is_nu': '', 'n_is_sth': ''},
 'capricorn': {'n_is_nu': '', 'n_is_sth': ''},
 'captivation': {'n_is_nu': '', 'n_is_sth': ''},
 'captivity': {'n_is_nu': '', 'n_is_sth': ''},
 'capture': {'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'captures', 'vb_to_vbd': 'captured', 'vb_to_vbn': 'captured', 'vb_to_vbg': 'capturing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'carbide': {'n_is_nu': '', 'n_is_sth': ''},
 'carbohydrate': {'n_is_nu': '', 'n_is_sth': ''},
 'carbon': {'n_is_nu': '', 'n_is_sth': ''},
 'cardboard': {'n_is_nu': '', 'n_is_sth': ''},
 'cardia': {'n_is_nu': '', 'n_is_sth': ''},
 'cardiogram': {'n_is_nu': '', 'n_is_sth': ''},
 'care': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'careful', 'nn_to_rb': 'carefully', 'v_compcl': '', 'v_to_vb': '', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_about': '', 'v_for': '', 'vb_to_vbz': 'cares', 'vb_to_vbd': 'cared', 'vb_to_vbn': 'cared', 'vb_to_rb': 'carefully', 'vb_to_jj': 'careful', 'vb_to_vbg': 'caring', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'nu_typical': '', 'n_is_nc': ''},
 'careerism': {'n_is_nu': '', 'n_is_sth': ''},
 'caribbean': {'n_is_nu': '', 'n_is_sth': '', 'cap_word': 'Caribbean'},
 'caries': {'n_is_nu': '', 'n_is_sth': ''},
 'carmine': {'n_is_nu': '', 'n_is_sth': ''},
 'carnage': {'n_is_nu': '', 'n_is_sth': ''},
 'carnality': {'n_is_nu': '', 'n_is_sth': ''},
 'carotene': {'n_is_nu': '', 'n_is_sth': ''},
 'carpentry': {'n_is_nu': '', 'n_is_sth': ''},
 'carrefour': {'n_is_nu': '', 'n_is_sth': ''},
 'carrion': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'cartography': {'n_is_nu': '', 'n_is_sth': ''},
 'cartouche': {'n_is_nu': '', 'n_is_sth': ''},
 'carving': {'n_is_nu': '', 'n_is_sth': ''},
 'casein': {'n_is_nu': '', 'n_is_sth': ''},
 'cash': {'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_in': '', 'vb_to_vbz': 'cashes', 'vb_to_vbd': 'cashed', 'vb_to_vbn': 'cashed', 'vb_to_vbg': 'cashing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'nu_typical': ''},
 'cashmere': {'n_is_nu': '', 'n_is_sth': ''},
 'cassia': {'n_is_nu': '', 'n_is_sth': ''},
 'cassiopeia': {'n_is_nu': '', 'n_is_sth': ''},
 'castigation': {'n_is_nu': '', 'n_is_sth': ''},
 'castration': {'n_is_nu': '', 'n_is_sth': ''},
 'casuarina': {'n_is_nu': '', 'n_is_sth': ''},
 'catalysis': {'n_is_nu': '', 'n_is_sth': ''},
 'cathay': {'n_is_nu': '', 'n_is_sth': ''},
 'catheterization': {'n_is_nu': '', 'n_is_sth': ''},
 'catholicism': {'n_is_nu': '', 'n_is_sth': ''},
 'catholicity': {'n_is_nu': '', 'n_is_sth': ''},
 'catnip': {'n_is_nu': '', 'n_is_sth': ''},
 'catsup': {'n_is_nu': '', 'n_is_sth': ''},
 'cattell': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'causality': {'n_is_nu': '', 'n_is_sth': ''},
 'causation': {'n_is_nu': '', 'n_is_sth': ''},
 'caustic': {'n_is_nu': '', 'n_is_sth': ''},
 'cautiousness': {'n_is_nu': '', 'n_is_sth': ''},
 'caviar': {'n_is_nu': '', 'n_is_sth': ''},
 'cease': {'n_is_nu': '', 'n_is_sth': '', 'v_vbg': '', 'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'ceases', 'vb_to_vbd': 'ceased', 'vb_to_vbn': 'ceased', 'vb_to_vbg': 'ceasing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'cedarwood': {'n_is_nu': '', 'n_is_sth': ''},
 'celerity': {'n_is_nu': '', 'n_is_sth': ''},
 'celery': {'n_is_nu': '', 'n_is_sth': ''},
 'celibacy': {'n_is_nu': '', 'n_is_sth': ''},
 'cellophane': {'n_is_nu': '', 'n_is_sth': ''},
 'celluloid': {'n_is_nu': '', 'n_is_sth': ''},
 'cellulose': {'n_is_nu': '', 'n_is_sth': ''},
 'cement': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'censorship': {'n_is_nu': '', 'n_is_sth': ''},
 'censure': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'centralism': {'n_is_nu': '', 'n_is_sth': ''},
 'centrality': {'n_is_nu': '', 'n_is_sth': ''},
 'centralization': {'n_is_nu': '', 'n_is_sth': ''},
 'ceramics': {'n_is_nu': '', 'n_is_sth': ''},
 'cerebration': {'n_is_nu': '', 'n_is_sth': ''},
 'cereus': {'n_is_nu': '', 'n_is_sth': ''},
 'cerise': {'n_is_nu': '', 'n_is_sth': ''},
 'certitude': {'n_is_nu': '', 'n_is_sth': ''},
 'cesium': {'n_is_nu': '', 'n_is_sth': ''},
 'ceylon': {'n_is_nu': '', 'n_is_sth': ''},
 'chafe': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'chaff': {'n_is_nu': '', 'n_is_sth': ''},
 'chagrin': {'n_is_nu': '', 'n_is_sth': ''},
 'champaign': {'n_is_nu': '', 'n_is_sth': ''},
 'changan': {'n_is_nu': '', 'n_is_sth': ''},
 'changeability': {'n_is_nu': '', 'n_is_sth': ''},
 'changeover': {'n_is_nu': '', 'n_is_sth': ''},
 'chaos': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nu_typical': ''},
 'chaparral': {'n_is_nu': '', 'n_is_sth': ''},
 'characterization': {'n_is_nu': '', 'n_is_sth': ''},
 'chard': {'n_is_nu': '', 'n_is_sth': ''},
 'charisma': {'n_is_nu': '', 'n_is_sth': ''},
 'chatter': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'chauvinism': {'n_is_nu': '', 'n_is_sth': ''},
 'cheapness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'cheap', 'nn_to_rb': 'cheaply'},
 'cheekiness': {'n_is_nu': '', 'n_is_sth': ''},
 'cheerfulness': {'n_is_nu': '', 'n_is_sth': ''},
 'chemotherapy': {'n_is_nu': '', 'n_is_sth': ''},
 'chert': {'n_is_nu': '', 'n_is_sth': ''},
 'chi': {'n_is_nu': '', 'n_is_sth': ''},
 'chicane': {'n_is_nu': '', 'n_is_sth': ''},
 'chickenpox': {'n_is_nu': '', 'n_is_sth': ''},
 'chicory': {'n_is_nu': '', 'n_is_sth': ''},
 'childbearing': {'n_is_nu': '', 'n_is_sth': ''},
 'childbirth': {'n_is_nu': '', 'n_is_sth': ''},
 'childishness': {'n_is_nu': '', 'n_is_sth': ''},
 'chili': {'n_is_nu': '', 'n_is_sth': ''},
 'chilliness': {'n_is_nu': '', 'n_is_sth': ''},
 'chinaware': {'n_is_nu': '', 'n_is_sth': ''},
 'chipboard': {'n_is_nu': '', 'n_is_sth': ''},
 'chitchat': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'chitin': {'n_is_nu': '', 'n_is_sth': ''},
 'chlorination': {'n_is_nu': '', 'n_is_sth': ''},
 'chlorine': {'n_is_nu': '', 'n_is_sth': ''},
 'chloroform': {'n_is_nu': '', 'n_is_sth': ''},
 'chlorophyll': {'n_is_nu': '', 'n_is_sth': ''},
 'chlorpromazine': {'n_is_nu': '', 'n_is_sth': ''},
 'cholera': {'n_is_nu': '', 'n_is_sth': ''},
 'cholesterol': {'n_is_nu': '', 'n_is_sth': ''},
 'choline': {'n_is_nu': '', 'n_is_sth': ''},
 'chomp': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'chowder': {'n_is_nu': '', 'n_is_sth': ''},
 'christendom': {'n_is_nu': '', 'n_is_sb': '0', 'n_is_sth': ''},
 'christopher': {'n_is_nu': '', 'n_is_sb': '0'},
 'chroma': {'n_is_nu': '', 'n_is_sth': ''},
 'chromatography': {'n_is_nu': '', 'n_is_sth': ''},
 'chrome': {'n_is_nu': '', 'n_is_sth': ''},
 'chromium': {'n_is_nu': '', 'n_is_sth': ''},
 'chutzpah': {'n_is_nu': '', 'n_is_sth': ''},
 'cigaret': {'n_is_nu': '', 'n_is_sth': ''},
 'cincinnati': {'n_is_nu': '', 'n_is_sth': ''},
 'cinnabar': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'cinnamon': {'n_is_nu': '', 'n_is_sth': ''},
 'circuitry': {'n_is_nu': '', 'n_is_sth': ''},
 'circularity': {'n_is_nu': '', 'n_is_sth': ''},
 'circumspection': {'n_is_nu': '', 'n_is_sth': ''},
 'circumvention': {'n_is_nu': '', 'n_is_sth': ''},
 'cirrhosis': {'n_is_nu': '', 'n_is_sth': ''},
 'cirrus': {'n_is_nu': '', 'n_is_sth': ''},
 'citrin': {'n_is_nu': '', 'n_is_sth': ''},
 'citrine': {'n_is_nu': '', 'n_is_sth': ''},
 'civet': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'civility': {'n_is_nu': '', 'n_is_sth': ''},
 'clairvoyance': {'n_is_nu': '', 'n_is_sth': ''},
 'clamor': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'clap': {'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'clarity': {'n_is_nu': '', 'n_is_sth': ''},
 'classicism': {'n_is_nu': '', 'n_is_sth': ''},
 'clatter': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'clay': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0', 'nu_typical': ''},
 'cleanliness': {'n_is_nu': '', 'n_is_sth': ''},
 'cleanness': {'n_is_nu': '', 'n_is_sth': ''},
 'clearness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'clear', 'nn_to_jj': 'clear', 'nn_to_rb': 'clear'},
 'cleavage': {'n_is_nu': '', 'n_is_sth': ''},
 'clemency': {'n_is_nu': '', 'n_is_sth': ''},
 'cleverness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'clever', 'nn_to_rb': 'cleverly'},
 'clientele': {'n_is_nu': '', 'n_is_sth': ''},
 'clinton': {'n_is_nu': '', 'n_is_sb': '0'},
 'clobber': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'cloisonne': {'n_is_nu': '', 'n_is_sth': ''},
 'clone': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3', 'v_n': '', 'nsubjpass': ''},
 'closeness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'close', 'nn_to_jj': 'close', 'nn_to_rb': 'close'},
 'closing': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'close', 'vbg_to_vbn': 'closed'},
 'clothing': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'cloudiness': {'n_is_nu': '', 'n_is_sth': ''},
 'clove': {'n_is_nu': '', 'n_is_sth': ''},
 'clover': {'n_is_nu': '', 'n_is_sth': ''},
 'clumsiness': {'n_is_nu': '', 'n_is_sth': ''},
 'clutter': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'co': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'co-optation': {'n_is_nu': '', 'n_is_sth': ''},
 'coagulation': {'n_is_nu': '', 'n_is_sth': ''},
 'coalescence': {'n_is_nu': '', 'n_is_sth': ''},
 'coarseness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'coarse', 'nn_to_rb': 'coarsely'},
 'cobalt': {'n_is_nu': '', 'n_is_sth': ''},
 'cocaine': {'n_is_nu': '', 'n_is_sth': ''},
 'cockfighting': {'n_is_nu': '', 'n_is_sth': ''},
 'cockiness': {'n_is_nu': '', 'n_is_sth': ''},
 'cockle': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'cocoa': {'n_is_nu': '', 'n_is_sth': ''},
 'codeine': {'n_is_nu': '', 'n_is_sth': ''},
 'coding': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'code', 'vbg_to_vbn': 'coded'},
 'coercion': {'n_is_nu': '', 'n_is_sth': ''},
 'coexistence': {'n_is_nu': '', 'n_is_sth': ''},
 'cogency': {'n_is_nu': '', 'n_is_sth': ''},
 'cogitation': {'n_is_nu': '', 'n_is_sth': ''},
 'cognition': {'n_is_nu': '', 'n_is_sth': ''},
 'cognizance': {'n_is_nu': '', 'n_is_sth': ''},
 'cohabitation': {'n_is_nu': '', 'n_is_sth': ''},
 'coherence': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'coincide', 'nn_to_jj': 'coherent', 'nn_to_rb': 'coherently'},
 'coherency': {'n_is_nu': '', 'n_is_sth': ''},
 'cohesion': {'n_is_nu': '', 'n_is_sth': ''},
 'coitus': {'n_is_nu': '', 'n_is_sth': ''},
 'coke': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'colic': {'n_is_nu': '', 'n_is_sth': ''},
 'colitis': {'n_is_nu': '', 'n_is_sth': ''},
 'collapse': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'collapsible', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_against': '', 'v_from': '', 'vb_to_vbz': 'collapses', 'vb_to_vbd': 'collapsed', 'vb_to_vbn': 'collapsed', 'vb_to_jj': 'collapsible', 'vb_to_vbg': 'collapsing', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'collateral': {'n_is_nu': '', 'n_is_sth': ''},
 'collectivism': {'n_is_nu': '', 'n_is_sth': ''},
 'collectivization': {'n_is_nu': '', 'n_is_sth': ''},
 'colonialism': {'n_is_nu': '', 'n_is_sth': ''},
 'colonization': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'colonize', 'nn_to_jj': 'colonial'},
 'coloration': {'n_is_nu': '', 'n_is_sth': ''},
 'coloring': {'n_is_nu': '', 'n_is_sth': ''},
 'colorlessness': {'n_is_nu': '', 'n_is_sth': ''},
 'combining': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'combine', 'vbg_to_vbn': 'combined'},
 'combustibility': {'n_is_nu': '', 'n_is_sth': ''},
 'combustion': {'n_is_nu': '', 'n_is_sth': ''},
 'commemoration': {'n_is_nu': '', 'n_is_sth': ''},
 'commerce': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'commercial', 'nn_to_rb': 'commercially'},
 'commiseration': {'n_is_nu': '', 'n_is_sth': ''},
 'commonality': {'n_is_nu': '', 'n_is_sth': ''},
 'commonness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'common', 'nn_to_rb': 'commonly'},
 'commonweal': {'n_is_nu': '', 'n_is_sth': ''},
 'commonwealth': {'n_is_nu': '', 'n_is_sth': ''},
 'communism': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'comp': {'n_is_nu': '', 'n_is_sth': ''},
 'compactness': {'n_is_nu': '', 'n_is_sth': ''},
 'compare': {'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_to': '', 'vb_to_vbz': 'compares', 'vb_to_vbd': 'compared', 'vb_to_vbn': 'compared', 'vb_to_nn': 'comparison', 'vb_to_jj': 'comparative', 'vb_to_vbg': 'comparing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'compassion': {'n_is_nu': '', 'n_is_sth': ''},
 'compatibility': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'compatible'},
 'competence': {'n_is_nu': '', 'n_is_sth': ''},
 'competitiveness': {'n_is_nu': '', 'n_is_sth': ''},
 'complacency': {'n_is_nu': '', 'n_is_sth': ''},
 'complementarity': {'n_is_nu': '', 'n_is_sth': ''},
 'completeness': {'n_is_nu': '', 'n_is_sth': ''},
 'compliance': {'n_is_nu': '', 'n_is_sth': ''},
 'complicity': {'n_is_nu': '', 'n_is_sth': ''},
 'comportment': {'n_is_nu': '', 'n_is_sth': ''},
 'composure': {'n_is_nu': '', 'n_is_sth': ''},
 'comprehensiveness': {'n_is_nu': '', 'n_is_sth': ''},
 'compunction': {'n_is_nu': '', 'n_is_sth': ''},
 'comradeship': {'n_is_nu': '', 'n_is_sth': ''},
 'comte': {'n_is_nu': '', 'n_is_sb': '0'},
 'concavity': {'n_is_nu': '', 'n_is_sth': ''},
 'concealment': {'n_is_nu': '', 'n_is_sth': ''},
 'conceit': {'n_is_nu': '', 'n_is_sth': ''},
 'conciliation': {'n_is_nu': '', 'n_is_sth': ''},
 'concision': {'n_is_nu': '', 'n_is_sth': ''},
 'concrete': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'concupiscence': {'n_is_nu': '', 'n_is_sth': ''},
 'condiment': {'n_is_nu': '', 'n_is_sth': ''},
 'conditioning': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'condition', 'vbg_to_vbn': 'conditioned'},
 'conduction': {'n_is_nu': '', 'n_is_sth': ''},
 'confectionary': {'n_is_nu': '', 'n_is_sth': ''},
 'confectionery': {'n_is_nu': '', 'n_is_sth': ''},
 'confetti': {'n_is_nu': '', 'n_is_sth': ''},
 'confinement': {'n_is_nu': '', 'n_is_sth': ''},
 'conformance': {'n_is_nu': '', 'n_is_sth': ''},
 'conformity': {'n_is_nu': '', 'n_is_sth': ''},
 'confucian': {'n_is_nu': '', 'n_is_sb': '0', 'cap_word': 'Confucian'},
 'confucianism': {'n_is_nu': '', 'n_is_sth': ''},
 'confucius': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'congee': {'n_is_nu': '', 'n_is_sth': ''},
 'congeniality': {'n_is_nu': '', 'n_is_sth': ''},
 'congestion': {'n_is_nu': '', 'n_is_sth': ''},
 'congo': {'n_is_nu': '', 'n_is_sth': ''},
 'congratulation': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'congratulate', 'n_is_nc': ''},
 'congruence': {'n_is_nu': '', 'n_is_sth': ''},
 'conjunctivitis': {'n_is_nu': '', 'n_is_sth': ''},
 'conk': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'connexion': {'n_is_nu': '', 'n_is_sth': ''},
 'connivance': {'n_is_nu': '', 'n_is_sth': ''},
 'consciousness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'conscious', 'nn_to_rb': 'consciously'},
 'conscription': {'n_is_nu': '', 'n_is_sth': ''},
 'consecration': {'n_is_nu': '', 'n_is_sth': ''},
 'consent': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'consenting', 'v_to_vb': '', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'consents', 'vb_to_vbd': 'consented', 'vb_to_vbn': 'consented', 'vb_to_nn': 'consensus', 'vb_to_jj': 'consenting', 'vb_to_vbg': 'consenting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'conservancy': {'n_is_nu': '', 'n_is_sth': ''},
 'conservatism': {'n_is_nu': '', 'n_is_sth': ''},
 'consignment': {'n_is_nu': '', 'n_is_sth': ''},
 'consolation': {'n_is_nu': '', 'n_is_sth': ''},
 'consomme': {'n_is_nu': '', 'n_is_sth': ''},
 'consonance': {'n_is_nu': '', 'n_is_sth': ''},
 'constancy': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'constant', 'nn_to_rb': 'constantly'},
 'consternation': {'n_is_nu': '', 'n_is_sth': ''},
 'constipation': {'n_is_nu': '', 'n_is_sth': ''},
 'constitutional': {'n_is_nu': '', 'n_is_sth': ''},
 'constitutionalism': {'n_is_nu': '', 'n_is_sth': ''},
 'constructivism': {'n_is_nu': '', 'n_is_sth': ''},
 'consumerism': {'n_is_nu': '', 'n_is_sth': ''},
 'consummation': {'n_is_nu': '', 'n_is_sth': ''},
 'consumption': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'consume', 'nn_to_jj': 'consuming'},
 'containment': {'n_is_nu': '', 'n_is_sth': ''},
 'contamination': {'n_is_nu': '', 'n_is_sth': ''},
 'contemplation': {'n_is_nu': '', 'n_is_sth': ''},
 'contempt': {'n_is_nu': '', 'n_is_sth': ''},
 'content': {'n_is_nu': '', 'n_is_sth': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'contents', 'vb_to_vbd': 'contented', 'vb_to_vbn': 'contented', 'vb_to_vbg': 'contenting', 'vbd_eq_vbn': ''},
 'contentment': {'n_is_nu': '', 'n_is_sth': ''},
 'contiguity': {'n_is_nu': '', 'n_is_sth': ''},
 'continence': {'n_is_nu': '', 'n_is_sth': ''},
 'continuity': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'continue', 'nn_to_jj': 'continuous'},
 'contraband': {'n_is_nu': '', 'n_is_sth': ''},
 'contraception': {'n_is_nu': '', 'n_is_sth': ''},
 'contrariness': {'n_is_nu': '', 'n_is_sth': ''},
 'contrition': {'n_is_nu': '', 'n_is_sth': ''},
 'contumely': {'n_is_nu': '', 'n_is_sth': ''},
 'convalescence': {'n_is_nu': '', 'n_is_sth': ''},
 'convection': {'n_is_nu': '', 'n_is_sth': ''},
 'convenience': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'convenient', 'nn_to_rb': 'conveniently', 'n_is_nc': ''},
 'conventionality': {'n_is_nu': '', 'n_is_sth': ''},
 'convergence': {'n_is_nu': '', 'n_is_sth': ''},
 'convertibility': {'n_is_nu': '', 'n_is_sth': ''},
 'conviviality': {'n_is_nu': '', 'n_is_sth': ''},
 'convocation': {'n_is_nu': '', 'n_is_sth': ''},
 'cookery': {'n_is_nu': '', 'n_is_sth': ''},
 'cooling': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'cool', 'vbg_to_vbn': 'cooled'},
 'coolness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'cool', 'nn_to_jj': 'cool', 'nn_to_rb': 'coolly'},
 'cooperation': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'cooperate', 'nn_to_jj': 'cooperative'},
 'coordination': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'coordinate', 'nn_to_jj': 'coordinate'},
 'copernicus': {'n_is_nu': '', 'n_is_sb': '0'},
 'copulation': {'n_is_nu': '', 'n_is_sth': ''},
 'cordial': {'n_is_nu': '', 'n_is_sth': ''},
 'cordiality': {'n_is_nu': '', 'n_is_sth': ''},
 'cordite': {'n_is_nu': '', 'n_is_sth': ''},
 'corduroy': {'n_is_nu': '', 'n_is_sth': ''},
 'coreopsis': {'n_is_nu': '', 'n_is_sth': ''},
 'coriander': {'n_is_nu': '', 'n_is_sth': ''},
 'corn': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cornmeal': {'n_is_nu': '', 'n_is_sth': ''},
 'corpulence': {'n_is_nu': '', 'n_is_sth': ''},
 'correctness': {'n_is_nu': '', 'n_is_sth': ''},
 'correspondence': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'correspond', 'nn_to_jj': 'corresponding'},
 'corroboration': {'n_is_nu': '', 'n_is_sth': ''},
 'corrosion': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'corroded', 'nn_to_vbn': 'corroded'},
 'corsica': {'n_is_nu': '', 'n_is_sth': ''},
 'cortes': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'cortisone': {'n_is_nu': '', 'n_is_sth': ''},
 'corydalis': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'cosmetology': {'n_is_nu': '', 'n_is_sth': ''},
 'costliness': {'n_is_nu': '', 'n_is_sth': ''},
 'cotton': {'n_is_nu': '', 'n_is_sth': '', 'vb_to_vbz': 'cottons', 'vb_to_vbd': 'cottoned', 'vb_to_vbn': 'cottoned', 'vb_to_vbg': 'cottoning', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nu_typical': ''},
 'cottonseed': {'n_is_nu': '', 'n_is_sth': ''},
 'countenance': {'n_is_nu': '', 'n_is_sth': '', 'v_vbg': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'counterpunch': {'n_is_nu': '', 'n_is_sth': ''},
 'counterrevolution': {'n_is_nu': '', 'n_is_sth': ''},
 'counterweight': {'n_is_nu': '', 'n_is_sth': ''},
 'counting': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'count', 'vbg_to_vbn': 'counted'},
 'countryside': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'courage': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'courageous', 'nu_typical': ''},
 'coursing': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'course', 'vbg_to_vbn': 'coursed'},
 'courtliness': {'n_is_nu': '', 'n_is_sth': ''},
 'courtship': {'n_is_nu': '', 'n_is_sth': ''},
 'coverage': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'cover', 'nn_to_jj': 'covering'},
 'cowardice': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'coward', 'nn_to_rb': 'cowardly'},
 'cowpox': {'n_is_nu': '', 'n_is_sth': ''},
 'craftiness': {'n_is_nu': '', 'n_is_sth': ''},
 'craftsmanship': {'n_is_nu': '', 'n_is_sth': ''},
 'crankiness': {'n_is_nu': '', 'n_is_sth': ''},
 'crap': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'dirtyword': ''},
 'craziness': {'n_is_nu': '', 'n_is_sth': ''},
 'creativeness': {'n_is_nu': '', 'n_is_sth': ''},
 'creativity': {'n_is_nu': '', 'n_is_sth': ''},
 'credence': {'n_is_nu': '', 'n_is_sth': ''},
 'credibility': {'n_is_nu': '', 'n_is_sth': ''},
 'credulity': {'n_is_nu': '', 'n_is_sth': ''},
 'cremation': {'n_is_nu': '', 'n_is_sth': ''},
 'crescendo': {'n_is_nu': '', 'n_is_sth': ''},
 'cress': {'n_is_nu': '', 'n_is_sth': ''},
 'cretinism': {'n_is_nu': '', 'n_is_sth': ''},
 'crimea': {'n_is_nu': '', 'n_is_sth': ''},
 'criminology': {'n_is_nu': '', 'n_is_sth': ''},
 'crimson': {'n_is_nu': '', 'n_is_sth': ''},
 'criticality': {'n_is_nu': '', 'n_is_sth': ''},
 'crochet': {'n_is_nu': '', 'n_is_sth': ''},
 'crockery': {'n_is_nu': '', 'n_is_sth': ''},
 'cronyism': {'n_is_nu': '', 'n_is_sth': ''},
 'cross-pollination': {'n_is_nu': '', 'n_is_sth': ''},
 'crossfire': {'n_is_nu': '', 'n_is_sth': ''},
 'crosstalk': {'n_is_nu': '', 'n_is_sth': ''},
 'croup': {'n_is_nu': '', 'n_is_sth': ''},
 'crude': {'n_is_nu': '', 'n_is_sth': '', 'jj_to_jjr': 'cruder', 'jj_to_jjs': 'crudest'},
 'crudeness': {'n_is_nu': '', 'n_is_sth': ''},
 'cryogenics': {'n_is_nu': '', 'n_is_sth': ''},
 'cryptology': {'n_is_nu': '', 'n_is_sth': ''},
 'cubism': {'n_is_nu': '', 'n_is_sth': ''},
 'cuisine': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'culmination': {'n_is_nu': '', 'n_is_sth': ''},
 'cultivation': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'cultivate', 'nn_to_jj': 'cultivated'},
 'cumberland': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'cumin': {'n_is_nu': '', 'n_is_sth': ''},
 'cumulonimbus': {'n_is_nu': '', 'n_is_sth': ''},
 'cuneiform': {'n_is_nu': '', 'n_is_sth': ''},
 'cunning': {'n_is_nu': '', 'n_is_sth': ''},
 'cupid': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'cupidity': {'n_is_nu': '', 'n_is_sth': ''},
 'curling': {'n_is_nu': '', 'n_is_sth': ''},
 'curvature': {'n_is_nu': '', 'n_is_sth': ''},
 'cussedness': {'n_is_nu': '', 'n_is_sth': ''},
 'custody': {'n_is_nu': '', 'n_is_sth': ''},
 'cutlery': {'n_is_nu': '', 'n_is_sth': ''},
 'cyan': {'n_is_nu': '', 'n_is_sth': ''},
 'cybernaut': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'cybernetics': {'n_is_nu': '', 'n_is_sth': ''},
 'cygnus': {'n_is_nu': '', 'n_is_sth': ''},
 'cynicism': {'n_is_nu': '', 'n_is_sth': ''},
 'cynosure': {'n_is_nu': '', 'n_is_sth': ''},
 'cystitis': {'n_is_nu': '', 'n_is_sth': ''},
 'cytoplasm': {'n_is_nu': '', 'n_is_sth': ''},
 'dacron': {'n_is_nu': '', 'n_is_sth': ''},
 'dahomey': {'n_is_nu': '', 'n_is_sth': ''},
 'daiquiri': {'n_is_nu': '', 'n_is_sth': ''},
 'dalian': {'n_is_nu': '', 'n_is_sth': ''},
 'dallas': {'n_is_nu': '', 'n_is_sth': ''},
 'damage': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'damaging', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'damages', 'vb_to_vbd': 'damaged', 'vb_to_vbn': 'damaged', 'vb_to_jj': 'damaging', 'vb_to_vbg': 'damaging', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'damask': {'n_is_nu': '', 'n_is_sth': ''},
 'damnation': {'n_is_nu': '', 'n_is_sth': ''},
 'dampener': {'n_is_nu': '', 'n_is_sth': ''},
 'dampness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'damp', 'nn_to_jj': 'damp'},
 'dander': {'n_is_nu': '', 'n_is_sth': ''},
 'dandruff': {'n_is_nu': '', 'n_is_sth': ''},
 'dandyism': {'n_is_nu': '', 'n_is_sth': ''},
 'danmark': {'n_is_nu': '', 'n_is_sth': ''},
 'danube': {'n_is_nu': '', 'n_is_sth': ''},
 'daphne': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'darkness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'dark', 'nn_to_rb': 'darkly', 'nu_typical': ''},
 'darwinism': {'n_is_nu': '', 'n_is_sth': ''},
 'datura': {'n_is_nu': '', 'n_is_sth': ''},
 'david': {'n_is_nu': '', 'n_is_sb': '0'},
 'davis': {'n_is_nu': '', 'n_is_sb': '0'},
 'daybreak': {'n_is_nu': '', 'n_is_sth': ''},
 'daylight': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'daytime': {'n_is_nu': '', 'n_is_sth': ''},
 'dazzle': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'db': {'n_is_nu': '', 'n_is_sth': ''},
 'dc': {'n_is_nu': '', 'n_is_sth': ''},
 'ddt': {'n_is_nu': '', 'n_is_sth': ''},
 'deactivation': {'n_is_nu': '', 'n_is_sth': ''},
 'deadliness': {'n_is_nu': '', 'n_is_sth': ''},
 'deadlock': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'deadness': {'n_is_nu': '', 'n_is_sth': ''},
 'deafness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'deaf', 'nn_to_rb': 'deafly'},
 'deal': {'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_with': '', 'vb_to_vbz': 'deals', 'vb_to_vbd': 'dealt', 'vb_to_vbn': 'dealt', 'vb_to_vbg': 'dealing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'n_is_nc': ''},
 'debarment': {'n_is_nu': '', 'n_is_sth': ''},
 'debauchery': {'n_is_nu': '', 'n_is_sth': ''},
 'dec': {'n_is_nu': '', 'n_is_sth': ''},
 'decadence': {'n_is_nu': '', 'n_is_sth': ''},
 'decay': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'decayed', 'vb_to_jj': 'decayed', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'deceleration': {'n_is_nu': '', 'n_is_sth': ''},
 'decency': {'n_is_nu': '', 'n_is_sth': ''},
 'decentralization': {'n_is_nu': '', 'n_is_sth': ''},
 'deception': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'deceive', 'nn_to_jj': 'deceived'},
 'decipherment': {'n_is_nu': '', 'n_is_sth': ''},
 'decisiveness': {'n_is_nu': '', 'n_is_sth': ''},
 'decolletage': {'n_is_nu': '', 'n_is_sth': ''},
 'decomposition': {'n_is_nu': '', 'n_is_sth': ''},
 'decompression': {'n_is_nu': '', 'n_is_sth': ''},
 'decontamination': {'n_is_nu': '', 'n_is_sth': ''},
 'decorum': {'n_is_nu': '', 'n_is_sth': ''},
 'decoupage': {'n_is_nu': '', 'n_is_sth': ''},
 'decrepitude': {'n_is_nu': '', 'n_is_sth': ''},
 'decryption': {'n_is_nu': '', 'n_is_sth': ''},
 'defacement': {'n_is_nu': '', 'n_is_sth': ''},
 'defamation': {'n_is_nu': '', 'n_is_sth': ''},
 'defecation': {'n_is_nu': '', 'n_is_sth': ''},
 'defence': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'defend', 'nn_to_jj': 'defending', 'nn_eq_nns': ''},
 'defensiveness': {'n_is_nu': '', 'n_is_sth': ''},
 'deference': {'n_is_nu': '', 'n_is_sth': ''},
 'deferment': {'n_is_nu': '', 'n_is_sth': ''},
 'defiance': {'n_is_nu': '', 'n_is_sth': ''},
 'defile': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'deflection': {'n_is_nu': '', 'n_is_sth': ''},
 'defoliation': {'n_is_nu': '', 'n_is_sth': ''},
 'deformity': {'n_is_nu': '', 'n_is_sth': ''},
 'degeneracy': {'n_is_nu': '', 'n_is_sth': ''},
 'degeneration': {'n_is_nu': '', 'n_is_sth': ''},
 'dehydration': {'n_is_nu': '', 'n_is_sth': ''},
 'deification': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'deity': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'dejection': {'n_is_nu': '', 'n_is_sth': ''},
 'delectation': {'n_is_nu': '', 'n_is_sth': ''},
 'delhi': {'n_is_nu': '', 'n_is_sth': ''},
 'delight': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'delightful', 'vb_to_jj': 'delightful', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'delineation': {'n_is_nu': '', 'n_is_sth': ''},
 'delinquency': {'n_is_nu': '', 'n_is_sth': ''},
 'delirium': {'n_is_nu': '', 'n_is_sth': ''},
 'deliverance': {'n_is_nu': '', 'n_is_sth': ''},
 'deluge': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'demarcation': {'n_is_nu': '', 'n_is_sth': ''},
 'demeanor': {'n_is_nu': '', 'n_is_sth': ''},
 'dementia': {'n_is_nu': '', 'n_is_sth': ''},
 'demimonde': {'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'demise': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'demobilization': {'n_is_nu': '', 'n_is_sth': ''},
 'demography': {'n_is_nu': '', 'n_is_sth': ''},
 'demur': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'dendrobium': {'n_is_nu': '', 'n_is_sth': ''},
 'denier': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'denigration': {'n_is_nu': '', 'n_is_sth': ''},
 'denim': {'n_is_nu': '', 'n_is_sth': ''},
 'denseness': {'n_is_nu': '', 'n_is_sth': ''},
 'density': {'n_is_nu': '', 'n_is_sth': ''},
 'dentifrice': {'n_is_nu': '', 'n_is_sth': ''},
 'dentistry': {'n_is_nu': '', 'n_is_sth': ''},
 'deodorant': {'n_is_nu': '', 'n_is_sth': ''},
 'dependence': {'n_is_nu': '', 'n_is_sth': ''},
 'dependency': {'n_is_nu': '', 'n_is_sth': ''},
 'depletion': {'n_is_nu': '', 'n_is_sth': ''},
 'deportment': {'n_is_nu': '', 'n_is_sth': ''},
 'depravation': {'n_is_nu': '', 'n_is_sth': ''},
 'deprecation': {'n_is_nu': '', 'n_is_sth': ''},
 'depreciation': {'n_is_nu': '', 'n_is_sth': ''},
 'derailment': {'n_is_nu': '', 'n_is_sth': ''},
 'dereliction': {'n_is_nu': '', 'n_is_sth': ''},
 'derision': {'n_is_nu': '', 'n_is_sth': ''},
 'dermatitis': {'n_is_nu': '', 'n_is_sth': ''},
 'dermatology': {'n_is_nu': '', 'n_is_sth': ''},
 'dermis': {'n_is_nu': '', 'n_is_sth': ''},
 'derogation': {'n_is_nu': '', 'n_is_sth': ''},
 'desalination': {'n_is_nu': '', 'n_is_sth': ''},
 'descartes': {'n_is_nu': '', 'n_is_sb': '0'},
 'desensitization': {'n_is_nu': '', 'n_is_sth': ''},
 'desertification': {'n_is_nu': '', 'n_is_sth': ''},
 'desertion': {'n_is_nu': '', 'n_is_sth': ''},
 'desiccation': {'n_is_nu': '', 'n_is_sth': ''},
 'desirability': {'n_is_nu': '', 'n_is_sth': ''},
 'desolation': {'n_is_nu': '', 'n_is_sth': ''},
 'despair': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'despairing', 'vb_to_jj': 'despairing', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'desperation': {'n_is_nu': '', 'n_is_sth': ''},
 'despoliation': {'n_is_nu': '', 'n_is_sth': ''},
 'despondency': {'n_is_nu': '', 'n_is_sth': ''},
 'despotism': {'n_is_nu': '', 'n_is_sth': ''},
 'destabilization': {'n_is_nu': '', 'n_is_sth': ''},
 'destitution': {'n_is_nu': '', 'n_is_sth': ''},
 'desuetude': {'n_is_nu': '', 'n_is_sth': ''},
 'detection': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'detect', 'nn_to_jj': 'detectable'},
 'detente': {'n_is_nu': '', 'n_is_sth': ''},
 'deterioration': {'n_is_nu': '', 'n_is_sth': ''},
 'determinism': {'n_is_nu': '', 'n_is_sth': ''},
 'deterrence': {'n_is_nu': '', 'n_is_sth': ''},
 'detestation': {'n_is_nu': '', 'n_is_sth': ''},
 'detonation': {'n_is_nu': '', 'n_is_sth': ''},
 'detoxification': {'n_is_nu': '', 'n_is_sth': ''},
 'detraction': {'n_is_nu': '', 'n_is_sth': ''},
 'detriment': {'n_is_nu': '', 'n_is_sth': ''},
 'detritus': {'n_is_nu': '', 'n_is_sth': ''},
 'deuterium': {'n_is_nu': '', 'n_is_sth': ''},
 'deutschland': {'n_is_nu': '', 'n_is_sth': ''},
 'devaluation': {'n_is_nu': '', 'n_is_sth': ''},
 'devastation': {'n_is_nu': '', 'n_is_sth': ''},
 'developing': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'develop', 'vbg_to_vbn': 'developed'},
 'devilment': {'n_is_nu': '', 'n_is_sth': ''},
 'devolution': {'n_is_nu': '', 'n_is_sth': ''},
 'devotion': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'devote', 'nn_to_jj': 'devoted'},
 'dew': {'n_is_nu': '', 'n_is_sth': ''},
 'dewey': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'dexterity': {'n_is_nu': '', 'n_is_sth': ''},
 'dextrose': {'n_is_nu': '', 'n_is_sth': ''},
 'diabetes': {'n_is_nu': '', 'n_is_sth': ''},
 'dialectics': {'n_is_nu': '', 'n_is_sth': ''},
 'dialysis': {'n_is_nu': '', 'n_is_sth': ''},
 'diarrhea': {'n_is_nu': '', 'n_is_sth': ''},
 'dicky': {'n_is_nu': '', 'n_is_sth': '', 'jj_to_jjr': 'dickier', 'jj_to_jjs': 'dickiest'},
 'diction': {'n_is_nu': '', 'n_is_sth': ''},
 'dietetics': {'n_is_nu': '', 'n_is_sth': ''},
 'differentiation': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'differentiate', 'nn_to_jj': 'differentiated'},
 'diffidence': {'n_is_nu': '', 'n_is_sth': ''},
 'diffraction': {'n_is_nu': '', 'n_is_sth': ''},
 'diffusion': {'n_is_nu': '', 'n_is_sth': ''},
 'digging': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'dig', 'vbg_to_vbn': 'digged'},
 'dignity': {'n_is_nu': '', 'n_is_sth': ''},
 'dilapidation': {'n_is_nu': '', 'n_is_sth': ''},
 'dilation': {'n_is_nu': '', 'n_is_sth': ''},
 'diligence': {'n_is_nu': '', 'n_is_sth': ''},
 'dimity': {'n_is_nu': '', 'n_is_sth': ''},
 'dimness': {'n_is_nu': '', 'n_is_sth': ''},
 'din': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'dinar': {'n_is_nu': '', 'n_is_sth': ''},
 'ding-dong': {'n_is_nu': '', 'n_is_sth': ''},
 'dinginess': {'n_is_nu': '', 'n_is_sth': ''},
 'dinnerware': {'n_is_nu': '', 'n_is_sth': ''},
 'diphtheria': {'n_is_nu': '', 'n_is_sth': ''},
 'diplomacy': {'n_is_nu': '', 'n_is_sth': ''},
 'directness': {'n_is_nu': '', 'n_is_sth': ''},
 'dirt': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'dirty', 'vb_to_jj': 'dirty', 'nu_typical': ''},
 'dirtiness': {'n_is_nu': '', 'n_is_sth': ''},
 'disaffection': {'n_is_nu': '', 'n_is_sth': ''},
 'disarmament': {'n_is_nu': '', 'n_is_sth': ''},
 'disarray': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'disassembly': {'n_is_nu': '', 'n_is_sth': ''},
 'disassociation': {'n_is_nu': '', 'n_is_sth': ''},
 'disbandment': {'n_is_nu': '', 'n_is_sth': ''},
 'disbelief': {'n_is_nu': '', 'n_is_sth': ''},
 'discernment': {'n_is_nu': '', 'n_is_sth': ''},
 'discombobulation': {'n_is_nu': '', 'n_is_sth': ''},
 'discomfiture': {'n_is_nu': '', 'n_is_sth': ''},
 'discomfort': {'n_is_nu': '', 'n_is_sth': ''},
 'discontentment': {'n_is_nu': '', 'n_is_sth': ''},
 'discontinuance': {'n_is_nu': '', 'n_is_sth': ''},
 'discontinuation': {'n_is_nu': '', 'n_is_sth': ''},
 'discordance': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'discordant'},
 'discredit': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'discrepancy': {'n_is_nu': '', 'n_is_sth': ''},
 'discretion': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'discrete', 'nn_to_rb': 'discretely'},
 'disdain': {'n_is_nu': '', 'n_is_sth': '', 'v_vbg': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vbg_non': ''},
 'disengagement': {'n_is_nu': '', 'n_is_sth': ''},
 'disgorgement': {'n_is_nu': '', 'n_is_sth': ''},
 'disgrace': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'disgust': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'disgusting', 'vb_to_jj': 'disgusting', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'dishabille': {'n_is_nu': '', 'n_is_sth': ''},
 'dishonesty': {'n_is_nu': '', 'n_is_sth': ''},
 'dishonor': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'disillusion': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'disillusionment': {'n_is_nu': '', 'n_is_sth': ''},
 'disinclination': {'n_is_nu': '', 'n_is_sth': ''},
 'disinfection': {'n_is_nu': '', 'n_is_sth': ''},
 'disintegration': {'n_is_nu': '', 'n_is_sth': ''},
 'disinterest': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'disinterment': {'n_is_nu': '', 'n_is_sth': ''},
 'disinvestment': {'n_is_nu': '', 'n_is_sth': ''},
 'disjunction': {'n_is_nu': '', 'n_is_sth': ''},
 'disloyalty': {'n_is_nu': '', 'n_is_sth': ''},
 'dismantlement': {'n_is_nu': '', 'n_is_sth': ''},
 'dismay': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'dismemberment': {'n_is_nu': '', 'n_is_sth': ''},
 'dismissal': {'n_is_nu': '', 'n_is_sth': ''},
 'disney': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'disobedience': {'n_is_nu': '', 'n_is_sth': ''},
 'disorganization': {'n_is_nu': '', 'n_is_sth': ''},
 'dispassion': {'n_is_nu': '', 'n_is_sth': ''},
 'dispersion': {'n_is_nu': '', 'n_is_sth': ''},
 'displacement': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'displace', 'nn_to_jj': 'displaced'},
 'displeasure': {'n_is_nu': '', 'n_is_sth': ''},
 'disposal': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'dispose', 'nn_to_jj': 'disposable'},
 'dispossession': {'n_is_nu': '', 'n_is_sth': ''},
 'disquiet': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'disquietude': {'n_is_nu': '', 'n_is_sth': ''},
 'disregard': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'disrepair': {'n_is_nu': '', 'n_is_sth': ''},
 'disrepute': {'n_is_nu': '', 'n_is_sth': ''},
 'disrespect': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'dissatisfaction': {'n_is_nu': '', 'n_is_sth': ''},
 'dissemination': {'n_is_nu': '', 'n_is_sth': ''},
 'dissent': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'dissidence': {'n_is_nu': '', 'n_is_sth': ''},
 'dissimulation': {'n_is_nu': '', 'n_is_sth': ''},
 'dissipation': {'n_is_nu': '', 'n_is_sth': ''},
 'dissociation': {'n_is_nu': '', 'n_is_sth': ''},
 'distaste': {'n_is_nu': '', 'n_is_sth': ''},
 'distemper': {'n_is_nu': '', 'n_is_sth': ''},
 'distillation': {'n_is_nu': '', 'n_is_sth': ''},
 'distinctiveness': {'n_is_nu': '', 'n_is_sth': ''},
 'distinctness': {'n_is_nu': '', 'n_is_sth': ''},
 'distress': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'distrust': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'disunion': {'n_is_nu': '', 'n_is_sth': ''},
 'disunity': {'n_is_nu': '', 'n_is_sth': ''},
 'disuse': {'n_is_nu': '', 'n_is_sth': ''},
 'diversification': {'n_is_nu': '', 'n_is_sth': ''},
 'divination': {'n_is_nu': '', 'n_is_sth': ''},
 'divinity': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'dizziness': {'n_is_nu': '', 'n_is_sth': ''},
 'docility': {'n_is_nu': '', 'n_is_sth': ''},
 'dockage': {'n_is_nu': '', 'n_is_sth': ''},
 'dod': {'n_is_nu': '', 'n_is_sth': ''},
 'dodder': {'n_is_nu': '', 'n_is_sth': ''},
 'doggedness': {'n_is_nu': '', 'n_is_sth': ''},
 'doggerel': {'n_is_nu': '', 'n_is_sth': ''},
 'dogmatism': {'n_is_nu': '', 'n_is_sth': ''},
 'dole': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'dolomite': {'n_is_nu': '', 'n_is_sth': ''},
 'dolor': {'n_is_nu': '', 'n_is_sth': ''},
 'domestication': {'n_is_nu': '', 'n_is_sth': ''},
 'domesticity': {'n_is_nu': '', 'n_is_sth': ''},
 'dominance': {'n_is_nu': '', 'n_is_sth': ''},
 'domination': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'dominate', 'nn_to_jj': 'dominant'},
 'dominus': {'n_is_nu': '', 'n_is_sb': '0'},
 'doom': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'doomsday': {'n_is_nu': '', 'n_is_sth': ''},
 'doppler': {'n_is_nu': '', 'n_is_sb': '0', 'cap_word': 'Doppler'},
 'dormancy': {'n_is_nu': '', 'n_is_sth': ''},
 'dotage': {'n_is_nu': '', 'n_is_sth': ''},
 'double-dealing': {'n_is_nu': '', 'n_is_sth': ''},
 'douglas': {'n_is_nu': '', 'n_is_sb': '0'},
 'downhill': {'n_is_nu': '', 'n_is_sth': ''},
 'doxycycline': {'n_is_nu': '', 'n_is_sth': ''},
 'drabness': {'n_is_nu': '', 'n_is_sth': ''},
 'draco': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'drafting': {'n_is_nu': '', 'n_is_sth': ''},
 'drainage': {'n_is_nu': '', 'n_is_sth': ''},
 'dramamine': {'n_is_nu': '', 'n_is_sth': ''},
 'drapery': {'n_is_nu': '', 'n_is_sth': ''},
 'draughts': {'n_is_nu': '', 'n_is_sth': ''},
 'dread': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'v_vbg': '', 'v_to_vb': '', 'v_n': ''},
 'dresden': {'n_is_nu': '', 'n_is_sth': ''},
 'driftwood': {'n_is_nu': '', 'n_is_sth': ''},
 'drilling': {'n_is_nu': '', 'n_is_sth': ''},
 'dripping': {'n_is_nu': '', 'n_is_sth': ''},
 'drool': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'droop': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'dropsy': {'n_is_nu': '', 'n_is_sth': ''},
 'dross': {'n_is_nu': '', 'n_is_sth': ''},
 'drowsiness': {'n_is_nu': '', 'n_is_sth': ''},
 'drudgery': {'n_is_nu': '', 'n_is_sth': ''},
 'drunkenness': {'n_is_nu': '', 'n_is_sth': ''},
 'druthers': {'n_is_nu': '', 'n_is_sth': ''},
 'dryness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'dry', 'nn_to_jj': 'dry', 'nn_to_rb': 'drily'},
 'dualism': {'n_is_nu': '', 'n_is_sth': ''},
 'duality': {'n_is_nu': '', 'n_is_sth': ''},
 'dub': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'dubbing': {'n_is_nu': '', 'n_is_sth': ''},
 'duckweed': {'n_is_nu': '', 'n_is_sth': ''},
 'duct': {'n_is_nu': '', 'n_is_sth': ''},
 'dudgeon': {'n_is_nu': '', 'n_is_sth': ''},
 'dullness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'dull', 'nn_to_jj': 'dull', 'nn_to_rb': 'dully'},
 'dumas': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'dumbness': {'n_is_nu': '', 'n_is_sth': ''},
 'dumping': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'dump', 'vbg_to_vbn': 'dumpped'},
 'dung': {'n_is_nu': '', 'n_is_sth': ''},
 'dunkirk': {'n_is_nu': '', 'n_is_sth': ''},
 'duplication': {'n_is_nu': '', 'n_is_sth': ''},
 'duplicity': {'n_is_nu': '', 'n_is_sth': ''},
 'duration': {'n_is_nu': '', 'n_is_sth': ''},
 'duress': {'n_is_nu': '', 'n_is_sth': ''},
 'dust': {'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'dusts', 'vb_to_vbd': 'dusted', 'vb_to_vbn': 'dusted', 'vb_to_vbg': 'dusting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nu_typical': ''},
 'dwarfism': {'n_is_nu': '', 'n_is_sth': ''},
 'dynamism': {'n_is_nu': '', 'n_is_sth': ''},
 'dynamite': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'dysentery': {'n_is_nu': '', 'n_is_sth': ''},
 'dysfunction': {'n_is_nu': '', 'n_is_sth': ''},
 'dyspepsia': {'n_is_nu': '', 'n_is_sth': ''},
 'dysphoria': {'n_is_nu': '', 'n_is_sth': ''},
 'eagerness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'eager', 'nn_to_rb': 'eagerly'},
 'earnestness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'earwax': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ease': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'eases', 'vb_to_vbd': 'eased', 'vb_to_vbn': 'eased', 'vb_to_vbg': 'easing', 'vbd_eq_vbn': ''},
 'easiness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'easy', 'nn_to_rb': 'easy'},
 'easing': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbg_to_vb': 'ease', 'vbg_to_vbn': 'eased'},
 'east': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'easter': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ebony': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ebullience': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'eccentricity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ecology': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nu_typical': ''},
 'economics': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ectoderm': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'eczema': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'edginess': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'edification': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'edison': {'n_is_nu': '', 'n_is_sb': '0', 'art_an': '', 'cap_word': 'Edison'},
 'education': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'educate', 'nn_to_jj': 'educational', 'n_usu_singular': ''},
 'eeriness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'effectiveness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'effeminacy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'effervescence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'efficacy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'efflorescence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'effrontery': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'egalitarianism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'egocentrism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'egoism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'egotism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'elaborateness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'elan': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'elasticity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'elastic', 'nn_to_rb': 'elastically'},
 'elation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'electricity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'electric', 'nn_to_rb': 'electrically', 'nu_typical': ''},
 'electrification': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'electrocution': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'electrolysis': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'electromagnetism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'electrophoresis': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'elegance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'elephantiasis': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'eligibility': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'elimination': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'eliminate', 'nn_to_jj': 'eliminating'},
 'elizabeth': {'n_is_nu': '', 'n_is_sb': '0', 'art_an': ''},
 'eloquence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'elysium': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'emaciation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'emancipation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'emasculation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'embezzlement': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'embroidery': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'embryology': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'emergence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'emerge', 'nn_to_jj': 'emergent'},
 'emery': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'emotionalism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'emotionality': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'empathy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'emphysema': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'empiricism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'empirical', 'nn_to_rb': 'empirically'},
 'employ': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'employed', 'v_n': '', 'v_n_to_vb': '', 'v_n_n': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'emploies', 'vb_to_vbd': 'employed', 'vb_to_vbn': 'employed', 'vb_to_nn': 'employment', 'vb_to_jj': 'employed', 'vb_to_vbg': 'employing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'employment': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'employ', 'nn_to_jj': 'employed'},
 'emptiness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'empyrean': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'emulation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'enamel': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'encasement': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'encephalitis': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'encirclement': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'encouragement': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'encourage', 'nn_to_jj': 'encouraging'},
 'encryption': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'end-all': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'endangerment': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'endeavor': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_to_vb': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'endurance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'enforcement': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'enforce', 'nn_to_jj': 'enforced'},
 'engels': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'engineering': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbg_to_vb': 'engineer', 'vbg_to_vbn': 'engineered'},
 'england': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'enlightenment': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ennui': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'enormity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'enormous', 'nn_to_rb': 'enormously'},
 'enormousness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'enrichment': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'enslavement': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'enteritis': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'entomology': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'entrapment': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'entree': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'entropy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'enunciation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'enuresis': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'envy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'envious', 'v_vbg': '', 'v_n': '', 'nsubjpass': '', 'v_for': '', 'vb_to_jj': 'envious', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'vt_typical': ''},
 'enzyme': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ephedrine': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ephemeral': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'epilepsy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'epinephrine': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'epiphany': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'epistemology': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'epoxy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'equality': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'equal', 'nn_to_jj': 'equal', 'nu_typical': ''},
 'equalization': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'equanimity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'equator': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'equilibrium': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'equipment': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'equip', 'nu_typical': ''},
 'equipoise': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'equivalence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'equivalent', 'nn_to_rb': 'equivalently'},
 'eradication': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'erasure': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'erbium': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ergometer': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'eros': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'erosion': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'erode', 'nn_to_jj': 'eroding'},
 'eroticism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'erudition': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'escapism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'escrow': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'esoterica': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'esperanto': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'espionage': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'espousal': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'esprit': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'esteem': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'esthetics': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'estrogen': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'estrus': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'eternity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ethane': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ethanol': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ether': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ethics': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ethnology': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ethylene': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'etiquette': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'etymology': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'eucharist': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'eugenics': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'euphrates': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'eurasia': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'europeanization': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'euthanasia': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'evaluation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'evaluate', 'nn_to_jj': 'evaluative', 'n_is_nc': ''},
 'evanescence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'evaporation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'evasiveness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'evenness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'evensong': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'everlasting': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'evilness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'evocation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exacerbation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exactitude': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exactness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exaltation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'examen': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exasperation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'excellence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'excel', 'nn_to_jj': 'excellent', 'nn_to_rb': 'excellently'},
 'excelsior': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'excessiveness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'excitability': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'excitation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exclusion': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'exclude', 'nn_to_jj': 'exclusive'},
 'exclusiveness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'excrement': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'excreta': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exculpation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exfoliation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exhaustion': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exhilaration': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exodus': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exoneration': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exoticism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'expectancy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'expedience': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'experimentalism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'experimentation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'expertise': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'expiation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'expiration': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'expiry': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exploitation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'exploit', 'nn_to_jj': 'exploitive'},
 'extensiveness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'extermination': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'extinction': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'extirpation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'extravagance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'extrication': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'extroversion': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exuberance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'exultation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'eyesight': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nu_typical': ''},
 'eyewash': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'eyre': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ezekiel': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'facelift': {'n_is_nu': '', 'n_is_sth': ''},
 'facsimile': {'n_is_nu': '', 'n_is_sth': ''},
 'factuality': {'n_is_nu': '', 'n_is_sth': ''},
 'fading': {'n_is_nu': '', 'n_is_sth': ''},
 'faintness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'faint', 'nn_to_jj': 'faint', 'nn_to_rb': 'faintly'},
 'fairness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'fair', 'nn_to_jj': 'fair', 'nn_to_rb': 'fair', 'nu_typical': ''},
 'faithfulness': {'n_is_nu': '', 'n_is_sth': ''},
 'fallibility': {'n_is_nu': '', 'n_is_sth': ''},
 'fallout': {'n_is_nu': '', 'n_is_sth': ''},
 'fallow': {'n_is_nu': '', 'n_is_sth': ''},
 'falseness': {'n_is_nu': '', 'n_is_sth': ''},
 'familiarity': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'familiar', 'nn_to_rb': 'familiarly'},
 'familiarization': {'n_is_nu': '', 'n_is_sth': ''},
 'fanaticism': {'n_is_nu': '', 'n_is_sth': ''},
 'farina': {'n_is_nu': '', 'n_is_sth': ''},
 'farming': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'farm', 'vbg_to_vbn': 'farmed'},
 'fasting': {'n_is_nu': '', 'n_is_sth': ''},
 'fatalism': {'n_is_nu': '', 'n_is_sth': ''},
 'fatigue': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'favoritism': {'n_is_nu': '', 'n_is_sth': ''},
 'favourite': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'fealty': {'n_is_nu': '', 'n_is_sth': ''},
 'fear': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'fearful', 'v_compcl': '', 'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'fears', 'vb_to_vbd': 'feared', 'vb_to_vbn': 'feared', 'vb_to_jj': 'fearful', 'v_vbg': '', 'vb_to_vbg': 'fearing', 'vbd_eq_vbn': ''},
 'fearfulness': {'n_is_nu': '', 'n_is_sth': ''},
 'fearlessness': {'n_is_nu': '', 'n_is_sth': ''},
 'feasibility': {'n_is_nu': '', 'n_is_sth': ''},
 'feb': {'n_is_nu': '', 'n_is_sth': ''},
 'fecundity': {'n_is_nu': '', 'n_is_sth': ''},
 'feebleness': {'n_is_nu': '', 'n_is_sth': ''},
 'feeding': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'feed', 'vbg_to_vbn': 'fed'},
 'feedstock': {'n_is_nu': '', 'n_is_sth': ''},
 'feldspar': {'n_is_nu': '', 'n_is_sth': ''},
 'fell': {'n_is_nu': '', 'n_is_sth': '', 'confu_pair': 'feel', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'fellowship': {'n_is_nu': '', 'n_is_sth': ''},
 'felt': {'n_is_nu': '', 'n_is_sth': '', 'vbd_to_vb': 'feel', 'vbn_to_vb': 'feel', 'vbn_to_vbg': 'feeling', 'vbd_eq_vbn': ''},
 'feminine': {'n_is_nu': '', 'n_is_sth': ''},
 'femininity': {'n_is_nu': '', 'n_is_sth': ''},
 'feminism': {'n_is_nu': '', 'n_is_sth': ''},
 'fennel': {'n_is_nu': '', 'n_is_sth': ''},
 'fermentation': {'n_is_nu': '', 'n_is_sth': ''},
 'ferrule': {'n_is_nu': '', 'n_is_sth': ''},
 'fertility': {'n_is_nu': '', 'n_is_sth': ''},
 'fertilization': {'n_is_nu': '', 'n_is_sth': ''},
 'fervency': {'n_is_nu': '', 'n_is_sth': ''},
 'fervor': {'n_is_nu': '', 'n_is_sth': ''},
 'fetishism': {'n_is_nu': '', 'n_is_sth': ''},
 'feudalism': {'n_is_nu': '', 'n_is_sth': ''},
 'fiberboard': {'n_is_nu': '', 'n_is_sth': ''},
 'fibrin': {'n_is_nu': '', 'n_is_sth': ''},
 'fibrinogen': {'n_is_nu': '', 'n_is_sth': ''},
 'fickleness': {'n_is_nu': '', 'n_is_sth': ''},
 'fidelity': {'n_is_nu': '', 'n_is_sth': ''},
 'fieldwork': {'n_is_nu': '', 'n_is_sth': ''},
 'fierceness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'fierce', 'nn_to_rb': 'fiercely'},
 'filariasis': {'n_is_nu': '', 'n_is_sth': ''},
 'filet': {'n_is_nu': '', 'n_is_sth': ''},
 'filmdom': {'n_is_nu': '', 'n_is_sth': ''},
 'filth': {'n_is_nu': '', 'n_is_sth': ''},
 'filtration': {'n_is_nu': '', 'n_is_sth': ''},
 'finality': {'n_is_nu': '', 'n_is_sth': ''},
 'finance': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'financial', 'vb_to_jj': 'financial'},
 'financing': {'n_is_nu': '', 'n_is_sth': ''},
 'fineness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'fine', 'nn_to_jj': 'fine', 'nn_to_rb': 'finely'},
 'finery': {'n_is_nu': '', 'n_is_sth': ''},
 'finesse': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'finger-pointing': {'n_is_nu': '', 'n_is_sth': ''},
 'fingering': {'n_is_nu': '', 'n_is_sth': ''},
 'fingerling': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'finis': {'n_is_nu': '', 'n_is_sth': ''},
 'firelight': {'n_is_nu': '', 'n_is_sth': ''},
 'firepower': {'n_is_nu': '', 'n_is_sth': ''},
 'firewater': {'n_is_nu': '', 'n_is_sth': ''},
 'firewood': {'n_is_nu': '', 'n_is_sth': ''},
 'firing': {'n_is_nu': '', 'n_is_sth': ''},
 'firmness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'firm', 'nn_to_jj': 'firm', 'nn_to_rb': 'firm'},
 'firmware': {'n_is_nu': '', 'n_is_sth': ''},
 'fishing': {'n_is_nu': '', 'n_is_sth': ''},
 'fishnet': {'n_is_nu': '', 'n_is_sth': ''},
 'fission': {'n_is_nu': '', 'n_is_sth': ''},
 'fitness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'fit', 'nn_to_jj': 'fit'},
 'fixity': {'n_is_nu': '', 'n_is_sth': ''},
 'fizz': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'flab': {'n_is_nu': '', 'n_is_sth': ''},
 'flagellation': {'n_is_nu': '', 'n_is_sth': ''},
 'flair': {'n_is_nu': '', 'n_is_sth': ''},
 'flamboyance': {'n_is_nu': '', 'n_is_sth': ''},
 'flammability': {'n_is_nu': '', 'n_is_sth': ''},
 'flare-up': {'n_is_nc': '', 'n_is_sth': ''},
 'flashing': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'flash', 'vbg_to_vbn': 'flashed'},
 'flashlight': {'n_is_nu': '', 'n_is_sth': ''},
 'flatness': {'n_is_nu': '', 'n_is_sth': ''},
 'flattery': {'n_is_nu': '', 'n_is_sth': ''},
 'flatulence': {'n_is_nu': '', 'n_is_sth': ''},
 'flaunt': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'flavoring': {'n_is_nu': '', 'n_is_sth': ''},
 'flax': {'n_is_nu': '', 'n_is_sth': ''},
 'fleetness': {'n_is_nu': '', 'n_is_sth': ''},
 'flesh': {'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'fleshes', 'vb_to_vbd': 'fleshed', 'vb_to_vbn': 'fleshed', 'vb_to_vbg': 'fleshing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nu_typical': ''},
 'flexibility': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'flexible', 'nn_to_rb': 'flexibly'},
 'flightiness': {'n_is_nu': '', 'n_is_sth': ''},
 'flimflam': {'n_is_nu': '', 'n_is_sth': ''},
 'flimsiness': {'n_is_nu': '', 'n_is_sth': ''},
 'flip-flop': {'n_is_nu': '', 'n_is_sth': ''},
 'flippancy': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'flippant'},
 'floatation': {'n_is_nu': '', 'n_is_sth': ''},
 'flooding': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'flood', 'vbg_to_vbn': 'flooded'},
 'floss': {'n_is_nu': '', 'n_is_sth': ''},
 'flotsam': {'n_is_nu': '', 'n_is_sth': ''},
 'flour': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'fluency': {'n_is_nu': '', 'n_is_sth': ''},
 'fluff': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'fluid': {'n_is_nu': '', 'n_is_sth': ''},
 'fluidity': {'n_is_nu': '', 'n_is_sth': ''},
 'fluor': {'n_is_nu': '', 'n_is_sth': ''},
 'fluorescence': {'n_is_nu': '', 'n_is_sth': ''},
 'fluorine': {'n_is_nu': '', 'n_is_sth': ''},
 'fluting': {'n_is_nu': '', 'n_is_sth': ''},
 'fm': {'n_is_nu': '', 'n_is_sth': ''},
 'foam': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'fodder': {'n_is_nu': '', 'n_is_sth': ''},
 'fog': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'folate': {'n_is_nu': '', 'n_is_sth': ''},
 'foliage': {'n_is_nu': '', 'n_is_sth': ''},
 'folklore': {'n_is_nu': '', 'n_is_sth': ''},
 'follow-through': {'n_is_nu': '', 'n_is_sth': ''},
 'fondness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'fond', 'nn_to_rb': 'fondly'},
 'foolhardiness': {'n_is_nu': '', 'n_is_sth': ''},
 'foolishness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'fool', 'nn_to_jj': 'fool'},
 'footgear': {'n_is_nu': '', 'n_is_sth': ''},
 'footwear': {'n_is_nu': '', 'n_is_sth': ''},
 'footwork': {'n_is_nu': '', 'n_is_sth': ''},
 'forage': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'forbearance': {'n_is_nu': '', 'n_is_sth': ''},
 'fore': {'n_is_nu': '', 'n_is_sth': ''},
 'foreboding': {'n_is_nu': '', 'n_is_sth': ''},
 'forefront': {'n_is_nu': '', 'n_is_sth': ''},
 'foreknowledge': {'n_is_nu': '', 'n_is_sth': ''},
 'foresight': {'n_is_nu': '', 'n_is_sth': ''},
 'forestry': {'n_is_nu': '', 'n_is_sth': ''},
 'forethought': {'n_is_nu': '', 'n_is_sth': ''},
 'forgetfulness': {'n_is_nu': '', 'n_is_sth': ''},
 'forgiveness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'forgive', 'nn_to_jj': 'forgiving'},
 'formaldehyde': {'n_is_nu': '', 'n_is_sth': ''},
 'formalin': {'n_is_nu': '', 'n_is_sth': ''},
 'formalism': {'n_is_nu': '', 'n_is_sth': ''},
 'formalization': {'n_is_nu': '', 'n_is_sth': ''},
 'formica': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'formosa': {'n_is_nu': '', 'n_is_sth': ''},
 'fornication': {'n_is_nu': '', 'n_is_sth': ''},
 'forsythia': {'n_is_nu': '', 'n_is_sth': ''},
 'fortitude': {'n_is_nu': '', 'n_is_sth': ''},
 'forwarding': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'forward', 'vbg_to_vbn': 'forwarded'},
 'fractionation': {'n_is_nu': '', 'n_is_sth': ''},
 'fragility': {'n_is_nu': '', 'n_is_sth': ''},
 'fragmentation': {'n_is_nu': '', 'n_is_sth': ''},
 'fragrance': {'n_is_nu': '', 'n_is_sth': ''},
 'framboise': {'n_is_nu': '', 'n_is_sth': ''},
 'frankincense': {'n_is_nu': '', 'n_is_sth': ''},
 'franklin': {'n_is_nu': '', 'n_is_sb': '0'},
 'frankness': {'n_is_nu': '', 'n_is_sth': ''},
 'fraudulence': {'n_is_nu': '', 'n_is_sth': ''},
 'fray': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'freezing': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'freeze', 'vbg_to_vbn': 'freezed'},
 'freon': {'n_is_nu': '', 'n_is_sth': ''},
 'freshness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'fresh', 'nn_to_rb': 'freshly'},
 'friendliness': {'n_is_nu': '', 'n_is_sth': ''},
 'fright': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'frightful', 'vb_to_jj': 'frightful'},
 'frigidity': {'n_is_nu': '', 'n_is_sth': ''},
 'frostbite': {'n_is_nu': '', 'n_is_sth': ''},
 'frosting': {'n_is_nu': '', 'n_is_sth': ''},
 'froth': {'n_is_nu': '', 'n_is_sth': ''},
 'fructose': {'n_is_nu': '', 'n_is_sth': ''},
 'frugality': {'n_is_nu': '', 'n_is_sth': ''},
 'fruition': {'n_is_nu': '', 'n_is_sth': ''},
 'fruitwood': {'n_is_nu': '', 'n_is_sth': ''},
 'fudge': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'fulfillment': {'n_is_nu': '', 'n_is_sth': ''},
 'fulfilment': {'n_is_nu': '', 'n_is_sth': ''},
 'fullness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'full', 'nn_to_jj': 'full', 'nn_to_rb': 'full'},
 'fun': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'funny', 'nu_typical': ''},
 'furnishing': {'n_is_nu': '', 'n_is_sth': ''},
 'furor': {'n_is_nu': '', 'n_is_sth': ''},
 'furtherance': {'n_is_nu': '', 'n_is_sth': ''},
 'fuss': {'n_is_nu': '', 'n_is_sth': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'fusses', 'vb_to_vbd': 'fussed', 'vb_to_vbn': 'fussed', 'vb_to_vbg': 'fussing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'futility': {'n_is_nu': '', 'n_is_sth': ''},
 'futurism': {'n_is_nu': '', 'n_is_sth': ''},
 'fuzz': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': ''},
 'g-force': {'n_is_nu': '', 'n_is_sth': ''},
 'gab': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'gadolinium': {'n_is_nu': '', 'n_is_sth': ''},
 'gaiety': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'gay'},
 'gala': {'n_is_nu': '', 'n_is_sth': ''},
 'galena': {'n_is_nu': '', 'n_is_sth': ''},
 'galilee': {'n_is_nu': '', 'n_is_sth': ''},
 'gallium': {'n_is_nu': '', 'n_is_sth': ''},
 'galton': {'n_is_nu': '', 'n_is_sb': '0'},
 'gameness': {'n_is_nu': '', 'n_is_sth': ''},
 'gaminess': {'n_is_nu': '', 'n_is_sth': ''},
 'gaming': {'n_is_nu': '', 'n_is_sth': ''},
 'gammon': {'n_is_nu': '', 'n_is_sth': ''},
 'ganges': {'n_is_nu': '', 'n_is_sth': ''},
 'gangrene': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'ganja': {'n_is_nu': '', 'n_is_sth': ''},
 'gansu': {'n_is_nu': '', 'n_is_sth': ''},
 'ganymede': {'n_is_nu': '', 'n_is_sth': ''},
 'gardening': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'garden', 'vbg_to_vbn': 'gardened', 'nu_typical': ''},
 'garrulity': {'n_is_nu': '', 'n_is_sth': ''},
 'garrulousness': {'n_is_nu': '', 'n_is_sth': ''},
 'gary': {'n_is_nu': '', 'n_is_sb': '0'},
 'gasification': {'n_is_nu': '', 'n_is_sth': ''},
 'gasoline': {'n_is_nu': '', 'n_is_sth': ''},
 'gastritis': {'n_is_nu': '', 'n_is_sth': ''},
 'gastroenteritis': {'n_is_nu': '', 'n_is_sth': ''},
 'gastronomy': {'n_is_nu': '', 'n_is_sth': ''},
 'gaudiness': {'n_is_nu': '', 'n_is_sth': ''},
 'gauze': {'n_is_nu': '', 'n_is_sth': ''},
 'gb': {'n_is_nu': '', 'n_is_sth': ''},
 'gdansk': {'n_is_nu': '', 'n_is_sth': ''},
 'gearing': {'n_is_nu': '', 'n_is_sth': ''},
 'gearshift': {'n_is_nu': '', 'n_is_sth': ''},
 'gee': {'n_is_nu': '', 'n_is_sth': ''},
 'gelatin': {'n_is_nu': '', 'n_is_sth': ''},
 'gelatine': {'n_is_nu': '', 'n_is_sth': ''},
 'generosity': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'generous', 'nn_to_rb': 'generously'},
 'genetics': {'n_is_nu': '', 'n_is_sth': ''},
 'geniality': {'n_is_nu': '', 'n_is_sth': ''},
 'genoa': {'n_is_nu': '', 'n_is_sth': ''},
 'genocide': {'n_is_nu': '', 'n_is_sth': ''},
 'gentamicin': {'n_is_nu': '', 'n_is_sth': ''},
 'gentility': {'n_is_nu': '', 'n_is_sth': ''},
 'gentleness': {'n_is_nu': '', 'n_is_sth': ''},
 'geochemistry': {'n_is_nu': '', 'n_is_sth': ''},
 'geology': {'n_is_nu': '', 'n_is_sth': ''},
 'geomancy': {'n_is_nu': '', 'n_is_sth': ''},
 'geometry': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'george': {'n_is_nu': '', 'n_is_sb': '0'},
 'georgette': {'n_is_nu': '', 'n_is_sth': ''},
 'germanium': {'n_is_nu': '', 'n_is_sth': ''},
 'germination': {'n_is_nu': '', 'n_is_sth': ''},
 'gerontology': {'n_is_nu': '', 'n_is_sth': ''},
 'gestation': {'n_is_nu': '', 'n_is_sth': ''},
 'get-up-and-go': {'n_is_nu': '', 'n_is_sth': ''},
 'ghee': {'n_is_nu': '', 'n_is_sth': ''},
 'giantism': {'n_is_nu': '', 'n_is_sth': ''},
 'gibraltar': {'n_is_nu': '', 'n_is_sth': ''},
 'giddiness': {'n_is_nu': '', 'n_is_sth': ''},
 'gigantism': {'n_is_nu': '', 'n_is_sth': ''},
 'gilding': {'n_is_nu': '', 'n_is_sth': ''},
 'gimmickry': {'n_is_nu': '', 'n_is_sth': ''},
 'ginger': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'gingivitis': {'n_is_nu': '', 'n_is_sth': ''},
 'ginseng': {'n_is_nu': '', 'n_is_sth': ''},
 'give': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'given', 'nn_to_rb': 'given', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_of': '', 'vb_to_vbz': 'gives', 'vb_to_vbd': 'gave', 'vb_to_vbn': 'given', 'vb_to_rb': 'given', 'vb_to_jj': 'given', 'vb_to_vbg': 'giving', 'v_compcl_non': '', 'vt_typical': '', 'v_sb_n': ''},
 'give-and-take': {'n_is_nu': '', 'n_is_sth': ''},
 'gladness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'glad', 'nn_to_jj': 'glad'},
 'glamor': {'n_is_nu': '', 'n_is_sth': ''},
 'glamour': {'n_is_nu': '', 'n_is_sth': ''},
 'glanders': {'n_is_nu': '', 'n_is_sth': ''},
 'glassware': {'n_is_nu': '', 'n_is_sth': ''},
 'glaucoma': {'n_is_nu': '', 'n_is_sth': ''},
 'glee': {'n_is_nu': '', 'n_is_sth': ''},
 'glitter': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'glitz': {'n_is_nu': '', 'n_is_sth': ''},
 'gloaming': {'n_is_nu': '', 'n_is_sth': ''},
 'gloat': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'gloom': {'n_is_nu': '', 'n_is_sth': ''},
 'gloominess': {'n_is_nu': '', 'n_is_sth': ''},
 'glorification': {'n_is_nu': '', 'n_is_sth': ''},
 'gloss': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'glucose': {'n_is_nu': '', 'n_is_sth': ''},
 'glue': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'gluten': {'n_is_nu': '', 'n_is_sth': ''},
 'gluttony': {'n_is_nu': '', 'n_is_sth': ''},
 'glycerin': {'n_is_nu': '', 'n_is_sth': ''},
 'glycerine': {'n_is_nu': '', 'n_is_sth': ''},
 'glycerol': {'n_is_nu': '', 'n_is_sth': ''},
 'glycol': {'n_is_nu': '', 'n_is_sth': ''},
 'gmt': {'n_is_nu': '', 'n_is_sth': ''},
 'gneiss': {'n_is_nu': '', 'n_is_sth': ''},
 'go-slow': {'n_is_nu': '', 'n_is_sth': ''},
 'gobbledygook': {'n_is_nu': '', 'n_is_sth': ''},
 'godhead': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'going': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'go', 'vbg_to_vbn': 'gone'},
 'goiter': {'n_is_nu': '', 'n_is_sth': ''},
 'goldenrod': {'n_is_nu': '', 'n_is_sth': ''},
 'golf': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'nu_typical': ''},
 'gonorrhea': {'n_is_nu': '', 'n_is_sth': ''},
 'goo': {'n_is_nu': '', 'n_is_sth': ''},
 'good-bye': {'n_is_nu': '', 'n_is_sth': ''},
 'goodness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'good', 'nn_to_rb': 'good', 'nu_typical': ''},
 'goodwill': {'n_is_nu': '', 'n_is_sth': ''},
 'goody': {'n_is_nu': '', 'n_is_sth': ''},
 'googly': {'n_is_nu': '', 'n_is_sth': ''},
 'googol': {'n_is_nu': '', 'n_is_sth': ''},
 'gore': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'vbg_non': ''},
 'gossamer': {'n_is_nu': '', 'n_is_sth': ''},
 'gothic': {'n_is_nu': '', 'n_is_sth': '', 'cap_word': 'Gothic'},
 'gout': {'n_is_nu': '', 'n_is_sth': ''},
 'governance': {'n_is_nu': '', 'n_is_sth': ''},
 'governorship': {'n_is_nu': '', 'n_is_sth': ''},
 'gracefulness': {'n_is_nu': '', 'n_is_sth': ''},
 'grackle': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'graininess': {'n_is_nu': '', 'n_is_sth': ''},
 'grandeur': {'n_is_nu': '', 'n_is_sth': ''},
 'grandiloquence': {'n_is_nu': '', 'n_is_sth': ''},
 'grandiosity': {'n_is_nu': '', 'n_is_sth': ''},
 'grandness': {'n_is_nu': '', 'n_is_sth': ''},
 'granite': {'n_is_nu': '', 'n_is_sth': ''},
 'granularity': {'n_is_nu': '', 'n_is_sth': ''},
 'grapeshot': {'n_is_nu': '', 'n_is_sth': ''},
 'graphite': {'n_is_nu': '', 'n_is_sth': ''},
 'graphology': {'n_is_nu': '', 'n_is_sth': ''},
 'grasp': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'v_at': '', 'vbd_eq_vbn': '', 'vt_typical': '', 'n_usu_singular': ''},
 'grassland': {'n_is_nu': '', 'n_is_sth': ''},
 'gratitude': {'n_is_nu': '', 'n_is_sth': ''},
 'gravitation': {'n_is_nu': '', 'n_is_sth': ''},
 'gravity': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'gravy': {'n_is_nu': '', 'n_is_sth': ''},
 'grayness': {'n_is_nu': '', 'n_is_sth': ''},
 'grease': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'greasy', 'vb_to_jj': 'greasy', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'greasepaint': {'n_is_nu': '', 'n_is_sth': ''},
 'greatness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'great', 'nn_to_rb': 'greatly'},
 'greed': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'greedy', 'nn_to_rb': 'greedily'},
 'greediness': {'n_is_nu': '', 'n_is_sth': ''},
 'greenery': {'n_is_nu': '', 'n_is_sth': ''},
 'greenness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'green', 'nn_to_jj': 'green'},
 'greensward': {'n_is_nu': '', 'n_is_sth': ''},
 'grenadine': {'n_is_nu': '', 'n_is_sth': ''},
 'grime': {'n_is_nu': '', 'n_is_sth': ''},
 'grimness': {'n_is_nu': '', 'n_is_sth': ''},
 'grippe': {'n_is_nu': '', 'n_is_sth': ''},
 'grist': {'n_is_nu': '', 'n_is_sth': ''},
 'gristle': {'n_is_nu': '', 'n_is_sth': ''},
 'grit': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'grizzle': {'n_is_nu': '', 'n_is_sth': ''},
 'grog': {'n_is_nu': '', 'n_is_sth': ''},
 'grotesqueness': {'n_is_nu': '', 'n_is_sth': ''},
 'grotesquerie': {'n_is_nu': '', 'n_is_sth': ''},
 'grounding': {'n_is_nu': '', 'n_is_sth': ''},
 'groundwork': {'n_is_nu': '', 'n_is_sth': ''},
 'grubstake': {'n_is_nu': '', 'n_is_sth': ''},
 'grudge': {'n_is_nu': '', 'n_is_sth': '', 'v_vbg': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'gruel': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'gu': {'n_is_nu': '', 'n_is_sth': ''},
 'guangzhou': {'n_is_nu': '', 'n_is_sth': '', 'cap_word': 'Guangzhou'},
 'guardianship': {'n_is_nu': '', 'n_is_sth': ''},
 'guesstimate': {'n_is_nu': '', 'n_is_sth': ''},
 'guesswork': {'n_is_nu': '', 'n_is_sth': ''},
 'guff': {'n_is_nu': '', 'n_is_sth': ''},
 'guile': {'n_is_nu': '', 'n_is_sth': ''},
 'gumbo': {'n_is_nu': '', 'n_is_sth': ''},
 'gumption': {'n_is_nu': '', 'n_is_sth': ''},
 'gunfire': {'n_is_nu': '', 'n_is_sth': ''},
 'gunnery': {'n_is_nu': '', 'n_is_sth': ''},
 'gunplay': {'n_is_nu': '', 'n_is_sth': ''},
 'gunpowder': {'n_is_nu': '', 'n_is_sth': ''},
 'gusto': {'n_is_nu': '', 'n_is_sth': ''},
 'gymnastics': {'n_is_nu': '', 'n_is_sth': ''},
 'gyp': {'n_is_nu': '', 'n_is_sth': ''},
 'gypsum': {'n_is_nu': '', 'n_is_sth': ''},
 'ha-ha': {'n_is_nu': '', 'n_is_sth': ''},
 'habituation': {'n_is_nu': '', 'n_is_sth': ''},
 'hades': {'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'haggle': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'haiphong': {'n_is_nu': '', 'n_is_sth': ''},
 'hairdressing': {'n_is_nu': '', 'n_is_sth': ''},
 'hairsplitting': {'n_is_nu': '', 'n_is_sth': ''},
 'half-and-half': {'n_is_nu': '', 'n_is_sth': ''},
 'halitosis': {'n_is_nu': '', 'n_is_sth': ''},
 'halloween': {'n_is_nu': '', 'n_is_sth': ''},
 'halogen': {'n_is_nu': '', 'n_is_sth': ''},
 'handiwork': {'n_is_nu': '', 'n_is_sth': ''},
 'handshaking': {'n_is_nu': '', 'n_is_sth': ''},
 'hangzhou': {'n_is_nu': '', 'n_is_sth': ''},
 'happiness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'happy', 'nn_to_rb': 'happily', 'sb_be_nn.nn_to_jj': 'happy', 'nu_typical': ''},
 'harassment': {'n_is_nu': '', 'n_is_sth': ''},
 'hardboard': {'n_is_nu': '', 'n_is_sth': ''},
 'hardening': {'n_is_nu': '', 'n_is_sth': ''},
 'hardiness': {'n_is_nu': '', 'n_is_sth': ''},
 'hardness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'harden', 'nn_to_jj': 'hard', 'nn_to_rb': 'hard'},
 'hardship': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_nns': 'hardships'},
 'harm': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'harmful', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'harms', 'vb_to_vbd': 'harmed', 'vb_to_vbn': 'harmed', 'vb_to_jj': 'harmful', 'vb_to_vbg': 'harming', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vt_typical': ''},
 'harmfulness': {'n_is_nu': '', 'n_is_sth': ''},
 'harmonization': {'n_is_nu': '', 'n_is_sth': ''},
 'haste': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'hasty', 'nn_to_rb': 'hastily', 'vb_to_rb': 'hastily', 'vb_to_jj': 'hasty'},
 'hastiness': {'n_is_nu': '', 'n_is_sth': ''},
 'hatred': {'n_is_nu': '', 'n_is_sth': ''},
 'haughtiness': {'n_is_nu': '', 'n_is_sth': ''},
 'hauteur': {'n_is_nu': '', 'n_is_sth': ''},
 'havoc': {'n_is_nu': '', 'n_is_sth': ''},
 'hay': {'n_is_nu': '', 'n_is_sth': ''},
 'haydn': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'haze': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'haziness': {'n_is_nu': '', 'n_is_sth': ''},
 'headroom': {'n_is_nu': '', 'n_is_sth': ''},
 'health': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'healthy', 'nu_typical': ''},
 'healthiness': {'n_is_nu': '', 'n_is_sth': ''},
 'hearsay': {'n_is_nu': '', 'n_is_sth': ''},
 'heartache': {'n_is_nu': '', 'n_is_sth': ''},
 'heartbreak': {'n_is_nu': '', 'n_is_sth': ''},
 'heartburn': {'n_is_nu': '', 'n_is_sth': ''},
 'heartiness': {'n_is_nu': '', 'n_is_sth': ''},
 'heartthrob': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'heating': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'heat', 'vbg_to_vbn': 'heated'},
 'heatstroke': {'n_is_nu': '', 'n_is_sth': ''},
 'heaviness': {'n_is_nu': '', 'n_is_sth': ''},
 'heebie-jeebies': {'n_is_nu': '', 'n_is_sth': ''},
 'heed': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'hegemony': {'n_is_nu': '', 'n_is_sth': ''},
 'helium': {'n_is_nu': '', 'n_is_sth': ''},
 'hematite': {'n_is_nu': '', 'n_is_sth': ''},
 'hematology': {'n_is_nu': '', 'n_is_sth': ''},
 'hemoglobin': {'n_is_nu': '', 'n_is_sth': ''},
 'hemophilia': {'n_is_nu': '', 'n_is_sth': ''},
 'hemp': {'n_is_nu': '', 'n_is_sth': ''},
 'henna': {'n_is_nu': '', 'n_is_sth': ''},
 'henry': {'n_is_nu': '', 'n_is_sb': '0'},
 'heparin': {'n_is_nu': '', 'n_is_sth': ''},
 'hepatitis': {'n_is_nu': '', 'n_is_sth': ''},
 'heraldry': {'n_is_nu': '', 'n_is_sth': ''},
 'herbicide': {'n_is_nu': '', 'n_is_sth': ''},
 'hereafter': {'n_is_nu': '', 'n_is_sth': ''},
 'heredity': {'n_is_nu': '', 'n_is_sth': ''},
 'hernia': {'n_is_nu': '', 'n_is_sth': ''},
 'heroism': {'n_is_nu': '', 'n_is_sth': ''},
 'herpes': {'n_is_nu': '', 'n_is_sth': ''},
 'hesitance': {'n_is_nu': '', 'n_is_sth': ''},
 'hesitancy': {'n_is_nu': '', 'n_is_sth': ''},
 'hesitation': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'hesitate', 'nn_to_jj': 'hesitating'},
 'hesperus': {'n_is_nu': '', 'n_is_sth': ''},
 'heterogeneity': {'n_is_nu': '', 'n_is_sth': ''},
 'hibernation': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'hide-and-seek': {'n_is_nu': '', 'n_is_sth': ''},
 'hiding': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'hide', 'vbg_to_vbn': 'hidden'},
 'hieroglyph': {'n_is_nu': '', 'n_is_sth': ''},
 'high-mindedness': {'n_is_nu': '', 'n_is_sth': ''},
 'highness': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_jj': 'high', 'nn_to_rb': 'highly'},
 'hiking': {'n_is_nu': '', 'n_is_sth': ''},
 'hilarity': {'n_is_nu': '', 'n_is_sth': ''},
 'hinduism': {'n_is_nu': '', 'n_is_sth': ''},
 'hindustan': {'n_is_nu': '', 'n_is_sth': ''},
 'hire': {'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'hires', 'vb_to_vbd': 'hired', 'vb_to_vbn': 'hired', 'vb_to_vbg': 'hiring', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vt_typical': ''},
 'histamine': {'n_is_nu': '', 'n_is_sth': ''},
 'histology': {'n_is_nu': '', 'n_is_sth': ''},
 'historiography': {'n_is_nu': '', 'n_is_sth': ''},
 'hitch': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'hoar': {'n_is_nu': '', 'n_is_sth': ''},
 'hoarseness': {'n_is_nu': '', 'n_is_sth': ''},
 'hocus-pocus': {'n_is_nu': '', 'n_is_sth': ''},
 'hogmanay': {'n_is_nu': '', 'n_is_sth': ''},
 'hogwash': {'n_is_nu': '', 'n_is_sth': ''},
 'hokkaido': {'n_is_nu': '', 'n_is_sth': ''},
 'holiness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'holy'},
 'hollowness': {'n_is_nu': '', 'n_is_sth': ''},
 'hollywood': {'n_is_nu': '', 'n_is_sth': ''},
 'holography': {'n_is_nu': '', 'n_is_sth': ''},
 'homage': {'n_is_nu': '', 'n_is_sth': ''},
 'homelessness': {'n_is_nu': '', 'n_is_sth': ''},
 'homeliness': {'n_is_nu': '', 'n_is_sth': ''},
 'homemaking': {'n_is_nu': '', 'n_is_sth': ''},
 'homeostasis': {'n_is_nu': '', 'n_is_sth': ''},
 'homesickness': {'n_is_nu': '', 'n_is_sth': ''},
 'homespun': {'n_is_nu': '', 'n_is_sth': ''},
 'homework': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'hominy': {'n_is_nu': '', 'n_is_sth': ''},
 'homogeneity': {'n_is_nu': '', 'n_is_sth': ''},
 'homosexuality': {'n_is_nu': '', 'n_is_sth': ''},
 'honesty': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'honest', 'nn_to_rb': 'honestly'},
 'honey': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nu_typical': ''},
 'honshu': {'n_is_nu': '', 'n_is_sth': ''},
 'hooch': {'n_is_nu': '', 'n_is_sth': ''},
 'hookup': {'n_is_nu': '', 'n_is_sth': ''},
 'hooliganism': {'n_is_nu': '', 'n_is_sth': ''},
 'hoopla': {'n_is_nu': '', 'n_is_sth': ''},
 'hopelessness': {'n_is_nu': '', 'n_is_sth': ''},
 'hops': {'n_is_nu': '', 'n_is_sth': ''},
 'hopscotch': {'n_is_nu': '', 'n_is_sth': ''},
 'horsehair': {'n_is_nu': '', 'n_is_sth': ''},
 'horsemanship': {'n_is_nu': '', 'n_is_sth': ''},
 'horticulture': {'n_is_nu': '', 'n_is_sth': ''},
 'hosiery': {'n_is_nu': '', 'n_is_sth': ''},
 'hospitality': {'n_is_nu': '', 'n_is_sth': ''},
 'hostility': {'n_is_nu': '', 'n_is_sth': ''},
 'hotness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'hot', 'nn_to_jj': 'hot', 'nn_to_rb': 'hot'},
 'housecleaning': {'n_is_nu': '', 'n_is_sth': ''},
 'housekeeping': {'n_is_nu': '', 'n_is_sth': ''},
 'housework': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'hp': {'n_is_nu': '', 'n_is_sth': ''},
 'hua': {'n_is_nu': '', 'n_is_sth': ''},
 'hubbub': {'n_is_nu': '', 'n_is_sth': ''},
 'hubris': {'n_is_nu': '', 'n_is_sth': ''},
 'hugo': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'humaneness': {'n_is_nu': '', 'n_is_sth': ''},
 'humanism': {'n_is_nu': '', 'n_is_sth': ''},
 'humanitarianism': {'n_is_nu': '', 'n_is_sth': ''},
 'humanity': {'n_is_nu': '', 'n_is_sth': ''},
 'humankind': {'n_is_nu': '', 'n_is_sb': '0'},
 'humanness': {'n_is_nu': '', 'n_is_sth': ''},
 'humbleness': {'n_is_nu': '', 'n_is_sth': ''},
 'humdrum': {'n_is_nu': '', 'n_is_sth': ''},
 'humidity': {'n_is_nu': '', 'n_is_sth': ''},
 'humiliation': {'n_is_nu': '', 'n_is_sth': ''},
 'humility': {'n_is_nu': '', 'n_is_sth': ''},
 'humor': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_nc': ''},
 'humus': {'n_is_nu': '', 'n_is_sth': ''},
 'hunger': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'hungry', 'nn_to_rb': 'hungrily', 'vb_to_rb': 'hungrily', 'vb_to_jj': 'hungry', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'hurling': {'n_is_nu': '', 'n_is_sth': ''},
 'hurry': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'hurried', 'nn_to_rb': 'hurriedly', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_to': '', 'vb_to_vbz': 'hurries', 'vb_to_vbd': 'hurried', 'vb_to_vbn': 'hurried', 'vb_to_rb': 'hurriedly', 'vb_to_jj': 'hurried', 'vb_to_vbg': 'hurrying', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'husbandry': {'n_is_nu': '', 'n_is_sth': ''},
 'hush': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'hustle': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'hybridization': {'n_is_nu': '', 'n_is_sth': ''},
 'hydrate': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'hydration': {'n_is_nu': '', 'n_is_sth': ''},
 'hydraulics': {'n_is_nu': '', 'n_is_sth': ''},
 'hydrazine': {'n_is_nu': '', 'n_is_sth': ''},
 'hydrocarbon': {'n_is_nu': '', 'n_is_sth': ''},
 'hydrocephalus': {'n_is_nu': '', 'n_is_sth': ''},
 'hydroelectricity': {'n_is_nu': '', 'n_is_sth': ''},
 'hydrogen': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'hydrology': {'n_is_nu': '', 'n_is_sth': ''},
 'hydrotherapy': {'n_is_nu': '', 'n_is_sth': ''},
 'hydroxyl': {'n_is_nu': '', 'n_is_sth': ''},
 'hygiene': {'n_is_nu': '', 'n_is_sth': ''},
 'hyla': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'hype': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'hyperopia': {'n_is_nu': '', 'n_is_sth': ''},
 'hyperplasia': {'n_is_nu': '', 'n_is_sth': ''},
 'hypersensitivity': {'n_is_nu': '', 'n_is_sth': ''},
 'hypertension': {'n_is_nu': '', 'n_is_sth': ''},
 'hyperthermia': {'n_is_nu': '', 'n_is_sth': ''},
 'hypertrophy': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'hyphenation': {'n_is_nu': '', 'n_is_sth': ''},
 'hypnosis': {'n_is_nu': '', 'n_is_sth': ''},
 'hypnotism': {'n_is_nu': '', 'n_is_sth': ''},
 'hypochondria': {'n_is_nu': '', 'n_is_sth': ''},
 'hypocrisy': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'hypocritical'},
 'hypoglycemia': {'n_is_nu': '', 'n_is_sth': ''},
 'hypotension': {'n_is_nu': '', 'n_is_sth': ''},
 'hypothalamus': {'n_is_nu': '', 'n_is_sth': ''},
 'hypothermia': {'n_is_nu': '', 'n_is_sth': ''},
 'hypoxia': {'n_is_nu': '', 'n_is_sth': ''},
 'hysteresis': {'n_is_nu': '', 'n_is_sth': ''},
 'hysteria': {'n_is_nu': '', 'n_is_sth': ''},
 'hysterics': {'n_is_nu': '', 'n_is_sth': ''},
 'ic': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'iciness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'icing': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'iconography': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'idealism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ideology': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'ideological', 'nn_to_rb': 'ideologically'},
 'idleness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ignominy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ignorance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'ignore', 'nn_to_jj': 'ignorant'},
 'ill-treatment': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'illegality': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'illegitimacy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'illiteracy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'imagery': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'imaginativeness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'imaging': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'imbalance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'immanence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'immaturity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'immediacy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'immediate', 'nn_to_rb': 'immediately'},
 'immensity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'immigration': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'immigrate', 'nn_to_jj': 'immigrant', 'nu_typical': ''},
 'imminence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'immobilization': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'immodesty': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'immolation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'immorality': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'immortality': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'impartiality': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'impatience': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'impedance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'impenetrability': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'imperialism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'impermanence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'impersonation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'impetigo': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'impetuosity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'impetus': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'implantation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'importance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'important', 'nn_to_rb': 'importantly', 'nu_typical': ''},
 'impotence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'impotency': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'impoundment': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'impoverishment': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'impregnation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'impressionism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'imprinting': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'imprisonment': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'impudence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inability': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_usu_singular': '', 'n_is_nc': ''},
 'inaccuracy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inaction': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inactivation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inactivity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inamorata': {'n_is_nu': '', 'n_is_sb': '0', 'art_an': ''},
 'inattention': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'incandescence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'incarceration': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'incense': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'incest': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inchon': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'incidence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'incident', 'nn_to_rb': 'incidentally', 'n_is_nc': '', 'n_usu_singular': ''},
 'incineration': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'incoherence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'incompetence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'incompleteness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inconclusiveness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inconsequence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inconsistency': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'incontinence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inconvenience': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'inconvenient', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'be_nn_in.nn_to_jj': ''},
 'incorporation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'incorporate', 'nn_to_jj': 'incorporate'},
 'incorrectness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'incredulity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'incubation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inculcation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'indebtedness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'indecency': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'indecision': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'indemnification': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'independence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'independent', 'nn_to_rb': 'independently', 'nu_typical': ''},
 'indeterminacy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'indifference': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'indigence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'indigestion': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'indignation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'indigo': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'indium': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'individualism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'individuality': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'individualise', 'nn_to_jj': 'individual'},
 'individuation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'indo-european': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'indochina': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'indoctrination': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'indolence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'industrialization': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inebriation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ineffectiveness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inefficiency': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inelegance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ineptitude': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inequality': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inertia': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inertness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inevitability': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'inevitable', 'nn_to_rb': 'inevitably'},
 'infamy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'infancy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'infantry': {'n_is_nu': '', 'n_is_sb': '0', 'art_an': ''},
 'infatuation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inferiority': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'infertility': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'infiltration': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'infinite': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'infinity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inflation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inflator': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inflexibility': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'infliction': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'influenza': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'informality': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'information': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'inform', 'nn_to_jj': 'informing', 'nu_typical': ''},
 'infrared': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'jj_ed': ''},
 'infrequency': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ingenuity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ingestion': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ingratiation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ingratitude': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ingress': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inhalation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inhibition': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'inhibit', 'nn_to_jj': 'inhibited'},
 'inhospitality': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inhumanity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'injustice': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inkling': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'innocence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inquisition': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ins': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'insanity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inscrutability': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'insecticide': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'insemination': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'insensitivity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'insignificance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'insincerity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'insinuation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'insistence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'insolence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'insomnia': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'insouciance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inspirer': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'instigation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'instrumentation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'insubordination': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'insularity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'insulation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'insulin': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'insurgence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'integration': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'integrate', 'nn_to_jj': 'integrate'},
 'integrity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'intelligence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'intelligent', 'nn_to_rb': 'intelligently', 'nu_typical': ''},
 'intelligibility': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'intemperance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'intensification': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'intercept': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'intercourse': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'interference': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'interfere'},
 'interferon': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'intermediation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'intermediate', 'nn_to_jj': 'intermediate'},
 'internationalism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'internationalization': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'internet': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'internment': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'interplay': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'interrupt': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'interrupted', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'v_with': '', 'vb_to_jj': 'interrupted', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'intimacy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'intimidation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'intolerance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'intoxication': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'introspection': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'introversion': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'intubation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'intussusception': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'invalidity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'invective': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inventiveness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inverse': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inverter': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'invigoration': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'invincibility': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'inwardness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'iodine': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ionization': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ionosphere': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'iota': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ipecac': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'irak': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'irascibility': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ire': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'iridescence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'iridium': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ironwork': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'irradiation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'irregularity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'irrelevance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'irresolution': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'irreverence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'irrigation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nu_typical': ''},
 'irritability': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'isaiah': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'islam': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'cap_word': 'Islam'},
 'islamism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'isolation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'isolate', 'nn_to_jj': 'isolate'},
 'isoniazid': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'iteration': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'jabber': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'jackfruit': {'n_is_nu': '', 'n_is_sth': ''},
 'jadeite': {'n_is_nu': '', 'n_is_sth': ''},
 'jape': {'n_is_nu': '', 'n_is_sth': ''},
 'jargon': {'n_is_nu': '', 'n_is_sth': ''},
 'jasper': {'n_is_nu': '', 'n_is_sth': ''},
 'jaundice': {'n_is_nu': '', 'n_is_sth': ''},
 'jauntiness': {'n_is_nu': '', 'n_is_sth': ''},
 'java': {'n_is_nu': '', 'n_is_sth': ''},
 'jazz': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'nu_typical': ''},
 'jehovah': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'jeopardy': {'n_is_nu': '', 'n_is_sth': ''},
 'jewel': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'vb_to_nn': 'jewelry'},
 'jewellery': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'jewelry': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'jewel'},
 'jewelweed': {'n_is_nu': '', 'n_is_sth': ''},
 'jewry': {'n_is_nu': '', 'n_is_sth': ''},
 'jibe': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'jingoism': {'n_is_nu': '', 'n_is_sth': ''},
 'jitter': {'n_is_nu': '', 'n_is_sth': ''},
 'jitteriness': {'n_is_nu': '', 'n_is_sth': ''},
 'jive': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'jocularity': {'n_is_nu': '', 'n_is_sth': ''},
 'jodhpur': {'n_is_nu': '', 'n_is_sth': ''},
 'john': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'johnson': {'n_is_nu': '', 'n_is_sb': '0'},
 'joinery': {'n_is_nu': '', 'n_is_sth': ''},
 'jones': {'n_is_nu': '', 'n_is_sb': '0', 'n_is_nc': ''},
 'joseph': {'n_is_nu': '', 'n_is_sb': '0'},
 'jove': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'jubilance': {'n_is_nu': '', 'n_is_sth': ''},
 'jubilation': {'n_is_nu': '', 'n_is_sth': ''},
 'jubilee': {'n_is_nu': '', 'n_is_sth': ''},
 'judaism': {'n_is_nu': '', 'n_is_sth': ''},
 'judas': {'n_is_nu': '', 'n_is_sb': '0'},
 'judea': {'n_is_nu': '', 'n_is_sth': ''},
 'judo': {'n_is_nu': '', 'n_is_sth': ''},
 'jujitsu': {'n_is_nu': '', 'n_is_sth': ''},
 'jumpiness': {'n_is_nu': '', 'n_is_sth': ''},
 'jupiter': {'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'jurisprudence': {'n_is_nu': '', 'n_is_sth': ''},
 'justness': {'n_is_nu': '', 'n_is_sth': ''},
 'jute': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'juxtaposition': {'n_is_nu': '', 'n_is_sth': ''},
 'kaolin': {'n_is_nu': '', 'n_is_sth': ''},
 'kapok': {'n_is_nu': '', 'n_is_sth': ''},
 'karma': {'n_is_nu': '', 'n_is_sth': ''},
 'kashmir': {'n_is_nu': '', 'n_is_sth': ''},
 'keen': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'be_jj_to_vb': '', 'jj_to_jjr': 'keener', 'jj_to_jjs': 'keenest'},
 'kelp': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'kelvin': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'kennedy': {'n_is_nu': '', 'n_is_sb': '0'},
 'keratin': {'n_is_nu': '', 'n_is_sth': ''},
 'kerfuffle': {'n_is_nu': '', 'n_is_sth': ''},
 'kerosene': {'n_is_nu': '', 'n_is_sth': ''},
 'ketchup': {'n_is_nu': '', 'n_is_sth': ''},
 'khaki': {'n_is_nu': '', 'n_is_sth': ''},
 'khrushchev': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'kibble': {'n_is_nu': '', 'n_is_sth': ''},
 'kindliness': {'n_is_nu': '', 'n_is_sth': ''},
 'kindling': {'n_is_nu': '', 'n_is_sth': ''},
 'kindness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'kind', 'nn_to_rb': 'kindly'},
 'kindred': {'n_is_nu': '', 'n_is_sth': '', 'jj_ed': ''},
 'kinesiology': {'n_is_nu': '', 'n_is_sth': ''},
 'kinetics': {'n_is_nu': '', 'n_is_sth': ''},
 'knack': {'n_is_nu': '', 'n_is_sth': ''},
 'knesset': {'n_is_nu': '', 'n_is_sth': ''},
 'knitting': {'n_is_nu': '', 'n_is_sth': ''},
 'knitwear': {'n_is_nu': '', 'n_is_sth': ''},
 'know-how': {'n_is_nu': '', 'n_is_sth': ''},
 'knowledge': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': '', 'nn_to_jj': '', 'n_usu_singular': ''},
 'knut': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'kohlrabi': {'n_is_nu': '', 'n_is_sth': ''},
 'krypton': {'n_is_nu': '', 'n_is_sth': ''},
 'kudos': {'n_is_nu': '', 'n_is_sth': ''},
 'kudzu': {'n_is_nu': '', 'n_is_sth': ''},
 'kuomintang': {'n_is_nu': '', 'n_is_sth': ''},
 'kyushu': {'n_is_nu': '', 'n_is_sth': ''},
 'labor': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'lac': {'n_is_nu': '', 'n_is_sth': ''},
 'lacework': {'n_is_nu': '', 'n_is_sth': ''},
 'lacing': {'n_is_nu': '', 'n_is_sth': ''},
 'lack': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'lacking', 'v_to_vbg': '', 'v_n': '', 'vdo': '', 'v_in': '', 'v_for': '', 'vb_to_vbz': 'lacks', 'vb_to_vbd': 'lacked', 'vb_to_vbn': 'lacked', 'vb_to_jj': 'lacking', 'vb_to_vbg': 'lacking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_pass_non': '', 'nu_typical': ''},
 'lacquer': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'lactation': {'n_is_nu': '', 'n_is_sth': ''},
 'lactose': {'n_is_nu': '', 'n_is_sth': ''},
 'lagging': {'n_is_nu': '', 'n_is_sth': ''},
 'lam': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'lameness': {'n_is_nu': '', 'n_is_sth': ''},
 'lampblack': {'n_is_nu': '', 'n_is_sth': ''},
 'lamplight': {'n_is_nu': '', 'n_is_sth': ''},
 'landfall': {'n_is_nu': '', 'n_is_sth': ''},
 'languor': {'n_is_nu': '', 'n_is_sth': ''},
 'lantana': {'n_is_nu': '', 'n_is_sth': ''},
 'lard': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'large': {'n_is_nu': '', 'n_is_sth': '', 'jj_to_jjr': 'larger', 'jj_to_jjs': 'largest'},
 'largeness': {'n_is_nu': '', 'n_is_sth': ''},
 'largess': {'n_is_nu': '', 'n_is_sth': ''},
 'largesse': {'n_is_nu': '', 'n_is_sth': ''},
 'laryngitis': {'n_is_nu': '', 'n_is_sth': ''},
 'lassitude': {'n_is_nu': '', 'n_is_sth': ''},
 'latency': {'n_is_nu': '', 'n_is_sth': ''},
 'latex': {'n_is_nu': '', 'n_is_sth': ''},
 'lather': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'laughton': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'lavage': {'n_is_nu': '', 'n_is_sth': ''},
 'laver': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'lawlessness': {'n_is_nu': '', 'n_is_sth': ''},
 'lawmaking': {'n_is_nu': '', 'n_is_sth': ''},
 'laxity': {'n_is_nu': '', 'n_is_sth': ''},
 'laziness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'lazy', 'nn_to_rb': 'lazily', 'nn_to_vb': 'laze'},
 'lea': {'n_is_nu': '', 'n_is_sth': ''},
 'lean': {'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_against': '', 'vb_to_vbz': 'leans', 'vb_to_vbd': 'leaned', 'vb_to_vbn': 'leaned', 'vb_to_vbg': 'leaning', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'jj_to_jjr': 'leaner', 'jj_to_jjs': 'leanest'},
 'leaning': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'lean', 'vbg_to_vbn': 'leaned'},
 'leanness': {'n_is_nu': '', 'n_is_sth': ''},
 'learning': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'learn', 'nn_to_jj': 'learned', 'vbg_to_vb': 'learn', 'vbg_to_vbn': 'learned,learnt'},
 'leatherette': {'n_is_nu': '', 'n_is_sth': ''},
 'leaven': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'lecithin': {'n_is_nu': '', 'n_is_sth': ''},
 'leeward': {'n_is_nu': '', 'n_is_sth': ''},
 'leeway': {'n_is_nu': '', 'n_is_sth': ''},
 'legalism': {'n_is_nu': '', 'n_is_sth': ''},
 'legality': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'legal', 'nn_to_rb': 'legally'},
 'legalization': {'n_is_nu': '', 'n_is_sth': ''},
 'legerdemain': {'n_is_nu': '', 'n_is_sth': ''},
 'legibility': {'n_is_nu': '', 'n_is_sth': ''},
 'legislation': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'legislate', 'nn_to_jj': 'legislative'},
 'legitimacy': {'n_is_nu': '', 'n_is_sth': ''},
 'leipzig': {'n_is_nu': '', 'n_is_sth': ''},
 'leisure': {'n_is_nu': '', 'n_is_sth': ''},
 'lemongrass': {'n_is_nu': '', 'n_is_sth': ''},
 'lena': {'n_is_nu': '', 'n_is_sb': '0'},
 'lend-lease': {'n_is_nu': '', 'n_is_sth': ''},
 'lenience': {'n_is_nu': '', 'n_is_sth': ''},
 'leniency': {'n_is_nu': '', 'n_is_sth': ''},
 'leningrad': {'n_is_nu': '', 'n_is_sth': ''},
 'leninism': {'n_is_nu': '', 'n_is_sth': ''},
 'lent': {'n_is_nu': '', 'n_is_sth': '', 'vbd_to_vb': 'lend', 'vbn_to_vb': 'lend', 'vbn_to_vbg': 'lending', 'vbd_eq_vbn': ''},
 'leprosy': {'n_is_nu': '', 'n_is_sth': ''},
 'lethality': {'n_is_nu': '', 'n_is_sth': ''},
 'lethargy': {'n_is_nu': '', 'n_is_sth': ''},
 'lettering': {'n_is_nu': '', 'n_is_sth': ''},
 'lettuce': {'n_is_nu': '', 'n_is_sth': ''},
 'letup': {'n_is_nu': '', 'n_is_sth': ''},
 'leukemia': {'n_is_nu': '', 'n_is_sth': ''},
 'levitation': {'n_is_nu': '', 'n_is_sth': ''},
 'levity': {'n_is_nu': '', 'n_is_sth': ''},
 'lewdness': {'n_is_nu': '', 'n_is_sth': ''},
 'lewis': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'lexicography': {'n_is_nu': '', 'n_is_sth': ''},
 'lhasa': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'liaison': {'n_is_nu': '', 'n_is_sth': ''},
 'liao': {'n_is_nu': '', 'n_is_sth': ''},
 'liberalism': {'n_is_nu': '', 'n_is_sth': ''},
 'liberality': {'n_is_nu': '', 'n_is_sth': ''},
 'liberalization': {'n_is_nu': '', 'n_is_sth': ''},
 'liberation': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'libra': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'librium': {'n_is_nu': '', 'n_is_sth': ''},
 'lichen': {'n_is_nu': '', 'n_is_sth': ''},
 'licorice': {'n_is_nu': '', 'n_is_sth': ''},
 'lieu': {'n_is_nu': '', 'n_is_sth': ''},
 'lifeblood': {'n_is_nu': '', 'n_is_sth': ''},
 'lifesaving': {'n_is_nu': '', 'n_is_sth': ''},
 'ligature': {'n_is_nu': '', 'n_is_sth': ''},
 'lighting': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'light', 'vbg_to_vbn': 'lighted'},
 'lightness': {'n_is_nu': '', 'n_is_sth': ''},
 'lightning': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'lignin': {'n_is_nu': '', 'n_is_sth': ''},
 'lignite': {'n_is_nu': '', 'n_is_sth': ''},
 'limbo': {'n_is_nu': '', 'n_is_sth': ''},
 'lime': {'n_is_nu': '', 'n_is_sth': ''},
 'linearity': {'n_is_nu': '', 'n_is_sth': ''},
 'linen': {'n_is_nu': '', 'n_is_sth': ''},
 'ling': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'linoleum': {'n_is_nu': '', 'n_is_sth': ''},
 'lint': {'n_is_nu': '', 'n_is_sth': ''},
 'liquefaction': {'n_is_nu': '', 'n_is_sth': ''},
 'liqueur': {'n_is_nu': '', 'n_is_sth': ''},
 'liquidity': {'n_is_nu': '', 'n_is_sth': ''},
 'liquor': {'n_is_nu': '', 'n_is_sth': ''},
 'literacy': {'n_is_nu': '', 'n_is_sth': ''},
 'literalism': {'n_is_nu': '', 'n_is_sth': ''},
 'literature': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'literary', 'nn_to_rb': 'literarily', 'nn_to_nns': 'literatures'},
 'lithium': {'n_is_nu': '', 'n_is_sth': ''},
 'lithography': {'n_is_nu': '', 'n_is_sth': ''},
 'litigation': {'n_is_nu': '', 'n_is_sth': ''},
 'litmus': {'n_is_nu': '', 'n_is_sth': ''},
 'livelihood': {'n_is_nu': '', 'n_is_sth': ''},
 'liveliness': {'n_is_nu': '', 'n_is_sth': ''},
 'loading': {'n_is_nu': '', 'n_is_sth': ''},
 'loam': {'n_is_nu': '', 'n_is_sth': ''},
 'loathing': {'n_is_nu': '', 'n_is_sth': ''},
 'localism': {'n_is_nu': '', 'n_is_sth': ''},
 'localization': {'n_is_nu': '', 'n_is_sth': ''},
 'lockjaw': {'n_is_nu': '', 'n_is_sth': ''},
 'locomotion': {'n_is_nu': '', 'n_is_sth': ''},
 'lodestar': {'n_is_nu': '', 'n_is_sth': ''},
 'loess': {'n_is_nu': '', 'n_is_sth': ''},
 'loftiness': {'n_is_nu': '', 'n_is_sth': ''},
 'logging': {'n_is_nu': '', 'n_is_sth': ''},
 'logrolling': {'n_is_nu': '', 'n_is_sth': ''},
 'loneliness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'lone'},
 'longevity': {'n_is_nu': '', 'n_is_sth': ''},
 'longing': {'n_is_nu': '', 'n_is_sth': ''},
 'lonicera': {'n_is_nu': '', 'n_is_sth': ''},
 'looseness': {'n_is_nu': '', 'n_is_sth': ''},
 'loot': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'lope': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'loquaciousness': {'n_is_nu': '', 'n_is_sth': ''},
 'lore': {'n_is_nu': '', 'n_is_sth': ''},
 'lorraine': {'n_is_nu': '', 'n_is_sth': ''},
 'lotion': {'n_is_nu': '', 'n_is_sth': ''},
 'loudness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'loud', 'nn_to_rb': 'loudly'},
 'loveliness': {'n_is_nu': '', 'n_is_sth': ''},
 'lovemaking': {'n_is_nu': '', 'n_is_sth': ''},
 'lovesickness': {'n_is_nu': '', 'n_is_sth': ''},
 'lower': {'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'lowers', 'vb_to_vbd': 'lowered', 'vb_to_vbn': 'lowered', 'vb_to_vbg': 'lowering', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'lowercase': {'n_is_nu': '', 'n_is_sth': ''},
 'lu': {'n_is_nu': '', 'n_is_sth': ''},
 'lube': {'n_is_nu': '', 'n_is_sth': ''},
 'lubrication': {'n_is_nu': '', 'n_is_sth': ''},
 'luce': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'lucerne': {'n_is_nu': '', 'n_is_sth': ''},
 'lucidity': {'n_is_nu': '', 'n_is_sth': ''},
 'luck': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'lucky', 'nn_to_rb': 'luckily', 'vb_to_rb': 'luckily', 'vb_to_jj': 'lucky', 'vbd_eq_vbn': '', 'nu_typical': ''},
 'lucre': {'n_is_nu': '', 'n_is_sth': ''},
 'luggage': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'luminance': {'n_is_nu': '', 'n_is_sth': ''},
 'luminescence': {'n_is_nu': '', 'n_is_sth': ''},
 'luna': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'lunacy': {'n_is_nu': '', 'n_is_sth': ''},
 'lungi': {'n_is_nu': '', 'n_is_sth': ''},
 'lupus': {'n_is_nu': '', 'n_is_sth': ''},
 'luster': {'n_is_nu': '', 'n_is_sth': ''},
 'lustiness': {'n_is_nu': '', 'n_is_sth': ''},
 'lustre': {'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'lutein': {'n_is_nu': '', 'n_is_sth': ''},
 'luxemburg': {'n_is_nu': '', 'n_is_sth': ''},
 'luxuriance': {'n_is_nu': '', 'n_is_sth': ''},
 'luzon': {'n_is_nu': '', 'n_is_sth': ''},
 'lymph': {'n_is_nu': '', 'n_is_sth': ''},
 'lyra': {'n_is_nu': '', 'n_is_sth': ''},
 'lyssa': {'n_is_nu': '', 'n_is_sth': ''},
 'macadam': {'n_is_nu': '', 'n_is_sth': ''},
 'macaroni': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'mace': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'maceration': {'n_is_nu': '', 'n_is_sth': ''},
 'macrame': {'n_is_nu': '', 'n_is_sth': ''},
 'macro': {'n_is_nu': '', 'n_is_sth': ''},
 'madness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'mad', 'nn_to_rb': 'madly'},
 'madonna': {'n_is_nu': '', 'n_is_sb': '0'},
 'magenta': {'n_is_nu': '', 'n_is_sth': ''},
 'magic': {'n_is_nu': '', 'n_is_sth': ''},
 'magma': {'n_is_nu': '', 'n_is_sth': ''},
 'magnanimity': {'n_is_nu': '', 'n_is_sth': ''},
 'magnesia': {'n_is_nu': '', 'n_is_sth': ''},
 'magnesium': {'n_is_nu': '', 'n_is_sth': ''},
 'magnetics': {'n_is_nu': '', 'n_is_sth': ''},
 'magnetism': {'n_is_nu': '', 'n_is_sth': ''},
 'magnetite': {'n_is_nu': '', 'n_is_sth': ''},
 'magnificence': {'n_is_nu': '', 'n_is_sth': ''},
 'mahjong': {'n_is_nu': '', 'n_is_sth': ''},
 'mainstay': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'maintenance': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'maintain', 'nn_to_jj': 'maintained'},
 'maitreya': {'n_is_nu': '', 'n_is_sb': '0'},
 'maize': {'n_is_nu': '', 'n_is_sth': ''},
 'majesty': {'n_is_nu': '', 'n_is_sth': ''},
 'make-up': {'n_is_nu': '', 'n_is_sth': ''},
 'makeup': {'n_is_nu': '', 'n_is_sth': ''},
 'making': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'make', 'vbg_to_vbn': 'made'},
 'malachite': {'n_is_nu': '', 'n_is_sth': ''},
 'malaise': {'n_is_nu': '', 'n_is_sth': ''},
 'malaria': {'n_is_nu': '', 'n_is_sth': ''},
 'malarkey': {'n_is_nu': '', 'n_is_sth': ''},
 'malarky': {'n_is_nu': '', 'n_is_sth': ''},
 'malathion': {'n_is_nu': '', 'n_is_sth': ''},
 'malaya': {'n_is_nu': '', 'n_is_sth': ''},
 'malevolence': {'n_is_nu': '', 'n_is_sth': ''},
 'malfeasance': {'n_is_nu': '', 'n_is_sth': ''},
 'malice': {'n_is_nu': '', 'n_is_sth': ''},
 'malleability': {'n_is_nu': '', 'n_is_sth': ''},
 'malt': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'malthus': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0', 'cap_word': 'Malthus'},
 'maltreatment': {'n_is_nu': '', 'n_is_sth': ''},
 'mammon': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'management': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'manage', 'nn_to_jj': 'managing'},
 'manchuria': {'n_is_nu': '', 'n_is_sth': ''},
 'mandala': {'n_is_nu': '', 'n_is_sth': ''},
 'mandarin': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'manes': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'maneuverability': {'n_is_nu': '', 'n_is_sth': ''},
 'manganese': {'n_is_nu': '', 'n_is_sth': ''},
 'mange': {'n_is_nu': '', 'n_is_sth': ''},
 'mangler': {'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'manhood': {'n_is_nu': '', 'n_is_sth': ''},
 'mania': {'n_is_nu': '', 'n_is_sth': '', 'n_is_nc': ''},
 'manifesto': {'n_is_nu': '', 'n_is_sth': ''},
 'manilla': {'n_is_nu': '', 'n_is_sth': ''},
 'manipulation': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'manipulate', 'nn_to_jj': 'manipulative'},
 'manliness': {'n_is_nu': '', 'n_is_sth': ''},
 'manna': {'n_is_nu': '', 'n_is_sth': ''},
 'manpower': {'n_is_nu': '', 'n_is_sth': ''},
 'manslaughter': {'n_is_nu': '', 'n_is_sth': ''},
 'manure': {'n_is_nu': '', 'n_is_sth': ''},
 'mar': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'marconi': {'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'margarine': {'n_is_nu': '', 'n_is_sth': ''},
 'marge': {'n_is_nu': '', 'n_is_sth': ''},
 'marijuana': {'n_is_nu': '', 'n_is_sth': '0'},
 'marketing': {'n_is_nu': '', 'n_is_sth': ''},
 'marksmanship': {'n_is_nu': '', 'n_is_sth': ''},
 'marmalade': {'n_is_nu': '', 'n_is_sth': ''},
 'maroon': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'mars': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'marseillaise': {'n_is_nu': '', 'n_is_sth': ''},
 'martyrdom': {'n_is_nu': '', 'n_is_sth': ''},
 'marvel': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'marxism-leninism': {'n_is_nu': '', 'n_is_sth': ''},
 'mary': {'n_is_nu': '', 'n_is_sb': '0'},
 'masculine': {'n_is_nu': '', 'n_is_sth': ''},
 'masculinity': {'n_is_nu': '', 'n_is_sth': ''},
 'masking': {'n_is_nu': '', 'n_is_sth': ''},
 'masonite': {'n_is_nu': '', 'n_is_sth': ''},
 'masonry': {'n_is_nu': '', 'n_is_sth': ''},
 'mastery': {'n_is_nu': '', 'n_is_sth': ''},
 'mastic': {'n_is_nu': '', 'n_is_sth': ''},
 'mastication': {'n_is_nu': '', 'n_is_sth': ''},
 'mastitis': {'n_is_nu': '', 'n_is_sth': ''},
 'masturbation': {'n_is_nu': '', 'n_is_sth': ''},
 'materialism': {'n_is_nu': '', 'n_is_sth': ''},
 'materiel': {'n_is_nu': '', 'n_is_sth': ''},
 'mathematics': {'n_is_nu': '', 'n_is_sth': '', 'nc_typical': ''},
 'maths': {'n_is_nu': '', 'n_is_sth': '', 'nc_typical': ''},
 'matrimony': {'n_is_nu': '', 'n_is_sth': ''},
 'matting': {'n_is_nu': '', 'n_is_sth': ''},
 'maturation': {'n_is_nu': '', 'n_is_sth': ''},
 'maturity': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'mature', 'nn_to_jj': 'mature', 'nn_to_rb': 'maturely'},
 'mauler': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'mayflower': {'n_is_nu': '', 'n_is_sth': ''},
 'mayhem': {'n_is_nu': '', 'n_is_sth': ''},
 'meanness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'mean', 'nn_to_jj': 'mean', 'nn_to_rb': 'meanly'},
 'meantime': {'n_is_nu': '', 'n_is_sth': ''},
 'measles': {'n_is_nu': '', 'n_is_sth': ''},
 'mechanics': {'n_is_nu': '', 'n_is_sth': ''},
 'mechanization': {'n_is_nu': '', 'n_is_sth': ''},
 'mediation': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'mediate', 'nn_to_jj': 'mediate'},
 'mediocrity': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'meditation': {'n_is_nu': '', 'n_is_sth': ''},
 'meekness': {'n_is_nu': '', 'n_is_sth': ''},
 'megalomania': {'n_is_nu': '', 'n_is_sth': ''},
 'mei': {'n_is_nu': '', 'n_is_sth': ''},
 'mekong': {'n_is_nu': '', 'n_is_sth': ''},
 'melancholy': {'n_is_nu': '', 'n_is_sth': ''},
 'melanin': {'n_is_nu': '', 'n_is_sth': ''},
 'memorization': {'n_is_nu': '', 'n_is_sth': ''},
 'menarche': {'n_is_nu': '', 'n_is_sth': ''},
 'mendacity': {'n_is_nu': '', 'n_is_sth': ''},
 'mending': {'n_is_nu': '', 'n_is_sth': ''},
 'meningitis': {'n_is_nu': '', 'n_is_sth': ''},
 'menopause': {'n_is_nu': '', 'n_is_sth': ''},
 'menthol': {'n_is_nu': '', 'n_is_sth': ''},
 'meow': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'merchandise': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'mercury': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'merriment': {'n_is_nu': '', 'n_is_sth': ''},
 'merrymaking': {'n_is_nu': '', 'n_is_sth': ''},
 'merton': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'mesopotamia': {'n_is_nu': '', 'n_is_sth': ''},
 'messiness': {'n_is_nu': '', 'n_is_sth': ''},
 'metallurgy': {'n_is_nu': '', 'n_is_sth': ''},
 'metalworking': {'n_is_nu': '', 'n_is_sth': ''},
 'metamorphosis': {'n_is_nu': '', 'n_is_sth': ''},
 'metaphysics': {'n_is_nu': '', 'n_is_sth': ''},
 'meteorology': {'n_is_nu': '', 'n_is_sth': ''},
 'methane': {'n_is_nu': '', 'n_is_sth': ''},
 'methanol': {'n_is_nu': '', 'n_is_sth': ''},
 'methodism': {'n_is_nu': '', 'n_is_sth': ''},
 'methyl': {'n_is_nu': '', 'n_is_sth': ''},
 'metis': {'n_is_nu': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'metric': {'n_is_nu': '', 'n_is_sth': ''},
 'metrics': {'n_is_nu': '', 'n_is_sth': ''},
 'mettle': {'n_is_nu': '', 'n_is_sth': ''},
 'mi': {'n_is_nu': '', 'n_is_sth': ''},
 'miami': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'mica': {'n_is_nu': '', 'n_is_sth': ''},
 'mickey': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'microbiology': {'n_is_nu': '', 'n_is_sth': ''},
 'microelectronics': {'n_is_nu': '', 'n_is_sth': ''},
 'midair': {'n_is_nu': '', 'n_is_sth': ''},
 'midbrain': {'n_is_nu': '', 'n_is_sth': ''},
 'midday': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'mideast': {'n_is_nu': '', 'n_is_sth': ''},
 'midnight': {'n_is_nu': '', 'nu_typical': ''},
 'midstream': {'n_is_nu': '', 'n_is_sth': ''},
 'midsummer': {'n_is_nu': '', 'n_is_sth': ''},
 'midweek': {'n_is_nu': '', 'n_is_sth': ''},
 'midwifery': {'n_is_nu': '', 'n_is_sth': ''},
 'midwinter': {'n_is_nu': '', 'n_is_sth': ''},
 'might': {'n_is_nu': '', 'n_is_sth': ''},
 'milan': {'n_is_nu': '', 'n_is_sth': ''},
 'mildew': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'mildness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'mild', 'nn_to_rb': 'mildly'},
 'militancy': {'n_is_nu': '', 'n_is_sth': ''},
 'militarism': {'n_is_nu': '', 'n_is_sth': ''},
 'militarization': {'n_is_nu': '', 'n_is_sth': ''},
 'military': {'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'millet': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'milling': {'n_is_nu': '', 'n_is_sth': ''},
 'milt': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'mimicry': {'n_is_nu': '', 'n_is_sth': ''},
 'mimosa': {'n_is_nu': '', 'n_is_sth': ''},
 'mineralogy': {'n_is_nu': '', 'n_is_sth': ''},
 'miniaturization': {'n_is_nu': '', 'n_is_sth': ''},
 'mining': {'n_is_nu': '', 'n_is_sth': ''},
 'minium': {'n_is_nu': '', 'n_is_sth': ''},
 'minstrelsy': {'n_is_nu': '', 'n_is_sth': ''},
 'mire': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'mirth': {'n_is_nu': '', 'n_is_sth': ''},
 'misanthropy': {'n_is_nu': '', 'n_is_sth': ''},
 'misapplication': {'n_is_nu': '', 'n_is_sth': ''},
 'miscegenation': {'n_is_nu': '', 'n_is_sth': ''},
 'miserliness': {'n_is_nu': '', 'n_is_sth': ''},
 'misfeasance': {'n_is_nu': '', 'n_is_sth': ''},
 'misgiving': {'n_is_nu': '', 'n_is_sth': ''},
 'mishmash': {'n_is_nu': '', 'n_is_sth': ''},
 'misinformation': {'n_is_nu': '', 'n_is_sth': ''},
 'misplacement': {'n_is_nu': '', 'n_is_sth': ''},
 'misrepresentation': {'n_is_nu': '', 'n_is_sth': ''},
 'misrule': {'n_is_nu': '', 'n_is_sth': ''},
 'mister': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'mistletoe': {'n_is_nu': '', 'n_is_sth': ''},
 'mistrust': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'mitigation': {'n_is_nu': '', 'n_is_sth': ''},
 'mix-up': {'n_is_nu': '', 'n_is_sth': ''},
 'mo': {'n_is_nu': '', 'n_is_sth': ''},
 'mobility': {'n_is_nu': '', 'n_is_sth': ''},
 'mobilization': {'n_is_nu': '', 'n_is_sth': ''},
 'mockery': {'n_is_nu': '', 'n_is_sth': ''},
 'modality': {'n_is_nu': '', 'n_is_sth': ''},
 'modeling': {'n_is_nu': '', 'n_is_sth': ''},
 'moderation': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'moderate', 'nn_to_jj': 'moderate'},
 'modernity': {'n_is_nu': '', 'n_is_sth': ''},
 'modernization': {'n_is_nu': '', 'n_is_sth': ''},
 'modesty': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'modest', 'nn_to_rb': 'modestly'},
 'modicum': {'n_is_nu': '', 'n_is_sth': ''},
 'mohair': {'n_is_nu': '', 'n_is_sth': ''},
 'moire': {'n_is_nu': '', 'n_is_sth': ''},
 'moistness': {'n_is_nu': '', 'n_is_sth': ''},
 'moisture': {'n_is_nu': '', 'n_is_sth': ''},
 'molasses': {'n_is_nu': '', 'n_is_sth': ''},
 'moldavia': {'n_is_nu': '', 'n_is_sth': ''},
 'molding': {'n_is_nu': '', 'n_is_sth': ''},
 'molestation': {'n_is_nu': '', 'n_is_sth': ''},
 'molt': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'molybdenum': {'n_is_nu': '', 'n_is_sth': ''},
 'momentum': {'n_is_nu': '', 'n_is_sth': ''},
 'monarchy': {'n_is_nu': '', 'n_is_sth': '', 'n_is_nc': ''},
 'monastery': {'n_is_nu': '', 'n_is_sth': '', 'n_is_nc': ''},
 'monastic': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'monasticism': {'n_is_nu': '', 'n_is_sth': ''},
 'money': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'monopolization': {'n_is_nu': '', 'n_is_sth': ''},
 'monotheism': {'n_is_nu': '', 'n_is_sth': ''},
 'monotony': {'n_is_nu': '', 'n_is_sth': ''},
 'moodiness': {'n_is_nu': '', 'n_is_sth': ''},
 'moolah': {'n_is_nu': '', 'n_is_sth': ''},
 'moonlight': {'n_is_nu': '', 'n_is_sth': ''},
 'moonshine': {'n_is_nu': '', 'n_is_sth': ''},
 'moorland': {'n_is_nu': '', 'n_is_sth': ''},
 'morale': {'n_is_nu': '', 'n_is_sth': ''},
 'moralism': {'n_is_nu': '', 'n_is_sth': ''},
 'morality': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'moral', 'nn_to_rb': 'morally'},
 'moravia': {'n_is_nu': '', 'n_is_sth': ''},
 'morbidity': {'n_is_nu': '', 'n_is_sth': ''},
 'morgan': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'mormonism': {'n_is_nu': '', 'n_is_sth': ''},
 'morphine': {'n_is_nu': '', 'n_is_sth': ''},
 'motherhood': {'n_is_nu': '', 'n_is_sth': ''},
 'motility': {'n_is_nu': '', 'n_is_sth': ''},
 'mould': {'n_is_nu': '', 'n_is_sth': ''},
 'mountaineering': {'n_is_nu': '', 'n_is_sth': ''},
 'mountebank': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'moxie': {'n_is_nu': '', 'n_is_sth': ''},
 'mozart': {'n_is_nu': '', 'n_is_sb': '0', 'cap_word': 'Mozart'},
 'mph': {'n_is_nu': '', 'n_is_sth': ''},
 'ms': {'n_is_nu': '', 'n_is_sth': ''},
 'mu': {'n_is_nu': '', 'n_is_sth': '', 'n_is_unit': ''},
 'muck': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'mucus': {'n_is_nu': '', 'n_is_sth': ''},
 'multiplication': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'multiply', 'nn_to_jj': 'multiply', 'nn_to_rb': 'multiply'},
 'multiplicity': {'n_is_nu': '', 'n_is_sth': ''},
 'multitude': {'n_is_nu': '', 'n_is_sth': '', 'n_of_nns': ''},
 'mum': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0', 'nc_typical': ''},
 'mumps': {'n_is_nu': '', 'n_is_sth': ''},
 'mung': {'n_is_nu': '', 'n_is_sth': ''},
 'munich': {'n_is_nu': '', 'n_is_sth': ''},
 'munificence': {'n_is_nu': '', 'n_is_sth': ''},
 'murray': {'n_is_nu': '', 'n_is_sb': '0'},
 'muscovy': {'n_is_nu': '', 'n_is_sth': ''},
 'music': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'musical', 'nn_to_rb': 'musically', 'nu_typical': ''},
 'musk': {'n_is_nu': '', 'n_is_sth': ''},
 'muslin': {'n_is_nu': '', 'n_is_sth': ''},
 'muss': {'n_is_nu': '', 'n_is_sth': ''},
 'mussolini': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'mustache': {'n_is_nu': '', 'n_is_sth': '', 'n_is_nc': ''},
 'mustard': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'mustiness': {'n_is_nu': '', 'n_is_sth': ''},
 'mutability': {'n_is_nu': '', 'n_is_sth': ''},
 'mutton': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'mutuality': {'n_is_nu': '', 'n_is_sth': ''},
 'mynah': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'myocarditis': {'n_is_nu': '', 'n_is_sth': ''},
 'myopia': {'n_is_nu': '', 'n_is_sth': ''},
 'myrrh': {'n_is_nu': '', 'n_is_sth': ''},
 'mysticism': {'n_is_nu': '', 'n_is_sth': ''},
 'mystification': {'n_is_nu': '', 'n_is_sth': ''},
 'mystique': {'n_is_nu': '', 'n_is_sth': ''},
 'nagasaki': {'n_is_nu': '', 'n_is_sth': ''},
 'nailhead': {'n_is_nu': '', 'n_is_sth': ''},
 'naivete': {'n_is_nu': '', 'n_is_sth': ''},
 'nakedness': {'n_is_nu': '', 'n_is_sth': ''},
 'nanchang': {'n_is_nu': '', 'n_is_sth': ''},
 'nanjing': {'n_is_nu': '', 'n_is_sth': ''},
 'nanking': {'n_is_nu': '', 'n_is_sth': ''},
 'nanning': {'n_is_nu': '', 'n_is_sth': ''},
 'naphtha': {'n_is_nu': '', 'n_is_sth': ''},
 'nara': {'n_is_nu': '', 'n_is_sth': ''},
 'narcissism': {'n_is_nu': '', 'n_is_sth': ''},
 'narrowness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'narrow', 'nn_to_jj': 'narrow', 'nn_to_rb': 'narrowly'},
 'nastiness': {'n_is_nu': '', 'n_is_sth': ''},
 'nationalism': {'n_is_nu': '', 'n_is_sth': ''},
 'nationality': {'n_is_nu': '', 'n_is_sth': '', 'n_is_nc': ''},
 'naturalism': {'n_is_nu': '', 'n_is_sth': ''},
 'naturalization': {'n_is_nu': '', 'n_is_sth': ''},
 'naturalness': {'n_is_nu': '', 'n_is_sth': ''},
 'naughtiness': {'n_is_nu': '', 'n_is_sth': ''},
 'nausea': {'n_is_nu': '', 'n_is_sth': ''},
 'navigation': {'n_is_nu': '', 'n_is_sth': ''},
 'nearsightedness': {'n_is_nu': '', 'n_is_sth': ''},
 'neatness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'neat', 'nn_to_rb': 'neatly'},
 'necking': {'n_is_nu': '', 'n_is_sth': ''},
 'necromancy': {'n_is_nu': '', 'n_is_sth': ''},
 'nectar': {'n_is_nu': '', 'n_is_sth': ''},
 'neediness': {'n_is_nu': '', 'n_is_sth': ''},
 'needlepoint': {'n_is_nu': '', 'n_is_sth': ''},
 'needlework': {'n_is_nu': '', 'n_is_sth': ''},
 'negation': {'n_is_nu': '', 'n_is_sth': ''},
 'negativity': {'n_is_nu': '', 'n_is_sth': ''},
 'neglect': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'neglected', 'v_vbg': '', 'v_to_vb': '', 'v_n': '', 'vb_to_jj': 'neglected', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'negligence': {'n_is_nu': '', 'n_is_sth': ''},
 'neighborliness': {'n_is_nu': '', 'n_is_sth': ''},
 'neodymium': {'n_is_nu': '', 'n_is_sth': ''},
 'neon': {'n_is_nu': '', 'n_is_sth': ''},
 'neoprene': {'n_is_nu': '', 'n_is_sth': ''},
 'nepotism': {'n_is_nu': '', 'n_is_sth': ''},
 'neptune': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'nervousness': {'n_is_nu': '', 'n_is_sth': ''},
 'netting': {'n_is_nu': '', 'n_is_sth': ''},
 'neuralgia': {'n_is_nu': '', 'n_is_sth': ''},
 'neurasthenia': {'n_is_nu': '', 'n_is_sth': ''},
 'neuropathy': {'n_is_nu': '', 'n_is_sth': ''},
 'neuroticism': {'n_is_nu': '', 'n_is_sth': ''},
 'neuter': {'n_is_nu': '', 'n_is_sth': ''},
 'neutrality': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'neutralize', 'nn_to_jj': 'neutral'},
 'neutralization': {'n_is_nu': '', 'n_is_sth': ''},
 'newness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'new', 'nn_to_rb': 'newly'},
 'news': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'newton': {'n_is_nu': '', 'n_is_sb': '0'},
 'ni': {'n_is_nu': '', 'n_is_sth': ''},
 'niacin': {'n_is_nu': '', 'n_is_sth': ''},
 'niagara': {'n_is_nu': '', 'n_is_sth': ''},
 'nicotiana': {'n_is_nu': '', 'n_is_sth': ''},
 'nicotine': {'n_is_nu': '', 'n_is_sth': ''},
 'nightclub': {'n_is_nu': '', 'n_is_sth': ''},
 'nightfall': {'n_is_nu': '', 'n_is_sth': ''},
 'nightshade': {'n_is_nu': '', 'n_is_sth': ''},
 'nighttime': {'n_is_nu': '', 'n_is_sth': ''},
 'nightwear': {'n_is_nu': '', 'n_is_sth': ''},
 'nihilism': {'n_is_nu': '', 'n_is_sth': ''},
 'nil': {'n_is_nu': '', 'n_is_sth': ''},
 'nile': {'n_is_nu': '', 'n_is_sth': ''},
 'nine': {'n_is_nu': '', 'n_is_sth': ''},
 'nirvana': {'n_is_nu': '', 'n_is_sth': ''},
 'nitrate': {'n_is_nu': '', 'n_is_sth': ''},
 'nitrogen': {'n_is_nu': '', 'n_is_sth': ''},
 'nitroglycerin': {'n_is_nu': '', 'n_is_sth': ''},
 'nitroglycerine': {'n_is_nu': '', 'n_is_sth': ''},
 'nitty-gritty': {'n_is_nu': '', 'n_is_sth': ''},
 'nix': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'nixon': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'nobility': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'noble', 'nn_to_jj': 'noble', 'nn_to_rb': 'nobly', 'n_is_collective': ''},
 'noblesse': {'n_is_nu': '', 'n_is_sth': ''},
 'noel': {'n_is_nu': '', 'n_is_sth': ''},
 'noisiness': {'n_is_nu': '', 'n_is_sth': ''},
 'noma': {'n_is_nu': '', 'n_is_sth': ''},
 'nome': {'n_is_nu': '', 'n_is_sth': ''},
 'nomenclature': {'n_is_nu': '', 'n_is_sth': ''},
 'nonalignment': {'n_is_nu': '', 'n_is_sth': ''},
 'nonce': {'n_is_nu': '', 'n_is_sth': ''},
 'nonchalance': {'n_is_nu': '', 'n_is_sth': ''},
 'noncompliance': {'n_is_nu': '', 'n_is_sth': ''},
 'nonfeasance': {'n_is_nu': '', 'n_is_sth': ''},
 'noninterference': {'n_is_nu': '', 'n_is_sth': ''},
 'nonmetal': {'n_is_nu': '', 'n_is_sth': ''},
 'nonviolence': {'n_is_nu': '', 'n_is_sth': ''},
 'noon': {'n_is_nu': '', 'n_is_sth': ''},
 'noonday': {'n_is_nu': '', 'n_is_sth': ''},
 'normalcy': {'n_is_nu': '', 'n_is_sth': ''},
 'normality': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'normalize', 'nn_to_jj': 'normal', 'nn_to_rb': 'normally'},
 'normalization': {'n_is_nu': '', 'n_is_sth': ''},
 'north': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'northwest': {'n_is_nu': '', 'n_is_sth': ''},
 'nosh': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'nostalgia': {'n_is_nu': '', 'n_is_sth': ''},
 'notepaper': {'n_is_nu': '', 'n_is_sth': ''},
 'nothingness': {'n_is_nu': '', 'n_is_sth': ''},
 'notoriety': {'n_is_nu': '', 'n_is_sth': ''},
 'nourishment': {'n_is_nu': '', 'n_is_sth': ''},
 'nous': {'n_is_nu': '', 'n_is_sth': ''},
 'nudity': {'n_is_nu': '', 'n_is_sth': ''},
 'nullification': {'n_is_nu': '', 'n_is_sth': ''},
 'nullity': {'n_is_nu': '', 'n_is_sth': ''},
 'numbness': {'n_is_nu': '', 'n_is_sth': ''},
 'nursery': {'n_is_nu': '', 'n_is_sth': '', 'nc_typical': ''},
 'nursing': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'nurturance': {'n_is_nu': '', 'n_is_sth': ''},
 'nurture': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'nutrition': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'nylon': {'n_is_nu': '', 'n_is_sth': ''},
 'nymphomania': {'n_is_nu': '', 'n_is_sb': '0'},
 'oatmeal': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ob': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'obduracy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'obedience': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'obey', 'nn_to_jj': 'obedient', 'nn_to_rb': 'obediently'},
 'obeisance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'obesity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'obfuscation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'obliqueness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'obliteration': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'oblivion': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'obloquy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'obscurantism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'obscurity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'obsequiousness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'observance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'obsolescence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'obstetrics': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'obstinacy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'obtuseness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'occident': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'occultism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'occupancy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'occurrence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'occur', 'nn_to_jj': 'occurent', 'n_is_nc': ''},
 'oceanography': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ocher': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ochre': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'oct': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'oddness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'odessa': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'odium': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'odor': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'offal': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'officialdom': {'n_is_nu': '', 'n_is_sb': '2', 'art_an': '', 'nn_to_jj': 'official', 'nn_to_rb': 'officially', 'n_is_sth': '2'},
 'offing': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'offset': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'v_infcl_non': '', 'vbd_eq_vbn': ''},
 'offside': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'oiliness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_jj': 'oiled', 'nn_to_rb': 'oily'},
 'ok': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'olefin': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'olfaction': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'olivine': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'olympics': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'olympus': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'omega': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'omnipotence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'omnipresence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'omniscience': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'oncoming': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'one-step': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'oneness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'onomatopoeia': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ontogeny': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ontology': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'onus': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'oolong': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'oomph': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ooze': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'opacity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'opal': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'opec': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'openness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'open', 'nn_to_jj': 'open', 'nn_to_rb': 'openly'},
 'ophthalmology': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'opportunism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'oppression': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'oppressiveness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'opprobrium': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'optics': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'optimism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'optimization': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_nc': ''},
 'optometry': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'opulence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'orang': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '3'},
 'orderliness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ordnance': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ordure': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'organdy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'organism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'orgy': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'orient': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vb_to_rb': 'originally', 'vb_to_nn': 'orientation', 'vb_to_jj': 'orientational', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'originality': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'origination': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'orion': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'ornamentation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ornithology': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'orphanage': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'orthography': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'orthopedics': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'oscar': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'osmium': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'osmosis': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ostentation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'osteomyelitis': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ostracism': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'otherness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'otherworldliness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'otolaryngology': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'outback': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'outdoors': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'rb_to_jj': 'outdoor'},
 'outerwear': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'outreach': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'outset': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'outsize': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'overburden': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'overconfidence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'overflight': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'overindulgence': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'overkill': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'overproduction': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'overskirt': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'overtime': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'overuse': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'overweight': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'overwork': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ovulation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ownership': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'own', 'nn_to_jj': 'own', 'nu_typical': ''},
 'oxalate': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'oxidation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'oxygen': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nu_typical': ''},
 'oxygenation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'oxytocin': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ozone': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'pabulum': {'n_is_nu': '', 'n_is_sth': ''},
 'pacification': {'n_is_nu': '', 'n_is_sth': ''},
 'pacifism': {'n_is_nu': '', 'n_is_sth': ''},
 'packaging': {'n_is_nu': '', 'n_is_sth': ''},
 'packing': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'pack', 'vbg_to_vbn': 'packed'},
 'paganism': {'n_is_nu': '', 'n_is_sth': ''},
 'pageantry': {'n_is_nu': '', 'n_is_sth': ''},
 'pagination': {'n_is_nu': '', 'n_is_sth': ''},
 'paint': {'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'paints', 'vb_to_vbd': 'painted', 'vb_to_vbn': 'painted', 'vb_to_vbg': 'painting', 'vt_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'palaver': {'n_is_nu': '', 'n_is_sth': ''},
 'paleness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'pale', 'nn_to_jj': 'pale', 'nn_to_rb': 'palely'},
 'paleobiology': {'n_is_nu': '', 'n_is_sth': ''},
 'paleontology': {'n_is_nu': '', 'n_is_sth': ''},
 'pali': {'n_is_nu': '', 'n_is_sth': ''},
 'palladium': {'n_is_nu': '', 'n_is_sth': ''},
 'pallor': {'n_is_nu': '', 'n_is_sth': ''},
 'palsy': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'panache': {'n_is_nu': '', 'n_is_sth': ''},
 'panegyric': {'n_is_nu': '', 'n_is_sth': ''},
 'pang': {'n_is_nu': '', 'n_is_sth': ''},
 'pantheism': {'n_is_nu': '', 'n_is_sth': ''},
 'pap': {'n_is_nu': '', 'n_is_sth': ''},
 'paperboard': {'n_is_nu': '', 'n_is_sth': ''},
 'papermaking': {'n_is_nu': '', 'n_is_sth': ''},
 'paprika': {'n_is_nu': '', 'n_is_sth': ''},
 'par': {'n_is_nu': '', 'n_is_sth': ''},
 'paradise': {'n_is_nu': '', 'n_is_sth': '', 'n_is_nc': ''},
 'paraffin': {'n_is_nu': '', 'n_is_sth': ''},
 'paraphernalia': {'n_is_nu': '', 'n_is_sth': ''},
 'paraplegia': {'n_is_nu': '', 'n_is_sth': ''},
 'parasitism': {'n_is_nu': '', 'n_is_sth': ''},
 'parenthood': {'n_is_nu': '', 'n_is_sth': ''},
 'parity': {'n_is_nu': '', 'n_is_sth': ''},
 'parking': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'park', 'vbg_to_vbn': 'parked', 'nu_typical': ''},
 'parlance': {'n_is_nu': '', 'n_is_sth': ''},
 'parnassus': {'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'parsimony': {'n_is_nu': '', 'n_is_sth': ''},
 'parthenogenesis': {'n_is_nu': '', 'n_is_sth': ''},
 'partiality': {'n_is_nu': '', 'n_is_sth': ''},
 'participation': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'participate', 'nn_to_jj': 'participatory'},
 'partisanship': {'n_is_nu': '', 'n_is_sth': ''},
 'partizan': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'passing': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vbn': 'passed', 'vbg_to_vb': 'pass'},
 'passivity': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'passive', 'nn_to_rb': 'passively'},
 'pastime': {'n_is_nu': '', 'n_is_sth': ''},
 'pastureland': {'n_is_nu': '', 'n_is_sth': ''},
 'paternity': {'n_is_nu': '', 'n_is_sth': ''},
 'pathogenesis': {'n_is_nu': '', 'n_is_sth': ''},
 'pathology': {'n_is_nu': '', 'n_is_sth': ''},
 'pathos': {'n_is_nu': '', 'n_is_sth': ''},
 'patience': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'patient', 'nn_to_rb': 'patiently', 'nu_typical': ''},
 'patina': {'n_is_nu': '', 'n_is_sth': ''},
 'patrimony': {'n_is_nu': '', 'n_is_sth': ''},
 'patriotism': {'n_is_nu': '', 'n_is_sth': ''},
 'patronage': {'n_is_nu': '', 'n_is_sth': ''},
 'patter': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'paucity': {'n_is_nu': '', 'n_is_sth': ''},
 'paul': {'n_is_nu': '', 'n_is_sb': '0'},
 'pavlov': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'pax': {'n_is_nu': '', 'n_is_sth': ''},
 'pay': {'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_for': '', 'vb_to_vbz': 'pays', 'vb_to_vbd': 'paid', 'vb_to_vbn': 'paid', 'vb_to_vbg': 'paying', 'v_compcl_non': '', 'nu_typical': ''},
 'paycheck': {'n_is_nu': '', 'n_is_sth': ''},
 'payola': {'n_is_nu': '', 'n_is_sth': ''},
 'peace': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'peaceful', 'nn_to_rb': 'peacefully', 'nu_typical': ''},
 'peasantry': {'n_is_nu': '', 'n_is_sb': '0'},
 'peat': {'n_is_nu': '', 'n_is_sth': ''},
 'peckerwood': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'pectin': {'n_is_nu': '', 'n_is_sth': ''},
 'pedagogy': {'n_is_nu': '', 'n_is_sth': ''},
 'pedantry': {'n_is_nu': '', 'n_is_sth': ''},
 'pederasty': {'n_is_nu': '', 'n_is_sth': ''},
 'pediatrics': {'n_is_nu': '', 'n_is_sth': ''},
 'pee': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'peeling': {'n_is_nu': '', 'n_is_sth': ''},
 'peking': {'n_is_nu': '', 'n_is_sth': ''},
 'pelargonium': {'n_is_nu': '', 'n_is_sth': ''},
 'pemmican': {'n_is_nu': '', 'n_is_sth': ''},
 'penicillin': {'n_is_nu': '', 'n_is_sth': ''},
 'penitence': {'n_is_nu': '', 'n_is_sth': ''},
 'penmanship': {'n_is_nu': '', 'n_is_sth': ''},
 'penology': {'n_is_nu': '', 'n_is_sth': ''},
 'pentecost': {'n_is_nu': '', 'n_is_sth': ''},
 'penury': {'n_is_nu': '', 'n_is_sth': ''},
 'pep': {'n_is_nu': '', 'n_is_sth': ''},
 'peptide': {'n_is_nu': '', 'n_is_sth': ''},
 'percussion': {'n_is_nu': '', 'n_is_sth': ''},
 'perdition': {'n_is_nu': '', 'n_is_sth': ''},
 'perfection': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'perfect', 'nn_to_rb': 'perfectly'},
 'perfidy': {'n_is_nu': '', 'n_is_sth': ''},
 'perfume': {'n_is_nu': '', 'n_is_sth': ''},
 'perfusion': {'n_is_nu': '', 'n_is_sth': ''},
 'peridot': {'n_is_nu': '', 'n_is_sth': ''},
 'perilla': {'n_is_nu': '', 'n_is_sth': ''},
 'periodicity': {'n_is_nu': '', 'n_is_sth': ''},
 'periodontitis': {'n_is_nu': '', 'n_is_sth': ''},
 'peristalsis': {'n_is_nu': '', 'n_is_sth': ''},
 'peritonitis': {'n_is_nu': '', 'n_is_sth': ''},
 'perjury': {'n_is_nu': '', 'n_is_sth': ''},
 'permanence': {'n_is_nu': '', 'n_is_sth': ''},
 'permeability': {'n_is_nu': '', 'n_is_sth': ''},
 'permissibility': {'n_is_nu': '', 'n_is_sth': ''},
 'peroxide': {'n_is_nu': '', 'n_is_sth': ''},
 'perpetration': {'n_is_nu': '', 'n_is_sth': ''},
 'perpetuity': {'n_is_nu': '', 'n_is_sth': ''},
 'perseverance': {'n_is_nu': '', 'n_is_sth': ''},
 'persia': {'n_is_nu': '', 'n_is_sth': ''},
 'persistence': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'persist', 'nn_to_jj': 'persistent', 'nn_to_rb': 'persistently'},
 'perspicacity': {'n_is_nu': '', 'n_is_sth': ''},
 'perspiration': {'n_is_nu': '', 'n_is_sth': ''},
 'persuasiveness': {'n_is_nu': '', 'n_is_sth': ''},
 'pertinence': {'n_is_nu': '', 'n_is_sth': ''},
 'pertussis': {'n_is_nu': '', 'n_is_sth': ''},
 'perversion': {'n_is_nu': '', 'n_is_sth': ''},
 'perversity': {'n_is_nu': '', 'n_is_sth': ''},
 'pessimism': {'n_is_nu': '', 'n_is_sth': ''},
 'pestis': {'n_is_nu': '', 'n_is_sth': ''},
 'petrol': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'petroleum': {'n_is_nu': '', 'n_is_sth': ''},
 'pettifoggery': {'n_is_nu': '', 'n_is_sth': ''},
 'pettiness': {'n_is_nu': '', 'n_is_sth': ''},
 'petting': {'n_is_nu': '', 'n_is_sth': ''},
 'petulance': {'n_is_nu': '', 'n_is_sth': ''},
 'pewter': {'n_is_nu': '', 'n_is_sth': ''},
 'pharmacology': {'n_is_nu': '', 'n_is_sth': ''},
 'phenobarbital': {'n_is_nu': '', 'n_is_sth': ''},
 'phenol': {'n_is_nu': '', 'n_is_sth': ''},
 'phenolphthalein': {'n_is_nu': '', 'n_is_sth': ''},
 'philanthropy': {'n_is_nu': '', 'n_is_sth': ''},
 'philately': {'n_is_nu': '', 'n_is_sth': ''},
 'philistinism': {'n_is_nu': '', 'n_is_sth': ''},
 'philology': {'n_is_nu': '', 'n_is_sth': ''},
 'phlebitis': {'n_is_nu': '', 'n_is_sth': ''},
 'phlegm': {'n_is_nu': '', 'n_is_sth': ''},
 'phoebus': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'phonetics': {'n_is_nu': '', 'n_is_sth': ''},
 'phonics': {'n_is_nu': '', 'n_is_sth': ''},
 'phosgene': {'n_is_nu': '', 'n_is_sth': ''},
 'phosphor': {'n_is_nu': '', 'n_is_sth': ''},
 'phosphorescence': {'n_is_nu': '', 'n_is_sth': ''},
 'phosphorus': {'n_is_nu': '', 'n_is_sth': ''},
 'photosynthesis': {'n_is_nu': '', 'n_is_sth': ''},
 'phraseology': {'n_is_nu': '', 'n_is_sth': ''},
 'phrasing': {'n_is_nu': '', 'n_is_sth': ''},
 'phylogeny': {'n_is_nu': '', 'n_is_sth': ''},
 'physics': {'n_is_nu': '', 'n_is_sth': '', 'nn_eq_nns': '', 'nu_typical': ''},
 'physiology': {'n_is_nu': '', 'n_is_sth': ''},
 'physiotherapy': {'n_is_nu': '', 'n_is_sth': ''},
 'pi': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'picasso': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'piffle': {'n_is_nu': '', 'n_is_sth': ''},
 'pigheadedness': {'n_is_nu': '', 'n_is_sth': ''},
 'pigment': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'pigmentation': {'n_is_nu': '', 'n_is_sth': ''},
 'pigskin': {'n_is_nu': '', 'n_is_sth': ''},
 'pilferage': {'n_is_nu': '', 'n_is_sth': ''},
 'pillage': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'pinchbeck': {'n_is_nu': '', 'n_is_sth': ''},
 'ping-pong': {'n_is_nu': '', 'n_is_sth': ''},
 'pinion': {'n_is_nu': '', 'n_is_sth': ''},
 'pinkeye': {'n_is_nu': '', 'n_is_sth': ''},
 'piping': {'n_is_nu': '', 'n_is_sth': ''},
 'piquancy': {'n_is_nu': '', 'n_is_sth': ''},
 'pique': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'piracy': {'n_is_nu': '', 'n_is_sth': ''},
 'pisa': {'n_is_nu': '', 'n_is_sth': ''},
 'piss': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'pitching': {'n_is_nu': '', 'n_is_sth': ''},
 'pith': {'n_is_nu': '', 'n_is_sth': ''},
 'pitter-patter': {'n_is_nu': '', 'n_is_sth': ''},
 'pittsburgh': {'n_is_nu': '', 'n_is_sth': ''},
 'pity': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'n_is_nc': ''},
 'pizzazz': {'n_is_nu': '', 'n_is_sth': ''},
 'placidity': {'n_is_nu': '', 'n_is_sth': ''},
 'plagiarism': {'n_is_nu': '', 'n_is_sth': ''},
 'planking': {'n_is_nu': '', 'n_is_sth': ''},
 'plankton': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'planning': {'n_is_nu': '', 'n_is_sth': ''},
 'planting': {'n_is_nu': '', 'n_is_sth': ''},
 'plasma': {'n_is_nu': '', 'n_is_sth': ''},
 'plaster': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'plastering': {'n_is_nu': '', 'n_is_sth': ''},
 'plasticine': {'n_is_nu': '', 'n_is_sth': ''},
 'plasticity': {'n_is_nu': '', 'n_is_sth': ''},
 'plating': {'n_is_nu': '', 'n_is_sth': ''},
 'platinum': {'n_is_nu': '', 'n_is_sth': ''},
 'plato': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'playacting': {'n_is_nu': '', 'n_is_sth': ''},
 'playfulness': {'n_is_nu': '', 'n_is_sth': ''},
 'pleading': {'n_is_nu': '', 'n_is_sth': ''},
 'pleasantry': {'n_is_nu': '', 'n_is_sth': ''},
 'plenitude': {'n_is_nu': '', 'n_is_sth': ''},
 'plenty': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'pleurisy': {'n_is_nu': '', 'n_is_sth': ''},
 'plexiglass': {'n_is_nu': '', 'n_is_sth': ''},
 'pliability': {'n_is_nu': '', 'n_is_sth': ''},
 'plumbago': {'n_is_nu': '', 'n_is_sth': ''},
 'plunder': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'pluralism': {'n_is_nu': '', 'n_is_sth': ''},
 'plush': {'n_is_nu': '', 'n_is_sth': '', 'jj_to_jjr': 'plusher', 'jj_to_jjs': 'plushest'},
 'plutonium': {'n_is_nu': '', 'n_is_sth': ''},
 'ply': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'plywood': {'n_is_nu': '', 'n_is_sth': ''},
 'pneumonia': {'n_is_nu': '', 'n_is_sth': ''},
 'po': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'poesy': {'n_is_nu': '', 'n_is_sth': ''},
 'poetry': {'n_is_nu': '', 'n_is_sth': ''},
 'poignancy': {'n_is_nu': '', 'n_is_sth': ''},
 'pointedness': {'n_is_nu': '', 'n_is_sth': ''},
 'poise': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'polarization': {'n_is_nu': '', 'n_is_sth': ''},
 'polenta': {'n_is_nu': '', 'n_is_sth': ''},
 'polio': {'n_is_nu': '', 'n_is_sth': ''},
 'poliomyelitis': {'n_is_nu': '', 'n_is_sth': ''},
 'politeness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'polite', 'nn_to_rb': 'politely'},
 'politesse': {'n_is_nu': '', 'n_is_sth': ''},
 'politics': {'n_is_nu': '', 'n_is_sth': '', 'nn_eq_nns': ''},
 'pollen': {'n_is_nu': '', 'n_is_sth': ''},
 'pollination': {'n_is_nu': '', 'n_is_sth': ''},
 'pollution': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'polo': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'polonium': {'n_is_nu': '', 'n_is_sth': ''},
 'polyamide': {'n_is_nu': '', 'n_is_sth': ''},
 'polyester': {'n_is_nu': '', 'n_is_sth': ''},
 'polyethylene': {'n_is_nu': '', 'n_is_sth': ''},
 'polygamy': {'n_is_nu': '', 'n_is_sth': ''},
 'polynesia': {'n_is_nu': '', 'n_is_sth': ''},
 'polypropylene': {'n_is_nu': '', 'n_is_sth': ''},
 'polystyrene': {'n_is_nu': '', 'n_is_sth': ''},
 'polytheism': {'n_is_nu': '', 'n_is_sth': ''},
 'polyurethane': {'n_is_nu': '', 'n_is_sth': ''},
 'pomade': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'pomp': {'n_is_nu': '', 'n_is_sth': ''},
 'pomposity': {'n_is_nu': '', 'n_is_sth': ''},
 'ponderousness': {'n_is_nu': '', 'n_is_sth': ''},
 'pone': {'n_is_nu': '', 'n_is_sth': ''},
 'poop': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'popcorn': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'poplin': {'n_is_nu': '', 'n_is_sth': ''},
 'poppycock': {'n_is_nu': '', 'n_is_sth': ''},
 'populace': {'n_is_nu': '', 'n_is_sth': ''},
 'popularity': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'popular', 'nn_to_rb': 'popularly'},
 'popularization': {'n_is_nu': '', 'n_is_sth': ''},
 'populism': {'n_is_nu': '', 'n_is_sth': ''},
 'porcelain': {'n_is_nu': '', 'n_is_sth': ''},
 'pork': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'pornography': {'n_is_nu': '', 'n_is_sth': ''},
 'porosity': {'n_is_nu': '', 'n_is_sth': ''},
 'porphyry': {'n_is_nu': '', 'n_is_sth': ''},
 'porridge': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'portability': {'n_is_nu': '', 'n_is_sth': ''},
 'portsmouth': {'n_is_nu': '', 'n_is_sth': ''},
 'positivism': {'n_is_nu': '', 'n_is_sth': ''},
 'positivity': {'n_is_nu': '', 'n_is_sth': ''},
 'post-mortem': {'n_is_nu': '', 'n_is_sth': ''},
 'postage': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'postulator': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'potage': {'n_is_nu': '', 'n_is_sth': ''},
 'potassium': {'n_is_nu': '', 'n_is_sth': ''},
 'potency': {'n_is_nu': '', 'n_is_sth': ''},
 'potential': {'n_is_nu': '', 'n_is_sth': ''},
 'potlatch': {'n_is_nu': '', 'n_is_sth': ''},
 'potluck': {'n_is_nu': '', 'n_is_sth': ''},
 'potpourri': {'n_is_nu': '', 'n_is_sth': ''},
 'pottage': {'n_is_nu': '', 'n_is_sth': ''},
 'pottery': {'n_is_nu': '', 'n_is_sth': ''},
 'poultry': {'n_is_nu': '', 'n_is_sb': '3', 'n_is_collective': '', 'n_is_sth': '3'},
 'poundage': {'n_is_nu': '', 'n_is_sth': ''},
 'poverty': {'n_is_nu': '', 'n_is_sth': ''},
 'powder': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'powdery', 'vb_to_jj': 'powdery', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'pox': {'n_is_nu': '', 'n_is_sth': ''},
 'pr': {'n_is_nu': '', 'n_is_sth': ''},
 'practicability': {'n_is_nu': '', 'n_is_sth': ''},
 'pragmatism': {'n_is_nu': '', 'n_is_sth': ''},
 'pratfall': {'n_is_nu': '', 'n_is_sth': ''},
 'prattle': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'prc': {'n_is_nu': '', 'n_is_sth': ''},
 'precedence': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'precede', 'nn_to_jj': 'precedent', 'nn_to_rb': 'precedently'},
 'preciseness': {'n_is_nu': '', 'n_is_sth': ''},
 'precision': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'precise', 'nn_to_rb': 'precisely'},
 'precocity': {'n_is_nu': '', 'n_is_sth': ''},
 'predation': {'n_is_nu': '', 'n_is_sth': ''},
 'predestination': {'n_is_nu': '', 'n_is_sth': ''},
 'prednisone': {'n_is_nu': '', 'n_is_sth': ''},
 'predominance': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'predominate', 'nn_to_jj': 'predominant', 'nn_to_rb': 'predominantly'},
 'preeminence': {'n_is_nu': '', 'n_is_sth': ''},
 'preemption': {'n_is_nu': '', 'n_is_sth': ''},
 'prehistory': {'n_is_nu': '', 'n_is_sth': ''},
 'premeditation': {'n_is_nu': '', 'n_is_sth': ''},
 'preparedness': {'n_is_nu': '', 'n_is_sth': ''},
 'preponderance': {'n_is_nu': '', 'n_is_sth': ''},
 'presbyopia': {'n_is_nu': '', 'n_is_sth': ''},
 'prescience': {'n_is_nu': '', 'n_is_sth': ''},
 'presentiment': {'n_is_nu': '', 'n_is_sth': ''},
 'presentment': {'n_is_nu': '', 'n_is_sth': ''},
 'preservation': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'preserve'},
 'prestidigitation': {'n_is_nu': '', 'n_is_sth': ''},
 'prestidigitator': {'n_is_nu': '', 'n_is_sb': '0'},
 'prestige': {'n_is_nu': '', 'n_is_sth': ''},
 'pretense': {'n_is_nu': '', 'n_is_sth': ''},
 'prettiness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'pretty', 'nn_to_rb': 'prettily'},
 'prevalence': {'n_is_nu': '', 'n_is_sth': ''},
 'prevention': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'prevent', 'nn_to_jj': 'preventable'},
 'prey': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'priapism': {'n_is_nu': '', 'n_is_sth': ''},
 'pride': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'primacy': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'prime'},
 'prime': {'n_is_nu': '', 'n_is_sth': '', 'jj_to_nn': 'primer', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'primo': {'n_is_nu': '', 'n_is_sth': ''},
 'princeton': {'n_is_nu': '', 'n_is_sth': ''},
 'privacy': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'private', 'nn_to_rb': 'privately'},
 'privet': {'n_is_nu': '', 'n_is_sth': ''},
 'probability': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'probable', 'nn_to_rb': 'probably'},
 'probation': {'n_is_nu': '', 'n_is_sth': ''},
 'probity': {'n_is_nu': '', 'n_is_sth': ''},
 'processing': {'n_is_nu': '', 'n_is_sth': ''},
 'procrastination': {'n_is_nu': '', 'n_is_sth': ''},
 'procreation': {'n_is_nu': '', 'n_is_sth': ''},
 'procurement': {'n_is_nu': '', 'n_is_sth': ''},
 'produce': {'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'produces', 'vb_to_vbd': 'produced', 'vb_to_vbn': 'produced', 'vb_to_nn': 'producer', 'vb_to_vbg': 'producing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'productivity': {'n_is_nu': '', 'n_is_sth': ''},
 'professionalization': {'n_is_nu': '', 'n_is_sth': ''},
 'proficiency': {'n_is_nu': '', 'n_is_sth': ''},
 'profiling': {'n_is_nu': '', 'n_is_sth': ''},
 'profligacy': {'n_is_nu': '', 'n_is_sth': ''},
 'profusion': {'n_is_nu': '', 'n_is_sth': ''},
 'progesterone': {'n_is_nu': '', 'n_is_sth': ''},
 'progestin': {'n_is_nu': '', 'n_is_sth': ''},
 'programming': {'n_is_nu': '', 'n_is_sth': ''},
 'progression': {'n_is_nu': '', 'n_is_sth': ''},
 'prolapse': {'n_is_nu': '', 'n_is_sth': ''},
 'proliferation': {'n_is_nu': '', 'n_is_sth': ''},
 'prolixity': {'n_is_nu': '', 'n_is_sth': ''},
 'promiscuity': {'n_is_nu': '', 'n_is_sth': ''},
 'promptness': {'n_is_nu': '', 'n_is_sth': ''},
 'promulgation': {'n_is_nu': '', 'n_is_sth': ''},
 'pronation': {'n_is_nu': '', 'n_is_sth': ''},
 'proneness': {'n_is_nu': '', 'n_is_sth': ''},
 'pronunciation': {'n_is_nu': '', 'n_is_sth': ''},
 'propaganda': {'n_is_nu': '', 'n_is_sth': ''},
 'propagation': {'n_is_nu': '', 'n_is_sth': ''},
 'propane': {'n_is_nu': '', 'n_is_sth': ''},
 'propellor': {'n_is_nu': '', 'n_is_sth': ''},
 'propinquity': {'n_is_nu': '', 'n_is_sth': ''},
 'proportionality': {'n_is_nu': '', 'n_is_sth': ''},
 'proprietorship': {'n_is_nu': '', 'n_is_sth': ''},
 'propriety': {'n_is_nu': '', 'n_is_sth': ''},
 'propulsion': {'n_is_nu': '', 'n_is_sth': ''},
 'propylene': {'n_is_nu': '', 'n_is_sth': ''},
 'proscription': {'n_is_nu': '', 'n_is_sth': ''},
 'prose': {'n_is_nu': '', 'n_is_sth': ''},
 'prosody': {'n_is_nu': '', 'n_is_sth': ''},
 'prostitution': {'n_is_nu': '', 'n_is_sth': ''},
 'prostration': {'n_is_nu': '', 'n_is_sth': ''},
 'protease': {'n_is_nu': '', 'n_is_sth': ''},
 'protestantism': {'n_is_nu': '', 'n_is_sth': ''},
 'protoplasm': {'n_is_nu': '', 'n_is_sth': ''},
 'provenance': {'n_is_nu': '', 'n_is_sth': ''},
 'provender': {'n_is_nu': '', 'n_is_sth': ''},
 'provincialism': {'n_is_nu': '', 'n_is_sth': ''},
 'prowess': {'n_is_nu': '', 'n_is_sth': ''},
 'proximity': {'n_is_nu': '', 'n_is_sth': ''},
 'prudence': {'n_is_nu': '', 'n_is_sth': ''},
 'pruning': {'n_is_nu': '', 'n_is_sth': ''},
 'prurience': {'n_is_nu': '', 'n_is_sth': ''},
 'prussia': {'n_is_nu': '', 'n_is_sth': ''},
 'pseudoscience': {'n_is_nu': '', 'n_is_sth': ''},
 'psilocybin': {'n_is_nu': '', 'n_is_sth': ''},
 'psoriasis': {'n_is_nu': '', 'n_is_sth': ''},
 'psychosis': {'n_is_nu': '', 'n_is_sth': ''},
 'puberty': {'n_is_nu': '', 'n_is_sth': ''},
 'pubescence': {'n_is_nu': '', 'n_is_sth': ''},
 'publicity': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'publical', 'nn_to_rb': 'publically', 'attribute': ''},
 'pueblo': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'puffiness': {'n_is_nu': '', 'n_is_sth': ''},
 'pugilism': {'n_is_nu': '', 'n_is_sth': ''},
 'pugnacity': {'n_is_nu': '', 'n_is_sth': ''},
 'puke': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'pulchritude': {'n_is_nu': '', 'n_is_sth': ''},
 'pulp': {'n_is_nu': '', 'n_is_sth': ''},
 'pulverization': {'n_is_nu': '', 'n_is_sth': ''},
 'pumice': {'n_is_nu': '', 'n_is_sth': ''},
 'punctuality': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'punctual', 'nn_to_rb': 'punctually'},
 'pungency': {'n_is_nu': '', 'n_is_sth': ''},
 'puppetry': {'n_is_nu': '', 'n_is_sth': ''},
 'purdah': {'n_is_nu': '', 'n_is_sth': ''},
 'pureness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'pure', 'nn_to_rb': 'purely'},
 'purgatory': {'n_is_nu': '', 'n_is_sth': ''},
 'purification': {'n_is_nu': '', 'n_is_sth': ''},
 'purity': {'n_is_nu': '', 'n_is_sth': ''},
 'purport': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'purpura': {'n_is_nu': '', 'n_is_sth': ''},
 'purslane': {'n_is_nu': '', 'n_is_sth': ''},
 'pus': {'n_is_nu': '', 'n_is_sth': ''},
 'pushiness': {'n_is_nu': '', 'n_is_sth': ''},
 'putrefaction': {'n_is_nu': '', 'n_is_sth': ''},
 'putty': {'n_is_nu': '', 'n_is_sth': ''},
 'puzzlement': {'n_is_nu': '', 'n_is_sth': ''},
 'pvc': {'n_is_nu': '', 'n_is_sth': ''},
 'pyrene': {'n_is_nu': '', 'n_is_sth': ''},
 'pyrotechnics': {'n_is_nu': '', 'n_is_sth': ''},
 'qin': {'n_is_nu': '', 'n_is_sth': ''},
 'quackery': {'n_is_nu': '', 'n_is_sth': ''},
 'quarantine': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'quartz': {'n_is_nu': '', 'n_is_sth': ''},
 'quickness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'questionable', 'nn_to_rb': 'quickly'},
 'quicksilver': {'n_is_nu': '', 'n_is_sth': ''},
 'quiescence': {'n_is_nu': '', 'n_is_sth': ''},
 'quiet': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'jj_to_jjr': 'quieter', 'jj_to_jjs': 'quietest'},
 'quietness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'quick', 'nn_to_rb': 'quietly'},
 'quietude': {'n_is_nu': '', 'n_is_sth': ''},
 'quinine': {'n_is_nu': '', 'n_is_sth': ''},
 'quintessence': {'n_is_nu': '', 'n_is_sth': ''},
 'rabies': {'n_is_nu': '', 'n_is_sth': ''},
 'racialism': {'n_is_nu': '', 'n_is_sth': ''},
 'raciness': {'n_is_nu': '', 'n_is_sth': ''},
 'racing': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'race', 'vbg_to_vbn': 'raced'},
 'racism': {'n_is_nu': '', 'n_is_sth': ''},
 'radiance': {'n_is_nu': '', 'n_is_sth': ''},
 'radioactivity': {'n_is_nu': '', 'n_is_sth': ''},
 'radiography': {'n_is_nu': '', 'n_is_sth': ''},
 'radiology': {'n_is_nu': '', 'n_is_sth': ''},
 'radiophone': {'n_is_nu': '', 'n_is_sth': ''},
 'radiotherapy': {'n_is_nu': '', 'n_is_sth': ''},
 'radium': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'radon': {'n_is_nu': '', 'n_is_sth': ''},
 'raiment': {'n_is_nu': '', 'n_is_sth': ''},
 'rain': {'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'vdo': '', 'v_on': '', 'v_in': '', 'vb_to_vbz': 'rains', 'vb_to_vbd': 'rained', 'vb_to_vbn': 'rained', 'vb_to_vbg': 'raining', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'n_is_nc': ''},
 'rainwater': {'n_is_nu': '', 'n_is_sth': ''},
 'raj': {'n_is_nu': '', 'n_is_sth': ''},
 'rancor': {'n_is_nu': '', 'n_is_sth': ''},
 'randomness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'random', 'nn_to_rb': 'randomly'},
 'rant': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'rapacity': {'n_is_nu': '', 'n_is_sth': ''},
 'raper': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'raphael': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'rapidity': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'rapid', 'nn_to_rb': 'rapidly'},
 'rapport': {'n_is_nu': '', 'n_is_sth': ''},
 'rapture': {'n_is_nu': '', 'n_is_sth': ''},
 'rarity': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'rare'},
 'rashness': {'n_is_nu': '', 'n_is_sth': ''},
 'ratification': {'n_is_nu': '', 'n_is_sth': ''},
 'ratiocination': {'n_is_nu': '', 'n_is_sth': ''},
 'rationalism': {'n_is_nu': '', 'n_is_sth': ''},
 'rationality': {'n_is_nu': '', 'n_is_sth': ''},
 'rattan': {'n_is_nu': '', 'n_is_sth': ''},
 'raunch': {'n_is_nu': '', 'n_is_sth': ''},
 'rave': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'ravioli': {'n_is_nu': '', 'n_is_sth': ''},
 'rawness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'raw', 'nn_to_rb': 'rawly'},
 'rayon': {'n_is_nu': '', 'n_is_sth': ''},
 'razzle': {'n_is_nu': '', 'n_is_sth': ''},
 'razzle-dazzle': {'n_is_nu': '', 'n_is_sth': ''},
 'razzmatazz': {'n_is_nu': '', 'n_is_sth': ''},
 'read': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'v_n_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'v_on': '', 'v_for': '', 'v_of': '', 'vb_to_vbz': 'reads', 'vb_to_nn': 'reader', 'nn_to_vbg': 'reading', 'vb_to_vbg': 'reading', 'vbn_to_vbg': 'reading'},
 'readability': {'n_is_nu': '', 'n_is_sth': ''},
 'readiness': {'n_is_nu': '', 'n_is_sth': ''},
 'readout': {'n_is_nu': '', 'n_is_sth': ''},
 'realism': {'n_is_nu': '', 'n_is_sth': ''},
 'realization': {'n_is_nu': '', 'n_is_sth': ''},
 'realness': {'n_is_nu': '', 'n_is_sth': ''},
 'reasonableness': {'n_is_nu': '', 'n_is_sth': ''},
 'reasoning': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'reason', 'vbg_to_vbn': 'reasoned'},
 'rebirth': {'n_is_nu': '', 'n_is_sth': ''},
 'recalcitrance': {'n_is_nu': '', 'n_is_sth': ''},
 'recapture': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'receptivity': {'n_is_nu': '', 'n_is_sth': ''},
 'reciprocation': {'n_is_nu': '', 'n_is_sth': ''},
 'reciprocity': {'n_is_nu': '', 'n_is_sth': ''},
 'recklessness': {'n_is_nu': '', 'n_is_sth': ''},
 'recognition': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'recognize'},
 'recognizance': {'n_is_nu': '', 'n_is_sth': ''},
 'recoil': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'recombination': {'n_is_nu': '', 'n_is_sth': ''},
 'recompense': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'reconciliation': {'n_is_nu': '', 'n_is_sth': ''},
 'reconnaissance': {'n_is_nu': '', 'n_is_sth': ''},
 'recourse': {'n_is_nu': '', 'n_is_sth': ''},
 'rectitude': {'n_is_nu': '', 'n_is_sth': ''},
 'recuperation': {'n_is_nu': '', 'n_is_sth': ''},
 'redemption': {'n_is_nu': '', 'n_is_sth': ''},
 'redeployment': {'n_is_nu': '', 'n_is_sth': ''},
 'redness': {'n_is_nu': '', 'n_is_sth': ''},
 'redress': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'reducing': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'reduce', 'vbg_to_vbn': 'reduced'},
 'reek': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'reentry': {'n_is_nu': '', 'n_is_sth': ''},
 'refining': {'n_is_nu': '', 'n_is_sth': ''},
 'reflux': {'n_is_nu': '', 'n_is_sth': ''},
 'reformation': {'n_is_nu': '', 'n_is_sth': ''},
 'refraction': {'n_is_nu': '', 'n_is_sth': ''},
 'refreshment': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'refresh'},
 'refrigeration': {'n_is_nu': '', 'n_is_sth': ''},
 'refuse': {'n_is_nu': '', 'n_is_sth': '', 'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'refuses', 'vb_to_vbd': 'refused', 'vb_to_vbn': 'refused', 'vb_to_nn': 'refusal', 'vb_to_vbg': 'refusing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'regalia': {'n_is_nu': '', 'n_is_sth': ''},
 'regeneration': {'n_is_nu': '', 'n_is_sth': ''},
 'regimentation': {'n_is_nu': '', 'n_is_sth': ''},
 'regionalism': {'n_is_nu': '', 'n_is_sth': ''},
 'regularization': {'n_is_nu': '', 'n_is_sth': ''},
 'regurgitation': {'n_is_nu': '', 'n_is_sth': ''},
 'rehabilitation': {'n_is_nu': '', 'n_is_sth': ''},
 'reinsurance': {'n_is_nu': '', 'n_is_sth': ''},
 'rejuvenation': {'n_is_nu': '', 'n_is_sth': ''},
 'relativism': {'n_is_nu': '', 'n_is_sth': ''},
 'relativity': {'n_is_nu': '', 'n_is_sth': ''},
 'relegation': {'n_is_nu': '', 'n_is_sth': ''},
 'relevance': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'relevant', 'nn_to_rb': 'relevantly'},
 'relevancy': {'n_is_nu': '', 'n_is_sth': ''},
 'reliability': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'rely', 'nn_to_jj': 'reliable', 'nn_to_rb': 'reliably'},
 'reliance': {'n_is_nu': '', 'n_is_sth': ''},
 'reluctance': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'reluctant', 'nn_to_rb': 'reluctantly'},
 'remand': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'remediation': {'n_is_nu': '', 'n_is_sth': ''},
 'remorse': {'n_is_nu': '', 'n_is_sth': ''},
 'remoteness': {'n_is_nu': '', 'n_is_sth': ''},
 'render': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'renewal': {'n_is_nu': '', 'n_is_sth': ''},
 'renown': {'n_is_nu': '', 'n_is_sth': ''},
 'reorientation': {'n_is_nu': '', 'n_is_sth': ''},
 'repatriation': {'n_is_nu': '', 'n_is_sth': ''},
 'repeal': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'repentance': {'n_is_nu': '', 'n_is_sth': ''},
 'repetitiveness': {'n_is_nu': '', 'n_is_sth': ''},
 'replenishment': {'n_is_nu': '', 'n_is_sth': ''},
 'reportage': {'n_is_nu': '', 'n_is_sth': ''},
 'repose': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'reposition': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'republicanism': {'n_is_nu': '', 'n_is_sth': ''},
 'repudiation': {'n_is_nu': '', 'n_is_sth': ''},
 'repugnance': {'n_is_nu': '', 'n_is_sth': ''},
 'repulsion': {'n_is_nu': '', 'n_is_sth': ''},
 'repute': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'resale': {'n_is_nu': '', 'n_is_sth': ''},
 'rescission': {'n_is_nu': '', 'n_is_sth': ''},
 'resentment': {'n_is_nu': '', 'n_is_sth': ''},
 'resilience': {'n_is_nu': '', 'n_is_sth': ''},
 'resin': {'n_is_nu': '', 'n_is_sth': ''},
 'resistance': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'resist', 'nn_to_jj': 'resistible'},
 'resourcefulness': {'n_is_nu': '', 'n_is_sth': ''},
 'respect': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'respectful', 'nn_to_rb': 'respectively', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'respects', 'vb_to_vbd': 'respected', 'vb_to_vbn': 'respected', 'vb_to_rb': 'respectively', 'vb_to_jj': 'respectful', 'vb_to_vbg': 'respecting', 'n_is_nc': '', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'respectability': {'n_is_nu': '', 'n_is_sth': ''},
 'respectfulness': {'n_is_nu': '', 'n_is_sth': ''},
 'respite': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_nc': ''},
 'restitution': {'n_is_nu': '', 'n_is_sth': ''},
 'resurgence': {'n_is_nu': '', 'n_is_sth': ''},
 'resurrection': {'n_is_nu': '', 'n_is_sth': ''},
 'resuscitation': {'n_is_nu': '', 'n_is_sth': ''},
 'retail': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'retaliation': {'n_is_nu': '', 'n_is_sth': ''},
 'retardation': {'n_is_nu': '', 'n_is_sth': ''},
 'retention': {'n_is_nu': '', 'n_is_sth': ''},
 'reticence': {'n_is_nu': '', 'n_is_sth': ''},
 'retort': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'retribution': {'n_is_nu': '', 'n_is_sth': ''},
 'retrieval': {'n_is_nu': '', 'n_is_sth': ''},
 'retrogression': {'n_is_nu': '', 'n_is_sth': ''},
 'retrospect': {'n_is_nu': '', 'n_is_sth': ''},
 'retrospection': {'n_is_nu': '', 'n_is_sth': ''},
 'revelry': {'n_is_nu': '', 'n_is_sth': ''},
 'revenge': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'reverence': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'revisionism': {'n_is_nu': '', 'n_is_sth': ''},
 'revitalization': {'n_is_nu': '', 'n_is_sth': ''},
 'revulsion': {'n_is_nu': '', 'n_is_sth': ''},
 'rheumatism': {'n_is_nu': '', 'n_is_sth': ''},
 'rhine': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'rhinitis': {'n_is_nu': '', 'n_is_sth': ''},
 'rhodesia': {'n_is_nu': '', 'n_is_sth': ''},
 'rhodium': {'n_is_nu': '', 'n_is_sth': ''},
 'rhodopsin': {'n_is_nu': '', 'n_is_sth': ''},
 'rhubarb': {'n_is_nu': '', 'n_is_sth': ''},
 'ribaldry': {'n_is_nu': '', 'n_is_sth': ''},
 'ribbing': {'n_is_nu': '', 'n_is_sth': ''},
 'riboflavin': {'n_is_nu': '', 'n_is_sth': ''},
 'ribose': {'n_is_nu': '', 'n_is_sth': ''},
 'ribosome': {'n_is_nu': '', 'n_is_sth': ''},
 'richness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'rich', 'nn_to_rb': 'richly'},
 'rickets': {'n_is_nu': '', 'n_is_sth': ''},
 'riddance': {'n_is_nu': '', 'n_is_sth': ''},
 'ridicule': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'rifling': {'n_is_nu': '', 'n_is_sth': ''},
 'rigging': {'n_is_nu': '', 'n_is_sth': ''},
 'righteousness': {'n_is_nu': '', 'n_is_sth': ''},
 'rightness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'right', 'nn_to_jj': 'rightful', 'nn_to_rb': 'rightfully'},
 'rigidity': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'rigid', 'nn_to_rb': 'rigidly'},
 'rigmarole': {'n_is_nu': '', 'n_is_sth': ''},
 'rigor': {'n_is_nu': '', 'n_is_sth': ''},
 'rime': {'n_is_nu': '', 'n_is_sth': ''},
 'rind': {'n_is_nu': '', 'n_is_sth': ''},
 'ringworm': {'n_is_nu': '', 'n_is_sth': ''},
 'rip-off': {'n_is_nu': '', 'n_is_sth': ''},
 'ripeness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'ripe'},
 'rna': {'n_is_nu': '', 'n_is_sth': ''},
 'roaring': {'n_is_nu': '', 'n_is_sth': ''},
 'rolling': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'roll', 'vbg_to_vbn': 'rolled'},
 'roma': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'romanticism': {'n_is_nu': '', 'n_is_sth': ''},
 'roofing': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'roof', 'vbg_to_vbn': 'roofed'},
 'roominess': {'n_is_nu': '', 'n_is_sth': ''},
 'roosevelt': {'n_is_nu': '', 'n_is_sb': '0'},
 'rosin': {'n_is_nu': '', 'n_is_sth': ''},
 'rosiness': {'n_is_nu': '', 'n_is_sth': ''},
 'rot': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'rote': {'n_is_nu': '', 'n_is_sth': ''},
 'rouge': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'rough-and-tumble': {'n_is_nu': '', 'n_is_sth': ''},
 'roughage': {'n_is_nu': '', 'n_is_sth': ''},
 'roughness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'rough', 'nn_to_rb': 'roughly'},
 'roundel': {'n_is_nu': '', 'n_is_sth': ''},
 'roundup': {'n_is_nu': '', 'n_is_sth': ''},
 'roving': {'n_is_nu': '', 'n_is_sth': ''},
 'rowing': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'row', 'vbg_to_vbn': 'rowed'},
 'rubbish': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'nu_typical': ''},
 'rubble': {'n_is_nu': '', 'n_is_sth': ''},
 'rubella': {'n_is_nu': '', 'n_is_sth': ''},
 'rubidium': {'n_is_nu': '', 'n_is_sth': ''},
 'ruble': {'n_is_nu': '', 'n_is_sth': ''},
 'ruckus': {'n_is_nu': '', 'n_is_sth': ''},
 'rudeness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'rude', 'nn_to_rb': 'rudely'},
 'rue': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'rugby': {'n_is_nu': '', 'n_is_sth': ''},
 'ruggedness': {'n_is_nu': '', 'n_is_sth': ''},
 'ruination': {'n_is_nu': '', 'n_is_sth': ''},
 'rum': {'n_is_nu': '', 'n_is_sth': ''},
 'rumania': {'n_is_nu': '', 'n_is_sth': ''},
 'runup': {'n_is_nu': '', 'n_is_sth': ''},
 'rust': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'rusty', 'vb_to_jj': 'rusty', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'rusticity': {'n_is_nu': '', 'n_is_sth': ''},
 'rustiness': {'n_is_nu': '', 'n_is_sth': ''},
 'ruth': {'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'ruthlessness': {'n_is_nu': '', 'n_is_sth': ''},
 'ryegrass': {'n_is_nu': '', 'n_is_sth': ''},
 'sabotage': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'saccharin': {'n_is_nu': '', 'n_is_sth': ''},
 'sackcloth': {'n_is_nu': '', 'n_is_sth': ''},
 'sacking': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'sack', 'vbg_to_vbn': 'sacked'},
 'saddlery': {'n_is_nu': '', 'n_is_sth': ''},
 'sadness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'sadden', 'nn_to_jj': 'sad', 'nn_to_rb': 'sadly', 'nu_typical': ''},
 'safekeeping': {'n_is_nu': '', 'n_is_sth': ''},
 'safety': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'safe', 'nn_to_rb': 'safely'},
 'saffron': {'n_is_nu': '', 'n_is_sth': ''},
 'sag': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'sagacity': {'n_is_nu': '', 'n_is_sth': ''},
 'sagebrush': {'n_is_nu': '', 'n_is_sth': ''},
 'sahara': {'n_is_nu': '', 'n_is_sth': ''},
 'sailcloth': {'n_is_nu': '', 'n_is_sth': ''},
 'sake': {'n_is_nu': '', 'n_is_sth': ''},
 'salaam': {'n_is_nu': '', 'n_is_sth': ''},
 'salability': {'n_is_nu': '', 'n_is_sth': ''},
 'saline': {'n_is_nu': '', 'n_is_sth': ''},
 'salinity': {'n_is_nu': '', 'n_is_sth': ''},
 'saliva': {'n_is_nu': '', 'n_is_sth': ''},
 'sallet': {'n_is_nu': '', 'n_is_sth': ''},
 'salmagundi': {'n_is_nu': '', 'n_is_sth': ''},
 'salmonella': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'salt': {'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'salts', 'vb_to_vbd': 'salted', 'vb_to_vbn': 'salted', 'vb_to_vbg': 'salting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'saltpeter': {'n_is_nu': '', 'n_is_sth': ''},
 'salvage': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'salvation': {'n_is_nu': '', 'n_is_sth': ''},
 'sam': {'n_is_nu': '', 'n_is_sb': '0'},
 'sameness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'same'},
 'sampling': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'sample', 'vbg_to_vbn': 'sampled'},
 'sanctification': {'n_is_nu': '', 'n_is_sth': ''},
 'sanctimony': {'n_is_nu': '', 'n_is_sth': ''},
 'sanctity': {'n_is_nu': '', 'n_is_sth': ''},
 'sandalwood': {'n_is_nu': '', 'n_is_sth': ''},
 'sandpaper': {'n_is_nu': '', 'n_is_sth': ''},
 'sandstone': {'n_is_nu': '', 'n_is_sth': ''},
 'sang-froid': {'n_is_nu': '', 'n_is_sth': ''},
 'sanitation': {'n_is_nu': '', 'n_is_sth': ''},
 'sanity': {'n_is_nu': '', 'n_is_sth': ''},
 'sanskrit': {'n_is_nu': '', 'n_is_sth': '', 'cap_word': 'Sanskrit'},
 'sapphire': {'n_is_nu': '', 'n_is_sth': ''},
 'sapwood': {'n_is_nu': '', 'n_is_sth': ''},
 'sarcasm': {'n_is_nu': '', 'n_is_sth': ''},
 'sardinia': {'n_is_nu': '', 'n_is_sth': ''},
 'sashimi': {'n_is_nu': '', 'n_is_sth': ''},
 'satanism': {'n_is_nu': '', 'n_is_sth': ''},
 'satiation': {'n_is_nu': '', 'n_is_sth': ''},
 'satiety': {'n_is_nu': '', 'n_is_sth': ''},
 'satin': {'n_is_nu': '', 'n_is_sth': ''},
 'saturation': {'n_is_nu': '', 'n_is_sth': ''},
 'saturn': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'sauciness': {'n_is_nu': '', 'n_is_sth': ''},
 'sauerkraut': {'n_is_nu': '', 'n_is_sth': ''},
 'sauna': {'n_is_nu': '', 'n_is_sth': ''},
 'saunter': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'savoir-faire': {'n_is_nu': '', 'n_is_sth': ''},
 'sawdust': {'n_is_nu': '', 'n_is_sth': ''},
 'say': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'v_to_n': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_about': '', 'v_to': '', 'vb_to_vbz': 'says', 'vb_to_vbd': 'said', 'vb_to_vbn': 'said', 'vb_to_vbg': 'saying', 'vt_typical': ''},
 'say-so': {'n_is_nu': '', 'n_is_sth': ''},
 'scabies': {'n_is_nu': '', 'n_is_sth': ''},
 'scaffolding': {'n_is_nu': '', 'n_is_sth': ''},
 'scag': {'n_is_nu': '', 'n_is_sth': ''},
 'scald': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'scandinavia': {'n_is_nu': '', 'n_is_sth': ''},
 'scanning': {'n_is_nu': '', 'n_is_sth': ''},
 'scarcity': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'scarce', 'nn_to_rb': 'scarcely'},
 'scarlet': {'n_is_nu': '', 'n_is_sth': ''},
 'scenery': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'scepticism': {'n_is_nu': '', 'n_is_sth': ''},
 'sceptre': {'n_is_nu': '', 'n_is_sth': ''},
 'schiller': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'schist': {'n_is_nu': '', 'n_is_sth': ''},
 'schistosomiasis': {'n_is_nu': '', 'n_is_sth': ''},
 'schizophrenia': {'n_is_nu': '', 'n_is_sth': ''},
 'schmaltz': {'n_is_nu': '', 'n_is_sth': ''},
 'schnapps': {'n_is_nu': '', 'n_is_sth': ''},
 'schooling': {'n_is_nu': '', 'n_is_sth': ''},
 'schoolwork': {'n_is_nu': '', 'n_is_sth': ''},
 'sclerosis': {'n_is_nu': '', 'n_is_sth': ''},
 'scoring': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'score', 'vbg_to_vbn': 'scored'},
 'scorn': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'scornful', 'nn_to_rb': 'scornfully', 'vb_to_rb': 'scornfully', 'vb_to_jj': 'scornful', 'v_vbg': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'scot': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'scotland': {'n_is_nu': '', 'n_is_sth': ''},
 'scour': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'scrub': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'scrutiny': {'n_is_nu': '', 'n_is_sth': ''},
 'scum': {'n_is_nu': '', 'n_is_sth': ''},
 'scurry': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'scurvy': {'n_is_nu': '', 'n_is_sth': ''},
 'seafood': {'n_is_nu': '', 'n_is_sth': ''},
 'sealant': {'n_is_nu': '', 'n_is_sth': ''},
 'sealing': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'seal', 'vbg_to_vbn': 'sealed'},
 'seasickness': {'n_is_nu': '', 'n_is_sth': ''},
 'seating': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'seat', 'vbg_to_vbn': 'seated'},
 'seawater': {'n_is_nu': '', 'n_is_sth': ''},
 'seaweed': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3', 'nu_typical': ''},
 'sebum': {'n_is_nu': '', 'n_is_sth': ''},
 'seclusion': {'n_is_nu': '', 'n_is_sth': ''},
 'secrecy': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'secret', 'nn_to_rb': 'secretly'},
 'sectarianism': {'n_is_nu': '', 'n_is_sth': ''},
 'secularization': {'n_is_nu': '', 'n_is_sth': ''},
 'sedation': {'n_is_nu': '', 'n_is_sth': ''},
 'sedge': {'n_is_nu': '', 'n_is_sth': ''},
 'sedimentation': {'n_is_nu': '', 'n_is_sth': ''},
 'sedition': {'n_is_nu': '', 'n_is_sth': ''},
 'seemliness': {'n_is_nu': '', 'n_is_sth': ''},
 'seersucker': {'n_is_nu': '', 'n_is_sth': ''},
 'segmentation': {'n_is_nu': '', 'n_is_sth': ''},
 'segregation': {'n_is_nu': '', 'n_is_sth': ''},
 'seiche': {'n_is_nu': '', 'n_is_sth': ''},
 'seismology': {'n_is_nu': '', 'n_is_sth': ''},
 'seizing': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'seize', 'vbg_to_vbn': 'seized'},
 'selectivity': {'n_is_nu': '', 'n_is_sth': ''},
 'selenium': {'n_is_nu': '', 'n_is_sth': ''},
 'self-abasement': {'n_is_nu': '', 'n_is_sth': ''},
 'self-abnegation': {'n_is_nu': '', 'n_is_sth': ''},
 'self-absorption': {'n_is_nu': '', 'n_is_sth': ''},
 'self-abuse': {'n_is_nu': '', 'n_is_sth': ''},
 'self-annihilation': {'n_is_nu': '', 'n_is_sth': ''},
 'self-assertion': {'n_is_nu': '', 'n_is_sth': ''},
 'self-assurance': {'n_is_nu': '', 'n_is_sth': ''},
 'self-confidence': {'n_is_nu': '', 'n_is_sth': ''},
 'self-control': {'n_is_nu': '', 'n_is_sth': ''},
 'self-criticism': {'n_is_nu': '', 'n_is_sth': ''},
 'self-deception': {'n_is_nu': '', 'n_is_sth': ''},
 'self-defense': {'n_is_nu': '', 'n_is_sth': ''},
 'self-denial': {'n_is_nu': '', 'n_is_sth': ''},
 'self-destruction': {'n_is_nu': '', 'n_is_sth': ''},
 'self-determination': {'n_is_nu': '', 'n_is_sth': ''},
 'self-discipline': {'n_is_nu': '', 'n_is_sth': ''},
 'self-effacement': {'n_is_nu': '', 'n_is_sth': ''},
 'self-esteem': {'n_is_nu': '', 'n_is_sth': ''},
 'self-examination': {'n_is_nu': '', 'n_is_sth': ''},
 'self-government': {'n_is_nu': '', 'n_is_sth': ''},
 'self-help': {'n_is_nu': '', 'n_is_sth': ''},
 'self-importance': {'n_is_nu': '', 'n_is_sth': ''},
 'self-indulgence': {'n_is_nu': '', 'n_is_sth': ''},
 'self-knowledge': {'n_is_nu': '', 'n_is_sth': ''},
 'self-love': {'n_is_nu': '', 'n_is_sth': ''},
 'self-pity': {'n_is_nu': '', 'n_is_sth': ''},
 'self-portrait': {'n_is_nu': '', 'n_is_sth': ''},
 'self-possession': {'n_is_nu': '', 'n_is_sth': ''},
 'self-protection': {'n_is_nu': '', 'n_is_sth': ''},
 'self-regard': {'n_is_nu': '', 'n_is_sth': ''},
 'self-reliance': {'n_is_nu': '', 'n_is_sth': ''},
 'self-reproach': {'n_is_nu': '', 'n_is_sth': ''},
 'self-respect': {'n_is_nu': '', 'n_is_sth': ''},
 'self-restraint': {'n_is_nu': '', 'n_is_sth': ''},
 'self-rule': {'n_is_nu': '', 'n_is_sth': ''},
 'self-sacrifice': {'n_is_nu': '', 'n_is_sth': ''},
 'self-satisfaction': {'n_is_nu': '', 'n_is_sth': ''},
 'sellout': {'n_is_nu': '', 'n_is_sth': ''},
 'semantics': {'n_is_nu': '', 'n_is_sth': ''},
 'semaphore': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl': ''},
 'semblance': {'n_is_nu': '', 'n_is_sth': ''},
 'semen': {'n_is_nu': '', 'n_is_sth': ''},
 'semi': {'n_is_nu': '', 'n_is_sth': ''},
 'semitone': {'n_is_nu': '', 'n_is_sth': ''},
 'sending': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'send', 'vbg_to_vbn': 'sent'},
 'senescence': {'n_is_nu': '', 'n_is_sth': ''},
 'senility': {'n_is_nu': '', 'n_is_sth': ''},
 'seniority': {'n_is_nu': '', 'n_is_sth': ''},
 'sensitivity': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'sensitive', 'nn_to_rb': 'sensitively'},
 'sensitization': {'n_is_nu': '', 'n_is_sth': ''},
 'sensuality': {'n_is_nu': '', 'n_is_sth': ''},
 'sentience': {'n_is_nu': '', 'n_is_sth': ''},
 'sentimentalism': {'n_is_nu': '', 'n_is_sth': ''},
 'sentimentality': {'n_is_nu': '', 'n_is_sth': ''},
 'sentry': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'separateness': {'n_is_nu': '', 'n_is_sth': ''},
 'separatism': {'n_is_nu': '', 'n_is_sth': ''},
 'sepia': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'sepsis': {'n_is_nu': '', 'n_is_sth': ''},
 'septicemia': {'n_is_nu': '', 'n_is_sth': ''},
 'sequoia': {'n_is_nu': '', 'n_is_sth': ''},
 'serenity': {'n_is_nu': '', 'n_is_sth': ''},
 'serfdom': {'n_is_nu': '', 'n_is_sth': ''},
 'serge': {'n_is_nu': '', 'n_is_sth': ''},
 'seriousness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'serious', 'nn_to_rb': 'seriously'},
 'serviceability': {'n_is_nu': '', 'n_is_sth': ''},
 'servility': {'n_is_nu': '', 'n_is_sth': ''},
 'servitude': {'n_is_nu': '', 'n_is_sth': ''},
 'sesame': {'n_is_nu': '', 'n_is_sth': ''},
 'set-to': {'n_is_nu': '', 'n_is_sth': ''},
 'seven': {'n_is_nu': '', 'n_is_sth': ''},
 'severance': {'n_is_nu': '', 'n_is_sth': ''},
 'severity': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'severe', 'nn_to_rb': 'severely'},
 'sewage': {'n_is_nu': '', 'n_is_sth': ''},
 'sewerage': {'n_is_nu': '', 'n_is_sth': ''},
 'sewing': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'sew', 'vbg_to_vbn': 'sewn'},
 'sex': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'sexual', 'nn_to_rb': 'sexually', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_rb': 'sexually', 'vb_to_jj': 'sexual'},
 'sexiness': {'n_is_nu': '', 'n_is_sth': ''},
 'sexuality': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'sex', 'nn_to_jj': 'sexual', 'nn_to_rb': 'sexually'},
 'shadowboxing': {'n_is_nu': '', 'n_is_sth': ''},
 'shakespeare': {'n_is_nu': '', 'n_is_sb': '0', 'cap_word': 'Shakespeare'},
 'shakiness': {'n_is_nu': '', 'n_is_sth': ''},
 'shale': {'n_is_nu': '', 'n_is_sth': ''},
 'shamanism': {'n_is_nu': '', 'n_is_sth': ''},
 'shang': {'n_is_nu': '', 'n_is_sth': ''},
 'shangri-la': {'n_is_nu': '', 'n_is_sth': ''},
 'shantung': {'n_is_nu': '', 'n_is_sth': ''},
 'shapeliness': {'n_is_nu': '', 'n_is_sth': ''},
 'sharing': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'share', 'vbg_to_vbn': 'shared'},
 'sharpness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'sharp', 'nn_to_jj': 'sharp', 'nn_to_rb': 'sharply'},
 'shaw': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'sheen': {'n_is_nu': '', 'n_is_sth': ''},
 'sheeting': {'n_is_nu': '', 'n_is_sth': ''},
 'shellac': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'sheller': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'shellfire': {'n_is_nu': '', 'n_is_sth': ''},
 'shelling': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'shell', 'vbg_to_vbn': 'shelled'},
 'shenyang': {'n_is_nu': '', 'n_is_sth': ''},
 'sherbet': {'n_is_nu': '', 'n_is_sth': ''},
 'shimmer': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'shinto': {'n_is_nu': '', 'n_is_sth': '', 'cap_word': 'Shinto'},
 'shipbuilding': {'n_is_nu': '', 'n_is_sth': ''},
 'shipping': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'ship', 'vbg_to_vbn': 'shipped'},
 'shogunate': {'n_is_nu': '', 'n_is_sth': ''},
 'shootout': {'n_is_nu': '', 'n_is_sth': ''},
 'shopping': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'shop', 'vbg_to_vbn': 'shopped', 'nu_typical': ''},
 'shortening': {'n_is_nu': '', 'n_is_sth': ''},
 'shorthand': {'n_is_nu': '', 'n_is_sth': ''},
 'shortness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'shorten', 'nn_to_jj': 'short', 'nn_to_rb': 'shortly'},
 'shortsightedness': {'n_is_nu': '', 'n_is_sth': ''},
 'shouting': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'shout', 'vbg_to_vbn': 'shouted'},
 'showiness': {'n_is_nu': '', 'n_is_sth': ''},
 'shrapnel': {'n_is_nu': '', 'n_is_sth': ''},
 'shrewdness': {'n_is_nu': '', 'n_is_sth': ''},
 'shrift': {'n_is_nu': '', 'n_is_sth': ''},
 'shrinkage': {'n_is_nu': '', 'n_is_sth': ''},
 'shtick': {'n_is_nu': '', 'n_is_sth': ''},
 'shutdown': {'n_is_nu': '', 'n_is_sth': ''},
 'shyness': {'n_is_nu': '', 'n_is_sth': ''},
 'siam': {'n_is_nu': '', 'n_is_sth': ''},
 'sian': {'n_is_nu': '', 'n_is_sth': ''},
 'sichuan': {'n_is_nu': '', 'n_is_sth': '', 'cap_word': 'Sichuan'},
 'sienna': {'n_is_nu': '', 'n_is_sth': ''},
 'sighting': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'sight', 'vbg_to_vbn': 'sighted'},
 'significance': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'signify', 'nn_to_jj': 'significant', 'nn_to_rb': 'significantly', 'nu_typical': ''},
 'silesia': {'n_is_nu': '', 'n_is_sth': ''},
 'silica': {'n_is_nu': '', 'n_is_sth': ''},
 'silicate': {'n_is_nu': '', 'n_is_sth': ''},
 'silicon': {'n_is_nu': '', 'n_is_sth': ''},
 'silicone': {'n_is_nu': '', 'n_is_sth': ''},
 'silicosis': {'n_is_nu': '', 'n_is_sth': ''},
 'silliness': {'n_is_nu': '', 'n_is_sth': ''},
 'silt': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'silver': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'silverish', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'silvers', 'vb_to_vbd': 'silvered', 'vb_to_vbn': 'silvered', 'vb_to_jj': 'silverish', 'vb_to_vbg': 'silvering', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'simmer': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'simplicity': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'simplify', 'nn_to_jj': 'simple', 'nn_to_rb': 'simply'},
 'simultaneity': {'n_is_nu': '', 'n_is_sth': ''},
 'sincerity': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'sincere', 'nn_to_rb': 'sincerely'},
 'singleness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'single'},
 'sirius': {'n_is_nu': '', 'n_is_sth': ''},
 'sirloin': {'n_is_nu': '', 'n_is_sth': ''},
 'skating': {'n_is_nu': '', 'n_is_sth': ''},
 'skulduggery': {'n_is_nu': '', 'n_is_sth': ''},
 'skullduggery': {'n_is_nu': '', 'n_is_sth': ''},
 'slackness': {'n_is_nu': '', 'n_is_sth': ''},
 'slang': {'n_is_nu': '', 'n_is_sth': ''},
 'slapstick': {'n_is_nu': '', 'n_is_sth': ''},
 'slaughter': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'sleepiness': {'n_is_nu': '', 'n_is_sth': ''},
 'sleet': {'n_is_nu': '', 'n_is_sth': ''},
 'sleight': {'n_is_nu': '', 'n_is_sth': ''},
 'slime': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'slobber': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'sloppiness': {'n_is_nu': '', 'n_is_sth': ''},
 'slops': {'n_is_nu': '', 'n_is_sth': ''},
 'sloth': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'slowness': {'n_is_nu': '', 'n_is_sth': ''},
 'sludge': {'n_is_nu': '', 'n_is_sth': ''},
 'sluggishness': {'n_is_nu': '', 'n_is_sth': ''},
 'slurry': {'n_is_nu': '', 'n_is_sth': ''},
 'slush': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'smallness': {'n_is_nu': '', 'n_is_sth': ''},
 'smallpox': {'n_is_nu': '', 'n_is_sth': ''},
 'smattering': {'n_is_nu': '', 'n_is_sth': ''},
 'smidgen': {'n_is_nu': '', 'n_is_sth': ''},
 'smith': {'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'smorgasbord': {'n_is_nu': '', 'n_is_sth': ''},
 'smuggling': {'n_is_nu': '', 'n_is_sth': ''},
 'smut': {'n_is_nu': '', 'n_is_sth': ''},
 'snobbery': {'n_is_nu': '', 'n_is_sth': ''},
 'snobbishness': {'n_is_nu': '', 'n_is_sth': ''},
 'snooker': {'n_is_nu': '', 'n_is_sth': ''},
 'snot': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'soapstone': {'n_is_nu': '', 'n_is_sth': ''},
 'soapwort': {'n_is_nu': '', 'n_is_sth': ''},
 'sobriety': {'n_is_nu': '', 'n_is_sth': ''},
 'sociability': {'n_is_nu': '', 'n_is_sth': ''},
 'socialism': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'socialization': {'n_is_nu': '', 'n_is_sth': ''},
 'sociology': {'n_is_nu': '', 'n_is_sth': ''},
 'socket': {'n_is_nu': '', 'n_is_sth': '', 'nc_typical': ''},
 'socrates': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0', 'cap_word': 'Socrates'},
 'sodium': {'n_is_nu': '', 'n_is_sth': ''},
 'sodomy': {'n_is_nu': '', 'n_is_sth': ''},
 'softness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'soften', 'nn_to_jj': 'softened', 'nn_to_rb': 'softly'},
 'software': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'soja': {'n_is_nu': '', 'n_is_sth': ''},
 'sol': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'solace': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'solarization': {'n_is_nu': '', 'n_is_sth': ''},
 'solder': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'solemnity': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'solemn', 'nn_to_rb': 'solemnly'},
 'solidarity': {'n_is_nu': '', 'n_is_sth': ''},
 'solidification': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'solidify', 'nn_to_jj': 'solidified', 'nn_to_rb': 'solidly'},
 'solidity': {'n_is_nu': '', 'n_is_sth': ''},
 'soliloquy': {'n_is_nu': '', 'n_is_sth': ''},
 'solipsism': {'n_is_nu': '', 'n_is_sth': ''},
 'solitude': {'n_is_nu': '', 'n_is_sth': ''},
 'somnolence': {'n_is_nu': '', 'n_is_sth': ''},
 'sonar': {'n_is_nu': '', 'n_is_sth': ''},
 'sonority': {'n_is_nu': '', 'n_is_sth': ''},
 'soot': {'n_is_nu': '', 'n_is_sth': ''},
 'sooth': {'n_is_nu': '', 'n_is_sth': ''},
 'sophistication': {'n_is_nu': '', 'n_is_sth': ''},
 'sorcery': {'n_is_nu': '', 'n_is_sth': ''},
 'sorghum': {'n_is_nu': '', 'n_is_sth': ''},
 'sorrel': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3'},
 'soul-searching': {'n_is_nu': '', 'n_is_sth': ''},
 'soundness': {'n_is_nu': '', 'n_is_sth': ''},
 'sourdough': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'sourness': {'n_is_nu': '', 'n_is_sth': ''},
 'south': {'n_is_nu': '', 'n_is_sth': ''},
 'southeast': {'n_is_nu': '', 'n_is_sth': ''},
 'southward': {'n_is_nu': '', 'n_is_sth': ''},
 'southwest': {'n_is_nu': '', 'n_is_sth': ''},
 'sovereignty': {'n_is_nu': '', 'n_is_sth': ''},
 'soy': {'n_is_nu': '', 'n_is_sth': ''},
 'soya': {'n_is_nu': '', 'n_is_sth': ''},
 'soymilk': {'n_is_nu': '', 'n_is_sth': ''},
 'spaceflight': {'n_is_nu': '', 'n_is_sth': ''},
 'spacing': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'space', 'nn_to_jj': 'spaced'},
 'spareness': {'n_is_nu': '', 'n_is_sth': ''},
 'sparsity': {'n_is_nu': '', 'n_is_sth': ''},
 'spasticity': {'n_is_nu': '', 'n_is_sth': ''},
 'spate': {'n_is_nu': '', 'n_is_sth': ''},
 'spawn': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '3', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'spearmint': {'n_is_nu': '', 'n_is_sth': ''},
 'spearpoint': {'n_is_nu': '', 'n_is_sth': ''},
 'speciality': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'specialize', 'nn_to_jj': 'specialist', 'nn_to_rb': 'specially'},
 'specialness': {'n_is_nu': '', 'n_is_sth': ''},
 'specificity': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'specific', 'nn_to_rb': 'specifically'},
 'spectroscope': {'n_is_nu': '', 'n_is_sth': ''},
 'spectroscopy': {'n_is_nu': '', 'n_is_sth': ''},
 'speediness': {'n_is_nu': '', 'n_is_sth': ''},
 'spencer': {'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'spending': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'spend', 'nn_to_jj': 'spent', 'vbg_to_vb': 'spend', 'vbg_to_vbn': 'spent'},
 'spice': {'n_is_nu': '', 'n_is_sth': ''},
 'spiciness': {'n_is_nu': '', 'n_is_sth': ''},
 'spinach': {'n_is_nu': '', 'n_is_sth': ''},
 'spinsterhood': {'n_is_nu': '', 'n_is_sth': ''},
 'spirituality': {'n_is_nu': '', 'n_is_sth': ''},
 'spite': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'spittle': {'n_is_nu': '', 'n_is_sth': ''},
 'splendor': {'n_is_nu': '', 'n_is_sth': ''},
 'splendour': {'n_is_nu': '', 'n_is_sth': ''},
 'spoilage': {'n_is_nu': '', 'n_is_sth': ''},
 'spontaneity': {'n_is_nu': '', 'n_is_sth': ''},
 'spoor': {'n_is_nu': '', 'n_is_sth': ''},
 'sportswear': {'n_is_nu': '', 'n_is_sth': ''},
 'springtime': {'n_is_nu': '', 'n_is_sth': ''},
 'spume': {'n_is_nu': '', 'n_is_sth': ''},
 'spunk': {'n_is_nu': '', 'n_is_sth': ''},
 'sputum': {'n_is_nu': '', 'n_is_sth': ''},
 'squalor': {'n_is_nu': '', 'n_is_sth': ''},
 'squareness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'square', 'nn_to_jj': 'square', 'nn_to_rb': 'squarely'},
 'squash': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'squish': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'stability': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'stable', 'nn_to_jj': 'stable'},
 'stabilization': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'stable', 'nn_to_jj': 'stable'},
 'stagecraft': {'n_is_nu': '', 'n_is_sth': ''},
 'stagnancy': {'n_is_nu': '', 'n_is_sth': ''},
 'stagnation': {'n_is_nu': '', 'n_is_sth': ''},
 'staleness': {'n_is_nu': '', 'n_is_sth': ''},
 'stamina': {'n_is_nu': '', 'n_is_sth': ''},
 'stand': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'standing', 'v_vbg': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vbe': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_in': '', 'v_for': '', 'v_against': '', 'v_to': '', 'vb_to_vbz': 'stands', 'vb_to_vbd': 'stood', 'vb_to_vbn': 'stood', 'vb_to_jj': 'standing', 'vb_to_vbg': 'standing', 'vi_typical': '', 'v_compcl_non': '', 'v_pass_non': '', 'nc_typical': ''},
 'standardization': {'n_is_nu': '', 'n_is_sth': ''},
 'standstill': {'n_is_nu': '', 'n_is_sth': ''},
 'stanford': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'stardust': {'n_is_nu': '', 'n_is_sth': ''},
 'stargazing': {'n_is_nu': '', 'n_is_sth': ''},
 'starlight': {'n_is_nu': '', 'n_is_sth': ''},
 'starting': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'start', 'vbg_to_vb': 'start', 'vbg_to_vbn': 'started'},
 'starvation': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'statecraft': {'n_is_nu': '', 'n_is_sth': ''},
 'stateliness': {'n_is_nu': '', 'n_is_sth': ''},
 'statesmanship': {'n_is_nu': '', 'n_is_sth': ''},
 'static': {'n_is_nu': '', 'n_is_sth': ''},
 'statice': {'n_is_nu': '', 'n_is_sth': ''},
 'stationery': {'n_is_nu': '', 'n_is_sth': ''},
 'stature': {'n_is_nu': '', 'n_is_sth': ''},
 'status': {'n_is_nu': '', 'n_is_sth': '', 'n_is_nc': ''},
 'stead': {'n_is_nu': '', 'n_is_sth': ''},
 'steadiness': {'n_is_nu': '', 'n_is_sth': ''},
 'stealth': {'n_is_nu': '', 'n_is_sth': ''},
 'steep': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'jj_to_jjr': 'steeper', 'jj_to_jjs': 'steepest'},
 'steepness': {'n_is_nu': '', 'n_is_sth': ''},
 'steerage': {'n_is_nu': '', 'n_is_sth': ''},
 'stenography': {'n_is_nu': '', 'n_is_sth': ''},
 'stenosis': {'n_is_nu': '', 'n_is_sth': ''},
 'sterility': {'n_is_nu': '', 'n_is_sth': ''},
 'sterilization': {'n_is_nu': '', 'n_is_sth': ''},
 'sterling': {'n_is_nu': '', 'n_is_sth': ''},
 'sternness': {'n_is_nu': '', 'n_is_sth': ''},
 'stew': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'stewardship': {'n_is_nu': '', 'n_is_sth': ''},
 'stickiness': {'n_is_nu': '', 'n_is_sth': ''},
 'stiffness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'stiff', 'nn_to_jj': 'stiff', 'nn_to_rb': 'stiff'},
 'stigmatization': {'n_is_nu': '', 'n_is_sth': ''},
 'stillness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'still', 'nn_to_jj': 'still', 'nn_to_rb': 'still'},
 'stimulation': {'n_is_nu': '', 'n_is_sth': ''},
 'stinginess': {'n_is_nu': '', 'n_is_sth': ''},
 'stock-in-trade': {'n_is_nu': '', 'n_is_sth': ''},
 'stonework': {'n_is_nu': '', 'n_is_sth': ''},
 'storage': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'storminess': {'n_is_nu': '', 'n_is_sth': ''},
 'stout': {'n_is_nu': '', 'n_is_sth': '', 'jj_to_jjr': 'stouter', 'jj_to_jjs': 'stoutest'},
 'stover': {'n_is_nu': '', 'n_is_sth': ''},
 'stowage': {'n_is_nu': '', 'n_is_sth': ''},
 'strabismus': {'n_is_nu': '', 'n_is_sth': ''},
 'straightness': {'n_is_nu': '', 'n_is_sth': ''},
 'strangeness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'strange'},
 'strangulation': {'n_is_nu': '', 'n_is_sth': ''},
 'strawboard': {'n_is_nu': '', 'n_is_sth': ''},
 'streptomycin': {'n_is_nu': '', 'n_is_sth': ''},
 'strictness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'strict', 'nn_to_rb': 'strictly'},
 'stringency': {'n_is_nu': '', 'n_is_sth': ''},
 'strop': {'n_is_nu': '', 'n_is_sth': ''},
 'struggler': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'stubble': {'n_is_nu': '', 'n_is_sth': ''},
 'stubbornness': {'n_is_nu': '', 'n_is_sth': ''},
 'studiousness': {'n_is_nu': '', 'n_is_sth': ''},
 'stuff': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'stuffed', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'stuffs', 'vb_to_vbd': 'stuffed', 'vb_to_vbn': 'stuffed', 'vb_to_jj': 'stuffed', 'vb_to_vbg': 'stuffing', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'stuffiness': {'n_is_nu': '', 'n_is_sth': ''},
 'stuffing': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'stuff', 'nn_to_jj': 'stuffed', 'vbg_to_vb': 'stuff', 'vbg_to_vbn': 'stuffed'},
 'stumble': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'stupefaction': {'n_is_nu': '', 'n_is_sth': ''},
 'stupor': {'n_is_nu': '', 'n_is_sth': ''},
 'sturdiness': {'n_is_nu': '', 'n_is_sth': ''},
 'styrene': {'n_is_nu': '', 'n_is_sth': ''},
 'styrofoam': {'n_is_nu': '', 'n_is_sth': ''},
 'styx': {'n_is_nu': '', 'n_is_sth': ''},
 'suasion': {'n_is_nu': '', 'n_is_sth': ''},
 'suavity': {'n_is_nu': '', 'n_is_sth': ''},
 'subconscious': {'n_is_nu': '', 'n_is_sth': ''},
 'subduction': {'n_is_nu': '', 'n_is_sth': ''},
 'subjection': {'n_is_nu': '', 'n_is_sth': ''},
 'subjectivity': {'n_is_nu': '', 'n_is_sth': ''},
 'subjugation': {'n_is_nu': '', 'n_is_sth': ''},
 'sublimation': {'n_is_nu': '', 'n_is_sth': ''},
 'sublimity': {'n_is_nu': '', 'n_is_sb': '0', 'n_is_sth': ''},
 'submersion': {'n_is_nu': '', 'n_is_sth': ''},
 'subordination': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'subordinate', 'nn_to_jj': 'subordinate'},
 'subornation': {'n_is_nu': '', 'n_is_sth': ''},
 'subservience': {'n_is_nu': '', 'n_is_sth': ''},
 'subsidization': {'n_is_nu': '', 'n_is_sth': ''},
 'subsistence': {'n_is_nu': '', 'n_is_sth': ''},
 'subsoil': {'n_is_nu': '', 'n_is_sth': ''},
 'substantiation': {'n_is_nu': '', 'n_is_sth': ''},
 'suburbia': {'n_is_nu': '', 'n_is_sth': ''},
 'subversion': {'n_is_nu': '', 'n_is_sth': ''},
 'succinctness': {'n_is_nu': '', 'n_is_sth': ''},
 'succulence': {'n_is_nu': '', 'n_is_sth': ''},
 'sucrose': {'n_is_nu': '', 'n_is_sth': ''},
 'suction': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'suddenness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'sudden', 'nn_to_rb': 'suddenly'},
 'suet': {'n_is_nu': '', 'n_is_sth': ''},
 'suez': {'n_is_nu': '', 'n_is_sth': ''},
 'sufferance': {'n_is_nu': '', 'n_is_sth': ''},
 'sufficiency': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'sufficient', 'nn_to_rb': 'sufficiently'},
 'suffocation': {'n_is_nu': '', 'n_is_sth': ''},
 'suffrage': {'n_is_nu': '', 'n_is_sth': ''},
 'sugarcane': {'n_is_nu': '', 'n_is_sth': ''},
 'suitability': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'suit', 'nn_to_jj': 'suited'},
 'suiting': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'suit', 'nn_to_jj': 'suited', 'vbg_to_vb': 'suit', 'vbg_to_vbn': 'suited'},
 'sulfate': {'n_is_nu': '', 'n_is_sth': ''},
 'sulfide': {'n_is_nu': '', 'n_is_sth': ''},
 'sulfur': {'n_is_nu': '', 'n_is_sth': ''},
 'sulphur': {'n_is_nu': '', 'n_is_sth': ''},
 'sultan': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'sultriness': {'n_is_nu': '', 'n_is_sth': ''},
 'summertime': {'n_is_nu': '', 'n_is_sth': ''},
 'sumo': {'n_is_nu': '', 'n_is_sth': ''},
 'sumptuousness': {'n_is_nu': '', 'n_is_sth': ''},
 'sunburn': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'sundown': {'n_is_nu': '', 'n_is_sth': ''},
 'sunlight': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'sunny', 'nn_to_rb': 'sunnily', 'nu_typical': ''},
 'sunniness': {'n_is_nu': '', 'n_is_sth': ''},
 'sunshine': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'shine', 'nn_to_jj': 'shiny', 'nn_to_rb': 'sunnily', 'nu_typical': ''},
 'sunstroke': {'n_is_nu': '', 'n_is_sth': ''},
 'superabundance': {'n_is_nu': '', 'n_is_sth': ''},
 'superconductivity': {'n_is_nu': '', 'n_is_sth': ''},
 'superiority': {'n_is_nu': '', 'n_is_sth': ''},
 'supernatural': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'superoxide': {'n_is_nu': '', 'n_is_sth': ''},
 'superposition': {'n_is_nu': '', 'n_is_sth': ''},
 'superpower': {'n_is_nu': '', 'n_is_sth': ''},
 'supervision': {'n_is_nu': '', 'n_is_sth': ''},
 'suppleness': {'n_is_nu': '', 'n_is_sth': ''},
 'supplication': {'n_is_nu': '', 'n_is_sth': ''},
 'suppression': {'n_is_nu': '', 'n_is_sth': ''},
 'supremacy': {'n_is_nu': '', 'n_is_sth': ''},
 'surcease': {'n_is_nu': '', 'n_is_sth': ''},
 'sureness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'sure', 'nn_to_rb': 'sure'},
 'surinam': {'n_is_nu': '', 'n_is_sth': ''},
 'surmise': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'surtax': {'n_is_nu': '', 'n_is_sth': ''},
 'surveillance': {'n_is_nu': '', 'n_is_sth': ''},
 'surveying': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'survey'},
 'sushi': {'n_is_nu': '', 'n_is_sth': ''},
 'suspense': {'n_is_nu': '', 'n_is_sth': ''},
 'sustenance': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'sustain', 'nn_to_jj': 'sustained'},
 'suzerainty': {'n_is_nu': '', 'n_is_sth': ''},
 'swagger': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'sward': {'n_is_nu': '', 'n_is_sth': ''},
 'swath': {'n_is_nu': '', 'n_is_sth': ''},
 'sweetness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'sweet', 'nn_to_rb': 'sweetly'},
 'swiftness': {'n_is_nu': '', 'n_is_sth': ''},
 'swimwear': {'n_is_nu': '', 'n_is_sth': ''},
 'swizzle': {'n_is_nu': '', 'n_is_sth': ''},
 'swordplay': {'n_is_nu': '', 'n_is_sth': ''},
 'swordsmanship': {'n_is_nu': '', 'n_is_sth': ''},
 'sycophancy': {'n_is_nu': '', 'n_is_sth': ''},
 'symbiosis': {'n_is_nu': '', 'n_is_sth': ''},
 'symbolism': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'symbolise', 'nn_to_jj': 'symbolic', 'nn_to_rb': 'symbolically'},
 'symbology': {'n_is_nu': '', 'n_is_sth': ''},
 'symmetry': {'n_is_nu': '', 'n_is_sth': ''},
 'sympathy': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'sympathetic', 'nn_to_rb': 'sympathetically'},
 'synchronization': {'n_is_nu': '', 'n_is_sth': ''},
 'syncopation': {'n_is_nu': '', 'n_is_sth': ''},
 'syncretism': {'n_is_nu': '', 'n_is_sth': ''},
 'syndrome': {'n_is_nu': '', 'n_is_sth': ''},
 'synergism': {'n_is_nu': '', 'n_is_sth': ''},
 'synergy': {'n_is_nu': '', 'n_is_sth': ''},
 'synonym': {'n_is_nu': '', 'n_is_sth': ''},
 'synonymy': {'n_is_nu': '', 'n_is_sth': ''},
 'syntax': {'n_is_nu': '', 'n_is_sth': ''},
 'syphilis': {'n_is_nu': '', 'n_is_sth': ''},
 'syrup': {'n_is_nu': '', 'n_is_sth': ''},
 'ta': {'n_is_nu': '', 'n_is_sth': ''},
 'tabletop': {'n_is_nu': '', 'n_is_sth': ''},
 'tableware': {'n_is_nu': '', 'n_is_sth': ''},
 'taciturnity': {'n_is_nu': '', 'n_is_sth': ''},
 'tact': {'n_is_nu': '', 'n_is_sth': ''},
 'tactility': {'n_is_nu': '', 'n_is_sth': ''},
 'taffeta': {'n_is_nu': '', 'n_is_sth': ''},
 'taffy': {'n_is_nu': '', 'n_is_sth': ''},
 'taichung': {'n_is_nu': '', 'n_is_sth': ''},
 'tailing': {'n_is_nu': '', 'n_is_sth': ''},
 'taint': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'taiyuan': {'n_is_nu': '', 'n_is_sth': ''},
 'take-up': {'n_is_nu': '', 'n_is_sth': ''},
 'takedown': {'n_is_nu': '', 'n_is_sth': ''},
 'takeoff': {'n_is_nu': '', 'n_is_sth': ''},
 'talc': {'n_is_nu': '', 'n_is_sth': ''},
 'talcum': {'n_is_nu': '', 'n_is_sth': ''},
 'tallness': {'n_is_nu': '', 'n_is_sth': ''},
 'tallow': {'n_is_nu': '', 'n_is_sth': ''},
 'tameness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'tame', 'nn_to_jj': 'tame'},
 'tangshan': {'n_is_nu': '', 'n_is_sth': ''},
 'tannin': {'n_is_nu': '', 'n_is_sth': ''},
 'tantalum': {'n_is_nu': '', 'n_is_sth': ''},
 'tao': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'taoism': {'n_is_nu': '', 'n_is_sth': ''},
 'tapioca': {'n_is_nu': '', 'n_is_sth': ''},
 'tapping': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'tap', 'nn_to_jj': 'tapped'},
 'tar': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'vbd_eq_vbn': ''},
 'tardiness': {'n_is_nu': '', 'n_is_sth': ''},
 'tarmac': {'n_is_nu': '', 'n_is_sth': ''},
 'tarnish': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'tattle': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'tautness': {'n_is_nu': '', 'n_is_sth': ''},
 'taxation': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'tax', 'nn_to_jj': 'taxable', 'nn_to_rb': 'taxably'},
 'taxonomy': {'n_is_nu': '', 'n_is_sth': ''},
 'tb': {'n_is_nu': '', 'n_is_sth': ''},
 'teak': {'n_is_nu': '', 'n_is_sth': ''},
 'teakettle': {'n_is_nu': '', 'n_is_sth': ''},
 'teamwork': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'tech': {'n_is_nu': '', 'n_is_sth': ''},
 'technetium': {'n_is_nu': '', 'n_is_sth': ''},
 'technicality': {'n_is_nu': '', 'n_is_sth': ''},
 'tediousness': {'n_is_nu': '', 'n_is_sth': ''},
 'tedium': {'n_is_nu': '', 'n_is_sth': ''},
 'telecommunication': {'n_is_nu': '', 'n_is_sth': ''},
 'telegraphy': {'n_is_nu': '', 'n_is_sth': ''},
 'telemetry': {'n_is_nu': '', 'n_is_sth': ''},
 'telephony': {'n_is_nu': '', 'n_is_sth': ''},
 'temerity': {'n_is_nu': '', 'n_is_sth': ''},
 'tempera': {'n_is_nu': '', 'n_is_sth': ''},
 'temperance': {'n_is_nu': '', 'n_is_sth': ''},
 'tenacity': {'n_is_nu': '', 'n_is_sth': ''},
 'tenderloin': {'n_is_nu': '', 'n_is_sth': ''},
 'tenderness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'tender', 'nn_to_jj': 'tender', 'nn_to_rb': 'tenderly'},
 'tendon': {'n_is_nu': '', 'n_is_sth': ''},
 'tennis': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'tenseness': {'n_is_nu': '', 'n_is_sth': ''},
 'tenure': {'n_is_nu': '', 'n_is_sth': ''},
 'termination': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'terminate', 'nn_to_jj': 'terminate'},
 'territoriality': {'n_is_nu': '', 'n_is_sth': ''},
 'terrorism': {'n_is_nu': '', 'n_is_sth': ''},
 'tertiary': {'n_is_nu': '', 'n_is_sth': ''},
 'testiness': {'n_is_nu': '', 'n_is_sth': ''},
 'tetanus': {'n_is_nu': '', 'n_is_sth': ''},
 'tetracycline': {'n_is_nu': '', 'n_is_sth': ''},
 'thalidomide': {'n_is_nu': '', 'n_is_sth': ''},
 'thallium': {'n_is_nu': '', 'n_is_sth': ''},
 'thames': {'n_is_nu': '', 'n_is_sth': ''},
 'thankfulness': {'n_is_nu': '', 'n_is_sth': ''},
 'theatricality': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'theatricalize', 'nn_to_jj': 'theatrical', 'nn_to_rb': 'theatrically'},
 'theism': {'n_is_nu': '', 'n_is_sth': ''},
 'therapeutics': {'n_is_nu': '', 'n_is_sth': ''},
 'thermodynamics': {'n_is_nu': '', 'n_is_sth': ''},
 'thiamine': {'n_is_nu': '', 'n_is_sth': ''},
 'thickness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'thick', 'nn_to_rb': 'thickly'},
 'thievery': {'n_is_nu': '', 'n_is_sth': ''},
 'thinner': {'n_is_nu': '', 'n_is_sth': ''},
 'thole': {'n_is_nu': '', 'n_is_sth': ''},
 'thorium': {'n_is_nu': '', 'n_is_sth': ''},
 'thoroughness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'thorough', 'nn_to_rb': 'thoroughly'},
 'thoughtfulness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'think', 'nn_to_jj': 'think', 'nn_to_rb': 'thoughtfully'},
 'thrash': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'thrift': {'n_is_nu': '', 'n_is_sth': ''},
 'throughput': {'n_is_nu': '', 'n_is_sth': ''},
 'throw': {'n_is_nu': '', 'n_is_sth': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'throws', 'vb_to_vbd': 'threw', 'vb_to_vbn': 'thrown', 'vb_to_vbg': 'throwing', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'tianjin': {'n_is_nu': '', 'n_is_sth': ''},
 'tibet': {'n_is_nu': '', 'n_is_sth': ''},
 'tickle': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'ticktock': {'n_is_nu': '', 'n_is_sth': ''},
 'tidewater': {'n_is_nu': '', 'n_is_sth': ''},
 'tidiness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'tidy', 'nn_to_jj': 'tidy', 'nn_to_rb': 'tidily'},
 'tie-in': {'n_is_nu': '', 'n_is_sth': ''},
 'tiffany': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'tiffin': {'n_is_nu': '', 'n_is_sth': ''},
 'tightness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'tighten', 'nn_to_jj': 'tight', 'nn_to_rb': 'tightly'},
 'tiling': {'n_is_nu': '', 'n_is_sth': ''},
 'tillage': {'n_is_nu': '', 'n_is_sth': ''},
 'tilth': {'n_is_nu': '', 'n_is_sth': ''},
 'timbre': {'n_is_nu': '', 'n_is_sth': ''},
 'timeliness': {'n_is_nu': '', 'n_is_sth': ''},
 'timidity': {'n_is_nu': '', 'n_is_sth': ''},
 'tinder': {'n_is_nu': '', 'n_is_sth': ''},
 'tinfoil': {'n_is_nu': '', 'n_is_sth': ''},
 'tinnitus': {'n_is_nu': '', 'n_is_sth': ''},
 'tinplate': {'n_is_nu': '', 'n_is_sth': ''},
 'tinsel': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'tip-off': {'n_is_nu': '', 'n_is_sth': ''},
 'tiptoe': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'tirana': {'n_is_nu': '', 'n_is_sth': ''},
 'tiredness': {'n_is_nu': '', 'n_is_sth': ''},
 'titanium': {'n_is_nu': '', 'n_is_sth': ''},
 'titillation': {'n_is_nu': '', 'n_is_sth': ''},
 'tnt': {'n_is_nu': '', 'n_is_sth': ''},
 'today': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'tofu': {'n_is_nu': '', 'n_is_sth': ''},
 'toil': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'toilette': {'n_is_nu': '', 'n_is_sth': ''},
 'tole': {'n_is_nu': '', 'n_is_sth': ''},
 'toleration': {'n_is_nu': '', 'n_is_sth': ''},
 'tolstoy': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'toluene': {'n_is_nu': '', 'n_is_sth': ''},
 'tomorrow': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'tonight': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'tonsillitis': {'n_is_nu': '', 'n_is_sth': ''},
 'topicality': {'n_is_nu': '', 'n_is_sth': ''},
 'topography': {'n_is_nu': '', 'n_is_sth': ''},
 'topside': {'n_is_nu': '', 'n_is_sth': ''},
 'topsoil': {'n_is_nu': '', 'n_is_sth': ''},
 'torchlight': {'n_is_nu': '', 'n_is_sth': ''},
 'torpor': {'n_is_nu': '', 'n_is_sth': ''},
 'torque': {'n_is_nu': '', 'n_is_sth': ''},
 'torsion': {'n_is_nu': '', 'n_is_sth': ''},
 'tosh': {'n_is_nu': '', 'n_is_sth': ''},
 'totalitarianism': {'n_is_nu': '', 'n_is_sth': ''},
 'totality': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'totalize', 'nn_to_jj': 'total', 'nn_to_rb': 'totally'},
 'toughness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'toughen', 'nn_to_jj': 'tough', 'nn_to_rb': 'toughly'},
 'tourism': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'tourmaline': {'n_is_nu': '', 'n_is_sth': ''},
 'toxicity': {'n_is_nu': '', 'n_is_sth': ''},
 'toxicology': {'n_is_nu': '', 'n_is_sth': ''},
 'trachoma': {'n_is_nu': '', 'n_is_sth': ''},
 'tracing': {'n_is_nu': '', 'n_is_sth': ''},
 'traction': {'n_is_nu': '', 'n_is_sth': '0'},
 'tradeoff': {'n_is_nu': '', 'n_is_sth': ''},
 'training': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'tranquility': {'n_is_nu': '', 'n_is_sth': ''},
 'tranquillity': {'n_is_nu': '', 'n_is_sth': ''},
 'transcendence': {'n_is_nu': '', 'n_is_sth': ''},
 'transference': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'transfer', 'nn_to_jj': 'transferable'},
 'transfiguration': {'n_is_nu': '', 'n_is_sth': ''},
 'transience': {'n_is_nu': '', 'n_is_sth': ''},
 'transit': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'transitory', 'nn_to_rb': 'transitionally', 'vb_to_rb': 'transitionally', 'vb_to_jj': 'transitory', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'transmogrification': {'n_is_nu': '', 'n_is_sth': ''},
 'transparency': {'n_is_nu': '', 'n_is_sth': ''},
 'transplantation': {'n_is_nu': '', 'n_is_sth': ''},
 'transportation': {'n_is_nu': '', 'n_is_sth': ''},
 'transubstantiation': {'n_is_nu': '', 'n_is_sth': ''},
 'trash': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'trashiness': {'n_is_nu': '', 'n_is_sth': ''},
 'traveling': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'travel', 'vbg_to_vbn': 'travelled'},
 'treacle': {'n_is_nu': '', 'n_is_sth': ''},
 'treadle': {'n_is_nu': '', 'n_is_sth': ''},
 'treason': {'n_is_nu': '', 'n_is_sth': ''},
 'treillage': {'n_is_nu': '', 'n_is_sth': ''},
 'trepidation': {'n_is_nu': '', 'n_is_sth': ''},
 'triangulation': {'n_is_nu': '', 'n_is_sth': ''},
 'triassic': {'n_is_nu': '', 'n_is_sth': ''},
 'tribalism': {'n_is_nu': '', 'n_is_sth': ''},
 'trichinosis': {'n_is_nu': '', 'n_is_sth': ''},
 'trichomoniasis': {'n_is_nu': '', 'n_is_sth': ''},
 'trickery': {'n_is_nu': '', 'n_is_sth': ''},
 'trickiness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'trick', 'nn_to_jj': 'trickish'},
 'trigonometry': {'n_is_nu': '', 'n_is_sth': ''},
 'trimming': {'n_is_nu': '', 'n_is_sth': ''},
 'trinity': {'n_is_nu': '', 'n_is_sth': ''},
 'tripe': {'n_is_nu': '', 'n_is_sth': ''},
 'triteness': {'n_is_nu': '', 'n_is_sth': ''},
 'tritium': {'n_is_nu': '', 'n_is_sth': ''},
 'triton': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'troposphere': {'n_is_nu': '', 'n_is_sth': ''},
 'troth': {'n_is_nu': '', 'n_is_sth': ''},
 'truancy': {'n_is_nu': '', 'n_is_sth': ''},
 'truculence': {'n_is_nu': '', 'n_is_sth': ''},
 'true': {'n_is_nu': '', 'n_is_sth': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'jj_to_jjr': 'truer', 'jj_to_jjs': 'truest'},
 'truism': {'n_is_nu': '', 'n_is_sth': ''},
 'trustworthiness': {'n_is_nu': '', 'n_is_sth': ''},
 'truthfulness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'TRUE', 'nn_to_rb': 'truly'},
 'tuberculosis': {'n_is_nu': '', 'n_is_sth': ''},
 'tubing': {'n_is_nu': '', 'n_is_sth': ''},
 'tuff': {'n_is_nu': '', 'n_is_sth': ''},
 'tug-of-war': {'n_is_nu': '', 'n_is_sth': ''},
 'tulle': {'n_is_nu': '', 'n_is_sth': ''},
 'tumbling': {'n_is_nu': '', 'n_is_sth': ''},
 'tundra': {'n_is_nu': '', 'n_is_sth': ''},
 'tungsten': {'n_is_nu': '', 'n_is_sth': ''},
 'tuning': {'n_is_nu': '', 'n_is_sth': ''},
 'turbidity': {'n_is_nu': '', 'n_is_sth': ''},
 'turbulence': {'n_is_nu': '', 'n_is_sth': ''},
 'turkmen': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'turmeric': {'n_is_nu': '', 'n_is_sth': ''},
 'turmoil': {'n_is_nu': '', 'n_is_sth': ''},
 'turpentine': {'n_is_nu': '', 'n_is_sth': ''},
 'turpitude': {'n_is_nu': '', 'n_is_sth': ''},
 'turquoise': {'n_is_nu': '', 'n_is_sth': ''},
 'tutelage': {'n_is_nu': '', 'n_is_sth': ''},
 'twaddle': {'n_is_nu': '', 'n_is_sth': ''},
 'tweak': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'tweed': {'n_is_nu': '', 'n_is_sth': ''},
 'twill': {'n_is_nu': '', 'n_is_sth': ''},
 'twine': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'twinkling': {'n_is_nu': '', 'n_is_sth': ''},
 'typhoid': {'n_is_nu': '', 'n_is_sth': ''},
 'typhus': {'n_is_nu': '', 'n_is_sth': ''},
 'typography': {'n_is_nu': '', 'n_is_sth': ''},
 'ubiquity': {'n_is_nu': '', 'n_is_sth': ''},
 'ugliness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'ulysses': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'umbilicus': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'umbrage': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'unanimity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'unavailability': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'unawareness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'unbelief': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'unconcern': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'unconscious': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'unconsciousness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'underestimation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'undergrowth': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'underpart': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'undervaluation': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'underwear': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nu_typical': ''},
 'undesirability': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'undoing': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'unease': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'unemployment': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nu_typical': ''},
 'unfairness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'unfaithfulness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'unification': {'n_is_nu': '', 'n_is_sth': ''},
 'uniformity': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'uniform', 'nn_to_jj': 'uniform', 'nn_to_rb': 'uniformly'},
 'unilateralism': {'n_is_nu': '', 'n_is_sth': ''},
 'unionism': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'union'},
 'uniqueness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'unique', 'nn_to_rb': 'uniquely'},
 'unison': {'n_is_nu': '', 'n_is_sth': ''},
 'universalism': {'n_is_nu': '', 'n_is_sth': ''},
 'universality': {'n_is_nu': '', 'n_is_sth': ''},
 'unpleasantness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'unpopularity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'unreality': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'unreason': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'unrest': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'nu_typical': ''},
 'unruliness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'unwieldiness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'unwillingness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'upbeat': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'upbringing': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'upholstery': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'upkeep': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'uplift': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'upright': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'uprightness': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'uproar': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'upshot': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'upstage': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'vbd_eq_vbn': ''},
 'uranium': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'uranus': {'n_is_nu': '', 'n_is_sth': '', 'art_an': '', 'n_is_sb': '2'},
 'urbanity': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'urbanization': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'urea': {'n_is_nu': '', 'n_is_sth': ''},
 'urination': {'n_is_nu': '', 'n_is_sth': ''},
 'urine': {'n_is_nu': '', 'n_is_sth': ''},
 'urology': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'usa': {'n_is_nu': '', 'n_is_sth': ''},
 'usability': {'n_is_nu': '', 'n_is_sth': ''},
 'usefulness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'use', 'nn_to_jj': 'useful', 'nn_to_rb': 'usefully'},
 'uselessness': {'n_is_nu': '', 'n_is_sth': ''},
 'ussr': {'n_is_nu': '', 'n_is_sth': ''},
 'usurpation': {'n_is_nu': '', 'n_is_sth': ''},
 'usury': {'n_is_nu': '', 'n_is_sth': ''},
 'utilitarianism': {'n_is_nu': '', 'n_is_sth': ''},
 'utilization': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'utilize', 'nn_to_jj': 'utilisable'},
 'utmost': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'utopia': {'n_is_nu': '', 'n_is_sth': '', 'art_an': ''},
 'vacancy': {'n_is_nu': '', 'n_is_sth': ''},
 'vacuity': {'n_is_nu': '', 'n_is_sth': ''},
 'vaginitis': {'n_is_nu': '', 'n_is_sth': ''},
 'vagrancy': {'n_is_nu': '', 'n_is_sth': ''},
 'vagueness': {'n_is_nu': '', 'n_is_sth': ''},
 'vainglory': {'n_is_nu': '', 'n_is_sth': ''},
 'valency': {'n_is_nu': '', 'n_is_sth': ''},
 'validity': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'validate', 'nn_to_jj': 'valid', 'nn_to_rb': 'validly'},
 'valium': {'n_is_nu': '', 'n_is_sth': ''},
 'valor': {'n_is_nu': '', 'n_is_sth': ''},
 'valour': {'n_is_nu': '', 'n_is_sth': ''},
 'vanadium': {'n_is_nu': '', 'n_is_sth': ''},
 'vanilla': {'n_is_nu': '', 'n_is_sth': ''},
 'vanity': {'n_is_nu': '', 'n_is_sth': ''},
 'vaporization': {'n_is_nu': '', 'n_is_sth': ''},
 'variability': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'vary', 'nn_to_jj': 'variable', 'nn_to_rb': 'variably'},
 'variegation': {'n_is_nu': '', 'n_is_sth': ''},
 'variola': {'n_is_nu': '', 'n_is_sth': ''},
 'vaseline': {'n_is_nu': '', 'n_is_sth': ''},
 'vastness': {'n_is_nu': '', 'n_is_sth': ''},
 'vega': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'vegetarianism': {'n_is_nu': '', 'n_is_sth': ''},
 'vegetation': {'n_is_nu': '', 'n_is_sth': ''},
 'vehemence': {'n_is_nu': '', 'n_is_sth': ''},
 'veiling': {'n_is_nu': '', 'n_is_sth': ''},
 'velvet': {'n_is_nu': '', 'n_is_sth': ''},
 'velveteen': {'n_is_nu': '', 'n_is_sth': ''},
 'venality': {'n_is_nu': '', 'n_is_sth': ''},
 'venerability': {'n_is_nu': '', 'n_is_sth': ''},
 'veneration': {'n_is_nu': '', 'n_is_sth': ''},
 'vengeance': {'n_is_nu': '', 'n_is_sth': ''},
 'venison': {'n_is_nu': '', 'n_is_sth': ''},
 'venom': {'n_is_nu': '', 'n_is_sth': ''},
 'ventriloquism': {'n_is_nu': '', 'n_is_sth': ''},
 'venus': {'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'veracity': {'n_is_nu': '', 'n_is_sth': ''},
 'verbiage': {'n_is_nu': '', 'n_is_sth': ''},
 'verbosity': {'n_is_nu': '', 'n_is_sth': ''},
 'verdigris': {'n_is_nu': '', 'n_is_sth': ''},
 'verdure': {'n_is_nu': '', 'n_is_sth': ''},
 'verisimilitude': {'n_is_nu': '', 'n_is_sth': ''},
 'vermicelli': {'n_is_nu': '', 'n_is_sth': ''},
 'vermilion': {'n_is_nu': '', 'n_is_sth': ''},
 'versailles': {'n_is_nu': '', 'n_is_sth': ''},
 'versatility': {'n_is_nu': '', 'n_is_sth': ''},
 'verticality': {'n_is_nu': '', 'n_is_sth': ''},
 'vertigo': {'n_is_nu': '', 'n_is_sth': ''},
 'verve': {'n_is_nu': '', 'n_is_sth': ''},
 'vetch': {'n_is_nu': '', 'n_is_sth': ''},
 'vibrancy': {'n_is_nu': '', 'n_is_sth': ''},
 'viciousness': {'n_is_nu': '', 'n_is_sth': ''},
 'victimization': {'n_is_nu': '', 'n_is_sth': ''},
 'vigilance': {'n_is_nu': '', 'n_is_sth': ''},
 'vigor': {'n_is_nu': '', 'n_is_sth': ''},
 'vilification': {'n_is_nu': '', 'n_is_sth': ''},
 'villainy': {'n_is_nu': '', 'n_is_sth': ''},
 'vim': {'n_is_nu': '', 'n_is_sth': ''},
 'vindication': {'n_is_nu': '', 'n_is_sth': ''},
 'vinegar': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'vino': {'n_is_nu': '', 'n_is_sth': ''},
 'violence': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'violent', 'nn_to_rb': 'violently', 'nu_typical': ''},
 'virginity': {'n_is_nu': '', 'n_is_sth': ''},
 'virgo': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'virility': {'n_is_nu': '', 'n_is_sth': ''},
 'virology': {'n_is_nu': '', 'n_is_sth': ''},
 'virulence': {'n_is_nu': '', 'n_is_sth': ''},
 'viscose': {'n_is_nu': '', 'n_is_sth': ''},
 'viscosity': {'n_is_nu': '', 'n_is_sth': ''},
 'visibility': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'visible', 'nn_to_rb': 'visibly'},
 'visualization': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'visualise', 'nn_to_jj': 'visual', 'nn_to_rb': 'visually'},
 'vitality': {'n_is_nu': '', 'n_is_sth': ''},
 'vitamin': {'n_is_nu': '', 'n_is_sth': ''},
 'vitiligo': {'n_is_nu': '', 'n_is_sth': ''},
 'vitriol': {'n_is_nu': '', 'n_is_sth': ''},
 'vituperation': {'n_is_nu': '', 'n_is_sth': ''},
 'vivacity': {'n_is_nu': '', 'n_is_sth': ''},
 'vocalism': {'n_is_nu': '', 'n_is_sth': ''},
 'void': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'volatility': {'n_is_nu': '', 'n_is_sth': ''},
 'volga': {'n_is_nu': '', 'n_is_sth': ''},
 'volition': {'n_is_nu': '', 'n_is_sth': ''},
 'volley': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'volubility': {'n_is_nu': '', 'n_is_sth': ''},
 'voracity': {'n_is_nu': '', 'n_is_sth': ''},
 'vulcan': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'vulcanization': {'n_is_nu': '', 'n_is_sth': ''},
 'vulgarization': {'n_is_nu': '', 'n_is_sth': ''},
 'vulnerability': {'n_is_nu': '', 'n_is_sth': ''},
 'wadding': {'n_is_nu': '', 'n_is_sth': ''},
 'waiting': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'wait', 'vbg_to_vbn': 'waited'},
 'wakefulness': {'n_is_nu': '', 'n_is_sth': ''},
 'walkout': {'n_is_nu': '', 'n_is_sth': ''},
 'wallop': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'wallpaper': {'n_is_nu': '', 'n_is_sth': ''},
 'waltz': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'wampum': {'n_is_nu': '', 'n_is_sth': ''},
 'wan': {'n_is_nu': '', 'n_is_sth': '', 'jj_to_jjr': 'wanner', 'jj_to_jjs': 'wannest'},
 'wane': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'wangle': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'warfare': {'n_is_nu': '', 'n_is_sth': ''},
 'wariness': {'n_is_nu': '', 'n_is_sth': ''},
 'warmth': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'warm', 'nn_to_jj': 'warm', 'nn_to_rb': 'warmly', 'nu_typical': ''},
 'wartime': {'n_is_nu': '', 'n_is_sth': ''},
 'washing': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'wash', 'vbg_to_vbn': 'washed'},
 'wastage': {'n_is_nu': '', 'n_is_sth': ''},
 'wastewater': {'n_is_nu': '', 'n_is_sth': ''},
 'watchfulness': {'n_is_nu': '', 'n_is_sth': ''},
 'water': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'waterless', 'v_n': '', 'nsubjpass': '', 'vb_to_jj': 'waterless', 'v_compcl_non': ''},
 'waterloo': {'n_is_nu': '', 'n_is_sth': ''},
 'waveform': {'n_is_nu': '', 'n_is_sth': ''},
 'wax': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'waxy', 'nn_to_rb': 'waxily', 'vb_to_rb': 'waxily', 'vb_to_jj': 'waxy', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'weal': {'n_is_nu': '', 'n_is_sth': ''},
 'wealth': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'wealthy', 'nn_to_rb': 'wealthily'},
 'weaponry': {'n_is_nu': '', 'n_is_sth': ''},
 'wear': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'wearable', 'nn_to_rb': 'wearily', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'wears', 'vb_to_vbd': 'wore', 'vb_to_vbn': 'worn', 'vb_to_rb': 'wearily', 'vb_to_jj': 'wearable', 'vb_to_vbg': 'wearing', 'v_compcl_non': ''},
 'weariness': {'n_is_nu': '', 'n_is_sth': ''},
 'weather': {'n_is_nu': '', 'n_is_sth': '', 'v_infcl_non': ''},
 'weave': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'woven', 'vb_to_jj': 'woven', 'v_compcl_non': ''},
 'weaving': {'n_is_nu': '', 'n_is_sth': ''},
 'wedlock': {'n_is_nu': '', 'n_is_sth': ''},
 'weft': {'n_is_nu': '', 'n_is_sth': ''},
 'weightiness': {'n_is_nu': '', 'n_is_sth': ''},
 'weightlessness': {'n_is_nu': '', 'n_is_sth': ''},
 'welfare': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'well-being': {'n_is_nu': '', 'n_is_sth': ''},
 'wellbeing': {'n_is_nu': '', 'n_is_sth': ''},
 'weltanschauung': {'n_is_nu': '', 'n_is_sth': ''},
 'west': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2'},
 'westernization': {'n_is_nu': '', 'n_is_sth': ''},
 'westminster': {'n_is_nu': '', 'n_is_sth': '', 'cap_word': 'Westminster'},
 'westward': {'n_is_nu': '', 'n_is_sth': ''},
 'wetness': {'n_is_nu': '', 'n_is_sth': ''},
 'whalebone': {'n_is_nu': '', 'n_is_sth': ''},
 'wheat': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'wheatgrass': {'n_is_nu': '', 'n_is_sth': ''},
 'wherewithal': {'n_is_nu': '', 'n_is_sth': ''},
 'whey': {'n_is_nu': '', 'n_is_sth': ''},
 'whinny': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'whiskey': {'n_is_nu': '', 'n_is_sth': ''},
 'whisky': {'n_is_nu': '', 'n_is_sth': ''},
 'whist': {'n_is_nu': '', 'n_is_sth': ''},
 'whiteness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'whiten', 'nn_to_jj': 'white'},
 'whitening': {'n_is_nu': '', 'n_is_sth': ''},
 'wholeness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'whole', 'nn_to_rb': 'wholly'},
 'wholesale': {'n_is_nu': '', 'n_is_sth': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'whoredom': {'n_is_nu': '', 'n_is_sth': ''},
 'wickedness': {'n_is_nu': '', 'n_is_sth': ''},
 'widowhood': {'n_is_nu': '', 'n_is_sth': ''},
 'width': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'widen', 'nn_to_jj': 'wide', 'nn_to_rb': 'widely'},
 'wilderness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'wild', 'nn_to_rb': 'wildly'},
 'wildness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'wild', 'nn_to_rb': 'wildly'},
 'wiliness': {'n_is_nu': '', 'n_is_sth': ''},
 'willpower': {'n_is_nu': '', 'n_is_sth': ''},
 'wimple': {'n_is_nu': '', 'n_is_sth': ''},
 'windburn': {'n_is_nu': '', 'n_is_sth': ''},
 'winding': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'wind', 'vbg_to_vbn': 'winded,wound'},
 'windup': {'n_is_nu': '', 'n_is_sth': ''},
 'windward': {'n_is_nu': '', 'n_is_sth': ''},
 'wintertime': {'n_is_nu': '', 'n_is_sth': ''},
 'wipe': {'n_is_nu': '', 'n_is_sth': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'wipes', 'vb_to_vbd': 'wiped', 'vb_to_vbn': 'wiped', 'vb_to_vbg': 'wiping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'wipeout': {'n_is_nu': '', 'n_is_sth': ''},
 'wiring': {'n_is_nu': '', 'n_is_sth': ''},
 'wisdom': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'wisen', 'nn_to_jj': 'wise', 'nn_to_rb': 'wisely', 'nu_typical': ''},
 'witchcraft': {'n_is_nu': '', 'n_is_sth': ''},
 'witchery': {'n_is_nu': '', 'n_is_sth': ''},
 'wizardry': {'n_is_nu': '', 'n_is_sth': ''},
 'wolfram': {'n_is_nu': '', 'n_is_sth': ''},
 'womanhood': {'n_is_nu': '', 'n_is_sth': ''},
 'womankind': {'n_is_nu': '', 'n_is_sth': ''},
 'wonderment': {'n_is_nu': '', 'n_is_sth': ''},
 'wont': {'n_is_nu': '', 'n_is_sth': ''},
 'wonton': {'n_is_nu': '', 'n_is_sth': ''},
 'woodcraft': {'n_is_nu': '', 'n_is_sth': ''},
 'woodland': {'n_is_nu': '', 'n_is_sth': ''},
 'woodwork': {'n_is_nu': '', 'n_is_sth': ''},
 'wool': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '2', 'nn_to_vb': 'woollen', 'nn_to_jj': 'woolly', 'nu_typical': ''},
 'wordiness': {'n_is_nu': '', 'n_is_sth': ''},
 'wording': {'n_is_nu': '', 'n_is_sth': ''},
 'wordplay': {'n_is_nu': '', 'n_is_sth': ''},
 'working': {'n_is_nu': '', 'n_is_sth': '', 'vbg_to_vb': 'work', 'vbg_to_vbn': 'worked'},
 'workmanship': {'n_is_nu': '', 'n_is_sth': ''},
 'wormwood': {'n_is_nu': '', 'n_is_sth': ''},
 'worse': {'n_is_nu': '', 'n_is_sth': ''},
 'worship': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'worshipful', 'nn_to_rb': 'worshipfully', 'vb_to_rb': 'worshipfully', 'vb_to_jj': 'worshipful', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'wow': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': ''},
 'wrath': {'n_is_nu': '', 'n_is_sth': ''},
 'wreckage': {'n_is_nu': '', 'n_is_sth': ''},
 'wrestling': {'n_is_nu': '', 'n_is_sth': ''},
 'wretchedness': {'n_is_nu': '', 'n_is_sth': ''},
 'wuhan': {'n_is_nu': '', 'n_is_sth': ''},
 'www': {'n_is_nu': '', 'n_is_sth': ''},
 'wye': {'n_is_nu': '', 'n_is_sth': ''},
 'xenon': {'n_is_nu': '', 'n_is_sth': ''},
 'xi': {'n_is_nu': '', 'n_is_sth': ''},
 'xinjiang': {'n_is_nu': '', 'n_is_sth': ''},
 'xmas': {'n_is_nu': '', 'n_is_sth': ''},
 'xylem': {'n_is_nu': '', 'n_is_sth': ''},
 'yalta': {'n_is_nu': '', 'n_is_sth': ''},
 'yanan': {'n_is_nu': '', 'n_is_sth': ''},
 'yang': {'n_is_nu': '', 'n_is_sth': ''},
 'yeast': {'n_is_nu': '', 'n_is_sth': ''},
 'yesterday': {'n_is_nu': '', 'n_is_sth': '', 'nu_typical': ''},
 'yesteryear': {'n_is_nu': '', 'n_is_sth': ''},
 'yin': {'n_is_nu': '', 'n_is_sth': ''},
 'yokohama': {'n_is_nu': '', 'n_is_sb': '0'},
 'yolk': {'n_is_nu': '', 'n_is_sth': ''},
 'yore': {'n_is_nu': '', 'n_is_sth': ''},
 'youthfulness': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_vb': 'youthen', 'nn_to_jj': 'youthful', 'nn_to_rb': 'youthfully'},
 'yuan': {'n_is_nu': '', 'n_is_sth': '', 'n_is_unit': ''},
 'yue': {'n_is_nu': '', 'n_is_sth': ''},
 'yunnan': {'n_is_nu': '', 'n_is_sth': ''},
 'zaire': {'n_is_nu': '', 'n_is_sth': ''},
 'zanzibar': {'n_is_nu': '', 'n_is_sth': ''},
 'zap': {'n_is_nu': '', 'n_is_sth': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'zeal': {'n_is_nu': '', 'n_is_sth': '', 'nn_to_jj': 'zealous'},
 'zealotry': {'n_is_nu': '', 'n_is_sth': ''},
 'zest': {'n_is_nu': '', 'n_is_sth': ''},
 'zeus': {'n_is_nu': '', 'n_is_sth': '', 'n_is_sb': '0'},
 'zhou': {'n_is_nu': '', 'n_is_sth': ''},
 'zhuang': {'n_is_nu': '', 'n_is_sth': ''},
 'zilch': {'n_is_nu': '', 'n_is_sb': '2', 'n_is_sth': ''},
 'zinc': {'n_is_nu': '', 'n_is_sth': ''},
 'zing': {'n_is_nu': '', 'n_is_sth': ''},
 'zion': {'n_is_nu': '', 'n_is_sth': ''},
 'zoroastrianism': {'n_is_nu': '', 'n_is_sth': ''},
 'I': {'n_is_sb': '0', 'prp_sub_to_obj': 'me', 'prp_is_sub_case': ''},
 'apollo': {'n_is_sb': '0', 'art_an': ''},
 'arab': {'n_is_sb': '0', 'art_an': '', 'cap_word': 'Arab'},
 'bach': {'n_is_sb': '0'},
 'benjamin': {'n_is_sb': '0'},
 'caesar': {'n_is_sb': '0', 'cap_word': 'Caesar'},
 'churchill': {'n_is_sb': '0'},
 'dickens': {'n_is_sb': '0'},
 'einstein': {'n_is_sb': '0', 'art_an': ''},
 'eugene': {'n_is_sb': '0', 'art_an': ''},
 'gabriel': {'n_is_sb': '0'},
 'galileo': {'n_is_sb': '0'},
 'gorbachev': {'n_is_sb': '0'},
 'helen': {'n_is_sb': '0'},
 'irving': {'n_is_sb': '0', 'art_an': ''},
 'kaiser': {'n_is_sb': '0'},
 'lindsay': {'n_is_sb': '0'},
 'louis': {'n_is_sb': '0'},
 'maxwell': {'n_is_sb': '0'},
 'napoleon': {'n_is_sb': '0'},
 'nobel': {'n_is_sb': '2', 'n_is_sth': '2'},
 'owen': {'n_is_sb': '0', 'art_an': ''},
 'rutherford': {'n_is_sb': '2', 'n_is_sth': '2'},
 'satan': {'n_is_sb': '0'},
 'sir': {'n_is_sb': '0'},
 'solomon': {'n_is_sb': '0'},
 'stalin': {'n_is_sb': '0'},
 'taxpayer': {'n_is_sb': '0', 'nn_to_vb': 'tax', 'nn_to_jj': 'taxable', 'nn_to_rb': 'taxably'},
 'tchaikovsky': {'n_is_sb': '0'},
 'acrobatics': {'n_is_sth': '', 'art_an': ''},
 'antarctica': {'n_is_sth': '', 'art_an': ''},
 'apache': {'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'archery': {'n_is_sth': '', 'art_an': ''},
 'berkshire': {'n_is_sth': ''},
 'bombay': {'n_is_sth': ''},
 'bonn': {'n_is_sth': ''},
 'coca': {'n_is_sth': '', 'n_is_sb': '2'},
 'cologne': {'n_is_sth': ''},
 'confines': {'n_is_sth': ''},
 'cosmos': {'n_is_sth': ''},
 'damascus': {'n_is_sth': ''},
 'esquire': {'n_is_sth': '', 'art_an': '', 'n_is_sb': '0'},
 'everest': {'n_is_sth': '', 'art_an': ''},
 'florence': {'n_is_sth': ''},
 'footage': {'n_is_sth': ''},
 'fuji': {'n_is_sth': ''},
 'genesis': {'n_is_sth': ''},
 'greenwich': {'n_is_sth': ''},
 'han': {'n_is_sth': ''},
 'hercules': {'n_is_sth': '', 'n_is_sb': '2'},
 'hiroshima': {'n_is_sth': ''},
 'jan': {'n_is_sth': ''},
 'kazakhstan': {'n_is_sth': ''},
 'kent': {'n_is_sth': '', 'n_is_sb': '2'},
 'kgb': {'n_is_sth': ''},
 'koran': {'n_is_sth': ''},
 'kyoto': {'n_is_sth': ''},
 'lyons': {'n_is_sth': ''},
 'manchester': {'n_is_sth': '', 'cap_word': 'Manchester'},
 'mecca': {'n_is_sth': ''},
 'mediterranean': {'n_is_sth': '', 'cap_word': 'Mediterranean'},
 'morrow': {'n_is_sth': ''},
 'naples': {'n_is_sth': '', 'cap_word': 'Naples'},
 'normandy': {'n_is_sth': ''},
 'okinawa': {'n_is_sth': '', 'art_an': ''},
 'orientation': {'n_is_sth': '', 'art_an': '', 'nn_to_vb': 'orient', 'nn_to_jj': 'orientational', 'nn_to_rb': 'originally'},
 'osaka': {'n_is_sth': '', 'art_an': ''},
 'passover': {'n_is_sth': ''},
 'rachel': {'n_is_sth': '', 'n_is_sb': '0'},
 'ramadan': {'n_is_sth': ''},
 'reich': {'n_is_sth': '', 'n_is_sb': '2'},
 'sabbath': {'n_is_sth': ''},
 'saigon': {'n_is_sth': ''},
 'siberia': {'n_is_sth': ''},
 'skinner': {'n_is_sth': '', 'n_is_sb': '0'},
 'stoma': {'n_is_sth': ''},
 'taurus': {'n_is_sth': '', 'n_is_sb': '2'},
 'venice': {'n_is_sth': '', 'cap_word': 'Venice'},
 'wicker': {'n_is_sth': ''},
 'aba': {'art_an': ''},
 'abb': {'art_an': ''},
 'abc': {'art_an': ''},
 'ade': {'art_an': ''},
 'adriatic': {'art_an': ''},
 'alps': {'art_an': ''},
 'arctic': {'art_an': ''},
 'aurora': {'art_an': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'e': {'art_an': ''},
 'eastward': {'art_an': ''},
 'eden': {'art_an': ''},
 'edinburgh': {'art_an': '', 'cap_word': 'Edinburgh'},
 'eleven': {'art_an': ''},
 'en': {'art_an': ''},
 'endemic': {'art_an': ''},
 'enough': {'art_an': ''},
 'entire': {'art_an': '', 'n_is_sb': '3', 'n_is_sth': '3'},
 'erotic': {'art_an': ''},
 'ethiopian': {'art_an': '', 'n_is_sb': '0'},
 'even': {'art_an': '', 'vbd_eq_vbn': '', 'v_pass_non': ''},
 'idle': {'art_an': '', 'jj_to_rb': 'idly', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'jj_to_jjr': 'idler', 'jj_to_jjs': 'idlest'},
 'imaginary': {'art_an': ''},
 'inc': {'art_an': ''},
 'invite': {'art_an': '', 'v_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'invites', 'vb_to_vbd': 'invited', 'vb_to_vbn': 'invited', 'vb_to_nn': 'invitation', 'vb_to_jj': 'inviting', 'vb_to_vbg': 'inviting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'ism': {'art_an': ''},
 'okay': {'art_an': ''},
 'old': {'art_an': '', 'jj_to_jjr': 'older', 'jj_to_jjs': 'oldest'},
 'othello': {'art_an': '', 'n_is_sb': '0'},
 'ouster': {'art_an': '', 'n_is_sb': '2', 'n_is_sth': '2'},
 'overcast': {'art_an': '', 'vbd_eq_vbn': ''},
 'ulster': {'art_an': ''},
 'un': {'art_an': ''},
 'uphill': {'art_an': ''},
 'uptick': {'art_an': ''},
 'a kempis': {'n_is_sb': '0'},
 'a. a. michelson': {'n_is_sb': '0'},
 'a. a. milne': {'n_is_sb': '0'},
 'a. conan doyle': {'n_is_sb': '0'},
 'a. e. burnside': {'n_is_sb': '0'},
 'a. e. housman': {'n_is_sb': '0'},
 'a. e. kennelly': {'n_is_sb': '0'},
 'a. e. w. mason': {'n_is_sb': '0'},
 'a. noam chomsky': {'n_is_sb': '0'},
 'a. testudineus': {'n_is_sb': '0'},
 'a.e.': {'n_is_sb': '0'},
 'aalto': {'n_is_sb': '0'},
 'aardvark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aardwolf': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aaron burr': {'n_is_sb': '0'},
 'aaron copland': {'n_is_sb': '0'},
 'abandoned infant': {'n_is_sb': '0'},
 'abandoned person': {'n_is_sb': '0'},
 'abbess': {'n_is_sb': '0'},
 'abbott lawrence lowell': {'n_is_sb': '0'},
 'abbreviator': {'n_is_sb': '2', 'n_is_sth': '2'},
 'abdias': {'n_is_sb': '0'},
 'abdicator': {'n_is_sb': '0'},
 'abecedarian': {'n_is_sb': '0'},
 'abel janszoon tasman': {'n_is_sb': '0'},
 'abel tasman': {'n_is_sb': '0'},
 'abelard': {'n_is_sb': '0'},
 'abel': {'n_is_sb': '0'},
 'aberdeen angus': {'n_is_sb': '0'},
 'aberrant': {'n_is_sb': '2', 'n_is_sth': '2'},
 'abetter': {'n_is_sb': '0'},
 'abettor': {'n_is_sb': '0'},
 'abhorrer': {'n_is_sb': '0'},
 'abiogenist': {'n_is_sb': '0'},
 'abkhas': {'n_is_sb': '0'},
 'abkhaz': {'n_is_sb': '2', 'n_is_sth': '2'},
 'able seaman': {'n_is_sb': '0'},
 'able-bodied seaman': {'n_is_sb': '0'},
 'abnaki': {'n_is_sb': '0'},
 'abnegator': {'n_is_sb': '0'},
 'abolitionist': {'n_is_sb': '0'},
 'abominable snowman': {'n_is_sb': '0'},
 'abominator': {'n_is_sb': '0'},
 'abortionist': {'n_is_sb': '0'},
 'abortus': {'n_is_sb': '0'},
 'abraham lincoln': {'n_is_sb': '0'},
 'abraham stoker': {'n_is_sb': '0'},
 'abraham': {'n_is_sb': '0'},
 'abramis brama': {'n_is_sb': '0'},
 'abramis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'abridger': {'n_is_sb': '0'},
 'abrocoma': {'n_is_sb': '3', 'n_is_sth': '3'},
 'abrocome': {'n_is_sb': '3', 'n_is_sth': '3'},
 'abrogator': {'n_is_sb': '0'},
 'absconder': {'n_is_sb': '0'},
 'abseiler': {'n_is_sb': '0'},
 'absentee': {'n_is_sb': '0'},
 'absolutist': {'n_is_sb': '0'},
 'absolver': {'n_is_sb': '0'},
 'abstainer': {'n_is_sb': '0'},
 'abstinent': {'n_is_sb': '0'},
 'abstract artist': {'n_is_sb': '0'},
 'abstracter': {'n_is_sb': '0'},
 'abstractionist': {'n_is_sb': '0'},
 'abstractor': {'n_is_sb': '2', 'n_is_sth': '2'},
 'abu ali al-husain ibn abdallah ibn sina': {'n_is_sb': '0'},
 'abudefduf saxatilis': {'n_is_sb': '0'},
 'abudefduf': {'n_is_sb': '3', 'n_is_sth': '3'},
 'abul-walid mohammed ibn-ahmad ibn-mohammed ibn-roshd': {'n_is_sb': '0'},
 'abuser': {'n_is_sb': '0'},
 'abutter': {'n_is_sb': '0'},
 'aby moritz warburg': {'n_is_sb': '0'},
 'aby warburg': {'n_is_sb': '0'},
 'abyssinian cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'abyssinian': {'n_is_sb': '0'},
 'academic administrator': {'n_is_sb': '0'},
 'acadian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'acanthisitta chloris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acanthisitta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acanthisittidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acanthocephalan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acanthocephala': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acanthocybium solandri': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acanthocybium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acanthophis antarcticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acanthophis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acanthopterygian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acanthopterygii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acanthoscelides obtectus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acanthoscelides': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acanthuridae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acanthurus chirurgus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acanthurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acaridae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acarid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acarina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acarine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acarus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'accentor': {'n_is_sb': '2', 'n_is_sth': '2'},
 'acceptor': {'n_is_sb': '2', 'n_is_sth': '2'},
 'accessary': {'n_is_sb': '0'},
 'accessory after the fact': {'n_is_sb': '0'},
 'accessory before the fact': {'n_is_sb': '0'},
 'accessory during the fact': {'n_is_sb': '0'},
 'accipiter cooperii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'accipiter gentilis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'accipiter nisus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'accipiter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'accipitridae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'accipitriformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'accommodation endorser': {'n_is_sb': '0'},
 'accommodator': {'n_is_sb': '0'},
 'accompanyist': {'n_is_sb': '0'},
 'accordionist': {'n_is_sb': '0'},
 'accoucheur': {'n_is_sb': '0'},
 'accoucheuse': {'n_is_sb': '0'},
 'account executive': {'n_is_sb': '0'},
 'account representative': {'n_is_sb': '0'},
 'accused': {'n_is_sb': '0', 'vbd_to_vb': 'accuse', 'vbn_to_vb': 'accuse', 'vbn_to_vbg': 'accusing', 'nn_eq_nns': '', 'vbd_eq_vbn': ''},
 'achaean': {'n_is_sb': '0'},
 'achaian': {'n_is_sb': '0'},
 'acherontia atropos': {'n_is_sb': '0'},
 'acherontia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acheson': {'n_is_sb': '0'},
 'acheta assimilis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acheta domestica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acheta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'achiever': {'n_is_sb': '0'},
 'achille ratti': {'n_is_sb': '0'},
 'achilles': {'n_is_sb': '0', 'cap_word': 'Achilles'},
 'achmad sukarno': {'n_is_sb': '0'},
 'achoerodus gouldii': {'n_is_sb': '0'},
 'achoerodus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'achomawi': {'n_is_sb': '0'},
 'acid head': {'n_is_sb': '0'},
 'acidophile': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acidophil': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acinonyx jubatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acinonyx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acipenser huso': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acipenser transmontanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acipenseridae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acipenser': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acnidosporidia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acorn barnacle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acquirer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'acrididae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acridid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acridotheres tristis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acridotheres': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acris crepitans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acris gryllus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acrobates': {'n_is_sb': '0'},
 'acrobat': {'n_is_sb': '0'},
 'acrocephalus schoenobaenus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acrocephalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acrodont': {'n_is_sb': '3', 'n_is_sth': '3'},
 'acropora': {'n_is_sb': '3', 'n_is_sth': '3'},
 'actias luna': {'n_is_sb': '3', 'n_is_sth': '3'},
 'actias': {'n_is_sb': '3', 'n_is_sth': '3'},
 'actinaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'actinian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'actiniarian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'actiniaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'actinia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'actinomyces': {'n_is_sb': '3', 'n_is_sth': '3'},
 'actinomycetaceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'actinomycetales': {'n_is_sb': '3', 'n_is_sth': '3'},
 'actinomycete': {'n_is_sb': '3', 'n_is_sth': '3'},
 'actinomyxidian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'actinomyxidia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'actinopoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'actinopod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'actinozoan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'actinozoa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'action officer': {'n_is_sb': '0'},
 'actitis hypoleucos': {'n_is_sb': '3', 'n_is_sth': '3'},
 'actitis macularia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'actitis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'active citizen': {'n_is_sb': '0'},
 "actor's agent": {'n_is_sb': '0'},
 "actor's assistant": {'n_is_sb': '0'},
 'adad': {'n_is_sb': '2', 'n_is_sth': '2'},
 'adalia bipunctata': {'n_is_sb': '0'},
 'adam smith': {'n_is_sb': '0'},
 'adams': {'n_is_sb': '0'},
 'adapa': {'n_is_sb': '0'},
 'adapid group': {'n_is_sb': '0'},
 'adapid': {'n_is_sb': '0'},
 'addax nasomaculatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'addax': {'n_is_sb': '3', 'n_is_sth': '3'},
 'addle-head': {'n_is_sb': '0'},
 'addlehead': {'n_is_sb': '0'},
 'adducer': {'n_is_sb': '0'},
 'adelges abietis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'adelges piceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'adelges': {'n_is_sb': '3', 'n_is_sth': '3'},
 'adelgidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'adelgid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'adelie penguin': {'n_is_sb': '0'},
 'adelie': {'n_is_sb': '0'},
 'adeline virginia stephen woolf': {'n_is_sb': '0'},
 'adenauer': {'n_is_sb': '0'},
 'adenota vardoni': {'n_is_sb': '0'},
 'adenota': {'n_is_sb': '3', 'n_is_sth': '3'},
 'adenovirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aditi': {'n_is_sb': '0'},
 'aditya': {'n_is_sb': '0'},
 'adjudicator': {'n_is_sb': '0'},
 'adjustor': {'n_is_sb': '2', 'n_is_sth': '2'},
 'adjutant bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'adjutant general': {'n_is_sb': '0'},
 'adjutant stork': {'n_is_sb': '2', 'n_is_sth': '2'},
 'adlai ewing stevenson': {'n_is_sb': '0'},
 'adlai stevenson': {'n_is_sb': '0'},
 'adman': {'n_is_sb': '0'},
 'administrative official': {'n_is_sb': '0'},
 'admiral byrd': {'n_is_sb': '0'},
 'admiral dewey': {'n_is_sb': '0'},
 'admiral nelson': {'n_is_sb': '0'},
 'admiral nimitz': {'n_is_sb': '0'},
 'admired': {'n_is_sb': '0', 'vbd_to_vb': 'admire', 'vbn_to_vb': 'admire', 'vbn_to_vbg': 'admiring', 'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'admonisher': {'n_is_sb': '0'},
 'adolf eichmann': {'n_is_sb': '0'},
 'adolf hitler': {'n_is_sb': '0'},
 'adolf loos': {'n_is_sb': '0'},
 'adolf windaus': {'n_is_sb': '0'},
 'adolph simon ochs': {'n_is_sb': '0'},
 'adolphe sax': {'n_is_sb': '0'},
 'adoptee': {'n_is_sb': '0'},
 'adopter': {'n_is_sb': '0'},
 'adoptive parent': {'n_is_sb': '0'},
 'adorer': {'n_is_sb': '0'},
 'adrian': {'n_is_sb': '0'},
 'adulator': {'n_is_sb': '0'},
 'adult female': {'n_is_sb': '0'},
 'adult male': {'n_is_sb': '0'},
 'adulterator': {'n_is_sb': '0'},
 'advancer': {'n_is_sb': '0'},
 'adventist': {'n_is_sb': '0'},
 'adventuress': {'n_is_sb': '0'},
 'adverse witness': {'n_is_sb': '0'},
 'advertiser': {'n_is_sb': '0'},
 'advertizer': {'n_is_sb': '0'},
 'advisee': {'n_is_sb': '0'},
 'advisor': {'n_is_sb': '0'},
 'advocator': {'n_is_sb': '0'},
 'aedes aegypti': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aedes albopictus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aedes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aegina': {'n_is_sb': '0'},
 'aegisthus': {'n_is_sb': '0'},
 'aegypiidae': {'n_is_sb': '0'},
 'aegypius monachus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aegypius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aegyptopithecus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aelfred': {'n_is_sb': '0'},
 'aelius donatus': {'n_is_sb': '0'},
 'aeneas silvius': {'n_is_sb': '0'},
 'aeneas': {'n_is_sb': '0'},
 'aengus': {'n_is_sb': '0'},
 'aeolian': {'n_is_sb': '0'},
 'aeolus': {'n_is_sb': '0'},
 'aepyceros melampus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aepyceros': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aepyornidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aepyorniformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aepyornis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aerobacter aerogenes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aerobacter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aerobe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aeronautical engineer': {'n_is_sb': '0'},
 'aeronaut': {'n_is_sb': '0'},
 'aerophile': {'n_is_sb': '0'},
 'aerospace engineer': {'n_is_sb': '0'},
 'aeschylus': {'n_is_sb': '0'},
 'aesculapius': {'n_is_sb': '0'},
 'aesir': {'n_is_sb': '0'},
 'aesop': {'n_is_sb': '0'},
 'aesthete': {'n_is_sb': '0'},
 'aesthetician': {'n_is_sb': '0'},
 'aetiologist': {'n_is_sb': '0'},
 'aetobatus narinari': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aetobatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'affenpinscher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'affiant': {'n_is_sb': '0'},
 'affine': {'n_is_sb': '2', 'n_is_sth': '2'},
 'affirmed': {'n_is_sb': '3', 'n_is_sth': '3', 'vbd_eq_vbn': ''},
 'affirmer': {'n_is_sb': '0'},
 'affluent': {'n_is_sb': '2', 'n_is_sth': '2'},
 'afghan hound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'afghanistani': {'n_is_sb': '0'},
 'afghan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'african chameleon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'african clawed frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'african coral snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'african crocodile': {'n_is_sb': '3', 'n_is_sth': '3'},
 'african elephant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'african gray': {'n_is_sb': '3', 'n_is_sth': '3'},
 'african green monkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'african hunting dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'african monitor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'african wild ass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'african-american': {'n_is_sb': '0', 'cap_word': 'African-American'},
 'africander': {'n_is_sb': '3', 'n_is_sth': '3'},
 'africanized bee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'africanized honey bee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'afrikander': {'n_is_sb': '0'},
 'afrikaner': {'n_is_sb': '0'},
 'afro-american': {'n_is_sb': '0'},
 'afropavo congensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'afropavo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'agama': {'n_is_sb': '3', 'n_is_sth': '3'},
 'agamemnon': {'n_is_sb': '0'},
 'agamid lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'agamidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'agamid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'agapornis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'agassiz': {'n_is_sb': '0'},
 'agatha christie': {'n_is_sb': '0'},
 'agdistis': {'n_is_sb': '0'},
 'agee': {'n_is_sb': '0'},
 'agelaius phoeniceus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'agelaius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'agent provocateur': {'n_is_sb': '0'},
 'agent-in-place': {'n_is_sb': '0'},
 'aggeus': {'n_is_sb': '0'},
 'aggravator': {'n_is_sb': '0'},
 'aggregator': {'n_is_sb': '2', 'n_is_sth': '2'},
 'agkistrodon contortrix': {'n_is_sb': '3', 'n_is_sth': '3'},
 'agkistrodon piscivorus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'agkistrodon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aglaia': {'n_is_sb': '0'},
 'agnate': {'n_is_sb': '0'},
 'agnathan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'agnatha': {'n_is_sb': '3', 'n_is_sth': '3'},
 'agnes de mille': {'n_is_sb': '0'},
 'agnes george de mille': {'n_is_sb': '0'},
 'agnes gonxha bojaxhiu': {'n_is_sb': '0'},
 'agni': {'n_is_sb': '0'},
 'agnostic': {'n_is_sb': '0'},
 'agonidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'agonus cataphractus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'agonus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'agony aunt': {'n_is_sb': '0'},
 'agouti': {'n_is_sb': '0'},
 'agricola': {'n_is_sb': '0'},
 'agricultural agent': {'n_is_sb': '0'},
 'agricultural laborer': {'n_is_sb': '0'},
 'agricultural labourer': {'n_is_sb': '0'},
 'agriculture secretary': {'n_is_sb': '0'},
 'agriculturist': {'n_is_sb': '0'},
 'agriocharis ocellata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'agriocharis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'agrippa': {'n_is_sb': '0'},
 'agrippina the elder': {'n_is_sb': '0'},
 'agrippina the younger': {'n_is_sb': '0'},
 'agrippina': {'n_is_sb': '0'},
 'agrobacterium tumefaciens': {'n_is_sb': '3', 'n_is_sth': '3'},
 'agrobacterium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'agua toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'agua': {'n_is_sb': '0'},
 'agust von wassermann': {'n_is_sb': '0'},
 'ahab': {'n_is_sb': '0'},
 'ahmad shah masoud': {'n_is_sb': '0'},
 'ahmed salman rushdie': {'n_is_sb': '0'},
 'ahmed zoki yamani': {'n_is_sb': '0'},
 'ahriman': {'n_is_sb': '0'},
 'ahura mazda': {'n_is_sb': '0'},
 'ahura': {'n_is_sb': '0'},
 'aides': {'n_is_sb': '0'},
 'aidoneus': {'n_is_sb': '0'},
 'aiken': {'n_is_sb': '0'},
 'ailanthus silkworm': {'n_is_sb': '0'},
 'ailey': {'n_is_sb': '0'},
 'ailuropoda melanoleuca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ailuropoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ailuropodidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ailurus fulgens': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ailurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aimee semple mcpherson': {'n_is_sb': '0'},
 'air attache': {'n_is_sb': '0'},
 'air force officer': {'n_is_sb': '0'},
 'air hostess': {'n_is_sb': '0'},
 'air marshal': {'n_is_sb': '0'},
 'air traveler': {'n_is_sb': '0'},
 'air traveller': {'n_is_sb': '0'},
 'aircraftman': {'n_is_sb': '0'},
 'aircraftsman': {'n_is_sb': '0'},
 'aircrewman': {'n_is_sb': '0'},
 'airedale terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'airedale': {'n_is_sb': '2', 'n_is_sth': '2'},
 'airhead': {'n_is_sb': '0'},
 'airplane pilot': {'n_is_sb': '0'},
 'airwoman': {'n_is_sb': '0'},
 'aix galericulata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aix sponsa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aix': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ajaia ajaja': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ajaia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ajax': {'n_is_sb': '0'},
 'akeridae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'akhenaten': {'n_is_sb': '0'},
 'akhenaton': {'n_is_sb': '0'},
 'akira kurosawa': {'n_is_sb': '0'},
 "akwa'ala": {'n_is_sb': '3', 'n_is_sth': '3'},
 'al capone': {'n_is_sb': '0'},
 'al gore': {'n_is_sb': '0'},
 'al jolson': {'n_is_sb': '0'},
 'al-hakim': {'n_is_sb': '0'},
 'al-hasan ibn al-haytham': {'n_is_sb': '0'},
 'al-haytham': {'n_is_sb': '0'},
 'alabaman': {'n_is_sb': '0'},
 'alabamian': {'n_is_sb': '0'},
 'aladdin': {'n_is_sb': '0'},
 'alan alexander milne': {'n_is_sb': '0'},
 'alan bartlett shepard jr.': {'n_is_sb': '0'},
 'alan hodgkin': {'n_is_sb': '0'},
 'alan jay lerner': {'n_is_sb': '0'},
 'alan mathison turing': {'n_is_sb': '0'},
 'alan paton': {'n_is_sb': '0'},
 'alan seeger': {'n_is_sb': '0'},
 'alan shepard': {'n_is_sb': '0'},
 'alan stewart paton': {'n_is_sb': '0'},
 'alan turing': {'n_is_sb': '0'},
 'alaric': {'n_is_sb': '0'},
 'alarmist': {'n_is_sb': '0'},
 'alaska cod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alaska crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alaska fur seal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alaska king crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alaska native': {'n_is_sb': '0'},
 'alaskan brown bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alaskan king crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alaskan malamute': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alaskan native': {'n_is_sb': '0'},
 'alaskan': {'n_is_sb': '0'},
 'alauda arvensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alauda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alaudidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'albacore': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alban berg': {'n_is_sb': '0'},
 'albee': {'n_is_sb': '0'},
 'alben barkley': {'n_is_sb': '0'},
 'alben william barkley': {'n_is_sb': '0'},
 'albers': {'n_is_sb': '0'},
 'albert abraham michelson': {'n_is_sb': '0'},
 'albert bruce sabin': {'n_is_sb': '0'},
 'albert camus': {'n_is_sb': '0'},
 'albert edward': {'n_is_sb': '0'},
 'albert einstein': {'n_is_sb': '0'},
 'albert francis charles augustus emmanuel': {'n_is_sb': '0'},
 'albert gore jr.': {'n_is_sb': '0'},
 'albert michelson': {'n_is_sb': '0'},
 'albert sabin': {'n_is_sb': '0'},
 'albert schweitzer': {'n_is_sb': '0'},
 'albert speer': {'n_is_sb': '0'},
 'albert szent-gyorgyi': {'n_is_sb': '0'},
 'albert von szent-gyorgyi': {'n_is_sb': '0'},
 'alberti': {'n_is_sb': '0'},
 'alberto giacometti': {'n_is_sb': '0'},
 'albert': {'n_is_sb': '0'},
 'albino luciano': {'n_is_sb': '0'},
 'albrecht durer': {'n_is_sb': '0'},
 'albrecht eusebius wenzel von wallenstein': {'n_is_sb': '0'},
 'albula vulpes': {'n_is_sb': '0'},
 'albula': {'n_is_sb': '0'},
 'albulidae': {'n_is_sb': '0'},
 'alca torda': {'n_is_sb': '0'},
 'alcaeus': {'n_is_sb': '0'},
 'alca': {'n_is_sb': '0'},
 'alcedinidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alcedo atthis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alcedo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alcelaphus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alces alces': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alces': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alcibiades': {'n_is_sb': '0'},
 'alcidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alcides': {'n_is_sb': '0'},
 'alcoholic': {'n_is_sb': '0', 'nc_typical': ''},
 'alcott': {'n_is_sb': '0'},
 'alcyonacea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alcyonaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alcyone': {'n_is_sb': '0'},
 'alder fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alderfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alderman': {'n_is_sb': '0'},
 'aldous huxley': {'n_is_sb': '0'},
 'aldous leonard huxley': {'n_is_sb': '0'},
 'ale drinker': {'n_is_sb': '0'},
 'alec guinness': {'n_is_sb': '0'},
 'alectis ciliaris': {'n_is_sb': '0'},
 'alectis': {'n_is_sb': '0'},
 'alectoris graeca': {'n_is_sb': '0'},
 'alectoris ruffa': {'n_is_sb': '0'},
 'alectoris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alecto': {'n_is_sb': '0'},
 'alectura lathami': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alectura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aleksandr aleksandrovich blok': {'n_is_sb': '0'},
 'aleksandr borodin': {'n_is_sb': '0'},
 'aleksandr feodorovich kerensky': {'n_is_sb': '0'},
 'aleksandr i. solzhenitsyn': {'n_is_sb': '0'},
 'aleksandr mikjailovich prokhorov': {'n_is_sb': '0'},
 'aleksandr nikolayevich scriabin': {'n_is_sb': '0'},
 'aleksandr pavlovich': {'n_is_sb': '0'},
 'aleksandr porfirevich borodin': {'n_is_sb': '0'},
 'aleksandr prokhorov': {'n_is_sb': '0'},
 'aleksandr scriabin': {'n_is_sb': '0'},
 'aleksandr sergeyevich pushkin': {'n_is_sb': '0'},
 'aleksey maksimovich peshkov': {'n_is_sb': '0'},
 'aleksey maximovich peshkov': {'n_is_sb': '0'},
 'alepisaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alessandro di mariano dei filipepi': {'n_is_sb': '0'},
 'alessandro manzoni': {'n_is_sb': '0'},
 'aletta jacobs': {'n_is_sb': '0'},
 'aleutian': {'n_is_sb': '0'},
 'aleut': {'n_is_sb': '0'},
 'alewife': {'n_is_sb': '0'},
 'alex haley': {'n_is_sb': '2', 'n_is_sth': '2'},
 'alexander alexandrovich blok': {'n_is_sb': '0'},
 'alexander bell': {'n_is_sb': '0'},
 'alexander calder': {'n_is_sb': '0'},
 'alexander fleming': {'n_is_sb': '0'},
 'alexander graham bell': {'n_is_sb': '0'},
 'alexander hamilton': {'n_is_sb': '0'},
 'alexander iii': {'n_is_sb': '0'},
 'alexander ii': {'n_is_sb': '0'},
 'alexander isayevich solzhenitsyn': {'n_is_sb': '0'},
 'alexander i': {'n_is_sb': '0'},
 'alexander melville bell': {'n_is_sb': '0'},
 'alexander pope': {'n_is_sb': '0'},
 'alexander pushkin': {'n_is_sb': '0'},
 'alexander selcraig': {'n_is_sb': '0'},
 'alexander selkirk': {'n_is_sb': '0'},
 'alexander the great': {'n_is_sb': '0'},
 'alexander the liberator': {'n_is_sb': '0'},
 'alexander vi': {'n_is_sb': '0'},
 'alexander wilson': {'n_is_sb': '0'},
 'alexander woollcott': {'n_is_sb': '0'},
 'alexandre dumas': {'n_is_sb': '0'},
 'alexandre emile jean yersin': {'n_is_sb': '0'},
 'alexandre gustave eiffel': {'n_is_sb': '0'},
 'alexandre yersin': {'n_is_sb': '0'},
 'alexic': {'n_is_sb': '0'},
 'alexis carrel': {'n_is_sb': '0'},
 'alexis charles henri maurice de tocqueville': {'n_is_sb': '0'},
 'alexis de tocqueville': {'n_is_sb': '0'},
 'aleyrodes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aleyrodidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alfonso borgia': {'n_is_sb': '0'},
 'alfred alistair cooke': {'n_is_sb': '0'},
 'alfred bernhard nobel': {'n_is_sb': '0'},
 'alfred binet': {'n_is_sb': '0'},
 'alfred charles kinsey': {'n_is_sb': '0'},
 'alfred charles william harmsworth': {'n_is_sb': '0'},
 'alfred damon runyon': {'n_is_sb': '0'},
 'alfred de musset': {'n_is_sb': '0'},
 'alfred dreyfus': {'n_is_sb': '0'},
 'alfred edward housman': {'n_is_sb': '0'},
 'alfred edward woodley mason': {'n_is_sb': '0'},
 'alfred eisenstaedt': {'n_is_sb': '0'},
 'alfred habdank skarbek korzybski': {'n_is_sb': '0'},
 'alfred hawthorne': {'n_is_sb': '0'},
 'alfred hitchcock': {'n_is_sb': '0'},
 'alfred joseph hitchcock': {'n_is_sb': '0'},
 'alfred kastler': {'n_is_sb': '0'},
 'alfred korzybski': {'n_is_sb': '0'},
 'alfred kroeber': {'n_is_sb': '0'},
 'alfred krupp': {'n_is_sb': '0'},
 'alfred lord tennyson': {'n_is_sb': '0'},
 'alfred lothar wegener': {'n_is_sb': '0'},
 'alfred louis kroeber': {'n_is_sb': '0'},
 'alfred lunt': {'n_is_sb': '0'},
 'alfred nobel': {'n_is_sb': '0'},
 'alfred north whitehead': {'n_is_sb': '0'},
 'alfred noyes': {'n_is_sb': '0'},
 'alfred russel wallace': {'n_is_sb': '0'},
 'alfred stieglitz': {'n_is_sb': '0'},
 'alfred tennyson': {'n_is_sb': '0'},
 'alfred thayer mahan': {'n_is_sb': '0'},
 'alfred the great': {'n_is_sb': '0'},
 'alfred': {'n_is_sb': '0'},
 'algebraist': {'n_is_sb': '0'},
 'algerian': {'n_is_sb': '0'},
 'algeripithecus minutus': {'n_is_sb': '0'},
 'algeripithecus': {'n_is_sb': '0'},
 'algernon charles swinburne': {'n_is_sb': '0'},
 'alger': {'n_is_sb': '0'},
 'algonkian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'algonkin': {'n_is_sb': '2', 'n_is_sth': '2'},
 'algonquian': {'n_is_sb': '0'},
 'algonquin': {'n_is_sb': '0'},
 'algren': {'n_is_sb': '0'},
 'alhazen': {'n_is_sb': '0'},
 'ali baba': {'n_is_sb': '0'},
 'alice b. toklas': {'n_is_sb': '0'},
 'alice hamilton': {'n_is_sb': '0'},
 'alice malsenior walker': {'n_is_sb': '0'},
 'alice paul': {'n_is_sb': '0'},
 'alice walker': {'n_is_sb': '0'},
 'alicia alonso': {'n_is_sb': '0'},
 'alien absconder': {'n_is_sb': '0'},
 'alienator': {'n_is_sb': '0'},
 'alienist': {'n_is_sb': '0'},
 'alistair cooke': {'n_is_sb': '0'},
 'aliterate person': {'n_is_sb': '0'},
 'aliterate': {'n_is_sb': '0'},
 'ali': {'n_is_sb': '0'},
 'alkali bee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alky': {'n_is_sb': '0'},
 'all arounder': {'n_is_sb': '0'},
 'all-rounder': {'n_is_sb': '0'},
 'alla nazimova': {'n_is_sb': '0'},
 'allayer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'allegoriser': {'n_is_sb': '0'},
 'allegorizer': {'n_is_sb': '0'},
 'allen ginsberg': {'n_is_sb': '0'},
 'allen stewart konigsberg': {'n_is_sb': '0'},
 'allen tate': {'n_is_sb': '0'},
 'allen': {'n_is_sb': '0'},
 'allergist': {'n_is_sb': '0'},
 'alleviator': {'n_is_sb': '0'},
 'alley cat': {'n_is_sb': '0'},
 'allice shad': {'n_is_sb': '0'},
 'allice': {'n_is_sb': '0'},
 'alligator lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alligator mississipiensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alligator sinensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alligator snapper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alligator snapping turtle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alligatorfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alligatoridae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'allis shad': {'n_is_sb': '0'},
 'allis': {'n_is_sb': '0'},
 'alliterator': {'n_is_sb': '0'},
 'allmouth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'allocator': {'n_is_sb': '0'},
 'allosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'allosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'almighty': {'n_is_sb': '0'},
 'almond moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'almoner': {'n_is_sb': '0'},
 'almoravid': {'n_is_sb': '0'},
 'almsgiver': {'n_is_sb': '0'},
 'alois senefelder': {'n_is_sb': '0'},
 'alonso': {'n_is_sb': '0'},
 'alopex lagopus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alopex': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alopiidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alopius vulpinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alopius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alosa alosa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alosa chrysocloris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alosa pseudoharengus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alosa sapidissima': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alosa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alouatta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aloys senefelder': {'n_is_sb': '0'},
 'alpaca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alphabetiser': {'n_is_sb': '0'},
 'alphabetizer': {'n_is_sb': '0'},
 'alphavirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alphonse bertillon': {'n_is_sb': '0'},
 'alphonse capone': {'n_is_sb': '0'},
 'alpine salamander': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alpinist': {'n_is_sb': '0'},
 'alsatian': {'n_is_sb': '0', 'cap_word': 'Alsatian'},
 'also-ran': {'n_is_sb': '0'},
 'alsophila pometaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alsophila': {'n_is_sb': '3', 'n_is_sth': '3'},
 'altaic': {'n_is_sb': '0'},
 'altar boy': {'n_is_sb': '0'},
 'alter ego': {'n_is_sb': '0'},
 'althea gibson': {'n_is_sb': '0'},
 'alto saxophonist': {'n_is_sb': '0'},
 'altoist': {'n_is_sb': '0'},
 'alton glenn miller': {'n_is_sb': '0'},
 'altruist': {'n_is_sb': '0'},
 'alvar aalto': {'n_is_sb': '0'},
 'alvin ailey': {'n_is_sb': '0'},
 'alytes cisternasi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alytes obstetricans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'alytes': {'n_is_sb': '0'},
 'amadavat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amaethon': {'n_is_sb': '0'},
 'amah': {'n_is_sb': '0'},
 'amalgamator': {'n_is_sb': '2', 'n_is_sth': '2'},
 'amandine aurore lucie dupin': {'n_is_sb': '0'},
 'amaterasu omikami': {'n_is_sb': '0'},
 'amaterasu': {'n_is_sb': '0'},
 'amati': {'n_is_sb': '2', 'n_is_sth': '2'},
 'amazed': {'n_is_sb': '0', 'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'amazon ant': {'n_is_sb': '0'},
 'amazona': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ambassadress': {'n_is_sb': '0', 'nc_typical': ''},
 'amberfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amberjack': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ambler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ambloplites rupestris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ambloplites': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amblyrhynchus cristatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amblyrhynchus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ambrogio damiano achille ratti': {'n_is_sb': '0'},
 'ambrose bierce': {'n_is_sb': '0'},
 'ambrose everett burnside': {'n_is_sb': '0'},
 'ambrose gwinett bierce': {'n_is_sb': '0'},
 'ambrose': {'n_is_sb': '0'},
 'ambulacrum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ambulance chaser': {'n_is_sb': '0'},
 'ambusher': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ambystoma maculatum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ambystoma mexicanum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ambystoma talpoideum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ambystoma tigrinum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ambystomatidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ambystoma': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ambystomid salamander': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ambystomid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ameba': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amedeo avogadro': {'n_is_sb': '0'},
 'amedeo modigliano': {'n_is_sb': '0'},
 'ameiuridae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ameiurus melas': {'n_is_sb': '0'},
 'ameiurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amelia earhart': {'n_is_sb': '0'},
 'amen-ra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amenhotep iv': {'n_is_sb': '0'},
 'american alligator': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american antelope': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american badger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american bison': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american bittern': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american black bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american blight': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american buffalo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american chameleon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american cockroach': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american coot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american copper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american crayfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american creeper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american crow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american dog tick': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american eagle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american egret': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american elk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american flagfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american flying squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american foxhound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american gallinule': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american green toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american harvest mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american indian': {'n_is_sb': '0'},
 'american kestrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american lady crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american lobster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american magpie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american marten': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american mastodont': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american mastodon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american merganser': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american mink': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american oriole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american pit bull terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american plaice': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american red squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american redstart': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american revolutionary leader': {'n_is_sb': '0'},
 'american robin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american sable': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american saddle horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american shrew mole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american smooth dogfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american staffordshire terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american water ouzel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american water shrew': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american water spaniel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american widgeon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'american woodcock': {'n_is_sb': '3', 'n_is_sth': '3'},
 'americus vespucius': {'n_is_sb': '0'},
 'amerigo vespucci': {'n_is_sb': '0'},
 'amerindian race': {'n_is_sb': '0'},
 'amerindian': {'n_is_sb': '0'},
 'amethystine python': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amhara': {'n_is_sb': '0'},
 'amia calva': {'n_is_sb': '0'},
 'amia': {'n_is_sb': '0'},
 'amicus curiae': {'n_is_sb': '0'},
 'amiidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amir': {'n_is_sb': '0'},
 'amish': {'n_is_sb': '0', 'cap_word': 'Amish'},
 'ammodytes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ammodytidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ammotragus lervia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ammotragus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amnesiac': {'n_is_sb': '0'},
 'amnesic': {'n_is_sb': '0'},
 'amniota': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amniote': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amon-ra': {'n_is_sb': '0'},
 'amon': {'n_is_sb': '0'},
 'amoralist': {'n_is_sb': '0'},
 'amora': {'n_is_sb': '0'},
 'amorist': {'n_is_sb': '0'},
 'amor': {'n_is_sb': '0'},
 'amos': {'n_is_sb': '0'},
 'amphibian family': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amphibian genus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amphibia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amphibolips': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amphidiploid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amphineura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amphioxidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amphioxus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amphipoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amphipod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amphiprion percula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amphiprion': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amphisbaena': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amphisbaenia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amphisbaenidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amphiuma': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amphiumidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'amputator': {'n_is_sb': '2', 'n_is_sth': '2'},
 'amputee': {'n_is_sb': '0'},
 'amundsen': {'n_is_sb': '2', 'n_is_sth': '2'},
 'amused': {'n_is_sb': '0', 'vbn_to_vb': 'amuse', 'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'amy lowell': {'n_is_sb': '0'},
 'amy lyon': {'n_is_sb': '0'},
 'anabantidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anabaptist': {'n_is_sb': '0'},
 'anabas testudineus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anabas': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anabrus simplex': {'n_is_sb': '0'},
 'anabrus': {'n_is_sb': '0'},
 'anacanthini': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anachronism': {'n_is_sb': '2', 'n_is_sth': '2'},
 'anaconda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anaerobe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anaesthetist': {'n_is_sb': '0'},
 'anagasta kuehniella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anagasta': {'n_is_sb': '0'},
 'anagnost': {'n_is_sb': '0'},
 'analogist': {'n_is_sb': '0'},
 'analphabetic': {'n_is_sb': '0'},
 'analphabet': {'n_is_sb': '0'},
 'analysand': {'n_is_sb': '0'},
 'ananias': {'n_is_sb': '0'},
 'anapsid reptile': {'n_is_sb': '0'},
 'anapsida': {'n_is_sb': '0'},
 'anapsid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anapurna': {'n_is_sb': '2', 'n_is_sth': '2'},
 'anarchist': {'n_is_sb': '0'},
 'anarhichadidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anarhichas': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anas acuta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anas americana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anas clypeata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anas crecca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anas discors': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anas penelope': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anas platyrhynchos': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anas querquedula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anas rubripes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anasa tristis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anasazi': {'n_is_sb': '2', 'n_is_sth': '2'},
 'anasa': {'n_is_sb': '0'},
 'anaspida': {'n_is_sb': '0'},
 'anaspid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anastomus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'anas': {'n_is_sb': '2', 'n_is_sth': '2'},
 'anatidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anatole france': {'n_is_sb': '0'},
 'anatoli karpov': {'n_is_sb': '0'},
 'anatoli yevgenevich karpov': {'n_is_sb': '0'},
 'anatomist': {'n_is_sb': '0'},
 'anatotitan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anaxagoras': {'n_is_sb': '0'},
 'anaximander': {'n_is_sb': '0'},
 'anaximenes': {'n_is_sb': '0'},
 'ancestress': {'n_is_sb': '0'},
 'anchorite': {'n_is_sb': '0'},
 'anchorman': {'n_is_sb': '0'},
 'anchorperson': {'n_is_sb': '0'},
 'ancistrodon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ancylidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ancylostomatidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ancylus fluviatilis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ancylus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'andean condor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anders celsius': {'n_is_sb': '0'},
 'anderson': {'n_is_sb': '0'},
 'andorran': {'n_is_sb': '0'},
 'andre derain': {'n_is_sb': '0'},
 'andre gide': {'n_is_sb': '0'},
 'andre le notre': {'n_is_sb': '0'},
 'andre maginot': {'n_is_sb': '0'},
 'andre malraux': {'n_is_sb': '0'},
 'andre markoff': {'n_is_sb': '0'},
 'andre maurois': {'n_is_sb': '0'},
 'andre paul guillaume gide': {'n_is_sb': '0'},
 'andre weil': {'n_is_sb': '0'},
 'andrea guarneri': {'n_is_sb': '0'},
 'andrea mantegna': {'n_is_sb': '0'},
 'andrea palladio': {'n_is_sb': '0'},
 'andreas vesalius': {'n_is_sb': '0'},
 'andrei andreyevich gromyko': {'n_is_sb': '0'},
 'andrei arsenevich tarkovsky': {'n_is_sb': '0'},
 'andrei dimitrievich sakharov': {'n_is_sb': '0'},
 'andrei gromyko': {'n_is_sb': '0'},
 'andrei markov': {'n_is_sb': '0'},
 'andrei sakharov': {'n_is_sb': '0'},
 'andrei tarkovsky': {'n_is_sb': '0'},
 'andrei voznesenski': {'n_is_sb': '0'},
 'andrena': {'n_is_sb': '3', 'n_is_sth': '3'},
 'andrenidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'andrenid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'andres martinez': {'n_is_sb': '0'},
 'andres segovia': {'n_is_sb': '0'},
 'andrew carnegie': {'n_is_sb': '0'},
 'andrew d. white': {'n_is_sb': '0'},
 'andrew dickson white': {'n_is_sb': '0'},
 'andrew fielding huxley': {'n_is_sb': '0'},
 'andrew huxley': {'n_is_sb': '0'},
 'andrew jackson downing': {'n_is_sb': '0'},
 'andrew jackson': {'n_is_sb': '0'},
 'andrew johnson': {'n_is_sb': '0'},
 'andrew lloyd webber': {'n_is_sb': '0'},
 'andrew marvell': {'n_is_sb': '0'},
 'andrew mellon': {'n_is_sb': '0'},
 'andrew w. mellon': {'n_is_sb': '0'},
 'andrew william mellon': {'n_is_sb': '0'},
 'andrew wyeth': {'n_is_sb': '0'},
 'andrews': {'n_is_sb': '0'},
 'andrew': {'n_is_sb': '0'},
 'andricus': {'n_is_sb': '0'},
 'andrzej wajda': {'n_is_sb': '0'},
 'andvari': {'n_is_sb': '0'},
 'andy warhol': {'n_is_sb': '0'},
 'anecdotist': {'n_is_sb': '0'},
 'aneides lugubris': {'n_is_sb': '0'},
 'anemone fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anesthesiologist': {'n_is_sb': '0'},
 'angel shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'angevine': {'n_is_sb': '0'},
 'angevin': {'n_is_sb': '0'},
 'angiologist': {'n_is_sb': '0'},
 'angler fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anglerfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'angler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'anglewing': {'n_is_sb': '3', 'n_is_sth': '3'},
 'angleworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anglican catholic': {'n_is_sb': '0'},
 'anglican': {'n_is_sb': '0', 'cap_word': 'Anglican'},
 'anglo-american': {'n_is_sb': '0'},
 'anglo-indian': {'n_is_sb': '0'},
 'anglo-saxon deity': {'n_is_sb': '0'},
 'anglo-saxon': {'n_is_sb': '0', 'cap_word': 'Anglo-Saxon'},
 'anglophile': {'n_is_sb': '0'},
 'anglophil': {'n_is_sb': '0'},
 'anglophobe': {'n_is_sb': '0'},
 'angolan': {'n_is_sb': '0'},
 'angolese': {'n_is_sb': '0'},
 'angora cat': {'n_is_sb': '0'},
 'angora goat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'angora rabbit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'angora': {'n_is_sb': '3', 'n_is_sth': '3'},
 'angoumois grain moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'angoumois moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anguid lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anguidae': {'n_is_sb': '0'},
 'anguilla sucklandii': {'n_is_sb': '0'},
 'anguillan': {'n_is_sb': '0'},
 'anguillula aceti': {'n_is_sb': '0'},
 'anguillula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anguis fragilis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anguis': {'n_is_sb': '0'},
 'angus frank johnstone wilson': {'n_is_sb': '0'},
 'angus og': {'n_is_sb': '0'},
 'angus': {'n_is_sb': '0'},
 'angwantibo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anhima cornuta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anhimidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anhinga anhinga': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anhinga': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anicius manlius severinus boethius': {'n_is_sb': '0'},
 'animal fancier': {'n_is_sb': '0'},
 'animal foot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'animal scientist': {'n_is_sb': '0'},
 'animal stuffer': {'n_is_sb': '0'},
 'animal trainer': {'n_is_sb': '0'},
 'animal virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'animalcule': {'n_is_sb': '3', 'n_is_sth': '3'},
 'animalculum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'animalia': {'n_is_sb': '2', 'n_is_sth': '2'},
 'animator': {'n_is_sb': '0'},
 'animist': {'n_is_sb': '0'},
 'anisoptera': {'n_is_sb': '2', 'n_is_sth': '2'},
 'anisotremus surinamensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anisotremus virginicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anisotremus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ani': {'n_is_sb': '0'},
 'ankylosaurus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ankylosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anna amalia mercouri': {'n_is_sb': '0'},
 'anna eleanor roosevelt': {'n_is_sb': '0'},
 'anna howard shaw': {'n_is_sb': '0'},
 'anna pavlova': {'n_is_sb': '0'},
 'annalist': {'n_is_sb': '0'},
 'annamese': {'n_is_sb': '2', 'n_is_sth': '2'},
 'annapurna': {'n_is_sb': '2', 'n_is_sth': '2'},
 'anne boleyn': {'n_is_sb': '0'},
 'anne bradstreet': {'n_is_sb': '0'},
 'anne bronte': {'n_is_sb': '0'},
 'anne dudley bradstreet': {'n_is_sb': '0'},
 'anne hathaway': {'n_is_sb': '0'},
 'anne hutchinson': {'n_is_sb': '0'},
 'anne mansfield sullivan': {'n_is_sb': '0'},
 'anne mary robertson moses': {'n_is_sb': '0'},
 'anne robert jacques turgot': {'n_is_sb': '0'},
 'anne sexton': {'n_is_sb': '0'},
 'anne sullivan': {'n_is_sb': '0'},
 'annelid worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'annelid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'annie oakley': {'n_is_sb': '2', 'n_is_sth': '2'},
 'annotator': {'n_is_sb': '0'},
 'annoyer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'annuitant': {'n_is_sb': '0'},
 'anoa depressicornis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anoa mindorensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anoa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anodonta': {'n_is_sb': '2', 'n_is_sth': '2'},
 'anointer': {'n_is_sb': '0'},
 'anole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anolis carolinensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anomala orientalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anomalist': {'n_is_sb': '0'},
 'anomalopteryx oweni': {'n_is_sb': '0'},
 'anomalopteryx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anomia ephippium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anopheline': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anoplophora glabripennis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anoplura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anorectic': {'n_is_sb': '0'},
 'anorexic': {'n_is_sb': '0'},
 'anouilh': {'n_is_sb': '0'},
 'anselm': {'n_is_sb': '0'},
 'anser anser': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anser cygnoides': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anseriform bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anseriformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anshar': {'n_is_sb': '0'},
 'answerer': {'n_is_sb': '0'},
 'ant bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ant bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ant cow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ant lion': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ant shrike': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ant thrush': {'n_is_sb': '2', 'n_is_sth': '2'},
 'antbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'antediluvian patriarch': {'n_is_sb': '0'},
 'antediluvian': {'n_is_sb': '0'},
 'antelope chipmunk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'antelope squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'antheraea mylitta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'antheraea pernyi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'antheraea polyphemus': {'n_is_sb': '0'},
 'anthologist': {'n_is_sb': '0'},
 'anthonomus grandis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anthony burgess': {'n_is_sb': '0'},
 'anthony charles lynton blair': {'n_is_sb': '0'},
 'anthony comstock': {'n_is_sb': '0'},
 'anthony hopkins': {'n_is_sb': '0'},
 'anthony trollope': {'n_is_sb': '0'},
 'anthony vandyke': {'n_is_sb': '0'},
 'anthony wayne': {'n_is_sb': '0'},
 'anthony': {'n_is_sb': '0'},
 'anthozoan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anthozoa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anthrenus scrophulariae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anthropoid ape': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anthropoid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anthropologist': {'n_is_sb': '0'},
 'anthropophagite': {'n_is_sb': '0'},
 'anthropophagus': {'n_is_sb': '0'},
 'anthus pratensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'anti-semite': {'n_is_sb': '0'},
 'antichrist': {'n_is_sb': '0'},
 'anticipant': {'n_is_sb': '0'},
 'anticipator': {'n_is_sb': '0'},
 'antidorcas euchore': {'n_is_sb': '3', 'n_is_sth': '3'},
 'antidorcas marsupialis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'antidorcas': {'n_is_sb': '3', 'n_is_sth': '3'},
 'antifeminist': {'n_is_sb': '0'},
 'antigone': {'n_is_sb': '0'},
 'antigonus cyclops': {'n_is_sb': '0'},
 'antigonus': {'n_is_sb': '0'},
 'antiguan': {'n_is_sb': '0'},
 'antihero': {'n_is_sb': '0'},
 'antilocapra americana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'antilocapra': {'n_is_sb': '2', 'n_is_sth': '2'},
 'antilope cervicapra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'antilope': {'n_is_sb': '3', 'n_is_sth': '3'},
 'antinomian': {'n_is_sb': '0'},
 'antiquarian': {'n_is_sb': '0'},
 'antiquary': {'n_is_sb': '0'},
 'antler moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'antlion fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'antlion': {'n_is_sb': '3', 'n_is_sth': '3'},
 'antoine domino': {'n_is_sb': '0'},
 'antoine henri becquerel': {'n_is_sb': '0'},
 'antoine laurent de jussieu': {'n_is_sb': '0'},
 'antoine laurent lavoisier': {'n_is_sb': '0'},
 'antoine lavoisier': {'n_is_sb': '0'},
 'anton bruckner': {'n_is_sb': '0'},
 'anton chekhov': {'n_is_sb': '0'},
 'anton chekov': {'n_is_sb': '0'},
 'anton gregor rubinstein': {'n_is_sb': '0'},
 'anton grigorevich rubinstein': {'n_is_sb': '0'},
 'anton pavlovich chekhov': {'n_is_sb': '0'},
 'anton pavlovich chekov': {'n_is_sb': '0'},
 'anton rubenstein': {'n_is_sb': '0'},
 'anton van leeuwenhoek': {'n_is_sb': '0'},
 'anton van leuwenhoek': {'n_is_sb': '0'},
 'antonin dvorak': {'n_is_sb': '0'},
 'antoninus': {'n_is_sb': '0'},
 'antonio allegri da correggio': {'n_is_sb': '0'},
 'antonio gaudi i cornet': {'n_is_sb': '0'},
 'antonio gaudi': {'n_is_sb': '0'},
 'antonio ghislieri': {'n_is_sb': '0'},
 'antonio lopez de santa ana': {'n_is_sb': '0'},
 'antonio lopez de santa anna': {'n_is_sb': '0'},
 'antonio lucio vivaldi': {'n_is_sb': '0'},
 'antonio stradivari': {'n_is_sb': '0'},
 'antonio vivaldi': {'n_is_sb': '0'},
 'antonius pius': {'n_is_sb': '0'},
 'antonius stradivarius': {'n_is_sb': '0'},
 'antonius': {'n_is_sb': '0'},
 'antony tudor': {'n_is_sb': '0'},
 'antony': {'n_is_sb': '0'},
 'antrozous pallidus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'antum': {'n_is_sb': '0'},
 'anubis': {'n_is_sb': '0'},
 'anunnaki': {'n_is_sb': '0'},
 'anuran': {'n_is_sb': '0'},
 'anura': {'n_is_sb': '2', 'n_is_sth': '2'},
 'anu': {'n_is_sb': '2', 'n_is_sth': '2'},
 'anwar el-sadat': {'n_is_sb': '0'},
 'anwar sadat': {'n_is_sb': '0'},
 'aotus trivirgatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aotus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aoudad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'apar': {'n_is_sb': '0'},
 'apatosaurus excelsus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'apatosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'apatosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'apatura iris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aperea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aper': {'n_is_sb': '0'},
 'aphakic': {'n_is_sb': '0'},
 'aphasic': {'n_is_sb': '0'},
 'aphid lion': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aphididae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aphidoidea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aphis fabae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aphis lion': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aphis pomi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aphorist': {'n_is_sb': '0'},
 'aphriza virgata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aphrodite': {'n_is_sb': '0'},
 'aphrophora saratogensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'apiarist': {'n_is_sb': '0'},
 'apiculturist': {'n_is_sb': '0'},
 'apis mellifera adansonii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'apis mellifera scutellata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'apis mellifera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'apis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aplacophoran': {'n_is_sb': '0'},
 'aplodontia rufa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aplodontia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aplysia punctata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aplysiidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'apodemus sylvaticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'apodemus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'apodiform bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'apogon maculatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'apoidea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'apolemia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'apollinaire': {'n_is_sb': '0'},
 'apostate': {'n_is_sb': '0'},
 'apostle of germany': {'n_is_sb': '0'},
 'apostle of the gentiles': {'n_is_sb': '0'},
 'apostle paul': {'n_is_sb': '0'},
 'apostolic delegate': {'n_is_sb': '0'},
 'appaloosa': {'n_is_sb': '0'},
 'appeaser': {'n_is_sb': '0'},
 'appellant': {'n_is_sb': '0'},
 'appendicularia': {'n_is_sb': '2', 'n_is_sth': '2'},
 'applauder': {'n_is_sb': '0'},
 'apple aphid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'apple maggot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'apple polisher': {'n_is_sb': '0'},
 'appleton': {'n_is_sb': '0'},
 'applied scientist': {'n_is_sb': '0'},
 'applier': {'n_is_sb': '0'},
 'appointee': {'n_is_sb': '0'},
 'appreciator': {'n_is_sb': '0'},
 'apprehender': {'n_is_sb': '0'},
 'appropriator': {'n_is_sb': '0'},
 'approver': {'n_is_sb': '0'},
 'april fool': {'n_is_sb': '0'},
 'apsu': {'n_is_sb': '0'},
 'aptenodytes forsteri': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aptenodytes patagonica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'apteryx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'apus apus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aquanaut': {'n_is_sb': '0'},
 'aquarius': {'n_is_sb': '2', 'n_is_sth': '2'},
 'aquatic bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aquatic mammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aquatic vertebrate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aquila chrysaetos': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aquila rapax': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aquinas': {'n_is_sb': '0'},
 'arab chief': {'n_is_sb': '0'},
 'arabian camel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arabist': {'n_is_sb': '0'},
 'arachnoid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arafat': {'n_is_sb': '0'},
 'aragon': {'n_is_sb': '2', 'n_is_sth': '2'},
 'aram ilich khachaturian': {'n_is_sb': '0'},
 'aram kachaturian': {'n_is_sb': '0'},
 'aram khachaturian': {'n_is_sb': '0'},
 'aramaean': {'n_is_sb': '2', 'n_is_sth': '2'},
 'aramean': {'n_is_sb': '0'},
 'arame': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aramus guarauna': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aramus pictus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aramus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aranea diademata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'araneida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'araneus cavaticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arapahoe': {'n_is_sb': '2', 'n_is_sth': '2'},
 'arapaho': {'n_is_sb': '2', 'n_is_sth': '2'},
 'arawakan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'arawak': {'n_is_sb': '2', 'n_is_sth': '2'},
 'arawn': {'n_is_sb': '0'},
 'ara': {'n_is_sb': '0'},
 'arbitrager': {'n_is_sb': '0'},
 'arbitrageur': {'n_is_sb': '0'},
 'arbitrator': {'n_is_sb': '0'},
 'arboreal salamander': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arboriculturist': {'n_is_sb': '0'},
 'arborist': {'n_is_sb': '0'},
 'arborvirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arbovirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arb': {'n_is_sb': '0'},
 'arcadian': {'n_is_sb': '0'},
 'arca': {'n_is_sb': '0'},
 'arcella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'archaebacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'archaebacterium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'archaeobacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'archaeologist': {'n_is_sb': '0'},
 'archaeopteryx lithographica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'archaeornis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'archangel': {'n_is_sb': '0'},
 'archdeacon': {'n_is_sb': '0'},
 'archduchess': {'n_is_sb': '0'},
 'archduke': {'n_is_sb': '0'},
 'archeobacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'archeologist': {'n_is_sb': '0'},
 'archeopteryx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'archerfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'archiannelida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'archiannelid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'archibald macleish': {'n_is_sb': '0'},
 'archibald percival wavell': {'n_is_sb': '0'},
 'archidiskidon imperator': {'n_is_sb': '3', 'n_is_sth': '3'},
 'archilochus colubris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'archilochus': {'n_is_sb': '0'},
 'archimandrite': {'n_is_sb': '0'},
 'archimedes': {'n_is_sb': '0'},
 'architeuthis': {'n_is_sb': '2', 'n_is_sth': '2'},
 'archivist': {'n_is_sb': '0'},
 'archosargus probatocephalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'archosargus rhomboidalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'archosaurian reptile': {'n_is_sb': '3', 'n_is_sth': '3'},
 'archosaurian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'archosauria': {'n_is_sb': '2', 'n_is_sth': '2'},
 'archosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'archpriest': {'n_is_sb': '0'},
 'arcidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arctic char': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arctic fox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arctic ground squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arctic hare': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arctic skua': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arctic wolf': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arctictis bintourong': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arctictis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arctiid moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arctiidae': {'n_is_sb': '2', 'n_is_sth': '2'},
 'arctiid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arctocebus calabarensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arctocephalus philippi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arctocephalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arctonyx collaris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ardea herodius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ardea occidentalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ardea': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ardeidae': {'n_is_sb': '2', 'n_is_sth': '2'},
 'arenaria interpres': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arenaria-melanocephala': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arenaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arenavirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arendt': {'n_is_sb': '0'},
 'areopagite': {'n_is_sb': '0'},
 'ares': {'n_is_sb': '0'},
 'argal': {'n_is_sb': '2', 'n_is_sth': '2'},
 'argasid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'argentinian': {'n_is_sb': '0', 'cap_word': 'Argentinian'},
 'argentinosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'argiope aurantia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'argiopidae': {'n_is_sb': '2', 'n_is_sth': '2'},
 'argonauta argo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'argonaut': {'n_is_sb': '0'},
 'arguer': {'n_is_sb': '0'},
 'argus pheasant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'argus': {'n_is_sb': '0'},
 'argyrotaenia citrana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arhant': {'n_is_sb': '0'},
 'arhat': {'n_is_sb': '0'},
 'ariadne': {'n_is_sb': '0'},
 'arianist': {'n_is_sb': '0'},
 'arianrhod': {'n_is_sb': '0'},
 'arianrod': {'n_is_sb': '0'},
 'aricara': {'n_is_sb': '2', 'n_is_sth': '2'},
 'aries': {'n_is_sb': '2', 'n_is_sth': '2'},
 'arikara': {'n_is_sb': '2', 'n_is_sth': '2'},
 'arilus cristatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aristarchus of samos': {'n_is_sb': '0'},
 'aristarchus': {'n_is_sb': '0'},
 'aristide maillol': {'n_is_sb': '0'},
 'aristophanes': {'n_is_sb': '0'},
 'aristotelean': {'n_is_sb': '0'},
 'aristotelian': {'n_is_sb': '0', 'cap_word': 'Aristotelian'},
 'aristotle': {'n_is_sb': '0', 'cap_word': 'Aristotle'},
 'arithmetician': {'n_is_sb': '0'},
 'arius': {'n_is_sb': '0'},
 'arizona elegans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arizonan': {'n_is_sb': '0'},
 'arizonian': {'n_is_sb': '0'},
 'arjuna': {'n_is_sb': '0'},
 'ark shell': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arkansan': {'n_is_sb': '0'},
 'arkansas kingbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arkansawyer': {'n_is_sb': '0'},
 'armadillidium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'armand jean du plessis': {'n_is_sb': '0'},
 'armchair liberal': {'n_is_sb': '0'},
 'armed bullhead': {'n_is_sb': '3', 'n_is_sth': '3'},
 'armiger': {'n_is_sb': '0'},
 'arminian': {'n_is_sb': '0'},
 'arminius': {'n_is_sb': '0'},
 'armin': {'n_is_sb': '2', 'n_is_sth': '2'},
 'armor-bearer': {'n_is_sb': '0'},
 'armored catfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'armored dinosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'armored scale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'armored sea robin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'armored searobin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'armourer': {'n_is_sb': '0'},
 'arms manufacturer': {'n_is_sb': '0'},
 'arms-runner': {'n_is_sb': '0'},
 'armstrong': {'n_is_sb': '0'},
 'army ant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'army attache': {'n_is_sb': '0'},
 'army brat': {'n_is_sb': '0'},
 'army cutworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'army engineer': {'n_is_sb': '0'},
 'army officer': {'n_is_sb': '0'},
 'army worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'armyworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arna wendell bontemps': {'n_is_sb': '0'},
 'arnold daniel palmer': {'n_is_sb': '0'},
 'arnold gesell': {'n_is_sb': '0'},
 'arnold joseph toynbee': {'n_is_sb': '0'},
 'arnold lucius gesell': {'n_is_sb': '0'},
 'arnold palmer': {'n_is_sb': '0'},
 'arnold schoenberg': {'n_is_sb': '0'},
 'arnold schonberg': {'n_is_sb': '0'},
 'arnold toynbee': {'n_is_sb': '0'},
 'arnold': {'n_is_sb': '0'},
 'arouet': {'n_is_sb': '0'},
 'arouser': {'n_is_sb': '0'},
 'arp': {'n_is_sb': '0'},
 'arranger': {'n_is_sb': '0'},
 'arrhenius': {'n_is_sb': '0'},
 'arriver': {'n_is_sb': '0'},
 'arrogator': {'n_is_sb': '0'},
 'arrowsmith': {'n_is_sb': '0'},
 'arrowworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'art critic': {'n_is_sb': '0'},
 'art dealer': {'n_is_sb': '0'},
 'art director': {'n_is_sb': '0'},
 'art editor': {'n_is_sb': '0'},
 'art historian': {'n_is_sb': '0'},
 'art student': {'n_is_sb': '0'},
 'art tatum': {'n_is_sb': '0'},
 'art teacher': {'n_is_sb': '0'},
 'artaxerxes ii': {'n_is_sb': '0'},
 'artaxerxes i': {'n_is_sb': '0'},
 'artaxerxes': {'n_is_sb': '0'},
 'artemia salina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'artemia': {'n_is_sb': '2', 'n_is_sth': '2'},
 'artemis': {'n_is_sb': '0'},
 'artemus ward': {'n_is_sb': '0'},
 'arthropod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'arthur ashe': {'n_is_sb': '0'},
 'arthur compton': {'n_is_sb': '0'},
 'arthur conan doyle': {'n_is_sb': '0'},
 'arthur edwin kennelly': {'n_is_sb': '0'},
 'arthur evans': {'n_is_sb': '0'},
 'arthur fiedler': {'n_is_sb': '0'},
 'arthur garfield hays': {'n_is_sb': '0'},
 'arthur holly compton': {'n_is_sb': '0'},
 'arthur holmes': {'n_is_sb': '0'},
 'arthur honegger': {'n_is_sb': '0'},
 'arthur jacob arshawsky': {'n_is_sb': '0'},
 'arthur james balfour': {'n_is_sb': '0'},
 'arthur john gielgud': {'n_is_sb': '0'},
 'arthur koestler': {'n_is_sb': '0'},
 'arthur laffer': {'n_is_sb': '0'},
 'arthur marx': {'n_is_sb': '0'},
 'arthur meier schlesinger jr.': {'n_is_sb': '0'},
 'arthur meier schlesinger': {'n_is_sb': '0'},
 'arthur miller': {'n_is_sb': '0'},
 'arthur mitchell': {'n_is_sb': '0'},
 'arthur neville chamberlain': {'n_is_sb': '0'},
 'arthur rimbaud': {'n_is_sb': '0'},
 'arthur robert ashe': {'n_is_sb': '0'},
 'arthur rubinstein': {'n_is_sb': '0'},
 'arthur schlesinger jr.': {'n_is_sb': '0'},
 'arthur schlesinger': {'n_is_sb': '0'},
 'arthur schopenhauer': {'n_is_sb': '0'},
 'arthur seymour sullivan': {'n_is_sb': '0'},
 'arthur stanley jefferson laurel': {'n_is_sb': '0'},
 'arthur sullivan': {'n_is_sb': '0'},
 'arthur symons': {'n_is_sb': '0'},
 'arthur tappan': {'n_is_sb': '0'},
 'arthur tatum': {'n_is_sb': '0'},
 'arthur wellesley': {'n_is_sb': '0'},
 'arthur': {'n_is_sb': '0'},
 'articulator': {'n_is_sb': '2', 'n_is_sth': '2'},
 'artie shaw': {'n_is_sb': '0'},
 'artificer': {'n_is_sb': '0'},
 'artiodactyl mammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'artiodactyl': {'n_is_sb': '3', 'n_is_sth': '3'},
 "artist's model": {'n_is_sb': '0'},
 'artur rubinstein': {'n_is_sb': '0'},
 'artur schnabel': {'n_is_sb': '0'},
 'arturo toscanini': {'n_is_sb': '0'},
 'arui': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aruru': {'n_is_sb': '0'},
 'arvicola amphibius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aryan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'asa gray': {'n_is_sb': '0'},
 'asa yoelson': {'n_is_sb': '0'},
 'asanga': {'n_is_sb': '0'},
 'asaph hall': {'n_is_sb': '0'},
 'ascaphus trui': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ascaphus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ascaridae': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ascaridia galli': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ascaridia': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ascaris lumbricoides': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ascaris': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ascendent': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ascender': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ascetic': {'n_is_sb': '0'},
 'aschelminthes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'asch': {'n_is_sb': '0'},
 'ascidian tadpole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ascidian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ascophyllum nodosum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ascophyllum': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ashe': {'n_is_sb': '0'},
 'ashir': {'n_is_sb': '0'},
 'ashkenazi': {'n_is_sb': '0'},
 'ashley montagu': {'n_is_sb': '0'},
 'ashton': {'n_is_sb': '0'},
 'ashtoreth': {'n_is_sb': '0'},
 'ashurbanipal': {'n_is_sb': '0'},
 'ashur': {'n_is_sb': '2', 'n_is_sth': '2'},
 'asian black grouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'asian coral snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'asian crocodile': {'n_is_sb': '3', 'n_is_sth': '3'},
 'asian horseshoe crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'asian longhorned beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'asian tiger mosquito': {'n_is_sb': '3', 'n_is_sth': '3'},
 'asian wild ox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'asiatic beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'asiatic black bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'asiatic buffalo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'asiatic cockroach': {'n_is_sb': '3', 'n_is_sth': '3'},
 'asiatic flying squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'asiatic shrew mole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'asiatic': {'n_is_sb': '0', 'cap_word': 'Asiatic'},
 'asimov': {'n_is_sb': '0'},
 'asio otus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'asker': {'n_is_sb': '0'},
 'asp viper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aspidelaps lubricus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aspidelaps': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aspidiotus perniciosus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aspidophoroides monopterygius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aspidophoroides': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aspirer': {'n_is_sb': '0'},
 'aspis': {'n_is_sb': '2', 'n_is_sth': '2'},
 'asp': {'n_is_sb': '2', 'n_is_sth': '2'},
 'asron montgomery ward': {'n_is_sb': '0'},
 'ass-kisser': {'n_is_sb': '0'},
 'assamese': {'n_is_sb': '2', 'n_is_sth': '2'},
 'assassin bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'assassinator': {'n_is_sb': '0'},
 'assaulter': {'n_is_sb': '0'},
 'assayer': {'n_is_sb': '0'},
 'assemblywoman': {'n_is_sb': '0'},
 'asserter': {'n_is_sb': '0'},
 'asseverator': {'n_is_sb': '0'},
 'assignee': {'n_is_sb': '0'},
 'assignor': {'n_is_sb': '0'},
 'assimilator': {'n_is_sb': '0'},
 'assistant foreman': {'n_is_sb': '0'},
 'assistant professor': {'n_is_sb': '0'},
 'associate professor': {'n_is_sb': '0'},
 'assurbanipal': {'n_is_sb': '0'},
 'assyrian': {'n_is_sb': '0'},
 'astacura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'astaire': {'n_is_sb': '0'},
 'astarte': {'n_is_sb': '0'},
 'asteroidea': {'n_is_sb': '2', 'n_is_sth': '2'},
 'asterope': {'n_is_sb': '0'},
 'astor': {'n_is_sb': '2', 'n_is_sth': '2'},
 'astrogator': {'n_is_sb': '0'},
 'astrologist': {'n_is_sb': '0'},
 'astronomer': {'n_is_sb': '0', 'nc_typical': ''},
 'astrophysicist': {'n_is_sb': '0'},
 'astrophyton muricatum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'astropogon stellatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'asura': {'n_is_sb': '0'},
 'asurbanipal': {'n_is_sb': '0'},
 'asvins': {'n_is_sb': '0'},
 'atakapa': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ataturk': {'n_is_sb': '0'},
 'atavist': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ateles geoffroyi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ateles': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ate': {'n_is_sb': '0', 'vbd_to_vb': 'eat', 'vbd_to_vbn': 'eaten'},
 'athabascan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'athabaskan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'athanasius the great': {'n_is_sb': '0'},
 'athanasius': {'n_is_sb': '0'},
 'athapascan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'athapaskan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'atheist': {'n_is_sb': '0'},
 'athelstan': {'n_is_sb': '0'},
 'athena': {'n_is_sb': '0'},
 'athene noctua': {'n_is_sb': '3', 'n_is_sth': '3'},
 'athene': {'n_is_sb': '2', 'n_is_sth': '2'},
 'athenian': {'n_is_sb': '0', 'cap_word': 'Athenian'},
 'atherinopsis californiensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'atherurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'athol fugard': {'n_is_sb': '0'},
 'atlantic bonito': {'n_is_sb': '3', 'n_is_sth': '3'},
 'atlantic bottlenose dolphin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'atlantic cod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'atlantic croaker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'atlantic halibut': {'n_is_sb': '3', 'n_is_sth': '3'},
 'atlantic herring': {'n_is_sb': '3', 'n_is_sth': '3'},
 'atlantic manta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'atlantic moonfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'atlantic puffin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'atlantic ridley': {'n_is_sb': '3', 'n_is_sth': '3'},
 'atlantic sailfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'atlantic salmon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'atlantic sea bream': {'n_is_sb': '3', 'n_is_sth': '3'},
 'atlantic spiny dogfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'atlantic tripletail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'atlantic walrus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'atlantides': {'n_is_sb': '0'},
 'atlas moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'atropos': {'n_is_sb': '0'},
 'atsugewi': {'n_is_sb': '2', 'n_is_sth': '2'},
 'attacapan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'attache': {'n_is_sb': '0'},
 'attack dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'attacker': {'n_is_sb': '0'},
 'attempter': {'n_is_sb': '0'},
 'attender': {'n_is_sb': '0'},
 'attestant': {'n_is_sb': '0'},
 'attestator': {'n_is_sb': '0'},
 'attester': {'n_is_sb': '0'},
 'attestor': {'n_is_sb': '0'},
 'atticus atlas': {'n_is_sb': '3', 'n_is_sth': '3'},
 'atticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'attila': {'n_is_sb': '0'},
 'attlee': {'n_is_sb': '0'},
 'attorney general': {'n_is_sb': '0'},
 'attracter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'attractor': {'n_is_sb': '2', 'n_is_sth': '2'},
 'au pair girl': {'n_is_sb': '0'},
 'au pair': {'n_is_sb': '0'},
 'auchincloss': {'n_is_sb': '0'},
 'audad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'auden': {'n_is_sb': '0'},
 'audile': {'n_is_sb': '2', 'n_is_sth': '2'},
 'audubon warbler': {'n_is_sb': '3', 'n_is_sth': '3'},
 "audubon's caracara": {'n_is_sb': '3', 'n_is_sth': '3'},
 "audubon's warbler": {'n_is_sb': '3', 'n_is_sth': '3'},
 'audubon': {'n_is_sb': '0'},
 'augeas': {'n_is_sb': '0'},
 'augur': {'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'august f. mobius': {'n_is_sb': '0'},
 'august ferdinand mobius': {'n_is_sb': '0'},
 'august friedrich leopold weismann': {'n_is_sb': '0'},
 'august strindberg': {'n_is_sb': '0'},
 'august wilhelm von hoffmann': {'n_is_sb': '0'},
 'auguste comte': {'n_is_sb': '0'},
 'auguste rodin': {'n_is_sb': '0'},
 'augustin eugene scribe': {'n_is_sb': '0'},
 'augustin jean fresnel': {'n_is_sb': '0'},
 'augustine of hippo': {'n_is_sb': '0'},
 'augustine': {'n_is_sb': '0'},
 'augustinian': {'n_is_sb': '0'},
 'augustus welby northmore pugin': {'n_is_sb': '0'},
 'augustus': {'n_is_sb': '0'},
 'auklet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'auk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aulostomus maculatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aulostomus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'aunty': {'n_is_sb': '0'},
 'aurelius': {'n_is_sb': '0'},
 'auriparus flaviceps': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aurochs': {'n_is_sb': '3', 'n_is_sth': '3', 'nn_eq_nns': ''},
 'auspex': {'n_is_sb': '0'},
 'aussie': {'n_is_sb': '0'},
 'austin friar': {'n_is_sb': '0'},
 'australian aborigine': {'n_is_sb': '0'},
 'australian blacksnake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'australian cockroach': {'n_is_sb': '3', 'n_is_sth': '3'},
 'australian coral snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'australian magpie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'australian sea lion': {'n_is_sb': '3', 'n_is_sth': '3'},
 'australian stilt': {'n_is_sb': '3', 'n_is_sth': '3'},
 'australian terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'australian turtledove': {'n_is_sb': '3', 'n_is_sth': '3'},
 'australopithecine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'australopithecus afarensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'australopithecus africanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'australopithecus boisei': {'n_is_sb': '3', 'n_is_sth': '3'},
 'australopithecus robustus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'australopithecus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'austrian': {'n_is_sb': '0', 'cap_word': 'Austrian'},
 'austronesian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'auteur': {'n_is_sb': '0'},
 'authenticator': {'n_is_sb': '2', 'n_is_sth': '2'},
 'authoress': {'n_is_sb': '0'},
 'authoriser': {'n_is_sb': '0'},
 'authoritarian': {'n_is_sb': '0'},
 'authority figure': {'n_is_sb': '0'},
 'authorizer': {'n_is_sb': '0'},
 'auto-mechanic': {'n_is_sb': '0'},
 'autobiographer': {'n_is_sb': '0'},
 'autodidact': {'n_is_sb': '0'},
 'automeris io': {'n_is_sb': '3', 'n_is_sth': '3'},
 'automobile driver': {'n_is_sb': '0'},
 'automobile mechanic': {'n_is_sb': '0'},
 'automobilist': {'n_is_sb': '0'},
 'automotive engineer': {'n_is_sb': '0'},
 'avadavat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'avahi laniger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'avahi': {'n_is_sb': '2', 'n_is_sth': '2'},
 'avalokiteshvara': {'n_is_sb': '0'},
 'avalokitesvara': {'n_is_sb': '0'},
 'avenger': {'n_is_sb': '0'},
 'averell harriman': {'n_is_sb': '0'},
 'averroes': {'n_is_sb': '0'},
 'aves': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aviatress': {'n_is_sb': '0'},
 'aviatrix': {'n_is_sb': '0'},
 'avicenna': {'n_is_sb': '0'},
 'avocet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'avogadro': {'n_is_sb': '0'},
 'avower': {'n_is_sb': '0'},
 'awol': {'n_is_sb': '3', 'n_is_sth': '3'},
 'axolotl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ayah': {'n_is_sb': '0'},
 'ayatollah khomeini': {'n_is_sb': '0'},
 'ayatollah ruholla khomeini': {'n_is_sb': '0'},
 'ayatollah': {'n_is_sb': '0'},
 'aye-aye': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ayn rand': {'n_is_sb': '0'},
 'ayrshire': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aythya affinis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aythya americana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aythya ferina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aythya marila': {'n_is_sb': '3', 'n_is_sth': '3'},
 'aythya valisineria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'azerbaijani': {'n_is_sb': '2', 'n_is_sth': '2'},
 'aztec': {'n_is_sb': '2', 'cap_word': 'Aztec', 'n_is_sth': '2'},
 'b-girl': {'n_is_sb': '2', 'n_is_sth': '2'},
 'b. b. king': {'n_is_sb': '0'},
 'b. f. skinner': {'n_is_sb': '0'},
 'baa-lamb': {'n_is_sb': '3', 'n_is_sth': '3'},
 'baal merodach': {'n_is_sb': '0'},
 'baas': {'n_is_sb': '0'},
 'babar': {'n_is_sb': '0'},
 'babe didrikson': {'n_is_sb': '0'},
 'babe ruth': {'n_is_sb': '0'},
 'babe zaharias': {'n_is_sb': '0'},
 'babiroussa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'babirusa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'babirussa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'baboo': {'n_is_sb': '0'},
 'babu': {'n_is_sb': '0'},
 'baby bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'baby boomer': {'n_is_sb': '0'},
 'baby buster': {'n_is_sb': '0'},
 'baby doctor': {'n_is_sb': '0'},
 'baby doc': {'n_is_sb': '0'},
 'baby farmer': {'n_is_sb': '0'},
 'baby minder': {'n_is_sb': '0'},
 'babyminder': {'n_is_sb': '0'},
 'babyrousa babyrussa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'babyrousa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bacchante': {'n_is_sb': '0'},
 'bacchant': {'n_is_sb': '0'},
 'bacchus': {'n_is_sb': '0'},
 'bachelor girl': {'n_is_sb': '0'},
 'bachelor-at-arms': {'n_is_sb': '0'},
 'bacillaceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bacillariophyceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bacillus anthracis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bacillus globigii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bacillus subtilis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'back judge': {'n_is_sb': '0'},
 'back-number': {'n_is_sb': '0'},
 'backbencher': {'n_is_sb': '0'},
 'backbiter': {'n_is_sb': '0'},
 'backpacker': {'n_is_sb': '0'},
 'backroom boy': {'n_is_sb': '0'},
 'backscratcher': {'n_is_sb': '2', 'n_is_sth': '2'},
 'backseat driver': {'n_is_sb': '0'},
 'backslapper': {'n_is_sb': '0'},
 'backslider': {'n_is_sb': '0'},
 'backstroker': {'n_is_sb': '0'},
 'backswimmer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'backup man': {'n_is_sb': '0'},
 'backwoodsman': {'n_is_sb': '0'},
 'bacteriologist': {'n_is_sb': '0'},
 'bacteroidaceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bacteroides': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bacteroid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bactrian camel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bad egg': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bad fairy': {'n_is_sb': '0'},
 'bad guy': {'n_is_sb': '0'},
 'bad hat': {'n_is_sb': '0'},
 'bad person': {'n_is_sb': '0'},
 'badaga': {'n_is_sb': '2', 'n_is_sth': '2'},
 'baddie': {'n_is_sb': '0'},
 'badger dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'badger skunk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'badgerer': {'n_is_sb': '0'},
 'baeda': {'n_is_sb': '0'},
 'baedeker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bag lady': {'n_is_sb': '0'},
 'baggageman': {'n_is_sb': '0'},
 'bagger': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bagpiper': {'n_is_sb': '0'},
 'bahai': {'n_is_sb': '0'},
 'bahamian': {'n_is_sb': '0'},
 'bahraini': {'n_is_sb': '0'},
 'bahreini': {'n_is_sb': '0'},
 'bailee': {'n_is_sb': '0'},
 'bailor': {'n_is_sb': '0'},
 'baiomys taylori': {'n_is_sb': '3', 'n_is_sth': '3'},
 'baiomys': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bairava': {'n_is_sb': '0'},
 'bairdiella chrysoura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bairdiella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bairn': {'n_is_sb': '0'},
 'bakunin': {'n_is_sb': '0'},
 'balaena mysticetus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'balaeniceps rex': {'n_is_sb': '3', 'n_is_sth': '3'},
 'balaenoptera acutorostrata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'balaenoptera borealis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'balaenoptera musculus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'balaenoptera physalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'balancer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'balanchine': {'n_is_sb': '0'},
 'balanus balanoides': {'n_is_sb': '3', 'n_is_sth': '3'},
 'balarama': {'n_is_sb': '0'},
 'balboa': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bald eagle': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bald-faced hornet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'balder': {'n_is_sb': '0'},
 'baldhead': {'n_is_sb': '0'},
 'baldpate': {'n_is_sb': '2', 'n_is_sth': '2'},
 'baldr': {'n_is_sb': '0'},
 'baldwin': {'n_is_sb': '2', 'n_is_sth': '2'},
 'baleen whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'balenciaga': {'n_is_sb': '0'},
 'balfour': {'n_is_sb': '0'},
 'balistes vetula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'balistes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'balkan': {'n_is_sb': '0', 'cap_word': 'Balkan'},
 'balker': {'n_is_sb': '0'},
 'ball boy': {'n_is_sb': '0'},
 'ball carrier': {'n_is_sb': '0'},
 'ball hawk': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ball of fire': {'n_is_sb': '0'},
 'ball-breaker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ball-buster': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ballad maker': {'n_is_sb': '0'},
 'balladeer': {'n_is_sb': '0'},
 'baller mistress': {'n_is_sb': '0'},
 'ballerina': {'n_is_sb': '0'},
 'ballet dancer': {'n_is_sb': '0'},
 'ballet master': {'n_is_sb': '0'},
 'balletomane': {'n_is_sb': '0'},
 'balloonfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'balloonist': {'n_is_sb': '0'},
 'ballplayer': {'n_is_sb': '0'},
 'ballyhoo artist': {'n_is_sb': '0'},
 'balsam woolly aphid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'balthasar': {'n_is_sb': '0'},
 'balthazar': {'n_is_sb': '2', 'n_is_sth': '2'},
 'baltimore bird': {'n_is_sb': '0'},
 'baltimore oriole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'banana quit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'band-tail pigeon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'band-tailed pigeon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'banded adder': {'n_is_sb': '3', 'n_is_sth': '3'},
 'banded anteater': {'n_is_sb': '3', 'n_is_sth': '3'},
 'banded gecko': {'n_is_sb': '3', 'n_is_sth': '3'},
 'banded krait': {'n_is_sb': '2', 'n_is_sth': '2'},
 'banded palm civet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'banded purple': {'n_is_sb': '3', 'n_is_sth': '3'},
 'banded rattlesnake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'banded rudderfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'banded sand snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'banded stilt': {'n_is_sb': '3', 'n_is_sth': '3'},
 'banded water snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'banderillero': {'n_is_sb': '0'},
 'bandicoot rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bandleader': {'n_is_sb': '0'},
 'bandmaster': {'n_is_sb': '0'},
 'bandsman': {'n_is_sb': '0'},
 'bandtail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bangladeshi': {'n_is_sb': '0'},
 'bangtail': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bank clerk': {'n_is_sb': '0'},
 'bank commissioner': {'n_is_sb': '0'},
 'bank examiner': {'n_is_sb': '0'},
 'bank guard': {'n_is_sb': '0'},
 'bank manager': {'n_is_sb': '0'},
 'bank martin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bank robber': {'n_is_sb': '0'},
 'bank swallow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bankhead': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bankia setaceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bankia': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bankrupt': {'n_is_sb': '0'},
 'banneret': {'n_is_sb': '0'},
 'bannister': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bantamweight': {'n_is_sb': '0'},
 'banteng': {'n_is_sb': '3', 'n_is_sth': '3'},
 'banting': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bantu': {'n_is_sb': '2', 'n_is_sth': '2'},
 'baptist': {'n_is_sb': '0'},
 'bar fly': {'n_is_sb': '0'},
 'bar girl': {'n_is_sb': '0'},
 'baraka': {'n_is_sb': '0'},
 'baranduki': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barany': {'n_is_sb': '0'},
 'barbadian': {'n_is_sb': '0'},
 'barbara hepworth': {'n_is_sb': '0'},
 'barbara tuchman': {'n_is_sb': '0'},
 'barbara ward': {'n_is_sb': '0'},
 'barbara wertheim tuchman': {'n_is_sb': '0'},
 'barbarian': {'n_is_sb': '0'},
 'barbarossa': {'n_is_sb': '0'},
 'barbary ape': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barbary pirate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barbary sheep': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barbel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barbet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barbra joan streisand': {'n_is_sb': '0'},
 'barbra streisand': {'n_is_sb': '0'},
 'barbu': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bardeen': {'n_is_sb': '0'},
 'bargain hunter': {'n_is_sb': '0'},
 'bargee': {'n_is_sb': '0'},
 'bargeman': {'n_is_sb': '0'},
 'bark beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bark louse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bark-louse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barkeep': {'n_is_sb': '0'},
 'barking deer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barking frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barkley': {'n_is_sb': '0'},
 'barmaid': {'n_is_sb': '0'},
 'barman': {'n_is_sb': '0'},
 'barn owl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barn spider': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barn swallow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barnacle goose': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barnacle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barnburner': {'n_is_sb': '2', 'n_is_sth': '2'},
 'barndoor skate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barney oldfield': {'n_is_sb': '0'},
 'barnstormer': {'n_is_sb': '0'},
 'barnum': {'n_is_sb': '0'},
 'baron adrian': {'n_is_sb': '0'},
 'baron alexander von humboldt': {'n_is_sb': '0'},
 'baron clive of plassey': {'n_is_sb': '0'},
 'baron clive': {'n_is_sb': '0'},
 'baron de la brede et de montesquieu': {'n_is_sb': '0'},
 'baron friedrich heinrich alexander von humboldt': {'n_is_sb': '0'},
 'baron friedrich wilhelm ludolf gerhard augustin von steuben': {'n_is_sb': '0'},
 'baron georges cuvier': {'n_is_sb': '0'},
 'baron hermann ludwig ferdinand von helmholtz': {'n_is_sb': '0'},
 'baron hugh caswall tremenheere dowding': {'n_is_sb': '0'},
 'baron jean baptiste joseph fourier': {'n_is_sb': '0'},
 'baron karl maria friedrich ernst von weber': {'n_is_sb': '0'},
 'baron karl wilhelm von humboldt': {'n_is_sb': '0'},
 'baron lister': {'n_is_sb': '0'},
 'baron lloyd webber of sydmonton': {'n_is_sb': '0'},
 'baron munchausen': {'n_is_sb': '0'},
 'baron olivier of birghton': {'n_is_sb': '0'},
 'baron richard von krafft-ebing': {'n_is_sb': '0'},
 'baron snow of leicester': {'n_is_sb': '0'},
 'baron verulam': {'n_is_sb': '0'},
 'baron wilhelm von humboldt': {'n_is_sb': '0'},
 'baronduki': {'n_is_sb': '3', 'n_is_sth': '3'},
 'baroness dudevant': {'n_is_sb': '0'},
 'baroness emmusca orczy': {'n_is_sb': '0'},
 'baroness jackson of lodsworth': {'n_is_sb': '0'},
 'baroness karen blixen': {'n_is_sb': '0'},
 'baroness thatcher of kesteven': {'n_is_sb': '0'},
 'baroness': {'n_is_sb': '0'},
 'baronet': {'n_is_sb': '0'},
 'baronne anne louise germaine necker de steal-holstein': {'n_is_sb': '0'},
 'barosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barramunda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barramundi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barred owl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barred pickerel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barrel maker': {'n_is_sb': '0'},
 'barrelfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barren ground caribou': {'n_is_sb': '3', 'n_is_sth': '3'},
 'barrie': {'n_is_sb': '0'},
 "barrow's goldeneye": {'n_is_sb': '3', 'n_is_sth': '3'},
 'barrow-boy': {'n_is_sb': '0'},
 'barrow-man': {'n_is_sb': '0'},
 'barrymore': {'n_is_sb': '0'},
 'barterer': {'n_is_sb': '0'},
 'barthelme': {'n_is_sb': '0'},
 'barthold george niebuhr': {'n_is_sb': '0'},
 'bartholdi': {'n_is_sb': '0'},
 'bartholin': {'n_is_sb': '0'},
 'bartholomeu dias': {'n_is_sb': '0'},
 'bartholomeu diaz': {'n_is_sb': '0'},
 'bartholomew roberts': {'n_is_sb': '0'},
 'barth': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bartlett': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bartok': {'n_is_sb': '0'},
 'bartolome esteban murillo': {'n_is_sb': '0'},
 'bartolomeo prignano': {'n_is_sb': '0'},
 'bartolomeo vanzetti': {'n_is_sb': '0'},
 'bartolommeo eustachio': {'n_is_sb': '0'},
 'bartramia longicauda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bartramian sandpiper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bart': {'n_is_sb': '0'},
 'baruch de spinoza': {'n_is_sb': '0'},
 'baruch': {'n_is_sb': '2', 'n_is_sth': '2'},
 'barunduki': {'n_is_sb': '3', 'n_is_sth': '3'},
 'baryshnikov': {'n_is_sb': '0'},
 'barytone': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bas bleu': {'n_is_sb': '0'},
 'base runner': {'n_is_sb': '0'},
 'baseball coach': {'n_is_sb': '0'},
 'baseball manager': {'n_is_sb': '0'},
 'baseball player': {'n_is_sb': '0'},
 'basenji': {'n_is_sb': '3', 'n_is_sth': '3'},
 'basil of caesarea': {'n_is_sb': '0'},
 'basil the great': {'n_is_sb': '0'},
 'basileus': {'n_is_sb': '0'},
 'basilisk': {'n_is_sb': '2', 'n_is_sth': '2'},
 'basil': {'n_is_sb': '3', 'n_is_sth': '3'},
 'basket fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'basket maker': {'n_is_sb': '0'},
 'basket star': {'n_is_sb': '3', 'n_is_sth': '3'},
 'basketball coach': {'n_is_sb': '0'},
 'basketball player': {'n_is_sb': '0'},
 'basketeer': {'n_is_sb': '0'},
 'basketmaker': {'n_is_sb': '0'},
 'basketweaver': {'n_is_sb': '0'},
 'basking shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'basotho': {'n_is_sb': '0'},
 'basque': {'n_is_sb': '2', 'cap_word': 'Basque', 'n_is_sth': '2'},
 'bassariscus astutus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bassariscus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bassarisk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'basset hound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bassist': {'n_is_sb': '0'},
 'bassoonist': {'n_is_sb': '0'},
 'bastard ridley': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bastard turtle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bat boy': {'n_is_sb': '0'},
 'batfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bather': {'n_is_sb': '0'},
 'bathyergidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'batoidei': {'n_is_sb': '2', 'n_is_sth': '2'},
 'baton twirler': {'n_is_sb': '0'},
 'batrachian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'batrachia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'batrachoseps': {'n_is_sb': '2', 'n_is_sth': '2'},
 'batsman': {'n_is_sb': '0'},
 'batswana': {'n_is_sb': '0'},
 'batting coach': {'n_is_sb': '0'},
 'battle-axe': {'n_is_sb': '2', 'n_is_sth': '2'},
 'battle-ax': {'n_is_sb': '2', 'n_is_sth': '2'},
 'battler': {'n_is_sb': '0'},
 'baudelaire': {'n_is_sb': '0'},
 'baulker': {'n_is_sb': '0'},
 'baum': {'n_is_sb': '0'},
 'bawler': {'n_is_sb': '0'},
 'bay lynx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bay scallop': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bay stater': {'n_is_sb': '0'},
 'bayard': {'n_is_sb': '0'},
 'baya': {'n_is_sb': '0'},
 'bayes': {'n_is_sb': '0'},
 'beach flea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'beachcomber': {'n_is_sb': '2', 'n_is_sth': '2'},
 'beaded lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'beadsman': {'n_is_sb': '0'},
 'beaked salmon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'beaked whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bean aphid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bean beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bean counter': {'n_is_sb': '0'},
 'bean weevil': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bear cat': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bear cub': {'n_is_sb': '3', 'n_is_sth': '3'},
 'beard worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bearded seal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bearded vulture': {'n_is_sb': '3', 'n_is_sth': '3'},
 'beast of burden': {'n_is_sb': '3', 'n_is_sth': '3'},
 'beatnik': {'n_is_sb': '0'},
 'beatrice lillie': {'n_is_sb': '0'},
 'beatrice webb': {'n_is_sb': '0'},
 'beatrice': {'n_is_sb': '0'},
 'beau brummell': {'n_is_sb': '0'},
 'beaugregory': {'n_is_sb': '3', 'n_is_sth': '3'},
 'beaumont': {'n_is_sb': '2', 'n_is_sth': '2'},
 'beauty consultant': {'n_is_sb': '0'},
 'beauvoir': {'n_is_sb': '0', 'cap_word': 'Beauvoir'},
 'beaver rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'beaverbrook': {'n_is_sb': '0'},
 'bechuana': {'n_is_sb': '2', 'n_is_sth': '2'},
 'beckett': {'n_is_sb': '0'},
 'becket': {'n_is_sb': '2', 'n_is_sth': '2'},
 'becquerel': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bed bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bed wetter': {'n_is_sb': '0'},
 'beda': {'n_is_sb': '0'},
 'bedesman': {'n_is_sb': '0'},
 'bede': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bedlamite': {'n_is_sb': '0'},
 'bedlington terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bedrich smetana': {'n_is_sb': '0'},
 'beduin': {'n_is_sb': '0'},
 'bedwetter': {'n_is_sb': '0'},
 'bee beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bee eater': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bee fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bee killer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bee moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'beech marten': {'n_is_sb': '3', 'n_is_sth': '3'},
 'beecher': {'n_is_sb': '0'},
 'beef cattle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'beef man': {'n_is_sb': '0'},
 'beefalo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'beekeeper': {'n_is_sb': '0'},
 'beer drinker': {'n_is_sb': '0'},
 'beer maker': {'n_is_sb': '0'},
 'beerbohm': {'n_is_sb': '0'},
 'beet armyworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'begetter': {'n_is_sb': '0'},
 'beggarman': {'n_is_sb': '0'},
 'beggarwoman': {'n_is_sb': '0'},
 'begin': {'n_is_sb': '0', 'v_vbg': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'begins', 'vb_to_vbd': 'began', 'vb_to_vbn': 'began', 'vb_to_vbg': 'beginning', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'beguiler': {'n_is_sb': '0'},
 'beguine': {'n_is_sb': '2', 'n_is_sth': '2'},
 'behaviorist': {'n_is_sb': '0'},
 'behaviourist': {'n_is_sb': '0'},
 'behmen': {'n_is_sb': '0'},
 'beholder': {'n_is_sb': '0'},
 'behrens': {'n_is_sb': '0'},
 'behring': {'n_is_sb': '0'},
 'bel esprit': {'n_is_sb': '0'},
 'bel-merodach': {'n_is_sb': '0'},
 'bela bartok': {'n_is_sb': '0'},
 'bela ferenc blasko': {'n_is_sb': '0'},
 'bela lugosi': {'n_is_sb': '0'},
 'beldam': {'n_is_sb': '0'},
 'belemnite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'belgian griffon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'belgian hare': {'n_is_sb': '3', 'n_is_sth': '3'},
 'belgian sheepdog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'belgian shepherd': {'n_is_sb': '0'},
 'belgian': {'n_is_sb': '0', 'cap_word': 'Belgian'},
 'belisarius': {'n_is_sb': '0'},
 'bell captain': {'n_is_sb': '0'},
 'bell founder': {'n_is_sb': '0'},
 'bell magpie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bell ringer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bell toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bellarmine': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bellarmino': {'n_is_sb': '0'},
 'bellbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'belle miriam silverman': {'n_is_sb': '0'},
 'bellerophon': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bellini': {'n_is_sb': '2', 'n_is_sth': '2'},
 'belloc': {'n_is_sb': '0'},
 'bellower': {'n_is_sb': '0'},
 'bellows fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'belly dancer': {'n_is_sb': '0'},
 'bellyacher': {'n_is_sb': '0'},
 'belorussian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'beloved': {'n_is_sb': '0', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'belshazzar': {'n_is_sb': '0'},
 'belt maker': {'n_is_sb': '0'},
 'belted kingfisher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'belted sandfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bel': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bemisia tabaci': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bemisia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ben gurion': {'n_is_sb': '0'},
 'ben hecht': {'n_is_sb': '0'},
 'ben hogan': {'n_is_sb': '0'},
 'ben jonson': {'n_is_sb': '0'},
 'ben shahn': {'n_is_sb': '0'},
 'bench warmer': {'n_is_sb': '0'},
 'benchley': {'n_is_sb': '0'},
 'benedick': {'n_is_sb': '0'},
 'benedict arnold': {'n_is_sb': '0'},
 'benedict de spinoza': {'n_is_sb': '0'},
 'benedictine': {'n_is_sb': '2', 'cap_word': 'Benedictine', 'n_is_sth': '2'},
 'benedict': {'n_is_sb': '0'},
 'benefactress': {'n_is_sb': '0'},
 'beneficiary': {'n_is_sb': '0'},
 'benet': {'n_is_sb': '0'},
 'bengal tiger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'beninese': {'n_is_sb': '0'},
 'benito mussolini': {'n_is_sb': '0'},
 'benjamin britten': {'n_is_sb': '0'},
 'benjamin david goodman': {'n_is_sb': '0'},
 'benjamin disraeli': {'n_is_sb': '0'},
 'benjamin franklin norris jr.': {'n_is_sb': '0'},
 'benjamin franklin': {'n_is_sb': '0'},
 'benjamin harrison': {'n_is_sb': '0'},
 'benjamin harris': {'n_is_sb': '0'},
 'benjamin henry latrobe': {'n_is_sb': '0'},
 'benjamin jonson': {'n_is_sb': '0'},
 'benjamin jowett': {'n_is_sb': '0'},
 'benjamin kubelsky': {'n_is_sb': '0'},
 'benjamin peirce': {'n_is_sb': '0'},
 'benjamin ricketson tucker': {'n_is_sb': '0'},
 'benjamin rush': {'n_is_sb': '0'},
 'benjamin shahn': {'n_is_sb': '0'},
 'benjamin spock': {'n_is_sb': '0'},
 'benjamin thompson': {'n_is_sb': '0'},
 'benjamin west': {'n_is_sb': '0'},
 'bennett': {'n_is_sb': '0'},
 'benny goodman': {'n_is_sb': '0'},
 'benny hill': {'n_is_sb': '0'},
 'benny': {'n_is_sb': '2', 'n_is_sth': '2'},
 'benoit mandelbrot': {'n_is_sb': '0'},
 'bentham': {'n_is_sb': '0'},
 'benton': {'n_is_sb': '0'},
 'benvenuto cellini': {'n_is_sb': '0'},
 'beowulf': {'n_is_sb': '0'},
 'berber': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bergall': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bergman': {'n_is_sb': '0'},
 'bergson': {'n_is_sb': '0'},
 'beria': {'n_is_sb': '0'},
 'berk': {'n_is_sb': '0'},
 'berlage': {'n_is_sb': '0'},
 'berliner': {'n_is_sb': '0'},
 'berlioz': {'n_is_sb': '0'},
 'bermuda chub': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bermudan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bermudian': {'n_is_sb': '0'},
 'berna eli oldfield': {'n_is_sb': '0'},
 'bernanrd arthur owen williams': {'n_is_sb': '0'},
 'bernard baruch': {'n_is_sb': '0'},
 'bernard hinault': {'n_is_sb': '0'},
 'bernard law montgomery': {'n_is_sb': '0'},
 'bernard malamud': {'n_is_sb': '0'},
 'bernard mannes baruch': {'n_is_sb': '0'},
 'bernardo bertolucci': {'n_is_sb': '0'},
 'bernard': {'n_is_sb': '0'},
 'bernd heinrich wilhelm von kleist': {'n_is_sb': '0'},
 'bernese mountain dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bernhard riemann': {'n_is_sb': '0'},
 'bernhardt': {'n_is_sb': '0'},
 'bernini': {'n_is_sb': '0'},
 'bernoulli': {'n_is_sb': '0'},
 'bernstein': {'n_is_sb': '0'},
 'beroe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'berra': {'n_is_sb': '0'},
 'berserker': {'n_is_sb': '0'},
 'berserk': {'n_is_sb': '0'},
 'bertillon': {'n_is_sb': '0'},
 'bertolt brecht': {'n_is_sb': '0'},
 'bertolucci': {'n_is_sb': '0'},
 'bertrand arthur william russell': {'n_is_sb': '0'},
 'bertrand russell': {'n_is_sb': '0'},
 'berzelius': {'n_is_sb': '0'},
 'besieger': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bessel': {'n_is_sb': '0'},
 'bessemer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bessie smith': {'n_is_sb': '0'},
 'bessy cerca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'best and greatest': {'n_is_sb': '0'},
 'best friend': {'n_is_sb': '0'},
 'best man': {'n_is_sb': '0'},
 'bete noire': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bethe': {'n_is_sb': '0'},
 'bethune': {'n_is_sb': '0'},
 'betsy griscom ross': {'n_is_sb': '0'},
 'betsy ross': {'n_is_sb': '0'},
 'bette davis': {'n_is_sb': '0'},
 'better half': {'n_is_sb': '0'},
 'bettongia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bettong': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bettor': {'n_is_sb': '0'},
 'betty friedan': {'n_is_sb': '0'},
 'betty naomi friedan': {'n_is_sb': '0'},
 'beveridge': {'n_is_sb': '0'},
 'beverly sills': {'n_is_sb': '0'},
 'bevin': {'n_is_sb': '0'},
 "bewick's swan": {'n_is_sb': '0'},
 'bey': {'n_is_sb': '0'},
 'bezoar goat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bhaga': {'n_is_sb': '0'},
 'bhumi devi': {'n_is_sb': '0'},
 'bhutanese': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bhutani': {'n_is_sb': '0'},
 'bibliographer': {'n_is_sb': '0'},
 'bibliophile': {'n_is_sb': '0'},
 'bibliopole': {'n_is_sb': '0'},
 'bibliopolist': {'n_is_sb': '0'},
 'bibliothec': {'n_is_sb': '0'},
 'bibliotist': {'n_is_sb': '0'},
 'bibos frontalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bibos gaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bibos': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bicycler': {'n_is_sb': '0'},
 'bicyclist': {'n_is_sb': '0'},
 'bierce': {'n_is_sb': '0'},
 'big bedbug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'big bill haywood': {'n_is_sb': '0'},
 'big bill tilden': {'n_is_sb': '0'},
 'big brother': {'n_is_sb': '0'},
 'big brown bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'big businessman': {'n_is_sb': '0'},
 'big cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'big cheese': {'n_is_sb': '0'},
 'big deal': {'n_is_sb': '2', 'n_is_sth': '2'},
 'big enchilada': {'n_is_sb': '0'},
 'big fish': {'n_is_sb': '2', 'n_is_sth': '2'},
 'big game': {'n_is_sb': '3', 'n_is_sth': '3'},
 'big gun': {'n_is_sb': '2', 'n_is_sth': '2'},
 'big leaguer': {'n_is_sb': '0'},
 'big shot': {'n_is_sb': '0'},
 'big sister': {'n_is_sb': '0'},
 'big spender': {'n_is_sb': '0'},
 'big wheel': {'n_is_sb': '0'},
 'big-eared bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'big-eyed scad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bigamist': {'n_is_sb': '0'},
 'bigeye scad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bigeye': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bigfoot': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bighorn sheep': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bighorn': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bilby': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bilingual': {'n_is_sb': '0'},
 'bill clinton': {'n_is_sb': '0'},
 'bill gates': {'n_is_sb': '0'},
 'bill haley': {'n_is_sb': '0'},
 'bill mauldin': {'n_is_sb': '0'},
 'bill poster': {'n_is_sb': '0'},
 'bill russell': {'n_is_sb': '0'},
 'bill sticker': {'n_is_sb': '0'},
 'billiard player': {'n_is_sb': '0'},
 'billie jean king': {'n_is_sb': '0'},
 'billie jean moffitt king': {'n_is_sb': '0'},
 'billie the kid': {'n_is_sb': '0'},
 'billy goat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'billy graham': {'n_is_sb': '0'},
 'billy mitchell': {'n_is_sb': '0'},
 'billy wilder': {'n_is_sb': '0'},
 'biloxi': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bimetallist': {'n_is_sb': '0'},
 'bin laden': {'n_is_sb': '0'},
 'binet': {'n_is_sb': '0'},
 'bing crosby': {'n_is_sb': '0'},
 'binger': {'n_is_sb': '0'},
 'binturong': {'n_is_sb': '3', 'n_is_sth': '3'},
 'biochemist': {'n_is_sb': '0'},
 'biographer': {'n_is_sb': '0'},
 'biologist': {'n_is_sb': '0'},
 'bionic man': {'n_is_sb': '0'},
 'bionic woman': {'n_is_sb': '0'},
 'biophysicist': {'n_is_sb': '0'},
 'biped': {'n_is_sb': '0'},
 'biplane flying fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'birch leaf miner': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bird dog': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bird fancier': {'n_is_sb': '0'},
 'bird louse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bird of jove': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bird of juno': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bird of minerva': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bird of night': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bird of paradise': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bird of passage': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bird of prey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bird parker': {'n_is_sb': '0'},
 'bird watcher': {'n_is_sb': '0'},
 'bird-footed dinosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'birder': {'n_is_sb': '0'},
 'birth-control campaigner': {'n_is_sb': '0'},
 'birth-control reformer': {'n_is_sb': '0'},
 'bisayan': {'n_is_sb': '0'},
 'bisexual person': {'n_is_sb': '0'},
 'bishop berkeley': {'n_is_sb': '0'},
 'bishop of rome': {'n_is_sb': '0'},
 'bishop ulfilas': {'n_is_sb': '0'},
 'bishop ulfila': {'n_is_sb': '0'},
 'bishop wulfila': {'n_is_sb': '0'},
 'bison bison': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bison bonasus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'biter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'biting louse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'biting midge': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bitis arietans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bitis gabonica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bittern': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bizet': {'n_is_sb': '2', 'n_is_sth': '2'},
 'blabber': {'n_is_sb': '0'},
 'blaberus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black african': {'n_is_sb': '0'},
 'black american': {'n_is_sb': '0'},
 'black and gold garden spider': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black and tan': {'n_is_sb': '0'},
 'black angus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black bass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black bee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black belt': {'n_is_sb': '2', 'n_is_sth': '2'},
 'black bream': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black buck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black buffalo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black carpet beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black cat': {'n_is_sb': '2', 'n_is_sth': '2'},
 'black cock': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black crappie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black duck': {'n_is_sb': '2', 'n_is_sth': '2'},
 'black fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black fox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black friar': {'n_is_sb': '0'},
 'black grouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black guillemot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black hawk': {'n_is_sb': '2', 'n_is_sth': '2'},
 'black jack pershing': {'n_is_sb': '0'},
 'black kite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black mamba': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black man': {'n_is_sb': '0'},
 'black margate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black marketeer': {'n_is_sb': '0'},
 'black marlin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black muslim': {'n_is_sb': '0'},
 'black panther': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black person': {'n_is_sb': '0'},
 'black prince': {'n_is_sb': '0'},
 'black racer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black race': {'n_is_sb': '0'},
 'black rat snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black rhinoceros': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black rockweed': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black rudderfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black sea bass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black sheep': {'n_is_sb': '2', 'n_is_sth': '2'},
 'black squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black stork': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black swan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black turnstone': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black vulture': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black weevil': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black widow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black woman': {'n_is_sb': '0'},
 'black-and-tan coonhound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black-and-tan terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black-backed gull': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black-billed cuckoo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black-capped chickadee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black-crowned night heron': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black-footed albatross': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black-footed ferret': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black-fronted bush shrike': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black-headed snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black-legged tick': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black-necked cobra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black-necked grebe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black-necked stilt': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black-necked stork': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black-tailed deer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'black-winged stilt': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blackamoor': {'n_is_sb': '0'},
 'blackback flounder': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blackbeard': {'n_is_sb': '2', 'n_is_sth': '2'},
 'blackbeetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blackbuck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blackburnian warbler': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blackcap': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blackcock': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blackfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blackfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blackfoot': {'n_is_sb': '2', 'n_is_sth': '2'},
 'blackfriar': {'n_is_sb': '0'},
 'blackleg': {'n_is_sb': '2', 'n_is_sth': '2'},
 'blackmailer': {'n_is_sb': '0'},
 'blackmouth bass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blackpoll': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blackshirt': {'n_is_sb': '0'},
 'blacksnake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blacktail deer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blacktail jackrabbit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blacktail prairie dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blacktail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blacktip shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bladder fucus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bladder worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bladdernose': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bladderwrack': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blair': {'n_is_sb': '0'},
 'blaise pascal': {'n_is_sb': '0'},
 'blake': {'n_is_sb': '0'},
 'blanquillo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blarina brevicauda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blarina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blasphemer': {'n_is_sb': '0'},
 'blaster': {'n_is_sb': '2', 'n_is_sth': '2'},
 'blatta orientalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blattaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blatta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blattella germanica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blattodea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bleeding heart': {'n_is_sb': '0'},
 'bleeding tooth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blenheim spaniel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blennioid fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blennioidea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blennioid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blennius pholis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blenny': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bleriot': {'n_is_sb': '0'},
 'blessed trinity': {'n_is_sb': '0'},
 'blessed virgin': {'n_is_sb': '0'},
 'blighter': {'n_is_sb': '0'},
 'bligh': {'n_is_sb': '0'},
 'blind date': {'n_is_sb': '2', 'n_is_sth': '2'},
 'blind eel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blind man': {'n_is_sb': '0'},
 'blind person': {'n_is_sb': '0'},
 'blind snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blindworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blissus leucopterus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blissus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blister beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blitzstein': {'n_is_sb': '0'},
 'blixen': {'n_is_sb': '0'},
 'bloch': {'n_is_sb': '0'},
 'blocker': {'n_is_sb': '2', 'nn_to_vb': 'block', 'nn_to_jj': 'blocked', 'n_is_sth': '2'},
 'blok': {'n_is_sb': '0'},
 'blonde': {'n_is_sb': '0'},
 'blond': {'n_is_sb': '0', 'jj_to_jjr': 'blonder', 'jj_to_jjs': 'blondest'},
 'blood brother': {'n_is_sb': '0'},
 'blood clam': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blood donor': {'n_is_sb': '0'},
 'blood fluke': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blood relation': {'n_is_sb': '0'},
 'blood relative': {'n_is_sb': '0'},
 'bloodworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bloody mary': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bloomfield': {'n_is_sb': '0'},
 'blow fly': {'n_is_sb': '2', 'n_is_sth': '2'},
 'blowfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blowfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blowhard': {'n_is_sb': '0'},
 'blubberer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bludgeoner': {'n_is_sb': '0'},
 'blue baby': {'n_is_sb': '0'},
 'blue blood': {'n_is_sb': '0'},
 'blue bull': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue catfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue channel catfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue channel cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue darter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue fox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue goose': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue jack': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue jay': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue marlin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue mockingbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue peafowl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue pickerel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue pikeperch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue pike': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue point siamese': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue pointed': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue point': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue racer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue runner': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue tit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue walleye': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue-belly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue-green algae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue-headed vireo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blue-winged teal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'blueback salmon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bluebill': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bluebird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bluebottle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bluefin tuna': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bluefin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bluefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bluegill': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bluehead': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bluejacket': {'n_is_sb': '0'},
 'bluepoint': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bluestocking': {'n_is_sb': '0'},
 'bluethroat pikeblenny': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bluethroat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bluetick': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bluewing': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bluffer': {'n_is_sb': '0'},
 'blunderer': {'n_is_sb': '0'},
 'blusterer': {'n_is_sb': '0'},
 "bo's'n": {'n_is_sb': '0'},
 "bo'sun": {'n_is_sb': '0'},
 'boa constrictor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'boann': {'n_is_sb': '0'},
 'board member': {'n_is_sb': '0'},
 'boarfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'boarhound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'boaster': {'n_is_sb': '0'},
 'boat bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'boat-billed heron': {'n_is_sb': '0'},
 'boatbill': {'n_is_sb': '3', 'n_is_sth': '3'},
 'boatbuilder': {'n_is_sb': '0'},
 'boatswain bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'boatswain': {'n_is_sb': '0'},
 'bob dylan': {'n_is_sb': '0'},
 'bob hope': {'n_is_sb': '0'},
 'bob marley': {'n_is_sb': '0'},
 'bob mathias': {'n_is_sb': '0'},
 'bobby fischer': {'n_is_sb': '0'},
 'bobby jones': {'n_is_sb': '0'},
 'bobby orr': {'n_is_sb': '0'},
 'bobby-socker': {'n_is_sb': '0'},
 'bobbysoxer': {'n_is_sb': '0'},
 'bobcat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bobolink': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bobwhite quail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bobwhite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'boccaccio': {'n_is_sb': '0'},
 'boddhisatva': {'n_is_sb': '0'},
 'bodoni': {'n_is_sb': '2', 'n_is_sth': '2'},
 'body louse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'body servant': {'n_is_sb': '0'},
 'body snatcher': {'n_is_sb': '0'},
 'bodybuilder': {'n_is_sb': '0'},
 'boehme': {'n_is_sb': '0'},
 'boehm': {'n_is_sb': '0'},
 'boer': {'n_is_sb': '0'},
 'boethius': {'n_is_sb': '0'},
 'bogart': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bogy': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bohemian waxwing': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bohme': {'n_is_sb': '0'},
 'bohr': {'n_is_sb': '0'},
 'boleyn': {'n_is_sb': '0'},
 'bolingbroke': {'n_is_sb': '0'},
 'bolivar': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bolivian': {'n_is_sb': '0'},
 'boll weevil': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bollworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bolshevik': {'n_is_sb': '0'},
 'bolshevist': {'n_is_sb': '0'},
 'bolshie': {'n_is_sb': '0', 'jj_to_jjr': 'bolshier', 'jj_to_jjs': 'bolshiest'},
 'bolti': {'n_is_sb': '3', 'n_is_sth': '3'},
 'boltzmann': {'n_is_sb': '0'},
 'bombardier beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bomber harris': {'n_is_sb': '0'},
 'bombina bombina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bombina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bombus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bombycid moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bombycid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bombycilla cedrorun': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bombycilla garrulus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bombycilla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bombyliidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bombyx mori': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bombyx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bon vivant': {'n_is_sb': '0'},
 'bonaparte': {'n_is_sb': '0'},
 'bonasa umbellus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bonasa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bond servant': {'n_is_sb': '0'},
 'bondholder': {'n_is_sb': '0'},
 'bondmaid': {'n_is_sb': '0'},
 'bondman': {'n_is_sb': '0'},
 'bondswoman': {'n_is_sb': '0'},
 'bondwoman': {'n_is_sb': '0'},
 'bone-headed dinosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bonefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bonesetter': {'n_is_sb': '0'},
 'bongo': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bonhoeffer': {'n_is_sb': '0'},
 'boniface': {'n_is_sb': '0'},
 'bonito shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bonito': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bonnet macaque': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bonnet monkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bonnet shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bonnethead': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bonney': {'n_is_sb': '0'},
 'bonobo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bontemps': {'n_is_sb': '0'},
 'bonxie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bony fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'boocercus eurycerus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'booger': {'n_is_sb': '2', 'n_is_sth': '2'},
 'boogeyman': {'n_is_sb': '0'},
 'book agent': {'n_is_sb': '0'},
 'book louse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'book lover': {'n_is_sb': '0'},
 'book scorpion': {'n_is_sb': '3', 'n_is_sth': '3'},
 'book seller': {'n_is_sb': '0'},
 'bookbinder': {'n_is_sb': '0'},
 'bookdealer': {'n_is_sb': '0'},
 'booker t. washington': {'n_is_sb': '0'},
 'booker taliaferro washington': {'n_is_sb': '0'},
 'booker': {'n_is_sb': '0'},
 'bookie': {'n_is_sb': '0'},
 'booking agent': {'n_is_sb': '0'},
 'booking clerk': {'n_is_sb': '0'},
 'booklouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'booklover': {'n_is_sb': '0'},
 'bookmaker': {'n_is_sb': '0'},
 'boole': {'n_is_sb': '0'},
 'boone': {'n_is_sb': '0'},
 'boot maker': {'n_is_sb': '0'},
 'bootblack': {'n_is_sb': '0'},
 'bootlicker': {'n_is_sb': '0'},
 'bootmaker': {'n_is_sb': '0'},
 'boozer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'border collie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'border patrolman': {'n_is_sb': '0'},
 'border terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'borderer': {'n_is_sb': '0'},
 'boreas': {'n_is_sb': '2', 'n_is_sth': '2'},
 'borges': {'n_is_sb': '0'},
 'borgia': {'n_is_sb': '0'},
 'boris fyodorovich godunov': {'n_is_sb': '0'},
 'boris godunov': {'n_is_sb': '0'},
 'boris karloff': {'n_is_sb': '0'},
 'boris leonidovich pasternak': {'n_is_sb': '0'},
 'boris pasternak': {'n_is_sb': '0'},
 'boris spassky': {'n_is_sb': '0'},
 'boris vasilevich spassky': {'n_is_sb': '0'},
 'born-again christian': {'n_is_sb': '0'},
 'bornean': {'n_is_sb': '0'},
 'born': {'n_is_sb': '0', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_in': '', 'v_with': ''},
 'borodin': {'n_is_sb': '0'},
 'borrelia burgdorferi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'borrelia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'borrower': {'n_is_sb': '0'},
 'borzoi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bos banteng': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bos grunniens': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bos indicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bos primigenius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bos taurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 "bos'n": {'n_is_sb': '0'},
 'bosch': {'n_is_sb': '2', 'n_is_sth': '2'},
 'boselaphus tragocamelus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'boselaphus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bose': {'n_is_sb': '0'},
 'boskop man': {'n_is_sb': '0'},
 'boston bull': {'n_is_sb': '3', 'n_is_sth': '3'},
 'boston terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bostonian': {'n_is_sb': '0'},
 'bosun': {'n_is_sb': '0'},
 'boswell': {'n_is_sb': '0'},
 'bos': {'n_is_sb': '0'},
 'botanist': {'n_is_sb': '0'},
 'botaurus lentiginosus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'botaurus stellaris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'botaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'botcher': {'n_is_sb': '2', 'n_is_sth': '2'},
 'botfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bothrops atrops': {'n_is_sb': '3', 'n_is_sth': '3'},
 'botticelli': {'n_is_sb': '0'},
 'bottle-nosed dolphin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bottle-nosed whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bottlenose dolphin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bottlenose whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bottom dog': {'n_is_sb': '0'},
 'bottom feeder': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bottom fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'botulinum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'botulinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bougainville': {'n_is_sb': '2', 'n_is_sth': '2'},
 'boulez': {'n_is_sb': '0'},
 'bounder': {'n_is_sb': '0'},
 'bounty hunter': {'n_is_sb': '0'},
 'bourbon': {'n_is_sb': '0'},
 'bouvier des flandres': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bouviers des flandres': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bovidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bovid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bovine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bovini': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bow-wow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bowditch': {'n_is_sb': '0'},
 'bowdler': {'n_is_sb': '0'},
 'bowerbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bowfin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bowhead whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bowhead': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bowie': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bowman': {'n_is_sb': '0'},
 'box tortoise': {'n_is_sb': '3', 'n_is_sth': '3'},
 'box turtle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'boxfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'boy scout': {'n_is_sb': '0'},
 'boy wonder': {'n_is_sb': '0'},
 'boyle': {'n_is_sb': '0'},
 'brabancon griffon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bracero': {'n_is_sb': '2', 'n_is_sth': '2'},
 'brachinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brachiopod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brachyuran': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bracketed blenny': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bradbury': {'n_is_sb': '0'},
 'bradford': {'n_is_sb': '0'},
 'bradley': {'n_is_sb': '0'},
 'bradstreet': {'n_is_sb': '0'},
 'bradypus tridactylus': {'n_is_sb': '0'},
 'bradypus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brady': {'n_is_sb': '2', 'n_is_sth': '2'},
 'brage': {'n_is_sb': '0'},
 'braggart': {'n_is_sb': '0'},
 'bragger': {'n_is_sb': '0'},
 'bragi': {'n_is_sb': '0'},
 'brahman': {'n_is_sb': '2', 'n_is_sth': '2'},
 'brahma': {'n_is_sb': '0'},
 'brahms': {'n_is_sb': '0'},
 'brahui': {'n_is_sb': '2', 'n_is_sth': '2'},
 'brain coral': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brain doctor': {'n_is_sb': '0'},
 'brain surgeon': {'n_is_sb': '0'},
 'brain truster': {'n_is_sb': '0'},
 'brain-worker': {'n_is_sb': '0'},
 'brainworker': {'n_is_sb': '0'},
 'brakeman': {'n_is_sb': '0'},
 'bram stoker': {'n_is_sb': '0'},
 'brama raii': {'n_is_sb': '0'},
 'bramante': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brama': {'n_is_sb': '2', 'n_is_sth': '2'},
 'brambling': {'n_is_sb': '3', 'n_is_sth': '3'},
 'branchiobdellidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'branchiopod crustacean': {'n_is_sb': '3', 'n_is_sth': '3'},
 'branchiopodan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'branchiopod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'branchiura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brancusi': {'n_is_sb': '0'},
 'brandt': {'n_is_sb': '0'},
 'brant goose': {'n_is_sb': '3', 'n_is_sth': '3'},
 'branta bernicla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'branta canadensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'branta leucopsis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'branta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'braque': {'n_is_sb': '0'},
 'brass hat': {'n_is_sb': '0'},
 'braun': {'n_is_sb': '0'},
 'brawler': {'n_is_sb': '0'},
 'braxton bragg': {'n_is_sb': '0'},
 'brazilian trumpeter': {'n_is_sb': '0'},
 'bread maker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'breaststroker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'brecht': {'n_is_sb': '0'},
 'brent goose': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brent': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bret harte': {'n_is_sb': '0'},
 'breton': {'n_is_sb': '2', 'n_is_sth': '2'},
 'breuer': {'n_is_sb': '0'},
 'breughel the elder': {'n_is_sb': '0'},
 'breughel': {'n_is_sb': '0'},
 'brevicipitidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brevoortia tyrannis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brevoortia': {'n_is_sb': '3', 'n_is_sth': '3'},
 "brewer's mole": {'n_is_sb': '3', 'n_is_sth': '3'},
 'brezhnev': {'n_is_sb': '0'},
 'briard': {'n_is_sb': '2', 'n_is_sth': '2'},
 'briber': {'n_is_sb': '0'},
 'bride-to-be': {'n_is_sb': '0'},
 'bridge agent': {'n_is_sb': '0'},
 'bridge partner': {'n_is_sb': '0'},
 'bridge player': {'n_is_sb': '0'},
 'bridget': {'n_is_sb': '0'},
 'brigadier general': {'n_is_sb': '0'},
 'brigham young': {'n_is_sb': '0'},
 'brigid': {'n_is_sb': '0'},
 'brigit nilsson': {'n_is_sb': '0'},
 'brigit': {'n_is_sb': '0'},
 'brihaspati': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brill': {'n_is_sb': '2', 'n_is_sth': '2'},
 'brine shrimp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brinton': {'n_is_sb': '0'},
 'brisling': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bristletail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'british people': {'n_is_sb': '0'},
 'britisher': {'n_is_sb': '0'},
 'brits': {'n_is_sb': '0'},
 'brittany spaniel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'britten': {'n_is_sb': '0'},
 'brittle star': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brittle-star': {'n_is_sb': '3', 'n_is_sth': '3'},
 'britt': {'n_is_sb': '2', 'n_is_sth': '2'},
 'brit': {'n_is_sb': '2', 'n_is_sth': '2'},
 'broadbill': {'n_is_sb': '3', 'n_is_sth': '3'},
 'broadcast journalist': {'n_is_sb': '0'},
 'broadtail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'broca': {'n_is_sb': '0'},
 'brocket': {'n_is_sb': '2', 'n_is_sth': '2'},
 'broglie': {'n_is_sb': '0'},
 'broker-dealer': {'n_is_sb': '0'},
 'broncho': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bronco buster': {'n_is_sb': '0'},
 'broncobuster': {'n_is_sb': '0'},
 'bronc': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bronislaw kasper malinowski': {'n_is_sb': '0'},
 'bronislaw malinowski': {'n_is_sb': '0'},
 'bronte': {'n_is_sb': '0'},
 'brontosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brontosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brood bitch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brood hen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'broodmare': {'n_is_sb': '3', 'n_is_sth': '3'},
 'broody hen': {'n_is_sb': '0'},
 'broody': {'n_is_sb': '3', 'n_is_sth': '3', 'jj_to_jjr': 'broodier', 'jj_to_jjs': 'broodiest'},
 'brook trout': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brooke': {'n_is_sb': '0'},
 'brooks': {'n_is_sb': '0'},
 'brosme brosme': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brosmius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'broth of a boy': {'n_is_sb': '0'},
 'broth of a man': {'n_is_sb': '0'},
 'brothel keeper': {'n_is_sb': '0'},
 'brotula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brotulidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brown algae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brown bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brown bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brown bullhead': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brown creeper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brown hyena': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brown lacewing': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brown lemming': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brown rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brown snail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brown soft scale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brown swiss': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brown thrasher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brown thrush': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brown trout': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brown-tail moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'browne': {'n_is_sb': '0'},
 'brownshirt': {'n_is_sb': '0'},
 'browntail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'browser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bruce lee': {'n_is_sb': '0'},
 'brucella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bruce': {'n_is_sb': '0'},
 'bruchus pisorum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bruch': {'n_is_sb': '0'},
 'bruckner': {'n_is_sb': '0'},
 'bruegel': {'n_is_sb': '0'},
 'brueghel': {'n_is_sb': '0'},
 'bruin': {'n_is_sb': '2', 'n_is_sth': '2'},
 'brummell': {'n_is_sb': '0'},
 'brummie': {'n_is_sb': '0'},
 'brummy': {'n_is_sb': '0'},
 'bruneian': {'n_is_sb': '0'},
 'brunelleschi': {'n_is_sb': '0'},
 'brunette': {'n_is_sb': '0'},
 'brunet': {'n_is_sb': '0'},
 'brunhild': {'n_is_sb': '0'},
 'brunnhilde': {'n_is_sb': '0'},
 'bruno walter': {'n_is_sb': '0'},
 'bruno': {'n_is_sb': '0'},
 'brush kangaroo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brush turkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brush wolf': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brush-footed butterfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brush-tail porcupine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brush-tailed phalanger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brush-tailed porcupine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brussels griffon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'brutus': {'n_is_sb': '0'},
 'bryan donkin': {'n_is_sb': '0'},
 'bryan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'brynhild': {'n_is_sb': '0'},
 'bryozoan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bryozoa': {'n_is_sb': '0'},
 'bubalus bubalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bubalus mindorensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bubalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bubble shell': {'n_is_sb': '3', 'n_is_sth': '3'},
 'buber': {'n_is_sb': '0'},
 'bubo virginianus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bubulcus ibis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bubulcus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bucephala islandica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bucephala': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bucephela albeola': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bucephela clangula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'buceros': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bucerotidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'buchanan': {'n_is_sb': '0'},
 'buchner': {'n_is_sb': '0'},
 'buck private': {'n_is_sb': '0'},
 'buckeroo': {'n_is_sb': '0'},
 'bucking bronco': {'n_is_sb': '3', 'n_is_sth': '3'},
 'buckminster fuller': {'n_is_sb': '0'},
 'buddy holly': {'n_is_sb': '0'},
 'budgereegah': {'n_is_sb': '0'},
 'budgerigar': {'n_is_sb': '3', 'n_is_sth': '3'},
 'budgerygah': {'n_is_sb': '3', 'n_is_sth': '3'},
 'budge': {'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'budgie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'budorcas taxicolor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'buffalo bill cody': {'n_is_sb': '0'},
 'buffalo bill': {'n_is_sb': '0'},
 'buffalo carpet beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'buffalo fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'buffalo gnat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'buffalo indian': {'n_is_sb': '0'},
 'buffalofish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bufflehead': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bufo americanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bufo boreas': {'n_is_sb': '0'},
 'bufo bufo': {'n_is_sb': '0'},
 'bufo calamita': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bufo canorus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bufo debilis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bufo marinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bufo microscaphus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bufo speciosus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bufo viridis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bufonidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bufo': {'n_is_sb': '2', 'n_is_sth': '2'},
 'bug-hunter': {'n_is_sb': '0'},
 'bugologist': {'n_is_sb': '0'},
 'bukharin': {'n_is_sb': '0'},
 'bulbul': {'n_is_sb': '0'},
 'bulimic': {'n_is_sb': '0'},
 'bull mastiff': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bull shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bull snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bull terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bull-snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bullbat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bulldog ant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bullfighter': {'n_is_sb': '0'},
 'bullfinch': {'n_is_sb': '3', 'n_is_sth': '3'},
 "bullock's oriole": {'n_is_sb': '3', 'n_is_sth': '3'},
 'bullterrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bullyboy': {'n_is_sb': '0'},
 'bultmann': {'n_is_sb': '0'},
 'bulwer-lytton': {'n_is_sb': '0'},
 'bumbler': {'n_is_sb': '0'},
 'bunche': {'n_is_sb': '0'},
 'bungarus fasciatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bungarus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bungler': {'n_is_sb': '0'},
 'bunkmate': {'n_is_sb': '0'},
 'bunny girl': {'n_is_sb': '0'},
 'bunny rabbit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bunsen': {'n_is_sb': '0'},
 'bunter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bunuel': {'n_is_sb': '0'},
 'bunyan': {'n_is_sb': '0'},
 'bunyavirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'burbage': {'n_is_sb': '0'},
 'burbank': {'n_is_sb': '0'},
 'burbot': {'n_is_sb': '3', 'n_is_sth': '3'},
 "burchell's zebra": {'n_is_sb': '3', 'n_is_sth': '3'},
 'burgoyne': {'n_is_sb': '0'},
 'burgrave': {'n_is_sb': '0'},
 'burhinus oedicnemus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'burke': {'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'burk': {'n_is_sb': '0'},
 'burmeisteria retusa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'burmese cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'burnett': {'n_is_sb': '0'},
 'burnham': {'n_is_sb': '0'},
 'burnside': {'n_is_sb': '0'},
 'burrfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'burrhus frederic skinner': {'n_is_sb': '0'},
 'burrill bernard crohn': {'n_is_sb': '0'},
 'burro deer': {'n_is_sb': '0'},
 'burroughs': {'n_is_sb': '0'},
 'bursar': {'n_is_sb': '0'},
 'burton': {'n_is_sb': '2', 'n_is_sth': '2'},
 'burt': {'n_is_sb': '0'},
 'burundian': {'n_is_sb': '0'},
 'burunduki': {'n_is_sb': '0'},
 'bus driver': {'n_is_sb': '0'},
 'busboy': {'n_is_sb': '0'},
 'bush baby': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bush leaguer': {'n_is_sb': '0'},
 'bush shrike': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bush tit': {'n_is_sb': '0'},
 'bushbaby': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bushbuck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bushman': {'n_is_sb': '0'},
 'bushnell': {'n_is_sb': '0'},
 'bushtit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'bushwhacker': {'n_is_sb': '0'},
 'bushytail woodrat': {'n_is_sb': '0'},
 'business agent': {'n_is_sb': '0'},
 'business editor': {'n_is_sb': '0'},
 'business executive': {'n_is_sb': '0'},
 'business leader': {'n_is_sb': '0'},
 'business traveler': {'n_is_sb': '0'},
 'businessperson': {'n_is_sb': '0'},
 'businesswoman': {'n_is_sb': '0', 'nc_typical': ''},
 'busker': {'n_is_sb': '0'},
 'busman': {'n_is_sb': '0'},
 'bustard quail': {'n_is_sb': '0'},
 'buster keaton': {'n_is_sb': '0'},
 'busy bee': {'n_is_sb': '0'},
 'busybody': {'n_is_sb': '0'},
 'butcher cumberland': {'n_is_sb': '0'},
 'butcherbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'buteo buteo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'buteo jamaicensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'buteo lagopus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'buteo lineatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'buteonine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'buteo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'butterfield': {'n_is_sb': '0'},
 'butterfingers': {'n_is_sb': '0'},
 'butterfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'butterfly collector': {'n_is_sb': '0'},
 'butterfly fish': {'n_is_sb': '2', 'n_is_sth': '2'},
 'butterfly ray': {'n_is_sb': '3', 'n_is_sth': '3'},
 'butterflyfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'buttinsky': {'n_is_sb': '0'},
 'button quail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'button-quail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'by-blow': {'n_is_sb': '0'},
 'by-catch': {'n_is_sb': '0'},
 'bycatch': {'n_is_sb': '0'},
 'byelorussian': {'n_is_sb': '0'},
 'byron': {'n_is_sb': '0'},
 'byssus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'byzantine': {'n_is_sb': '0', 'cap_word': 'Byzantine'},
 'c. d. gibson': {'n_is_sb': '0'},
 'c. h. best': {'n_is_sb': '0'},
 'c. k. ogden': {'n_is_sb': '0'},
 'c. northcote parkinson': {'n_is_sb': '0'},
 'c. p. snow': {'n_is_sb': '0'},
 'c. psittaci': {'n_is_sb': '3', 'n_is_sth': '3'},
 'c. s. forester': {'n_is_sb': '0'},
 'c. s. lewis': {'n_is_sb': '0'},
 'c. trachomatis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'c. vann woodward': {'n_is_sb': '0'},
 'c. w. post': {'n_is_sb': '0'},
 'cabalist': {'n_is_sb': '0'},
 'cabassous unicinctus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cabassous': {'n_is_sb': '0'},
 'cabbage butterfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cabbageworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cabby': {'n_is_sb': '0'},
 'cabdriver': {'n_is_sb': '0'},
 'cabell': {'n_is_sb': '0'},
 'cabin boy': {'n_is_sb': '0'},
 'cabinet minister': {'n_is_sb': '0'},
 'cabinetmaker': {'n_is_sb': '0'},
 'cabman': {'n_is_sb': '0'},
 'cabot': {'n_is_sb': '0'},
 'cacajao': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cacao moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cacatua galerita': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cachalot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cackler': {'n_is_sb': '0'},
 'cacodaemon': {'n_is_sb': '0'},
 'cacodemon': {'n_is_sb': '0'},
 'cacomistle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cacomixle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cactus mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cactus wren': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caddice fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caddice-fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caddie': {'n_is_sb': '0'},
 'caddis fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caddis-fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caddisworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caddo': {'n_is_sb': '0'},
 'cadger': {'n_is_sb': '0'},
 'cadra cautella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cadra figulilella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cadra': {'n_is_sb': '0'},
 'cad': {'n_is_sb': '0'},
 'caeciliadae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caecilian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caeciliidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caenolestes': {'n_is_sb': '0'},
 'caffein addict': {'n_is_sb': '0'},
 'caffeine addict': {'n_is_sb': '0'},
 'caffer cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caffer': {'n_is_sb': '0'},
 'caffre': {'n_is_sb': '0'},
 'cager': {'n_is_sb': '0'},
 'cagliostro': {'n_is_sb': '0'},
 'cagney': {'n_is_sb': '0'},
 'cahita': {'n_is_sb': '0'},
 'caiman lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caiman sclerops': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caiman': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cain': {'n_is_sb': '0'},
 'cairene': {'n_is_sb': '0'},
 'cairina moschata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cairn terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cairn': {'n_is_sb': '2', 'n_is_sth': '2'},
 'caitiff': {'n_is_sb': '0'},
 'cajun': {'n_is_sb': '0', 'cap_word': 'Cajun'},
 'cakchiquel': {'n_is_sb': '0'},
 'calamity jane': {'n_is_sb': '0'},
 'calamus penna': {'n_is_sb': '3', 'n_is_sth': '3'},
 'calamus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'calapooya': {'n_is_sb': '0'},
 'calapuya': {'n_is_sb': '0'},
 'calderon de la barca': {'n_is_sb': '0'},
 'calderon': {'n_is_sb': '0'},
 'calder': {'n_is_sb': '0'},
 'caldwell': {'n_is_sb': '0'},
 'calico cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'calico crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'calidris canutus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'calidris ferruginea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'calidris melanotos': {'n_is_sb': '3', 'n_is_sth': '3'},
 'california condor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'california newt': {'n_is_sb': '2', 'n_is_sth': '2'},
 'california pompano': {'n_is_sb': '3', 'n_is_sth': '3'},
 'california quail': {'n_is_sb': '2', 'n_is_sth': '2'},
 'california sea lion': {'n_is_sb': '3', 'n_is_sth': '3'},
 'california whipsnake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'californian': {'n_is_sb': '0', 'cap_word': 'Californian'},
 'calif': {'n_is_sb': '0'},
 'caligula': {'n_is_sb': '0'},
 'calixtus iii': {'n_is_sb': '0'},
 'call girl': {'n_is_sb': '0'},
 'callas': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caller-out': {'n_is_sb': '0'},
 'caller-up': {'n_is_sb': '0'},
 'calligraphist': {'n_is_sb': '0'},
 'callimorpha jacobeae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'callimorpha': {'n_is_sb': '3', 'n_is_sth': '3'},
 'callinectes sapidus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'callinectes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'callionymidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'calliope': {'n_is_sb': '2', 'n_is_sth': '2'},
 'calliphora vicina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'callisaurus draconoides': {'n_is_sb': '3', 'n_is_sth': '3'},
 'callophis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'callorhinus ursinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'calosoma scrutator': {'n_is_sb': '0'},
 'calosoma': {'n_is_sb': '3', 'n_is_sth': '3'},
 'calvert vaux': {'n_is_sb': '0'},
 'calvin coolidge': {'n_is_sb': '0'},
 'calvin klein': {'n_is_sb': '0'},
 'calvin richard klein': {'n_is_sb': '0'},
 'calvinist': {'n_is_sb': '0'},
 'calvino': {'n_is_sb': '0'},
 'calvin': {'n_is_sb': '0'},
 'calycle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'calyculus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'calymmatobacterium granulomatis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'calymmatobacterium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'calypso': {'n_is_sb': '0'},
 'camberwell beauty': {'n_is_sb': '0'},
 'cambodian': {'n_is_sb': '0'},
 'camelidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'camelopard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'camelus bactrianus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'camelus dromedarius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'camera operator': {'n_is_sb': '0'},
 'cameroonian': {'n_is_sb': '0'},
 'camillo golgi': {'n_is_sb': '0'},
 'camp follower': {'n_is_sb': '0'},
 'camp robber': {'n_is_sb': '0'},
 'campbell': {'n_is_sb': '0'},
 'campephilus principalis': {'n_is_sb': '0'},
 'campephilus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'camper': {'n_is_sb': '0'},
 'campfire girl': {'n_is_sb': '0'},
 'campmate': {'n_is_sb': '0'},
 'camponotus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'camus': {'n_is_sb': '0'},
 'canaanite': {'n_is_sb': '0'},
 'canachites canadensis': {'n_is_sb': '0'},
 'canachites': {'n_is_sb': '3', 'n_is_sth': '3'},
 'canada goose': {'n_is_sb': '3', 'n_is_sth': '3'},
 'canada jay': {'n_is_sb': '3', 'n_is_sth': '3'},
 'canada lynx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'canada porcupine': {'n_is_sb': '2', 'n_is_sth': '2'},
 'canadian goose': {'n_is_sb': '3', 'n_is_sth': '3'},
 'canarese': {'n_is_sb': '0'},
 'canary bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cancer borealis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cancer irroratus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cancer magister': {'n_is_sb': '0'},
 'candlemaker': {'n_is_sb': '0'},
 'candy striper': {'n_is_sb': '0'},
 'candymaker': {'n_is_sb': '0'},
 'canebrake rattler': {'n_is_sb': '0'},
 'canebrake rattlesnake': {'n_is_sb': '0'},
 'canetti': {'n_is_sb': '0'},
 'canidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'canid': {'n_is_sb': '0'},
 'canis aureus': {'n_is_sb': '0'},
 'canis dingo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'canis familiaris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'canis latrans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'canis lupus tundrarum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'canis lupus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'canis niger': {'n_is_sb': '0'},
 'canis rufus': {'n_is_sb': '0'},
 'cankerworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cannibal': {'n_is_sb': '0'},
 'cannon fodder': {'n_is_sb': '0'},
 'cannoneer': {'n_is_sb': '0'},
 'canoeist': {'n_is_sb': '0'},
 'canonist': {'n_is_sb': '0'},
 'cantabrigian': {'n_is_sb': '0'},
 'cantor': {'n_is_sb': '0'},
 'canuck': {'n_is_sb': '0'},
 'canute the great': {'n_is_sb': '0'},
 'canute': {'n_is_sb': '0'},
 'canvasback duck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'canvasback': {'n_is_sb': '3', 'n_is_sth': '3'},
 'canyon treefrog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cape buffalo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cape hunting dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cape lobster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cape may warbler': {'n_is_sb': '3', 'n_is_sth': '3'},
 'capek': {'n_is_sb': '0'},
 'capelan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'capelin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'capercaillie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'capercailzie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'capetian': {'n_is_sb': '0'},
 'capet': {'n_is_sb': '0'},
 'capibara': {'n_is_sb': '3', 'n_is_sth': '3'},
 'capiz': {'n_is_sb': '0'},
 'caplin': {'n_is_sb': '2', 'n_is_sth': '2'},
 'capone': {'n_is_sb': '0'},
 'capped macaque': {'n_is_sb': '3', 'n_is_sth': '3'},
 'capra aegagrus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'capra falconeri': {'n_is_sb': '3', 'n_is_sth': '3'},
 'capra hircus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'capra ibex': {'n_is_sb': '3', 'n_is_sth': '3'},
 'capra': {'n_is_sb': '2', 'n_is_sth': '2'},
 'capreolus capreolus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'capreolus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'capricornis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caprimulgid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caprimulgiform bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caprimulgus carolinensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caprimulgus europaeus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caprimulgus vociferus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caprine animal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'capros aper': {'n_is_sb': '0'},
 'capsid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'captain bligh': {'n_is_sb': '0'},
 'captain bob': {'n_is_sb': '0'},
 'captain cook': {'n_is_sb': '0'},
 'captain horatio hornblower': {'n_is_sb': '0'},
 'captain james cook': {'n_is_sb': '0'},
 'captain john smith': {'n_is_sb': '0'},
 'captain kidd': {'n_is_sb': '0'},
 'captor': {'n_is_sb': '0'},
 'capturer': {'n_is_sb': '0'},
 'capybara': {'n_is_sb': '3', 'n_is_sth': '3'},
 'car-mechanic': {'n_is_sb': '0'},
 'carabao': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carabid beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carabineer': {'n_is_sb': '0'},
 'carabinier': {'n_is_sb': '0'},
 'caracal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caracara': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caracul': {'n_is_sb': '2', 'n_is_sth': '2'},
 'carageen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carancha': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carangid fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carangid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caranx bartholomaei': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caranx crysos': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caranx hippos': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carassius auratus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carassius carassius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carassius vulgaris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carassius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caravaggio': {'n_is_sb': '0'},
 'carcajou': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carcharhinus leucas': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carcharhinus limbatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carcharhinus obscurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carcharhinus plumbeus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carcharhinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carcharias taurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carcharias': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carcharinus longimanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carcharodon carcharias': {'n_is_sb': '3', 'n_is_sth': '3'},
 'card player': {'n_is_sb': '0'},
 'card shark': {'n_is_sb': '0'},
 'card sharper': {'n_is_sb': '0'},
 'card sharp': {'n_is_sb': '0'},
 'cardigan welsh corgi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cardiidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cardinal bellarmine': {'n_is_sb': '0'},
 'cardinal grosbeak': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cardinal newman': {'n_is_sb': '0'},
 'cardinal richelieu': {'n_is_sb': '0'},
 'cardinal tetra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cardinalfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cardinalis cardinalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cardiologist': {'n_is_sb': '0'},
 'cardium edule': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cardsharper': {'n_is_sb': '0'},
 'cardsharp': {'n_is_sb': '0'},
 'carducci': {'n_is_sb': '0'},
 'carduelis cannabina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carduelis carduelis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carduelis cucullata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carduelis flammea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carduelis hornemanni': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carduelis spinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'career girl': {'n_is_sb': '0'},
 'career man': {'n_is_sb': '0'},
 'caregiver': {'n_is_sb': '0'},
 'carelian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'caretta caretta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caretta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carew': {'n_is_sb': '0'},
 'carhop': {'n_is_sb': '0'},
 'cariama cristata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cariama': {'n_is_sb': '2', 'n_is_sth': '2'},
 'carib indian': {'n_is_sb': '0'},
 'caribe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carib': {'n_is_sb': '0'},
 'carillonneur': {'n_is_sb': '0'},
 'carinate bird': {'n_is_sb': '0'},
 'carinate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carioca': {'n_is_sb': '2', 'n_is_sth': '2'},
 'carl anderson': {'n_is_sb': '0'},
 'carl august nielson': {'n_is_sb': '0'},
 'carl clinton van doren': {'n_is_sb': '0'},
 'carl david anderson': {'n_is_sb': '0'},
 'carl gustaf mossander': {'n_is_sb': '0'},
 'carl gustav jung': {'n_is_sb': '0'},
 'carl jung': {'n_is_sb': '0'},
 'carl lewis': {'n_is_sb': '0'},
 'carl maria von weber': {'n_is_sb': '0'},
 'carl nielson': {'n_is_sb': '0'},
 'carl orff': {'n_is_sb': '0'},
 'carl rogers': {'n_is_sb': '0'},
 'carl sandburg': {'n_is_sb': '0'},
 'carl van doren': {'n_is_sb': '0'},
 'carl von linne': {'n_is_sb': '0'},
 'carl xvi gustaf': {'n_is_sb': '0'},
 'carl xvi gustav': {'n_is_sb': '0'},
 'carl yastrzemski': {'n_is_sb': '0'},
 'carlo goldoni': {'n_is_sb': '0'},
 'carlos chavez': {'n_is_sb': '0'},
 'carlos fuentes': {'n_is_sb': '0'},
 'carlos the jackal': {'n_is_sb': '0'},
 'carlos': {'n_is_sb': '0'},
 'carlovingian': {'n_is_sb': '0'},
 'carlyle': {'n_is_sb': '0'},
 'carmelite': {'n_is_sb': '0'},
 'carmichael': {'n_is_sb': '0'},
 'carnegie': {'n_is_sb': '0'},
 'carniolan bee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carnivore': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carnivorous bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carnosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carnot': {'n_is_sb': '0'},
 'caroler': {'n_is_sb': '0'},
 'carolina chickadee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carolina parakeet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carolina wren': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carolingian': {'n_is_sb': '0'},
 'carolinian': {'n_is_sb': '0'},
 'caroller': {'n_is_sb': '0'},
 'carolus linnaeus': {'n_is_sb': '0'},
 'carothers': {'n_is_sb': '0'},
 'carouser': {'n_is_sb': '0'},
 'carpenter ant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carpenter bee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carper': {'n_is_sb': '0'},
 'carpet beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carpet bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carpet knight': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carpet moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carpet shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carpet snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carpetbagger': {'n_is_sb': '0'},
 'carphophis amoenus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carpocapsa pomonella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carpocapsa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carpodacus mexicanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carpodacus purpureus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carrageen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carragheen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carrel': {'n_is_sb': '2', 'n_is_sth': '2'},
 'carrere': {'n_is_sb': '0'},
 'carriage dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carrier pigeon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carrion crow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carroll': {'n_is_sb': '0'},
 'carrottop': {'n_is_sb': '0'},
 'carry amelia moore nation': {'n_is_sb': '0'},
 'carry nation': {'n_is_sb': '0'},
 'carson mccullers': {'n_is_sb': '0'},
 'carson smith mccullers': {'n_is_sb': '0'},
 'carson': {'n_is_sb': '0'},
 'cart horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carthaginian': {'n_is_sb': '0'},
 'carthorse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'carthusian': {'n_is_sb': '0'},
 'cartier': {'n_is_sb': '0'},
 'cartilaginous fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cartwright': {'n_is_sb': '0'},
 'caruso': {'n_is_sb': '0'},
 'cary grant': {'n_is_sb': '0'},
 'casals': {'n_is_sb': '0'},
 'casanova de seingalt': {'n_is_sb': '0'},
 'casanova': {'n_is_sb': '0'},
 'cascades frog': {'n_is_sb': '0'},
 'case officer': {'n_is_sb': '0'},
 'casemaking clothes moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caseworker': {'n_is_sb': '0'},
 'caseworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'casey jones': {'n_is_sb': '0'},
 'casey stengel': {'n_is_sb': '0'},
 'cashmere goat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'casimir funk': {'n_is_sb': '0'},
 'casmerodius albus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caspar bartholin': {'n_is_sb': '0'},
 'caspar': {'n_is_sb': '0'},
 'cass gilbert': {'n_is_sb': '0'},
 'cassandra': {'n_is_sb': '0'},
 "cassin's kingbird": {'n_is_sb': '3', 'n_is_sth': '3'},
 'cassirer': {'n_is_sb': '0'},
 'cassite': {'n_is_sb': '0'},
 'cassius clay': {'n_is_sb': '0'},
 'cassius longinus': {'n_is_sb': '0'},
 'cassius marcellus clay': {'n_is_sb': '0'},
 'cassius': {'n_is_sb': '0'},
 'castor canadensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'castor fiber': {'n_is_sb': '3', 'n_is_sth': '3'},
 'castoroides': {'n_is_sb': '2', 'n_is_sth': '2'},
 'castrate': {'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'n_is_sth': '2'},
 'castrato': {'n_is_sb': '0'},
 'castro': {'n_is_sb': '0'},
 'casuist': {'n_is_sb': '0'},
 'cat bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cat burglar': {'n_is_sb': '0'},
 'cat fancier': {'n_is_sb': '0'},
 'cat flea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cat shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cat squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 "cat's-paw": {'n_is_sb': '0'},
 'catacala': {'n_is_sb': '2', 'n_is_sth': '2'},
 'catalan': {'n_is_sb': '0', 'cap_word': 'Catalan'},
 'cataleptic': {'n_is_sb': '0'},
 'cataloger': {'n_is_sb': '0'},
 'cataloguer': {'n_is_sb': '0'},
 'catalufa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'catamountain': {'n_is_sb': '2', 'n_is_sth': '2'},
 'catarrhine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'catawba': {'n_is_sb': '0'},
 'catbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'catechist': {'n_is_sb': '0'},
 'catechumen': {'n_is_sb': '0'},
 'caterer': {'n_is_sb': '0'},
 'catharacta skua': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cathartes aura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cathartes': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cathartid': {'n_is_sb': '0'},
 'catherine de medicis': {'n_is_sb': '0'},
 'catherine howard': {'n_is_sb': '0'},
 'catherine ii': {'n_is_sb': '0'},
 'catherine i': {'n_is_sb': '0'},
 'catherine of aragon': {'n_is_sb': '0'},
 'catherine parr': {'n_is_sb': '0'},
 'catherine the great': {'n_is_sb': '0'},
 'catherine': {'n_is_sb': '0'},
 'cather': {'n_is_sb': '0'},
 'catholic pope': {'n_is_sb': '0'},
 'catholicos': {'n_is_sb': '0'},
 'catocala nupta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'catoptrophorus semipalmatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'catoptrophorus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'catostomid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cattalo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cattle egret': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cattle thief': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cattleman': {'n_is_sb': '0'},
 'catullus': {'n_is_sb': '0'},
 'caucasian race': {'n_is_sb': '0'},
 'caucasoid race': {'n_is_sb': '0'},
 'caudate': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cavalla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cavalry horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cave bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cave dweller': {'n_is_sb': '0'},
 'cave man': {'n_is_sb': '0'},
 'cave myotis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cavell': {'n_is_sb': '0'},
 'caveman': {'n_is_sb': '0'},
 'cavendish': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cavia cobaya': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cavia porcellus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cavia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caviler': {'n_is_sb': '0'},
 'caviller': {'n_is_sb': '0'},
 'cavy': {'n_is_sb': '3', 'n_is_sth': '3'},
 'caxton': {'n_is_sb': '0'},
 'cayman': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cayuga': {'n_is_sb': '0'},
 'cayuse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cazique': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cebuan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cebuella pygmaea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cebus capucinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cecil b. demille': {'n_is_sb': '0'},
 'cecil blount demille': {'n_is_sb': '0'},
 'cecil frank powell': {'n_is_sb': '0'},
 'cecil j. rhodes': {'n_is_sb': '0'},
 'cecil john rhodes': {'n_is_sb': '0'},
 'cecil rhodes': {'n_is_sb': '0'},
 'cecil scott forester': {'n_is_sb': '0'},
 'cecropia moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cecropia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cedar waxwing': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cedarbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'celebrant': {'n_is_sb': '0'},
 'celebrater': {'n_is_sb': '0'},
 'celebrator': {'n_is_sb': '0'},
 'celibate': {'n_is_sb': '0'},
 'cellini': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cellist': {'n_is_sb': '0'},
 'celsius': {'n_is_sb': '0'},
 'celtic deity': {'n_is_sb': '0'},
 'celt': {'n_is_sb': '0'},
 'cenobite': {'n_is_sb': '0'},
 'census taker': {'n_is_sb': '0'},
 'centaur': {'n_is_sb': '2', 'n_is_sth': '2'},
 'centenarian': {'n_is_sb': '0'},
 'center fielder': {'n_is_sb': '0'},
 'centerfielder': {'n_is_sb': '0'},
 'central american': {'n_is_sb': '0'},
 'central chimpanzee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'centrarchid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'centrocercus urophasianus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'centropistes striata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'centropristis philadelphica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'centropus phasianinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'centropus sinensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'centurion': {'n_is_sb': '0'},
 'ceo': {'n_is_sb': '0'},
 'cephalochordate': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cephalopod mollusk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cephalopoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cephalopod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cephalopterus ornatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cephalopterus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cepphus columba': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cepphus grylle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cerambycidae': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ceramicist': {'n_is_sb': '0'},
 'ceramist': {'n_is_sb': '0'},
 'cerapteryx graminis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cerapteryx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cerastes cornutus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cerastes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ceras': {'n_is_sb': '0'},
 'ceratitis capitata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ceratitis': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ceratodus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ceratopsian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ceratosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ceratosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ceratotherium simum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ceratotherium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cerberus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cercaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cercocebus': {'n_is_sb': ''},
 'cercopithecus aethiops pygerythrus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cercopithecus aethiops sabaeus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cercopithecus aethiops': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cercopithecus talapoin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ceres': {'n_is_sb': '0'},
 'cerripede': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cerriped': {'n_is_sb': '3', 'n_is_sth': '3'},
 'certhia americana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'certhia familiaris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'certified public accountant': {'n_is_sb': '0'},
 'cervantes saavedra': {'n_is_sb': '0'},
 'cervantes': {'n_is_sb': '0'},
 'cervid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cervus canadensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cervus elaphus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cervus nipon': {'n_is_sb': '0'},
 'cervus sika': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cervus unicolor': {'n_is_sb': '0'},
 'ceryle alcyon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cesar chavez': {'n_is_sb': '0'},
 'cesar estrada chavez': {'n_is_sb': '0'},
 'cesar franck': {'n_is_sb': '0'},
 'cesar ritz': {'n_is_sb': '0'},
 'cesare borgia': {'n_is_sb': '0'},
 'cestida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cestode': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cestum veneris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cestum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cetacean mammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cetonia aurata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cetorhinus maximus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cezanne': {'n_is_sb': '0'},
 'cfo': {'n_is_sb': '0'},
 'chachalaca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chachka': {'n_is_sb': '0'},
 'chacma baboon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chacma': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chadian': {'n_is_sb': '0'},
 'chaenopsis ocellata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chaeta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chaetodipterus faber': {'n_is_sb': '0'},
 'chaetodontidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chaetognath': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chaffinch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chagall': {'n_is_sb': '0'},
 'chaim azriel weizmann': {'n_is_sb': '0'},
 'chaim soutine': {'n_is_sb': '0'},
 'chaim weizmann': {'n_is_sb': '0'},
 'chain pickerel': {'n_is_sb': '0'},
 'chain pike': {'n_is_sb': '0'},
 'chain-smoker': {'n_is_sb': '0'},
 'chairman of the board': {'n_is_sb': '0'},
 'chairwoman': {'n_is_sb': '0', 'nc_typical': ''},
 'chaja': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chalaza': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chalcid fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chalcid wasp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chalcidfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chalcid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chalcis fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chaldaean': {'n_is_sb': '2', 'n_is_sth': '2'},
 'chaldean': {'n_is_sb': '0'},
 'chaldee': {'n_is_sb': '0'},
 'challenger': {'n_is_sb': '0'},
 'chamaea fasciata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chamaea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chamaeleo chamaeleon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chamaeleo oweni': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chamaeleon': {'n_is_sb': '2', 'n_is_sth': '2'},
 'chambered nautilus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chameleon tree frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'champlain': {'n_is_sb': '0'},
 'champollion': {'n_is_sb': '0'},
 'chancellor of the exchequer': {'n_is_sb': '0'},
 'chandi': {'n_is_sb': '0'},
 'chang kuo-lao': {'n_is_sb': '0'},
 'chang kuo': {'n_is_sb': '0'},
 'changer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'channel bass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'channel catfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'channel cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chaparral cock': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chapelgoer': {'n_is_sb': '0'},
 'chaperon': {'n_is_sb': '0', 'vbd_eq_vbn': ''},
 'chaplin': {'n_is_sb': '0'},
 'chapman': {'n_is_sb': '0'},
 'characin fish': {'n_is_sb': '2', 'n_is_sth': '2'},
 'characin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'character actor': {'n_is_sb': '0'},
 'character witness': {'n_is_sb': '0'},
 'charadrius melodus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'charadrius morinellus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'charadrius vociferus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chara': {'n_is_sb': '2', 'n_is_sth': '2'},
 'charcoal burner': {'n_is_sb': '2', 'n_is_sth': '2'},
 'charcot': {'n_is_sb': '2', 'n_is_sth': '2'},
 "charge d'affaires": {'n_is_sb': '2', 'n_is_sth': '2'},
 'charge of quarters': {'n_is_sb': '2', 'n_is_sth': '2'},
 'chargeman': {'n_is_sb': '0'},
 'charina bottae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'charioteer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'charity case': {'n_is_sb': '0'},
 'charlemagne': {'n_is_sb': '0'},
 'charles a. lindbergh': {'n_is_sb': '0'},
 'charles andre joseph marie de gaulle': {'n_is_sb': '0'},
 'charles augustin de coulomb': {'n_is_sb': '0'},
 'charles augustus lindbergh': {'n_is_sb': '0'},
 'charles baudelaire': {'n_is_sb': '0'},
 'charles bullfinch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'charles camille saint-saens': {'n_is_sb': '0'},
 'charles christopher parker': {'n_is_sb': '0'},
 'charles cornwallis': {'n_is_sb': '0'},
 'charles dana gibson': {'n_is_sb': '0'},
 'charles darwin': {'n_is_sb': '0'},
 'charles de gaulle': {'n_is_sb': '0'},
 'charles dickens': {'n_is_sb': '0'},
 'charles digby harrod': {'n_is_sb': '0'},
 'charles dillon stengel': {'n_is_sb': '0'},
 'charles dodgson': {'n_is_sb': '0'},
 'charles dudley warner': {'n_is_sb': '0'},
 'charles eames': {'n_is_sb': '0'},
 'charles edouard jeanneret': {'n_is_sb': '0'},
 'charles edward berry': {'n_is_sb': '0'},
 'charles edward ives': {'n_is_sb': '0'},
 'charles evans hughes': {'n_is_sb': '0'},
 'charles farrar browne': {'n_is_sb': '0'},
 'charles follen mckim': {'n_is_sb': '0'},
 'charles fourier': {'n_is_sb': '0'},
 'charles francis hall': {'n_is_sb': '0'},
 'charles francois gounod': {'n_is_sb': '0'},
 'charles franklin kettering': {'n_is_sb': '0'},
 'charles franklin peirce': {'n_is_sb': '0'},
 'charles frederick menninger': {'n_is_sb': '0'},
 'charles frederick worth': {'n_is_sb': '0'},
 'charles goodyear': {'n_is_sb': '0'},
 'charles grey': {'n_is_sb': '0'},
 'charles hardin holley': {'n_is_sb': '0'},
 'charles henry harrod': {'n_is_sb': '0'},
 'charles herbert best': {'n_is_sb': '0'},
 'charles ii': {'n_is_sb': '0'},
 'charles ix': {'n_is_sb': '0'},
 'charles i': {'n_is_sb': '0'},
 'charles james fox': {'n_is_sb': '0'},
 'charles john huffam dickens': {'n_is_sb': '0'},
 'charles joseph clark': {'n_is_sb': '0'},
 'charles kay ogden': {'n_is_sb': '0'},
 'charles kettering': {'n_is_sb': '0'},
 "charles l'enfant": {'n_is_sb': '0'},
 'charles lamb': {'n_is_sb': '0'},
 'charles laughton': {'n_is_sb': '0'},
 'charles lindbergh': {'n_is_sb': '0'},
 'charles liston': {'n_is_sb': '0'},
 'charles louis de secondat': {'n_is_sb': '0'},
 'charles louis napoleon bonaparte': {'n_is_sb': '0'},
 'charles lutwidge dodgson': {'n_is_sb': '0'},
 'charles m. schulz': {'n_is_sb': '0'},
 'charles martin hall': {'n_is_sb': '0'},
 'charles maurice de talleyrand': {'n_is_sb': '0'},
 'charles menninger': {'n_is_sb': '0'},
 'charles munroe schulz': {'n_is_sb': '0'},
 'charles peirce': {'n_is_sb': '0'},
 'charles percy snow': {'n_is_sb': '0'},
 'charles pierre baudelaire': {'n_is_sb': '0'},
 'charles proteus steinmetz': {'n_is_sb': '0'},
 'charles ringling': {'n_is_sb': '0'},
 'charles robert darwin': {'n_is_sb': '0'},
 'charles robert redford': {'n_is_sb': '0'},
 'charles schulz': {'n_is_sb': '0'},
 'charles stewart parnell': {'n_is_sb': '0'},
 'charles stuart': {'n_is_sb': '0'},
 'charles taze russell': {'n_is_sb': '0'},
 'charles the bald': {'n_is_sb': '0'},
 'charles the great': {'n_is_sb': '0'},
 'charles thomson rees wilson': {'n_is_sb': '0'},
 'charles vii': {'n_is_sb': '0'},
 'charles watson-wentworth': {'n_is_sb': '0'},
 'charles wesley': {'n_is_sb': '0'},
 'charles wilkes': {'n_is_sb': '0'},
 'charles william post': {'n_is_sb': '0'},
 'charles': {'n_is_sb': '0'},
 'charlie chaplin': {'n_is_sb': '0'},
 'charlie parker': {'n_is_sb': '0'},
 'charlotte anna perkins gilman': {'n_is_sb': '0'},
 'charlotte bronte': {'n_is_sb': '0'},
 'charlotte corday': {'n_is_sb': '0'},
 'charolais': {'n_is_sb': '0'},
 'charon': {'n_is_sb': '0'},
 'charronia flavigula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'charronia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'charter member': {'n_is_sb': '0'},
 'chartered accountant': {'n_is_sb': '0'},
 'chartist': {'n_is_sb': '0'},
 'charwoman': {'n_is_sb': '0'},
 'chasid': {'n_is_sb': '0'},
 'chassid': {'n_is_sb': '0'},
 'chateaubriand': {'n_is_sb': '2', 'n_is_sth': '2'},
 'chatelaine': {'n_is_sb': '0'},
 'chateura pelagica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chateura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chatterer': {'n_is_sb': '0'},
 'chaucer': {'n_is_sb': '0'},
 'chauffeuse': {'n_is_sb': '0'},
 'chauna torquata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chauna': {'n_is_sb': '0'},
 'chauvinist': {'n_is_sb': '0'},
 'chavez': {'n_is_sb': '0'},
 'chawbacon': {'n_is_sb': '0'},
 'che guevara': {'n_is_sb': '0'},
 'cheap-jack': {'n_is_sb': '0'},
 'chebab': {'n_is_sb': '0'},
 'chechen': {'n_is_sb': '2', 'n_is_sth': '2'},
 'check girl': {'n_is_sb': '0'},
 'checkered adder': {'n_is_sb': '3', 'n_is_sth': '3'},
 'checkered whiptail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'checker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cheerer': {'n_is_sb': '0'},
 'cheerleader': {'n_is_sb': '0'},
 'cheesemonger': {'n_is_sb': '0'},
 'cheever': {'n_is_sb': '0'},
 'cheewink': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chekhov': {'n_is_sb': '0'},
 'chekov': {'n_is_sb': '0'},
 'chelicerata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chelicera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chelifer cancroides': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chelifer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chelonia mydas': {'n_is_sb': '0'},
 'chelonian reptile': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chelonian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chelydra serpentina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chen caerulescens': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chen n. yang': {'n_is_sb': '0'},
 'chenfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chen': {'n_is_sb': '0'},
 'cheremiss': {'n_is_sb': '0'},
 'cheremis': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cherokee': {'n_is_sb': '0'},
 'cherrystone clam': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cherrystone': {'n_is_sb': '0'},
 'cherubini': {'n_is_sb': '0'},
 'chesapeake bay retriever': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cheshire cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chess master': {'n_is_sb': '0'},
 'chess player': {'n_is_sb': '0'},
 'chester a. arthur': {'n_is_sb': '0'},
 'chester alan arthur': {'n_is_sb': '0'},
 'chester nimitz': {'n_is_sb': '0'},
 'chester william nimitz': {'n_is_sb': '0'},
 'chesterton': {'n_is_sb': '0'},
 'chetah': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chevalier de bayard': {'n_is_sb': '0'},
 'chevalier de lamarck': {'n_is_sb': '0'},
 'cheviot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chevrotain': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chewa': {'n_is_sb': '2', 'n_is_sth': '2'},
 'chewer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'chewink': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chiacoan peccary': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chiang chung-cheng': {'n_is_sb': '0'},
 'chiang kai-shek': {'n_is_sb': '0'},
 'chickasaw': {'n_is_sb': '0'},
 'chicken hawk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chicken little': {'n_is_sb': '2', 'n_is_sth': '2'},
 'chicken louse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chicken roundworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chicken snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chickeree': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chico': {'n_is_sb': '2', 'n_is_sth': '2'},
 'chief assistant': {'n_is_sb': '0'},
 'chief constable': {'n_is_sb': '0'},
 'chief executive officer': {'n_is_sb': '0'},
 'chief executive': {'n_is_sb': '0'},
 'chief financial officer': {'n_is_sb': '0'},
 'chief joseph': {'n_is_sb': '0'},
 'chief justice': {'n_is_sb': '0'},
 'chief of staff': {'n_is_sb': '0'},
 'chief of state': {'n_is_sb': '0'},
 'chief operating officer': {'n_is_sb': '0'},
 'chief petty officer': {'n_is_sb': '0'},
 'chief secretary': {'n_is_sb': '0'},
 'chigetai': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chigoe flea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chigoe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chihuahuan spotted whiptail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chihuahua': {'n_is_sb': '3', 'n_is_sth': '3'},
 'child molester': {'n_is_sb': '0'},
 'child prodigy': {'n_is_sb': '0'},
 'childe hassam': {'n_is_sb': '0'},
 'chile bonito': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chilean bonito': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chilean': {'n_is_sb': '2', 'n_is_sth': '2'},
 'chiliast': {'n_is_sb': '0'},
 'chilomeniscus cinctus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chimaera monstrosa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chimaera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chimakum': {'n_is_sb': '0'},
 'chimariko': {'n_is_sb': '2', 'n_is_sth': '2'},
 'chimney swallow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chimney swift': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chimneysweeper': {'n_is_sb': '0'},
 'chimneysweep': {'n_is_sb': '2', 'n_is_sth': '2'},
 'chinaman': {'n_is_sb': '0'},
 'chinch bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chinchilla laniger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chinchilla rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chinchillidae': {'n_is_sb': '2', 'n_is_sth': '2'},
 'chinchillon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chinch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chinese alligator': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chinese deity': {'n_is_sb': '0'},
 'chinese goose': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chinese paddlefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chinook salmon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chinook': {'n_is_sb': '2', 'n_is_sth': '2'},
 'chipewyan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'chipmunk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chippendale': {'n_is_sb': '2', 'n_is_sth': '2'},
 'chippewa': {'n_is_sb': '0'},
 'chipping sparrow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chirico': {'n_is_sb': '0'},
 'chirocephalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chiromancer': {'n_is_sb': '0'},
 'chironomidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chironomus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chiropodist': {'n_is_sb': '0'},
 'chiropractor': {'n_is_sb': '0'},
 'chiropteran': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chiseler': {'n_is_sb': '0'},
 'chiseller': {'n_is_sb': '0'},
 'chiton': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chlamydera nuchalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chlamydia psittaci': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chlamydia trachomatis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chlamydia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chlamydomonas': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chlamydosaurus kingi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chlamyphore': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chlamyphorus truncatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chloe anthony wofford': {'n_is_sb': '0'},
 'chlorella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chlorococcales': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chlorococcum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chlorophis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chlorophoneus nigrifrons': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chlorophoneus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chlorophthalmidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chlorophyta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chlorophyte': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chlorura chlorura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chlorura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'choctaw': {'n_is_sb': '2', 'n_is_sth': '2'},
 'choeronycteris mexicana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'choirboy': {'n_is_sb': '0'},
 'choirmaster': {'n_is_sb': '0'},
 'choloepus didactylus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'choloepus hoffmanni': {'n_is_sb': '3', 'n_is_sth': '3'},
 'choloepus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chomsky': {'n_is_sb': '0'},
 'chondrichthian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chondrus crispus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chooser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'chopin': {'n_is_sb': '0'},
 'choragus': {'n_is_sb': '0'},
 'chordata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chordate family': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chordate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'choreographer': {'n_is_sb': '0'},
 'chorine': {'n_is_sb': '0'},
 'choriotis australis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'choriotis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chorister': {'n_is_sb': '0'},
 'chorizagrotis auxiliaris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chorizagrotis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chorus frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chorus girl': {'n_is_sb': '0'},
 'chou en-lai': {'n_is_sb': '0'},
 'chough': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chow chow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chris evert': {'n_is_sb': '0'},
 'chrissie evert': {'n_is_sb': '0'},
 'christiaan eijkman': {'n_is_sb': '0'},
 'christiaan huygens': {'n_is_sb': '0'},
 'christian dior': {'n_is_sb': '0'},
 'christian friedrich hebbel': {'n_is_sb': '0'},
 'christian friedrich schonbein': {'n_is_sb': '0'},
 'christian huygens': {'n_is_sb': '0'},
 'christian johann doppler': {'n_is_sb': '0'},
 'christian schonbein': {'n_is_sb': '0'},
 'christian scientist': {'n_is_sb': '0'},
 'christie': {'n_is_sb': '0'},
 'christine marie evert': {'n_is_sb': '0'},
 'christoph willibald von gluck': {'n_is_sb': '0'},
 'christopher carson': {'n_is_sb': '0'},
 'christopher columbus': {'n_is_sb': '0'},
 'christopher fry': {'n_is_sb': '0'},
 'christopher isherwood': {'n_is_sb': '0'},
 'christopher marlowe': {'n_is_sb': '0'},
 'christopher william bradshaw isherwood': {'n_is_sb': '0'},
 'chronicler': {'n_is_sb': '0'},
 'chronoperates paradoxus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chronoperates': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chrysanthemum dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chrysaora quinquecirrha': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chrysaora': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chrysemys picta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chrysemys': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chrysochloris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chrysolophus pictus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chrysolophus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chrysomelidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chrysomelid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chrysophrys auratus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chrysophrys australis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chrysophrys': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chrysophyta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chrysopidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chrysopid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chuang-tzu': {'n_is_sb': '0'},
 'chub mackerel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chub': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chuck berry': {'n_is_sb': '0'},
 "chuck-will's-widow": {'n_is_sb': '3', 'n_is_sth': '3'},
 'chucker-out': {'n_is_sb': '0'},
 'chuckwalla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chunga burmeisteri': {'n_is_sb': '3', 'n_is_sth': '3'},
 'chunga': {'n_is_sb': '3', 'n_is_sth': '3'},
 'church father': {'n_is_sb': '0'},
 'church member': {'n_is_sb': '0'},
 'church mouse': {'n_is_sb': '2', 'n_is_sth': '2'},
 'church officer': {'n_is_sb': '0'},
 'churchgoer': {'n_is_sb': '0'},
 'churchwarden': {'n_is_sb': '2', 'n_is_sth': '2'},
 'chutzpanik': {'n_is_sb': '0'},
 'chuvash': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ciardi': {'n_is_sb': '0'},
 'cicada killer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cicadidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cicala': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cicero': {'n_is_sb': '0'},
 'cichlid fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cichlid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cicily isabel fairfield': {'n_is_sb': '0'},
 'ciconia ciconia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ciconia nigra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ciconia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ciconiidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ciconiiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cigar smoker': {'n_is_sb': '0'},
 'cigarette smoker': {'n_is_sb': '0'},
 'cigarfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ciliata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ciliated protozoan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ciliate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cilioflagellata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ciliophoran': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cimabue': {'n_is_sb': '0'},
 'cimarron': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cimex lectularius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cimex': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cincinnatus': {'n_is_sb': '0'},
 'cinclus aquaticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cinclus mexicanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cinclus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cinderella': {'n_is_sb': '0'},
 'cinematographer': {'n_is_sb': '0'},
 'cinnabar moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cinnamon bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'circaetus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'circassian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'circus acrobat': {'n_is_sb': '0'},
 'circus aeruginosus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'circus cyaneus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'circus pygargus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cisco': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cistercian': {'n_is_sb': '0'},
 'cistothorus palustris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cistothorus platensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cistothorus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'citellus citellus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'citellus lateralis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'citellus leucurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'citellus parryi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'citellus richardsoni': {'n_is_sb': '3', 'n_is_sth': '3'},
 'citellus variegatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'citellus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'citharichthys cornutus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'citizen genet': {'n_is_sb': '0'},
 'citrophilous mealybug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'citrophilus mealybug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'citrus mealybug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'citrus whitefly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'city boy': {'n_is_sb': '0'},
 'city editor': {'n_is_sb': '0'},
 'city father': {'n_is_sb': '0'},
 'city manager': {'n_is_sb': '0'},
 'city man': {'n_is_sb': '0'},
 'city slicker': {'n_is_sb': '0'},
 'civet cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'civic leader': {'n_is_sb': '0'},
 'civil authority': {'n_is_sb': '0'},
 'civil engineer': {'n_is_sb': '0'},
 'civil leader': {'n_is_sb': '0'},
 'civil rights activist': {'n_is_sb': '0'},
 'civil rights leader': {'n_is_sb': '0'},
 'civil rights worker': {'n_is_sb': '0'},
 'civil servant': {'n_is_sb': '0'},
 'cladorhyncus leucocephalum': {'n_is_sb': '0'},
 'claes oldenberg': {'n_is_sb': '0'},
 'claim agent': {'n_is_sb': '0'},
 'claim jumper': {'n_is_sb': '0'},
 'claims adjuster': {'n_is_sb': '0'},
 'claims adjustor': {'n_is_sb': '0'},
 'clamatores': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clan member': {'n_is_sb': '0'},
 'clangula hyemalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clangula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clansman': {'n_is_sb': '0'},
 'clanswoman': {'n_is_sb': '0'},
 'clara josephine schumann': {'n_is_sb': '0'},
 'clare booth luce': {'n_is_sb': '0'},
 'clarence darrow': {'n_is_sb': '0'},
 'clarence day': {'n_is_sb': '0'},
 'clarence malcolm lowry': {'n_is_sb': '0'},
 'clarence seward darrow': {'n_is_sb': '0'},
 'clarence shepard day jr.': {'n_is_sb': '0'},
 'clarinetist': {'n_is_sb': '0'},
 'clarinettist': {'n_is_sb': '0'},
 'clark gable': {'n_is_sb': '0'},
 "clark's nutcracker": {'n_is_sb': '3', 'n_is_sth': '3'},
 'clark': {'n_is_sb': '0'},
 'class act': {'n_is_sb': '0'},
 'class amphibia': {'n_is_sb': '0'},
 'class arachnida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class asteroidea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class aves': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class bacillariophyceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class bivalvia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class cephalopoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class cestoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class channidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class charophyceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class chilopoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class chlorophyceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class chondrichthyes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class chrysophyceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class ciliata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class ciliophora': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class crinoidea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class crustacea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class cryptophyceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class cyanobacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class cyanophyceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class cyclosporeae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class diatomophyceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class diplopoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class echinoidea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class euglenophyceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class fellow': {'n_is_sb': '0'},
 'class flagellata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class gasteropoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class gastropoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class heterokontae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class hexapoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class hirudinea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class holothuroidea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class hyalospongiae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class hydrozoa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class insecta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class lamellibranchia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class larvacea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class mammalia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class mastigophora': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class merostomata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class myriapoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class nuda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class oligochaeta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class onychophora': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class ophiuroidea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class osteichthyes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class pauropoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class pelecypoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class phaeophyceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class phasmidia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class placodermi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class polychaeta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class polyplacophora': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class reptilia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class rhodophyceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class sarcodina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class scaphopoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class schizomycetes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class scyphozoa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class sporozoa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class symphyla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class tardigrada': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class tentaculata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class thaliacea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class trematoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class turbellaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class ulvophyceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'class xanthophyceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'classical scholar': {'n_is_sb': '0'},
 'classicist': {'n_is_sb': '0'},
 'classifier': {'n_is_sb': '2', 'n_is_sth': '2'},
 'claude achille debussy': {'n_is_sb': '0'},
 'claude bernard': {'n_is_sb': '0'},
 'claude debussey': {'n_is_sb': '0'},
 'claude e. shannon': {'n_is_sb': '0'},
 'claude elwood shannon': {'n_is_sb': '0'},
 'claude levi-strauss': {'n_is_sb': '0'},
 'claude monet': {'n_is_sb': '0'},
 'claude shannon': {'n_is_sb': '0'},
 'claudio monteverdi': {'n_is_sb': '0'},
 'claudius i': {'n_is_sb': '0'},
 'claudius ptolemaeus': {'n_is_sb': '0'},
 'claudius': {'n_is_sb': '0'},
 'clausewitz': {'n_is_sb': '0'},
 'claustrophobe': {'n_is_sb': '0'},
 'clay-colored robin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cleaning lady': {'n_is_sb': '0'},
 'cleaning woman': {'n_is_sb': '0'},
 'cleanthes': {'n_is_sb': '0'},
 'clegg': {'n_is_sb': '0'},
 'cleg': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clemence sophia harned lozier': {'n_is_sb': '0'},
 'clemenceau': {'n_is_sb': '0'},
 'clemens': {'n_is_sb': '0'},
 'clement attlee': {'n_is_sb': '0'},
 'clement philibert leo delibes': {'n_is_sb': '0'},
 'clement richard attlee': {'n_is_sb': '0'},
 'cleopatra': {'n_is_sb': '0'},
 'clericalist': {'n_is_sb': '0'},
 'clerid beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cleridae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clerid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clethrionomys': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cleveland': {'n_is_sb': '0'},
 'clever clogs': {'n_is_sb': '0'},
 'clever dick': {'n_is_sb': '0'},
 'click beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cliff dweller': {'n_is_sb': '0'},
 'cliff swallow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clifford odets': {'n_is_sb': '0'},
 'climber': {'n_is_sb': '2', 'n_is_sth': '2'},
 'climbing perch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'climbing salamander': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clingfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clinical psychologist': {'n_is_sb': '0'},
 'clinician': {'n_is_sb': '0'},
 'clinid fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clio': {'n_is_sb': '0'},
 'clip artist': {'n_is_sb': '0'},
 'clive sinclair': {'n_is_sb': '0'},
 'clive staples lewis': {'n_is_sb': '0'},
 'clive': {'n_is_sb': '0'},
 'cloakmaker': {'n_is_sb': '0'},
 'clock watcher': {'n_is_sb': '0'},
 'clockmaker': {'n_is_sb': '0'},
 'clocksmith': {'n_is_sb': '0'},
 'clog dancer': {'n_is_sb': '0'},
 'closer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'closet queen': {'n_is_sb': '0'},
 'clostridia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clostridium botulinum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clostridium perfringens': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clostridium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clothes designer': {'n_is_sb': '0'},
 'clothes moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clotheshorse': {'n_is_sb': '2', 'n_is_sth': '2'},
 'clotho': {'n_is_sb': '0'},
 'cloud seeder': {'n_is_sb': '0'},
 'cloven hoof': {'n_is_sb': '0'},
 'clovis i': {'n_is_sb': '0'},
 'clovis': {'n_is_sb': '0'},
 'clown anemone fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'club member': {'n_is_sb': '0'},
 'clumber spaniel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clumber': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clumsy person': {'n_is_sb': '0'},
 'clupea harangus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clupea harengus harengus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clupea harengus pallasii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clupea sprattus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clupea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clupeid fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clupeidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clupeid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clyde william tombaugh': {'n_is_sb': '0'},
 'clydesdale terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clydesdale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'clytemnestra': {'n_is_sb': '0'},
 'cmv': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cnemidophorus exsanguis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cnemidophorus sexlineatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cnemidophorus tesselatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cnemidophorus tigris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cnemidophorus velox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cnemidophorus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cnidarian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cnidaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cnut': {'n_is_sb': '0'},
 'co-defendant': {'n_is_sb': '0'},
 'co-respondent': {'n_is_sb': '0'},
 'coach dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coach horse': {'n_is_sb': '2', 'n_is_sth': '2'},
 'coachbuilder': {'n_is_sb': '0'},
 'coachwhip snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coachwhip': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coal miner': {'n_is_sb': '0'},
 'coalman': {'n_is_sb': '0'},
 'coastal diving bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coastguardsman': {'n_is_sb': '0'},
 'coat-of-mail shell': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coati-mondi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coati-mundi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coati': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coaxer': {'n_is_sb': '0'},
 'cobber': {'n_is_sb': '0'},
 'cobia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cobitidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cocaine addict': {'n_is_sb': '0'},
 'coccid insect': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coccidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coccidium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cocci': {'n_is_sb': '2', 'n_is_sth': '2'},
 'coccobacillus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coccothraustes coccothraustes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coccothraustes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coccus hesperidum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coccus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coccyzus erythropthalmus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coccyzus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cochimi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cochin china': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cochineal insect': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cochineal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cochin': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cochise': {'n_is_sb': '0'},
 'cochlearius cochlearius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cochlearius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cochran': {'n_is_sb': '0'},
 'cock of the rock': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cockateel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cockatiel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cockatoo parrot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cockatoo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cockatrice': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cockchafer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cockcroft': {'n_is_sb': '0'},
 'cocker spaniel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cockerel': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cocker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cockney': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cocksucker': {'n_is_sb': '0', 'dirtyword': ''},
 'coconspirator': {'n_is_sb': '0'},
 'cocopah': {'n_is_sb': '0'},
 'cocopa': {'n_is_sb': '0'},
 'cocotte': {'n_is_sb': '0'},
 'cocteau': {'n_is_sb': '0'},
 'cocus': {'n_is_sb': '0'},
 'coddler': {'n_is_sb': '0'},
 'codefendant': {'n_is_sb': '0'},
 'codetalker': {'n_is_sb': '0'},
 'codlin moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'codling moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'codling': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cody': {'n_is_sb': '0'},
 'coelacanth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coelenterate genus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coelenterate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coelophysis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coenobite': {'n_is_sb': '0'},
 'coereba': {'n_is_sb': '0'},
 'coeval': {'n_is_sb': '0'},
 'cofounder': {'n_is_sb': '0'},
 'cognate': {'n_is_sb': '0'},
 'cognitive neuroscientist': {'n_is_sb': '0'},
 'cognitive scientist': {'n_is_sb': '0'},
 'cognoscenti': {'n_is_sb': '0'},
 'cohan': {'n_is_sb': '0'},
 'cohn': {'n_is_sb': '0'},
 'coho salmon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cohoe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coho': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coiffeur': {'n_is_sb': '0'},
 'coiffeuse': {'n_is_sb': '0'},
 'coin collector': {'n_is_sb': '0'},
 'coiner': {'n_is_sb': '0'},
 'colaptes auratus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'colaptes caper collaris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'colaptes chrysoides': {'n_is_sb': '3', 'n_is_sth': '3'},
 'colaptes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cold fish': {'n_is_sb': '0'},
 'cole albert porter': {'n_is_sb': '0'},
 'cole porter': {'n_is_sb': '0'},
 'coleman hawkins': {'n_is_sb': '0'},
 'coleonyx': {'n_is_sb': '0'},
 'coleoptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coleridge': {'n_is_sb': '0'},
 'colette': {'n_is_sb': '0'},
 'colin luther powell': {'n_is_sb': '0'},
 'colin powell': {'n_is_sb': '0'},
 'colinus virginianus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'colinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coliphage': {'n_is_sb': '3', 'n_is_sth': '3'},
 'collar cell': {'n_is_sb': '3', 'n_is_sth': '3'},
 'collared lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'collared peccary': {'n_is_sb': '3', 'n_is_sth': '3'},
 'collared pika': {'n_is_sb': '3', 'n_is_sth': '3'},
 'collectivist': {'n_is_sb': '0'},
 'collector of internal revenue': {'n_is_sb': '0'},
 'college boy': {'n_is_sb': '0'},
 'college girl': {'n_is_sb': '0'},
 'college man': {'n_is_sb': '0'},
 'college student': {'n_is_sb': '0'},
 'collegian': {'n_is_sb': '0'},
 'collembolan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'collie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'collins': {'n_is_sb': '0'},
 'collis potter huntington': {'n_is_sb': '0'},
 'collocalia inexpectata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'collocalia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'colobus guereza': {'n_is_sb': '3', 'n_is_sth': '3'},
 'colobus monkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'colobus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'colombian': {'n_is_sb': '0', 'cap_word': 'Colombian'},
 'colonel blimp': {'n_is_sb': '0'},
 'colonialist': {'n_is_sb': '0'},
 'coloniser': {'n_is_sb': '0'},
 'colonist': {'n_is_sb': '0'},
 'colonizer': {'n_is_sb': '0'},
 'color bearer': {'n_is_sb': '0'},
 'color guard': {'n_is_sb': '0'},
 'color sergeant': {'n_is_sb': '0'},
 'color-blind person': {'n_is_sb': '0'},
 'coloradan': {'n_is_sb': '0'},
 'colorado beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'colorado potato beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coloratura soprano': {'n_is_sb': '0'},
 'colored person': {'n_is_sb': '0'},
 'colored': {'n_is_sb': '0', 'vbd_eq_vbn': ''},
 'colorist': {'n_is_sb': '0'},
 'colossian': {'n_is_sb': '0'},
 'coluber constrictor flaviventris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coluber constrictor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coluber hippocrepis': {'n_is_sb': '0'},
 'coluber': {'n_is_sb': '3', 'n_is_sth': '3'},
 'colubrid snake': {'n_is_sb': '0'},
 'colubrid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'colugo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'columba fasciata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'columba livia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'columba palumbus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'columbian mammoth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'columbidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'columbiform bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'columbiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'columnist': {'n_is_sb': '0'},
 'comanche': {'n_is_sb': '2', 'n_is_sth': '2'},
 'comatula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'comatulidae': {'n_is_sb': '0'},
 'comatulid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'comb jelly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'comb-footed spider': {'n_is_sb': '3', 'n_is_sth': '3'},
 'combat pilot': {'n_is_sb': '0'},
 'combtooth blenny': {'n_is_sb': '3', 'n_is_sth': '3'},
 'comedienne': {'n_is_sb': '0'},
 'comenius': {'n_is_sb': '0'},
 'comer vann woodward': {'n_is_sb': '0'},
 'comer': {'n_is_sb': '0'},
 'comfort woman': {'n_is_sb': '0'},
 'comic': {'n_is_sb': '2', 'n_is_sth': '2'},
 'comma bacillus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'comma butterfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'commander in chief': {'n_is_sb': '0'},
 'commanding officer': {'n_is_sb': '0'},
 'commensal': {'n_is_sb': '0'},
 'commerce secretary': {'n_is_sb': '0'},
 'commercial artist': {'n_is_sb': '0'},
 'commercial traveler': {'n_is_sb': '0'},
 'commercial traveller': {'n_is_sb': '0'},
 'commissaire maigret': {'n_is_sb': '0'},
 'commissionaire': {'n_is_sb': '0'},
 'commissioned military officer': {'n_is_sb': '0'},
 'commissioned naval officer': {'n_is_sb': '0'},
 'commissioned officer': {'n_is_sb': '0'},
 'committee member': {'n_is_sb': '0'},
 'committeewoman': {'n_is_sb': '0'},
 'commodore perry': {'n_is_sb': '0'},
 'commodore vanderbilt': {'n_is_sb': '0'},
 'commodore': {'n_is_sb': '0'},
 'common american shad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common blackfish': {'n_is_sb': '0'},
 'common booklouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common brant goose': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common canary': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common dolphin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common eel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common eland': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common european earwig': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common european jay': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common garter snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common iguana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common kingsnake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common limpet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common louse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common lynx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common mackerel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common man': {'n_is_sb': '0'},
 'common mosquito': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common murre': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common newt': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common nutcracker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common opossum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common person': {'n_is_sb': '0'},
 'common pond-skater': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common raccoon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common racoon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common rorqual': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common roundworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common scold': {'n_is_sb': '0'},
 'common scoter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common seal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common shiner': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common shrew': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common snapping turtle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common snipe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common soldier': {'n_is_sb': '0'},
 'common spoonbill': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common starling': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common viper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common wallaby': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common wasp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common water snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common yellowthroat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'common zebra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'communicant': {'n_is_sb': '0'},
 'commuter': {'n_is_sb': '0'},
 'company man': {'n_is_sb': '0'},
 'company operator': {'n_is_sb': '0'},
 'comparative anatomist': {'n_is_sb': '0'},
 'compeer': {'n_is_sb': '0'},
 'compere': {'n_is_sb': '0'},
 'complainer': {'n_is_sb': '0'},
 'complexifier': {'n_is_sb': '0'},
 'compositor': {'n_is_sb': '0'},
 'compromiser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'compsognathus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'compton': {'n_is_sb': '0'},
 'comptroller general': {'n_is_sb': '0'},
 'comptroller of the currency': {'n_is_sb': '0'},
 'compulsive': {'n_is_sb': '0'},
 'computational linguist': {'n_is_sb': '0'},
 'computer expert': {'n_is_sb': '0'},
 'computer guru': {'n_is_sb': '0'},
 'computer programmer': {'n_is_sb': '0'},
 'computer scientist': {'n_is_sb': '0'},
 'computer user': {'n_is_sb': '0'},
 'comstock mealybug': {'n_is_sb': '3', 'n_is_sth': '3'},
 "comstock's mealybug": {'n_is_sb': '3', 'n_is_sth': '3'},
 'comstock': {'n_is_sb': '0'},
 'comte de mirabeau': {'n_is_sb': '0'},
 'comte de rochambeau': {'n_is_sb': '0'},
 'comte de saxe': {'n_is_sb': '0'},
 'comte donatien alphonse francois de sade': {'n_is_sb': '0'},
 'comtesse du barry': {'n_is_sb': '0'},
 'con artist': {'n_is_sb': '0', 'e_trp.dobj': ''},
 'con man': {'n_is_sb': '0'},
 'conan doyle': {'n_is_sb': '0'},
 'conceiver': {'n_is_sb': '0'},
 'concert-goer': {'n_is_sb': '0'},
 'concessionaire': {'n_is_sb': '0'},
 'concessioner': {'n_is_sb': '0'},
 'conchfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'conchologist': {'n_is_sb': '0'},
 'conciliator': {'n_is_sb': '0'},
 'conductress': {'n_is_sb': '0'},
 'condylura cristata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'condylura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cone-nosed bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'conenose bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'conenose': {'n_is_sb': '3', 'n_is_sth': '3'},
 'conepatus leuconotus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'conepatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'confectioner': {'n_is_sb': '2', 'n_is_sth': '2'},
 'confederate soldier': {'n_is_sb': '0'},
 'conferee': {'n_is_sb': '0'},
 'conferva': {'n_is_sb': '3', 'n_is_sth': '3'},
 'confervoid algae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'confessor': {'n_is_sb': '0'},
 'confidante': {'n_is_sb': '0'},
 'confidence man': {'n_is_sb': '0'},
 'conformist': {'n_is_sb': '0'},
 'confrere': {'n_is_sb': '0'},
 'confuter': {'n_is_sb': '0'},
 'congenator': {'n_is_sb': '3', 'n_is_sth': '3'},
 'congener': {'n_is_sb': '2', 'n_is_sth': '2'},
 'conger eel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'congo eel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'congo peafowl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'congo snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'congolese': {'n_is_sb': '2', 'n_is_sth': '2'},
 'congregationalist': {'n_is_sb': '0'},
 'congresswoman': {'n_is_sb': '0'},
 'congridae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'conilurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'conjoined twin': {'n_is_sb': '0'},
 'conjure man': {'n_is_sb': '0'},
 'connecticuter': {'n_is_sb': '0'},
 'connochaetes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'connolly': {'n_is_sb': '0'},
 'connors': {'n_is_sb': '0'},
 'conodonta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'conodont': {'n_is_sb': '3', 'n_is_sth': '3'},
 'conoy': {'n_is_sb': '0'},
 'conquistador': {'n_is_sb': '0'},
 'conrad aiken': {'n_is_sb': '0'},
 'conrad potter aiken': {'n_is_sb': '0'},
 'conrad': {'n_is_sb': '0'},
 'conscientious objector': {'n_is_sb': '0'},
 'conscript': {'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'conservationist': {'n_is_sb': '0'},
 'conservative jew': {'n_is_sb': '0'},
 'conservativist': {'n_is_sb': '0'},
 'consignee': {'n_is_sb': '0'},
 'consigner': {'n_is_sb': '0'},
 'consignor': {'n_is_sb': '0'},
 'conspecific': {'n_is_sb': '3', 'n_is_sth': '3'},
 'constant lambert': {'n_is_sb': '0'},
 'constantin brancusi': {'n_is_sb': '0'},
 'constantine i': {'n_is_sb': '0'},
 'constantine the great': {'n_is_sb': '0'},
 'constantine': {'n_is_sb': '0'},
 'constrictor constrictor': {'n_is_sb': '2', 'n_is_sth': '2'},
 'construction worker': {'n_is_sb': '0'},
 'constructivist': {'n_is_sb': '0'},
 'consumptive': {'n_is_sb': '0'},
 'contadino': {'n_is_sb': '0'},
 'conte alessandro giuseppe antonio anastasio volta': {'n_is_sb': '0'},
 'conte alessandro volta': {'n_is_sb': '0'},
 'contemplative': {'n_is_sb': '0'},
 'contestee': {'n_is_sb': '0'},
 'contester': {'n_is_sb': '0'},
 'contopus sordidulus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'contopus virens': {'n_is_sb': '3', 'n_is_sth': '3'},
 'contortionist': {'n_is_sb': '0'},
 'contrabandist': {'n_is_sb': '0'},
 'contrapuntist': {'n_is_sb': '0'},
 'contrarian': {'n_is_sb': '0'},
 'contributor': {'n_is_sb': '0'},
 'contriver': {'n_is_sb': '0'},
 'control freak': {'n_is_sb': '0'},
 'controversialist': {'n_is_sb': '0'},
 'conuropsis carolinensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'conuropsis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'convalescent': {'n_is_sb': '0'},
 'convergent thinker': {'n_is_sb': '0'},
 'conversational partner': {'n_is_sb': '0'},
 'conversationalist': {'n_is_sb': '0'},
 'converso': {'n_is_sb': '0'},
 'conveyancer': {'n_is_sb': '0'},
 'conveyer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'convict fish': {'n_is_sb': '0'},
 'convictfish': {'n_is_sb': '0'},
 'cony': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cooke': {'n_is_sb': '0'},
 'coolidge': {'n_is_sb': '0'},
 'cooly': {'n_is_sb': '0'},
 'coon bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coon cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coondog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coonhound': {'n_is_sb': '3', 'n_is_sth': '3'},
 "cooper's hawk": {'n_is_sb': '3', 'n_is_sth': '3'},
 'cooperator': {'n_is_sb': '0'},
 'cooper': {'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'coordinator': {'n_is_sb': '0'},
 'cooter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'copartner': {'n_is_sb': '0'},
 'copepod crustacean': {'n_is_sb': '3', 'n_is_sth': '3'},
 'copepod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'copilot': {'n_is_sb': '0'},
 'copland': {'n_is_sb': '0'},
 'copley': {'n_is_sb': '0'},
 'copper rockfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 "copper's nark": {'n_is_sb': '3', 'n_is_sth': '3'},
 'copperhead': {'n_is_sb': '2', 'n_is_sth': '2'},
 'coppola': {'n_is_sb': '0'},
 'copt': {'n_is_sb': '0'},
 'copy editor': {'n_is_sb': '0'},
 'copycat': {'n_is_sb': '0'},
 'copyreader': {'n_is_sb': '0'},
 'copywriter': {'n_is_sb': '0'},
 'coracias garrulus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coraciiform bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coragyps atratus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coragyps': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coral snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cora': {'n_is_sb': '0'},
 'corbett': {'n_is_sb': '0'},
 'corbina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'corday': {'n_is_sb': '0'},
 'cordell hull': {'n_is_sb': '0'},
 'cordoba': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cordon bleu': {'n_is_sb': '0'},
 'cordova': {'n_is_sb': '2', 'n_is_sth': '2'},
 'coregonus artedi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coregonus clupeaformis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coreid bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coreidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coreid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coreligionist': {'n_is_sb': '0'},
 'corespondent': {'n_is_sb': '0'},
 'corinthian': {'n_is_sb': '0', 'cap_word': 'Corinthian'},
 'corixidae': {'n_is_sb': '0'},
 'corn borer moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'corn borer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'corn earworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'corn snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'corncrake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'corneille': {'n_is_sb': '0'},
 'cornelia otis skinner': {'n_is_sb': '0'},
 'cornelis jansen': {'n_is_sb': '0'},
 'cornelius jansenius': {'n_is_sb': '0'},
 'cornelius vanderbilt': {'n_is_sb': '0'},
 'cornell': {'n_is_sb': '0'},
 'corner man': {'n_is_sb': '0'},
 'cornerback': {'n_is_sb': '0'},
 'cornetfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cornetist': {'n_is_sb': '0'},
 'cornhusker': {'n_is_sb': '0'},
 'cornishman': {'n_is_sb': '0'},
 'cornishwoman': {'n_is_sb': '0'},
 'cornish': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cornwallis': {'n_is_sb': '0'},
 'coroner': {'n_is_sb': '0'},
 'corot': {'n_is_sb': '0'},
 'corporate executive': {'n_is_sb': '0'},
 'correggio': {'n_is_sb': '0'},
 'cortez': {'n_is_sb': '0'},
 'corvidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'corvine bird': {'n_is_sb': '0'},
 'corvus brachyrhyncos': {'n_is_sb': '3', 'n_is_sth': '3'},
 'corvus corax': {'n_is_sb': '2', 'n_is_sth': '2'},
 'corvus frugilegus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'corvus monedula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'corydalus cornutus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'corydalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'corynebacterium diphtheriae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'corynebacterium': {'n_is_sb': '2', 'n_is_sth': '2'},
 'coryphaena equisetis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coryphaena hippurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'corythosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'corythosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cosignatory': {'n_is_sb': '0'},
 'cosigner': {'n_is_sb': '0'},
 'cosimo de medici': {'n_is_sb': '0'},
 'cosimo the elder': {'n_is_sb': '0'},
 'cosmetic surgeon': {'n_is_sb': '0'},
 'cosmetician': {'n_is_sb': '0'},
 'cosmetologist': {'n_is_sb': '0'},
 'cosmocampus profundus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cosmographer': {'n_is_sb': '0'},
 'cosmographist': {'n_is_sb': '0'},
 'cosmologist': {'n_is_sb': '0'},
 'cosmopolitan': {'n_is_sb': '0'},
 'cosmopolite': {'n_is_sb': '0'},
 'cost accountant': {'n_is_sb': '0'},
 'costa rican': {'n_is_sb': '0'},
 'costanoan': {'n_is_sb': '0'},
 'costermonger': {'n_is_sb': '0'},
 'costia necatrix': {'n_is_sb': '3', 'n_is_sth': '3'},
 'costia': {'n_is_sb': '0'},
 'costume designer': {'n_is_sb': '0'},
 'costumer': {'n_is_sb': '0'},
 'costumier': {'n_is_sb': '0'},
 'cotenant': {'n_is_sb': '0'},
 'cotinga': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cotswold': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cottage dweller': {'n_is_sb': '0'},
 'cottager': {'n_is_sb': '0'},
 'cottar': {'n_is_sb': '0'},
 'cotton bollworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cotton mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cotton rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cotton stainer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cotton strain': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cottonmouth moccasin': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cottonmouth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cottontail rabbit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cottontail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cottonwick': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cottus': {'n_is_sb': '0'},
 'coturnix communis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coturnix coturnix': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coturnix': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coucal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'couch potato': {'n_is_sb': '0'},
 'coulomb': {'n_is_sb': '0'},
 'council member': {'n_is_sb': '0'},
 'councilwoman': {'n_is_sb': '0'},
 'counsel to the crown': {'n_is_sb': '0'},
 'counselor-at-law': {'n_is_sb': '0'},
 'count alessandro di cagliostro': {'n_is_sb': '0'},
 'count alessandro volta': {'n_is_sb': '0'},
 'count ferdinand von zeppelin': {'n_is_sb': '0'},
 'count fleet': {'n_is_sb': '0'},
 'count lev nikolayevitch tolstoy': {'n_is_sb': '0'},
 'count maurice maeterlinck': {'n_is_sb': '0'},
 'count nikolaus ludwig von zinzendorf': {'n_is_sb': '0'},
 'count palatine': {'n_is_sb': '0'},
 'count rumford': {'n_is_sb': '0'},
 'counter-revolutionist': {'n_is_sb': '0'},
 'counterdemonstrator': {'n_is_sb': '0'},
 'counterfeiter': {'n_is_sb': '0'},
 'counterman': {'n_is_sb': '0'},
 'counterperson': {'n_is_sb': '0'},
 'counterrevolutionist': {'n_is_sb': '0'},
 'counterspy': {'n_is_sb': '0'},
 'countertenor': {'n_is_sb': '0'},
 'counterwoman': {'n_is_sb': '0'},
 'countess': {'n_is_sb': '0'},
 'country doctor': {'n_is_sb': '0'},
 'countrywoman': {'n_is_sb': '0'},
 'county agent': {'n_is_sb': '0'},
 'couperin': {'n_is_sb': '0'},
 'courbet': {'n_is_sb': '0'},
 'coureur de bois': {'n_is_sb': '0'},
 'courlan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'courser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'courtier': {'n_is_sb': '0'},
 'cousin-german': {'n_is_sb': '0'},
 'cousteau': {'n_is_sb': '0'},
 'couturier': {'n_is_sb': '0'},
 'cover girl': {'n_is_sb': '0'},
 'cow man': {'n_is_sb': '0'},
 'cow pony': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cow shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cow-nosed ray': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cowbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cowfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cowgirl': {'n_is_sb': '0'},
 'cowhand': {'n_is_sb': '0'},
 'cowman': {'n_is_sb': '0'},
 'cownose ray': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cowper': {'n_is_sb': '0'},
 'cowpoke': {'n_is_sb': '0'},
 'cowry': {'n_is_sb': '2', 'n_is_sth': '2'},
 'coxcomb': {'n_is_sb': '2', 'n_is_sth': '2'},
 'coxsackie virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coxsackievirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coydog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'coypu': {'n_is_sb': '0'},
 'cpa': {'n_is_sb': '0'},
 'crab louse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crab-eating dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crab-eating fox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crab-eating macaque': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crab-eating opossum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crab-eating raccoon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crab-eating seal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crabby person': {'n_is_sb': '0'},
 'crabeater seal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crack addict': {'n_is_sb': '0'},
 'crack shot': {'n_is_sb': '0'},
 'crackerjack': {'n_is_sb': '0'},
 'cracksman': {'n_is_sb': '0'},
 'crafter': {'n_is_sb': '0'},
 'cragsman': {'n_is_sb': '0'},
 'craig ventner': {'n_is_sb': '0'},
 'craigie': {'n_is_sb': '0'},
 'crake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crammer': {'n_is_sb': '0'},
 'crampfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crane fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'craniata': {'n_is_sb': '2', 'n_is_sth': '2'},
 'craniate': {'n_is_sb': '0'},
 'craniologist': {'n_is_sb': '0'},
 'crap-shooter': {'n_is_sb': '0'},
 'crapaud': {'n_is_sb': '2', 'n_is_sth': '2'},
 'crappie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crapshooter': {'n_is_sb': '0'},
 'crassostrea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'craven': {'n_is_sb': '0'},
 'crawdaddy': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crawdad': {'n_is_sb': '2', 'n_is_sth': '2'},
 'crawford': {'n_is_sb': '2', 'n_is_sth': '2'},
 'crax': {'n_is_sb': '2', 'n_is_sth': '2'},
 'crazy horse': {'n_is_sb': '2', 'n_is_sth': '2'},
 'crazy': {'n_is_sb': '0'},
 'cream-colored courser': {'n_is_sb': '3', 'n_is_sth': '3'},
 'creative person': {'n_is_sb': '0'},
 'creative thinker': {'n_is_sb': '0'},
 'credit analyst': {'n_is_sb': '0'},
 'creepy-crawly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cree': {'n_is_sb': '0'},
 'creole-fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'creole': {'n_is_sb': '0'},
 'creon': {'n_is_sb': '0'},
 'crested cariama': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crested myna': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crested penguin': {'n_is_sb': '2', 'n_is_sth': '2'},
 'crested screamer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crested swift': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cretan': {'n_is_sb': '0'},
 'cretin': {'n_is_sb': '0'},
 'crevalle jack': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crew member': {'n_is_sb': '0'},
 'crex crex': {'n_is_sb': '2', 'n_is_sth': '2'},
 'crex': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cricetus cricetus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crichton': {'n_is_sb': '0'},
 'cricket frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cricketer': {'n_is_sb': '0'},
 'crick': {'n_is_sb': '0'},
 'criminologist': {'n_is_sb': '0'},
 'crimper': {'n_is_sb': '2', 'n_is_sth': '2'},
 'crinoidea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crinoid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'criollo': {'n_is_sb': '0'},
 'crispin': {'n_is_sb': '0'},
 'cristobal balenciaga': {'n_is_sb': '0'},
 'cristobal colon': {'n_is_sb': '0'},
 'cristoforo colombo': {'n_is_sb': '0'},
 'critter sitter': {'n_is_sb': '0'},
 'critter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crius': {'n_is_sb': '0'},
 'cro-magnon': {'n_is_sb': '0'},
 'croatian': {'n_is_sb': '0'},
 'croat': {'n_is_sb': '0'},
 'crocethia alba': {'n_is_sb': '0'},
 'crockett': {'n_is_sb': '0'},
 'crocodile bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crocodilian reptile': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crocodilian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crocodilus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crocodylus niloticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crocodylus porosus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crocuta crocuta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crocuta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'croesus': {'n_is_sb': '0'},
 'crofter': {'n_is_sb': '0'},
 'crohn': {'n_is_sb': '0'},
 'cromwell': {'n_is_sb': '0'},
 'cronus': {'n_is_sb': '0'},
 'croo monkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crookback': {'n_is_sb': '0'},
 'crookes': {'n_is_sb': '0'},
 'crooner': {'n_is_sb': '0'},
 'crosby': {'n_is_sb': '0'},
 'cross-dresser': {'n_is_sb': '0'},
 'cross-examiner': {'n_is_sb': '0'},
 'cross-questioner': {'n_is_sb': '0'},
 'crossbencher': {'n_is_sb': '0'},
 'crossbill': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crossbred': {'n_is_sb': '0', 'vbd_eq_vbn': ''},
 'crossing guard': {'n_is_sb': '0'},
 'crossopterygian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crossover voter': {'n_is_sb': '0'},
 'crosspatch': {'n_is_sb': '0'},
 'crotalus adamanteus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crotalus atrox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crotalus cerastes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crotalus horridus atricaudatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crotalus horridus horridus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crotalus lepidus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crotalus mitchellii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crotalus scutulatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crotalus tigris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crotalus viridis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crotalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'croton bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crotonbug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'croupier': {'n_is_sb': '0'},
 'crouse': {'n_is_sb': '0'},
 'crow blackbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crow pheasant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crow-bait': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crowbait': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crown monkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crown princess': {'n_is_sb': '0'},
 'crown prince': {'n_is_sb': '0'},
 'crowned head': {'n_is_sb': '0'},
 'crucian carp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crucifix fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cruiserweight': {'n_is_sb': '0'},
 'crusader': {'n_is_sb': '0'},
 'crustacea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'crybaby': {'n_is_sb': '0'},
 'cryptacanthodes maculatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cryptanalyst': {'n_is_sb': '0'},
 'cryptobranchus alleganiensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cryptologist': {'n_is_sb': '0'},
 'cryptomonad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cryptophyta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cryptophyte': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cryptoprocta ferox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cryptoprocta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cryptotermes brevis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cryptotis parva': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ctene': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ctenidium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ctenocephalides canis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ctenocephalides felis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ctenophora': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ctenophore family': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ctenophore genus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ctenophore': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cub scout': {'n_is_sb': '0'},
 'cub shark': {'n_is_sb': '0'},
 'cuban': {'n_is_sb': '0', 'cap_word': 'Cuban'},
 'cubist': {'n_is_sb': '0'},
 'cuckoo-bumblebee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cuculidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cuculiform bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cuculiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cuculus canorus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cuirassier': {'n_is_sb': '0'},
 'culbertson': {'n_is_sb': '0'},
 'culex fatigans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'culex pipiens': {'n_is_sb': '3', 'n_is_sth': '3'},
 'culex quinquefasciatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cultist': {'n_is_sb': '0'},
 'cultivator': {'n_is_sb': '0'},
 'cultural attache': {'n_is_sb': '0'},
 'cummings': {'n_is_sb': '0'},
 'cunctator': {'n_is_sb': '0'},
 'cuniculus paca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cunner': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cunningham': {'n_is_sb': '0'},
 'cunt': {'n_is_sb': '2', 'n_is_sth': '2', 'dirtyword': ''},
 'cuon alpinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cuon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cupbearer': {'n_is_sb': '0'},
 'curandera': {'n_is_sb': '0'},
 'curandero': {'n_is_sb': '0'},
 'curassow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'curate': {'n_is_sb': '0'},
 'curlew sandpiper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'curlew': {'n_is_sb': '3', 'n_is_sth': '3'},
 'curly-coated retriever': {'n_is_sb': '3', 'n_is_sth': '3'},
 'curmudgeon': {'n_is_sb': '0'},
 'currawong': {'n_is_sb': '3', 'n_is_sth': '3'},
 'currer bell': {'n_is_sb': '0'},
 'currier': {'n_is_sb': '0'},
 'cursorius cursor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'curtiss': {'n_is_sb': '0'},
 'curtis': {'n_is_sb': '0'},
 'cuscus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cushat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cushing': {'n_is_sb': '0'},
 'cusk-eel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cusk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'custer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'customer agent': {'n_is_sb': '0'},
 "customer's broker": {'n_is_sb': '0'},
 "customer's man": {'n_is_sb': '0'},
 'cut-up': {'n_is_sb': '0'},
 'cutlassfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cutler': {'n_is_sb': '0'},
 'cutpurse': {'n_is_sb': '0'},
 'cuttle': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cutworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cuvier': {'n_is_sb': '0'},
 'cy young': {'n_is_sb': '0'},
 'cyamus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cyanobacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cyanocitta cristata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cyanophyceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cybele': {'n_is_sb': '0'},
 'cyber-terrorist': {'n_is_sb': '0'},
 'cyberpunk': {'n_is_sb': '0'},
 'cyborg': {'n_is_sb': '2', 'n_is_sth': '2'},
 'cyclist': {'n_is_sb': '0', 'nc_typical': ''},
 'cyclopes didactylus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cyclopes': {'n_is_sb': '0'},
 'cyclops': {'n_is_sb': '0'},
 'cyclopterus lumpus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cyclostome': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cygnet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cygnus atratus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cygnus buccinator': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cygnus columbianus bewickii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cygnus columbianus columbianus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cygnus columbianus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cygnus cygnus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cygnus olor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cynewulf': {'n_is_sb': '0'},
 'cynic': {'n_is_sb': '0'},
 'cynipid gall wasp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cynipid wasp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cynips': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cynocephalus variegatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cynocephalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cynodont': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cynomys gunnisoni': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cynomys ludovicianus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cynomys': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cynopterus sphinx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cynoscion nebulosus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cynoscion regalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cynthia moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cynthia': {'n_is_sb': '0'},
 'cynwulf': {'n_is_sb': '0'},
 'cyon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cypraea moneta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cypraea tigris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cyprian': {'n_is_sb': '0'},
 'cyprinid fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cyprinid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cypriniform fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cyprinodont': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cyprinus carpio': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cyprinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cypriote': {'n_is_sb': '0'},
 'cypriot': {'n_is_sb': '0'},
 'cyril burt': {'n_is_sb': '0'},
 'cyril lodowic burt': {'n_is_sb': '0'},
 'cyril northcote parkinson': {'n_is_sb': '0'},
 'cyrus hall mccormick': {'n_is_sb': '0'},
 'cyrus ii': {'n_is_sb': '0'},
 'cyrus mccormick': {'n_is_sb': '0'},
 'cyrus the elder': {'n_is_sb': '0'},
 'cyrus the great': {'n_is_sb': '0'},
 'cyrus the younger': {'n_is_sb': '0'},
 'cyrus': {'n_is_sb': '0'},
 'cystophora cristata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'cytherea': {'n_is_sb': '0'},
 'cytogeneticist': {'n_is_sb': '0'},
 'cytologist': {'n_is_sb': '0'},
 'cytomegalovirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'czar alexander iii': {'n_is_sb': '0'},
 'czar alexander ii': {'n_is_sb': '0'},
 'czar alexander i': {'n_is_sb': '0'},
 'czar nicholas i': {'n_is_sb': '0'},
 'czar peter i': {'n_is_sb': '0'},
 'czarina': {'n_is_sb': '0'},
 'czaritza': {'n_is_sb': '0'},
 'czechoslovakian': {'n_is_sb': '0'},
 'czechoslovak': {'n_is_sb': '0', 'cap_word': 'Czechoslovak'},
 'czerny': {'n_is_sb': '0'},
 "d'oyly carte": {'n_is_sb': '2', 'n_is_sth': '2'},
 'd. h. lawrence': {'n_is_sb': '0'},
 'd. w. griffith': {'n_is_sb': '0'},
 'da gamma': {'n_is_sb': '0'},
 'da vinci': {'n_is_sb': '0'},
 'dabbling duck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dabchick': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dacelo gigas': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dacelo': {'n_is_sb': '2', 'n_is_sth': '2'},
 'dachshund': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dachsie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dacoit': {'n_is_sb': '0'},
 'dactylopius coccus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'daddy longlegs': {'n_is_sb': '3', 'n_is_sth': '3'},
 'daedalus': {'n_is_sb': '0'},
 'daedal': {'n_is_sb': '2', 'n_is_sth': '2'},
 'daemon': {'n_is_sb': '2', 'n_is_sth': '2'},
 'dag hammarskjold': {'n_is_sb': '0'},
 'dag hjalmar agne carl hammarskjold': {'n_is_sb': '0'},
 'dagan': {'n_is_sb': '0'},
 'dagda': {'n_is_sb': '0'},
 'dagon': {'n_is_sb': '0'},
 'dago': {'n_is_sb': '0'},
 'daguerre': {'n_is_sb': '0'},
 'daimler': {'n_is_sb': '0'},
 'daimon': {'n_is_sb': '0'},
 'dairy cattle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dairy cow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dairy farmer': {'n_is_sb': '0'},
 'dairymaid': {'n_is_sb': '0'},
 'dairyman': {'n_is_sb': '0'},
 'dakoit': {'n_is_sb': '0'},
 'dakota': {'n_is_sb': '2', 'n_is_sth': '2'},
 'dalai lama': {'n_is_sb': '0'},
 'dale carnegie': {'n_is_sb': '0'},
 'dalesman': {'n_is_sb': '0'},
 'dali': {'n_is_sb': '0'},
 'dall sheep': {'n_is_sb': '3', 'n_is_sth': '3'},
 "dall's sheep": {'n_is_sb': '3', 'n_is_sth': '3'},
 'dallier': {'n_is_sb': '0'},
 'dalmatian': {'n_is_sb': '0'},
 'dalton trumbo': {'n_is_sb': '0'},
 'dalton': {'n_is_sb': '0'},
 'dama dama': {'n_is_sb': '0'},
 'damaliscus lunatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'damaliscus': {'n_is_sb': '0'},
 'damaraland mole rat': {'n_is_sb': '0'},
 'damascene': {'n_is_sb': '0'},
 'dama': {'n_is_sb': '0'},
 'dame agatha mary clarissa christie': {'n_is_sb': '0'},
 'dame alice ellen terry': {'n_is_sb': '0'},
 'dame alicia markova': {'n_is_sb': '0'},
 'dame barbara hepworth': {'n_is_sb': '0'},
 'dame daphne du maurier': {'n_is_sb': '0'},
 'dame edith louisa sitwell': {'n_is_sb': '0'},
 'dame edith sitwell': {'n_is_sb': '0'},
 'dame ellen terry': {'n_is_sb': '0'},
 'dame jean iris murdoch': {'n_is_sb': '0'},
 'dame joan sutherland': {'n_is_sb': '0'},
 'dame kiri janette te kanawa': {'n_is_sb': '0'},
 'dame kiri te kanawa': {'n_is_sb': '0'},
 'dame margot fonteyn': {'n_is_sb': '0'},
 'dame muriel spark': {'n_is_sb': '0'},
 'dame myra hess': {'n_is_sb': '0'},
 'dame nellie melba': {'n_is_sb': '0'},
 'dame rebecca west': {'n_is_sb': '0'},
 'dame sybil thorndike': {'n_is_sb': '0'},
 'damgalnunna': {'n_is_sb': '0'},
 'damkina': {'n_is_sb': '0'},
 'damocles': {'n_is_sb': '0'},
 'damoiselle': {'n_is_sb': '0'},
 'damon and pythias': {'n_is_sb': '0'},
 'damon runyon': {'n_is_sb': '0'},
 'damon': {'n_is_sb': '0'},
 'damosel': {'n_is_sb': '0'},
 'damozel': {'n_is_sb': '0'},
 'damselfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'damselfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'danaid butterfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'danaidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'danaid': {'n_is_sb': '0'},
 'danaus plexippus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'danaus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'dana': {'n_is_sb': '2', 'n_is_sth': '2'},
 'dancing partner': {'n_is_sb': '0'},
 'dandie dinmont terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dandie dinmont': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dane': {'n_is_sb': '0'},
 'daniel bernoulli': {'n_is_sb': '0'},
 'daniel boone': {'n_is_sb': '0'},
 'daniel chester french': {'n_is_sb': '0'},
 'daniel defoe': {'n_is_sb': '0'},
 'daniel garrison brinton': {'n_is_sb': '0'},
 'daniel hudson burnham': {'n_is_sb': '0'},
 'daniel jones': {'n_is_sb': '0'},
 'daniel morgan': {'n_is_sb': '0'},
 'daniel ortega saavedra': {'n_is_sb': '0'},
 'daniel ortega': {'n_is_sb': '0'},
 'daniel rutherford': {'n_is_sb': '0'},
 'daniel webster': {'n_is_sb': '0'},
 'daniel': {'n_is_sb': '0'},
 'danseur noble': {'n_is_sb': '0'},
 'danseur': {'n_is_sb': '0'},
 'danseuse': {'n_is_sb': '0'},
 'dante alighieri': {'n_is_sb': '0'},
 'dante gabriel rossetti': {'n_is_sb': '0'},
 'dante': {'n_is_sb': '0'},
 'danton true young': {'n_is_sb': '0'},
 'danton': {'n_is_sb': '0'},
 'danu': {'n_is_sb': '0'},
 'daphne du maurier': {'n_is_sb': '0'},
 'daphnia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dardanian': {'n_is_sb': '0'},
 'dardanus': {'n_is_sb': '0'},
 'dardan': {'n_is_sb': '0'},
 'darius iii': {'n_is_sb': '0'},
 'darius i': {'n_is_sb': '0'},
 'darius milhaud': {'n_is_sb': '0'},
 'darius the great': {'n_is_sb': '0'},
 'dark horse': {'n_is_sb': '0'},
 'dark-eyed junco': {'n_is_sb': '3', 'n_is_sth': '3'},
 'darkey': {'n_is_sb': '0'},
 'darkie': {'n_is_sb': '0'},
 'darkling beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'darkling groung beetle': {'n_is_sb': '0'},
 'darky': {'n_is_sb': '0'},
 'darning needle': {'n_is_sb': '2', 'n_is_sth': '2'},
 'darrow': {'n_is_sb': '0'},
 'darryl francis zanuck': {'n_is_sb': '0'},
 'darryl zanuck': {'n_is_sb': '0'},
 'dart player': {'n_is_sb': '0'},
 'darter': {'n_is_sb': '0'},
 'darwinian': {'n_is_sb': '0', 'cap_word': 'Darwinian'},
 'dashiell hammett': {'n_is_sb': '0'},
 'dassie': {'n_is_sb': '0'},
 'dastard': {'n_is_sb': '0'},
 'dasyatis centroura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dasyprocta aguti': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dasyprocta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dasypus novemcinctus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dasyure': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dasyurid marsupial': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dasyurus quoll': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dasyurus viverrinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'das': {'n_is_sb': '0'},
 'daubentonia madagascariensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'daubentonia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'daumier': {'n_is_sb': '0'},
 'dauphin': {'n_is_sb': '0'},
 'david alfaro siqueiros': {'n_is_sb': '0'},
 'david barnard steinman': {'n_is_sb': '0'},
 'david ben gurion': {'n_is_sb': '0'},
 'david bruce': {'n_is_sb': '0'},
 'david bushnell': {'n_is_sb': '0'},
 'david crockett': {'n_is_sb': '0'},
 'david garrick': {'n_is_sb': '0'},
 'david glasgow farragut': {'n_is_sb': '0'},
 'david grun': {'n_is_sb': '0'},
 'david hartley': {'n_is_sb': '0'},
 'david herbert lawrence': {'n_is_sb': '0'},
 'david hilbert': {'n_is_sb': '0'},
 'david hubel': {'n_is_sb': '0'},
 'david hume': {'n_is_sb': '0'},
 'david john moore cornwell': {'n_is_sb': '0'},
 'david lewelyn wark griffith': {'n_is_sb': '0'},
 'david livingstone': {'n_is_sb': '0'},
 'david low': {'n_is_sb': '0'},
 'david mamet': {'n_is_sb': '0'},
 'david o. selznick': {'n_is_sb': '0'},
 'david oliver selznick': {'n_is_sb': '0'},
 'david ricardo': {'n_is_sb': '0'},
 'david riesman jr.': {'n_is_sb': '0'},
 'david riesman': {'n_is_sb': '0'},
 'david rittenhouse': {'n_is_sb': '0'},
 'david roland smith': {'n_is_sb': '0'},
 'david sarnoff': {'n_is_sb': '0'},
 'david siqueiros': {'n_is_sb': '0'},
 'david smith': {'n_is_sb': '0'},
 'davy crockett': {'n_is_sb': '0'},
 'davys': {'n_is_sb': '0'},
 'davy': {'n_is_sb': '0'},
 'dawdler': {'n_is_sb': '0'},
 'dawes': {'n_is_sb': '0'},
 'dawn horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'daw': {'n_is_sb': '0'},
 'day boarder': {'n_is_sb': '0'},
 'day laborer': {'n_is_sb': '0'},
 'day labourer': {'n_is_sb': '0'},
 'dayan': {'n_is_sb': '0'},
 'dayboy': {'n_is_sb': '0'},
 'dayfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'daygirl': {'n_is_sb': '0'},
 'da': {'n_is_sb': '2', 'n_is_sth': '2'},
 'de bakey': {'n_is_sb': '0'},
 'de broglie': {'n_is_sb': '0'},
 'de forest': {'n_is_sb': '0'},
 'de gaulle': {'n_is_sb': '0'},
 'de kooning': {'n_is_sb': '0'},
 "de l'orme": {'n_is_sb': '0'},
 'de la mare': {'n_is_sb': '0'},
 'de mille': {'n_is_sb': '0'},
 'de niro': {'n_is_sb': '0'},
 'de quincey': {'n_is_sb': '0'},
 'de sade': {'n_is_sb': '0'},
 'de saussure': {'n_is_sb': '0'},
 'de sica': {'n_is_sb': '0'},
 'de spinoza': {'n_is_sb': '0'},
 'de valera': {'n_is_sb': '0'},
 'de vries': {'n_is_sb': '0'},
 'deaconess': {'n_is_sb': '0'},
 'dead animal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dead person': {'n_is_sb': '0'},
 'dead ringer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'dead soul': {'n_is_sb': '0'},
 'deadbeat dad': {'n_is_sb': '0'},
 'deadbeat': {'n_is_sb': '0'},
 'deadhead': {'n_is_sb': '0'},
 'deaf person': {'n_is_sb': '0'},
 'deaf-and-dumb person': {'n_is_sb': '0'},
 'dealfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dean acheson': {'n_is_sb': '0'},
 'dean gooderham acheson': {'n_is_sb': '0'},
 'dean martin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dean swift': {'n_is_sb': '0'},
 'dearest': {'n_is_sb': '0'},
 'dearie': {'n_is_sb': '0'},
 'deary': {'n_is_sb': '0'},
 'death adder': {'n_is_sb': '3', 'n_is_sth': '3'},
 "death's-head moth": {'n_is_sb': '3', 'n_is_sth': '3'},
 'deathwatch beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'deathwatch': {'n_is_sb': '0'},
 'debaser': {'n_is_sb': '0'},
 'debater': {'n_is_sb': '0'},
 'debauchee': {'n_is_sb': '0'},
 'debaucher': {'n_is_sb': '0'},
 'debs': {'n_is_sb': '0'},
 'debussy': {'n_is_sb': '0'},
 'debutante': {'n_is_sb': '0'},
 'deb': {'n_is_sb': '0'},
 'decapod crustacean': {'n_is_sb': '3', 'n_is_sth': '3'},
 'decapod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'decapterus macarellus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'decapterus punctatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'decatur': {'n_is_sb': '2', 'n_is_sth': '2'},
 'deceased person': {'n_is_sb': '0'},
 'deceased': {'n_is_sb': '0', 'vbd_eq_vbn': ''},
 'decimus junius juvenalis': {'n_is_sb': '0'},
 'decipherer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'decision maker': {'n_is_sb': '0'},
 'decius': {'n_is_sb': '0'},
 'decker': {'n_is_sb': '0'},
 'deckhand': {'n_is_sb': '0'},
 'declarer': {'n_is_sb': '0'},
 'decorator': {'n_is_sb': '0'},
 'decuma': {'n_is_sb': '0'},
 'deems taylor': {'n_is_sb': '0'},
 'deep-sea diver': {'n_is_sb': '0'},
 'deepwater pipefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'deepwater squirrelfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'deer hunter': {'n_is_sb': '0'},
 'deer mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'deer tick': {'n_is_sb': '3', 'n_is_sth': '3'},
 'deere': {'n_is_sb': '2', 'n_is_sth': '2'},
 'deerhound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'defalcator': {'n_is_sb': '0'},
 'defamer': {'n_is_sb': '0'},
 'defaulter': {'n_is_sb': '0'},
 'defeatist': {'n_is_sb': '0'},
 'defecator': {'n_is_sb': '0'},
 'defense attorney': {'n_is_sb': '0'},
 'defense contractor': {'n_is_sb': '0'},
 'defense lawyer': {'n_is_sb': '0'},
 'defense secretary': {'n_is_sb': '0'},
 'defiler': {'n_is_sb': '0'},
 'definitive host': {'n_is_sb': '0'},
 'defoe': {'n_is_sb': '0'},
 'defoliator': {'n_is_sb': '2', 'n_is_sth': '2'},
 'degrader': {'n_is_sb': '3', 'n_is_sth': '3'},
 'deinocheirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'deinonychus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'deipnosophist': {'n_is_sb': '0'},
 'deist': {'n_is_sb': '0'},
 'dekker': {'n_is_sb': '0'},
 'delacroix': {'n_is_sb': '0'},
 'delawarean': {'n_is_sb': '0'},
 'delawarian': {'n_is_sb': '0'},
 'delayer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'delbruck': {'n_is_sb': '0'},
 'delibes': {'n_is_sb': '0'},
 'delichon urbica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'delilah': {'n_is_sb': '0'},
 'delinquent': {'n_is_sb': '0'},
 'delius': {'n_is_sb': '0'},
 'delivery boy': {'n_is_sb': '0'},
 'delorme': {'n_is_sb': '0'},
 'delphinapterus leucas': {'n_is_sb': '3', 'n_is_sth': '3'},
 'delphinapterus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'delphinidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'delphinus delphis': {'n_is_sb': '0'},
 'demagogue': {'n_is_sb': '0'},
 'demagog': {'n_is_sb': '0'},
 'demander': {'n_is_sb': '0'},
 'demeter': {'n_is_sb': '0'},
 'demetrius i': {'n_is_sb': '0'},
 'demetrius poliorcetes': {'n_is_sb': '0'},
 'demetrius': {'n_is_sb': '0'},
 'demigod': {'n_is_sb': '0'},
 'demille': {'n_is_sb': '0'},
 'demimondaine': {'n_is_sb': '0'},
 'demiurge': {'n_is_sb': '0'},
 'democrat': {'n_is_sb': '0'},
 'democritus': {'n_is_sb': '0'},
 'demogorgon': {'n_is_sb': '0'},
 'demographer': {'n_is_sb': '0'},
 'demographist': {'n_is_sb': '0'},
 'demoniac': {'n_is_sb': '0'},
 'demonstrator': {'n_is_sb': '0'},
 'demosthenes': {'n_is_sb': '0'},
 'dempsey': {'n_is_sb': '0'},
 'den mother': {'n_is_sb': '0'},
 'den-mother': {'n_is_sb': '0'},
 'dendraspis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dendroaspis augusticeps': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dendroaspis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dendrocolaptes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dendroctonus rufipennis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dendroctonus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dendroica auduboni': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dendroica coronata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dendroica fusca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dendroica petechia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dendroica striate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dendroica tigrina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dendroica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dendrolagus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'deng xiaoping': {'n_is_sb': '0'},
 'denis diderot': {'n_is_sb': '0'},
 'denisonia superba': {'n_is_sb': '3', 'n_is_sth': '3'},
 'denisonia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'denmark vesey': {'n_is_sb': '0'},
 'dennis gabor': {'n_is_sb': '0'},
 'dental assistant': {'n_is_sb': '0'},
 'dental hygienist': {'n_is_sb': '0'},
 'dental practitioner': {'n_is_sb': '0'},
 'dental surgeon': {'n_is_sb': '0'},
 'dental technician': {'n_is_sb': '0'},
 'denturist': {'n_is_sb': '0'},
 'depardieu': {'n_is_sb': '0'},
 'departed': {'n_is_sb': '0', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'departer': {'n_is_sb': '0'},
 'department head': {'n_is_sb': '0'},
 'deportee': {'n_is_sb': '0'},
 'depreciator': {'n_is_sb': '0'},
 'depressive': {'n_is_sb': '0'},
 'deputy sheriff': {'n_is_sb': '0'},
 'der fuhrer': {'n_is_sb': '0'},
 'derain': {'n_is_sb': '0'},
 'derelict': {'n_is_sb': '2', 'n_is_sth': '2'},
 'dermacentor variabilis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dermacentor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dermatobia hominis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dermatologist': {'n_is_sb': '0', 'n_is_nc': ''},
 'dermochelyidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dermochelys coriacea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dermochelys': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dermoptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'derrida': {'n_is_sb': '0'},
 'dervish': {'n_is_sb': '0'},
 'descendent': {'n_is_sb': '2', 'n_is_sth': '2'},
 'descender': {'n_is_sb': '2', 'n_is_sth': '2'},
 'desert fox': {'n_is_sb': '0'},
 'desert iguana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'desert lynx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'desert rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'desert tortoise': {'n_is_sb': '3', 'n_is_sth': '3'},
 'desiderius erasmus': {'n_is_sb': '0'},
 'designated driver': {'n_is_sb': '0'},
 'designated hitter': {'n_is_sb': '0'},
 'desk clerk': {'n_is_sb': '0'},
 'desk officer': {'n_is_sb': '0'},
 'desk sergeant': {'n_is_sb': '0'},
 'deskman': {'n_is_sb': '0'},
 'desmidium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'desmid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'desmodus rotundus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'desmodus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'desmograthus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'desmond tutu': {'n_is_sb': '0'},
 'desperate criminal': {'n_is_sb': '0'},
 'desperate': {'n_is_sb': '0'},
 'despoiler': {'n_is_sb': '0'},
 'despoina': {'n_is_sb': '0'},
 'detainee': {'n_is_sb': '0'},
 'determinist': {'n_is_sb': '0'},
 'detractor': {'n_is_sb': '0'},
 'deus ex machina': {'n_is_sb': '2', 'n_is_sth': '2'},
 'deviant': {'n_is_sb': '2', 'n_is_sth': '2'},
 'deviate': {'n_is_sb': '0', 'vb_to_nn': 'deviation', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'deviationist': {'n_is_sb': '0'},
 'devil dog': {'n_is_sb': '0'},
 'devil ray': {'n_is_sb': '3', 'n_is_sth': '3'},
 'devil worshiper': {'n_is_sb': '0'},
 "devil's advocate": {'n_is_sb': '0'},
 "devil's darning needle": {'n_is_sb': '3', 'n_is_sth': '3'},
 'devilfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'devisee': {'n_is_sb': '0'},
 'deviser': {'n_is_sb': '0'},
 'devisor': {'n_is_sb': '0'},
 'devi': {'n_is_sb': '0'},
 'devon': {'n_is_sb': '2', 'n_is_sth': '2'},
 'devourer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'devries': {'n_is_sb': '0'},
 'dew worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dewar': {'n_is_sb': '2', 'n_is_sth': '2'},
 'dewitt clinton': {'n_is_sb': '0'},
 'dharma': {'n_is_sb': '2', 'n_is_sth': '2'},
 'dhegiha': {'n_is_sb': '2', 'n_is_sth': '2'},
 'dhole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diabetic': {'n_is_sb': '0'},
 'diabolist': {'n_is_sb': '0'},
 'diadophis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diaghilev': {'n_is_sb': '0'},
 'diagnostician': {'n_is_sb': '0'},
 'dialectician': {'n_is_sb': '0'},
 'dialeurodes citri': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dialeurodes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diamond jim brady': {'n_is_sb': '0'},
 'diamond jim': {'n_is_sb': '0'},
 'diamondback rattlesnake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diamondback terrapin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diamondback': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diana': {'n_is_sb': '0'},
 'diane de poitiers': {'n_is_sb': '0'},
 'diapheromera femorata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diapheromera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diapsid reptile': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diapsid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diarist': {'n_is_sb': '0'},
 'diary keeper': {'n_is_sb': '0'},
 'dias': {'n_is_sb': '2', 'n_is_sth': '2'},
 'diatomophyceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diatom': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diaz': {'n_is_sb': '0'},
 'dibbuk': {'n_is_sb': '0'},
 'dibranchiate mollusk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dibranchiate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dibranch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dicamptodon ensatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dicamptodontidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dicamptodontid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dicamptodon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diceros bicornis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diceros simus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diceros': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dichromat': {'n_is_sb': '0'},
 'dick fosbury': {'n_is_sb': '0'},
 'dick turpin': {'n_is_sb': '0'},
 'dickey-bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dickeybird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dickhead': {'n_is_sb': '0'},
 'dickinson': {'n_is_sb': '0'},
 'dicky-bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dickybird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dicrostonyx hudsonius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dictyoptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dictyopterous insect': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dicynodont': {'n_is_sb': '3', 'n_is_sth': '3'},
 'didelphidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'didelphis marsupialis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'didelphis virginiana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'didelphis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diderot': {'n_is_sb': '0'},
 'didion': {'n_is_sb': '0'},
 'didrikson': {'n_is_sb': '0'},
 'die-sinker': {'n_is_sb': '0'},
 'diego rivera': {'n_is_sb': '0'},
 'diego rodriguez de silva y velazquez': {'n_is_sb': '0'},
 'diegueno': {'n_is_sb': '0'},
 'diemaker': {'n_is_sb': '0'},
 'diesinker': {'n_is_sb': '0'},
 'dietician': {'n_is_sb': '0'},
 'dietitian': {'n_is_sb': '0'},
 'dietrich bonhoeffer': {'n_is_sb': '0'},
 'dietrich': {'n_is_sb': '0'},
 'differentiator': {'n_is_sb': '2', 'n_is_sth': '2'},
 'difflugia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'digger wasp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'digitigrade mammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dihybrid': {'n_is_sb': '2', 'n_is_sth': '2'},
 'dik-dik': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dilettante': {'n_is_sb': '0'},
 'dilly-dallier': {'n_is_sb': '0'},
 'dillydallier': {'n_is_sb': '0'},
 'dimaggio': {'n_is_sb': '0'},
 'dimetrodon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'din land': {'n_is_sb': '0'},
 'dindymene': {'n_is_sb': '0'},
 'dinesen': {'n_is_sb': '0'},
 'dingo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dining companion': {'n_is_sb': '0'},
 'dining-room attendant': {'n_is_sb': '0'},
 'dino paul crocetti': {'n_is_sb': '0'},
 'dinoceras': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dinoflagellate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dinornis giganteus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dinornis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dinornithidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diodon holocanthus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diodon hystrix': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diodora apertura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diogenes': {'n_is_sb': '0'},
 'diomedea exulans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diomedea nigripes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diomedeidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dionysius the elder': {'n_is_sb': '0'},
 'dionysius': {'n_is_sb': '0'},
 'dionysus': {'n_is_sb': '0'},
 'diophantus': {'n_is_sb': '0'},
 'dior': {'n_is_sb': '2', 'n_is_sth': '2'},
 'diphylla ecaudata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diplococcus pneumoniae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diplococcus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diplodocus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diplomate': {'n_is_sb': '0'},
 'diplomatic minister': {'n_is_sb': '0'},
 'diplomatist': {'n_is_sb': '0'},
 'diplopoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dipodidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dipodomys ordi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dipodomys phillipsii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dipodomys': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dipsomaniac': {'n_is_sb': '0'},
 'dipsosaurus dorsalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dipteran': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dipteron': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dipterous insect': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dipus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dirac': {'n_is_sb': '0'},
 'director of central intelligence': {'n_is_sb': '2', 'n_is_sth': '2'},
 'director of research': {'n_is_sb': '0'},
 'dirt ball': {'n_is_sb': '0'},
 'dirty dog': {'n_is_sb': '0'},
 'dirty old man': {'n_is_sb': '0'},
 'disagreeable person': {'n_is_sb': '0'},
 'disagreeable woman': {'n_is_sb': '0'},
 'disarmer': {'n_is_sb': '0'},
 'disbeliever': {'n_is_sb': '0'},
 'disburser': {'n_is_sb': '0'},
 'disc jockey': {'n_is_sb': '0'},
 'disciplinarian': {'n_is_sb': '0'},
 'discoverer': {'n_is_sb': '0'},
 'discriminator': {'n_is_sb': '2', 'n_is_sth': '2'},
 'discussant': {'n_is_sb': '0'},
 'diseased person': {'n_is_sb': '0'},
 'disembodied spirit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'disentangler': {'n_is_sb': '0'},
 'disinfestation officer': {'n_is_sb': '0'},
 'disk jockey': {'n_is_sb': '0'},
 'disparager': {'n_is_sb': '0'},
 'dispatch rider': {'n_is_sb': '0'},
 'displaced person': {'n_is_sb': '0'},
 'disprover': {'n_is_sb': '0'},
 'disputant': {'n_is_sb': '0'},
 'disraeli': {'n_is_sb': '0'},
 'disreputable person': {'n_is_sb': '0'},
 'disseminator': {'n_is_sb': '2', 'n_is_sth': '2'},
 'dissenter': {'n_is_sb': '0'},
 'distortionist': {'n_is_sb': '0'},
 'distributer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'district attorney': {'n_is_sb': '0'},
 'district manager': {'n_is_sb': '0'},
 'disturber': {'n_is_sb': '2', 'n_is_sth': '2'},
 'dis': {'n_is_sb': '0'},
 'ditch digger': {'n_is_sb': '2', 'n_is_sth': '2'},
 'diva': {'n_is_sb': '0'},
 'divergent thinker': {'n_is_sb': '0'},
 'diversionist': {'n_is_sb': '0'},
 'divine messenger': {'n_is_sb': '0'},
 'diviner': {'n_is_sb': '0'},
 'diving duck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'diving petrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'division chrysophyta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'division cyanophyta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'division cynodontia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'division dicynodontia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'division euglenophyta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'division heterokontophyta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'division protista': {'n_is_sb': '3', 'n_is_sth': '3'},
 'divorce lawyer': {'n_is_sb': '0'},
 'divorced man': {'n_is_sb': '0'},
 'divorcee': {'n_is_sb': '0'},
 'dizygotic twin': {'n_is_sb': '0'},
 'dizzy gillespie': {'n_is_sb': '0'},
 'djiboutian': {'n_is_sb': '0'},
 'djinni': {'n_is_sb': '0'},
 'djinny': {'n_is_sb': '0'},
 'dj': {'n_is_sb': '0'},
 'dmitri dmitrievich shostakovich': {'n_is_sb': '0'},
 'dmitri ivanovich mendeleev': {'n_is_sb': '0'},
 'dmitri ivanovich mendeleyev': {'n_is_sb': '0'},
 'dmitri mendeleev': {'n_is_sb': '0'},
 'dmitri mendeleyev': {'n_is_sb': '0'},
 'dmitri shostakovich': {'n_is_sb': '0'},
 'do-gooder': {'n_is_sb': '0'},
 'do-nothing': {'n_is_sb': '0'},
 'doberman pinscher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'doberman': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dobson fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dobsonfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dock worker': {'n_is_sb': '0'},
 'dock-walloper': {'n_is_sb': '0'},
 'docker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'dockhand': {'n_is_sb': '0'},
 'doctor of the church': {'n_is_sb': '0'},
 'doctor-fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'doctorfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'doctorow': {'n_is_sb': '0'},
 'doctrinaire': {'n_is_sb': '0'},
 'dodderer': {'n_is_sb': '0'},
 'dodgson': {'n_is_sb': '0'},
 'dodo': {'n_is_sb': '2', 'n_is_sth': '2'},
 'doe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dog catcher': {'n_is_sb': '0'},
 'dog flea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dog in the manger': {'n_is_sb': '0'},
 'dog-day cicada': {'n_is_sb': '3', 'n_is_sth': '3'},
 'doge': {'n_is_sb': '0'},
 'dogfighter': {'n_is_sb': '0'},
 'dogfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'doggie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'doggy': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dogie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dogmatist': {'n_is_sb': '0'},
 'dogsbody': {'n_is_sb': '0'},
 'dogy': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dolby': {'n_is_sb': '2', 'n_is_sth': '2'},
 'dolichonyx oryzivorus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dolichonyx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dolichotis patagonum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dolichotis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'doliolidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'doliolum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dollarfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dolphinfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'domenikos theotocopoulos': {'n_is_sb': '0'},
 'domestic animal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'domestic ass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'domestic carp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'domestic cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'domestic dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'domestic fowl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'domestic goat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'domestic help': {'n_is_sb': '0'},
 'domestic llama': {'n_is_sb': '3', 'n_is_sth': '3'},
 'domestic partner': {'n_is_sb': '0'},
 'domestic pigeon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'domestic prelate': {'n_is_sb': '0'},
 'domestic sheep': {'n_is_sb': '3', 'n_is_sth': '3'},
 'domestic silkworm moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dominatrix': {'n_is_sb': '0'},
 'dominee': {'n_is_sb': '0'},
 'domine': {'n_is_sb': '0'},
 'domingo de guzman': {'n_is_sb': '0'},
 'domingo': {'n_is_sb': '0'},
 'dominican': {'n_is_sb': '0'},
 'dominick': {'n_is_sb': '0'},
 'dominic': {'n_is_sb': '0'},
 'dominie': {'n_is_sb': '0'},
 'dominique': {'n_is_sb': '3', 'n_is_sth': '3'},
 'domino': {'n_is_sb': '2', 'n_is_sth': '2'},
 'domitian': {'n_is_sb': '0'},
 'don budge': {'n_is_sb': '0'},
 'don juan': {'n_is_sb': '0'},
 'don luchino visconti conte di modrone': {'n_is_sb': '0'},
 'don marquis': {'n_is_sb': '0'},
 'don quixote': {'n_is_sb': '0'},
 "don't-know": {'n_is_sb': '0'},
 'donald arthur glaser': {'n_is_sb': '0'},
 'donald barthelme': {'n_is_sb': '0'},
 'donald duck': {'n_is_sb': '0'},
 'donald glaser': {'n_is_sb': '0'},
 'donald robert perry marquis': {'n_is_sb': '0'},
 'donar': {'n_is_sb': '0'},
 'donatello': {'n_is_sb': '0'},
 'donatist': {'n_is_sb': '0'},
 'donato bramante': {'n_is_sb': '0'},
 "donato d'agnolo bramante": {'n_is_sb': '0'},
 'donato di betto bardi': {'n_is_sb': '0'},
 'donatus': {'n_is_sb': '0'},
 'donee': {'n_is_sb': '0'},
 'donizetti': {'n_is_sb': '0'},
 'donkin': {'n_is_sb': '0'},
 'donna': {'n_is_sb': '0'},
 'donne': {'n_is_sb': '0'},
 'doofus': {'n_is_sb': '0'},
 'doolittle': {'n_is_sb': '0'},
 'door guard': {'n_is_sb': '2', 'n_is_sth': '2'},
 'doormat': {'n_is_sb': '2', 'n_is_sth': '2'},
 'doppelganger': {'n_is_sb': '2', 'n_is_sth': '2'},
 'dorbeetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dorian': {'n_is_sb': '0'},
 'doris lessing': {'n_is_sb': '0'},
 'doris may lessing': {'n_is_sb': '0'},
 'doris': {'n_is_sb': '0'},
 'dorking': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dork': {'n_is_sb': '0'},
 'dormouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'doroteo arango': {'n_is_sb': '0'},
 'dorothea lange': {'n_is_sb': '0'},
 'dorothy dix': {'n_is_sb': '0'},
 'dorothy hodgkin': {'n_is_sb': '0'},
 'dorothy l. sayers': {'n_is_sb': '0'},
 'dorothy leigh sayers': {'n_is_sb': '0'},
 'dorothy mary crowfoot hodgkin': {'n_is_sb': '0'},
 'dorothy parker': {'n_is_sb': '0'},
 'dorothy rothschild parker': {'n_is_sb': '0'},
 'dorothy sayers': {'n_is_sb': '0'},
 'dos passos': {'n_is_sb': '0'},
 'dosser': {'n_is_sb': '0'},
 'dostoevski': {'n_is_sb': '0'},
 'dostoevsky': {'n_is_sb': '0'},
 'dostoyevsky': {'n_is_sb': '0'},
 'dotard': {'n_is_sb': '0'},
 'dotrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dotterel': {'n_is_sb': '2', 'n_is_sth': '2'},
 'double agent': {'n_is_sb': '0'},
 'double dipper': {'n_is_sb': '0'},
 'double-crosser': {'n_is_sb': '0'},
 'double-dealer': {'n_is_sb': '0'},
 'doubter': {'n_is_sb': '0'},
 'doubting thomas': {'n_is_sb': '0'},
 'douglas elton fairbanks': {'n_is_sb': '0'},
 'douglas fairbanks jr.': {'n_is_sb': '0'},
 'douglas fairbanks': {'n_is_sb': '0'},
 'douglas macarthur': {'n_is_sb': '0'},
 'douglas moore': {'n_is_sb': '0'},
 'douglas squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'douglass': {'n_is_sb': '0'},
 'douroucouli': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dovekie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dowding': {'n_is_sb': '0'},
 'dowdy': {'n_is_sb': '0', 'jj_to_jjr': 'dowdier', 'jj_to_jjs': 'dowdiest'},
 'dowitcher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dowland': {'n_is_sb': '0'},
 'down easter': {'n_is_sb': '0'},
 'down-and-out': {'n_is_sb': '0'},
 'downing': {'n_is_sb': '0'},
 'downy woodpecker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dowser': {'n_is_sb': '0'},
 'doyenne': {'n_is_sb': '0'},
 'dp': {'n_is_sb': '0'},
 'dr. johnson': {'n_is_sb': '0'},
 'dr. j': {'n_is_sb': '0'},
 'dr. seuss': {'n_is_sb': '0'},
 'dr.': {'n_is_sb': '0'},
 'dracula': {'n_is_sb': '0'},
 'dracunculus medinensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'draft animal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'draft dodger': {'n_is_sb': '0'},
 'draft evader': {'n_is_sb': '0'},
 'draft horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'draftee': {'n_is_sb': '0'},
 'drafter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'draftsperson': {'n_is_sb': '0'},
 'dragger': {'n_is_sb': '2', 'n_is_sth': '2'},
 'dragoman': {'n_is_sb': '0'},
 'dragon lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dragonet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'drake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'drama critic': {'n_is_sb': '0'},
 'draught horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'draughtsman': {'n_is_sb': '0'},
 'dravidian': {'n_is_sb': '0'},
 'drawee': {'n_is_sb': '0'},
 'drawing card': {'n_is_sb': '2', 'n_is_sth': '2'},
 'drawler': {'n_is_sb': '0'},
 'dray horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'drayhorse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dred scott': {'n_is_sb': '0'},
 'dreiser': {'n_is_sb': '0'},
 'dreissena polymorpha': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dreissena': {'n_is_sb': '3', 'n_is_sth': '3'},
 'drepanis': {'n_is_sb': '3', 'n_is_sth': '3'},
 "dressmaker's model": {'n_is_sb': '0'},
 'drew': {'n_is_sb': '0', 'vbd_to_vb': 'draw', 'vbd_to_vbn': 'drawn'},
 'dreyfus': {'n_is_sb': '0'},
 'dribbler': {'n_is_sb': '0'},
 'driftfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'drill instructor': {'n_is_sb': '0'},
 'drill master': {'n_is_sb': '0'},
 'driveller': {'n_is_sb': '0'},
 'driver ant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dromaeosauridae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dromaeosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dromaius novaehollandiae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'drooler': {'n_is_sb': '0'},
 'dropkicker': {'n_is_sb': '0'},
 'dropout': {'n_is_sb': '0'},
 'drosophila melanogaster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'drosophilidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'drover': {'n_is_sb': '0'},
 'drug addict': {'n_is_sb': '0'},
 'drug baron': {'n_is_sb': '0'},
 'drug dealer': {'n_is_sb': '0'},
 'drug lord': {'n_is_sb': '0'},
 'drug peddler': {'n_is_sb': '0'},
 'drug trafficker': {'n_is_sb': '0'},
 'drug user': {'n_is_sb': '0'},
 'drum majorette': {'n_is_sb': '0'},
 'drum major': {'n_is_sb': '0'},
 'drumbeater': {'n_is_sb': '0'},
 'drumfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'drunk-and-disorderly': {'n_is_sb': '0'},
 'drunken reveler': {'n_is_sb': '0'},
 'drunken reveller': {'n_is_sb': '0'},
 'druse': {'n_is_sb': '0'},
 'druze': {'n_is_sb': '0'},
 'dry cleaner': {'n_is_sb': '2', 'n_is_sth': '2'},
 'dry nurse': {'n_is_sb': '0'},
 'dryad': {'n_is_sb': '0'},
 'dryden': {'n_is_sb': '0'},
 'drymarchon corais couperi': {'n_is_sb': '0'},
 'drymarchon corais': {'n_is_sb': '0'},
 'dryopithecine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dryopithecus rudapithecus hungaricus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dryopithecus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'du barry': {'n_is_sb': '0'},
 'du bois': {'n_is_sb': '0'},
 'du maurier': {'n_is_sb': '0'},
 'dualist': {'n_is_sb': '0'},
 'dubliner': {'n_is_sb': '0'},
 'dubois heyward': {'n_is_sb': '0'},
 'dubya': {'n_is_sb': '0'},
 'dubyuh': {'n_is_sb': '0'},
 "duc d'elchingen": {'n_is_sb': '0'},
 'duc de richelieu': {'n_is_sb': '0'},
 'duc de sully': {'n_is_sb': '0'},
 'duchamp': {'n_is_sb': '0'},
 'duchess of ferrara': {'n_is_sb': '0'},
 'duchess of windsor': {'n_is_sb': '0'},
 'duchesse de valentinois': {'n_is_sb': '0'},
 'duchess': {'n_is_sb': '0'},
 'duck hunter': {'n_is_sb': '0'},
 'duck-billed dinosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'duck-billed platypus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'duckbilled platypus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dudley moore': {'n_is_sb': '0'},
 'dudley stuart john moore': {'n_is_sb': '0'},
 'dueler': {'n_is_sb': '0'},
 'duelist': {'n_is_sb': '0'},
 'dueller': {'n_is_sb': '0'},
 'duellist': {'n_is_sb': '0'},
 'duenna': {'n_is_sb': '0'},
 'dufy': {'n_is_sb': '0'},
 'dugald stewart': {'n_is_sb': '0'},
 'dugong dugon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dugong': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dug': {'n_is_sb': '3', 'n_is_sth': '3', 'vbd_eq_vbn': ''},
 'dukas': {'n_is_sb': '0'},
 'duke ellington': {'n_is_sb': '0'},
 'duke of cumberland': {'n_is_sb': '0'},
 'duke of edinburgh': {'n_is_sb': '0'},
 'duke of marlborough': {'n_is_sb': '0'},
 'duke of wellington': {'n_is_sb': '0'},
 'duke of windsor': {'n_is_sb': '0'},
 'duke wayne': {'n_is_sb': '0'},
 'dulles': {'n_is_sb': '0'},
 'dulse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dumetella carolinensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dumetella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dumuzi': {'n_is_sb': '0'},
 'duncan grant': {'n_is_sb': '0'},
 'duncan james corrow grant': {'n_is_sb': '0'},
 'duncan': {'n_is_sb': '0'},
 'dung beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dungeness crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dunkard': {'n_is_sb': '2', 'n_is_sth': '2'},
 'dunlin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dunnock': {'n_is_sb': '3', 'n_is_sth': '3'},
 'duns scotus': {'n_is_sb': '0'},
 'dun': {'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'dupe': {'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'durante': {'n_is_sb': '0'},
 'durant': {'n_is_sb': '2', 'n_is_sth': '2'},
 'durer': {'n_is_sb': '0'},
 'durga': {'n_is_sb': '0'},
 'durham': {'n_is_sb': '0'},
 'durkheim': {'n_is_sb': '0'},
 'durrell': {'n_is_sb': '0'},
 'duse': {'n_is_sb': '2', 'n_is_sth': '2'},
 'dusicyon cancrivorus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dusicyon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dusky salamander': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dusky shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dusky-footed woodrat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dustin hoffman': {'n_is_sb': '0'},
 'dustman': {'n_is_sb': '0'},
 'dutch leonard': {'n_is_sb': '0'},
 'dutch people': {'n_is_sb': '0'},
 'dutch uncle': {'n_is_sb': '0'},
 'dutch-elm beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'duvalier': {'n_is_sb': '0'},
 'dvorak': {'n_is_sb': '0'},
 'dwarf buffalo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dwarf pipefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dwarf pocket rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dwarf sperm whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dweeb': {'n_is_sb': '0'},
 'dwight d. eisenhower': {'n_is_sb': '0'},
 'dwight david eisenhower': {'n_is_sb': '0'},
 'dwight davis': {'n_is_sb': '0'},
 'dwight eisenhower': {'n_is_sb': '0'},
 'dwight filley davis': {'n_is_sb': '0'},
 'dwight lyman moody': {'n_is_sb': '0'},
 'dyaus-pitar': {'n_is_sb': '0'},
 'dyaus': {'n_is_sb': '0'},
 'dybbuk': {'n_is_sb': '0'},
 'dyer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'dylan marlais thomas': {'n_is_sb': '0'},
 'dylan thomas': {'n_is_sb': '0'},
 'dylan': {'n_is_sb': '0'},
 'dynamiter': {'n_is_sb': '0'},
 'dynamitist': {'n_is_sb': '0'},
 'dynast': {'n_is_sb': '0'},
 'dyspeptic': {'n_is_sb': '0'},
 'dytiscidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'dziggetai': {'n_is_sb': '3', 'n_is_sth': '3'},
 'e. a. von willebrand': {'n_is_sb': '0'},
 'e. b. white': {'n_is_sb': '0'},
 'e. coli': {'n_is_sb': '3', 'n_is_sth': '3'},
 'e. e. cummings': {'n_is_sb': '0'},
 'e. g. marshall': {'n_is_sb': '0'},
 'e. h. harriman': {'n_is_sb': '0'},
 'e. h. weber': {'n_is_sb': '0'},
 'e. l. doctorow': {'n_is_sb': '0'},
 'e. o. lawrence': {'n_is_sb': '0'},
 'e. o. wilson': {'n_is_sb': '0'},
 'e. t. a. hoffmann': {'n_is_sb': '0'},
 'e. t. s. walton': {'n_is_sb': '0'},
 'e. w. morley': {'n_is_sb': '0'},
 'eacles imperialis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eacles': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eadweard muybridge': {'n_is_sb': '0'},
 'eadwig': {'n_is_sb': '0'},
 'eager beaver': {'n_is_sb': '0'},
 'eagle ray': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eagle scout': {'n_is_sb': '0'},
 'eaglet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eames': {'n_is_sb': '0'},
 'eamon de valera': {'n_is_sb': '0'},
 'ear doctor': {'n_is_sb': '0'},
 'ear specialist': {'n_is_sb': '0'},
 'ear-nose-and-throat doctor': {'n_is_sb': '0'},
 'ear-shell': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eared grebe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eared seal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'earhart': {'n_is_sb': '0'},
 'earl marshal': {'n_is_sb': '0'},
 'earl of leicester': {'n_is_sb': '0'},
 'earl of warwick': {'n_is_sb': '0'},
 'earl russell': {'n_is_sb': '0'},
 'earl warren': {'n_is_sb': '0'},
 'earless lizard': {'n_is_sb': '0'},
 'earless seal': {'n_is_sb': '0'},
 'early bird': {'n_is_sb': '0'},
 'earner': {'n_is_sb': '0'},
 'earth mother': {'n_is_sb': '0'},
 'earth-goddess': {'n_is_sb': '0'},
 'earth-god': {'n_is_sb': '0'},
 'earthman': {'n_is_sb': '0'},
 'earwig': {'n_is_sb': '3', 'n_is_sth': '3'},
 'east german': {'n_is_sb': '2', 'n_is_sth': '2'},
 'east-sider': {'n_is_sb': '0'},
 'easter bunny': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eastern chimpanzee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eastern chipmunk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eastern coral snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eastern cottontail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eastern cricket frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eastern dasyure': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eastern fence lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eastern fox squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eastern gray squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eastern ground snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eastern indigo snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eastern kingbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eastern lowland gorilla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eastern meadowlark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eastern narrow-mouthed toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eastern pipistrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eastern red-backed salamander': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eastern sioux': {'n_is_sb': '0'},
 'eastern woodrat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'easterner': {'n_is_sb': '0'},
 'eastman': {'n_is_sb': '0'},
 'easy mark': {'n_is_sb': '0'},
 'eater': {'n_is_sb': '0'},
 'eavesdropper': {'n_is_sb': '0'},
 'ea': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ebionite': {'n_is_sb': '0'},
 'eblis': {'n_is_sb': '0'},
 'ebola virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ebv': {'n_is_sb': '2', 'n_is_sth': '2'},
 'eccentric person': {'n_is_sb': '0'},
 'ecclesiastic': {'n_is_sb': '0'},
 'eccles': {'n_is_sb': '0'},
 'ecdysiast': {'n_is_sb': '0'},
 'echeneis naucrates': {'n_is_sb': '3', 'n_is_sth': '3'},
 'echidnophaga gallinacea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'echinococcus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'echinoderm family': {'n_is_sb': '3', 'n_is_sth': '3'},
 'echinodermata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'echinoderm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'echinoidea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'echinus esculentus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'echovirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eckhart': {'n_is_sb': '0'},
 'eclecticist': {'n_is_sb': '0'},
 'eclectic': {'n_is_sb': '0'},
 'ecologist': {'n_is_sb': '0'},
 'econometrician': {'n_is_sb': '0'},
 'econometrist': {'n_is_sb': '0'},
 'economic expert': {'n_is_sb': '0'},
 'economiser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'economizer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ecrevisse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ectomorph': {'n_is_sb': '0'},
 'ectoparasite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ectopistes migratorius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ectoprocta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ectoproct': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ectotherm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ectozoan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ectozoon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ecuadoran': {'n_is_sb': '0'},
 'ed sullivan': {'n_is_sb': '0'},
 'edaphosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eddie rickenbacker': {'n_is_sb': '0'},
 'eddington': {'n_is_sb': '0'},
 'eddy merckx': {'n_is_sb': '0'},
 'edentate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ederle': {'n_is_sb': '0'},
 'edgar albert guest': {'n_is_sb': '0'},
 'edgar allen poe': {'n_is_sb': '0'},
 'edgar douglas adrian': {'n_is_sb': '0'},
 'edgar guest': {'n_is_sb': '0'},
 'edgar lee masters': {'n_is_sb': '0'},
 'edgar rice burroughs': {'n_is_sb': '0'},
 'edgar wallace': {'n_is_sb': '0'},
 'edgard lawrence doctorow': {'n_is_sb': '0'},
 'edgard varese': {'n_is_sb': '0'},
 'edgar': {'n_is_sb': '0'},
 'edger': {'n_is_sb': '0'},
 'edible cockle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'edible mussel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'edible sea urchin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'edible snail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'edith cavell': {'n_is_sb': '0'},
 'edith giovanna gassion': {'n_is_sb': '0'},
 'edith louisa cavell': {'n_is_sb': '0'},
 'edith newbold jones wharton': {'n_is_sb': '0'},
 'edith piaf': {'n_is_sb': '0'},
 'edith wharton': {'n_is_sb': '0'},
 'editor in chief': {'n_is_sb': '0'},
 'editorialist': {'n_is_sb': '0'},
 'edmond de goncourt': {'n_is_sb': '0'},
 'edmond halley': {'n_is_sb': '0'},
 'edmond hoyle': {'n_is_sb': '0'},
 'edmond louis antoine huot de goncourt': {'n_is_sb': '0'},
 'edmond malone': {'n_is_sb': '0'},
 'edmond rostand': {'n_is_sb': '0'},
 'edmontonia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'edmontosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'edmund burke': {'n_is_sb': '0'},
 'edmund cartwright': {'n_is_sb': '0'},
 'edmund charles edouard genet': {'n_is_sb': '0'},
 'edmund halley': {'n_is_sb': '0'},
 'edmund hillary': {'n_is_sb': '0'},
 'edmund husserl': {'n_is_sb': '0'},
 'edmund ii': {'n_is_sb': '0'},
 'edmund ironside': {'n_is_sb': '0'},
 'edmund i': {'n_is_sb': '0'},
 'edmund john millington synge': {'n_is_sb': '0'},
 'edmund kean': {'n_is_sb': '0'},
 'edmund malone': {'n_is_sb': '0'},
 'edmund spenser': {'n_is_sb': '0'},
 'edmund wilson': {'n_is_sb': '0'},
 'edna ferber': {'n_is_sb': '0'},
 'edna millay': {'n_is_sb': '0'},
 "edna o'brien": {'n_is_sb': '0'},
 'edna saint vincent millay': {'n_is_sb': '0'},
 'edouard lemaitre': {'n_is_sb': '0'},
 'edouard manet': {'n_is_sb': '0'},
 'edouard vuillard': {'n_is_sb': '0'},
 'edo': {'n_is_sb': '0'},
 'edsel bryant ford': {'n_is_sb': '0'},
 'eduard buchner': {'n_is_sb': '0'},
 'educatee': {'n_is_sb': '0'},
 'education secretary': {'n_is_sb': '0'},
 'educationalist': {'n_is_sb': '0'},
 'educationist': {'n_is_sb': '0'},
 'edvard grieg': {'n_is_sb': '0'},
 'edvard hagerup grieg': {'n_is_sb': '0'},
 'edvard munch': {'n_is_sb': '0'},
 'edward albee': {'n_is_sb': '0'},
 'edward antony richard louis': {'n_is_sb': '0'},
 'edward appleton': {'n_is_sb': '0'},
 'edward benjamin britten': {'n_is_sb': '0'},
 'edward bouverie pusey': {'n_is_sb': '0'},
 'edward calvin kendall': {'n_is_sb': '0'},
 'edward durell stone': {'n_is_sb': '0'},
 'edward estlin cummings': {'n_is_sb': '0'},
 'edward everett hale': {'n_is_sb': '0'},
 'edward fitzgerald': {'n_is_sb': '0'},
 'edward franklin albeen': {'n_is_sb': '0'},
 'edward g. robinson': {'n_is_sb': '0'},
 'edward george earle bulwer-lytton': {'n_is_sb': '0'},
 'edward gibbon': {'n_is_sb': '0'},
 'edward goldenberg robinson': {'n_is_sb': '0'},
 'edward henry harriman': {'n_is_sb': '0'},
 'edward iii': {'n_is_sb': '0'},
 'edward ii': {'n_is_sb': '0'},
 'edward iv': {'n_is_sb': '0'},
 'edward i': {'n_is_sb': '0'},
 'edward james hughes': {'n_is_sb': '0'},
 'edward james muggeridge': {'n_is_sb': '0'},
 'edward jean steichen': {'n_is_sb': '0'},
 'edward jenner': {'n_is_sb': '0'},
 'edward kendall': {'n_is_sb': '0'},
 'edward kennedy ellington': {'n_is_sb': '0'},
 'edward lawrie tatum': {'n_is_sb': '0'},
 'edward lear': {'n_is_sb': '0'},
 'edward lee thorndike': {'n_is_sb': '0'},
 'edward macdowell': {'n_is_sb': '0'},
 'edward morley': {'n_is_sb': '0'},
 'edward osborne wilson': {'n_is_sb': '0'},
 'edward pusey': {'n_is_sb': '0'},
 'edward r. murrow': {'n_is_sb': '0'},
 'edward roscoe murrow': {'n_is_sb': '0'},
 'edward sapir': {'n_is_sb': '0'},
 'edward teach': {'n_is_sb': '0'},
 'edward teller': {'n_is_sb': '0'},
 'edward thatch': {'n_is_sb': '0'},
 'edward the confessor': {'n_is_sb': '0'},
 'edward the elder': {'n_is_sb': '0'},
 'edward the martyr': {'n_is_sb': '0'},
 'edward vernon rickenbacker': {'n_is_sb': '0'},
 'edward viii': {'n_is_sb': '0'},
 'edward vii': {'n_is_sb': '0'},
 'edward vincent sullivan': {'n_is_sb': '0'},
 'edward vi': {'n_is_sb': '0'},
 'edward v': {'n_is_sb': '0'},
 'edward weston': {'n_is_sb': '0'},
 'edward williams morley': {'n_is_sb': '0'},
 'edward winslow': {'n_is_sb': '0'},
 'edward wyllis scripps': {'n_is_sb': '0'},
 'edward young': {'n_is_sb': '0'},
 'edwardian': {'n_is_sb': '0', 'cap_word': 'Edwardian'},
 'edwards': {'n_is_sb': '0'},
 'edward': {'n_is_sb': '0'},
 'edwin arlington robinson': {'n_is_sb': '0'},
 'edwin dubois hayward': {'n_is_sb': '0'},
 'edwin herbert land': {'n_is_sb': '0'},
 'edwin hubble': {'n_is_sb': '0'},
 'edwin powell hubble': {'n_is_sb': '0'},
 'edwin': {'n_is_sb': '0'},
 'edwy': {'n_is_sb': '0'},
 'eelblenny': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eelpout': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eelworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eero saarinen': {'n_is_sb': '0'},
 'effecter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'effector': {'n_is_sb': '2', 'n_is_sth': '2'},
 'effendi': {'n_is_sb': '0'},
 'efficiency engineer': {'n_is_sb': '0'},
 'efficiency expert': {'n_is_sb': '0'},
 'efrem zimbalist': {'n_is_sb': '0'},
 'eft': {'n_is_sb': '3', 'n_is_sth': '3'},
 'egalitarian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'egbert': {'n_is_sb': '0'},
 'egg-laying mammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eggar': {'n_is_sb': '3', 'n_is_sth': '3'},
 'egger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'egocentric': {'n_is_sb': '0'},
 'egoist': {'n_is_sb': '0'},
 'egomaniac': {'n_is_sb': '0'},
 'egotist': {'n_is_sb': '0'},
 'egretta albus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'egretta caerulea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'egretta garzetta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'egretta thula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'egretta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'egyptian cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'egyptian cobra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'egyptian deity': {'n_is_sb': '0'},
 'egyptian vulture': {'n_is_sb': '3', 'n_is_sth': '3'},
 'egyptologist': {'n_is_sb': '0'},
 'ehrenberg': {'n_is_sb': '0'},
 'ehrlich': {'n_is_sb': '0'},
 'eichmann': {'n_is_sb': '0'},
 'eider duck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eider': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eiffel': {'n_is_sb': '0'},
 'eigen': {'n_is_sb': '0'},
 'eijkman': {'n_is_sb': '0'},
 'eileen farrell': {'n_is_sb': '0'},
 'eimeria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'einthoven': {'n_is_sb': '0'},
 'eira barbara': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eira': {'n_is_sb': '2', 'n_is_sth': '2'},
 'eisenhower': {'n_is_sb': '0'},
 'eisenstaedt': {'n_is_sb': '2', 'n_is_sth': '2'},
 'eisenstein': {'n_is_sb': '0'},
 'ejaculator': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ekman': {'n_is_sb': '0'},
 'el caudillo': {'n_is_sb': '0'},
 'el cid': {'n_is_sb': '0'},
 'el greco': {'n_is_sb': '0'},
 'el libertador': {'n_is_sb': '0'},
 'el nino': {'n_is_sb': '2', 'n_is_sth': '2'},
 'elagatis bipinnulata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elamite': {'n_is_sb': '0'},
 'eland': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elanoides forficatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elanoides': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elanus leucurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elaphe guttata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elaphe obsoleta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elaphe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elaphure': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elaphurus davidianus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elaphurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elapid snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elapid': {'n_is_sb': '0'},
 'elasmobranch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elaterid beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elateridae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elater': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elder hand': {'n_is_sb': '0'},
 'elder statesman': {'n_is_sb': '0'},
 'eldest hand': {'n_is_sb': '0'},
 'eldest': {'n_is_sb': '0'},
 'eleanor gwynne': {'n_is_sb': '0'},
 'eleanor gwynn': {'n_is_sb': '0'},
 'eleanor gwyn': {'n_is_sb': '0'},
 'eleanor of aquitaine': {'n_is_sb': '0'},
 'eleanor roosevelt': {'n_is_sb': '0'},
 'elected official': {'n_is_sb': '0'},
 'electra': {'n_is_sb': '0'},
 'electric catfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'electric eel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'electric ray': {'n_is_sb': '3', 'n_is_sth': '3'},
 'electrical engineer': {'n_is_sb': '0'},
 'electrocutioner': {'n_is_sb': '0'},
 'electrologist': {'n_is_sb': '0'},
 'electrophorus electric': {'n_is_sb': '3', 'n_is_sth': '3'},
 'electroplater': {'n_is_sb': '2', 'n_is_sth': '2'},
 'electrotherapist': {'n_is_sb': '0'},
 'elegist': {'n_is_sb': '0'},
 'eleonora duse': {'n_is_sb': '0'},
 'elephant bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elephant seal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elephas maximus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eleutherodactylus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elevator boy': {'n_is_sb': '0'},
 'elevator girl': {'n_is_sb': '0'},
 'elevator man': {'n_is_sb': '0'},
 'elevator operator': {'n_is_sb': '0'},
 'elgar': {'n_is_sb': '0'},
 'eli whitney': {'n_is_sb': '0'},
 'elias canetti': {'n_is_sb': '0'},
 'elias howe': {'n_is_sb': '0'},
 'elia': {'n_is_sb': '0'},
 'elie metchnikoff': {'n_is_sb': '0'},
 'elie metchnikov': {'n_is_sb': '0'},
 'elie wiesel': {'n_is_sb': '0'},
 'eliel saarinen': {'n_is_sb': '0'},
 'eliezer wiesel': {'n_is_sb': '0'},
 'elihu thomson': {'n_is_sb': '0'},
 'elihu yale': {'n_is_sb': '0'},
 'elijah muhammad': {'n_is_sb': '0'},
 'elijah': {'n_is_sb': '0'},
 'elinor morton hoyt wylie': {'n_is_sb': '0'},
 'eliomys': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eliot': {'n_is_sb': '0'},
 'elisabeth vigee-lebrun': {'n_is_sb': '0'},
 'elisha graves otis': {'n_is_sb': '0'},
 'elitist': {'n_is_sb': '0'},
 'elizabeth barrett browning': {'n_is_sb': '0'},
 'elizabeth cady stanton': {'n_is_sb': '0'},
 'elizabeth cleghorn stevenson gaskell': {'n_is_sb': '0'},
 'elizabeth cochrane seaman': {'n_is_sb': '0'},
 'elizabeth gaskell': {'n_is_sb': '0'},
 'elizabeth haldane': {'n_is_sb': '0'},
 'elizabeth ii': {'n_is_sb': '0'},
 'elizabeth i': {'n_is_sb': '0'},
 'elizabeth merriwether gilmer': {'n_is_sb': '0'},
 'elizabeth palmer peabody': {'n_is_sb': '0'},
 'elizabeth peabody': {'n_is_sb': '0'},
 'elizabeth sanderson haldane': {'n_is_sb': '0'},
 'elizabeth seaman': {'n_is_sb': '0'},
 'elizabeth seton': {'n_is_sb': '0'},
 'elizabeth taylor': {'n_is_sb': '0'},
 'elkhound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ella fitzgerald': {'n_is_sb': '0'},
 'ellen price wood': {'n_is_sb': '0'},
 'ellington': {'n_is_sb': '0'},
 'ellison': {'n_is_sb': '0'},
 'elli': {'n_is_sb': '0'},
 'elmer ambrose sperry': {'n_is_sb': '0'},
 'elmer leopold rice': {'n_is_sb': '0'},
 'elmer reizenstein': {'n_is_sb': '0'},
 'elmer rice': {'n_is_sb': '0'},
 'elmore john leonard': {'n_is_sb': '0'},
 'elmore leonard': {'n_is_sb': '0'},
 'elocutionist': {'n_is_sb': '0'},
 'elops saurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elops': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elsa schiaparelli': {'n_is_sb': '0'},
 'elver': {'n_is_sb': '3', 'n_is_sth': '3'},
 'elvis aron presley': {'n_is_sb': '0'},
 'elvis presley': {'n_is_sb': '0'},
 'elwyn brooks white': {'n_is_sb': '0'},
 'ely culbertson': {'n_is_sb': '0'},
 'elytron': {'n_is_sb': '3', 'n_is_sth': '3'},
 'emancipationist': {'n_is_sb': '0'},
 'emanuel svedberg': {'n_is_sb': '0'},
 'emanuel swedenborg': {'n_is_sb': '0'},
 'embalmer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'embassador': {'n_is_sb': '0'},
 'emberiza aureola': {'n_is_sb': '3', 'n_is_sth': '3'},
 'emberiza citrinella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'emberiza hortulana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'emberiza schoeniclus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'embroideress': {'n_is_sb': '0'},
 'emeer': {'n_is_sb': '0'},
 'emerald shiner': {'n_is_sb': '3', 'n_is_sth': '3'},
 'emerson': {'n_is_sb': '0'},
 'emigree': {'n_is_sb': '0'},
 'emil hermann fischer': {'n_is_sb': '0'},
 'emil klaus julius fuchs': {'n_is_sb': '0'},
 'emile durkheim': {'n_is_sb': '0'},
 'emile gaboriau': {'n_is_sb': '0'},
 'emile herzog': {'n_is_sb': '0'},
 'emile zola': {'n_is_sb': '0'},
 'emile': {'n_is_sb': '0'},
 'emiliano zapata': {'n_is_sb': '0'},
 'emilie charlotte le breton': {'n_is_sb': '0'},
 'emily bronte': {'n_is_sb': '0'},
 'emily dickinson': {'n_is_sb': '0'},
 'emily jane bronte': {'n_is_sb': '0'},
 'emily post': {'n_is_sb': '0'},
 'emily price post': {'n_is_sb': '0'},
 'eminence grise': {'n_is_sb': '0'},
 'emma goldman': {'n_is_sb': '0'},
 'emma hart willard': {'n_is_sb': '0'},
 'emmett kelly': {'n_is_sb': '0'},
 'emmy noether': {'n_is_sb': '0'},
 'emotional person': {'n_is_sb': '0'},
 'empedocles': {'n_is_sb': '0'},
 'emperor butterfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'emperor francis ii': {'n_is_sb': '0'},
 'emperor moth': {'n_is_sb': '0'},
 'emperor napoleon iii': {'n_is_sb': '0'},
 'emperor of rome': {'n_is_sb': '0'},
 'emperor penguin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'employment agent': {'n_is_sb': '0'},
 'emptor': {'n_is_sb': '0'},
 'empty nester': {'n_is_sb': '0'},
 'emu novaehollandiae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'en-lil': {'n_is_sb': '0'},
 'enate': {'n_is_sb': '0'},
 'enchanter': {'n_is_sb': '0'},
 'encroacher': {'n_is_sb': '0'},
 'encyclopaedist': {'n_is_sb': '0'},
 'encyclopedist': {'n_is_sb': '0'},
 'end man': {'n_is_sb': '0'},
 'end user': {'n_is_sb': '0'},
 'endameba': {'n_is_sb': '2', 'n_is_sth': '2'},
 'endamoeba histolytica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'endamoeba': {'n_is_sb': '3', 'n_is_sth': '3'},
 'endecott': {'n_is_sb': '0'},
 'endocrinologist': {'n_is_sb': '0'},
 'endodontist': {'n_is_sb': '2', 'n_is_sth': '2'},
 'endomorph': {'n_is_sb': '0'},
 'endoparasite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'endoprocta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'endorser': {'n_is_sb': '0'},
 'endospore-forming bacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'endozoan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'enea silvio piccolomini': {'n_is_sb': '0'},
 'energiser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'energizer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'energy secretary': {'n_is_sb': '0'},
 'enesco': {'n_is_sb': '0'},
 'enfant terrible': {'n_is_sb': '0'},
 'enforcer': {'n_is_sb': '0'},
 'engelbert humperdinck': {'n_is_sb': '0'},
 'engine driver': {'n_is_sb': '0'},
 'english bulldog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'english cocker spaniel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'english foxhound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'english lady crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'english people': {'n_is_sb': '0'},
 'english person': {'n_is_sb': '0'},
 'english professor': {'n_is_sb': '0'},
 'english setter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'english sole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'english sparrow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'english springer spaniel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'english springer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'english teacher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'english toy spaniel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'englishwoman': {'n_is_sb': '0'},
 'engraulis encrasicholus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'engraulis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'enhydra lutris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'enhydra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'enjoyer': {'n_is_sb': '0'},
 'enkidu': {'n_is_sb': '0'},
 'enki': {'n_is_sb': '0'},
 'enlil': {'n_is_sb': '0'},
 'enlisted man': {'n_is_sb': '0'},
 'enlisted person': {'n_is_sb': '0'},
 'enlisted woman': {'n_is_sb': '0'},
 'enlistee': {'n_is_sb': '0'},
 'enologist': {'n_is_sb': '0'},
 'enquirer': {'n_is_sb': '0'},
 'enrico caruso': {'n_is_sb': '0'},
 'enrico fermi': {'n_is_sb': '0'},
 'enrollee': {'n_is_sb': '0'},
 'ensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ent man': {'n_is_sb': '0'},
 'entellus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'enteric bacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'enterics': {'n_is_sb': '3', 'n_is_sth': '3'},
 'enterobacteriaceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'enterobacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'enterobius vermicularis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'enterobius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'enterovirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'enterpriser': {'n_is_sb': '0'},
 'entomologist': {'n_is_sb': '0'},
 'entoparasite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'entoprocta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'entoproct': {'n_is_sb': '3', 'n_is_sth': '3'},
 'entozoan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'entozoon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'enuki': {'n_is_sb': '0'},
 'enumerator': {'n_is_sb': '2', 'n_is_sth': '2'},
 'environmentalist': {'n_is_sb': '0'},
 'envoy extraordinary': {'n_is_sb': '0'},
 'enzymologist': {'n_is_sb': '0'},
 'eohippus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eolian': {'n_is_sb': '0'},
 'eoraptor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eos': {'n_is_sb': '0'},
 'eparch': {'n_is_sb': '0'},
 'ephemera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ephemerid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ephemeron': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ephemeroptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ephesian': {'n_is_sb': '0'},
 'ephestia elutella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ephestia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ephippiorhynchus senegalensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ephippiorhynchus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'epicine person': {'n_is_sb': '0'},
 'epicine': {'n_is_sb': '0'},
 'epictetus': {'n_is_sb': '0'},
 'epicurus': {'n_is_sb': '0'},
 'epidemiologist': {'n_is_sb': '0'},
 'epigone': {'n_is_sb': '0'},
 'epigon': {'n_is_sb': '0'},
 'epilachna varivestis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'epilachna': {'n_is_sb': '3', 'n_is_sth': '3'},
 'epileptic': {'n_is_sb': '0'},
 'epimetheus': {'n_is_sb': '0'},
 'epinephelus adscensionis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'epinephelus fulvus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'epinephelus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'episcopalian': {'n_is_sb': '0'},
 'epistemologist': {'n_is_sb': '0'},
 'epizoan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'epizoon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'epona': {'n_is_sb': '0'},
 'epstein-barr virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'epstein': {'n_is_sb': '0'},
 'eptesicus fuscus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eptesicus serotinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eptesicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'equalitarian': {'n_is_sb': '0'},
 'equerry': {'n_is_sb': '0'},
 'equetus lanceolatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'equetus pulcher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'equetus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'equidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'equid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'equivocator': {'n_is_sb': '0'},
 'equus asinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'equus burchelli': {'n_is_sb': '3', 'n_is_sth': '3'},
 'equus caballus gomelini': {'n_is_sb': '3', 'n_is_sth': '3'},
 'equus caballus przevalskii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'equus caballus przewalskii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'equus caballus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'equus grevyi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'equus hemionus hemionus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'equus hemionus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'equus kiang': {'n_is_sb': '3', 'n_is_sth': '3'},
 'equus quagga': {'n_is_sb': '3', 'n_is_sth': '3'},
 'equus zebra zebra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eradicator': {'n_is_sb': '2', 'n_is_sth': '2'},
 'erasmus': {'n_is_sb': '0'},
 'eratosthenes': {'n_is_sb': '0'},
 'erato': {'n_is_sb': '0'},
 'erebus': {'n_is_sb': '0'},
 'eremite': {'n_is_sb': '0'},
 'eresh-kigal': {'n_is_sb': '0'},
 'ereshkigal': {'n_is_sb': '0'},
 'ereshkigel': {'n_is_sb': '0'},
 'erethizon dorsatum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'erethizon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eretmochelys imbricata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eretmochelys': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eric arthur blair': {'n_is_sb': '0'},
 'eric blair': {'n_is_sb': '0'},
 'erica jong': {'n_is_sb': '0'},
 'erich mendelsohn': {'n_is_sb': '0'},
 'erich von stroheim': {'n_is_sb': '0'},
 'erignathus barbatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'erik adolf von willebrand': {'n_is_sb': '0'},
 'erik alfred leslie satie': {'n_is_sb': '0'},
 'erik axel karlfeldt': {'n_is_sb': '0'},
 'erik satie': {'n_is_sb': '0'},
 'erik von willebrand': {'n_is_sb': '0'},
 'erik weisz': {'n_is_sb': '0'},
 'erinaceus europaeus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'erinaceus europeaeus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'erinyes': {'n_is_sb': '0'},
 'eriosoma lanigerum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eriosoma': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eristic': {'n_is_sb': '2', 'n_is_sth': '2'},
 'eris': {'n_is_sb': '0'},
 'erithacus rubecola': {'n_is_sb': '3', 'n_is_sth': '3'},
 'erithacus svecicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eritrean': {'n_is_sb': '0'},
 'erle stanley gardner': {'n_is_sb': '0'},
 'erlenmeyer': {'n_is_sb': '0'},
 'ernest bevin': {'n_is_sb': '0'},
 'ernest bloch': {'n_is_sb': '0'},
 'ernest hemingway': {'n_is_sb': '0'},
 'ernest orlando lawrence': {'n_is_sb': '0'},
 'ernest rutherford': {'n_is_sb': '0'},
 'ernest solvay': {'n_is_sb': '0'},
 'ernest thomas sinton walton': {'n_is_sb': '0'},
 'ernest walton': {'n_is_sb': '0'},
 'ernestine schumann-heink': {'n_is_sb': '0'},
 'ernesto guevara': {'n_is_sb': '0'},
 'erne': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ernst boris chain': {'n_is_sb': '0'},
 'ernst cassirer': {'n_is_sb': '0'},
 'ernst heinrich haeckel': {'n_is_sb': '0'},
 'ernst heinrich weber': {'n_is_sb': '0'},
 'ernst lubitsch': {'n_is_sb': '0'},
 'ernst ludwig kirchner': {'n_is_sb': '0'},
 'ernst mach': {'n_is_sb': '0'},
 'ernst theodor amadeus hoffmann': {'n_is_sb': '0'},
 'ernst theodor wilhelm hoffmann': {'n_is_sb': '0'},
 'ernst werner von siemens': {'n_is_sb': '0'},
 'ernst': {'n_is_sb': '0'},
 'ern': {'n_is_sb': '3', 'n_is_sth': '3'},
 'erolia alpina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'erolia minutilla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'errand boy': {'n_is_sb': '0'},
 'erskine caldwell': {'n_is_sb': '0'},
 'erskine preston caldwell': {'n_is_sb': '0'},
 'erving': {'n_is_sb': '0'},
 'erwin panofsky': {'n_is_sb': '0'},
 'erwin rommel': {'n_is_sb': '0'},
 'erwin schrodinger': {'n_is_sb': '0'},
 'erwinia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'erythrocebus patas': {'n_is_sb': '3', 'n_is_sth': '3'},
 'erythrocebus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'esaki': {'n_is_sb': '0'},
 'esau': {'n_is_sb': '0'},
 'escalader': {'n_is_sb': '2', 'n_is_sth': '2'},
 'escallop': {'n_is_sb': '3', 'n_is_sth': '3'},
 'escape expert': {'n_is_sb': '0'},
 'escapist': {'n_is_sb': '0'},
 'escapologist': {'n_is_sb': '0'},
 'eschatologist': {'n_is_sb': '2', 'n_is_sth': '2'},
 'escherichia coli': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eschrichtius gibbosus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eschrichtius robustus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'escolar': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eskimo curlew': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eskimo dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eskimo': {'n_is_sb': '0'},
 'esme stuart lennox robinson': {'n_is_sb': '0'},
 'esocidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'esox americanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'esox lucius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'esox masquinongy': {'n_is_sb': '3', 'n_is_sth': '3'},
 'esox niger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'espionage agent': {'n_is_sb': '0'},
 'esquimau': {'n_is_sb': '0'},
 'esq': {'n_is_sb': '0'},
 'esselen': {'n_is_sb': '0'},
 'essene': {'n_is_sb': '0'},
 'estate agent': {'n_is_sb': '0'},
 'esther hobart mcquigg slack morris': {'n_is_sb': '0'},
 'esther morris': {'n_is_sb': '0'},
 'esther': {'n_is_sb': '0'},
 'estimator': {'n_is_sb': '0'},
 'etcher': {'n_is_sb': '0'},
 'ethan allen': {'n_is_sb': '0'},
 'ethel barrymore': {'n_is_sb': '0'},
 'ethel merman': {'n_is_sb': '0'},
 'ethel waters': {'n_is_sb': '0'},
 'ethelbert': {'n_is_sb': '0'},
 'ethelred ii': {'n_is_sb': '0'},
 'ethelred i': {'n_is_sb': '0'},
 'ethelred the unready': {'n_is_sb': '0'},
 'ethelred': {'n_is_sb': '0'},
 'ethician': {'n_is_sb': '0'},
 'ethicist': {'n_is_sb': '0'},
 'ethnographer': {'n_is_sb': '0'},
 'ethnologist': {'n_is_sb': '0'},
 'ethologist': {'n_is_sb': '0'},
 'etienne-louis arthur fallot': {'n_is_sb': '0'},
 'etiologist': {'n_is_sb': '0'},
 'etonian': {'n_is_sb': '0'},
 'etropus rimosus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'etruscan': {'n_is_sb': '0', 'cap_word': 'Etruscan'},
 'etymologist': {'n_is_sb': '0'},
 'euarctos americanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'euarctos': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eubacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eubacterium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eucaryote': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eucinostomus gula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'euclid': {'n_is_sb': '0'},
 'eudaemon': {'n_is_sb': '0'},
 'eudemon': {'n_is_sb': '0'},
 'euderma maculata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eudora welty': {'n_is_sb': '0'},
 'eudromias morinellus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eugene curran kelly': {'n_is_sb': '0'},
 'eugene delacroix': {'n_is_sb': '0'},
 "eugene gladstone o'neill": {'n_is_sb': '0'},
 'eugene ionesco': {'n_is_sb': '0'},
 'eugene luther vidal': {'n_is_sb': '0'},
 "eugene o'neill": {'n_is_sb': '0'},
 'eugene ormandy': {'n_is_sb': '0'},
 'eugene paul wigner': {'n_is_sb': '0'},
 'eugene sue': {'n_is_sb': '0'},
 'eugene v. debs': {'n_is_sb': '0'},
 'eugene victor debs': {'n_is_sb': '0'},
 'eugene wigner': {'n_is_sb': '0'},
 'eugenio pacelli': {'n_is_sb': '0'},
 'euglena': {'n_is_sb': '3', 'n_is_sth': '3'},
 'euglenid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'euglenoid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'euglenophyceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'euglenophyta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'euglenophyte': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eukaryote': {'n_is_sb': '3', 'n_is_sth': '3'},
 'euler': {'n_is_sb': '0'},
 'eumeces callicephalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eumeces skiltonianus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eumeces': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eumenes': {'n_is_sb': '0'},
 'eumenides': {'n_is_sb': '0'},
 'eumetopias jubatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eunectes murinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eunectes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'euopean hoopoe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'euphagus carilonus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'euphagus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'euphausia pacifica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'euphausiacea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'euphractus sexcinctus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'euphractus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'euphrosyne': {'n_is_sb': '0'},
 'euproctis chrysorrhoea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'euproctis phaeorrhoea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eurafrican': {'n_is_sb': '0'},
 'eurasian badger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eurasian green toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eurasian hamster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eurasian kingfisher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eurasian otter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eurasian woodcock': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eurasian': {'n_is_sb': '0', 'cap_word': 'Eurasian'},
 'euripides': {'n_is_sb': '0'},
 'euronithopoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'euronithopod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european bittern': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european black grouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european blackbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european bream': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european brown bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european catfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european corn borer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european creeper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european cuckoo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european curlew': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european elk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european fire salamander': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european flatfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european gallinule': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european goatsucker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european hare': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european house cricket': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european lemming': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european lobster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european magpie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european nightjar': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european nuthatch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european perch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european rabbit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european roller': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european sandpiper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european sea bream': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european sea eagle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european shrike': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european smelt': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european sole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european spider crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european swift': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european tortoise': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european water ouzel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european water shrew': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european wildcat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european wolf spider': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european wood mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'european': {'n_is_sb': '0', 'cap_word': 'European'},
 'euryale': {'n_is_sb': '0'},
 'eurydice': {'n_is_sb': '0'},
 'eurypterid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eusebius hieronymus': {'n_is_sb': '0'},
 'eusebius of caesarea': {'n_is_sb': '0'},
 'eusebius sophronius hieronymus': {'n_is_sb': '0'},
 'eusebius': {'n_is_sb': '0'},
 'eustachio': {'n_is_sb': '0'},
 'eutamias': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eutamius asiaticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eutamius sibiricus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'euterpe': {'n_is_sb': '0'},
 'eutherian mammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eutherian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'euthynnus pelamis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eva braun': {'n_is_sb': '0'},
 'eva le gallienne': {'n_is_sb': '0'},
 'evacuee': {'n_is_sb': '0'},
 'evaluator': {'n_is_sb': '2', 'n_is_sth': '2'},
 'evangelista torricelli': {'n_is_sb': '0'},
 'evangelist': {'n_is_sb': '0'},
 'evans': {'n_is_sb': '0'},
 'evariste galois': {'n_is_sb': '0'},
 'evelyn arthur saint john waugh': {'n_is_sb': '0'},
 'evelyn waugh': {'n_is_sb': '0'},
 'even-toed ungulate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'evening grosbeak': {'n_is_sb': '3', 'n_is_sth': '3'},
 'evenki': {'n_is_sb': '0'},
 'evenk': {'n_is_sb': '0'},
 'event planner': {'n_is_sb': '0'},
 'evers': {'n_is_sb': '0'},
 'evert': {'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'evil spirit': {'n_is_sb': '0'},
 'ewenki': {'n_is_sb': '0'},
 'ewe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ex-gambler': {'n_is_sb': '0'},
 'ex-mayor': {'n_is_sb': '0'},
 'ex-president': {'n_is_sb': '0'},
 'ex-serviceman': {'n_is_sb': '0'},
 'ex-spouse': {'n_is_sb': '0'},
 'exaeretodon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'examinee': {'n_is_sb': '0'},
 'exarch': {'n_is_sb': '0'},
 'exboyfriend': {'n_is_sb': '0'},
 'exchanger': {'n_is_sb': '2', 'n_is_sth': '2'},
 'exciseman': {'n_is_sb': '0'},
 'excogitator': {'n_is_sb': '0'},
 'excursionist': {'n_is_sb': '0'},
 'excuser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'executant': {'n_is_sb': '0'},
 'executive director': {'n_is_sb': '0'},
 'executive officer': {'n_is_sb': '0'},
 'executive secretary': {'n_is_sb': '0'},
 'executive vice president': {'n_is_sb': '0'},
 'executrix': {'n_is_sb': '0'},
 'exegete': {'n_is_sb': '0'},
 'exhibitioner': {'n_is_sb': '0'},
 'exhibitionist': {'n_is_sb': '0'},
 'exhibitor': {'n_is_sb': '0'},
 'existentialist': {'n_is_sb': '0'},
 'exmoor': {'n_is_sb': '2', 'n_is_sth': '2'},
 'exodontist': {'n_is_sb': '0'},
 'exorciser': {'n_is_sb': '0'},
 'exorcist': {'n_is_sb': '0'},
 'exotic belly dancer': {'n_is_sb': '0'},
 'exotic dancer': {'n_is_sb': '0'},
 'expatriate': {'n_is_sb': '0'},
 'expectorator': {'n_is_sb': '0'},
 'expender': {'n_is_sb': '0'},
 'experimenter': {'n_is_sb': '0'},
 'expert witness': {'n_is_sb': '0'},
 'exporter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'expressionist': {'n_is_sb': '0'},
 'extension agent': {'n_is_sb': '0'},
 'extern': {'n_is_sb': '0'},
 'extoller': {'n_is_sb': '0'},
 'extortioner': {'n_is_sb': '0'},
 'extortionist': {'n_is_sb': '0'},
 'extraterrestrial being': {'n_is_sb': '0'},
 'extravert': {'n_is_sb': '0'},
 'extreme right-winger': {'n_is_sb': '0'},
 'extrovert': {'n_is_sb': '0'},
 'exwife': {'n_is_sb': '0'},
 'eyas': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eyck': {'n_is_sb': '0'},
 'eye doctor': {'n_is_sb': '0'},
 'eye of ra': {'n_is_sb': '0'},
 'eyeglass wearer': {'n_is_sb': '0'},
 'eyeish': {'n_is_sb': '0'},
 'eyra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'eysenck': {'n_is_sb': '0'},
 'ezechiel': {'n_is_sb': '0'},
 'ezekias': {'n_is_sb': '0'},
 'ezra cornell': {'n_is_sb': '0'},
 'ezra loomis pound': {'n_is_sb': '0'},
 'ezra pound': {'n_is_sb': '0'},
 'ezra': {'n_is_sb': '0'},
 'f. d. roosevelt': {'n_is_sb': '0'},
 'f. g. banting': {'n_is_sb': '0'},
 'f. scott fitzgerald': {'n_is_sb': '0'},
 'faberge': {'n_is_sb': '0'},
 'fabricator': {'n_is_sb': '0'},
 'fabulist': {'n_is_sb': '0'},
 'facilitator': {'n_is_sb': '0'},
 'factory worker': {'n_is_sb': '0'},
 'factotum': {'n_is_sb': '0'},
 'faculty member': {'n_is_sb': '0'},
 'faddist': {'n_is_sb': '0'},
 'faerie': {'n_is_sb': '0'},
 'faery': {'n_is_sb': '0'},
 'fafnir': {'n_is_sb': '0'},
 'fagin': {'n_is_sb': '0'},
 'fagot': {'n_is_sb': '2', 'n_is_sth': '2'},
 'fahd ibn abdel aziz al-saud': {'n_is_sb': '0'},
 'fahd': {'n_is_sb': '0'},
 'fair game': {'n_is_sb': '2', 'n_is_sth': '2'},
 'fairbanks': {'n_is_sb': '2', 'n_is_sth': '2'},
 'fairy armadillo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fairy bluebird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fairy godmother': {'n_is_sb': '0'},
 'fairy shrimp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fairy swallow': {'n_is_sb': '0'},
 'faisal ibn abdel aziz al-saud': {'n_is_sb': '0'},
 'faisal': {'n_is_sb': '0'},
 'fakeer': {'n_is_sb': '0'},
 'falco columbarius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'falco peregrinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'falco rusticolus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'falco sparverius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'falco subbuteo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'falco tinnunculus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'falcon-gentil': {'n_is_sb': '3', 'n_is_sth': '3'},
 'falcon-gentle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'falconer': {'n_is_sb': '0'},
 'falkner': {'n_is_sb': '0'},
 'fall armyworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fall cankerworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fall guy': {'n_is_sb': '0'},
 'fall webworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'falla': {'n_is_sb': '0'},
 'fallot': {'n_is_sb': '0'},
 'fallow deer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'false gavial': {'n_is_sb': '3', 'n_is_sth': '3'},
 'false saber-toothed tiger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'false scorpion': {'n_is_sb': '3', 'n_is_sth': '3'},
 'false vampire bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'false vampire': {'n_is_sb': '3', 'n_is_sth': '3'},
 'false witness': {'n_is_sb': '0'},
 'falsifier': {'n_is_sb': '0'},
 'falstaff': {'n_is_sb': '0'},
 'familiar spirit': {'n_is_sb': '0'},
 'family balistidae': {'n_is_sb': ''},
 'family bangiaceae': {'n_is_sb': ''},
 'family bathyergidae': {'n_is_sb': ''},
 'family batrachoididae': {'n_is_sb': ''},
 'family doctor': {'n_is_sb': '0'},
 'family man': {'n_is_sb': '0'},
 'famous person': {'n_is_sb': '0'},
 'famulus': {'n_is_sb': '0'},
 'fanaloka': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fanatic': {'n_is_sb': '0'},
 'fancy man': {'n_is_sb': '0'},
 'fancy woman': {'n_is_sb': '0'},
 'fannie farmer': {'n_is_sb': '0'},
 'fannie merritt farmer': {'n_is_sb': '0'},
 'fanny wright': {'n_is_sb': '0'},
 'fantasist': {'n_is_sb': '0'},
 'fantast': {'n_is_sb': '0'},
 'faqir': {'n_is_sb': '0'},
 'faquir': {'n_is_sb': '0'},
 'faraday': {'n_is_sb': '0'},
 'farm animal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'farm boy': {'n_is_sb': '0'},
 'farm girl': {'n_is_sb': '0'},
 'farm horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'farm worker': {'n_is_sb': '0'},
 'farmerette': {'n_is_sb': '0'},
 'farouk i': {'n_is_sb': '0'},
 'farragut': {'n_is_sb': '0'},
 'farrell': {'n_is_sb': '0'},
 'farsi': {'n_is_sb': '2', 'n_is_sth': '2'},
 'faruk i': {'n_is_sb': '0'},
 'fasciola hepatica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fasciola': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fasciolopsis buski': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fasciolopsis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fashion arbiter': {'n_is_sb': '0'},
 'fashion consultant': {'n_is_sb': '0'},
 'fashion designer': {'n_is_sb': '0'},
 'fashion model': {'n_is_sb': '0'},
 'fashion plate': {'n_is_sb': '2', 'n_is_sth': '2'},
 'fashionmonger': {'n_is_sb': '0'},
 'fat cat': {'n_is_sb': '0'},
 'fat person': {'n_is_sb': '0'},
 'fatalist': {'n_is_sb': '0'},
 'father brown': {'n_is_sb': '0'},
 'father christmas': {'n_is_sb': '0'},
 'father figure': {'n_is_sb': '0'},
 'father of the church': {'n_is_sb': '0'},
 'father of the submarine': {'n_is_sb': '0'},
 'father surrogate': {'n_is_sb': '0'},
 'father-figure': {'n_is_sb': '0'},
 'father-god': {'n_is_sb': '0'},
 'fatimah': {'n_is_sb': '0'},
 'fatima': {'n_is_sb': '0'},
 'fats domino': {'n_is_sb': '0'},
 'fats waller': {'n_is_sb': '0'},
 'faulkner': {'n_is_sb': '0'},
 'faultfinder': {'n_is_sb': '2', 'n_is_sth': '2'},
 'fauntleroy': {'n_is_sb': '0'},
 'faunus': {'n_is_sb': '0'},
 'faun': {'n_is_sb': '0'},
 'fausto paolo sozzini': {'n_is_sb': '0'},
 'faustus socinus': {'n_is_sb': '0'},
 'faustus': {'n_is_sb': '0'},
 'faust': {'n_is_sb': '0'},
 'fauve': {'n_is_sb': '0'},
 'fauvist': {'n_is_sb': '0'},
 'favorite son': {'n_is_sb': '0'},
 'favourite son': {'n_is_sb': '0'},
 'fawkes': {'n_is_sb': '0'},
 'fawner': {'n_is_sb': '0'},
 'fbi agent': {'n_is_sb': '0'},
 'fdr': {'n_is_sb': '0'},
 'feather star': {'n_is_sb': '3', 'n_is_sth': '3'},
 'featherweight': {'n_is_sb': '2', 'n_is_sth': '2'},
 'fechner': {'n_is_sb': '0'},
 'federal agent': {'n_is_sb': '0'},
 'federal official': {'n_is_sb': '0'},
 'federal soldier': {'n_is_sb': '0'},
 'federalist': {'n_is_sb': '0'},
 'fed': {'n_is_sb': '2', 'vbd_to_vb': 'feed', 'vbn_to_vb': 'feed', 'vbn_to_vbg': 'feeding', 'n_is_sth': '2', 'vbd_eq_vbn': ''},
 'feifer': {'n_is_sb': '0'},
 'feist': {'n_is_sb': '2', 'n_is_sth': '2'},
 'felidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'felid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'feline': {'n_is_sb': '3', 'n_is_sth': '3'},
 'felis bengalensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'felis catus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'felis chaus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'felis concolor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'felis domesticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'felis manul': {'n_is_sb': '3', 'n_is_sth': '3'},
 'felis ocreata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'felis onca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'felis pardalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'felis serval': {'n_is_sb': '3', 'n_is_sth': '3'},
 'felis silvestris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'felis tigrina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'felis wiedi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'felis yagouaroundi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'felis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'felix klein': {'n_is_sb': '0'},
 'felix mendelssohn': {'n_is_sb': '0'},
 'fellah': {'n_is_sb': '0'},
 'fellata': {'n_is_sb': '0'},
 'fellow traveler': {'n_is_sb': '0'},
 'fellow traveller': {'n_is_sb': '0'},
 'fellow worker': {'n_is_sb': '0'},
 'felo-de-se': {'n_is_sb': '0'},
 'female aristocrat': {'n_is_sb': '0'},
 'female child': {'n_is_sb': '0'},
 'female horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'female mammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'female monarch': {'n_is_sb': '0'},
 'female offspring': {'n_is_sb': '0'},
 'female parent': {'n_is_sb': '0'},
 'female person': {'n_is_sb': '0'},
 'female sibling': {'n_is_sb': '0'},
 'feminist': {'n_is_sb': '0'},
 'femme fatale': {'n_is_sb': '0'},
 'fence lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fence-sitter': {'n_is_sb': '0'},
 'fencer': {'n_is_sb': '0'},
 'fencesitter': {'n_is_sb': '0'},
 'fenrir': {'n_is_sb': '0'},
 'fenusa pusilla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fenusa': {'n_is_sb': '0'},
 'feodor dostoevski': {'n_is_sb': '0'},
 'feodor dostoevsky': {'n_is_sb': '0'},
 'feodor dostoyevsky': {'n_is_sb': '0'},
 'feodor mikhailovich dostoevski': {'n_is_sb': '0'},
 'feodor mikhailovich dostoevsky': {'n_is_sb': '0'},
 'feodor mikhailovich dostoyevsky': {'n_is_sb': '0'},
 'fer-de-lance': {'n_is_sb': '3', 'n_is_sth': '3'},
 'feral man': {'n_is_sb': '0'},
 'ferber': {'n_is_sb': '0'},
 'ferdinand de lesseps': {'n_is_sb': '0'},
 'ferdinand de saussure': {'n_is_sb': '0'},
 'ferdinand iii': {'n_is_sb': '0'},
 'ferdinand ii': {'n_is_sb': '0'},
 'ferdinand i': {'n_is_sb': '0'},
 'ferdinand joseph la menthe morton': {'n_is_sb': '0'},
 'ferdinand julius cohn': {'n_is_sb': '0'},
 'ferdinand magellan': {'n_is_sb': '0'},
 'ferdinand the catholic': {'n_is_sb': '0'},
 'ferdinand the great': {'n_is_sb': '0'},
 'ferdinand victor eugene delacroix': {'n_is_sb': '0'},
 'ferdinand v': {'n_is_sb': '0'},
 'ferenc molnar': {'n_is_sb': '0'},
 'fermat': {'n_is_sb': '0'},
 'fermentologist': {'n_is_sb': '0'},
 'fermi': {'n_is_sb': '0'},
 'fernand leger': {'n_is_sb': '0'},
 'fernao magalhaes': {'n_is_sb': '0'},
 'ferret badger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ferryman': {'n_is_sb': '0'},
 'fetishist': {'n_is_sb': '0'},
 'feudal lord': {'n_is_sb': '0'},
 'feudatory': {'n_is_sb': '2', 'n_is_sth': '2'},
 'feynman': {'n_is_sb': '0'},
 'fibber': {'n_is_sb': '0'},
 'fice': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fictional animal': {'n_is_sb': '0'},
 'fictional character': {'n_is_sb': '0'},
 'fictitious character': {'n_is_sb': '0'},
 'fiddler crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fidel castro ruz': {'n_is_sb': '0'},
 'fidel castro': {'n_is_sb': '0'},
 'fiduciary': {'n_is_sb': '0'},
 'fiedler': {'n_is_sb': '0'},
 'field cricket': {'n_is_sb': '3', 'n_is_sth': '3'},
 'field general': {'n_is_sb': '0'},
 'field hand': {'n_is_sb': '0'},
 'field judge': {'n_is_sb': '0'},
 'field marshal': {'n_is_sb': '0'},
 'field mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'field officer': {'n_is_sb': '0'},
 'field spaniel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'field sparrow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'field-grade officer': {'n_is_sb': '0'},
 'fielder': {'n_is_sb': '0'},
 'fieldfare': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fieldhand': {'n_is_sb': '0'},
 'fielding': {'n_is_sb': '0'},
 'fieldmouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fieldsman': {'n_is_sb': '0'},
 'fieldworker': {'n_is_sb': '0'},
 'fifth columnist': {'n_is_sb': '0'},
 'fig moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fig-bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'figeater': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fighter pilot': {'n_is_sb': '0'},
 'fighting cock': {'n_is_sb': '0'},
 'fighting joe hooker': {'n_is_sb': '0'},
 'figurer': {'n_is_sb': '0'},
 'fijian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'filaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'file clerk': {'n_is_sb': '0'},
 'filefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'filer': {'n_is_sb': '0'},
 'filibusterer': {'n_is_sb': '0'},
 'filing clerk': {'n_is_sb': '0'},
 'filipino': {'n_is_sb': '2', 'n_is_sth': '2'},
 'filippino lippi': {'n_is_sb': '0'},
 'filippo brunelleschi': {'n_is_sb': '0'},
 'fille de chambre': {'n_is_sb': '0'},
 'fillmore': {'n_is_sb': '0'},
 'filly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'film director': {'n_is_sb': '0'},
 'film maker': {'n_is_sb': '0'},
 'film producer': {'n_is_sb': '0'},
 'film star': {'n_is_sb': '0'},
 'film writer': {'n_is_sb': '0'},
 'filmmaker': {'n_is_sb': '0'},
 'filovirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fin whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'finagler': {'n_is_sb': '0'},
 'finalist': {'n_is_sb': '0'},
 'finance minister': {'n_is_sb': '0'},
 'financial analyst': {'n_is_sb': '0'},
 'financial officer': {'n_is_sb': '0'},
 'finback whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fingerprint expert': {'n_is_sb': '0'},
 'fingerprint man': {'n_is_sb': '0'},
 'fingerprint specialist': {'n_is_sb': '0'},
 'finnbogadottir': {'n_is_sb': '0'},
 'finn': {'n_is_sb': '0'},
 'fire ant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fire beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fire chief': {'n_is_sb': '0'},
 'fire fighter': {'n_is_sb': '0'},
 'fire marshall': {'n_is_sb': '0'},
 'fire marshal': {'n_is_sb': '0'},
 'fire salamander': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fire walker': {'n_is_sb': '0'},
 'fire warden': {'n_is_sb': '0'},
 'fire watcher': {'n_is_sb': '0'},
 'fire-bellied toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fire-eater': {'n_is_sb': '0'},
 'fire-swallower': {'n_is_sb': '0'},
 'firebird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'firebrat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'firedrake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'first baron beveridge': {'n_is_sb': '0'},
 'first baron kelvin': {'n_is_sb': '0'},
 'first baron lytton': {'n_is_sb': '0'},
 'first baron macaulay': {'n_is_sb': '0'},
 'first baron marks of broughton': {'n_is_sb': '0'},
 'first baron passfield': {'n_is_sb': '0'},
 'first baron rutherford of nelson': {'n_is_sb': '0'},
 'first baron rutherford': {'n_is_sb': '0'},
 'first baron tennyson': {'n_is_sb': '0'},
 'first baseman': {'n_is_sb': '0'},
 'first cause': {'n_is_sb': '2', 'n_is_sth': '2'},
 'first cousin': {'n_is_sb': '0'},
 'first duke of marlborough': {'n_is_sb': '0'},
 'first duke of wellington': {'n_is_sb': '0'},
 'first earl kitchener of khartoum': {'n_is_sb': '0'},
 'first earl of beaconsfield': {'n_is_sb': '0'},
 'first earl of chatham': {'n_is_sb': '0'},
 'first earl of orford': {'n_is_sb': '0'},
 'first earl wavell': {'n_is_sb': '0'},
 'first lady': {'n_is_sb': '0'},
 'first lieutenant': {'n_is_sb': '0'},
 'first lord of the treasury': {'n_is_sb': '0'},
 'first marquess cornwallis': {'n_is_sb': '0'},
 'first mate': {'n_is_sb': '0'},
 'first offender': {'n_is_sb': '0'},
 'first sacker': {'n_is_sb': '0'},
 'first sergeant': {'n_is_sb': '0'},
 'first viscount haldane of cloan': {'n_is_sb': '0'},
 'first viscount nuffield': {'n_is_sb': '0'},
 'first-nighter': {'n_is_sb': '0'},
 'first-rater': {'n_is_sb': '2', 'n_is_sth': '2'},
 'firth': {'n_is_sb': '2', 'n_is_sth': '2'},
 'fischer': {'n_is_sb': '0'},
 'fish doctor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fish duck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fish eagle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fish family': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fish fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fish genus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fish hawk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fish louse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fish-fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fisher cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fishing eagle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fishing worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fishwife': {'n_is_sb': '0'},
 'fishworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fissiped mammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fissipedia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fissiped': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fissurella apertura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fissurella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fissurellidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fitch': {'n_is_sb': '2', 'n_is_sth': '2'},
 'fitzgerald': {'n_is_sb': '0'},
 'flack catcher': {'n_is_sb': '0'},
 'flag captain': {'n_is_sb': '0'},
 'flag officer': {'n_is_sb': '0'},
 'flag-waver': {'n_is_sb': '2', 'n_is_sth': '2'},
 'flagellant': {'n_is_sb': '0'},
 'flagellate protozoan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flagellated protozoan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flagellate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flagfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flak catcher': {'n_is_sb': '0'},
 'flame fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flamefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flamen': {'n_is_sb': '0'},
 'flaminius': {'n_is_sb': '0'},
 'flanker back': {'n_is_sb': '0'},
 'flanker': {'n_is_sb': '0'},
 "flannery o'connor": {'n_is_sb': '0'},
 'flash in the pan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'flasher': {'n_is_sb': '2', 'n_is_sth': '2'},
 'flashlight fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flat-coated retriever': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flathead catfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flatmate': {'n_is_sb': '0'},
 'flatterer': {'n_is_sb': '0'},
 'flatworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flaubert': {'n_is_sb': '0'},
 'flautist': {'n_is_sb': '0'},
 'flavius josephus': {'n_is_sb': '0'},
 'flavivirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flea beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fleet admiral': {'n_is_sb': '0'},
 'fleming': {'n_is_sb': '0'},
 'flesh fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fletcher': {'n_is_sb': '0'},
 'flibbertigibbet': {'n_is_sb': '0'},
 'flickertail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flight attendant': {'n_is_sb': '0'},
 'flight engineer': {'n_is_sb': '0'},
 'flight surgeon': {'n_is_sb': '0'},
 'flightless bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flirt': {'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'flo ziegfeld': {'n_is_sb': '0'},
 'floating voter': {'n_is_sb': '0'},
 'flogger': {'n_is_sb': '0'},
 'floor leader': {'n_is_sb': '0'},
 'floorwalker': {'n_is_sb': '0'},
 'floozie': {'n_is_sb': '0'},
 'floozy': {'n_is_sb': '0'},
 'florence nightingale': {'n_is_sb': '0'},
 'florenz ziegfeld': {'n_is_sb': '0'},
 'florey': {'n_is_sb': '0'},
 'florida gallinule': {'n_is_sb': '3', 'n_is_sth': '3'},
 'florida pompano': {'n_is_sb': '3', 'n_is_sth': '3'},
 'florida smoothhound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'florida water rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'floridian': {'n_is_sb': '0'},
 'florio': {'n_is_sb': '0'},
 'flory': {'n_is_sb': '0'},
 'flour beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flour weevil': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flouter': {'n_is_sb': '0'},
 'flower child': {'n_is_sb': '0'},
 'flower girl': {'n_is_sb': '0'},
 'floyd bennett': {'n_is_sb': '0'},
 'flunkey': {'n_is_sb': '0'},
 'flute player': {'n_is_sb': '0'},
 'flutist': {'n_is_sb': '0'},
 'flycatching warbler': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flying bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flying cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flying dragon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flying dutchman': {'n_is_sb': '0'},
 'flying fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flying fox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flying gecko': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flying gurnard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flying horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flying lemur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flying lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flying marmot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flying mouse': {'n_is_sb': '2', 'n_is_sth': '2'},
 'flying opossum': {'n_is_sb': '2', 'n_is_sth': '2'},
 'flying phalanger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flying reptile': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flying robin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flying squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'flyweight': {'n_is_sb': '0'},
 'foeman': {'n_is_sb': '0'},
 'foetus': {'n_is_sb': '0'},
 'fogey': {'n_is_sb': '0'},
 'fogy': {'n_is_sb': '0'},
 'folk dancer': {'n_is_sb': '0'},
 'folk poet': {'n_is_sb': '0'},
 'folk singer': {'n_is_sb': '0'},
 'folk writer': {'n_is_sb': '0'},
 'fomenter': {'n_is_sb': '0'},
 'fomorian': {'n_is_sb': '0'},
 'fomor': {'n_is_sb': '0'},
 'fonda': {'n_is_sb': '2', 'n_is_sth': '2'},
 'fondler': {'n_is_sb': '0'},
 'fontanne': {'n_is_sb': '0'},
 'fonteyn': {'n_is_sb': '0'},
 'food faddist': {'n_is_sb': '0'},
 'food fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'food manufacturer': {'n_is_sb': '0'},
 'foodie': {'n_is_sb': '0'},
 'foolish woman': {'n_is_sb': '0'},
 'foot doctor': {'n_is_sb': '0'},
 'foot soldier': {'n_is_sb': '0'},
 'football coach': {'n_is_sb': '0'},
 'football hero': {'n_is_sb': '0'},
 'football official': {'n_is_sb': '0'},
 'football player': {'n_is_sb': '0'},
 'footballer': {'n_is_sb': '0'},
 'footer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'footpad': {'n_is_sb': '0'},
 'footslogger': {'n_is_sb': '0'},
 'foraminifera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'foraminifer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'foram': {'n_is_sb': '3', 'n_is_sth': '3'},
 'forbear': {'n_is_sb': '0', 'v_vbg': ''},
 'ford hermann hueffer': {'n_is_sb': '0'},
 'ford madox ford': {'n_is_sb': '0'},
 'foreign agent': {'n_is_sb': '0'},
 'foreign correspondent': {'n_is_sb': '0'},
 'foreign minister': {'n_is_sb': '0'},
 'forelady': {'n_is_sb': '0'},
 'foremother': {'n_is_sb': '0'},
 'foreperson': {'n_is_sb': '0'},
 'forest fire fighter': {'n_is_sb': '0'},
 'forest goat': {'n_is_sb': '0'},
 'forest god': {'n_is_sb': '0'},
 'forest tent caterpillar': {'n_is_sb': '3', 'n_is_sth': '3'},
 'forester': {'n_is_sb': '0'},
 'forewoman': {'n_is_sb': '0'},
 'forficula auricularia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'forgetful person': {'n_is_sb': '0'},
 'forgiver': {'n_is_sb': '0'},
 'formica fusca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'formica rufa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'formica sanguinea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'formicidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fornicator': {'n_is_sb': '0'},
 'fornicatress': {'n_is_sb': '0'},
 'forseti': {'n_is_sb': '0'},
 'fortuna': {'n_is_sb': '0'},
 'fortune hunter': {'n_is_sb': '0'},
 'fortune teller': {'n_is_sb': '0'},
 'fortuneteller': {'n_is_sb': '0'},
 'forty-niner': {'n_is_sb': '0'},
 'forward passer': {'n_is_sb': '0'},
 'fosbury': {'n_is_sb': '0'},
 'fossa cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fossa fossa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fossilist': {'n_is_sb': '0'},
 'fossorial mammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'foster-brother': {'n_is_sb': '0'},
 'foster-child': {'n_is_sb': '0'},
 'foster-daughter': {'n_is_sb': '0'},
 'foster-father': {'n_is_sb': '0'},
 'foster-mother': {'n_is_sb': '0'},
 'foster-nurse': {'n_is_sb': '0'},
 'foster-parent': {'n_is_sb': '0'},
 'foster-sister': {'n_is_sb': '0'},
 'foster-son': {'n_is_sb': '0'},
 'fosterling': {'n_is_sb': '0'},
 'foster': {'n_is_sb': '0', 'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'foucault': {'n_is_sb': '0'},
 'foulmart': {'n_is_sb': '3', 'n_is_sth': '3'},
 'foumart': {'n_is_sb': '3', 'n_is_sth': '3'},
 'founding father': {'n_is_sb': '0'},
 'foundress': {'n_is_sb': '0'},
 'four-flusher': {'n_is_sb': '0'},
 'four-footed butterfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'four-lined leaf bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'four-lined plant bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'four-minute man': {'n_is_sb': '0'},
 'four-wing flying fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fourier': {'n_is_sb': '0'},
 'fourth earl of chesterfield': {'n_is_sb': '0'},
 'fourth earl of orford': {'n_is_sb': '0'},
 'fowler': {'n_is_sb': '0'},
 'fox hunter': {'n_is_sb': '0'},
 'fox shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fox squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fox talbot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fox terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'foxhound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fo': {'n_is_sb': '0'},
 'fra filippo lippi': {'n_is_sb': '0'},
 'fragonard': {'n_is_sb': '0'},
 'framer': {'n_is_sb': '0'},
 'franc-tireur': {'n_is_sb': '0'},
 'frances eliza hodgson burnett': {'n_is_sb': '0'},
 'frances elizabeth caroline willard': {'n_is_sb': '0'},
 'frances hodgson burnett': {'n_is_sb': '0'},
 'frances wright': {'n_is_sb': '0'},
 'francesco petrarca': {'n_is_sb': '0'},
 'francis albert sinatra': {'n_is_sb': '0'},
 'francis bacon': {'n_is_sb': '0'},
 'francis beaumont': {'n_is_sb': '0'},
 'francis crick': {'n_is_sb': '0'},
 'francis drake': {'n_is_sb': '0'},
 'francis edgar stanley': {'n_is_sb': '0'},
 'francis everett townsend': {'n_is_sb': '0'},
 'francis ferdinand': {'n_is_sb': '0'},
 'francis ford coppola': {'n_is_sb': '0'},
 'francis galton': {'n_is_sb': '0'},
 'francis henry compton crick': {'n_is_sb': '0'},
 'francis hopkinson': {'n_is_sb': '0'},
 'francis ii': {'n_is_sb': '0'},
 'francis joseph i': {'n_is_sb': '0'},
 'francis joseph': {'n_is_sb': '0'},
 'francis of assisi': {'n_is_sb': '0'},
 'francis peyton rous': {'n_is_sb': '0'},
 'francis poulenc': {'n_is_sb': '0'},
 'francis richard stockton': {'n_is_sb': '0'},
 'francis scott key fitzgerald': {'n_is_sb': '0'},
 'francis scott key': {'n_is_sb': '0'},
 'francis turner palgrave': {'n_is_sb': '0'},
 'franciscan': {'n_is_sb': '0', 'cap_word': 'Franciscan'},
 'francisco de goya': {'n_is_sb': '0'},
 'francisco fernandez cordoba': {'n_is_sb': '0'},
 'francisco fernandez de cordova': {'n_is_sb': '0'},
 'francisco franco': {'n_is_sb': '0'},
 'francisco goya': {'n_is_sb': '0'},
 'francisco jimenez de cisneros': {'n_is_sb': '0'},
 'francisco jose de goya y lucientes': {'n_is_sb': '0'},
 'francisco jose de goya': {'n_is_sb': '0'},
 'francisco pizarro': {'n_is_sb': '0'},
 'francisco villa': {'n_is_sb': '0'},
 'francisella tularensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'franck': {'n_is_sb': '0'},
 'franco-american': {'n_is_sb': '0'},
 'francois auguste rene rodin': {'n_is_sb': '0'},
 'francois charles mauriac': {'n_is_sb': '0'},
 'francois couperin': {'n_is_sb': '0'},
 'francois de la rochefoucauld': {'n_is_sb': '0'},
 'francois duvalier': {'n_is_sb': '0'},
 'francois jacob': {'n_is_sb': '0'},
 'francois mansart': {'n_is_sb': '0'},
 'francois marie charles fourier': {'n_is_sb': '0'},
 'francois mauriac': {'n_is_sb': '0'},
 'francois maurice marie mitterand': {'n_is_sb': '0'},
 'francois mitterand': {'n_is_sb': '0'},
 'francois rabelais': {'n_is_sb': '0'},
 'francois rene chateaubriand': {'n_is_sb': '0'},
 'francois truffaut': {'n_is_sb': '0'},
 'francois villon': {'n_is_sb': '0'},
 'francois-marie arouet': {'n_is_sb': '0'},
 "francoise d'aubigne": {'n_is_sb': '0'},
 'francoise-athenais de rochechouart': {'n_is_sb': '0'},
 'francophile': {'n_is_sb': '0'},
 'francophil': {'n_is_sb': '0'},
 'francophobe': {'n_is_sb': '0'},
 'franco': {'n_is_sb': '0'},
 'frank baum': {'n_is_sb': '0'},
 'frank capra': {'n_is_sb': '0'},
 'frank cooper': {'n_is_sb': '0'},
 'frank harris': {'n_is_sb': '0'},
 'frank lloyd wright': {'n_is_sb': '0'},
 'frank morrison spillane': {'n_is_sb': '0'},
 'frank norris': {'n_is_sb': '0'},
 'frank philip stella': {'n_is_sb': '0'},
 'frank sinatra': {'n_is_sb': '0'},
 'frank stella': {'n_is_sb': '0'},
 'frank stockton': {'n_is_sb': '0'},
 'frank winfield woolworth': {'n_is_sb': '0'},
 "frankenstein's monster": {'n_is_sb': '0'},
 'frankenstein': {'n_is_sb': '0'},
 'franklin delano roosevelt': {'n_is_sb': '0'},
 'franklin pierce': {'n_is_sb': '0'},
 'franklin roosevelt': {'n_is_sb': '0'},
 'frankliniella fusca': {'n_is_sb': '0'},
 'franz anton mesmer': {'n_is_sb': '0'},
 'franz ferdinand': {'n_is_sb': '0'},
 'franz josef i': {'n_is_sb': '0'},
 'franz joseph haydn': {'n_is_sb': '0'},
 'franz joseph kline': {'n_is_sb': '0'},
 'franz joseph': {'n_is_sb': '0'},
 'franz kafka': {'n_is_sb': '0'},
 'franz kline': {'n_is_sb': '0'},
 'franz lehar': {'n_is_sb': '0'},
 'franz liszt': {'n_is_sb': '0'},
 'franz peter schubert': {'n_is_sb': '0'},
 'franz schubert': {'n_is_sb': '0'},
 'franz seraph peter schubert': {'n_is_sb': '0'},
 'franz werfel': {'n_is_sb': '0'},
 'fratercula arctica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fratercula corniculata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fratercula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fraternal twin': {'n_is_sb': '0'},
 'frazer': {'n_is_sb': '0'},
 'fred astaire': {'n_is_sb': '0'},
 'fred hoyle': {'n_is_sb': '0'},
 'fred sanger': {'n_is_sb': '0'},
 'fred skinner': {'n_is_sb': '0'},
 'fred zinnemann': {'n_is_sb': '0'},
 'frederic auguste bartholdi': {'n_is_sb': '0'},
 'frederic francois chopin': {'n_is_sb': '0'},
 'frederic william maitland': {'n_is_sb': '0'},
 'frederick barbarossa': {'n_is_sb': '0'},
 'frederick carleton lewis': {'n_is_sb': '0'},
 'frederick childe hassam': {'n_is_sb': '0'},
 'frederick delius': {'n_is_sb': '0'},
 'frederick douglass': {'n_is_sb': '0'},
 'frederick ii': {'n_is_sb': '0'},
 'frederick i': {'n_is_sb': '0'},
 'frederick jackson turner': {'n_is_sb': '0'},
 'frederick james furnivall': {'n_is_sb': '0'},
 'frederick law olmsted': {'n_is_sb': '0'},
 'frederick loewe': {'n_is_sb': '0'},
 'frederick moore vinson': {'n_is_sb': '0'},
 'frederick north': {'n_is_sb': '0'},
 'frederick sanger': {'n_is_sb': '0'},
 'frederick soddy': {'n_is_sb': '0'},
 'frederick the great': {'n_is_sb': '0'},
 'frederick william iii': {'n_is_sb': '0'},
 'frederick william ii': {'n_is_sb': '0'},
 'frederick william iv': {'n_is_sb': '0'},
 'frederick william i': {'n_is_sb': '0'},
 'frederick william': {'n_is_sb': '0'},
 'frederico garcia lorca': {'n_is_sb': '0'},
 'free agent': {'n_is_sb': '0'},
 'free spirit': {'n_is_sb': '0'},
 'free trader': {'n_is_sb': '0'},
 'free-liver': {'n_is_sb': '0'},
 'free-tailed bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'freebooter': {'n_is_sb': '0'},
 'freedom fighter': {'n_is_sb': '0'},
 'freedom rider': {'n_is_sb': '0'},
 'freedwoman': {'n_is_sb': '0'},
 'freeholder': {'n_is_sb': '0'},
 'freelance': {'n_is_sb': '0'},
 'freeloader': {'n_is_sb': '0'},
 'freemason': {'n_is_sb': '0'},
 'freetailed bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'freetail': {'n_is_sb': '0'},
 'freethinker': {'n_is_sb': '0'},
 'freewheeler': {'n_is_sb': '0'},
 'freewoman': {'n_is_sb': '0'},
 'freight agent': {'n_is_sb': '0'},
 'fremont': {'n_is_sb': '2', 'n_is_sth': '2'},
 'french bulldog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'french canadian': {'n_is_sb': '0'},
 'french people': {'n_is_sb': '0'},
 'french person': {'n_is_sb': '0'},
 'french teacher': {'n_is_sb': '0'},
 'frenchwoman': {'n_is_sb': '0'},
 'frequenter': {'n_is_sb': '0'},
 'fresh fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fresher': {'n_is_sb': '0'},
 'freshwater bass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'freshwater bream': {'n_is_sb': '3', 'n_is_sth': '3'},
 'freshwater clam': {'n_is_sb': '3', 'n_is_sth': '3'},
 'freshwater eel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'freshwater limpet': {'n_is_sb': '2', 'n_is_sth': '2'},
 'freshwater mussel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fresnel': {'n_is_sb': '0'},
 'freud': {'n_is_sb': '0', 'cap_word': 'Freud'},
 'freya': {'n_is_sb': '0'},
 'freyja': {'n_is_sb': '0'},
 'freyr': {'n_is_sb': '0'},
 'frey': {'n_is_sb': '0'},
 'friar preacher': {'n_is_sb': '0'},
 'frick': {'n_is_sb': '0'},
 'fridtjof nansen': {'n_is_sb': '0'},
 'friedan': {'n_is_sb': '0'},
 'friedman': {'n_is_sb': '0'},
 'friedrich anton mesmer': {'n_is_sb': '0'},
 'friedrich august kekule von stradonitz': {'n_is_sb': '0'},
 'friedrich august kekule': {'n_is_sb': '0'},
 'friedrich august von hayek': {'n_is_sb': '0'},
 'friedrich august wolf': {'n_is_sb': '0'},
 'friedrich engels': {'n_is_sb': '0'},
 'friedrich froebel': {'n_is_sb': '0'},
 'friedrich gottlieb klopstock': {'n_is_sb': '0'},
 'friedrich hebbel': {'n_is_sb': '0'},
 'friedrich krupp': {'n_is_sb': '0'},
 'friedrich max muller': {'n_is_sb': '0'},
 'friedrich wilhelm august froebel': {'n_is_sb': '0'},
 'friedrich wilhelm bessel': {'n_is_sb': '0'},
 'friedrich wilhelm nietzsche': {'n_is_sb': '0'},
 'friend of the court': {'n_is_sb': '0'},
 'friesian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'frigate bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'frigga': {'n_is_sb': '0'},
 'frigg': {'n_is_sb': '0'},
 'frilled lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fringe-toed lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fringed gecko': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fringilla coelebs': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fringilla montifringilla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'frisch': {'n_is_sb': '0'},
 'frisian': {'n_is_sb': '0'},
 'fritz albert lipmann': {'n_is_sb': '0'},
 'fritz haber': {'n_is_sb': '0'},
 'fritz kreisler': {'n_is_sb': '0'},
 'fritz w. meissner': {'n_is_sb': '0'},
 'frobisher': {'n_is_sb': '0'},
 'froebel': {'n_is_sb': '0'},
 'frogfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'froghopper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'frogmouth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fromental halevy': {'n_is_sb': '0'},
 'front man': {'n_is_sb': '0'},
 'front-runner': {'n_is_sb': '0'},
 'frontbencher': {'n_is_sb': '0'},
 'frontiersman': {'n_is_sb': '0'},
 'frontierswoman': {'n_is_sb': '0'},
 'frost fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'frosted bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'frotteur': {'n_is_sb': '2', 'n_is_sth': '2'},
 'fruit bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fruit fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fruit grower': {'n_is_sb': '0'},
 'fruitcake': {'n_is_sb': '2', 'n_is_sth': '2'},
 'fruiterer': {'n_is_sb': '0'},
 'fry cook': {'n_is_sb': '2', 'n_is_sth': '2'},
 'frye': {'n_is_sb': '2', 'n_is_sth': '2'},
 'fuchs': {'n_is_sb': '0'},
 'fucker': {'n_is_sb': '0'},
 'fuckhead': {'n_is_sb': '0', 'dirtyword': ''},
 'fuckup': {'n_is_sb': '2', 'n_is_sth': '2'},
 'fucoid algae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fucoid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fucus serratus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fucus vesiculosus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fucus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fuentes': {'n_is_sb': '0'},
 'fugard': {'n_is_sb': '0'},
 'fugitive from justice': {'n_is_sb': '0'},
 'fugleman': {'n_is_sb': '0'},
 'fulah': {'n_is_sb': '0'},
 'fulani': {'n_is_sb': '0'},
 'fula': {'n_is_sb': '0'},
 'fulbe': {'n_is_sb': '0'},
 'fulbright': {'n_is_sb': '2', 'n_is_sth': '2'},
 'fulica americana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fulica atra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'full admiral': {'n_is_sb': '0'},
 'full cousin': {'n_is_sb': '0'},
 'full general': {'n_is_sb': '0'},
 'full professor': {'n_is_sb': '0'},
 'fuller': {'n_is_sb': '0'},
 'fulmar petrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fulmarus glacialis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fulmar': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fulton': {'n_is_sb': '0'},
 'fumbler': {'n_is_sb': '0'},
 'fumimaro konoe': {'n_is_sb': '0'},
 'fumimaro konoye': {'n_is_sb': '0'},
 'funambulist': {'n_is_sb': '0'},
 'functional illiterate': {'n_is_sb': '0'},
 'functionalist': {'n_is_sb': '0'},
 'fundamentalist': {'n_is_sb': '0'},
 'fundraiser': {'n_is_sb': '0'},
 'fundulus heteroclitus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fundulus majalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'funeral director': {'n_is_sb': '0'},
 'funeral undertaker': {'n_is_sb': '0'},
 'fungia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fungus gnat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'fur seal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'furcula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'furniture maker': {'n_is_sb': '0'},
 'furnivall': {'n_is_sb': '0'},
 'furrier': {'n_is_sb': '0'},
 'fusilier': {'n_is_sb': '0'},
 'fuss-budget': {'n_is_sb': '0'},
 'fusspot': {'n_is_sb': '0'},
 'futurist': {'n_is_sb': '0'},
 'fyodor dostoevski': {'n_is_sb': '0'},
 'fyodor dostoevsky': {'n_is_sb': '0'},
 'fyodor dostoyevsky': {'n_is_sb': '0'},
 'fyodor mikhailovich dostoevski': {'n_is_sb': '0'},
 'fyodor mikhailovich dostoevsky': {'n_is_sb': '0'},
 'fyodor mikhailovich dostoyevsky': {'n_is_sb': '0'},
 'g. b. shaw': {'n_is_sb': '0'},
 'g. e. moore': {'n_is_sb': '0'},
 'g. k. chesterton': {'n_is_sb': '0'},
 'g. r. kirchhoff': {'n_is_sb': '0'},
 'g. stanley hall': {'n_is_sb': '0'},
 'gabonese': {'n_is_sb': '0'},
 'gaboon viper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gaboriau': {'n_is_sb': '0'},
 'gabor': {'n_is_sb': '0'},
 'gabriel daniel fahrenheit': {'n_is_sb': '0'},
 'gabriel lippmann': {'n_is_sb': '0'},
 'gabriel tellez': {'n_is_sb': '0'},
 'gadaba': {'n_is_sb': '0'},
 'gadabout': {'n_is_sb': '0'},
 'gaddafi': {'n_is_sb': '0'},
 'gadgeteer': {'n_is_sb': '0'},
 'gadoid fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gadoid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gadus macrocephalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gadus merlangus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gadus morhua': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gadus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gaea': {'n_is_sb': '0'},
 'gael': {'n_is_sb': '0'},
 'gaetan vestris': {'n_is_sb': '0'},
 'gaetano donizetti': {'n_is_sb': '0'},
 'gagarin': {'n_is_sb': '0'},
 'gagman': {'n_is_sb': '0'},
 'gagster': {'n_is_sb': '0'},
 'gagwriter': {'n_is_sb': '0'},
 'gaia': {'n_is_sb': '0'},
 'gainsborough': {'n_is_sb': '0'},
 'gaiseric': {'n_is_sb': '0'},
 'gaius caesar': {'n_is_sb': '0'},
 'gaius cassius longinus': {'n_is_sb': '0'},
 'gaius flaminius': {'n_is_sb': '0'},
 'gaius julius caesar octavianus': {'n_is_sb': '0'},
 'gaius julius caesar': {'n_is_sb': '0'},
 'gaius octavianus': {'n_is_sb': '0'},
 'gaius petronius': {'n_is_sb': '0'},
 'gaius plinius caecilius secundus': {'n_is_sb': '0'},
 'gaius plinius secundus': {'n_is_sb': '0'},
 'gaius valerius catullus': {'n_is_sb': '0'},
 'gaius': {'n_is_sb': '0'},
 'galago': {'n_is_sb': '3', 'n_is_sth': '3'},
 'galahad': {'n_is_sb': '0'},
 'galatea': {'n_is_sb': '2', 'n_is_sth': '2'},
 'galatian': {'n_is_sb': '0'},
 'galbraith': {'n_is_sb': '0'},
 'galeocerdo cuvieri': {'n_is_sb': '3', 'n_is_sth': '3'},
 'galeorhinus zyopterus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'galictis vittatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'galilaean': {'n_is_sb': '0'},
 'galilean': {'n_is_sb': '0'},
 'galileo galilei': {'n_is_sb': '0'},
 'galina sergeevna ulanova': {'n_is_sb': '0'},
 'galina ulanova': {'n_is_sb': '0'},
 'gall gnat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gall midge': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gall wasp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gallant fox': {'n_is_sb': '0'},
 'gallaudet': {'n_is_sb': '0'},
 'galleria mellonella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'galley slave': {'n_is_sb': '0'},
 'gallfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gallinacean': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gallinaceous bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gallinago gallinago delicata': {'n_is_sb': '0'},
 'gallinago gallinago': {'n_is_sb': '0'},
 'gallinago media': {'n_is_sb': '0'},
 'gallina': {'n_is_sb': '2', 'n_is_sth': '2'},
 'gallinula chloropus cachinnans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gallinula chloropus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gallinule': {'n_is_sb': '3', 'n_is_sth': '3'},
 'galloway': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gallows bird': {'n_is_sb': '0'},
 'gallus gallus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gallus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'galois': {'n_is_sb': '0'},
 'galsworthy': {'n_is_sb': '0'},
 'galvaniser': {'n_is_sb': '0'},
 'galvanizer': {'n_is_sb': '0'},
 'galvani': {'n_is_sb': '0'},
 'gamal abdel nasser': {'n_is_sb': '0'},
 'gambelia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gambian': {'n_is_sb': '0'},
 'gambusia affinis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gambusia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'game bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'game fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'game fowl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'game warden': {'n_is_sb': '0'},
 'gamekeeper': {'n_is_sb': '0'},
 'games-master': {'n_is_sb': '0'},
 'games-mistress': {'n_is_sb': '0'},
 'gamma': {'n_is_sb': '2', 'n_is_sth': '2'},
 'gamow': {'n_is_sb': '0'},
 'ganapati': {'n_is_sb': '0'},
 'gandhi': {'n_is_sb': '0'},
 'gandy dancer': {'n_is_sb': '0'},
 'ganef': {'n_is_sb': '0'},
 'ganesa': {'n_is_sb': '0'},
 'ganesha': {'n_is_sb': '0'},
 'ganesh': {'n_is_sb': '0'},
 'ganger': {'n_is_sb': '0'},
 "gangster's moll": {'n_is_sb': '0'},
 'gannet': {'n_is_sb': '0'},
 'ganof': {'n_is_sb': '0'},
 'ganoid fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ganoid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gaolbird': {'n_is_sb': '0'},
 'gaoler': {'n_is_sb': '0'},
 'garbage carter': {'n_is_sb': '0'},
 'garbage collector': {'n_is_sb': '0'},
 'garbage hauler': {'n_is_sb': '0'},
 'garbage man': {'n_is_sb': '0'},
 'garbo': {'n_is_sb': '0'},
 'garcia lorca': {'n_is_sb': '0'},
 'garden centipede': {'n_is_sb': '3', 'n_is_sth': '3'},
 'garden snail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'garden spider': {'n_is_sb': '3', 'n_is_sth': '3'},
 'garden symphilid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'garden webworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gardiner': {'n_is_sb': '0'},
 'gardner': {'n_is_sb': '0'},
 'garfield': {'n_is_sb': '0'},
 'garfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'garganey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'garibaldi': {'n_is_sb': '2', 'n_is_sth': '2'},
 'garment cutter': {'n_is_sb': '0'},
 'garment worker': {'n_is_sb': '0'},
 'garment-worker': {'n_is_sb': '0'},
 'garmentmaker': {'n_is_sb': '0'},
 'garnier': {'n_is_sb': '2', 'n_is_sth': '2'},
 'garpike': {'n_is_sb': '3', 'n_is_sth': '3'},
 'garrick': {'n_is_sb': '2', 'n_is_sth': '2'},
 'garroter': {'n_is_sb': '0'},
 'garrotter': {'n_is_sb': '0'},
 'garter snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 "gartner's bacillus": {'n_is_sb': '3', 'n_is_sth': '3'},
 'garuda': {'n_is_sb': '0'},
 'garullus garullus': {'n_is_sb': '0'},
 'gary cooper': {'n_is_sb': '0'},
 'gary kasparov': {'n_is_sb': '0'},
 'gary weinstein': {'n_is_sb': '0'},
 'gar': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gas fitter': {'n_is_sb': '0'},
 'gaskell': {'n_is_sb': '0'},
 'gasman': {'n_is_sb': '0'},
 'gaspar': {'n_is_sb': '2', 'n_is_sth': '2'},
 'gasterophilus intestinalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gasterosteus aculeatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gasterosteus pungitius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gaston lachaise': {'n_is_sb': '0'},
 'gastroenterologist': {'n_is_sb': '0'},
 'gastrophryne carolinensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gastrophryne olivacea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gastropod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gatecrasher': {'n_is_sb': '0'},
 'gatherer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'gatling': {'n_is_sb': '2', 'n_is_sth': '2'},
 'gator': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gaucho': {'n_is_sb': '0'},
 'gaudi i cornet': {'n_is_sb': '0'},
 'gaudi': {'n_is_sb': '0'},
 'gauguin': {'n_is_sb': '0'},
 'gaul': {'n_is_sb': '0'},
 'gauri': {'n_is_sb': '0'},
 'gauss': {'n_is_sb': '2', 'n_is_sth': '2'},
 'gautama buddha': {'n_is_sb': '0'},
 'gautama siddhartha': {'n_is_sb': '0'},
 'gautama': {'n_is_sb': '0'},
 'gavialis gangeticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gavial': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gaviiform seabird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gawain': {'n_is_sb': '0'},
 'gawk': {'n_is_sb': '0'},
 'gay man': {'n_is_sb': '0'},
 'gay woman': {'n_is_sb': '0'},
 'gay-lussac': {'n_is_sb': '0'},
 'gayal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gazella subgutturosa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gazella thomsoni': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gazella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gazelle hound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'geb': {'n_is_sb': '0'},
 'gee-gee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'geert geerts': {'n_is_sb': '0'},
 'gehrig': {'n_is_sb': '0'},
 'geiger': {'n_is_sb': '0'},
 'geisel': {'n_is_sb': '0'},
 'geisha girl': {'n_is_sb': '0'},
 'gelechia gossypiella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gelechiid moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gelechiid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gell-mann': {'n_is_sb': '0'},
 'gelnn theodore seaborg': {'n_is_sb': '0'},
 'gem cutter': {'n_is_sb': '0'},
 'gempylid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gempylus serpens': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gemsbok': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gemsbuck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gene kelly': {'n_is_sb': '0'},
 'gene sarazen': {'n_is_sb': '0'},
 'gene tunney': {'n_is_sb': '0'},
 'genealogist': {'n_is_sb': '0'},
 'general agent': {'n_is_sb': '0'},
 'general charles de gaulle': {'n_is_sb': '0'},
 'general custer': {'n_is_sb': '0'},
 'general de gaulle': {'n_is_sb': '0'},
 'general manager': {'n_is_sb': '0'},
 'general officer': {'n_is_sb': '0'},
 'general practitioner': {'n_is_sb': '0'},
 'geneticist': {'n_is_sb': '0'},
 'genetta genetta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genetta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genet': {'n_is_sb': '0'},
 'genghis khan': {'n_is_sb': '0'},
 'genitor': {'n_is_sb': '0'},
 'genius loci': {'n_is_sb': '2', 'n_is_sth': '2'},
 'genseric': {'n_is_sb': '0'},
 'gentleman jim': {'n_is_sb': '0'},
 'gentleman johnny': {'n_is_sb': '0'},
 "gentleman's gentleman": {'n_is_sb': '0'},
 'gentleman-at-arms': {'n_is_sb': '0'},
 'genus amoeba': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus amphisbaenia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus anasa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus anastomus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus anguillula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus aotus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus aramus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus aranea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus ara': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus archaeornis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus argentinosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus arizona': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus asio': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus aspidophoroides': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus aspis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus atticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus auriparus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus babyrousa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus bankia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus bettongia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus blaberus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus branta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus browmius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus burhinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus caenolestes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus calamus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus callimorpha': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus canachites': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus capreolus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus capricornis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus caretta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus carphophis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus carpocapsa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus carpodacus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus castor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus cathartes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus centrocercus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus centropristis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus cephalopterus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus cercopithecus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus cestum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus chaetodipterus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus chalcis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus chara': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus chauna': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus chirocephalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus chlorura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus chordeiles': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus choriotis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus chorizagrotis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus clethrionomys': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus coereba': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus colinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus collocalia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus cryptocercus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus cuon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus dama': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus deinonychus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus draco': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus eacles': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus eoraptor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus exaeretodon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus gambelia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus gelechia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus gerrhonotus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus haldea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus hemipteronatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus hesperiphona': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus iguanodon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus lasiurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus lebistes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus lofortyx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus lophodytes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus lophophorus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus macrodactylus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus meleagris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus microdipodops': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus micromyx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus moloch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus mononychus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus myxinikela': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus neophron': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus neotoma': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus onychogalea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus palaemon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus passerina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus penelope': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus peripatopsis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus pholis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus pleurobrachia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus pyrophorus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus rodolia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus salamandra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus salmonella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus saturnia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus sonora': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus strymon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus tautoga': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus terebella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genus thermobia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'genyonemus lineatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'geochelone': {'n_is_sb': '3', 'n_is_sth': '3'},
 'geococcyx californianus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'geococcyx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'geoduck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'geoffrey chaucer': {'n_is_sb': '0'},
 'geoffrey of monmouth': {'n_is_sb': '0'},
 'geomancer': {'n_is_sb': '0'},
 'geometrician': {'n_is_sb': '0'},
 'geometrid moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'geometridae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'geometrid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'geometry teacher': {'n_is_sb': '0'},
 'geomyidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'geomys bursarius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'geomys pinetis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'geophilidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'geophilomorpha': {'n_is_sb': '3', 'n_is_sth': '3'},
 'geophilus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'geophysicist': {'n_is_sb': '0'},
 'georg friedrich bernhard riemann': {'n_is_sb': '0'},
 'georg friedrich handel': {'n_is_sb': '0'},
 'georg meissner': {'n_is_sb': '0'},
 'georg philipp telemann': {'n_is_sb': '0'},
 'georg simon ohm': {'n_is_sb': '0'},
 'georg wilhelm friedrich hegel': {'n_is_sb': '0'},
 'georg wilhelm steller': {'n_is_sb': '0'},
 'george armstrong custer': {'n_is_sb': '0'},
 'george balanchine': {'n_is_sb': '0'},
 'george beadle': {'n_is_sb': '0'},
 'george berkeley': {'n_is_sb': '0'},
 'george bernard shaw': {'n_is_sb': '0'},
 'george boole': {'n_is_sb': '0'},
 'george bryan brummell': {'n_is_sb': '0'},
 'george burns': {'n_is_sb': '0'},
 'george bush': {'n_is_sb': '0'},
 'george c. scott': {'n_is_sb': '0'},
 'george catlett marshall': {'n_is_sb': '0'},
 'george charles hevesy de hevesy': {'n_is_sb': '0'},
 'george dewey': {'n_is_sb': '0'},
 'george dibdin pitt': {'n_is_sb': '0'},
 'george dibdin-pitt': {'n_is_sb': '0'},
 'george du maurier': {'n_is_sb': '0'},
 'george eastman': {'n_is_sb': '0'},
 'george edward moore': {'n_is_sb': '0'},
 'george edward pickett': {'n_is_sb': '0'},
 'george eliot': {'n_is_sb': '0'},
 'george ellery hale': {'n_is_sb': '0'},
 'george enescu': {'n_is_sb': '0'},
 'george fox': {'n_is_sb': '0'},
 'george frederic handel': {'n_is_sb': '0'},
 'george gamow': {'n_is_sb': '0'},
 'george gershwin': {'n_is_sb': '0'},
 'george gilbert aime murphy': {'n_is_sb': '0'},
 'george gordon meade': {'n_is_sb': '0'},
 'george guess': {'n_is_sb': '0'},
 'george h.w. bush': {'n_is_sb': '0'},
 'george harrison': {'n_is_sb': '0'},
 'george herbert hitchings': {'n_is_sb': '0'},
 'george herbert mead': {'n_is_sb': '0'},
 'george herbert walker bush': {'n_is_sb': '0'},
 'george herman ruth': {'n_is_sb': '0'},
 'george hubert wilkins': {'n_is_sb': '0'},
 'george iii': {'n_is_sb': '0'},
 'george ii': {'n_is_sb': '0'},
 'george iv': {'n_is_sb': '0'},
 'george i': {'n_is_sb': '0'},
 'george louis palmella busson du maurier': {'n_is_sb': '0'},
 'george lucas': {'n_is_sb': '0'},
 'george m. cohan': {'n_is_sb': '0'},
 'george macaulay trevelyan': {'n_is_sb': '0'},
 'george marshall': {'n_is_sb': '0'},
 'george mason': {'n_is_sb': '0'},
 'george meany': {'n_is_sb': '0'},
 'george meredith': {'n_is_sb': '0'},
 'george michael cohan': {'n_is_sb': '0'},
 'george orson welles': {'n_is_sb': '0'},
 'george orwell': {'n_is_sb': '0'},
 'george otto trevelyan': {'n_is_sb': '0'},
 'george paget thomson': {'n_is_sb': '0'},
 'george percy aldridge grainger': {'n_is_sb': '0'},
 'george pitt': {'n_is_sb': '0'},
 'george s. kaufman': {'n_is_sb': '0'},
 'george sand': {'n_is_sb': '0'},
 'george segal': {'n_is_sb': '0'},
 'george simon kaufman': {'n_is_sb': '0'},
 'george stephenson': {'n_is_sb': '0'},
 'george stevens': {'n_is_sb': '0'},
 'george szell': {'n_is_sb': '0'},
 'george vancouver': {'n_is_sb': '0'},
 'george vi': {'n_is_sb': '0'},
 'george v': {'n_is_sb': '0'},
 'george w. bush': {'n_is_sb': '0'},
 'george walker bush': {'n_is_sb': '0'},
 'george washington carver': {'n_is_sb': '0'},
 'george washington goethals': {'n_is_sb': '0'},
 'george washington': {'n_is_sb': '0'},
 'george wells beadle': {'n_is_sb': '0'},
 'george westinghouse': {'n_is_sb': '0'},
 'george william russell': {'n_is_sb': '0'},
 'georges bizet': {'n_is_sb': '0'},
 'georges braque': {'n_is_sb': '0'},
 'georges clemenceau': {'n_is_sb': '0'},
 'georges cuvier': {'n_is_sb': '0'},
 'georges de la tour': {'n_is_sb': '0'},
 'georges enesco': {'n_is_sb': '0'},
 'georges eugene benjamin clemenceau': {'n_is_sb': '0'},
 'georges gilles de la tourette': {'n_is_sb': '0'},
 'georges henri lemaitre': {'n_is_sb': '0'},
 'georges jacques danton': {'n_is_sb': '0'},
 'georges joseph christian simenon': {'n_is_sb': '0'},
 'georges leopold chretien frederic dagobert cuvier': {'n_is_sb': '0'},
 'georges pierre seurat': {'n_is_sb': '0'},
 'georges seurat': {'n_is_sb': '0'},
 'georges simenon': {'n_is_sb': '0'},
 'georgi konstantinovich zhukov': {'n_is_sb': '0'},
 'georgia okeeffe': {'n_is_sb': '0'},
 'georgiana barrymore': {'n_is_sb': '0'},
 'georgiana emma barrymore': {'n_is_sb': '0'},
 'geothlypis trichas': {'n_is_sb': '3', 'n_is_sth': '3'},
 'geothlypis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'geraint': {'n_is_sb': '0'},
 'gerald ford': {'n_is_sb': '0'},
 'gerald r. ford': {'n_is_sb': '0'},
 'gerald rudolph ford': {'n_is_sb': '0'},
 'gerard depardieu': {'n_is_sb': '0'},
 'gerard manley hopkins': {'n_is_sb': '0'},
 'gerardus mercator': {'n_is_sb': '0'},
 'gerbille': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gerbil': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gerenuk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gerfalcon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gerhard gerhards': {'n_is_sb': '0'},
 'gerhard herzberg': {'n_is_sb': '0'},
 'gerhard kremer': {'n_is_sb': '0'},
 'geriatrician': {'n_is_sb': '0'},
 'german american': {'n_is_sb': '0'},
 'german bee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'german cockroach': {'n_is_sb': '3', 'n_is_sth': '3'},
 'german nazi': {'n_is_sb': '0'},
 'german police dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'german shepherd dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'german shepherd': {'n_is_sb': '3', 'n_is_sth': '3'},
 'german short-haired pointer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'geronimo': {'n_is_sb': '0'},
 'gerontologist': {'n_is_sb': '0'},
 'gerreidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gerres cinereus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gerrhonotus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gerridae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gerris lacustris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gershwin': {'n_is_sb': '0'},
 'gertrude caroline ederle': {'n_is_sb': '0'},
 'gertrude ederle': {'n_is_sb': '0'},
 'gertrude lawrence': {'n_is_sb': '0'},
 'gertrude stein': {'n_is_sb': '0'},
 'geryon': {'n_is_sb': '0'},
 'gesell': {'n_is_sb': '0'},
 'gesner': {'n_is_sb': '0'},
 'getulio dornelles vargas': {'n_is_sb': '0'},
 'ge': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ghanian': {'n_is_sb': '0'},
 'ghostfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ghostwriter': {'n_is_sb': '0'},
 'ghoul': {'n_is_sb': '0'},
 'giacometti': {'n_is_sb': '0'},
 'giacomo meyerbeer': {'n_is_sb': '0'},
 'giacomo puccini': {'n_is_sb': '0'},
 'giambattista lulli': {'n_is_sb': '0'},
 'giambattista marini': {'n_is_sb': '0'},
 'giambattista marino': {'n_is_sb': '0'},
 'gian carlo menotti': {'n_is_sb': '0'},
 'gianbattista bodoni': {'n_is_sb': '0'},
 'gianni versace': {'n_is_sb': '0'},
 'giant anteater': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant armadillo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant clam': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant cockroach': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant conch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant eland': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant fulmar': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant hornet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant kangaroo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant moa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant northwest shipworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant panda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant petrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant pigfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant salamander': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant scallop': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant schnauzer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant silkworm moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant silkworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant squid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant tortoise': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giant water bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giantess': {'n_is_sb': '0'},
 'giardia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gibbs': {'n_is_sb': '0'},
 'gibraltarian': {'n_is_sb': '0'},
 'gibran': {'n_is_sb': '0'},
 'gibson girl': {'n_is_sb': '2', 'n_is_sth': '2'},
 'gibson': {'n_is_sb': '2', 'n_is_sth': '2'},
 'gib': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gideon algernon mantell': {'n_is_sb': '0'},
 'gide': {'n_is_sb': '0'},
 'gielgud': {'n_is_sb': '0'},
 'giggler': {'n_is_sb': '0'},
 'gigolo': {'n_is_sb': '0'},
 'gila monster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gilbert charles stuart': {'n_is_sb': '0'},
 'gilbert keith chesterton': {'n_is_sb': '0'},
 'gilbert murray': {'n_is_sb': '0'},
 'gilbert stuart': {'n_is_sb': '0'},
 'gilbert': {'n_is_sb': '2', 'n_is_sth': '2'},
 'gilded flicker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gilder': {'n_is_sb': '0'},
 'giles lytton strachey': {'n_is_sb': '0'},
 'gilgamesh': {'n_is_sb': '0'},
 'gilgamish': {'n_is_sb': '0'},
 'gilles de la tourette': {'n_is_sb': '0'},
 'gillespie': {'n_is_sb': '0'},
 'gillette': {'n_is_sb': '0'},
 'gillie': {'n_is_sb': '0'},
 'gilman': {'n_is_sb': '0'},
 'gilmer': {'n_is_sb': '0'},
 'giloacchino antonio rossini': {'n_is_sb': '0'},
 'ginger rogers': {'n_is_sb': '0'},
 'ginglymostoma cirratum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ginglymostoma': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ginsberg': {'n_is_sb': '0'},
 'giordano bruno': {'n_is_sb': '0'},
 'giorgio de chirico': {'n_is_sb': '0'},
 'giorgio vasari': {'n_is_sb': '0'},
 'giosue carducci': {'n_is_sb': '0'},
 'giotto di bondone': {'n_is_sb': '0'},
 'giotto': {'n_is_sb': '0'},
 'giovanni battista tiepolo': {'n_is_sb': '0'},
 'giovanni boccaccio': {'n_is_sb': '0'},
 'giovanni cabato': {'n_is_sb': '0'},
 'giovanni cimabue': {'n_is_sb': '0'},
 'giovanni da verrazano': {'n_is_sb': '0'},
 'giovanni da verrazzano': {'n_is_sb': '0'},
 'giovanni de medici': {'n_is_sb': '0'},
 'giovanni di bernardone': {'n_is_sb': '0'},
 'giovanni jacopo casanova de seingalt': {'n_is_sb': '0'},
 'giovanni jacopo casanova': {'n_is_sb': '0'},
 'giovanni lorenzo bernini': {'n_is_sb': '0'},
 'giovanni pierluigi da palestrina': {'n_is_sb': '0'},
 'giovanni virginio schiaparelli': {'n_is_sb': '0'},
 'gipsy moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gipsy': {'n_is_sb': '0'},
 'giraffa camelopardalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'giraffa': {'n_is_sb': '2', 'n_is_sth': '2'},
 'giraffidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'girard': {'n_is_sb': '0'},
 'giraudoux': {'n_is_sb': '0'},
 'girl friday': {'n_is_sb': '0'},
 'girl scout': {'n_is_sb': '0'},
 'girl wonder': {'n_is_sb': '0'},
 'girolamo savonarola': {'n_is_sb': '0'},
 'girondist': {'n_is_sb': '0'},
 'girru': {'n_is_sb': '0'},
 'gish': {'n_is_sb': '0'},
 'gitana': {'n_is_sb': '0'},
 'gitano': {'n_is_sb': '2', 'n_is_sth': '2'},
 'git': {'n_is_sb': '0'},
 'giulio natta': {'n_is_sb': '0'},
 'giuseppe balsamo': {'n_is_sb': '0'},
 'giuseppe garibaldi': {'n_is_sb': '0'},
 'giuseppe mazzini': {'n_is_sb': '0'},
 'giuseppe melchiorre sarto': {'n_is_sb': '0'},
 'giuseppe verdi': {'n_is_sb': '0'},
 'giver': {'n_is_sb': '0'},
 'gjellerup': {'n_is_sb': '0'},
 'gladiator': {'n_is_sb': '0'},
 'gladstone': {'n_is_sb': '2', 'n_is_sth': '2'},
 'gladys smith': {'n_is_sb': '0'},
 'glareole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'glareolidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'glaser': {'n_is_sb': '0'},
 'glass cutter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'glass lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'glass snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'glass sponge': {'n_is_sb': '3', 'n_is_sth': '3'},
 'glass-cutter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'glassblower': {'n_is_sb': '2', 'n_is_sth': '2'},
 'glassmaker': {'n_is_sb': '0'},
 'glassworker': {'n_is_sb': '0'},
 'glaswegian': {'n_is_sb': '0'},
 'glaucomys sabrinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'glaucomys volans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'glaucomys': {'n_is_sb': '3', 'n_is_sth': '3'},
 'glazier': {'n_is_sb': '0'},
 'gleaner': {'n_is_sb': '0'},
 'glen gebhard': {'n_is_sb': '0'},
 'glenda jackson': {'n_is_sb': '0'},
 'glendower': {'n_is_sb': '0'},
 'glenn curtiss': {'n_is_sb': '0'},
 'glenn hammond curtiss': {'n_is_sb': '0'},
 'glenn miller': {'n_is_sb': '0'},
 'glenn t. seaborg': {'n_is_sb': '0'},
 'glenn': {'n_is_sb': '0'},
 'gliding bacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'glinka': {'n_is_sb': '0'},
 'gliridae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'glis glis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'glis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'globefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'globetrotter': {'n_is_sb': '0'},
 'globicephala melaena': {'n_is_sb': '3', 'n_is_sth': '3'},
 'globicephala': {'n_is_sb': '3', 'n_is_sth': '3'},
 'globigerina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gloomy gus': {'n_is_sb': '0'},
 'gloria may josephine svensson': {'n_is_sb': '0'},
 'gloria steinem': {'n_is_sb': '0'},
 'gloria swanson': {'n_is_sb': '0'},
 'glossina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'glossopsitta versicolor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'glossy snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'glowworm': {'n_is_sb': '0'},
 'gluck': {'n_is_sb': '0'},
 'gnaeus julius agricola': {'n_is_sb': '0'},
 'gnaeus pompeius magnus': {'n_is_sb': '0'},
 'gnatcatcher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gnathostome': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gnawer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gnawing animal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gnawing mammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gnostic': {'n_is_sb': '0'},
 'gnu goat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gnu': {'n_is_sb': '3', 'n_is_sth': '3'},
 'go-getter': {'n_is_sb': '0'},
 'goaltender': {'n_is_sb': '0'},
 'goat antelope': {'n_is_sb': '3', 'n_is_sth': '3'},
 'goat herder': {'n_is_sb': '0'},
 'goatfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gobbler': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gobiesox strumosus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gobio gobio': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gobio': {'n_is_sb': '3', 'n_is_sth': '3'},
 'goby': {'n_is_sb': '2', 'n_is_sth': '2'},
 'god almighty': {'n_is_sb': '0'},
 'god of war': {'n_is_sb': '0'},
 'godard': {'n_is_sb': '0'},
 'godchild': {'n_is_sb': '0'},
 'goddard': {'n_is_sb': '0'},
 'goddaughter': {'n_is_sb': '0'},
 'godel': {'n_is_sb': '0'},
 'godiva': {'n_is_sb': '0'},
 'godmother': {'n_is_sb': '0'},
 'godson': {'n_is_sb': '0'},
 'godunov': {'n_is_sb': '0'},
 'godwit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'goebbels': {'n_is_sb': '0'},
 'goering': {'n_is_sb': '0'},
 'goethals': {'n_is_sb': '0'},
 'goethe': {'n_is_sb': '0'},
 'goggle-eye': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gogh': {'n_is_sb': '0'},
 'gogol': {'n_is_sb': '0'},
 'gold digger': {'n_is_sb': '0'},
 'gold miner': {'n_is_sb': '0'},
 'gold panner': {'n_is_sb': '0'},
 'gold-beater': {'n_is_sb': '0'},
 'gold-crowned kinglet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gold-tail moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gold-worker': {'n_is_sb': '0'},
 'golda meir': {'n_is_sb': '0'},
 'goldbeater': {'n_is_sb': '0'},
 'goldberg': {'n_is_sb': '0'},
 'goldbrick': {'n_is_sb': '2', 'n_is_sth': '2'},
 'goldcrest': {'n_is_sb': '3', 'n_is_sth': '3'},
 'golden ager': {'n_is_sb': '0'},
 'golden algae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'golden boy': {'n_is_sb': '0'},
 'golden eagle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'golden hamster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'golden mole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'golden oriole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'golden pheasant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'golden plover': {'n_is_sb': '3', 'n_is_sth': '3'},
 'golden potto': {'n_is_sb': '3', 'n_is_sth': '3'},
 'golden retriever': {'n_is_sb': '3', 'n_is_sth': '3'},
 'golden shiner': {'n_is_sb': '3', 'n_is_sth': '3'},
 'golden warbler': {'n_is_sb': '3', 'n_is_sth': '3'},
 'golden-crested kinglet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'golden-eyed fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'goldeneye': {'n_is_sb': '3', 'n_is_sth': '3'},
 'golding': {'n_is_sb': '0'},
 'goldman': {'n_is_sb': '0'},
 'goldmark': {'n_is_sb': '2', 'n_is_sth': '2'},
 'goldoni': {'n_is_sb': '0'},
 'goldsmith': {'n_is_sb': '0'},
 'goldworker': {'n_is_sb': '0'},
 'goldwyn': {'n_is_sb': '0'},
 'golf caddie': {'n_is_sb': '0'},
 'golf player': {'n_is_sb': '0'},
 'golf pro': {'n_is_sb': '0'},
 'golf widow': {'n_is_sb': '0'},
 'golfer': {'n_is_sb': '0'},
 'golgi': {'n_is_sb': '0', 'cap_word': 'Golgi'},
 'goliard': {'n_is_sb': '0'},
 'goliath frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'goliath': {'n_is_sb': '0'},
 'gombrowicz': {'n_is_sb': '0'},
 'gompers': {'n_is_sb': '0'},
 'gomphothere': {'n_is_sb': '3', 'n_is_sth': '3'},
 'goncourt': {'n_is_sb': '0'},
 'gondoliere': {'n_is_sb': '0'},
 'gondolier': {'n_is_sb': '0'},
 'gond': {'n_is_sb': '0'},
 'goner': {'n_is_sb': '0'},
 'gongora': {'n_is_sb': '0'},
 'gongorist': {'n_is_sb': '0'},
 'goniff': {'n_is_sb': '0'},
 'gonif': {'n_is_sb': '0'},
 'gonne': {'n_is_sb': '0'},
 'gonococcus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gonorhynchus gonorhynchus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gonorhynchus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'good egg': {'n_is_sb': '0'},
 'good guy': {'n_is_sb': '0'},
 "good ol' boy": {'n_is_sb': '0'},
 'good old boy': {'n_is_sb': '0'},
 'good ole boy': {'n_is_sb': '0'},
 'good person': {'n_is_sb': '0'},
 'good samaritan': {'n_is_sb': '0'},
 'good shepherd': {'n_is_sb': '0'},
 'good speller': {'n_is_sb': '0'},
 'good spirit': {'n_is_sb': '0'},
 'good-for-naught': {'n_is_sb': '0'},
 'good-for-nothing': {'n_is_sb': '0'},
 'goodall': {'n_is_sb': '0'},
 'goody-goody': {'n_is_sb': '0'},
 'goodyear': {'n_is_sb': '2', 'n_is_sth': '2'},
 'goof-off': {'n_is_sb': '2', 'n_is_sth': '2'},
 'goofy': {'n_is_sb': '0', 'jj_to_jjr': 'goofier', 'jj_to_jjs': 'goofiest'},
 'gooney bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gooney': {'n_is_sb': '3', 'n_is_sth': '3'},
 'goonie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'goony': {'n_is_sb': '3', 'n_is_sth': '3'},
 'goosander': {'n_is_sb': '3', 'n_is_sth': '3'},
 'goose barnacle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'goosefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gooseneck barnacle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gopher snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gopher tortoise': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gopher turtle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gopherus agassizii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gopherus polypemus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gopherus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'goral': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gordimer': {'n_is_sb': '0'},
 'gordon setter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gore vidal': {'n_is_sb': '0'},
 'gorgas': {'n_is_sb': '0'},
 'gorger': {'n_is_sb': '2', 'n_is_sth': '2'},
 'gorgoniacea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gorgonian coral': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gorgonian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gorgonocephalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gorgon': {'n_is_sb': '0'},
 'gorilla gorilla beringei': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gorilla gorilla gorilla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gorilla gorilla grauri': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gorilla gorilla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'goring': {'n_is_sb': '0'},
 'gorki': {'n_is_sb': '2', 'n_is_sth': '2'},
 'gorky': {'n_is_sb': '0'},
 'gospeler': {'n_is_sb': '0'},
 'gospeller': {'n_is_sb': '0'},
 'gossip columnist': {'n_is_sb': '0'},
 'gossiper': {'n_is_sb': '0'},
 'gossipmonger': {'n_is_sb': '0'},
 'gothic romancer': {'n_is_sb': '0'},
 'goth': {'n_is_sb': '0'},
 'gottfried wilhelm leibnitz': {'n_is_sb': '0'},
 'gottfried wilhelm leibniz': {'n_is_sb': '0'},
 'gotthold ephraim lessing': {'n_is_sb': '0'},
 'gottlieb daimler': {'n_is_sb': '0'},
 'gouger': {'n_is_sb': '0'},
 'goujon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gould': {'n_is_sb': '0'},
 'gounod': {'n_is_sb': '0'},
 'gourmet': {'n_is_sb': '0'},
 'gouverneur morris': {'n_is_sb': '0'},
 'governess': {'n_is_sb': '0'},
 'government agent': {'n_is_sb': '0'},
 'government man': {'n_is_sb': '0'},
 'government minister': {'n_is_sb': '0'},
 'governor general': {'n_is_sb': '0'},
 'goya y lucientes': {'n_is_sb': '0'},
 'goya': {'n_is_sb': '0'},
 'gp': {'n_is_sb': '0'},
 'grabber': {'n_is_sb': '0'},
 'grace ethel cecile rosalie allen': {'n_is_sb': '0'},
 'grace kelly': {'n_is_sb': '0'},
 'grace patricia kelly': {'n_is_sb': '0'},
 'gracie allen': {'n_is_sb': '0'},
 'gracie': {'n_is_sb': '0'},
 'gracilariid moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gracilariid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gracillariidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gracula religiosa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'grad student': {'n_is_sb': '0'},
 'grader': {'n_is_sb': '2', 'n_is_sth': '2'},
 'graduate nurse': {'n_is_sb': '0'},
 'graduate student': {'n_is_sb': '0'},
 'graeco-roman deity': {'n_is_sb': '0'},
 'graecophile': {'n_is_sb': '0'},
 'graf': {'n_is_sb': '0'},
 'graham greene': {'n_is_sb': '0'},
 'grahame': {'n_is_sb': '0'},
 'graham': {'n_is_sb': '0'},
 'grain merchant': {'n_is_sb': '0'},
 'grain moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'grainger': {'n_is_sb': '0'},
 'grammarian': {'n_is_sb': '0'},
 'gramps': {'n_is_sb': '0'},
 'grampus griseus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'grampus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'grand dragon': {'n_is_sb': '0'},
 'grand duchess': {'n_is_sb': '0'},
 'grand duke': {'n_is_sb': '0'},
 'grand inquisitor': {'n_is_sb': '0'},
 'grand lama': {'n_is_sb': '0'},
 'grand mufti': {'n_is_sb': '0'},
 'grand turk': {'n_is_sb': '0'},
 'grandaunt': {'n_is_sb': '0'},
 'granddaddy': {'n_is_sb': '0'},
 'grande dame': {'n_is_sb': '0'},
 'grandma moses': {'n_is_sb': '0'},
 'grandmaster': {'n_is_sb': '0'},
 'grandstander': {'n_is_sb': '0'},
 'granduncle': {'n_is_sb': '0'},
 'grannie': {'n_is_sb': '0'},
 'grant wood': {'n_is_sb': '0'},
 'grantee': {'n_is_sb': '0'},
 'granter': {'n_is_sb': '0'},
 'grantor': {'n_is_sb': '0'},
 'granville stanley hall': {'n_is_sb': '0'},
 'granville-barker': {'n_is_sb': '0'},
 'gran': {'n_is_sb': '2', 'n_is_sth': '2'},
 'grape louse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'grape phylloxera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'graphic artist': {'n_is_sb': '0'},
 'graphologist': {'n_is_sb': '0'},
 'grappelli': {'n_is_sb': '0'},
 'grappler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'grass bacillus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'grass finch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'grass frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'grass parakeet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'grass snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'grass widower': {'n_is_sb': '0'},
 'grass widow': {'n_is_sb': '0'},
 'grassfinch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'grasshopper mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gratified': {'n_is_sb': '', 'sb_be_jj': '', 'vbd_eq_vbn': ''},
 'gravedigger': {'n_is_sb': '2', 'n_is_sth': '2'},
 'graverobber': {'n_is_sb': '0'},
 'gravida iii': {'n_is_sb': '0'},
 'gravida ii': {'n_is_sb': '0'},
 'gravida i': {'n_is_sb': '0'},
 'gravida': {'n_is_sb': '0'},
 'gray catbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gray flounder': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gray fox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gray friar': {'n_is_sb': '0'},
 'gray hen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gray jay': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gray kingbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gray lemming': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gray mullet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gray partridge': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gray sea eagle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gray skate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gray snapper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gray whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gray wolf': {'n_is_sb': '3', 'n_is_sth': '3'},
 'grayback': {'n_is_sb': '3', 'n_is_sth': '3'},
 'grayhen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'graylag': {'n_is_sb': '3', 'n_is_sth': '3'},
 'grazier': {'n_is_sb': '0'},
 'grease monkey': {'n_is_sb': '0'},
 'greaseball': {'n_is_sb': '2', 'n_is_sth': '2'},
 'great anteater': {'n_is_sb': '3', 'n_is_sth': '3'},
 'great ape': {'n_is_sb': '3', 'n_is_sth': '3'},
 'great auk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'great barracuda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'great black-backed gull': {'n_is_sb': '3', 'n_is_sth': '3'},
 'great blue heron': {'n_is_sb': '3', 'n_is_sth': '3'},
 'great blue shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'great bowerbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'great bustard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'great crested grebe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'great dane': {'n_is_sb': '3', 'n_is_sth': '3'},
 'great grandfather': {'n_is_sb': '3', 'n_is_sth': '3'},
 'great grandmother': {'n_is_sb': '0'},
 'great grandparent': {'n_is_sb': '0'},
 'great gray kangaroo': {'n_is_sb': '0'},
 'great gray owl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'great horned owl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'great mother': {'n_is_sb': '0'},
 'great pyrenees': {'n_is_sb': '3', 'n_is_sth': '3'},
 'great russian': {'n_is_sb': '0'},
 'great skua': {'n_is_sb': '3', 'n_is_sth': '3'},
 'great snipe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'great white heron': {'n_is_sb': '3', 'n_is_sth': '3'},
 'great white hope': {'n_is_sb': '0'},
 'great white shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'great-niece': {'n_is_sb': '0'},
 'great-uncle': {'n_is_sb': '0'},
 'greater kudu': {'n_is_sb': '3', 'n_is_sth': '3'},
 'greater pichiciego': {'n_is_sb': '3', 'n_is_sth': '3'},
 'greater prairie chicken': {'n_is_sb': '3', 'n_is_sth': '3'},
 'greater scaup': {'n_is_sb': '3', 'n_is_sth': '3'},
 'greater whitethroat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'greater yellowlegs': {'n_is_sb': '3', 'n_is_sth': '3'},
 'grebe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'greco-roman deity': {'n_is_sb': '0'},
 'greco': {'n_is_sb': '0'},
 'greek catholic': {'n_is_sb': '0'},
 'greek deity': {'n_is_sb': '0'},
 'greek partridge': {'n_is_sb': '3', 'n_is_sth': '3'},
 'greeley': {'n_is_sb': '2', 'n_is_sth': '2'},
 'green algae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'green apple aphid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'green beret': {'n_is_sb': '2', 'n_is_sth': '2'},
 'green frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'green june beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'green lacewing': {'n_is_sb': '3', 'n_is_sth': '3'},
 'green lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'green mamba': {'n_is_sb': '3', 'n_is_sth': '3'},
 'green monkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'green peach aphid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'green peafowl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'green plover': {'n_is_sb': '3', 'n_is_sth': '3'},
 'green snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'green turtle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'green woodpecker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'green-tailed towhee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'green-winged teal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'greenberg': {'n_is_sb': '0'},
 'greenbottle fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'greenbottle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'greeneye': {'n_is_sb': '3', 'n_is_sth': '3'},
 'greene': {'n_is_sb': '0'},
 'greenfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'greengrocer': {'n_is_sb': '0', 'nc_typical': ''},
 'greenhouse whitefly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'greenland caribou': {'n_is_sb': '3', 'n_is_sth': '3'},
 'greenland whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'greenling': {'n_is_sb': '3', 'n_is_sth': '3'},
 'greenshank': {'n_is_sb': '3', 'n_is_sth': '3'},
 'greenskeeper': {'n_is_sb': '0'},
 'greenwing': {'n_is_sb': '3', 'n_is_sth': '3'},
 'greeter': {'n_is_sb': '0'},
 'greg norman': {'n_is_sb': '0'},
 'gregarine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gregor mendel': {'n_is_sb': '0'},
 'gregory goodwin pincus': {'n_is_sb': '0'},
 'gregory i': {'n_is_sb': '0'},
 'gregory john norman': {'n_is_sb': '0'},
 'gregory nazianzen': {'n_is_sb': '0'},
 'gregory of nazianzen': {'n_is_sb': '0'},
 'gregory pincus': {'n_is_sb': '0'},
 'gregory the great': {'n_is_sb': '0'},
 'gregory vii': {'n_is_sb': '0'},
 'gregory xiii': {'n_is_sb': '0'},
 'gregory': {'n_is_sb': '0'},
 'grenade thrower': {'n_is_sb': '0'},
 'grenadian': {'n_is_sb': '0'},
 'grenadier': {'n_is_sb': '0'},
 'gresham': {'n_is_sb': '0'},
 'greta garbo': {'n_is_sb': '0'},
 'greta louisa gustafsson': {'n_is_sb': '0'},
 'gretzky': {'n_is_sb': '0'},
 "grevy's zebra": {'n_is_sb': '3', 'n_is_sth': '3'},
 'grey fox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'greybeard': {'n_is_sb': '0'},
 'greyhound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'greylag goose': {'n_is_sb': '3', 'n_is_sth': '3'},
 'greylag': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gridiron-tailed lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'grieg': {'n_is_sb': '0'},
 'griever': {'n_is_sb': '0'},
 'griffith': {'n_is_sb': '0'},
 'griffon vulture': {'n_is_sb': '3', 'n_is_sth': '3'},
 'griffon': {'n_is_sb': '2', 'n_is_sth': '2'},
 'grigori efimovich rasputin': {'n_is_sb': '0'},
 'grim reaper': {'n_is_sb': '0'},
 'grimm': {'n_is_sb': '0'},
 'grindle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gringo': {'n_is_sb': '0'},
 'grinner': {'n_is_sb': '0'},
 'griot': {'n_is_sb': '0'},
 'grison vittatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'grison': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gris': {'n_is_sb': '2', 'n_is_sth': '2'},
 'grivet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'grizzly bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'grizzly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'groaner': {'n_is_sb': '0'},
 'grocery boy': {'n_is_sb': '0'},
 'grocer': {'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'groenendael': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gromyko': {'n_is_sb': '0'},
 'groom-to-be': {'n_is_sb': '0'},
 'gropius': {'n_is_sb': '0'},
 'gros ventre': {'n_is_sb': '2', 'n_is_sth': '2'},
 'grosbeak': {'n_is_sb': '3', 'n_is_sth': '3'},
 'grossbeak': {'n_is_sb': '3', 'n_is_sth': '3'},
 'groucho': {'n_is_sb': '0'},
 'ground beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ground rattler': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ground roller': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ground sloth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ground snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ground squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ground-shaker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'groundbreaker': {'n_is_sb': '0'},
 'groundfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'groundkeeper': {'n_is_sb': '0'},
 'groundling': {'n_is_sb': '2', 'n_is_sth': '2'},
 'groundskeeper': {'n_is_sb': '0'},
 'groundsman': {'n_is_sb': '0'},
 'group captain': {'n_is_sb': '0'},
 'groupie': {'n_is_sb': '0'},
 'groveler': {'n_is_sb': '0'},
 'groveller': {'n_is_sb': '0'},
 'grover cleveland': {'n_is_sb': '0'},
 'groves': {'n_is_sb': '0'},
 'growler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'grownup': {'n_is_sb': '0'},
 'grubby': {'n_is_sb': '3', 'n_is_sth': '3', 'jj_to_jjr': 'grubbier', 'jj_to_jjs': 'grubbiest'},
 'grumbler': {'n_is_sb': '0'},
 'grunter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'grus americana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'grus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'gryphon': {'n_is_sb': '0'},
 'guacharo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'guadalupe fur seal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'guanaco': {'n_is_sb': '3', 'n_is_sth': '3'},
 'guano bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'guarani': {'n_is_sb': '2', 'n_is_sth': '2'},
 'guard dog': {'n_is_sb': '0'},
 'guard of honor': {'n_is_sb': '0'},
 'guardian angel': {'n_is_sb': '0'},
 'guardian spirit': {'n_is_sb': '0'},
 'guarnerius': {'n_is_sb': '2', 'n_is_sth': '2'},
 'guarneri': {'n_is_sb': '0'},
 'guarnieri': {'n_is_sb': '0'},
 'guatemalan': {'n_is_sb': '0'},
 'gudgeon': {'n_is_sb': '2', 'n_is_sth': '2'},
 'guenevere': {'n_is_sb': '0'},
 'guenon monkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'guenon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'guereza': {'n_is_sb': '3', 'n_is_sth': '3'},
 'guerilla': {'n_is_sb': '0'},
 'guernsey': {'n_is_sb': '2', 'n_is_sth': '2'},
 'guerrilla': {'n_is_sb': '2', 'n_is_sth': '2'},
 'guesser': {'n_is_sb': '0'},
 'guest of honor': {'n_is_sb': '0'},
 'guest worker': {'n_is_sb': '0'},
 'guestworker': {'n_is_sb': '0'},
 'guevara': {'n_is_sb': '0'},
 'guggenheim': {'n_is_sb': '0'},
 'guglielmo marconi': {'n_is_sb': '0'},
 'guib': {'n_is_sb': '3', 'n_is_sth': '3'},
 'guide dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'guiding light': {'n_is_sb': '0'},
 'guillaume apollinaire': {'n_is_sb': '0'},
 'guillemot': {'n_is_sb': '2', 'n_is_sth': '2'},
 'guinea fowl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'guinea hen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'guinea pig': {'n_is_sb': '3', 'n_is_sth': '3'},
 'guinea worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'guinean': {'n_is_sb': '0'},
 'guinevere': {'n_is_sb': '0'},
 'guinness': {'n_is_sb': '2', 'n_is_sth': '2'},
 'guiseppe fortunino francesco verdi': {'n_is_sb': '0'},
 'guiseppe guarneri': {'n_is_sb': '0'},
 'guitar player': {'n_is_sb': '0'},
 'guitarfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'guitarist': {'n_is_sb': '0'},
 'gujerati': {'n_is_sb': '2', 'n_is_sth': '2'},
 'gula': {'n_is_sb': '2', 'n_is_sth': '2'},
 'gulfweed': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gulliver': {'n_is_sb': '0'},
 'gulo gulo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gulo luscus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gulper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gun dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gun for hire': {'n_is_sb': '0'},
 'gun moll': {'n_is_sb': '0'},
 'gunman': {'n_is_sb': '0'},
 'gunnar myrdal': {'n_is_sb': '0'},
 'gunnel': {'n_is_sb': '2', 'n_is_sth': '2'},
 'gunnery sergeant': {'n_is_sb': '0'},
 'gunrunner': {'n_is_sb': '0'},
 'gunsmith': {'n_is_sb': '0'},
 'gunter grass': {'n_is_sb': '0'},
 'gunter wilhelm grass': {'n_is_sb': '0'},
 'guppy': {'n_is_sb': '2', 'n_is_sth': '2'},
 'gurkha': {'n_is_sb': '0'},
 'gurnard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'guru nanak': {'n_is_sb': '0'},
 'gustav hertz': {'n_is_sb': '0'},
 'gustav klimt': {'n_is_sb': '0'},
 'gustav ludwig hertz': {'n_is_sb': '0'},
 'gustav mahler': {'n_is_sb': '0'},
 'gustav robert kirchhoff': {'n_is_sb': '0'},
 'gustav theodor fechner': {'n_is_sb': '0'},
 'gustave courbet': {'n_is_sb': '0'},
 'gustave flaubert': {'n_is_sb': '0'},
 'gustavus adolphus': {'n_is_sb': '0'},
 'gustavus franklin swift': {'n_is_sb': '0'},
 'gustavus ii': {'n_is_sb': '0'},
 'gustavus i': {'n_is_sb': '0'},
 'gustavus v': {'n_is_sb': '0'},
 'gustavus': {'n_is_sb': '0'},
 'gutenberg': {'n_is_sb': '0'},
 'guthrie': {'n_is_sb': '0'},
 'guttersnipe': {'n_is_sb': '0'},
 'guvnor': {'n_is_sb': '0'},
 'guy de maupassant': {'n_is_sb': '0'},
 'guy fawkes': {'n_is_sb': '0'},
 'guyanese': {'n_is_sb': '0'},
 'gwydion': {'n_is_sb': '0'},
 'gwynn': {'n_is_sb': '0'},
 'gwyn': {'n_is_sb': '0'},
 'gym rat': {'n_is_sb': '0'},
 'gymnast': {'n_is_sb': '0'},
 'gymnelis viridis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gymnogyps californianus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gymnogyps': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gymnorhina tibicen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gymnosophist': {'n_is_sb': '0'},
 'gymnura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gynaecologist': {'n_is_sb': '0'},
 'gynandromorph': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gynecologist': {'n_is_sb': '0'},
 'gynne': {'n_is_sb': '0'},
 'gypaetus barbatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gyps fulvus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gypsy moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gypsy rose lee': {'n_is_sb': '0'},
 'gyps': {'n_is_sb': '2', 'n_is_sth': '2'},
 'gyrfalcon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'gywn': {'n_is_sb': '0'},
 'h. g. wells': {'n_is_sb': '0'},
 'h. h. munro': {'n_is_sb': '0'},
 'h. j. eysenck': {'n_is_sb': '0'},
 'h. l. mencken': {'n_is_sb': '0'},
 'h. pylori': {'n_is_sb': '3', 'n_is_sth': '3'},
 'habakkuk': {'n_is_sb': '2', 'n_is_sth': '2'},
 'haberdasher': {'n_is_sb': '0'},
 'haber': {'n_is_sb': '0'},
 'habitual criminal': {'n_is_sb': '0'},
 'hablot knight browne': {'n_is_sb': '0'},
 'hachiman': {'n_is_sb': '0'},
 'hack driver': {'n_is_sb': '0'},
 'hack writer': {'n_is_sb': '0'},
 'hack-driver': {'n_is_sb': '0'},
 'hackee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haddock': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hadji': {'n_is_sb': '0'},
 'hadrian': {'n_is_sb': '0'},
 'hadrosauridae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hadrosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hadrosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haeckel': {'n_is_sb': '0'},
 'haematobia irritans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haematologist': {'n_is_sb': '0'},
 'haematopodidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haemophile': {'n_is_sb': '0'},
 'haemophiliac': {'n_is_sb': '0'},
 'haemopis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haemoproteidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haemoproteid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haemosporidian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haemulidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haemulon album': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haemulon aurolineatum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haemulon macrostomum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haemulon malanurum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haemulon parra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hagfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haggai': {'n_is_sb': '0'},
 'haggard': {'n_is_sb': '2', 'n_is_sth': '2'},
 'haggler': {'n_is_sb': '0'},
 'hagiographer': {'n_is_sb': '0'},
 'hagiographist': {'n_is_sb': '0'},
 'hagiologist': {'n_is_sb': '0'},
 'hahn': {'n_is_sb': '0'},
 'haida': {'n_is_sb': '2', 'n_is_sth': '2'},
 'haile selassie': {'n_is_sb': '0'},
 'hair seal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hair-tailed mole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hairsplitter': {'n_is_sb': '0'},
 'hairstreak butterfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hairstreak': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hairstylist': {'n_is_sb': '0'},
 'hairtail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hairy-legged vampire bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haitian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'haji': {'n_is_sb': '0'},
 'hajji': {'n_is_sb': '0'},
 'hakeem': {'n_is_sb': '0'},
 'hake': {'n_is_sb': '2', 'n_is_sth': '2'},
 'halberdier': {'n_is_sb': '0'},
 'halchidhoma': {'n_is_sb': '0'},
 'haldane': {'n_is_sb': '0'},
 'haldea striatula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haldea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'halevy': {'n_is_sb': '0'},
 'haley': {'n_is_sb': '0'},
 'hale': {'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'half blood': {'n_is_sb': '0'},
 'half sister': {'n_is_sb': '0'},
 'half snipe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'half-brother': {'n_is_sb': '0'},
 'half-caste': {'n_is_sb': '0'},
 'half-pint': {'n_is_sb': '2', 'n_is_sth': '2'},
 'halfbeak': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haliaeetus leucocephalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haliaeetus leucorhyphus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haliaeetus pelagicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haliatus albicilla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'halibut': {'n_is_sb': '3', 'n_is_sth': '3'},
 'halicoeres bivittatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'halicoeres radiatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haliotidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haliotis tuberculata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haliotis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hall porter': {'n_is_sb': '0'},
 'halley': {'n_is_sb': '0'},
 'halobacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'halobacterium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'halobacter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'halophile': {'n_is_sb': '3', 'n_is_sth': '3'},
 'halophil': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ham actor': {'n_is_sb': '0'},
 'hamadryad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haman': {'n_is_sb': '0'},
 'haminoea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hammarskjold': {'n_is_sb': '0'},
 'hammerhead shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hammerstein': {'n_is_sb': '0'},
 'hammett': {'n_is_sb': '0'},
 'hammurabi': {'n_is_sb': '0'},
 'hammurapi': {'n_is_sb': '0'},
 'hampshire down': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hampshire': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hampton': {'n_is_sb': '0'},
 'hamsun': {'n_is_sb': '0'},
 'hancock': {'n_is_sb': '2', 'n_is_sth': '2'},
 'handel': {'n_is_sb': '0'},
 'handicapped person': {'n_is_sb': '0'},
 'handicapper': {'n_is_sb': '0'},
 'handmaiden': {'n_is_sb': '0'},
 'handsaw fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'handwriting expert': {'n_is_sb': '0'},
 'handy': {'n_is_sb': '0', 'jj_to_jjr': 'handier', 'jj_to_jjs': 'handiest'},
 'hang glider': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hangbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hanging fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hank aaron': {'n_is_sb': '0'},
 'hank williams': {'n_is_sb': '0'},
 'hanks': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hannah arendt': {'n_is_sb': '0'},
 'hannibal': {'n_is_sb': '0'},
 'hanoverian': {'n_is_sb': '0'},
 'hans adolf krebs': {'n_is_sb': '0'},
 'hans albrecht bethe': {'n_is_sb': '0'},
 'hans arp': {'n_is_sb': '0'},
 'hans bethe': {'n_is_sb': '0'},
 'hans c. j. gram': {'n_is_sb': '0'},
 'hans christian andersen': {'n_is_sb': '0'},
 'hans christian oersted': {'n_is_sb': '0'},
 'hans conrad julius reiter': {'n_is_sb': '0'},
 'hans eysenck': {'n_is_sb': '0'},
 'hans fischer': {'n_is_sb': '0'},
 'hans geiger': {'n_is_sb': '0'},
 'hans holbein': {'n_is_sb': '0'},
 'hans jurgen eysenck': {'n_is_sb': '0'},
 'hans zinsser': {'n_is_sb': '0'},
 'hanuman': {'n_is_sb': '2', 'n_is_sth': '2'},
 'haplosporidian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'haranguer': {'n_is_sb': '0'},
 'harasser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'harbor porpoise': {'n_is_sb': '3', 'n_is_sth': '3'},
 'harbor seal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hard hat': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hard tick': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hard worker': {'n_is_sb': '0'},
 'hard-shell clam': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hard-shell crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'harding': {'n_is_sb': '0'},
 'hardwareman': {'n_is_sb': '0'},
 'hardy': {'n_is_sb': '2', 'n_is_sth': '2', 'jj_to_jjr': 'hardier', 'jj_to_jjs': 'hardiest'},
 'hare krishna': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hare wallaby': {'n_is_sb': '3', 'n_is_sth': '3'},
 'harefoot': {'n_is_sb': '0'},
 'hargreaves': {'n_is_sb': '0'},
 'harijan': {'n_is_sb': '0'},
 'harlan fiske stone': {'n_is_sb': '0'},
 'harlean carpenter': {'n_is_sb': '0'},
 'harlequin-snake': {'n_is_sb': '0'},
 'harley granville-barker': {'n_is_sb': '0'},
 'harlow shapley': {'n_is_sb': '0'},
 'harlow': {'n_is_sb': '0'},
 'harmoniser': {'n_is_sb': '0'},
 'harmonizer': {'n_is_sb': '0'},
 'harmsworth': {'n_is_sb': '0'},
 'harness horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'harnessed antelope': {'n_is_sb': '3', 'n_is_sth': '3'},
 'harold clayton lloyd': {'n_is_sb': '0'},
 'harold clayton urey': {'n_is_sb': '0'},
 'harold harefoot': {'n_is_sb': '0'},
 'harold hart crane': {'n_is_sb': '0'},
 'harold hirschsprung': {'n_is_sb': '0'},
 'harold ii': {'n_is_sb': '0'},
 'harold i': {'n_is_sb': '0'},
 'harold kroto': {'n_is_sb': '0'},
 'harold lloyd': {'n_is_sb': '0'},
 'harold nicolson': {'n_is_sb': '0'},
 'harold pinter': {'n_is_sb': '0'},
 'harold urey': {'n_is_sb': '0'},
 'harold w. kroto': {'n_is_sb': '0'},
 'harp seal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'harper': {'n_is_sb': '0'},
 'harpia harpyja': {'n_is_sb': '3', 'n_is_sth': '3'},
 'harpist': {'n_is_sb': '0'},
 'harpooneer': {'n_is_sb': '0'},
 'harpooner': {'n_is_sb': '0'},
 'harpo': {'n_is_sb': '0'},
 'harpsichordist': {'n_is_sb': '0'},
 'harpy bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'harpy eagle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'harpy': {'n_is_sb': '0'},
 'harridan': {'n_is_sb': '0'},
 'harrier eagle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'harriet beecher stowe': {'n_is_sb': '0'},
 'harriet elizabeth beecher stowe': {'n_is_sb': '0'},
 'harriet tubman': {'n_is_sb': '0'},
 'harriet wilson': {'n_is_sb': '0'},
 'harriman': {'n_is_sb': '0'},
 'harrison': {'n_is_sb': '0'},
 'harris': {'n_is_sb': '0'},
 'harrod': {'n_is_sb': '0'},
 'harry bridges': {'n_is_sb': '0'},
 'harry f. klinefelter': {'n_is_sb': '0'},
 'harry fitch kleinfelter': {'n_is_sb': '0'},
 'harry hotspur': {'n_is_sb': '0'},
 'harry houdini': {'n_is_sb': '0'},
 'harry lauder': {'n_is_sb': '0'},
 'harry lillis crosby': {'n_is_sb': '0'},
 'harry s truman': {'n_is_sb': '0'},
 'harry sinclair lewis': {'n_is_sb': '0'},
 'harry stack sullivan': {'n_is_sb': '0'},
 'harry truman': {'n_is_sb': '0'},
 'hart crane': {'n_is_sb': '0'},
 'hartebeest': {'n_is_sb': '3', 'n_is_sth': '3'},
 'harte': {'n_is_sb': '0'},
 'hartley': {'n_is_sb': '0'},
 'hart': {'n_is_sb': '2', 'n_is_sth': '2'},
 'harum-scarum': {'n_is_sb': '2', 'n_is_sth': '2'},
 'harvard': {'n_is_sb': '2', 'n_is_sth': '2'},
 'harvery williams cushing': {'n_is_sb': '0'},
 'harvest fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'harvest mite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'harvest mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'harvestfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'harvestman': {'n_is_sb': '2', 'n_is_sth': '2'},
 'harvey cushing': {'n_is_sb': '0'},
 'harvey': {'n_is_sb': '0'},
 'has-been': {'n_is_sb': '0'},
 'hasdrubal': {'n_is_sb': '0'},
 'hasek': {'n_is_sb': '0'},
 'hash head': {'n_is_sb': '0'},
 'hasid': {'n_is_sb': '0'},
 'hassam': {'n_is_sb': '0'},
 'hassel': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hassid': {'n_is_sb': '0'},
 'hastings': {'n_is_sb': '0'},
 'hatcheck girl': {'n_is_sb': '0'},
 'hatchet man': {'n_is_sb': '0'},
 'hatchling': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hatemonger': {'n_is_sb': '0'},
 'hater': {'n_is_sb': '0'},
 'hathaway': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hatmaker': {'n_is_sb': '0'},
 'haulier': {'n_is_sb': '0'},
 'hausa': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hausen': {'n_is_sb': '2', 'n_is_sth': '2'},
 'haussa': {'n_is_sb': '2', 'n_is_sth': '2'},
 'havasupai': {'n_is_sb': '2', 'n_is_sth': '2'},
 'havel': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hawaiian honeycreeper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hawaiian': {'n_is_sb': '2', 'cap_word': 'Hawaiian', 'n_is_sth': '2'},
 'hawfinch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hawk moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hawk owl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hawkbill': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hawkins': {'n_is_sb': '0'},
 'hawkmoth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hawksbill turtle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hawkshaw': {'n_is_sb': '0'},
 'hawkyns': {'n_is_sb': '0'},
 'haworth': {'n_is_sb': '0'},
 'hawthorne': {'n_is_sb': '0'},
 'hay bacillus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hayek': {'n_is_sb': '0'},
 'hayes': {'n_is_sb': '0'},
 'haym salomon': {'n_is_sb': '0'},
 'hayseed': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hays': {'n_is_sb': '0'},
 'haywood': {'n_is_sb': '0'},
 'hazan': {'n_is_sb': '0'},
 'hazel mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hazlitt': {'n_is_sb': '0'},
 'he-goat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'head honcho': {'n_is_sb': '0'},
 'head linesman': {'n_is_sb': '0'},
 'head louse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'head nurse': {'n_is_sb': '0'},
 'head of household': {'n_is_sb': '0'},
 'head of state': {'n_is_sb': '0'},
 'head teacher': {'n_is_sb': '0'},
 'head-shrinker': {'n_is_sb': '0'},
 'headcounter': {'n_is_sb': '0'},
 'headfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'headhunter': {'n_is_sb': '0'},
 'headliner': {'n_is_sb': '0'},
 'headsman': {'n_is_sb': '0'},
 'healer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'health care provider': {'n_is_sb': '0'},
 'health professional': {'n_is_sb': '0'},
 'hearing dog': {'n_is_sb': '0'},
 'hearing examiner': {'n_is_sb': '0'},
 'hearing officer': {'n_is_sb': '0'},
 'hearst': {'n_is_sb': '0'},
 'heart specialist': {'n_is_sb': '0'},
 'heart surgeon': {'n_is_sb': '0'},
 'heart urchin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'heath hen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'heathfowl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'heavenly jewel': {'n_is_sb': '0'},
 'heaver': {'n_is_sb': '2', 'confu_pair': 'heavier', 'n_is_sth': '2'},
 'heaviside': {'n_is_sb': '0'},
 'heavy hitter': {'n_is_sb': '0'},
 'heavyweight': {'n_is_sb': '0'},
 'hebbel': {'n_is_sb': '0'},
 'hebe': {'n_is_sb': '0'},
 'hebraist': {'n_is_sb': '0'},
 'hecate': {'n_is_sb': '0'},
 'hecht': {'n_is_sb': '0'},
 'heckler': {'n_is_sb': '0'},
 'hector berlioz': {'n_is_sb': '0'},
 'hector hevodidbon': {'n_is_sb': '0'},
 'hector hugh munro': {'n_is_sb': '0'},
 'hector': {'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'hedge sparrow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hedger': {'n_is_sb': '0'},
 'hedonist': {'n_is_sb': '0'},
 'hegel': {'n_is_sb': '0'},
 'heidegger': {'n_is_sb': '0'},
 'heidelberg man': {'n_is_sb': '0'},
 'heimdallr': {'n_is_sb': '0'},
 'heimdall': {'n_is_sb': '0'},
 'heimdal': {'n_is_sb': '0'},
 'heinlein': {'n_is_sb': '0'},
 'heinrich boll': {'n_is_sb': '0'},
 'heinrich engelhard steinway': {'n_is_sb': '0'},
 'heinrich hertz': {'n_is_sb': '0'},
 'heinrich himmler': {'n_is_sb': '0'},
 'heinrich rudolph hertz': {'n_is_sb': '0'},
 'heinrich schliemann': {'n_is_sb': '0'},
 'heinrich theodor boll': {'n_is_sb': '0'},
 'heinrich von kleist': {'n_is_sb': '0'},
 'heinz': {'n_is_sb': '2', 'n_is_sth': '2'},
 'heir apparent': {'n_is_sb': '0'},
 'heir presumptive': {'n_is_sb': '0'},
 'heir-at-law': {'n_is_sb': '0'},
 'heiress': {'n_is_sb': '0'},
 'heisenberg': {'n_is_sb': '0'},
 'heitor villa-lobos': {'n_is_sb': '0'},
 'hela': {'n_is_sb': '2', 'n_is_sth': '2'},
 'helen adams keller': {'n_is_sb': '0'},
 'helen hayes': {'n_is_sb': '0'},
 'helen hunt jackson': {'n_is_sb': '0'},
 'helen keller': {'n_is_sb': '0'},
 'helen laura sumner woodbury': {'n_is_sb': '0'},
 'helen maria fiske hunt jackson': {'n_is_sb': '0'},
 'helen newington wills': {'n_is_sb': '0'},
 'helen of troy': {'n_is_sb': '0'},
 'helen porter mitchell': {'n_is_sb': '0'},
 'helen traubel': {'n_is_sb': '0'},
 'helen wills moody': {'n_is_sb': '0'},
 'helen wills': {'n_is_sb': '0'},
 'helicidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'heliobacter pylori': {'n_is_sb': '3', 'n_is_sth': '3'},
 'heliobacter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'helios': {'n_is_sb': '0'},
 'heliothis moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'heliothis zia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'heliozoan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'helix aspersa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'helix hortensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'helix pomatia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hell-kite': {'n_is_sb': '0'},
 'hell-rooster': {'n_is_sb': '0'},
 'hellbender': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hellene': {'n_is_sb': '0'},
 'helleri': {'n_is_sb': '3', 'n_is_sth': '3'},
 'heller': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hellgrammiate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hellman': {'n_is_sb': '0'},
 'helmholtz': {'n_is_sb': '0'},
 'helminth': {'n_is_sb': '0'},
 'helmut heinrich waldemar schmidt': {'n_is_sb': '0'},
 'helmut schmidt': {'n_is_sb': '0'},
 'heloderma horridum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'heloderma suspectum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'heloise': {'n_is_sb': '0'},
 'helot': {'n_is_sb': '0'},
 'hel': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hemachatus haemachatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hemachatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hematologist': {'n_is_sb': '0'},
 'hemerobiid fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hemerobiidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hemerobiid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hemigalus hardwickii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hemigalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hemigrammus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hemimetabola': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hemingway': {'n_is_sb': '0'},
 'heming': {'n_is_sb': '0'},
 'hemiplegic': {'n_is_sb': '0'},
 'hemipode': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hemipteran': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hemiptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hemipteronatus novacula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hemipteronatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hemipteron': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hemipterous insect': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hemitripterus americanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hemitripterus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hemminge': {'n_is_sb': '0'},
 'hemophile': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hemophiliac': {'n_is_sb': '0'},
 'hen harrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hen hawk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hendrik antoon lorentz': {'n_is_sb': '0'},
 'hendrik frensch verwoerd': {'n_is_sb': '0'},
 'hendrik petrus berlage': {'n_is_sb': '0'},
 'hendrik verwoerd': {'n_is_sb': '0'},
 'hendrix': {'n_is_sb': '2', 'n_is_sth': '2'},
 'henri becquerel': {'n_is_sb': '0'},
 'henri bergson': {'n_is_sb': '0'},
 'henri clemens van de velde': {'n_is_sb': '0'},
 'henri emile benoit matisse': {'n_is_sb': '0'},
 'henri labrouste': {'n_is_sb': '0'},
 'henri louis bergson': {'n_is_sb': '0'},
 'henri matisse': {'n_is_sb': '0'},
 'henri rene albert guy de maupassant': {'n_is_sb': '0'},
 'henri rousseau': {'n_is_sb': '0'},
 'henri toulouse-lautrec': {'n_is_sb': '0'},
 'henri van de velde': {'n_is_sb': '0'},
 'henriette rosine bernard': {'n_is_sb': '0'},
 'henrik ibsen': {'n_is_sb': '0'},
 'henrik johan ibsen': {'n_is_sb': '0'},
 'henry alfred kissinger': {'n_is_sb': '0'},
 'henry beauclerc': {'n_is_sb': '0'},
 'henry bolingbroke': {'n_is_sb': '0'},
 'henry cavendish': {'n_is_sb': '0'},
 'henry clay frick': {'n_is_sb': '0'},
 'henry clay': {'n_is_sb': '0'},
 'henry david thoreau': {'n_is_sb': '0'},
 'henry engelhard steinway': {'n_is_sb': '0'},
 'henry fielding': {'n_is_sb': '0'},
 'henry fonda': {'n_is_sb': '0'},
 'henry ford ii': {'n_is_sb': '0'},
 'henry ford': {'n_is_sb': '0'},
 'henry graham greene': {'n_is_sb': '0'},
 'henry hobson richardson': {'n_is_sb': '0'},
 'henry hubert turner': {'n_is_sb': '0'},
 'henry hudson': {'n_is_sb': '0'},
 'henry iii': {'n_is_sb': '0'},
 'henry ii': {'n_is_sb': '0'},
 'henry iv': {'n_is_sb': '0'},
 'henry i': {'n_is_sb': '0'},
 'henry james': {'n_is_sb': '0'},
 'henry john heinz': {'n_is_sb': '0'},
 'henry kenneth alfred russell': {'n_is_sb': '0'},
 'henry kissinger': {'n_is_sb': '0'},
 'henry laurens': {'n_is_sb': '0'},
 'henry le chatelier': {'n_is_sb': '0'},
 'henry lee': {'n_is_sb': '0'},
 'henry louis aaron': {'n_is_sb': '0'},
 'henry louis gehrig': {'n_is_sb': '0'},
 'henry louis mencken': {'n_is_sb': '0'},
 'henry luce': {'n_is_sb': '0'},
 'henry m. robert': {'n_is_sb': '0'},
 'henry m. stanley': {'n_is_sb': '0'},
 'henry martyn robert': {'n_is_sb': '0'},
 'henry miller': {'n_is_sb': '0'},
 'henry moore': {'n_is_sb': '0'},
 'henry morgan': {'n_is_sb': '0'},
 'henry norris russell': {'n_is_sb': '0'},
 'henry oscar houghton': {'n_is_sb': '0'},
 'henry purcell': {'n_is_sb': '0'},
 'henry robinson luce': {'n_is_sb': '0'},
 'henry rowe schoolcraft': {'n_is_sb': '0'},
 'henry russell': {'n_is_sb': '0'},
 'henry spencer moore': {'n_is_sb': '0'},
 'henry steinway': {'n_is_sb': '0'},
 'henry sweet': {'n_is_sb': '0'},
 'henry tudor': {'n_is_sb': '0'},
 'henry valentine miller': {'n_is_sb': '0'},
 'henry viii': {'n_is_sb': '0'},
 'henry vii': {'n_is_sb': '0'},
 'henry villard': {'n_is_sb': '0'},
 'henry vi': {'n_is_sb': '0'},
 'henry v': {'n_is_sb': '0'},
 'henry wadsworth longfellow': {'n_is_sb': '0'},
 'henry ward beecher': {'n_is_sb': '0'},
 'henry watson fowler': {'n_is_sb': '0'},
 'henry wheeler shaw': {'n_is_sb': '0'},
 'henson': {'n_is_sb': '0'},
 'hepadnavirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hepatic tanager': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hepatitis a virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hepburn': {'n_is_sb': '0'},
 'hephaestus': {'n_is_sb': '0'},
 'hephaistos': {'n_is_sb': '0'},
 'hepworth': {'n_is_sb': '0'},
 'heracles': {'n_is_sb': '2', 'n_is_sth': '2'},
 'heraclitus': {'n_is_sb': '0'},
 'herakles': {'n_is_sb': '0'},
 'hera': {'n_is_sb': '0'},
 'herb doctor': {'n_is_sb': '0'},
 'herb simon': {'n_is_sb': '0'},
 'herbart': {'n_is_sb': '0'},
 'herbert a. simon': {'n_is_sb': '0'},
 'herbert alexander simon': {'n_is_sb': '0'},
 'herbert blythe': {'n_is_sb': '0'},
 'herbert clark hoover': {'n_is_sb': '0'},
 'herbert george wells': {'n_is_sb': '0'},
 'herbert hoover': {'n_is_sb': '0'},
 'herbert kitchener': {'n_is_sb': '0'},
 'herbert marcuse': {'n_is_sb': '0'},
 'herbert marshall mcluhan': {'n_is_sb': '0'},
 'herbert marx': {'n_is_sb': '0'},
 'herbert mclean evans': {'n_is_sb': '0'},
 'herbert spencer': {'n_is_sb': '0'},
 'herbert': {'n_is_sb': '0'},
 'herder': {'n_is_sb': '0'},
 'hereford': {'n_is_sb': '3', 'n_is_sth': '3'},
 'here': {'n_is_sb': '1'},
 'heritor': {'n_is_sb': '0'},
 'herman hollerith': {'n_is_sb': '0'},
 'herman melville': {'n_is_sb': '0'},
 'herman northrop frye': {'n_is_sb': '0'},
 'herman wouk': {'n_is_sb': '0'},
 'hermann goering': {'n_is_sb': '0'},
 'hermann goring': {'n_is_sb': '0'},
 'hermann hesse': {'n_is_sb': '0'},
 'hermann joseph muller': {'n_is_sb': '0'},
 'hermann ludwig ferdinand von helmholtz': {'n_is_sb': '0'},
 'hermann maurice saxe': {'n_is_sb': '0'},
 'hermann minkowski': {'n_is_sb': '0'},
 'hermann snellen': {'n_is_sb': '0'},
 'hermann von helmholtz': {'n_is_sb': '0'},
 'hermann wilhelm goring': {'n_is_sb': '0'},
 'hermann': {'n_is_sb': '0'},
 'herman': {'n_is_sb': '0'},
 'hermaphroditus': {'n_is_sb': '0'},
 'hermes': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hermissenda crassicornis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hermit crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hermit thrush': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hernan cortes': {'n_is_sb': '0'},
 'hernan cortez': {'n_is_sb': '0'},
 'hernando cortes': {'n_is_sb': '0'},
 'hernando cortez': {'n_is_sb': '0'},
 'hero of alexandria': {'n_is_sb': '0'},
 'hero worshiper': {'n_is_sb': '0'},
 'hero worshipper': {'n_is_sb': '0'},
 'herod the great': {'n_is_sb': '0'},
 'herodotus': {'n_is_sb': '0'},
 'herod': {'n_is_sb': '0'},
 'heroin addict': {'n_is_sb': '0'},
 'herpes simplex 1': {'n_is_sb': '3', 'n_is_sth': '3'},
 'herpes simplex 2': {'n_is_sb': '3', 'n_is_sth': '3'},
 'herpes simplex virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'herpes simplex': {'n_is_sb': '3', 'n_is_sth': '3'},
 'herpes varicella zoster virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'herpes varicella zoster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'herpes virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'herpes zoster virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'herpestes ichneumon': {'n_is_sb': '0'},
 'herpestes nyula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'herpestes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'herpetologist': {'n_is_sb': '0'},
 'herrerasaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'herrerasaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'herrick': {'n_is_sb': '0'},
 'herring gull': {'n_is_sb': '3', 'n_is_sth': '3'},
 'herring hog': {'n_is_sb': '0'},
 'herr': {'n_is_sb': '0'},
 'herschel': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hershey': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hertha': {'n_is_sb': '0'},
 'herzberg': {'n_is_sb': '0'},
 'hesiod': {'n_is_sb': '0'},
 'hesitater': {'n_is_sb': '0'},
 'hesitator': {'n_is_sb': '0'},
 'hesperides': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hesperiphona vespertina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hesperiphona': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hesse': {'n_is_sb': '0'},
 'hessian fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hess': {'n_is_sb': '0'},
 'hestia': {'n_is_sb': '0'},
 'heterocephalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'heterokontophyta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'heteropterous insect': {'n_is_sb': '3', 'n_is_sth': '3'},
 'heteroscelus incanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'heterosexual person': {'n_is_sb': '0'},
 'heterosexual': {'n_is_sb': '0'},
 'heterostracan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hevesy': {'n_is_sb': '0'},
 'hewer': {'n_is_sb': '0'},
 'hexagrammos decagrammus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hexamita': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hexanchus griseus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'heyerdahl': {'n_is_sb': '0'},
 'heyrovsky': {'n_is_sb': '0'},
 'heyse': {'n_is_sb': '0'},
 'heyward': {'n_is_sb': '0'},
 'hezekiah': {'n_is_sb': '0'},
 'hiawatha': {'n_is_sb': '0'},
 'hickock': {'n_is_sb': '0'},
 'hick': {'n_is_sb': '0'},
 'hidatsa': {'n_is_sb': '0'},
 'hideki yukawa': {'n_is_sb': '0'},
 'hideyo noguchi': {'n_is_sb': '0'},
 'hierarch': {'n_is_sb': '0'},
 'hieronymus bosch': {'n_is_sb': '0'},
 'hieronymus': {'n_is_sb': '0'},
 'higginson': {'n_is_sb': '0'},
 'high commissioner': {'n_is_sb': '0'},
 'high muckamuck': {'n_is_sb': '0'},
 'high priest': {'n_is_sb': '0'},
 'high roller': {'n_is_sb': '0'},
 'high stepper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'high-muck-a-muck': {'n_is_sb': '0'},
 'high-up': {'n_is_sb': '0'},
 'highbinder': {'n_is_sb': '0'},
 'highflier': {'n_is_sb': '2', 'n_is_sth': '2'},
 'highflyer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'highjacker': {'n_is_sb': '0'},
 'highlander': {'n_is_sb': '0'},
 'highway engineer': {'n_is_sb': '0'},
 'hiker': {'n_is_sb': '0'},
 'hilaire belloc': {'n_is_sb': '0'},
 'hilbert': {'n_is_sb': '0'},
 'hildebrand': {'n_is_sb': '0'},
 'hill myna': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hillary': {'n_is_sb': '0'},
 'himantopus himantopus leucocephalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'himantopus himantopus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'himantopus mexicanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'himantopus novae-zelandiae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'himantopus stilt': {'n_is_sb': '3', 'n_is_sth': '3'},
 'himmler': {'n_is_sb': '0'},
 'hinault': {'n_is_sb': '0'},
 'hinayanist': {'n_is_sb': '0'},
 'hindemith': {'n_is_sb': '0'},
 'hindenburg': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hindoo': {'n_is_sb': '0'},
 'hindu deity': {'n_is_sb': '0'},
 'hindustani': {'n_is_sb': '0'},
 'hindu': {'n_is_sb': '0', 'cap_word': 'Hindu'},
 'hinny': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hipparchus': {'n_is_sb': '0'},
 'hippobosca equina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hippocrates': {'n_is_sb': '0'},
 'hippodamia convergens': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hippoglossoides platessoides': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hippoglossus hippoglossus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hippoglossus stenolepsis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hippoglossus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hippolyte jean giraudoux': {'n_is_sb': '0'},
 'hippopotamus amphibius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hipposideros': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hippotragus niger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hipsurus caryi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hiram king williams': {'n_is_sb': '0'},
 'hiram ulysses grant': {'n_is_sb': '0'},
 'hiram williams': {'n_is_sb': '0'},
 'hired gun': {'n_is_sb': '0'},
 'hired hand': {'n_is_sb': '0'},
 'hired help': {'n_is_sb': '0'},
 'hired man': {'n_is_sb': '0'},
 'hirer': {'n_is_sb': '0'},
 'hirohito': {'n_is_sb': '0'},
 'hirschsprung': {'n_is_sb': '0'},
 'hirudinean': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hirudo medicinalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hirudo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hirundo nigricans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hirundo pyrrhonota': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hirundo rustica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hispanic american': {'n_is_sb': '0'},
 'hispanic': {'n_is_sb': '0', 'cap_word': 'Hispanic'},
 'hispid pocket mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hisser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'histologist': {'n_is_sb': '0'},
 'historiographer': {'n_is_sb': '0'},
 'histrion': {'n_is_sb': '0'},
 'hit man': {'n_is_sb': '0'},
 'hitchcock': {'n_is_sb': '0'},
 'hitchhiker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hitchings': {'n_is_sb': '0'},
 'hitchiti': {'n_is_sb': '0'},
 'hitman': {'n_is_sb': '0'},
 'hitter': {'n_is_sb': '0'},
 'hittite': {'n_is_sb': '0'},
 'hiv': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ho chi minh': {'n_is_sb': '0'},
 'hoactzin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hoagland howard carmichael': {'n_is_sb': '0'},
 'hoagland': {'n_is_sb': '0'},
 'hoagy carmichael': {'n_is_sb': '0'},
 'hoarder': {'n_is_sb': '0'},
 'hoary marmot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hoatzin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hoaxer': {'n_is_sb': '0'},
 'hobbes': {'n_is_sb': '0'},
 'hobbit': {'n_is_sb': '0'},
 'hobbledehoy': {'n_is_sb': '0'},
 'hobbler': {'n_is_sb': '0'},
 'hobbs': {'n_is_sb': '0'},
 'hockey coach': {'n_is_sb': '0'},
 'hockey player': {'n_is_sb': '0'},
 'hod carrier': {'n_is_sb': '0'},
 'hoder': {'n_is_sb': '0'},
 'hodgkin': {'n_is_sb': '0'},
 'hodman': {'n_is_sb': '0'},
 'hodr': {'n_is_sb': '0'},
 'hoenir': {'n_is_sb': '0'},
 'hoffa': {'n_is_sb': '0'},
 'hoffmannsthal': {'n_is_sb': '0'},
 'hoffmann': {'n_is_sb': '0'},
 'hoffman': {'n_is_sb': '0'},
 'hog badger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hog molly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hog snapper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hog sucker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hog-nosed badger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hog-nosed skunk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hogan': {'n_is_sb': '0'},
 'hogarth': {'n_is_sb': '0'},
 'hogchoker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hogfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hogget': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hogg': {'n_is_sb': '0'},
 'hognose bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hognose snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hognosed skunk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hoister': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hokan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hoka': {'n_is_sb': '0'},
 'hokusai': {'n_is_sb': '0'},
 'holbein the elder': {'n_is_sb': '0'},
 'holbein the younger': {'n_is_sb': '0'},
 'holbein': {'n_is_sb': '0'},
 'holdup man': {'n_is_sb': '0'},
 'holibut': {'n_is_sb': '3', 'n_is_sth': '3'},
 'holidaymaker': {'n_is_sb': '0'},
 'hollander': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hollerith': {'n_is_sb': '2', 'n_is_sth': '2'},
 'holman hunt': {'n_is_sb': '0'},
 'holmes': {'n_is_sb': '0'},
 'holocanthus tricolor': {'n_is_sb': '0'},
 'holocentrus ascensionis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'holocentrus bullisi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'holocentrus coruscus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'holocephalan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'holofernes': {'n_is_sb': '0'},
 'holothuria edulis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'holothurian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'holstein-friesian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'holstein': {'n_is_sb': '3', 'n_is_sth': '3'},
 'holy father': {'n_is_sb': '0'},
 'holy ghost': {'n_is_sb': '0'},
 'holy joe': {'n_is_sb': '0'},
 'holy man': {'n_is_sb': '0'},
 'holy person': {'n_is_sb': '0'},
 'holy roller': {'n_is_sb': '0'},
 'holy roman emperor frederick ii': {'n_is_sb': '0'},
 'holy roman emperor': {'n_is_sb': '0'},
 'holy spirit': {'n_is_sb': '0'},
 'holy terror': {'n_is_sb': '0'},
 'holy trinity': {'n_is_sb': '0'},
 'homarus americanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'homarus capensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'homarus vulgaris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'homarus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hombre': {'n_is_sb': '0'},
 'home buyer': {'n_is_sb': '0'},
 'home help': {'n_is_sb': '0'},
 'home secretary': {'n_is_sb': '0'},
 'home-builder': {'n_is_sb': '0'},
 'homebody': {'n_is_sb': '0'},
 'homeboy': {'n_is_sb': '0'},
 'homebuilder': {'n_is_sb': '0'},
 'homegirl': {'n_is_sb': '0'},
 'homeless person': {'n_is_sb': '0'},
 'homeless': {'n_is_sb': '0'},
 'homeopath': {'n_is_sb': '0'},
 'homeowner': {'n_is_sb': '0'},
 'homer a. thompson': {'n_is_sb': '0'},
 'homer armstrong thompson': {'n_is_sb': '0'},
 'homer thompson': {'n_is_sb': '0'},
 'homesteader': {'n_is_sb': '0'},
 'homing pigeon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hominoid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'homo erectus': {'n_is_sb': '0'},
 'homo habilis': {'n_is_sb': '0'},
 'homo heidelbergensis': {'n_is_sb': '0'},
 'homo rhodesiensis': {'n_is_sb': '0'},
 'homo sapiens neanderthalensis': {'n_is_sb': '0'},
 'homo sapiens sapiens': {'n_is_sb': '0'},
 'homo sapiens': {'n_is_sb': '0'},
 'homo soloensis': {'n_is_sb': '0'},
 'homocercal fin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'homoeopath': {'n_is_sb': '0'},
 'homona coffearia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'homona': {'n_is_sb': '3', 'n_is_sth': '3'},
 'homophobe': {'n_is_sb': '0'},
 'homopteran': {'n_is_sb': '3', 'n_is_sth': '3'},
 'homopterous insect': {'n_is_sb': '3', 'n_is_sth': '3'},
 'homosexual': {'n_is_sb': '0'},
 'homo': {'n_is_sb': '0'},
 'honduran': {'n_is_sb': '0'},
 'honegger': {'n_is_sb': '0'},
 'honest woman': {'n_is_sb': '0'},
 'honey badger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'honey bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'honey buzzard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'honey eater': {'n_is_sb': '3', 'n_is_sth': '3'},
 'honey guide': {'n_is_sb': '3', 'n_is_sth': '3'},
 'honeycreeper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'honeymooner': {'n_is_sb': '0'},
 'honeysucker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'honker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'honkey': {'n_is_sb': '0'},
 'honkie': {'n_is_sb': '0'},
 'honor guard': {'n_is_sb': '0'},
 'honore balzac': {'n_is_sb': '0'},
 'honore daumier': {'n_is_sb': '0'},
 'honore de balzac': {'n_is_sb': '0'},
 'honore-gabriel victor riqueti': {'n_is_sb': '0'},
 'honoree': {'n_is_sb': '0'},
 'hooded merganser': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hooded seal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hooded sheldrake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hooded skunk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hoofed mammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hooke': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hooky player': {'n_is_sb': '0'},
 'hoop snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hoopoe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hoopoo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hooray henry': {'n_is_sb': '0'},
 'hoosier': {'n_is_sb': '0'},
 'hoot owl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hoover': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hoper': {'n_is_sb': '0'},
 'hopi': {'n_is_sb': '0'},
 'hopkinson': {'n_is_sb': '0'},
 'hopkins': {'n_is_sb': '0'},
 'horace greeley': {'n_is_sb': '0'},
 'horace mann': {'n_is_sb': '0'},
 'horace walpole': {'n_is_sb': '0'},
 'horace': {'n_is_sb': '0'},
 'horatio alger': {'n_is_sb': '0'},
 'horatio herbert kitchener': {'n_is_sb': '0'},
 'horatio hornblower': {'n_is_sb': '0'},
 'horatio nelson': {'n_is_sb': '0'},
 'horatio walpole': {'n_is_sb': '0'},
 'horn fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horned asp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horned chameleon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horned dinosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horned lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horned owl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horned pout': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horned puffin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horned rattlesnake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horned screamer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horned toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horned viper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horned whiff': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hornist': {'n_is_sb': '0'},
 'hornpout': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horny frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horologer': {'n_is_sb': '0'},
 'horologist': {'n_is_sb': '0'},
 'horowitz': {'n_is_sb': '0'},
 'horse botfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horse doctor': {'n_is_sb': '0'},
 'horse fancier': {'n_is_sb': '0'},
 'horse fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horse mackerel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horse of the wood': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horse tick': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horse trader': {'n_is_sb': '0'},
 'horse wrangler': {'n_is_sb': '0'},
 'horse-head': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horseback rider': {'n_is_sb': '0'},
 'horsefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horsehead': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horseleech': {'n_is_sb': '2', 'n_is_sth': '2'},
 'horseshoe bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horseshoe crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horseshoe whipsnake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'horseshoer': {'n_is_sb': '0'},
 'horsewoman': {'n_is_sb': '0'},
 'horta': {'n_is_sb': '0'},
 'horus': {'n_is_sb': '0'},
 'hosea': {'n_is_sb': '0'},
 'hosier': {'n_is_sb': '0'},
 'hosni mubarak': {'n_is_sb': '0'},
 'hospital attendant': {'n_is_sb': '0'},
 'hospital chaplain': {'n_is_sb': '0'},
 'hosteller': {'n_is_sb': '0'},
 'hostile witness': {'n_is_sb': '0'},
 'hostler': {'n_is_sb': '0'},
 'hot dog': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hotei': {'n_is_sb': '0'},
 'hotel clerk': {'n_is_sb': '0'},
 'hotel desk clerk': {'n_is_sb': '0'},
 'hotel detective': {'n_is_sb': '0'},
 'hotel manager': {'n_is_sb': '0'},
 'hotelier': {'n_is_sb': '0'},
 'hotelkeeper': {'n_is_sb': '0'},
 'hotelman': {'n_is_sb': '0'},
 'hothr': {'n_is_sb': '0'},
 'hoth': {'n_is_sb': '0'},
 'hotspur': {'n_is_sb': '0'},
 'houdini': {'n_is_sb': '0'},
 'houghton': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hound dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'houri': {'n_is_sb': '0'},
 'house agent': {'n_is_sb': '0'},
 'house cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'house centipede': {'n_is_sb': '3', 'n_is_sth': '3'},
 'house decorator': {'n_is_sb': '0'},
 'house detective': {'n_is_sb': '0'},
 'house dick': {'n_is_sb': '0'},
 'house finch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'house guest': {'n_is_sb': '0'},
 'house husband': {'n_is_sb': '0'},
 'house martin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'house mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'house painter': {'n_is_sb': '0'},
 'house physician': {'n_is_sb': '0'},
 'house servant': {'n_is_sb': '0'},
 'house sitter': {'n_is_sb': '0'},
 'house snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'house sparrow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'house wren': {'n_is_sb': '3', 'n_is_sth': '3'},
 'house-builder': {'n_is_sb': '0'},
 'housebreaker': {'n_is_sb': '0'},
 'housebuilder': {'n_is_sb': '0'},
 'housedog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'housefather': {'n_is_sb': '0'},
 'houseguest': {'n_is_sb': '0'},
 'housemother': {'n_is_sb': '0'},
 'housewrecker': {'n_is_sb': '0'},
 'housing commissioner': {'n_is_sb': '0'},
 'housman': {'n_is_sb': '0'},
 'houyhnhnm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'howard carter': {'n_is_sb': '0'},
 'howard florey': {'n_is_sb': '0'},
 'howard hughes': {'n_is_sb': '0'},
 'howard lindsay': {'n_is_sb': '0'},
 'howard robard hughes': {'n_is_sb': '0'},
 'howard': {'n_is_sb': '0'},
 'howells': {'n_is_sb': '0'},
 'howe': {'n_is_sb': '2', 'n_is_sth': '2'},
 'howler monkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'howler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hoyden': {'n_is_sb': '0'},
 'hoyle': {'n_is_sb': '0'},
 'hrolf': {'n_is_sb': '0'},
 'hs1': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hs2': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hsv-1': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hsv-2': {'n_is_sb': '3', 'n_is_sth': '3'},
 'htlv-1': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hualapai': {'n_is_sb': '0'},
 'hualpai': {'n_is_sb': '0'},
 'huayna capac': {'n_is_sb': '0'},
 'hubbard': {'n_is_sb': '0'},
 'hubble': {'n_is_sb': '0'},
 'hubel': {'n_is_sb': '0'},
 'huck finn': {'n_is_sb': '0'},
 'huckleberry finn': {'n_is_sb': '0'},
 'huddie leadbetter': {'n_is_sb': '0'},
 'huddler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hudson bay collared lemming': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hudson hoagland': {'n_is_sb': '0'},
 'hudsonian godwit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hudson': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hugger': {'n_is_sb': '0'},
 'huggins': {'n_is_sb': '0'},
 'hugh capet': {'n_is_sb': '0'},
 'hugh dowding': {'n_is_sb': '0'},
 'hughes': {'n_is_sb': '0'},
 'hugo alvar henrik aalto': {'n_is_sb': '0'},
 'hugo de vries': {'n_is_sb': '0'},
 'hugo devries': {'n_is_sb': '0'},
 'hugo junkers': {'n_is_sb': '0'},
 'hugo von hoffmannsthal': {'n_is_sb': '0'},
 'hugo wolf': {'n_is_sb': '0'},
 'huguenot': {'n_is_sb': '0'},
 'huldreich zwingli': {'n_is_sb': '0'},
 'hulk': {'n_is_sb': '2', 'n_is_sth': '2'},
 'human being': {'n_is_sb': '0', 'nc_typical': ''},
 'human botfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'human dynamo': {'n_is_sb': '0'},
 'human immunodeficiency virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'human papilloma virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'human t-cell leukemia virus-1': {'n_is_sb': '3', 'n_is_sth': '3'},
 'humanist': {'n_is_sb': '0'},
 'humblebee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'humboldt': {'n_is_sb': '0'},
 'humdinger': {'n_is_sb': '0'},
 'hume': {'n_is_sb': '0'},
 'hummingbird moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'humorist': {'n_is_sb': '0'},
 'humourist': {'n_is_sb': '0'},
 'humpback whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'humperdinck': {'n_is_sb': '0'},
 'humphrey bogart': {'n_is_sb': '0'},
 'humphrey davy': {'n_is_sb': '0'},
 'humphrey deforest bogart': {'n_is_sb': '0'},
 'humphrey gilbert': {'n_is_sb': '0'},
 'humpty dumpty': {'n_is_sb': '0'},
 'hundred-percenter': {'n_is_sb': '0'},
 'hungarian partridge': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hungarian pointer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hunger marcher': {'n_is_sb': '0'},
 'hunkpapa': {'n_is_sb': '0'},
 'hunted person': {'n_is_sb': '0'},
 'hunter-gatherer': {'n_is_sb': '0'},
 'hunting dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hunting guide': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hunting spider': {'n_is_sb': '3', 'n_is_sth': '3'},
 'huntington': {'n_is_sb': '0'},
 'huntress': {'n_is_sb': '0'},
 'hupa': {'n_is_sb': '0'},
 'hurdler': {'n_is_sb': '0'},
 'hurok': {'n_is_sb': '0'},
 'husain': {'n_is_sb': '0'},
 'husayn': {'n_is_sb': '0'},
 'husbandman': {'n_is_sb': '0'},
 'hussar monkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hussein': {'n_is_sb': '0'},
 'husserl': {'n_is_sb': '0'},
 'hussite': {'n_is_sb': '0'},
 'huss': {'n_is_sb': '3', 'n_is_sth': '3'},
 'huston': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hutchinson': {'n_is_sb': '0'},
 'hutchins': {'n_is_sb': '0'},
 'hutton': {'n_is_sb': '0'},
 'hutu': {'n_is_sb': '0'},
 'huxley': {'n_is_sb': '0'},
 'huygens': {'n_is_sb': '0'},
 'hyaena brunnea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hyaena hyaena': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hyaena': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hyalophora cecropia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hyalophora': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hydrobates pelagicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hydrochoerus hydrochaeris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hydrochoerus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hydrodamalis gigas': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hydroid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hydromancer': {'n_is_sb': '0'},
 'hydromantes brunus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hydromantes shastae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hydromys': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hydrozoan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hydrozoa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hyemoschus aquaticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hyena dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hygeia': {'n_is_sb': '0'},
 'hyla arenicolor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hyla crucifer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hyla regilla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hylactophryne augusti': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hylactophryne': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hylobates lar': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hylobates syndactylus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hylocichla fuscescens': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hylocichla guttata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hylocichla mustelina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hylocichla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hylophylax naevioides': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hylophylax': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hyman george rickover': {'n_is_sb': '0'},
 'hyman rickover': {'n_is_sb': '0'},
 'hymenopteran': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hymenopteron': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hymenopterous insect': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hymenopter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hymen': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hymie': {'n_is_sb': '0'},
 'hynerpeton bassetti': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hynerpeton': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hypatia': {'n_is_sb': '0'},
 'hypentelium nigricans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hypentelium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hyperborean': {'n_is_sb': '0'},
 'hyperglyphe perciformis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hyperion': {'n_is_sb': '0'},
 'hypermastigote': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hyperodontidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hyperoodon ampullatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hyperope': {'n_is_sb': '0'},
 'hyperotreta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hyphantria cunea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hypnos': {'n_is_sb': '0'},
 'hypnotiser': {'n_is_sb': '0'},
 'hypnotist': {'n_is_sb': '0'},
 'hypnotizer': {'n_is_sb': '0'},
 'hypochondriac': {'n_is_sb': '0'},
 'hypopachus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hypoplastic dwarf': {'n_is_sb': '0'},
 'hypostasis': {'n_is_sb': '2', 'n_is_sth': '2'},
 'hypothetical creature': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hypsiglena torquata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hypsiglena': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hypsiprymnodon moschatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hypsiprymnodon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hyrax': {'n_is_sb': '3', 'n_is_sth': '3'},
 'hystricomorpha': {'n_is_sb': '3', 'n_is_sth': '3'},
 'i. a. richards': {'n_is_sb': '0'},
 'i. f. stone': {'n_is_sb': '0'},
 'i. m. pei': {'n_is_sb': '0'},
 'iago': {'n_is_sb': '0'},
 'ian douglas smith': {'n_is_sb': '0'},
 'ian fleming': {'n_is_sb': '0'},
 'ian lancaster fleming': {'n_is_sb': '0'},
 'ian smith': {'n_is_sb': '0'},
 'ian wilmut': {'n_is_sb': '0'},
 'ianfu': {'n_is_sb': '0'},
 'iapetus': {'n_is_sb': '0'},
 'ibero-mesornis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ibert': {'n_is_sb': '0'},
 'ibis ibis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ibizan hound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ibizan podenco': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ibn al-haytham': {'n_is_sb': '0'},
 'ibn talal hussein': {'n_is_sb': '0'},
 'ibn-roshd': {'n_is_sb': '0'},
 'ibn-sina': {'n_is_sb': '0'},
 'ibrahim': {'n_is_sb': '0'},
 'ibsen': {'n_is_sb': '0'},
 'icarus': {'n_is_sb': '0'},
 'ice bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ice-hockey player': {'n_is_sb': '0'},
 'ice-skater': {'n_is_sb': '0'},
 'icelander': {'n_is_sb': '0'},
 'iceman': {'n_is_sb': '0'},
 'ichneumon fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ichneumon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ichthyologist': {'n_is_sb': '0'},
 'ichthyosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ichthyosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ichyostega': {'n_is_sb': '3', 'n_is_sth': '3'},
 'iconoclast': {'n_is_sb': '0'},
 'ictalurus punctatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'icteria virens': {'n_is_sb': '3', 'n_is_sth': '3'},
 'icteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'icterus galbula bullockii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'icterus galbula galbula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'icterus galbula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'icterus spurius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'icterus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ictiobus niger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ictodosauria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ictodosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ictonyx frenata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ictonyx striata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'idahoan': {'n_is_sb': '0'},
 'identical twin': {'n_is_sb': '0'},
 'idiot savant': {'n_is_sb': '0'},
 'idol worshiper': {'n_is_sb': '0'},
 'idolater': {'n_is_sb': '0'},
 'idolatress': {'n_is_sb': '0'},
 'idoliser': {'n_is_sb': '0'},
 'idolizer': {'n_is_sb': '0'},
 'idun': {'n_is_sb': '0'},
 'ieoh ming pei': {'n_is_sb': '0'},
 'igbo': {'n_is_sb': '0'},
 'igigi': {'n_is_sb': '0'},
 'iglesias': {'n_is_sb': '0'},
 'ignace jan paderewski': {'n_is_sb': '0'},
 'ignace paderewski': {'n_is_sb': '0'},
 'ignatius of loyola': {'n_is_sb': '0'},
 'ignatius': {'n_is_sb': '0'},
 'igor fyodorovich stravinsky': {'n_is_sb': '0'},
 'igor ivanovich sikorsky': {'n_is_sb': '0'},
 'igor sikorsky': {'n_is_sb': '0'},
 'igor stravinsky': {'n_is_sb': '0'},
 'igor tamm': {'n_is_sb': '0'},
 'igor yevgeneevich tamm': {'n_is_sb': '0'},
 'iguana iguana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'iguana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'iguanid lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'iguanid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'iguanodon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ike': {'n_is_sb': '0'},
 'ikhanaton': {'n_is_sb': '0'},
 'il duce': {'n_is_sb': '0'},
 'ilich ramirez sanchez': {'n_is_sb': '0'},
 'ilich sanchez': {'n_is_sb': '0'},
 'illegitimate child': {'n_is_sb': '0'},
 'illegitimate': {'n_is_sb': '0'},
 'illinoisan': {'n_is_sb': '0'},
 'illiterate person': {'n_is_sb': '0'},
 'illustrator': {'n_is_sb': '0'},
 'ilya ehrenberg': {'n_is_sb': '0'},
 'ilya grigorievich ehrenberg': {'n_is_sb': '0'},
 'ilya ilich metchnikov': {'n_is_sb': '0'},
 'image breaker': {'n_is_sb': '0'},
 'imaginary being': {'n_is_sb': '2', 'n_is_sth': '2'},
 'imaginary creature': {'n_is_sb': '2', 'n_is_sth': '2'},
 'imamu amiri baraka': {'n_is_sb': '0'},
 'imaum': {'n_is_sb': '0'},
 'imbiber': {'n_is_sb': '0'},
 'immanuel kant': {'n_is_sb': '0'},
 'immune carrier': {'n_is_sb': '0'},
 'immune': {'n_is_sb': '0'},
 'immunologist': {'n_is_sb': '0'},
 'imogene coca': {'n_is_sb': '0'},
 'impala': {'n_is_sb': '3', 'n_is_sth': '3'},
 'imperial elephant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'imperial mammoth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'imperial moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'imperialist': {'n_is_sb': '0'},
 'important person': {'n_is_sb': '0'},
 'importee': {'n_is_sb': '0'},
 'imposter': {'n_is_sb': '0'},
 'impressionist': {'n_is_sb': '0'},
 'improver': {'n_is_sb': '2', 'n_is_sth': '2'},
 'in-law': {'n_is_sb': '0'},
 'inachis io': {'n_is_sb': '3', 'n_is_sth': '3'},
 'inamorato': {'n_is_sb': '0'},
 'inanna': {'n_is_sb': '0'},
 'incan': {'n_is_sb': '0'},
 'inca': {'n_is_sb': '0'},
 'inciter': {'n_is_sb': '0'},
 'incompetent person': {'n_is_sb': '0'},
 'incompetent': {'n_is_sb': '0'},
 'incumbent': {'n_is_sb': '0'},
 'incurable': {'n_is_sb': '0'},
 'index case': {'n_is_sb': '2', 'n_is_sth': '2'},
 'indian agent': {'n_is_sb': '0'},
 'indian buffalo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'indian chieftain': {'n_is_sb': '0'},
 'indian chief': {'n_is_sb': '0'},
 'indian cobra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'indian elephant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'indian giver': {'n_is_sb': '0'},
 'indian grackle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'indian mongoose': {'n_is_sb': '3', 'n_is_sth': '3'},
 'indian pony': {'n_is_sb': '0'},
 'indian python': {'n_is_sb': '3', 'n_is_sth': '3'},
 'indian race': {'n_is_sb': '2', 'n_is_sth': '2'},
 'indian rat snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'indian rhinoceros': {'n_is_sb': '3', 'n_is_sth': '3'},
 'indian tapir': {'n_is_sb': '3', 'n_is_sth': '3'},
 'indianan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'indigene': {'n_is_sb': '2', 'n_is_sth': '2'},
 'indigen': {'n_is_sb': '2', 'n_is_sth': '2'},
 'indigo bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'indigo bunting': {'n_is_sb': '3', 'n_is_sth': '3'},
 'indigo finch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'indigo snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'indira gandhi': {'n_is_sb': '0'},
 'indira nehru gandhi': {'n_is_sb': '0'},
 'individualist': {'n_is_sb': '0'},
 'indorser': {'n_is_sb': '0'},
 'indra': {'n_is_sb': '0'},
 'indri brevicaudatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'indri indri': {'n_is_sb': '3', 'n_is_sth': '3'},
 'indris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'indri': {'n_is_sb': '3', 'n_is_sth': '3'},
 'inducer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'inductee': {'n_is_sb': '0'},
 'industry analyst': {'n_is_sb': '0'},
 'indweller': {'n_is_sb': '2', 'n_is_sth': '2'},
 'inebriate': {'n_is_sb': '0', 'vbd_eq_vbn': ''},
 'inexperienced person': {'n_is_sb': '0'},
 'infant prodigy': {'n_is_sb': '0'},
 'infernal': {'n_is_sb': '0'},
 'infielder': {'n_is_sb': '0'},
 'infiltrator': {'n_is_sb': '0'},
 'influence peddler': {'n_is_sb': '0'},
 'influential person': {'n_is_sb': '0'},
 'infusorian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ingenue': {'n_is_sb': '0'},
 'ingerman': {'n_is_sb': '0'},
 'inger': {'n_is_sb': '0'},
 'inge': {'n_is_sb': '0'},
 'ingmar bergman': {'n_is_sb': '0'},
 'ingrate': {'n_is_sb': '0'},
 'ingres': {'n_is_sb': '0'},
 'ingrian': {'n_is_sb': '0'},
 'ingrid bergman': {'n_is_sb': '0'},
 'inheritress': {'n_is_sb': '0'},
 'inheritrix': {'n_is_sb': '0'},
 'inigo jones': {'n_is_sb': '0'},
 'injun': {'n_is_sb': '0'},
 'injured party': {'n_is_sb': '0'},
 'inka': {'n_is_sb': '0'},
 'innkeeper': {'n_is_sb': '0'},
 'innocent iii': {'n_is_sb': '0'},
 'innovator': {'n_is_sb': '0'},
 'inoculator': {'n_is_sb': '2', 'n_is_sth': '2'},
 'inpatient': {'n_is_sb': '0'},
 'inquirer': {'n_is_sb': '0'},
 'inquiry agent': {'n_is_sb': '0'},
 'insectivore': {'n_is_sb': '3', 'n_is_sth': '3'},
 'insessores': {'n_is_sb': '3', 'n_is_sth': '3'},
 'insolvent': {'n_is_sb': '0'},
 'insomniac': {'n_is_sb': '0'},
 'inspector general': {'n_is_sb': '0'},
 'inspector maigret': {'n_is_sb': '0'},
 'instar': {'n_is_sb': '2', 'n_is_sth': '2'},
 'instigant': {'n_is_sb': '0'},
 'instigator': {'n_is_sb': '0'},
 'instructress': {'n_is_sb': '0'},
 'instrumentalist': {'n_is_sb': '0'},
 'insurance agent': {'n_is_sb': '0'},
 'insurance broker': {'n_is_sb': '0'},
 'insured person': {'n_is_sb': '0'},
 'insurgent': {'n_is_sb': '0'},
 'insurrectionist': {'n_is_sb': '0'},
 'intelligence agent': {'n_is_sb': '0'},
 'intelligence analyst': {'n_is_sb': '0'},
 'intelligence officer': {'n_is_sb': '0'},
 'intercessor': {'n_is_sb': '0'},
 'interior decorator': {'n_is_sb': '0'},
 'interior designer': {'n_is_sb': '0'},
 'interior secretary': {'n_is_sb': '0'},
 'interlocutor': {'n_is_sb': '0'},
 'interloper': {'n_is_sb': '0'},
 'intermediate host': {'n_is_sb': '3', 'n_is_sth': '3'},
 'intermediator': {'n_is_sb': '0'},
 'internal auditor': {'n_is_sb': '0'},
 'internal revenue agent': {'n_is_sb': '0'},
 'international grandmaster': {'n_is_sb': '0'},
 'internationalist': {'n_is_sb': '0'},
 'internee': {'n_is_sb': '0'},
 'interne': {'n_is_sb': '0'},
 'internist': {'n_is_sb': '0'},
 'internuncio': {'n_is_sb': '0'},
 'intern': {'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'intervenor': {'n_is_sb': '0'},
 'interviewee': {'n_is_sb': '0'},
 'intestinal flora': {'n_is_sb': '3', 'n_is_sth': '3'},
 'introvert': {'n_is_sb': '2', 'n_is_sth': '2'},
 'inuit': {'n_is_sb': '0'},
 'invalidator': {'n_is_sb': '0'},
 'invertebrate': {'n_is_sb': '0'},
 'investment adviser': {'n_is_sb': '0'},
 'investment advisor': {'n_is_sb': '0'},
 'investment banker': {'n_is_sb': '0'},
 'invigilator': {'n_is_sb': '2', 'n_is_sth': '2'},
 'invitee': {'n_is_sb': '0'},
 'io moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ionesco': {'n_is_sb': '0'},
 'ionian': {'n_is_sb': '0'},
 'iosif vissarionovich dzhugashvili': {'n_is_sb': '0'},
 'iowan': {'n_is_sb': '0'},
 'ioway': {'n_is_sb': '0'},
 'io': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ira gershwin': {'n_is_sb': '0'},
 'iraki': {'n_is_sb': '0'},
 'iranian': {'n_is_sb': '0'},
 'irani': {'n_is_sb': '0'},
 'irelander': {'n_is_sb': '0'},
 'irena': {'n_is_sb': '0'},
 'irene joliot-curie': {'n_is_sb': '0'},
 'iridoprocne bicolor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'iris murdoch': {'n_is_sb': '0'},
 'irish moss': {'n_is_sb': '3', 'n_is_sth': '3'},
 'irish people': {'n_is_sb': '0'},
 'irish person': {'n_is_sb': '0'},
 'irish setter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'irish terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'irish water spaniel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'irish wolfhound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'irishwoman': {'n_is_sb': '0'},
 'iron chancellor': {'n_is_sb': '0'},
 'iron lady': {'n_is_sb': '0'},
 'iron man': {'n_is_sb': '0'},
 'ironist': {'n_is_sb': '0'},
 'ironman': {'n_is_sb': '0'},
 'ironmonger': {'n_is_sb': '0'},
 'ironsides': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ironside': {'n_is_sb': '0'},
 'iroquois': {'n_is_sb': '0'},
 'irredentist': {'n_is_sb': '0'},
 'irreligionist': {'n_is_sb': '0'},
 'irridentist': {'n_is_sb': '0'},
 'irving berlin': {'n_is_sb': '0'},
 'irving langmuir': {'n_is_sb': '0'},
 'isaac asimov': {'n_is_sb': '0'},
 'isaac bashevis singer': {'n_is_sb': '0'},
 'isaac hull': {'n_is_sb': '0'},
 'isaac m. singer': {'n_is_sb': '0'},
 'isaac mayer wise': {'n_is_sb': '0'},
 'isaac merrit singer': {'n_is_sb': '0'},
 'isaac newton': {'n_is_sb': '0'},
 'isaac stern': {'n_is_sb': '0'},
 'isaac watts': {'n_is_sb': '0'},
 'isaac': {'n_is_sb': '0'},
 'isabella i': {'n_is_sb': '0'},
 'isabella stewart gardner': {'n_is_sb': '0'},
 'isabella the catholic': {'n_is_sb': '0'},
 'isadora duncan': {'n_is_sb': '0'},
 'isak dinesen': {'n_is_sb': '0'},
 'isamu noguchi': {'n_is_sb': '0'},
 'iseult': {'n_is_sb': '0'},
 'isherwood': {'n_is_sb': '0'},
 'ishmael': {'n_is_sb': '0'},
 'ishtar': {'n_is_sb': '0'},
 'isidor feinstein stone': {'n_is_sb': '0'},
 'isidore auguste marie francois comte': {'n_is_sb': '0'},
 'isis': {'n_is_sb': '0'},
 'islamist': {'n_is_sb': '0'},
 'island-dweller': {'n_is_sb': '0'},
 'islander': {'n_is_sb': '0'},
 'ismailian': {'n_is_sb': '0'},
 'ismaili': {'n_is_sb': '0'},
 'isocrates': {'n_is_sb': '0'},
 'isolationist': {'n_is_sb': '0'},
 'isopod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'isoroku yamamoto': {'n_is_sb': '0'},
 'israel baline': {'n_is_sb': '0'},
 'israel zangwill': {'n_is_sb': '0'},
 'issachar': {'n_is_sb': '0'},
 'istiophorus albicans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'isurus glaucus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'isurus oxyrhincus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'isurus paucus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'italian bee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'italian greyhound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'italo calvino': {'n_is_sb': '0'},
 'itch mite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ithunn': {'n_is_sb': '0'},
 'itinerant': {'n_is_sb': '0'},
 'ivan iii vasilievich': {'n_is_sb': '0'},
 'ivan iii': {'n_is_sb': '0'},
 'ivan iv vasilievich': {'n_is_sb': '0'},
 'ivan iv': {'n_is_sb': '0'},
 'ivan lendl': {'n_is_sb': '0'},
 'ivan pavlov': {'n_is_sb': '0'},
 'ivan petrovich pavlov': {'n_is_sb': '0'},
 'ivan sergeevich turgenev': {'n_is_sb': '0'},
 'ivan the great': {'n_is_sb': '0'},
 'ivan the terrible': {'n_is_sb': '0'},
 'ivan turgenev': {'n_is_sb': '0'},
 'ivanov': {'n_is_sb': '0'},
 'ives': {'n_is_sb': '0'},
 'ivor armstrong richards': {'n_is_sb': '0'},
 'ivory gull': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ivory-billed woodpecker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ivorybill': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ivy leaguer': {'n_is_sb': '0'},
 'ixobrychus exilis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ixobrychus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ixodes dammini': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ixodes dentatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ixodes neotomae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ixodes pacificus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ixodes persulcatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ixodes ricinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ixodes scapularis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ixodes spinipalpis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ixodes': {'n_is_sb': ''},
 'ixodidae': {'n_is_sb': ''},
 'ixodid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'izaak walton': {'n_is_sb': '0'},
 'izanagi': {'n_is_sb': '0'},
 'izanami': {'n_is_sb': '0'},
 'j. b. rhine': {'n_is_sb': '0'},
 'j. b. s. haldane': {'n_is_sb': '0'},
 'j. c. maxwell': {'n_is_sb': '0'},
 'j. craig ventner': {'n_is_sb': '0'},
 'j. d. salinger': {'n_is_sb': '0'},
 'j. e. johnston': {'n_is_sb': '0'},
 'j. edgar hoover': {'n_is_sb': '0'},
 'j. j. hill': {'n_is_sb': '0'},
 'j. m. barrie': {'n_is_sb': '0'},
 'j. m. synge': {'n_is_sb': '0'},
 'j. p. morgan': {'n_is_sb': '0'},
 'j. r. firth': {'n_is_sb': '0'},
 'j.r.r. tolkien': {'n_is_sb': '0'},
 'jabberer': {'n_is_sb': '0'},
 'jabiru mycteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jabiru': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jacamar': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jack benny': {'n_is_sb': '0'},
 'jack crevalle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jack dempsey': {'n_is_sb': '0'},
 'jack frost': {'n_is_sb': ''},
 'jack kennedy': {'n_is_sb': '0'},
 'jack kerouac': {'n_is_sb': '0'},
 'jack lemmon': {'n_is_sb': '0'},
 'jack london': {'n_is_sb': '0'},
 'jack mackerel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jack nicklaus': {'n_is_sb': '0'},
 'jack of all trades': {'n_is_sb': '0'},
 'jack roosevelt robinson': {'n_is_sb': '0'},
 'jack salmon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jack the ripper': {'n_is_sb': '0'},
 'jack william nicklaus': {'n_is_sb': '0'},
 'jack-tar': {'n_is_sb': '0'},
 'jackanapes': {'n_is_sb': '2', 'n_is_sth': '2'},
 'jackass bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jackass penguin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jackdaw': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jackie robinson': {'n_is_sb': '0'},
 'jackknife clam': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jackknife-fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jackrabbit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jacksmelt': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jacksnipe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jackson pollock': {'n_is_sb': '0'},
 'jacob epstein': {'n_is_sb': '0'},
 'jacob harmensen': {'n_is_sb': '0'},
 'jacobean': {'n_is_sb': '0', 'cap_word': 'Jacobean'},
 'jacobin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jacobite': {'n_is_sb': '0'},
 'jacobi': {'n_is_sb': '0'},
 'jacobs': {'n_is_sb': '0'},
 'jacobus arminius': {'n_is_sb': '0'},
 'jacob': {'n_is_sb': '0'},
 'jacopo robusti': {'n_is_sb': '0'},
 'jacquard': {'n_is_sb': '2', 'n_is_sth': '2'},
 'jacqueline cochran': {'n_is_sb': '0'},
 'jacques alexandre cesar charles': {'n_is_sb': '0'},
 'jacques anatole francois thibault': {'n_is_sb': '0'},
 'jacques bernoulli': {'n_is_sb': '0'},
 'jacques cartier': {'n_is_sb': '0'},
 'jacques charles': {'n_is_sb': '0'},
 'jacques costeau': {'n_is_sb': '0'},
 'jacques derrida': {'n_is_sb': '0'},
 'jacques etienne montgolfier': {'n_is_sb': '0'},
 'jacques francois antoine ibert': {'n_is_sb': '0'},
 'jacques francois fromental elie halevy': {'n_is_sb': '0'},
 'jacques germain soufflot': {'n_is_sb': '0'},
 'jacques lipchitz': {'n_is_sb': '0'},
 'jacques loeb': {'n_is_sb': '0'},
 'jacques louis david': {'n_is_sb': '0'},
 'jacques lucien monod': {'n_is_sb': '0'},
 'jacques marquette': {'n_is_sb': '0'},
 'jacques monod': {'n_is_sb': '0'},
 'jacques offenbach': {'n_is_sb': '0'},
 'jacques tatischeff': {'n_is_sb': '0'},
 'jacques tati': {'n_is_sb': '0'},
 'jacques yves costeau': {'n_is_sb': '0'},
 'jaculus jaculus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jaculus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jafar umar thalib': {'n_is_sb': '0'},
 'jafar': {'n_is_sb': '0'},
 'jaffar umar thalib': {'n_is_sb': '0'},
 'jaffar': {'n_is_sb': '0'},
 'jagannatha': {'n_is_sb': '0'},
 'jagannath': {'n_is_sb': '0'},
 'jagganath': {'n_is_sb': '0'},
 'jagger': {'n_is_sb': '2', 'n_is_sth': '2'},
 'jaguarondi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jaguarundi cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jaguarundi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jahvey': {'n_is_sb': '0'},
 'jahweh': {'n_is_sb': '0'},
 'jailbird': {'n_is_sb': '0'},
 'jailor': {'n_is_sb': '0'},
 'jainist': {'n_is_sb': '0'},
 'jakob behmen': {'n_is_sb': '0'},
 'jakob bernoulli': {'n_is_sb': '0'},
 'jakob boehme': {'n_is_sb': '0'},
 'jakob boehm': {'n_is_sb': '0'},
 'jakob bohme': {'n_is_sb': '0'},
 'jakob grimm': {'n_is_sb': '0'},
 'jakob hermandszoon': {'n_is_sb': '0'},
 'jakob liebmann beer': {'n_is_sb': '0'},
 'jakob ludwig felix mendelssohn-bartholdy': {'n_is_sb': '0'},
 'jakob ludwig karl grimm': {'n_is_sb': '0'},
 'jakobson': {'n_is_sb': '0'},
 'jamaican': {'n_is_sb': '0'},
 'james a. garfield': {'n_is_sb': '0'},
 'james abbott mcneill whistler': {'n_is_sb': '0'},
 'james abraham garfield': {'n_is_sb': '0'},
 'james agee': {'n_is_sb': '0'},
 'james albert michener': {'n_is_sb': '0'},
 'james alfred van allen': {'n_is_sb': '0'},
 'james arthur baldwin': {'n_is_sb': '0'},
 'james augustine aloysius joyce': {'n_is_sb': '0'},
 'james augustus henry murray': {'n_is_sb': '0'},
 'james augustus murray': {'n_is_sb': '0'},
 'james baldwin': {'n_is_sb': '0'},
 'james barrie': {'n_is_sb': '0'},
 'james bernoulli': {'n_is_sb': '0'},
 'james bond': {'n_is_sb': '0'},
 'james boswell': {'n_is_sb': '0'},
 'james bowie': {'n_is_sb': '0'},
 'james branch cabell': {'n_is_sb': '0'},
 'james buchanan brady': {'n_is_sb': '0'},
 'james buchanan': {'n_is_sb': '0'},
 'james butler hickock': {'n_is_sb': '0'},
 'james byron dean': {'n_is_sb': '0'},
 'james cagney': {'n_is_sb': '0'},
 'james clark ross': {'n_is_sb': '0'},
 'james clerk maxwell': {'n_is_sb': '0'},
 'james cleveland owens': {'n_is_sb': '0'},
 'james cook': {'n_is_sb': '0'},
 'james crichton': {'n_is_sb': '0'},
 'james dean': {'n_is_sb': '0'},
 'james dewey watson': {'n_is_sb': '0'},
 'james douglas morrison': {'n_is_sb': '0'},
 'james earl carter jr.': {'n_is_sb': '0'},
 'james earl carter': {'n_is_sb': '0'},
 'james edmund scripps': {'n_is_sb': '0'},
 'james edward meade': {'n_is_sb': '0'},
 'james fenimore cooper': {'n_is_sb': '0'},
 'james francis thorpe': {'n_is_sb': '0'},
 'james franck': {'n_is_sb': '0'},
 'james garfield': {'n_is_sb': '0'},
 'james george frazer': {'n_is_sb': '0'},
 'james grover thurber': {'n_is_sb': '0'},
 'james hargreaves': {'n_is_sb': '0'},
 'james harold doolittle': {'n_is_sb': '0'},
 'james harvey robinson': {'n_is_sb': '0'},
 'james henry leigh hunt': {'n_is_sb': '0'},
 'james hogg': {'n_is_sb': '0'},
 'james howard meredith': {'n_is_sb': '0'},
 'james hutton': {'n_is_sb': '0'},
 'james ii': {'n_is_sb': '0'},
 'james ives': {'n_is_sb': '0'},
 'james iv': {'n_is_sb': '0'},
 'james i': {'n_is_sb': '0'},
 'james jerome hill': {'n_is_sb': '0'},
 'james john corbett': {'n_is_sb': '0'},
 'james joseph tunney': {'n_is_sb': '0'},
 'james joyce': {'n_is_sb': '0'},
 'james k. polk': {'n_is_sb': '0'},
 'james knox polk': {'n_is_sb': '0'},
 'james langston hughes': {'n_is_sb': '0'},
 'james leonard farmer': {'n_is_sb': '0'},
 'james madison': {'n_is_sb': '0'},
 'james maitland stewart': {'n_is_sb': '0'},
 'james marshall hendrix': {'n_is_sb': '0'},
 'james mason': {'n_is_sb': '0'},
 'james matthew barrie': {'n_is_sb': '0'},
 'james mckeen cattell': {'n_is_sb': '0'},
 'james meredith': {'n_is_sb': '0'},
 'james merritt ives': {'n_is_sb': '0'},
 'james michener': {'n_is_sb': '0'},
 'james mill': {'n_is_sb': '0'},
 'james monroe': {'n_is_sb': '0'},
 'james murray': {'n_is_sb': '0'},
 'james naismith': {'n_is_sb': '0'},
 'james neville mason': {'n_is_sb': '0'},
 'james parkinson': {'n_is_sb': '0'},
 'james polk': {'n_is_sb': '0'},
 'james prescott joule': {'n_is_sb': '0'},
 'james riddle hoffa': {'n_is_sb': '0'},
 'james scott connors': {'n_is_sb': '0'},
 'james thomas farrell': {'n_is_sb': '0'},
 'james thomas harris': {'n_is_sb': '0'},
 'james thurber': {'n_is_sb': '0'},
 'james tobin': {'n_is_sb': '0'},
 'james usher': {'n_is_sb': '0'},
 'james ussher': {'n_is_sb': '0'},
 'james watson': {'n_is_sb': '0'},
 'james watt': {'n_is_sb': '0'},
 'james whitcomb riley': {'n_is_sb': '0'},
 'james william fulbright': {'n_is_sb': '0'},
 'james wilson': {'n_is_sb': '0'},
 'james wyatt': {'n_is_sb': '0'},
 'james': {'n_is_sb': '0'},
 'jamison': {'n_is_sb': '0'},
 'jan amos komensky': {'n_is_sb': '0'},
 'jan christian smuts': {'n_is_sb': '0'},
 'jan evangelista purkinje': {'n_is_sb': '0'},
 'jan hendrix oort': {'n_is_sb': '0'},
 'jan hus': {'n_is_sb': '0'},
 'jan swammerdam': {'n_is_sb': '0'},
 'jan tinbergen': {'n_is_sb': '0'},
 'jan van der meer': {'n_is_sb': '0'},
 'jan van eyck': {'n_is_sb': '0'},
 'jan vermeer': {'n_is_sb': '0'},
 'jane austen': {'n_is_sb': '0'},
 'jane doe': {'n_is_sb': '0'},
 'jane fonda': {'n_is_sb': '0'},
 'jane goodall': {'n_is_sb': '0'},
 'jane jacobs': {'n_is_sb': '0'},
 'jane seymour': {'n_is_sb': '0'},
 'janis joplin': {'n_is_sb': '0'},
 'janissary': {'n_is_sb': '0'},
 'jansenist': {'n_is_sb': '0'},
 'jansen': {'n_is_sb': '0'},
 'janus': {'n_is_sb': '0'},
 'japanese beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'japanese deer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'japanese deity': {'n_is_sb': '0'},
 'japanese oyster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'japanese spaniel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'japheth': {'n_is_sb': '0'},
 'jap': {'n_is_sb': '2', 'n_is_sth': '2'},
 'jaroslav hasek': {'n_is_sb': '0'},
 'jarrell': {'n_is_sb': '0'},
 'jason': {'n_is_sb': '0'},
 'jasper johns': {'n_is_sb': '0'},
 'jaspers': {'n_is_sb': '0'},
 'jassidae': {'n_is_sb': '0'},
 'jassid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jat': {'n_is_sb': '0'},
 'jaun gris': {'n_is_sb': '0'},
 'java finch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'java man': {'n_is_sb': '0'},
 'java sparrow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'javanese': {'n_is_sb': '2', 'n_is_sth': '2'},
 'javanthropus': {'n_is_sb': ''},
 'javan': {'n_is_sb': '0'},
 'javelina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jawaharlal nehru': {'n_is_sb': '0'},
 'jawan': {'n_is_sb': '0'},
 'jawfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jawless fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jawless vertebrate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jay cooke': {'n_is_sb': '0'},
 'jay gould': {'n_is_sb': '0'},
 'jaybird': {'n_is_sb': '2', 'n_is_sth': '2'},
 'jaywalker': {'n_is_sb': '0'},
 'jazz musician': {'n_is_sb': '0'},
 'jazzman': {'n_is_sb': '0'},
 'jean anouilh': {'n_is_sb': '0'},
 'jean antoine watteau': {'n_is_sb': '0'},
 'jean arp': {'n_is_sb': '0'},
 'jean auguste dominique ingres': {'n_is_sb': '0'},
 'jean baptiste camille corot': {'n_is_sb': '0'},
 'jean baptiste de lamarck': {'n_is_sb': '0'},
 'jean baptiste donatien de vimeur': {'n_is_sb': '0'},
 'jean baptiste joseph fourier': {'n_is_sb': '0'},
 'jean baptiste lully': {'n_is_sb': '0'},
 'jean baptiste racine': {'n_is_sb': '0'},
 'jean bernard leon foucault': {'n_is_sb': '0'},
 'jean bernoulli': {'n_is_sb': '0'},
 'jean caulvin': {'n_is_sb': '0'},
 'jean cauvin': {'n_is_sb': '0'},
 'jean chauvin': {'n_is_sb': '0'},
 'jean cocteau': {'n_is_sb': '0'},
 'jean de la fontaine': {'n_is_sb': '0'},
 'jean edouard vuillard': {'n_is_sb': '0'},
 'jean francois champollion': {'n_is_sb': '0'},
 'jean francois millet': {'n_is_sb': '0'},
 'jean genet': {'n_is_sb': '0'},
 'jean giraudoux': {'n_is_sb': '0'},
 'jean harlow': {'n_is_sb': '0'},
 'jean honore fragonard': {'n_is_sb': '0'},
 'jean laffite': {'n_is_sb': '0'},
 'jean lafitte': {'n_is_sb': '0'},
 'jean louis charles garnier': {'n_is_sb': '0'},
 'jean louis rodolphe agassiz': {'n_is_sb': '0'},
 'jean luc godard': {'n_is_sb': '0'},
 'jean martin charcot': {'n_is_sb': '0'},
 'jean monnet': {'n_is_sb': '0'},
 'jean nicholas arthur rimbaud': {'n_is_sb': '0'},
 'jean paul marat': {'n_is_sb': '0'},
 'jean piaget': {'n_is_sb': '0'},
 'jean racine': {'n_is_sb': '0'},
 'jean sibelius': {'n_is_sb': '0'},
 'jean-baptiste poquelin': {'n_is_sb': '0'},
 'jean-claude duvalier': {'n_is_sb': '0'},
 'jean-frederic joliot-curie': {'n_is_sb': '0'},
 'jean-frederic joliot': {'n_is_sb': '0'},
 'jean-jacques rousseau': {'n_is_sb': '0'},
 'jean-louis lebris de kerouac': {'n_is_sb': '0'},
 'jean-paul sartre': {'n_is_sb': '0'},
 'jean-philippe rameau': {'n_is_sb': '0'},
 'jeanne antoinette poisson': {'n_is_sb': '0'},
 "jeanne d'arc": {'n_is_sb': '0'},
 'jeannette rankin': {'n_is_sb': '0'},
 'jeerer': {'n_is_sb': '0'},
 'jefferson davis': {'n_is_sb': '0'},
 'jefferson': {'n_is_sb': '0'},
 'jeffers': {'n_is_sb': '0'},
 "jehovah's witness": {'n_is_sb': '0'},
 'jekyll and hyde': {'n_is_sb': '0'},
 'jelly roll morton': {'n_is_sb': '0'},
 'jenghiz khan': {'n_is_sb': '0'},
 'jenner': {'n_is_sb': '0'},
 'jennet': {'n_is_sb': '2', 'n_is_sth': '2'},
 'jenny ass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jenny lind': {'n_is_sb': '0'},
 'jenny wren': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jenny': {'n_is_sb': '2', 'n_is_sth': '2'},
 'jens otto harry jespersen': {'n_is_sb': '0'},
 'jensen': {'n_is_sb': '0'},
 'jerboa kangaroo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jerboa rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jerboa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jeremiah': {'n_is_sb': '0'},
 'jeremy bentham': {'n_is_sb': '0'},
 'jerk-off': {'n_is_sb': '0'},
 'jerker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'jeroboam i': {'n_is_sb': '0'},
 'jeroboam': {'n_is_sb': '0'},
 'jerom bos': {'n_is_sb': '0'},
 'jerome david kern': {'n_is_sb': '0'},
 'jerome david salinger': {'n_is_sb': '0'},
 'jerome kern': {'n_is_sb': '0'},
 'jerome robbins': {'n_is_sb': '0'},
 'jerome': {'n_is_sb': '0'},
 'jerry lee lewis': {'n_is_sb': '0'},
 'jerry-builder': {'n_is_sb': '0'},
 'jerry': {'n_is_sb': '0'},
 'jerusalem cricket': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jespersen': {'n_is_sb': '0'},
 'jesse jackson': {'n_is_sb': '0'},
 'jesse james': {'n_is_sb': '0'},
 'jesse louis jackson': {'n_is_sb': '0'},
 'jesse owens': {'n_is_sb': '0'},
 'jessica lucy mitford': {'n_is_sb': '0'},
 'jessica mitford': {'n_is_sb': '0'},
 'jessye norman': {'n_is_sb': '0'},
 'jester': {'n_is_sb': '0'},
 'jesuit': {'n_is_sb': '0'},
 'jesus christ': {'n_is_sb': '0'},
 'jesus of nazareth': {'n_is_sb': '0'},
 'jeune fille': {'n_is_sb': '0'},
 'jevons': {'n_is_sb': '0'},
 'jew-baiter': {'n_is_sb': '0'},
 'jewelry maker': {'n_is_sb': '0'},
 'jewfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jewison': {'n_is_sb': '0'},
 'jfk': {'n_is_sb': '0'},
 'jhvh': {'n_is_sb': '0'},
 'jigaboo': {'n_is_sb': '0'},
 'jihadist': {'n_is_sb': '0'},
 'jilt': {'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'jim bowie': {'n_is_sb': '0'},
 'jim corbett': {'n_is_sb': '0'},
 'jim henson': {'n_is_sb': '0'},
 'jim morrison': {'n_is_sb': '0'},
 'jim thorpe': {'n_is_sb': '0'},
 'jimdandy': {'n_is_sb': '2', 'n_is_sth': '2'},
 'jimenez de cisneros': {'n_is_sb': '0'},
 'jimenez': {'n_is_sb': '0'},
 'jimhickey': {'n_is_sb': '2', 'n_is_sth': '2'},
 'jimi hendrix': {'n_is_sb': '0'},
 'jimmy cagney': {'n_is_sb': '0'},
 'jimmy carter': {'n_is_sb': '0'},
 'jimmy conors': {'n_is_sb': '0'},
 'jimmy doolittle': {'n_is_sb': '0'},
 'jimmy durante': {'n_is_sb': '0'},
 'jimmy hoffa': {'n_is_sb': '0'},
 'jimmy stewart': {'n_is_sb': '0'},
 'jinghis khan': {'n_is_sb': '0'},
 'jingoist': {'n_is_sb': '0'},
 'jingo': {'n_is_sb': '0'},
 'jinnah': {'n_is_sb': '0'},
 'jinnee': {'n_is_sb': '0'},
 'jinni': {'n_is_sb': '0'},
 'jird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jnr': {'n_is_sb': '0'},
 'joachim': {'n_is_sb': '0'},
 'joan crawford': {'n_is_sb': '0'},
 'joan didion': {'n_is_sb': '0'},
 'joan miro': {'n_is_sb': '0'},
 'joan of arc': {'n_is_sb': '0'},
 'joan sutherland': {'n_is_sb': '0'},
 'job candidate': {'n_is_sb': '0'},
 "job's comforter": {'n_is_sb': '0'},
 'jobholder': {'n_is_sb': '0'},
 'jocasta': {'n_is_sb': '0'},
 'joe bloggs': {'n_is_sb': '0'},
 'joe blow': {'n_is_sb': '0'},
 'joe clark': {'n_is_sb': '0'},
 'joe dimaggio': {'n_is_sb': '0'},
 'joe louis': {'n_is_sb': '0'},
 'joel': {'n_is_sb': '2', 'n_is_sth': '2'},
 'joffrey': {'n_is_sb': '0'},
 'joffre': {'n_is_sb': '0'},
 'jogger': {'n_is_sb': '0'},
 'johan august strindberg': {'n_is_sb': '0'},
 'johan julius christian sibelius': {'n_is_sb': '0'},
 'johan kepler': {'n_is_sb': '0'},
 'johann bernoulli': {'n_is_sb': '0'},
 'johann christoph friedrich von schiller': {'n_is_sb': '0'},
 'johann friedrich herbart': {'n_is_sb': '0'},
 'johann gottfried von herder': {'n_is_sb': '0'},
 'johann gutenberg': {'n_is_sb': '0'},
 'johann joachim winckelmann': {'n_is_sb': '0'},
 'johann ludwig uhland': {'n_is_sb': '0'},
 'johann mendel': {'n_is_sb': '0'},
 'johann muller': {'n_is_sb': '0'},
 'johann sebastian bach': {'n_is_sb': '0'},
 'johann strauss': {'n_is_sb': '0'},
 'johann winckelmann': {'n_is_sb': '0'},
 'johann wolfgang von goethe': {'n_is_sb': '0'},
 'johannes brahms': {'n_is_sb': '0'},
 'johannes diderik van der waals': {'n_is_sb': '0'},
 'johannes eckhart': {'n_is_sb': '0'},
 'johannes evangelista purkinje': {'n_is_sb': '0'},
 'johannes gutenberg': {'n_is_sb': '0'},
 'johannes kepler': {'n_is_sb': '0'},
 'johannes peter muller': {'n_is_sb': '0'},
 'johannes van der waals': {'n_is_sb': '0'},
 'johannes vilhelm jensen': {'n_is_sb': '0'},
 'john adams': {'n_is_sb': '0'},
 'john addington symonds': {'n_is_sb': '0'},
 'john amos comenius': {'n_is_sb': '0'},
 'john anthony ciardi': {'n_is_sb': '0'},
 'john augustus roebling': {'n_is_sb': '0'},
 'john bach mcmaster': {'n_is_sb': '0'},
 'john bardeen': {'n_is_sb': '0'},
 'john barrington wain': {'n_is_sb': '0'},
 'john barrymore': {'n_is_sb': '0'},
 'john barth': {'n_is_sb': '0'},
 'john bartlett': {'n_is_sb': '0'},
 'john bernoulli': {'n_is_sb': '0'},
 'john berry hobbs': {'n_is_sb': '0'},
 'john birks gillespie': {'n_is_sb': '0'},
 'john broadus watson': {'n_is_sb': '0'},
 'john brown': {'n_is_sb': '0'},
 'john bull': {'n_is_sb': '0'},
 'john bunyan': {'n_is_sb': '0'},
 'john burdon sanderson haldane': {'n_is_sb': '0'},
 'john burgoyne': {'n_is_sb': '0'},
 'john c. fremont': {'n_is_sb': '0'},
 'john cabot': {'n_is_sb': '0'},
 'john cage': {'n_is_sb': '0'},
 'john calvin': {'n_is_sb': '0'},
 'john chapman': {'n_is_sb': '0'},
 'john charles fremont': {'n_is_sb': '0'},
 'john cheever': {'n_is_sb': '0'},
 'john chrysostom': {'n_is_sb': '0'},
 'john churchill': {'n_is_sb': '0'},
 'john ciardi': {'n_is_sb': '0'},
 'john constable': {'n_is_sb': '0'},
 'john copley': {'n_is_sb': '0'},
 'john d. rockefeller': {'n_is_sb': '0'},
 'john dalton': {'n_is_sb': '0'},
 'john davison rockefeller': {'n_is_sb': '0'},
 'john davis': {'n_is_sb': '0'},
 'john davys': {'n_is_sb': '0'},
 'john deere': {'n_is_sb': '0'},
 'john dewey': {'n_is_sb': '0'},
 'john doe': {'n_is_sb': '0'},
 'john donald budge': {'n_is_sb': '0'},
 'john donne': {'n_is_sb': '0'},
 'john dory': {'n_is_sb': '3', 'n_is_sth': '3'},
 'john dos passos': {'n_is_sb': '0'},
 'john dowland': {'n_is_sb': '0'},
 'john drew': {'n_is_sb': '0'},
 'john dryden': {'n_is_sb': '0'},
 'john duns scotus': {'n_is_sb': '0'},
 'john eccles': {'n_is_sb': '0'},
 'john edgar hoover': {'n_is_sb': '0'},
 'john edward masefield': {'n_is_sb': '0'},
 'john endecott': {'n_is_sb': '0'},
 'john endicott': {'n_is_sb': '0'},
 'john ernst steinbeck': {'n_is_sb': '0'},
 'john fitzgerald kennedy': {'n_is_sb': '0'},
 'john fletcher': {'n_is_sb': '0'},
 'john florio': {'n_is_sb': '0'},
 'john ford': {'n_is_sb': '0'},
 'john foster dulles': {'n_is_sb': '0'},
 'john galbraith': {'n_is_sb': '0'},
 'john galsworthy': {'n_is_sb': '0'},
 'john glenn': {'n_is_sb': '0'},
 'john greenleaf whittier': {'n_is_sb': '0'},
 'john griffith chaney': {'n_is_sb': '0'},
 'john haldane': {'n_is_sb': '0'},
 'john hancock': {'n_is_sb': '0'},
 'john hanning speke': {'n_is_sb': '0'},
 'john harvard': {'n_is_sb': '0'},
 'john hasbrouck van vleck': {'n_is_sb': '0'},
 'john heming': {'n_is_sb': '0'},
 'john hemminge': {'n_is_sb': '0'},
 'john henry newman': {'n_is_sb': '0'},
 "john henry o'hara": {'n_is_sb': '0'},
 'john henry': {'n_is_sb': '0'},
 'john herschel glenn jr.': {'n_is_sb': '0'},
 'john herschel': {'n_is_sb': '0'},
 'john hope franklin': {'n_is_sb': '0'},
 'john howard northrop': {'n_is_sb': '0'},
 'john hoyer updike': {'n_is_sb': '0'},
 'john huss': {'n_is_sb': '0'},
 'john huston': {'n_is_sb': '0'},
 'john irving': {'n_is_sb': '0'},
 'john jacob astor': {'n_is_sb': '0'},
 'john james audubon': {'n_is_sb': '0'},
 'john james osborne': {'n_is_sb': '0'},
 'john james rickard macleod': {'n_is_sb': '0'},
 'john jay': {'n_is_sb': '0'},
 'john joseph mcgraw': {'n_is_sb': '0'},
 'john joseph pershing': {'n_is_sb': '0'},
 'john keats': {'n_is_sb': '0'},
 'john keble': {'n_is_sb': '0'},
 'john kenneth galbraith': {'n_is_sb': '0'},
 'john knox': {'n_is_sb': '0'},
 'john l. h. down': {'n_is_sb': '0'},
 'john l. lewis': {'n_is_sb': '0'},
 'john lackland': {'n_is_sb': '0'},
 'john le carre': {'n_is_sb': '0'},
 'john lennon': {'n_is_sb': '0'},
 'john llewelly lewis': {'n_is_sb': '0'},
 'john locke': {'n_is_sb': '0'},
 'john luther jones': {'n_is_sb': '0'},
 'john lyly': {'n_is_sb': '0'},
 'john m. browning': {'n_is_sb': '0'},
 'john macleod': {'n_is_sb': '0'},
 'john major': {'n_is_sb': '0'},
 'john marquand': {'n_is_sb': '0'},
 'john marshall': {'n_is_sb': '0'},
 'john marstan': {'n_is_sb': '0'},
 'john masefield': {'n_is_sb': '0'},
 'john maynard keynes': {'n_is_sb': '0'},
 'john mccormick': {'n_is_sb': '0'},
 'john mcgraw': {'n_is_sb': '0'},
 'john mercer': {'n_is_sb': '0'},
 'john merven carrere': {'n_is_sb': '0'},
 'john millington synge': {'n_is_sb': '0'},
 'john mill': {'n_is_sb': '0'},
 'john milton cage jr.': {'n_is_sb': '0'},
 'john milton': {'n_is_sb': '0'},
 'john mitchell': {'n_is_sb': '0'},
 'john moses browning': {'n_is_sb': '0'},
 'john muir': {'n_is_sb': '0'},
 'john napier': {'n_is_sb': '0'},
 'john orley allen tate': {'n_is_sb': '0'},
 'john osborne': {'n_is_sb': '0'},
 'john paul ii': {'n_is_sb': '0'},
 'john paul i': {'n_is_sb': '0'},
 'john paul jones': {'n_is_sb': '0'},
 'john philip marquand': {'n_is_sb': '0'},
 'john philip sousa': {'n_is_sb': '0'},
 'john pierpont morgan': {'n_is_sb': '0'},
 'john quincy adams': {'n_is_sb': '0'},
 'john r. major': {'n_is_sb': '0'},
 'john reed': {'n_is_sb': '0'},
 'john robinson jeffers': {'n_is_sb': '0'},
 'john rock': {'n_is_sb': '0'},
 'john roebling': {'n_is_sb': '0'},
 'john ronald reuel tolkien': {'n_is_sb': '0'},
 'john ross': {'n_is_sb': '0'},
 'john rowlands': {'n_is_sb': '0'},
 'john roy major': {'n_is_sb': '0'},
 'john rupert firth': {'n_is_sb': '0'},
 'john ruskin': {'n_is_sb': '0'},
 'john scopes': {'n_is_sb': '0'},
 'john scott haldane': {'n_is_sb': '0'},
 'john simmons barth': {'n_is_sb': '0'},
 'john singer sargent': {'n_is_sb': '0'},
 'john singleton copley': {'n_is_sb': '0'},
 'john smith': {'n_is_sb': '0'},
 'john speke': {'n_is_sb': '0'},
 'john steinbeck': {'n_is_sb': '0'},
 'john stuart mill': {'n_is_sb': '0'},
 'john the baptist': {'n_is_sb': '0'},
 'john the divine': {'n_is_sb': '0'},
 'john the evangelist': {'n_is_sb': '0'},
 'john thomas scopes': {'n_is_sb': '0'},
 'john tradescant': {'n_is_sb': '0'},
 'john trumbull': {'n_is_sb': '0'},
 'john tuzo wilson': {'n_is_sb': '0'},
 'john tyler': {'n_is_sb': '0'},
 'john tyndall': {'n_is_sb': '0'},
 'john uhler': {'n_is_sb': '0'},
 'john updike': {'n_is_sb': '0'},
 'john van vleck': {'n_is_sb': '0'},
 'john vanbrugh': {'n_is_sb': '0'},
 'john venn': {'n_is_sb': '0'},
 'john von neumann': {'n_is_sb': '0'},
 'john wain': {'n_is_sb': '0'},
 'john walker': {'n_is_sb': '0'},
 'john wanamaker': {'n_is_sb': '0'},
 'john wayne': {'n_is_sb': '0'},
 'john webster': {'n_is_sb': '0'},
 'john wesley': {'n_is_sb': '0'},
 'john wickliffe': {'n_is_sb': '0'},
 'john wiclif': {'n_is_sb': '0'},
 'john wilkes booth': {'n_is_sb': '0'},
 'john wilkes': {'n_is_sb': '0'},
 'john william strutt': {'n_is_sb': '0'},
 'john witherspoon': {'n_is_sb': '0'},
 'john wycliffe': {'n_is_sb': '0'},
 'john wyclif': {'n_is_sb': '0'},
 'johnny appleseed': {'n_is_sb': '0'},
 'johnny reb': {'n_is_sb': '0'},
 'johnny': {'n_is_sb': '2', 'n_is_sth': '2'},
 'johns hopkins': {'n_is_sb': '0'},
 'johnston': {'n_is_sb': '0'},
 'johns': {'n_is_sb': '0'},
 'joint author': {'n_is_sb': '0'},
 'joint snake': {'n_is_sb': '0'},
 'jointworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jokester': {'n_is_sb': '0'},
 'joliet': {'n_is_sb': '0'},
 'joliot-curie': {'n_is_sb': '0'},
 'joliot': {'n_is_sb': '0'},
 'jolliet': {'n_is_sb': '0'},
 'jolson': {'n_is_sb': '0'},
 'jomo kenyata': {'n_is_sb': '0'},
 'jonah crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jonah': {'n_is_sb': '0'},
 'jonas edward salk': {'n_is_sb': '0'},
 'jonas salk': {'n_is_sb': '0'},
 'jonathan edwards': {'n_is_sb': '0'},
 'jonathan swift': {'n_is_sb': '0'},
 'jonathan trumbull': {'n_is_sb': '0'},
 'jongleur': {'n_is_sb': '0'},
 'jong': {'n_is_sb': '0'},
 'jons jakob berzelius': {'n_is_sb': '0'},
 'jonson': {'n_is_sb': '0'},
 'joplin': {'n_is_sb': '0'},
 'jordanella floridae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jordanella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jordanian': {'n_is_sb': '0'},
 'jorge borges': {'n_is_sb': '0'},
 'jorge luis borges': {'n_is_sb': '0'},
 'jorge mario pedro vargas llosa': {'n_is_sb': '0'},
 'joroslav heyrovsky': {'n_is_sb': '0'},
 'jose clemente orozco': {'n_is_sb': '0'},
 'jose julian marti': {'n_is_sb': '0'},
 'jose orozco': {'n_is_sb': '0'},
 'jose ortega y gasset': {'n_is_sb': '0'},
 'josef albers': {'n_is_sb': '0'},
 'josef hoffmann': {'n_is_sb': '0'},
 'josef michel montgolfier': {'n_is_sb': '0'},
 'josef von sternberg': {'n_is_sb': '0'},
 'joseph alois schumpeter': {'n_is_sb': '0'},
 'joseph banks rhine': {'n_is_sb': '0'},
 'joseph ben matthias': {'n_is_sb': '0'},
 'joseph black': {'n_is_sb': '0'},
 'joseph campbell': {'n_is_sb': '0'},
 'joseph conrad': {'n_is_sb': '0'},
 'joseph deems taylor': {'n_is_sb': '0'},
 'joseph eggleston johnston': {'n_is_sb': '0'},
 'joseph emerson worcester': {'n_is_sb': '0'},
 'joseph francis keaton': {'n_is_sb': '0'},
 'joseph goebbels': {'n_is_sb': '0'},
 'joseph greenberg': {'n_is_sb': '0'},
 'joseph haydn': {'n_is_sb': '0'},
 'joseph heller': {'n_is_sb': '0'},
 'joseph henry': {'n_is_sb': '0'},
 'joseph hilaire peter belloc': {'n_is_sb': '0'},
 'joseph hooker': {'n_is_sb': '0'},
 'joseph jacques cesaire joffre': {'n_is_sb': '0'},
 'joseph joachim': {'n_is_sb': '0'},
 'joseph john thomson': {'n_is_sb': '0'},
 'joseph lincoln steffens': {'n_is_sb': '0'},
 'joseph lister': {'n_is_sb': '0'},
 'joseph louis barrow': {'n_is_sb': '0'},
 'joseph louis gay-lussac': {'n_is_sb': '0'},
 'joseph m. jacquard': {'n_is_sb': '0'},
 'joseph mallord william turner': {'n_is_sb': '0'},
 'joseph marie jacquard': {'n_is_sb': '0'},
 'joseph mccarthy': {'n_is_sb': '0'},
 'joseph oliver': {'n_is_sb': '0'},
 'joseph paul dimaggio': {'n_is_sb': '0'},
 'joseph paxton': {'n_is_sb': '0'},
 'joseph priestley': {'n_is_sb': '0'},
 'joseph pulitzer': {'n_is_sb': '0'},
 'joseph raymond mccarthy': {'n_is_sb': '0'},
 'joseph rudyard kipling': {'n_is_sb': '0'},
 'joseph schumpeter': {'n_is_sb': '0'},
 'joseph smith': {'n_is_sb': '0'},
 'joseph stalin': {'n_is_sb': '0'},
 'joseph warren stilwell': {'n_is_sb': '0'},
 'josephus': {'n_is_sb': '0'},
 'josh billings': {'n_is_sb': '0'},
 'joshua': {'n_is_sb': '0'},
 'josiah quincy': {'n_is_sb': '0'},
 'josiah spode': {'n_is_sb': '0'},
 'josiah wedgwood': {'n_is_sb': '0'},
 'josiah willard gibbs': {'n_is_sb': '0'},
 'josip broz': {'n_is_sb': '0'},
 'jotunn': {'n_is_sb': '0'},
 'jotun': {'n_is_sb': '0'},
 'journeyer': {'n_is_sb': '0'},
 'jowett': {'n_is_sb': '0'},
 'joyce carol oates': {'n_is_sb': '0'},
 'joyce': {'n_is_sb': '0'},
 'jr': {'n_is_sb': '0'},
 'juan carlos victor maria de borbon y borbon': {'n_is_sb': '0'},
 'juan carlos': {'n_is_sb': '0'},
 'juan domingo peron': {'n_is_sb': '0'},
 'juan ramon jimenez': {'n_is_sb': '0'},
 'judah': {'n_is_sb': '0'},
 'judas iscariot': {'n_is_sb': '0'},
 'judas maccabaeus': {'n_is_sb': '0'},
 'jude': {'n_is_sb': '0'},
 'judge advocate general': {'n_is_sb': '0'},
 'judge advocate': {'n_is_sb': '0'},
 'judith jamison': {'n_is_sb': '0'},
 'judith': {'n_is_sb': '0'},
 'judy garland': {'n_is_sb': '0'},
 'juggernaut': {'n_is_sb': '0'},
 'jugoslavian': {'n_is_sb': '0'},
 'jugoslav': {'n_is_sb': '0'},
 'jules alfred huot de goncourt': {'n_is_sb': '0'},
 'jules de goncourt': {'n_is_sb': '0'},
 'jules emile frederic massenet': {'n_is_sb': '0'},
 'jules feifer': {'n_is_sb': '0'},
 'jules verne': {'n_is_sb': '0'},
 'julia evelina smith': {'n_is_sb': '0'},
 'julia ward howe': {'n_is_sb': '0'},
 'julian bond': {'n_is_sb': '0'},
 'julio iglesias': {'n_is_sb': '0'},
 'julius caesar': {'n_is_sb': '0'},
 'julius erving': {'n_is_sb': '0'},
 'julius marx': {'n_is_sb': '0'},
 'julius ullman': {'n_is_sb': '0'},
 'julius winfield erving': {'n_is_sb': '0'},
 'jument': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jumping bristletail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jumping mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jumping plant louse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'junco hyemalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'junco': {'n_is_sb': '3', 'n_is_sth': '3'},
 'june beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'june bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jungle cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jungle cock': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jungle fowl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jungle hen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'jung': {'n_is_sb': '0'},
 'junin virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'junior lightweight': {'n_is_sb': '2', 'n_is_sth': '2'},
 'junior middleweight': {'n_is_sb': '2', 'n_is_sth': '2'},
 'junior welterweight': {'n_is_sb': '2', 'n_is_sth': '2'},
 'junipero serra': {'n_is_sb': '0'},
 'junkers': {'n_is_sb': '2', 'n_is_sth': '2'},
 'junker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'junkie': {'n_is_sb': '0'},
 'junky': {'n_is_sb': '0'},
 'juno': {'n_is_sb': '0'},
 'jupiter fidius': {'n_is_sb': '0'},
 'jupiter fulgur': {'n_is_sb': '0'},
 'jupiter fulminator': {'n_is_sb': '0'},
 'jupiter optimus maximus': {'n_is_sb': '0'},
 'jupiter pluvius': {'n_is_sb': '0'},
 'jupiter tonans': {'n_is_sb': '0'},
 'juryman': {'n_is_sb': '0'},
 'jurywoman': {'n_is_sb': '0'},
 'jussieu': {'n_is_sb': '0'},
 'justice of the peace': {'n_is_sb': '0'},
 'justiciary': {'n_is_sb': '0'},
 'justiciar': {'n_is_sb': '0'},
 'justifier': {'n_is_sb': '0'},
 'justinian i': {'n_is_sb': '0'},
 'justinian the great': {'n_is_sb': '0'},
 'justinian': {'n_is_sb': '0'},
 'juvenal': {'n_is_sb': '0'},
 'juvenile delinquent': {'n_is_sb': '0'},
 'juvenile person': {'n_is_sb': '0'},
 'jynx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kabbalist': {'n_is_sb': '0'},
 'kachaturian': {'n_is_sb': '0'},
 'kaffir cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kaffir': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kafir': {'n_is_sb': '0'},
 'kafka': {'n_is_sb': '0'},
 'kahlil gibran': {'n_is_sb': '0'},
 'kahn': {'n_is_sb': '0'},
 'kaiser bill': {'n_is_sb': '0'},
 'kaiser wilhelm': {'n_is_sb': '0'},
 'kakatoe galerita': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kakatoe leadbeateri': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kakatoe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kalapooia': {'n_is_sb': '0'},
 'kalapuya': {'n_is_sb': '0'},
 'kalif': {'n_is_sb': '0'},
 'kalinin': {'n_is_sb': '0'},
 'kaliph': {'n_is_sb': '0'},
 'kali': {'n_is_sb': '0'},
 'kalka': {'n_is_sb': '0'},
 'kalki': {'n_is_sb': '0'},
 'kalon tripa': {'n_is_sb': '0'},
 'kalotermes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kalotermitidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kama': {'n_is_sb': '2', 'n_is_sth': '2'},
 'kamchatkan sea eagle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kamehameha i': {'n_is_sb': '0'},
 'kamehameha the great': {'n_is_sb': '0'},
 'kamia': {'n_is_sb': '0'},
 'kamikaze': {'n_is_sb': '0'},
 'kami': {'n_is_sb': '0'},
 'kampuchean': {'n_is_sb': '2', 'n_is_sth': '2'},
 'kanarese': {'n_is_sb': '2', 'n_is_sth': '2'},
 'kanchil': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kandinsky': {'n_is_sb': '0'},
 'kangaroo bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kangaroo hare': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kangaroo jerboa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kangaroo mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kangaroo rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kansan': {'n_is_sb': '0'},
 'kansa': {'n_is_sb': '2', 'n_is_sth': '2'},
 'kant': {'n_is_sb': '0'},
 'karakalpak': {'n_is_sb': '2', 'n_is_sth': '2'},
 'karakul': {'n_is_sb': '3', 'n_is_sth': '3'},
 'karel capek': {'n_is_sb': '0'},
 'karelian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'karen blixen': {'n_is_sb': '0'},
 'karl adolf eichmann': {'n_is_sb': '0'},
 'karl adolph verner': {'n_is_sb': '0'},
 'karl alex muller': {'n_is_sb': '0'},
 'karl augustus menninger': {'n_is_sb': '0'},
 'karl baedeker': {'n_is_sb': '0'},
 'karl barth': {'n_is_sb': '0'},
 'karl czerny': {'n_is_sb': '0'},
 'karl friedrich gauss': {'n_is_sb': '0'},
 'karl friedrich hieronymus von munchhausen': {'n_is_sb': '0'},
 'karl gauss': {'n_is_sb': '0'},
 'karl gjellerup': {'n_is_sb': '0'},
 'karl gunnar myrdal': {'n_is_sb': '0'},
 'karl gustav jacob jacobi': {'n_is_sb': '0'},
 'karl jaspers': {'n_is_sb': '0'},
 'karl landsteiner': {'n_is_sb': '0'},
 'karl linne': {'n_is_sb': '0'},
 'karl marx': {'n_is_sb': '0'},
 'karl menninger': {'n_is_sb': '0'},
 'karl rudolf gerd von rundstedt': {'n_is_sb': '0'},
 'karl scheele': {'n_is_sb': '0'},
 'karl theodor jaspers': {'n_is_sb': '0'},
 'karl von clausewitz': {'n_is_sb': '0'},
 'karl von frisch': {'n_is_sb': '0'},
 'karl waldemar ziegler': {'n_is_sb': '0'},
 'karl wernicke': {'n_is_sb': '0'},
 'karl wilhelm scheele': {'n_is_sb': '0'},
 'karl wilhelm siemens': {'n_is_sb': '0'},
 'karlfeldt': {'n_is_sb': '0'},
 'karloff': {'n_is_sb': '0'},
 'karok': {'n_is_sb': '0'},
 'karol wojtyla': {'n_is_sb': '0'},
 'karpov': {'n_is_sb': '0'},
 'karsavina': {'n_is_sb': '0'},
 'kartikeya': {'n_is_sb': '0'},
 'karttikeya': {'n_is_sb': '0'},
 'kashmir goat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kashmiri': {'n_is_sb': '2', 'n_is_sth': '2'},
 'kaspar friedrich wolff': {'n_is_sb': '0'},
 'kasparov': {'n_is_sb': '0'},
 'kassite': {'n_is_sb': '2', 'n_is_sth': '2'},
 'kastler': {'n_is_sb': '0'},
 'katari': {'n_is_sb': '0'},
 'kate chopin': {'n_is_sb': '0'},
 "kate o'flaherty chopin": {'n_is_sb': '0'},
 'kate smith': {'n_is_sb': '0'},
 'katharine hepburn': {'n_is_sb': '0'},
 'katharine houghton hepburn': {'n_is_sb': '0'},
 'katherine anne porter': {'n_is_sb': '0'},
 'katherine cornell': {'n_is_sb': '0'},
 'katherine mansfield': {'n_is_sb': '0'},
 'kathleen mansfield beauchamp': {'n_is_sb': '0'},
 'kathryn elizabeth smith': {'n_is_sb': '0'},
 'katsushika hokusai': {'n_is_sb': '0'},
 'katsuwonus pelamis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'katsuwonus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kaufman': {'n_is_sb': '0'},
 'kaunda': {'n_is_sb': '0'},
 'kay boyle': {'n_is_sb': '0'},
 'kazakhstani': {'n_is_sb': '0'},
 'kazimir malevich': {'n_is_sb': '0'},
 'kazimir severinovich malevich': {'n_is_sb': '0'},
 'ka': {'n_is_sb': '2', 'n_is_sth': '2'},
 'kean': {'n_is_sb': '0'},
 'keaton': {'n_is_sb': '0'},
 'keats': {'n_is_sb': '0'},
 'kea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'keble': {'n_is_sb': '0'},
 'keb': {'n_is_sb': '0'},
 'kechua': {'n_is_sb': '0'},
 'keeshond': {'n_is_sb': '3', 'n_is_sth': '3'},
 'keith rupert murdoch': {'n_is_sb': '0'},
 'kekchi': {'n_is_sb': '0'},
 'kekule': {'n_is_sb': '0'},
 'keller': {'n_is_sb': '0'},
 'kellogg': {'n_is_sb': '0'},
 'kelp greenling': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kelpie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kelpy': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kelt': {'n_is_sb': '2', 'n_is_sth': '2'},
 'kemal ataturk': {'n_is_sb': '0'},
 'kemal pasha': {'n_is_sb': '0'},
 'ken elton kesey': {'n_is_sb': '0'},
 'ken kesey': {'n_is_sb': '0'},
 'ken russell': {'n_is_sb': '0'},
 'kendall': {'n_is_sb': '0'},
 'kendrew': {'n_is_sb': '0'},
 'kennelly': {'n_is_sb': '0'},
 'kenneth bancroft clark': {'n_is_sb': '0'},
 'kenneth clark': {'n_is_sb': '0'},
 'kenneth david kaunda': {'n_is_sb': '0'},
 'kenneth grahame': {'n_is_sb': '0'},
 'kenneth kaunda': {'n_is_sb': '0'},
 'kenneth roberts': {'n_is_sb': '0'},
 'kentuckian': {'n_is_sb': '0'},
 'kentucky black bass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kenyan': {'n_is_sb': '0', 'cap_word': 'Kenyan'},
 'kenyapithecus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kenyata': {'n_is_sb': '0'},
 'kenzo tange': {'n_is_sb': '0'},
 'keokuk': {'n_is_sb': '0'},
 'kepler': {'n_is_sb': '0'},
 'kept woman': {'n_is_sb': '0'},
 'kerb crawler': {'n_is_sb': '0'},
 'kerensky': {'n_is_sb': '0'},
 'kerouac': {'n_is_sb': '0'},
 'kerry blue terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kesey': {'n_is_sb': '0'},
 'kestrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kettering': {'n_is_sb': '0'},
 'keyboardist': {'n_is_sb': '0'},
 'keyhole limpet': {'n_is_sb': '0'},
 'keynes': {'n_is_sb': '0'},
 'khachaturian': {'n_is_sb': '0'},
 'khadafy': {'n_is_sb': '0'},
 'khalifah': {'n_is_sb': '0'},
 'khalif': {'n_is_sb': '0'},
 'khalka': {'n_is_sb': '0'},
 'khalkha': {'n_is_sb': '0'},
 'khama': {'n_is_sb': '0'},
 'khanty': {'n_is_sb': '0'},
 'khayr ad-din': {'n_is_sb': '0'},
 'khedive': {'n_is_sb': '0'},
 'khepera': {'n_is_sb': '0'},
 'khirghiz': {'n_is_sb': '0'},
 'khomeini': {'n_is_sb': '0'},
 'kiang': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kibbutznik': {'n_is_sb': '0'},
 'kibitzer': {'n_is_sb': '0'},
 'kichai': {'n_is_sb': '0'},
 'kickapoo': {'n_is_sb': '2', 'n_is_sth': '2'},
 'kicker': {'n_is_sb': '0'},
 'kidd': {'n_is_sb': '0'},
 'kierkegaard': {'n_is_sb': '0'},
 'kieslowski': {'n_is_sb': '0'},
 'kike': {'n_is_sb': '0'},
 'kildeer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kiliwa': {'n_is_sb': '0'},
 'kiliwi': {'n_is_sb': '0'},
 'killdeer plover': {'n_is_sb': '3', 'n_is_sth': '3'},
 'killdeer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'killer bee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'killer whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'killifish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'killjoy': {'n_is_sb': '2', 'n_is_sth': '2'},
 'kilroy': {'n_is_sb': '0'},
 'kine': {'n_is_sb': '0'},
 'king arthur': {'n_is_sb': '0'},
 'king camp gilette': {'n_is_sb': '0'},
 'king charles spaniel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'king cobra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'king crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'king harold ii': {'n_is_sb': '0'},
 'king harold i': {'n_is_sb': '0'},
 'king hussein': {'n_is_sb': '0'},
 'king john': {'n_is_sb': '0'},
 'king lear': {'n_is_sb': '0'},
 'king mackerel': {'n_is_sb': '0'},
 'king oedipus': {'n_is_sb': '0'},
 'king of beasts': {'n_is_sb': '3', 'n_is_sth': '3'},
 'king of england': {'n_is_sb': '0'},
 'king of france': {'n_is_sb': '0'},
 'king of great britain': {'n_is_sb': '0'},
 'king of the herring': {'n_is_sb': '3', 'n_is_sth': '3'},
 'king oliver': {'n_is_sb': '0'},
 'king penguin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'king salmon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'king snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'king vulture': {'n_is_sb': '3', 'n_is_sth': '3'},
 'king whiting': {'n_is_sb': '3', 'n_is_sth': '3'},
 "king's counsel": {'n_is_sb': '0'},
 'kingbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kingfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kinglet': {'n_is_sb': '0'},
 'kingmaker': {'n_is_sb': '0'},
 'kingsnake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kinkajou': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kinsey': {'n_is_sb': '0'},
 'kinsperson': {'n_is_sb': '0'},
 'kinswoman': {'n_is_sb': '0'},
 'kiowa': {'n_is_sb': '0'},
 'kipling': {'n_is_sb': '0'},
 'kirchhoff': {'n_is_sb': '0'},
 'kirchner': {'n_is_sb': '0'},
 'kirghiz': {'n_is_sb': '2', 'n_is_sth': '2'},
 'kirgiz': {'n_is_sb': '0'},
 'kishar': {'n_is_sb': '0'},
 'kissing bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kissing cousin': {'n_is_sb': '0'},
 'kissing kin': {'n_is_sb': '0'},
 'kissinger': {'n_is_sb': '0'},
 'kit carson': {'n_is_sb': '0'},
 'kit fox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kitchen help': {'n_is_sb': '0'},
 'kittiwake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kitty-cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ki': {'n_is_sb': '0'},
 'klansman': {'n_is_sb': '0'},
 'klaproth': {'n_is_sb': '0'},
 'klaus fuchs': {'n_is_sb': '0'},
 'klebs-loeffler bacillus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'klebsiella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'klee': {'n_is_sb': '0'},
 'klein': {'n_is_sb': '0'},
 'kleist': {'n_is_sb': '0'},
 'klemens metternich': {'n_is_sb': '0'},
 'kleptomaniac': {'n_is_sb': '0'},
 'klimt': {'n_is_sb': '0'},
 'klinefelter': {'n_is_sb': '0'},
 'kline': {'n_is_sb': '0'},
 'klopstock': {'n_is_sb': '0'},
 'kluxer': {'n_is_sb': '0'},
 'knacker': {'n_is_sb': '0'},
 'kneeler': {'n_is_sb': '0'},
 'knife-handle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'knight bachelor': {'n_is_sb': '0'},
 'knight banneret': {'n_is_sb': '0'},
 'knight of the round table': {'n_is_sb': '0'},
 'knight of the square flag': {'n_is_sb': '0'},
 'knight templar': {'n_is_sb': '0'},
 'knight-errant': {'n_is_sb': '0'},
 'know nothing': {'n_is_sb': '0'},
 'know-all': {'n_is_sb': '0'},
 'know-it-all': {'n_is_sb': '0'},
 'knower': {'n_is_sb': '0'},
 'knox': {'n_is_sb': '0'},
 'knut hamsun': {'n_is_sb': '0'},
 'knut pedersen': {'n_is_sb': '0'},
 'koala bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'koala': {'n_is_sb': '3', 'n_is_sth': '3'},
 'koasati': {'n_is_sb': '0'},
 'kobus kob': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kobus leche': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kobus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'kob': {'n_is_sb': '0'},
 'koch': {'n_is_sb': '0'},
 'kodagu': {'n_is_sb': '0'},
 'kodiak bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kodiak': {'n_is_sb': '3', 'n_is_sth': '3'},
 'koestler': {'n_is_sb': '0'},
 'kogia breviceps': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kogia simus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kogia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kolam': {'n_is_sb': '0'},
 'kolkhoznik': {'n_is_sb': '0'},
 'komi': {'n_is_sb': '0'},
 'komodo dragon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'komodo lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'komondor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'konoe': {'n_is_sb': '0'},
 'konoye': {'n_is_sb': '0'},
 'konrad adenauer': {'n_is_sb': '0'},
 'konrad lorenz': {'n_is_sb': '0'},
 'konrad von gesner': {'n_is_sb': '0'},
 'konrad zacharias lorenz': {'n_is_sb': '0'},
 'konstantin sergeevich alekseev': {'n_is_sb': '0'},
 'konstantin sergeyevich stanislavsky': {'n_is_sb': '0'},
 'konstantin stanislavsky': {'n_is_sb': '0'},
 'koodoo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kookaburra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'koopmans': {'n_is_sb': '0'},
 'korbut': {'n_is_sb': '0'},
 'korchnoi': {'n_is_sb': '0'},
 'korda': {'n_is_sb': '0'},
 'kore': {'n_is_sb': '0'},
 'korzybski': {'n_is_sb': '0'},
 'kosciusko': {'n_is_sb': '0'},
 'kosciuszko': {'n_is_sb': '0'},
 'kotar': {'n_is_sb': '0'},
 'kota': {'n_is_sb': '0'},
 'koto player': {'n_is_sb': '0'},
 'koudou': {'n_is_sb': '0'},
 'koussevitzky': {'n_is_sb': '0'},
 'krafft-ebing': {'n_is_sb': '0'},
 'krait': {'n_is_sb': '3', 'n_is_sth': '3'},
 'krasner': {'n_is_sb': '0'},
 'krauthead': {'n_is_sb': '2', 'n_is_sth': '2'},
 'krebs': {'n_is_sb': '0'},
 'kreisler': {'n_is_sb': '0'},
 'krishna': {'n_is_sb': '0'},
 'kriss kringle': {'n_is_sb': '0'},
 'kroeber': {'n_is_sb': '0'},
 'kronecker': {'n_is_sb': '0'},
 'kropotkin': {'n_is_sb': '0'},
 'kroto': {'n_is_sb': '0'},
 'kruger': {'n_is_sb': '0'},
 'krupp': {'n_is_sb': '0'},
 'krypterophaneron': {'n_is_sb': '0'},
 'krzysztof kieslowski': {'n_is_sb': '0'},
 'kshatriya': {'n_is_sb': '0'},
 'ku kluxer': {'n_is_sb': '0'},
 'kuan yin': {'n_is_sb': '0'},
 'kubla khan': {'n_is_sb': '0'},
 'kublai kaan': {'n_is_sb': '0'},
 'kublai khan': {'n_is_sb': '0'},
 'kubrick': {'n_is_sb': '0'},
 'kudu': {'n_is_sb': '0'},
 'kuhn': {'n_is_sb': '0'},
 'kui': {'n_is_sb': '0'},
 'kund johan victor rasmussen': {'n_is_sb': '0'},
 'kung futzu': {'n_is_sb': '0'},
 'kurd': {'n_is_sb': '0'},
 'kurosawa': {'n_is_sb': '0'},
 'kurt godel': {'n_is_sb': '0'},
 'kurt vonnegut': {'n_is_sb': '0'},
 'kurt waldheim': {'n_is_sb': '0'},
 'kurt weill': {'n_is_sb': '0'},
 'kusan': {'n_is_sb': '0'},
 'kutuzov': {'n_is_sb': '0'},
 'kuvasz': {'n_is_sb': '3', 'n_is_sth': '3'},
 'kuwaiti': {'n_is_sb': '0'},
 'kuznets': {'n_is_sb': '0'},
 'kvetch': {'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'kwakiutl': {'n_is_sb': '0'},
 'kwan-yin': {'n_is_sb': '0'},
 'kwannon': {'n_is_sb': '0'},
 'kyd': {'n_is_sb': '0'},
 'kyphosus sectatrix': {'n_is_sb': '0'},
 "l'enfant": {'n_is_sb': '0'},
 'l. m. montgomery': {'n_is_sb': '0'},
 'l. monocytogenes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'l. ron hubbard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'l. s. lowry': {'n_is_sb': '0'},
 'la fayette': {'n_is_sb': '0'},
 'la fontaine': {'n_is_sb': '0'},
 'la rochefoucauld': {'n_is_sb': '0'},
 'la tour': {'n_is_sb': '0'},
 'laban': {'n_is_sb': '0'},
 'labor coach': {'n_is_sb': '0'},
 'labor leader': {'n_is_sb': '0'},
 'labor organizer': {'n_is_sb': '0'},
 'labor secretary': {'n_is_sb': '0'},
 'labourer': {'n_is_sb': '0'},
 'labourite': {'n_is_sb': '0'},
 'labrador retriever': {'n_is_sb': '0'},
 'labrouste': {'n_is_sb': '0'},
 'labyrinthodonta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'labyrinthodont': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lace bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lacerta agilis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lacerta viridis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lacertid lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lacertid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lacer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lacewing fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lachaise': {'n_is_sb': '0'},
 'lachesis': {'n_is_sb': '0'},
 'lachnolaimus maximus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'laconian': {'n_is_sb': '0'},
 'lacrosse player': {'n_is_sb': '0'},
 'lactobacillaceae': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lactophrys quadricornis': {'n_is_sb': '3', 'n_is_sth': '3'},
 "ladies' man": {'n_is_sb': '0'},
 'ladino': {'n_is_sb': '0'},
 'lady beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lady crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lady diana frances spencer': {'n_is_sb': '0'},
 'lady emma hamilton': {'n_is_sb': '0'},
 'lady friend': {'n_is_sb': '0'},
 'lady godiva': {'n_is_sb': '0'},
 'lady jane grey': {'n_is_sb': '0'},
 'lady killer': {'n_is_sb': '0'},
 'lady of pleasure': {'n_is_sb': '0'},
 'lady of the house': {'n_is_sb': '0'},
 'lady peel': {'n_is_sb': '0'},
 "lady's maid": {'n_is_sb': '0'},
 'ladybeetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ladybird beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ladyfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ladylove': {'n_is_sb': '0'},
 'laertes': {'n_is_sb': '0'},
 'lafayette': {'n_is_sb': '0'},
 'laffer': {'n_is_sb': '0'},
 'laffite': {'n_is_sb': '0'},
 'lafitte': {'n_is_sb': '0'},
 'lagger': {'n_is_sb': '0'},
 'lagodon rhomboides': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lagomorph': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lagopus scoticus': {'n_is_sb': '0'},
 'lagopus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lagorchestes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lagostomus maximus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'laius': {'n_is_sb': '0'},
 'lake duck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lake herring': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lake salmon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lake trout': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lake whitefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lakeland terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lakshmi': {'n_is_sb': '0'},
 'lama guanicoe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lama pacos': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lama peruana': {'n_is_sb': '0'},
 'lamaist': {'n_is_sb': '0'},
 'lamarck': {'n_is_sb': '0'},
 'lambert': {'n_is_sb': '0'},
 'lambis': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lambkin': {'n_is_sb': '0'},
 'lame duck': {'n_is_sb': '0'},
 'lamellibranch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lamellicorn beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lamenter': {'n_is_sb': '0'},
 'lame': {'n_is_sb': '2', 'n_is_sth': '2', 'jj_to_jjr': 'lamer', 'jj_to_jjs': 'lamest'},
 'lamia': {'n_is_sb': '0'},
 'laminaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'laminator': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lammergeier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lammergeyer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lamp shell': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lamper eel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lamplighter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lampoon artist': {'n_is_sb': '0'},
 'lampooner': {'n_is_sb': '0'},
 'lamprey eel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lamprey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lampris guttatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lampris regius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lampropeltis getulus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lampropeltis triangulum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lampropeltis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lampshell': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lancastrian': {'n_is_sb': '0'},
 'lance corporal': {'n_is_sb': '0'},
 'lancelet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lancelot': {'n_is_sb': '0'},
 'lancer': {'n_is_sb': '0'},
 'lancet fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lancetfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'land agent': {'n_is_sb': '0'},
 'land rail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'landgrave': {'n_is_sb': '0'},
 'landlocked salmon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'landlubber': {'n_is_sb': '0'},
 'landman': {'n_is_sb': '0'},
 'landowska': {'n_is_sb': '0'},
 'landscape architect': {'n_is_sb': '0'},
 'landscape gardener': {'n_is_sb': '0'},
 'landscaper': {'n_is_sb': '0'},
 'landscapist': {'n_is_sb': '0'},
 'landsteiner': {'n_is_sb': '0'},
 'laney': {'n_is_sb': '0'},
 'lange': {'n_is_sb': '0'},
 'langlauffer': {'n_is_sb': '0'},
 'langley': {'n_is_sb': '0'},
 'langmuir': {'n_is_sb': '0'},
 'langobard': {'n_is_sb': '0'},
 'langouste': {'n_is_sb': '3', 'n_is_sth': '3'},
 'langston hughes': {'n_is_sb': '0'},
 'langtry': {'n_is_sb': '0'},
 'languisher': {'n_is_sb': '0'},
 'langur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lanius borealis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lanius excubitor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lanius lucovicianus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lanius ludovicianus excubitorides': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lanius ludovicianus migrans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lantern fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lantern-fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lanternfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lanthanotus borneensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lao-tse': {'n_is_sb': '0'},
 'lao-tzu': {'n_is_sb': '0'},
 'lao-zi': {'n_is_sb': '0'},
 'laocoon': {'n_is_sb': '0'},
 'laotian': {'n_is_sb': '0'},
 'lapidarist': {'n_is_sb': '0'},
 'lapidary': {'n_is_sb': '0'},
 'lapidator': {'n_is_sb': '0'},
 'lapidist': {'n_is_sb': '0'},
 'lapin': {'n_is_sb': '2', 'n_is_sth': '2'},
 'laplace': {'n_is_sb': '0'},
 'lappet caterpillar': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lappet moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lapplander': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lapp': {'n_is_sb': '0'},
 'lapwing': {'n_is_sb': '3', 'n_is_sth': '3'},
 'larcener': {'n_is_sb': '0'},
 'larcenist': {'n_is_sb': '0'},
 'lardner': {'n_is_sb': '0'},
 'large civet': {'n_is_sb': '0'},
 'large person': {'n_is_sb': '0'},
 'large poodle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'large white': {'n_is_sb': '3', 'n_is_sth': '3'},
 'largemouth bass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'largemouth black bass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'largemouthed bass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'largemouthed black bass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'largemouth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'laricariidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'larid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lari': {'n_is_sb': '0'},
 'larousse': {'n_is_sb': '0'},
 'lars onsager': {'n_is_sb': '0'},
 'larus argentatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'larus canus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'larus marinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'larus ridibundus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'larvacean': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lasalle': {'n_is_sb': '0'},
 'lascar': {'n_is_sb': '0'},
 'lasiocampid moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lasiocampid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lasiurus borealis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lasiurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lassa virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lass': {'n_is_sb': '0'},
 'laszlo lowestein': {'n_is_sb': '0'},
 'latchkey child': {'n_is_sb': '0'},
 'latecomer': {'n_is_sb': '0'},
 'latimeria chalumnae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'latimeria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'latin american': {'n_is_sb': '0'},
 'latinist': {'n_is_sb': '0'},
 'latino': {'n_is_sb': '0'},
 'latitudinarian': {'n_is_sb': '0'},
 'latona': {'n_is_sb': '0'},
 'latrobe': {'n_is_sb': '0'},
 'latrodectus mactans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'latrodectus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'latter-day saint': {'n_is_sb': '0'},
 'laudator': {'n_is_sb': '0'},
 'lauder': {'n_is_sb': '2', 'n_is_sth': '2'},
 'laugher': {'n_is_sb': '0'},
 'laughing gull': {'n_is_sb': '3', 'n_is_sth': '3'},
 'laughing hyena': {'n_is_sb': '3', 'n_is_sth': '3'},
 'laughing jackass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'laughing owl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'launce': {'n_is_sb': '3', 'n_is_sth': '3'},
 'laundress': {'n_is_sb': '0'},
 'laundryman': {'n_is_sb': '0'},
 'laundrywoman': {'n_is_sb': '0'},
 'laureate': {'n_is_sb': '0'},
 'laurence olivier': {'n_is_sb': '0'},
 'laurence stephen lowry': {'n_is_sb': '0'},
 'laurence sterne': {'n_is_sb': '0'},
 'laurens': {'n_is_sb': '0'},
 'laurentius': {'n_is_sb': '0'},
 'lauritz lebrecht hommel melchior': {'n_is_sb': '0'},
 'lauritz melchior': {'n_is_sb': '0'},
 'lavoisier': {'n_is_sb': '0'},
 'lavrenti pavlovich beria': {'n_is_sb': '0'},
 'law agent': {'n_is_sb': '0'},
 'law offender': {'n_is_sb': '0'},
 'law officer': {'n_is_sb': '0'},
 'law student': {'n_is_sb': '0'},
 'lawbreaker': {'n_is_sb': '0'},
 'lawgiver': {'n_is_sb': '0'},
 'lawmaker': {'n_is_sb': '0'},
 'lawman': {'n_is_sb': '0'},
 'lawrence durrell': {'n_is_sb': '0'},
 'lawrence george durrell': {'n_is_sb': '0'},
 'lawrence of arabia': {'n_is_sb': '0'},
 'lawrence peter berra': {'n_is_sb': '0'},
 'lawrence': {'n_is_sb': '0'},
 'lay reader': {'n_is_sb': '0'},
 'lay witness': {'n_is_sb': '0'},
 'layabout': {'n_is_sb': '0'},
 'layperson': {'n_is_sb': '0'},
 'lazarus': {'n_is_sb': '0'},
 'lazar': {'n_is_sb': '0'},
 'lazzaro spallanzani': {'n_is_sb': '0'},
 'lbj': {'n_is_sb': '0'},
 'le carre': {'n_is_sb': '0'},
 'le chatelier': {'n_is_sb': '0'},
 'le corbusier': {'n_is_sb': '0'},
 'le douanier rousseau': {'n_is_sb': '0'},
 'le duc tho': {'n_is_sb': '0'},
 'le gallienne': {'n_is_sb': '0'},
 'le notre': {'n_is_sb': '0'},
 'leacock': {'n_is_sb': '0'},
 'leadbelly': {'n_is_sb': '0'},
 'leading lady': {'n_is_sb': '0'},
 'leading light': {'n_is_sb': '2', 'n_is_sth': '2'},
 'leading man': {'n_is_sb': '0'},
 'leaf beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leaf bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leaf insect': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leaf miner': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leaf roller': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leaf-cutter bee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leaf-cutter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'leaf-cutting bee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leaf-foot bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leaf-footed bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leaf-miner': {'n_is_sb': '2', 'n_is_sth': '2'},
 'leaf-nosed bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leaf-nosed snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leaf-roller': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leafhopper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leafnose bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leaker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'leakey': {'n_is_sb': '0'},
 'leander': {'n_is_sb': '0'},
 'leaper': {'n_is_sb': '0'},
 'learned person': {'n_is_sb': '0'},
 'leary': {'n_is_sb': '0', 'jj_to_jjr': 'learier', 'jj_to_jjs': 'leariest'},
 'lear': {'n_is_sb': '0'},
 'lease giver': {'n_is_sb': '0'},
 'least bittern': {'n_is_sb': '2', 'n_is_sth': '2'},
 'least sandpiper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'least shrew': {'n_is_sb': '0'},
 'leather carp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leatherback turtle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leatherback': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leatherfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leatherjacket': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leatherjack': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leatherneck': {'n_is_sb': '0'},
 'leathery turtle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leaver': {'n_is_sb': '0'},
 'lebanese': {'n_is_sb': '0'},
 'lebistes reticulatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lebistes': {'n_is_sb': '0'},
 'lech walesa': {'n_is_sb': '0'},
 'lecher': {'n_is_sb': '0'},
 'lechwe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leda': {'n_is_sb': '0'},
 'ledbetter': {'n_is_sb': '0'},
 'ledgeman': {'n_is_sb': '0'},
 'lee buck trevino': {'n_is_sb': '0'},
 'lee de forest': {'n_is_sb': '0'},
 'lee harvey oswald': {'n_is_sb': '0'},
 'lee krasner': {'n_is_sb': '0'},
 'lee trevino': {'n_is_sb': '0'},
 'lee yuen kam': {'n_is_sb': '0'},
 'leeuwenhoek': {'n_is_sb': '0'},
 'left fielder': {'n_is_sb': '0'},
 'left hander': {'n_is_sb': '0'},
 'left-handed pitcher': {'n_is_sb': '0'},
 'left-winger': {'n_is_sb': '0'},
 'lefteye flounder': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lefteyed flounder': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lefthander': {'n_is_sb': '0'},
 'legal assistant': {'n_is_sb': '0'},
 'legal expert': {'n_is_sb': '0'},
 'legal guardian': {'n_is_sb': '0'},
 'legal representative': {'n_is_sb': '0'},
 'legatee': {'n_is_sb': '0'},
 'legendary creature': {'n_is_sb': '0'},
 'leger': {'n_is_sb': '2', 'n_is_sth': '2'},
 'legionary ant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'legionary': {'n_is_sb': '0'},
 'legionella pneumophilia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'legionella': {'n_is_sb': '2', 'n_is_sth': '2'},
 'legionnaire': {'n_is_sb': '0'},
 'legless lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lehar': {'n_is_sb': '0'},
 'leibnitz': {'n_is_sb': '0'},
 'leibniz': {'n_is_sb': '0'},
 'leigh hunt': {'n_is_sb': '0'},
 'leigh': {'n_is_sb': '0'},
 'leipoa ocellata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leipoa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leishmania': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leland stanford': {'n_is_sb': '0'},
 'lemaitre': {'n_is_sb': '0'},
 'lemming': {'n_is_sb': '0'},
 'lemmon': {'n_is_sb': '0'},
 'lemmus lemmus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lemmus trimucronatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lemon shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lemon sole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lemur catta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lemur': {'n_is_sb': '0'},
 'lenard': {'n_is_sb': '0'},
 'lendl': {'n_is_sb': '0'},
 'lenin': {'n_is_sb': '0'},
 'lennon': {'n_is_sb': '0'},
 'lennox robinson': {'n_is_sb': '0'},
 'lens maker': {'n_is_sb': '0'},
 'lensman': {'n_is_sb': '0'},
 'leo delibes': {'n_is_sb': '0'},
 'leo esaki': {'n_is_sb': '0'},
 'leo iii': {'n_is_sb': '0'},
 'leo i': {'n_is_sb': '0'},
 'leo szilard': {'n_is_sb': '0'},
 'leo the great': {'n_is_sb': '0'},
 'leo tolstoy': {'n_is_sb': '0'},
 'leo x': {'n_is_sb': '0'},
 'leon battista alberti': {'n_is_sb': '0'},
 'leon trotsky': {'n_is_sb': '0'},
 'leonard bernstein': {'n_is_sb': '0'},
 'leonard bloomfield': {'n_is_sb': '0'},
 'leonard constant lambert': {'n_is_sb': '0'},
 'leonard marx': {'n_is_sb': '0'},
 'leonardo da vinci': {'n_is_sb': '0'},
 'leonardo': {'n_is_sb': '0'},
 'leonard': {'n_is_sb': '0'},
 'leonberg': {'n_is_sb': '0'},
 'leoncita': {'n_is_sb': '0'},
 'leonhard euler': {'n_is_sb': '0'},
 'leonid brezhnev': {'n_is_sb': '0'},
 'leonid fyodorovich myasin': {'n_is_sb': '0'},
 'leonid ilyich brezhnev': {'n_is_sb': '0'},
 'leonidas': {'n_is_sb': '0'},
 'leonide fedorovitch massine': {'n_is_sb': '0'},
 'leontief': {'n_is_sb': '0'},
 'leontocebus oedipus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leontocebus rosalia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leontyne price': {'n_is_sb': '0'},
 'leopard cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leopard frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leopard lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leopardess': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leopold antoni stanislaw stokowski': {'n_is_sb': '0'},
 'leopold kronecker': {'n_is_sb': '0'},
 'leopold stokowski': {'n_is_sb': '0'},
 'leo': {'n_is_sb': '0'},
 'lepas fascicularis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lepas': {'n_is_sb': '0'},
 'leper': {'n_is_sb': '0'},
 'lepidochelys kempii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lepidochelys olivacea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lepidocybium flavobrunneum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lepidopterist': {'n_is_sb': '0'},
 'lepidopteron': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lepidopterous insect': {'n_is_sb': '0'},
 'lepisma saccharina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lepisosteus osseus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lepomis gibbosus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lepomis macrochirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lepomis punctatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leporid mammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leporide': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leporid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leppy': {'n_is_sb': '0'},
 'leprosy bacillus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leptinotarsa decemlineata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leptocephalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leptodactylid frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leptodactylid': {'n_is_sb': '0'},
 'leptodactylus pentadactylus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leptoptilus crumeniferus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leptoptilus dubius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leptospira': {'n_is_sb': '2', 'n_is_sth': '2'},
 'leptotyphlops humilis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lepus americanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lepus arcticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lepus californicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lepus europaeus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lepus townsendi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lermontov': {'n_is_sb': '0'},
 'lerner': {'n_is_sb': '0'},
 'leroi jones': {'n_is_sb': '0'},
 'lerot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leroy robert paige': {'n_is_sb': '0'},
 'ler': {'n_is_sb': '0'},
 'lesbian': {'n_is_sb': '0'},
 'leslie howard stainer': {'n_is_sb': '0'},
 'leslie howard': {'n_is_sb': '0'},
 'leslie richard groves': {'n_is_sb': '0'},
 'leslie townes hope': {'n_is_sb': '0'},
 'lesseps': {'n_is_sb': '0'},
 'lesser anteater': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lesser ape': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lesser kudu': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lesser panda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lesser prairie chicken': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lesser rorqual': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lesser scaup duck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lesser scaup': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lesser whitethroat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lesser yellowlegs': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lessing': {'n_is_sb': '0'},
 'lester willis young': {'n_is_sb': '0'},
 'letch': {'n_is_sb': '0'},
 'leto': {'n_is_sb': '0'},
 'letter carrier': {'n_is_sb': '0'},
 'letter writer': {'n_is_sb': '0'},
 'letterer': {'n_is_sb': '0'},
 'letterman': {'n_is_sb': '0'},
 'leuciscus cephalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leuciscus leuciscus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leucocytozoan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'leuwenhoek': {'n_is_sb': '0'},
 'lev davidovich bronstein': {'n_is_sb': '0'},
 'lev davidovich landau': {'n_is_sb': '0'},
 'lev ivanov': {'n_is_sb': '0'},
 'levantine': {'n_is_sb': '0'},
 'leveler': {'n_is_sb': '0'},
 'leveller': {'n_is_sb': '2', 'n_is_sth': '2'},
 'leveret': {'n_is_sb': '3', 'n_is_sth': '3'},
 'levi-strauss': {'n_is_sb': '0'},
 'levite': {'n_is_sb': '0'},
 'levi': {'n_is_sb': '0'},
 'lewis carroll': {'n_is_sb': '0'},
 'lewis henry morgan': {'n_is_sb': '0'},
 'lexicographer': {'n_is_sb': '0'},
 'lexicologist': {'n_is_sb': '0'},
 'lhasa apso': {'n_is_sb': '3', 'n_is_sth': '3'},
 'li po': {'n_is_sb': '0'},
 "liam o'flaherty": {'n_is_sb': '0'},
 'liar': {'n_is_sb': '0'},
 'libber': {'n_is_sb': '0'},
 'libby': {'n_is_sb': '0'},
 'libeler': {'n_is_sb': '0'},
 'liberian': {'n_is_sb': '0'},
 'libertarian': {'n_is_sb': '0'},
 'libyan': {'n_is_sb': '0'},
 'licencee': {'n_is_sb': '0'},
 'licensed practical nurse': {'n_is_sb': '0'},
 'licensee': {'n_is_sb': '0'},
 'licenser': {'n_is_sb': '0'},
 'licentiate': {'n_is_sb': '0'},
 'lichanura trivirgata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lichtenstein': {'n_is_sb': '0'},
 'lie-abed': {'n_is_sb': '0', 'vbd_eq_vbn': ''},
 'liechtensteiner': {'n_is_sb': '0'},
 'lieder singer': {'n_is_sb': '0'},
 'liege subject': {'n_is_sb': '0'},
 'liegeman': {'n_is_sb': '0'},
 'lieutenant colonel': {'n_is_sb': '0'},
 'lieutenant commander': {'n_is_sb': '0'},
 'lieutenant general': {'n_is_sb': '0'},
 'lieutenant governor': {'n_is_sb': '0'},
 'lieutenant jg': {'n_is_sb': '0'},
 'lieutenant junior grade': {'n_is_sb': '0'},
 'life peer': {'n_is_sb': '0'},
 'life principle': {'n_is_sb': '0'},
 'life scientist': {'n_is_sb': '0'},
 'life tenant': {'n_is_sb': '0'},
 'lifesaver': {'n_is_sb': '0'},
 'liftman': {'n_is_sb': '0'},
 'liger': {'n_is_sb': '0'},
 'light colonel': {'n_is_sb': '0'},
 'light flyweight': {'n_is_sb': '0'},
 'light heavyweight': {'n_is_sb': '0'},
 'light middleweight': {'n_is_sb': '0'},
 'light welterweight': {'n_is_sb': '0'},
 "light-o'-love": {'n_is_sb': '0'},
 'light-of-love': {'n_is_sb': '0'},
 'lighterman': {'n_is_sb': '0'},
 'lighthorse harry lee': {'n_is_sb': '0'},
 'lighthouse keeper': {'n_is_sb': '0'},
 'lightning bug': {'n_is_sb': '0'},
 'lightning hurler': {'n_is_sb': '0'},
 'lightning rod': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lightweight': {'n_is_sb': '0'},
 'lilian alicia marks': {'n_is_sb': '0'},
 'lilith': {'n_is_sb': '0'},
 'liliuokalani': {'n_is_sb': '0'},
 'lillian gish': {'n_is_sb': '0'},
 'lillian hellman': {'n_is_sb': '0'},
 'lillian russell': {'n_is_sb': '0'},
 'lillie langtry': {'n_is_sb': '0'},
 'lillie': {'n_is_sb': '0'},
 'limanda ferruginea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'limax': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lime disease spirochete': {'n_is_sb': '3', 'n_is_sth': '3'},
 'limenitis archippus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'limenitis arthemis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'limenitis astyanax': {'n_is_sb': '3', 'n_is_sth': '3'},
 'limenitis camilla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'limestone salamander': {'n_is_sb': '3', 'n_is_sth': '3'},
 'limey': {'n_is_sb': '0'},
 'limicoline bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'limner': {'n_is_sb': '0'},
 'limnocryptes minima': {'n_is_sb': '3', 'n_is_sth': '3'},
 'limnodromus griseus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'limnodromus scolopaceus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'limnologist': {'n_is_sb': '0'},
 'limosa haemastica': {'n_is_sb': '0'},
 'limosa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'limper': {'n_is_sb': '0'},
 'limpet': {'n_is_sb': '2', 'n_is_sth': '2'},
 'limpkin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'limulus polyphemus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'limulus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lincoln steffens': {'n_is_sb': '0'},
 'lindbergh': {'n_is_sb': '0'},
 'lind': {'n_is_sb': '0'},
 'line backer': {'n_is_sb': '0'},
 'line coach': {'n_is_sb': '0'},
 'line judge': {'n_is_sb': '0'},
 'line officer': {'n_is_sb': '0'},
 'line worker': {'n_is_sb': '0'},
 'line-shooter': {'n_is_sb': '0'},
 'linebacker': {'n_is_sb': '0'},
 'lined snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lineman': {'n_is_sb': '0'},
 'linendraper': {'n_is_sb': '0'},
 'ling-pao': {'n_is_sb': '0'},
 'lingcod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lingerer': {'n_is_sb': '0'},
 'linguistic scientist': {'n_is_sb': '0'},
 'linkboy': {'n_is_sb': '0'},
 'linkman': {'n_is_sb': '0'},
 'linksman': {'n_is_sb': '0'},
 'linnaeus': {'n_is_sb': '0'},
 'linnet': {'n_is_sb': '0'},
 'lintwhite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'linus carl pauling': {'n_is_sb': '0'},
 'linus pauling': {'n_is_sb': '0'},
 'lin': {'n_is_sb': '0'},
 'liomys irroratus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lion cub': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lion marmoset': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lion monkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lion-hunter': {'n_is_sb': '0'},
 'lionel barrymore': {'n_is_sb': '0'},
 'lionel hampton': {'n_is_sb': '0'},
 'lionel trilling': {'n_is_sb': '0'},
 'lionet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lionfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'liopelma hamiltoni': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lip reader': {'n_is_sb': '0'},
 'liparis liparis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lipchitz': {'n_is_sb': '0'},
 'lipizzan': {'n_is_sb': '0'},
 'lipmann': {'n_is_sb': '0'},
 'liposcelis divinatorius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lippizaner': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lippizan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lippi': {'n_is_sb': '0'},
 'lippmann': {'n_is_sb': '0'},
 'lipscomb': {'n_is_sb': '0'},
 'liquidator': {'n_is_sb': '0'},
 'lir': {'n_is_sb': '0'},
 'lise meitner': {'n_is_sb': '0'},
 'lisper': {'n_is_sb': '0'},
 'listeria monocytogenes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lister': {'n_is_sb': '2', 'n_is_sth': '2'},
 'liston': {'n_is_sb': '0'},
 'liszt': {'n_is_sb': '0'},
 'literary agent': {'n_is_sb': '0'},
 'literary critic': {'n_is_sb': '0'},
 'literary hack': {'n_is_sb': '0'},
 'literary pirate': {'n_is_sb': '0'},
 'literate person': {'n_is_sb': '0'},
 'literate': {'n_is_sb': '0'},
 'lithographer': {'n_is_sb': '0'},
 'lithomancer': {'n_is_sb': '0'},
 'litigator': {'n_is_sb': '0'},
 'litocranius walleri': {'n_is_sb': '3', 'n_is_sth': '3'},
 'litter lout': {'n_is_sb': '0'},
 'litter-bearer': {'n_is_sb': '0'},
 'litterateur': {'n_is_sb': '0'},
 'litterbug': {'n_is_sb': '0'},
 'litterer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'little auk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'little black ant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'little blue heron': {'n_is_sb': '3', 'n_is_sth': '3'},
 'little brother': {'n_is_sb': '2', 'n_is_sth': '2'},
 'little brown bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'little brown myotis': {'n_is_sb': '2', 'n_is_sth': '2'},
 'little chief hare': {'n_is_sb': '3', 'n_is_sth': '3'},
 'little egret': {'n_is_sb': '3', 'n_is_sth': '3'},
 'little girl': {'n_is_sb': '0'},
 'little grebe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'little john': {'n_is_sb': '0'},
 'little leaguer': {'n_is_sb': '0'},
 'little lord fauntleroy': {'n_is_sb': '0'},
 'little mo connolly': {'n_is_sb': '0'},
 'little owl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'little red ricing hood': {'n_is_sb': '0'},
 'little sister': {'n_is_sb': '0'},
 'little skate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'little sparrow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'little spotted skunk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'little terror': {'n_is_sb': '0'},
 'littleneck clam': {'n_is_sb': '3', 'n_is_sth': '3'},
 'littleneck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'littorina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'littorinidae': {'n_is_sb': '2', 'n_is_sth': '2'},
 'littre': {'n_is_sb': '0'},
 'liturgist': {'n_is_sb': '0'},
 'live wire': {'n_is_sb': '2', 'n_is_sth': '2'},
 'live-bearer': {'n_is_sb': '0'},
 'liveborn infant': {'n_is_sb': '0'},
 'liver chestnut': {'n_is_sb': '3', 'n_is_sth': '3'},
 'liver fluke': {'n_is_sb': '3', 'n_is_sth': '3'},
 'liver-spotted dalmatian': {'n_is_sb': '0'},
 'livermore': {'n_is_sb': '2', 'n_is_sth': '2'},
 'liverpudlian': {'n_is_sb': '0'},
 'livery driver': {'n_is_sb': '0'},
 'liveryman': {'n_is_sb': '0'},
 'livingstone': {'n_is_sb': '2', 'n_is_sth': '2'},
 'livingston': {'n_is_sb': '2', 'n_is_sth': '2'},
 'livonian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'livy': {'n_is_sb': '0'},
 'lizardfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'liza': {'n_is_sb': '0'},
 'llama': {'n_is_sb': '2', 'n_is_sth': '2'},
 'llew llaw gyffes': {'n_is_sb': '0'},
 'lloyd webber': {'n_is_sb': '0'},
 'lloyd': {'n_is_sb': '0'},
 'llud': {'n_is_sb': '0'},
 'llyr': {'n_is_sb': '0'},
 'loader': {'n_is_sb': '2', 'n_is_sth': '2'},
 'loan shark': {'n_is_sb': '0'},
 'loather': {'n_is_sb': '0'},
 'lobachevsky': {'n_is_sb': '0'},
 'lobe-finned fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lobipes lobatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lobipes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lobotes pacificus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lobotes surinamensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lobsterback': {'n_is_sb': '0'},
 'lobsterman': {'n_is_sb': '0'},
 'lobworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'locater': {'n_is_sb': '2', 'n_is_sth': '2'},
 'loch ness monster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'locke': {'n_is_sb': '0'},
 'lockkeeper': {'n_is_sb': '0'},
 'lockman': {'n_is_sb': '0'},
 'lockmaster': {'n_is_sb': '0'},
 'locomotive engineer': {'n_is_sb': '0'},
 'locum tenens': {'n_is_sb': '0'},
 'locum': {'n_is_sb': '2', 'n_is_sth': '2'},
 'locusta migratoria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'locusta': {'n_is_sb': '0'},
 'loeb': {'n_is_sb': '0'},
 'loewe': {'n_is_sb': '0'},
 'loewi': {'n_is_sb': '0'},
 'lofortyx californicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lofortyx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'loggerhead shrike': {'n_is_sb': '3', 'n_is_sth': '3'},
 'loggerhead turtle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'logical positivist': {'n_is_sb': '0'},
 'logician': {'n_is_sb': '0'},
 'logistician': {'n_is_sb': '0'},
 'logomachist': {'n_is_sb': '0'},
 'logomach': {'n_is_sb': '0'},
 'loir': {'n_is_sb': '0'},
 'loiterer': {'n_is_sb': '0'},
 'loki': {'n_is_sb': '0'},
 'lola montez': {'n_is_sb': '0'},
 'loligo': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lolita': {'n_is_sb': '0'},
 'lollipop lady': {'n_is_sb': '0'},
 'lollipop woman': {'n_is_sb': '0'},
 'londoner': {'n_is_sb': '0'},
 'lone hand': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lone wolf': {'n_is_sb': '0'},
 'loner': {'n_is_sb': '0'},
 'long shot': {'n_is_sb': '2', 'n_is_sth': '2'},
 'long-billed marsh wren': {'n_is_sb': '3', 'n_is_sth': '3'},
 'long-clawed prawn': {'n_is_sb': '3', 'n_is_sth': '3'},
 'long-distance runner': {'n_is_sb': '0'},
 'long-eared bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'long-eared owl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'long-fin tunny': {'n_is_sb': '3', 'n_is_sth': '3'},
 'long-horned beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'long-horned grasshopper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'long-neck clam': {'n_is_sb': '3', 'n_is_sth': '3'},
 'long-tailed porcupine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'long-tailed weasel': {'n_is_sb': '2', 'n_is_sth': '2'},
 'longbowman': {'n_is_sb': '0'},
 'longer': {'n_is_sb': '0'},
 'longfellow': {'n_is_sb': '0'},
 'longfin mako': {'n_is_sb': '3', 'n_is_sth': '3'},
 'longhorn': {'n_is_sb': '2', 'n_is_sth': '2'},
 'longicorn beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'longicorn': {'n_is_sb': '3', 'n_is_sth': '3'},
 'longlegs': {'n_is_sb': '0'},
 'longshoreman': {'n_is_sb': '0'},
 'longtail weasel': {'n_is_sb': '2', 'n_is_sth': '2'},
 'longwool': {'n_is_sb': '3', 'n_is_sth': '3'},
 'look-alike': {'n_is_sb': '0'},
 'lookdown fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lookdown': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lookout man': {'n_is_sb': '0'},
 'looney': {'n_is_sb': '0'},
 'loony': {'n_is_sb': '0', 'jj_to_jjr': 'loonier', 'jj_to_jjs': 'looniest'},
 'looper': {'n_is_sb': '2', 'n_is_sth': '2'},
 'loose cannon': {'n_is_sb': '0'},
 'loose woman': {'n_is_sb': '0'},
 'loos': {'n_is_sb': '2', 'n_is_sth': '2'},
 'looter': {'n_is_sb': '0'},
 'lope de vega': {'n_is_sb': '0'},
 'lope felix de vega carpio': {'n_is_sb': '0'},
 'lophius americanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lophodytes cucullatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lopholatilus chamaeleonticeps': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lorado taft': {'n_is_sb': '0'},
 'lorca': {'n_is_sb': '0'},
 'lord britten of aldeburgh': {'n_is_sb': '0'},
 'lord chancellor': {'n_is_sb': '0'},
 'lord george gordon byron': {'n_is_sb': '0'},
 'lord high chancellor': {'n_is_sb': '0'},
 'lord macaulay': {'n_is_sb': '0'},
 'lord nelson': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lord of misrule': {'n_is_sb': '0'},
 'lord privy seal': {'n_is_sb': '0'},
 'lord rayleigh': {'n_is_sb': '0'},
 'lorelei': {'n_is_sb': '0'},
 'lorentz': {'n_is_sb': '0'},
 'lorenz hart': {'n_is_sb': '0'},
 'lorenz milton hart': {'n_is_sb': '0'},
 'lorenz okenfuss': {'n_is_sb': '0'},
 'lorenz oken': {'n_is_sb': '0'},
 'lorenzo de medici': {'n_is_sb': '0'},
 'lorenzo the magnificent': {'n_is_sb': '0'},
 'lorenz': {'n_is_sb': '0'},
 'loren': {'n_is_sb': '0'},
 'loretta young': {'n_is_sb': '0'},
 'lorica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lorikeet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'loris gracilis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lorre': {'n_is_sb': '0'},
 'lory': {'n_is_sb': '0'},
 "lot's wife": {'n_is_sb': '2', 'n_is_sth': '2'},
 'lota lota': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lotario di segni': {'n_is_sb': '0'},
 'lota': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lothario': {'n_is_sb': '0'},
 'lottery winner': {'n_is_sb': '0'},
 'lotte': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lotus-eater': {'n_is_sb': '0'},
 'lou gehrig': {'n_is_sb': '0'},
 'loudmouth': {'n_is_sb': '0'},
 'louis agassiz': {'n_is_sb': '0'},
 'louis antoine de bougainville': {'n_is_sb': '0'},
 'louis aragon': {'n_is_sb': '0'},
 'louis armstrong': {'n_is_sb': '0'},
 'louis auchincloss': {'n_is_sb': '0'},
 'louis b. mayer': {'n_is_sb': '0'},
 'louis bleriot': {'n_is_sb': '0'},
 'louis braille': {'n_is_sb': '0'},
 'louis burt mayer': {'n_is_sb': '0'},
 'louis charles alfred de musset': {'n_is_sb': '0'},
 'louis comfort tiffany': {'n_is_sb': '0'},
 "louis d'outremer": {'n_is_sb': '0'},
 'louis eugene felix neel': {'n_is_sb': '0'},
 'louis henri sullivan': {'n_is_sb': '0'},
 'louis henry sullivan': {'n_is_sb': '0'},
 'louis iii': {'n_is_sb': '0'},
 'louis ii': {'n_is_sb': '0'},
 'louis isadore kahn': {'n_is_sb': '0'},
 'louis iv': {'n_is_sb': '0'},
 'louis ix': {'n_is_sb': '0'},
 'louis i': {'n_is_sb': '0'},
 'louis jacques mande daguerre': {'n_is_sb': '0'},
 'louis joliet': {'n_is_sb': '0'},
 'louis jolliet': {'n_is_sb': '0'},
 'louis le begue': {'n_is_sb': '0'},
 'louis le faineant': {'n_is_sb': '0'},
 'louis le hutin': {'n_is_sb': '0'},
 'louis leakey': {'n_is_sb': '0'},
 'louis pasteur': {'n_is_sb': '0'},
 'louis seymour bazett leakey': {'n_is_sb': '0'},
 'louis stanton auchincloss': {'n_is_sb': '0'},
 'louis sullivan': {'n_is_sb': '0'},
 'louis the bruiser': {'n_is_sb': '0'},
 'louis the far': {'n_is_sb': '0'},
 'louis the german': {'n_is_sb': '0'},
 'louis the great': {'n_is_sb': '0'},
 'louis the pious': {'n_is_sb': '0'},
 'louis the quarreller': {'n_is_sb': '0'},
 'louis the stammerer': {'n_is_sb': '0'},
 'louis the wideawake': {'n_is_sb': '0'},
 'louis untermeyer': {'n_is_sb': '0'},
 'louis victor de broglie': {'n_is_sb': '0'},
 'louis viii': {'n_is_sb': '0'},
 'louis vii': {'n_is_sb': '0'},
 'louis vi': {'n_is_sb': '0'},
 'louis v': {'n_is_sb': '0'},
 'louis xiii': {'n_is_sb': '0'},
 'louis xii': {'n_is_sb': '0'},
 'louis xiv': {'n_is_sb': '0'},
 'louis xi': {'n_is_sb': '0'},
 'louis xvi': {'n_is_sb': '0'},
 'louis xv': {'n_is_sb': '0'},
 'louis x': {'n_is_sb': '0'},
 'louis-hector berlioz': {'n_is_sb': '0'},
 'louisa may alcott': {'n_is_sb': '0'},
 'louise nevelson': {'n_is_sb': '0'},
 'louisianan': {'n_is_sb': '0'},
 'louisianian': {'n_is_sb': '0'},
 'lounge lizard': {'n_is_sb': '0'},
 'lounger': {'n_is_sb': '0'},
 'louse fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'louvar': {'n_is_sb': '3', 'n_is_sth': '3'},
 'love child': {'n_is_sb': '0'},
 'lovebird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'loved one': {'n_is_sb': '0'},
 'lovell': {'n_is_sb': '0'},
 'low-birth-weight baby': {'n_is_sb': '0'},
 'low-birth-weight infant': {'n_is_sb': '0'},
 'lowan': {'n_is_sb': '0'},
 'lowbrow': {'n_is_sb': '0'},
 'lowell jackson thomas': {'n_is_sb': '0'},
 'lowell thomas': {'n_is_sb': '0'},
 'lowell': {'n_is_sb': '0'},
 'lowerclassman': {'n_is_sb': '0'},
 'lowland burrowing treefrog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lowlander': {'n_is_sb': '0'},
 'lowlife': {'n_is_sb': '0'},
 'lowry': {'n_is_sb': '2', 'n_is_sth': '2'},
 'loxia curvirostra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'loxodonta africana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'loxodonta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'loxostege similalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'loyola': {'n_is_sb': '0'},
 'lozier': {'n_is_sb': '0'},
 'lpn': {'n_is_sb': '0'},
 'lubavitcher': {'n_is_sb': '0'},
 'luba': {'n_is_sb': '0'},
 'lubber': {'n_is_sb': '0'},
 'lubitsch': {'n_is_sb': '0'},
 'lucas': {'n_is_sb': '0'},
 'luchino visconti': {'n_is_sb': '0'},
 'luciano pavarotti': {'n_is_sb': '0'},
 'lucilia': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lucille ball': {'n_is_sb': '0'},
 'lucius annaeus seneca': {'n_is_sb': '0'},
 'lucius clay': {'n_is_sb': '0'},
 'lucius cornelius sulla felix': {'n_is_sb': '0'},
 'lucius domitius ahenobarbus': {'n_is_sb': '0'},
 'lucius dubignon clay': {'n_is_sb': '0'},
 'lucius licinius luculus': {'n_is_sb': '0'},
 'lucius quinctius cincinnatus': {'n_is_sb': '0'},
 'lucius tarquinius superbus': {'n_is_sb': '0'},
 'lucky lindy': {'n_is_sb': '0'},
 'lucretia coffin mott': {'n_is_sb': '0'},
 'lucretius': {'n_is_sb': '0'},
 'lucrezia borgia': {'n_is_sb': '0'},
 'luculus': {'n_is_sb': '0'},
 'lucy craft laney': {'n_is_sb': '0'},
 'lucy maud montgomery': {'n_is_sb': '0'},
 'lucy stone': {'n_is_sb': '0'},
 'lucy': {'n_is_sb': '0'},
 'luddite': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ludwig boltzmann': {'n_is_sb': '0'},
 'ludwig josef johan wittgenstein': {'n_is_sb': '0'},
 'ludwig mies van der rohe': {'n_is_sb': '0'},
 'ludwig van beethoven': {'n_is_sb': '0'},
 'ludwig wittgenstein': {'n_is_sb': '0'},
 'lufengpithecus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'luger': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lugh': {'n_is_sb': '0'},
 'lugosi': {'n_is_sb': '0'},
 'lugworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'luigi barnaba gregorio chiaramonti': {'n_is_sb': '0'},
 'luigi cherubini': {'n_is_sb': '0'},
 'luigi galvani': {'n_is_sb': '0'},
 'luigi pirandello': {'n_is_sb': '0'},
 'luis bunuel': {'n_is_sb': '0'},
 'luis de gongora y argote': {'n_is_sb': '0'},
 'luke': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lulli': {'n_is_sb': '0'},
 'lully': {'n_is_sb': '0'},
 'lulu': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lumberjack': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lumberman': {'n_is_sb': '0'},
 'lumpenus lumpretaeformis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lumper': {'n_is_sb': '0'},
 'lumpsucker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'luna moth': {'n_is_sb': '2', 'n_is_sth': '2'},
 'luncher': {'n_is_sb': '0'},
 'lunda cirrhata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lunda': {'n_is_sb': '0'},
 'lunger': {'n_is_sb': '0'},
 'lungless salamander': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lurcher': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lurker': {'n_is_sb': '0'},
 'luscinia luscinia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'luscinia megarhynchos': {'n_is_sb': '3', 'n_is_sth': '3'},
 'luscinia': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lusus naturae': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lutanist': {'n_is_sb': '0'},
 'lutenist': {'n_is_sb': '0'},
 'luther burbank': {'n_is_sb': '0'},
 'lutheran': {'n_is_sb': '0'},
 'luther': {'n_is_sb': '0'},
 'luthier': {'n_is_sb': '0'},
 'lutist': {'n_is_sb': '0'},
 'lutjanus analis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lutjanus apodus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lutjanus blackfordi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lutjanus griseus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lutjanus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lutra canadensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lutra lutra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lutra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lutyens': {'n_is_sb': '0'},
 'luvarus imperialis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'luxembourger': {'n_is_sb': '0'},
 'luxemburger': {'n_is_sb': '0'},
 'lycaena hypophlaeas': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lycaenid butterfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lycaeon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lycanthrope': {'n_is_sb': '0'},
 'lycaon pictus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lycosa tarentula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lydia kamekeha paki liliuokalani': {'n_is_sb': '0'},
 'lygaeid bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lygaeid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lygus bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lygus lineolaris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lygus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lyly': {'n_is_sb': '0'},
 'lyman frank brown': {'n_is_sb': '0'},
 'lymantria dispar': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lymantria': {'n_is_sb': '2', 'n_is_sth': '2'},
 'lymantriid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lympphocytic choriomeningitis virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lyndon baines johnson': {'n_is_sb': '0'},
 'lyndon johnson': {'n_is_sb': '0'},
 'lynn fontanne': {'n_is_sb': '0'},
 'lynx canadensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lynx caracal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lynx lynx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lynx pardina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lynx rufus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lyre snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lyrebird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lyricist': {'n_is_sb': '0'},
 'lyrurus mlokosiewiczi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lyrurus tetrix': {'n_is_sb': '3', 'n_is_sth': '3'},
 'lysander': {'n_is_sb': '0'},
 'lysenko': {'n_is_sb': '0'},
 'lysimachus': {'n_is_sb': '0'},
 'lysippus': {'n_is_sb': '0'},
 'lytton strachey': {'n_is_sb': '0'},
 'lytton': {'n_is_sb': '0'},
 'm. j. schleiden': {'n_is_sb': '0'},
 "ma'am": {'n_is_sb': '0'},
 'macaca irus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'macaca mulatta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'macaca radiata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'macaca sylvana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'macaca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'macarthur': {'n_is_sb': '0'},
 'macaulay': {'n_is_sb': '0'},
 'macaw': {'n_is_sb': '0'},
 'macbeth': {'n_is_sb': '0'},
 'macdowell': {'n_is_sb': '0'},
 'macebearer': {'n_is_sb': '0'},
 'macer': {'n_is_sb': '0'},
 'macgregor': {'n_is_sb': '0'},
 'machiavelli': {'n_is_sb': '0'},
 'machinator': {'n_is_sb': '0'},
 'machine gunner': {'n_is_sb': '0'},
 'machine politician': {'n_is_sb': '0'},
 'macho-man': {'n_is_sb': '0'},
 'machupo virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mach': {'n_is_sb': '0'},
 'mack sennett': {'n_is_sb': '0'},
 'mackenzie': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mackerel scad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mackerel shad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mackerel shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'macleish': {'n_is_sb': '0'},
 'macleod': {'n_is_sb': '0'},
 'macrocephalon maleo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'macrocheira kaempferi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'macroclemys temmincki': {'n_is_sb': '3', 'n_is_sth': '3'},
 'macrodactylus subspinosus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'macroeconomic expert': {'n_is_sb': '0'},
 'macroeconomist': {'n_is_sb': '0'},
 'macronectes giganteus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'macropus agiles': {'n_is_sb': '3', 'n_is_sth': '3'},
 'macropus giganteus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'macrotis lagotis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'macrotus californicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'macrotus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'macrozoarces americanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'macrozoarces': {'n_is_sb': '3', 'n_is_sth': '3'},
 'macushla': {'n_is_sb': '0'},
 'mad anthony wayne': {'n_is_sb': '0'},
 'madagascan': {'n_is_sb': '0'},
 'madagascar cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'madame curie': {'n_is_sb': '0'},
 'madame de maintenon': {'n_is_sb': '0'},
 'madame de stael': {'n_is_sb': '0'},
 'madame tussaud': {'n_is_sb': '0'},
 'madcap': {'n_is_sb': '0'},
 'madonna louise ciccone': {'n_is_sb': '0'},
 'madrepore': {'n_is_sb': '3', 'n_is_sth': '3'},
 'madrigalist': {'n_is_sb': '0'},
 'madriporian coral': {'n_is_sb': '3', 'n_is_sth': '3'},
 'madwoman': {'n_is_sb': '0'},
 'mae west': {'n_is_sb': '2', 'n_is_sth': '2'},
 'maenad': {'n_is_sb': '0'},
 'maestro': {'n_is_sb': '0'},
 'maeterlinck': {'n_is_sb': '0'},
 'mafioso': {'n_is_sb': '0'},
 'magdalen': {'n_is_sb': '2', 'n_is_sth': '2'},
 'magellan': {'n_is_sb': '0'},
 'magicicada septendecim': {'n_is_sb': '3', 'n_is_sth': '3'},
 'magicicada': {'n_is_sb': '3', 'n_is_sth': '3'},
 'maginot': {'n_is_sb': '2', 'n_is_sth': '2'},
 'magna mater': {'n_is_sb': '0'},
 'magnificio': {'n_is_sb': '0'},
 'magritte': {'n_is_sb': '0'},
 'magus': {'n_is_sb': '0'},
 'magyar': {'n_is_sb': '0'},
 'mahalia jackson': {'n_is_sb': '0'},
 'mahan': {'n_is_sb': '0'},
 'maharajah': {'n_is_sb': '0'},
 'maharaja': {'n_is_sb': '0'},
 'maharanee': {'n_is_sb': '0'},
 'mahatma gandhi': {'n_is_sb': '0'},
 'mahayanist': {'n_is_sb': '0'},
 'maha': {'n_is_sb': '0'},
 'mahican': {'n_is_sb': '0'},
 'mahimahi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mahler': {'n_is_sb': '0'},
 'mahomet': {'n_is_sb': '0'},
 'mahound': {'n_is_sb': '0'},
 'mahout': {'n_is_sb': '0'},
 'mahratta': {'n_is_sb': '0'},
 'maia': {'n_is_sb': '0'},
 'maid of honor': {'n_is_sb': '0'},
 'maiden aunt': {'n_is_sb': '0'},
 'maidu': {'n_is_sb': '0'},
 'maiger': {'n_is_sb': '2', 'n_is_sth': '2'},
 'maigre': {'n_is_sb': '0'},
 'mail carrier': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mail clerk': {'n_is_sb': '0'},
 'maillol': {'n_is_sb': '0'},
 'maimer': {'n_is_sb': '0'},
 'maimonides': {'n_is_sb': '0'},
 'maine lobster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mainer': {'n_is_sb': '0'},
 'maintainer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'maintenance man': {'n_is_sb': '0'},
 'maintenon': {'n_is_sb': '0'},
 'maitland': {'n_is_sb': '0'},
 "maitre d'hotel": {'n_is_sb': '2', 'n_is_sth': '2'},
 "maitre d'": {'n_is_sb': '0'},
 'maja squinado': {'n_is_sb': '3', 'n_is_sth': '3'},
 'maja': {'n_is_sb': '0'},
 'major leaguer': {'n_is_sb': '0'},
 'major-general': {'n_is_sb': '0'},
 'majority leader': {'n_is_sb': '0'},
 'makaira albida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'makaira marlina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'makaira mazara': {'n_is_sb': '3', 'n_is_sth': '3'},
 'makaira mitsukurii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'makaira nigricans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'makataimeshekiakiak': {'n_is_sb': '0'},
 'make-peace': {'n_is_sb': '0'},
 'mako shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mako': {'n_is_sb': '0'},
 'maksim gorky': {'n_is_sb': '0'},
 'malachias': {'n_is_sb': '0'},
 'malachi': {'n_is_sb': '0'},
 'malaclemys centrata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'malacopterygian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'malacosoma americana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'malacosoma disstria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'malacosoma': {'n_is_sb': '0'},
 'malacostracan crustacean': {'n_is_sb': '3', 'n_is_sth': '3'},
 'malahini': {'n_is_sb': '0'},
 'malamud': {'n_is_sb': '0'},
 'malamute': {'n_is_sb': '3', 'n_is_sth': '3'},
 'malaria mosquito': {'n_is_sb': '3', 'n_is_sth': '3'},
 'malaria parasite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'malarial mosquito': {'n_is_sb': '3', 'n_is_sth': '3'},
 'malawian': {'n_is_sb': '0'},
 'malayan tapir': {'n_is_sb': '3', 'n_is_sth': '3'},
 'malayan': {'n_is_sb': '0'},
 'malaysian': {'n_is_sb': '0', 'cap_word': 'Malaysian'},
 'malcolm little': {'n_is_sb': '0'},
 'malcolm lowry': {'n_is_sb': '0'},
 'malcolm x': {'n_is_sb': '0'},
 'maldivan': {'n_is_sb': '0'},
 'maldivian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'male aristocrat': {'n_is_sb': '0'},
 'male chauvinist': {'n_is_sb': '0'},
 'male child': {'n_is_sb': '0'},
 'male horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'male monarch': {'n_is_sb': '0'},
 'male offspring': {'n_is_sb': '0'},
 'male parent': {'n_is_sb': '0'},
 'male person': {'n_is_sb': '0'},
 'male sibling': {'n_is_sb': '0'},
 'malebranche': {'n_is_sb': '0'},
 'malecite': {'n_is_sb': '2', 'n_is_sth': '2'},
 'malemute': {'n_is_sb': '3', 'n_is_sth': '3'},
 'maleo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'malevich': {'n_is_sb': '0'},
 'malfeasant': {'n_is_sb': '0'},
 'malian': {'n_is_sb': '0'},
 'maligner': {'n_is_sb': '0'},
 'malik': {'n_is_sb': '0'},
 'malingerer': {'n_is_sb': '0'},
 'malinois': {'n_is_sb': '3', 'n_is_sth': '3'},
 'malinowski': {'n_is_sb': '0'},
 'mallarme': {'n_is_sb': '0'},
 'mallee fowl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mallee hen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mallon': {'n_is_sb': '0'},
 'mallophaga': {'n_is_sb': '2', 'n_is_sth': '2'},
 'malone': {'n_is_sb': '0'},
 'malopterurus electricus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'malopterurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'malory': {'n_is_sb': '0'},
 'malpighi': {'n_is_sb': '0'},
 'malraux': {'n_is_sb': '0'},
 'maltese cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'maltese dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'malthusian': {'n_is_sb': '0', 'cap_word': 'Malthusian'},
 'maltman': {'n_is_sb': '3', 'n_is_sth': '3'},
 'malto': {'n_is_sb': '3', 'n_is_sth': '3'},
 'maltreater': {'n_is_sb': '0'},
 'maltster': {'n_is_sb': '0'},
 'malvina hoffman': {'n_is_sb': '0'},
 "mama's boy": {'n_is_sb': '0'},
 'mamba': {'n_is_sb': '0'},
 'mamet': {'n_is_sb': '0'},
 "mamma's boy": {'n_is_sb': '0'},
 'mammal semnopithecus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mammalia': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mammut americanum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mammuthus columbi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mammuthus primigenius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mammuthus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mammutidae': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mammut': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mamo': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mam': {'n_is_sb': '0'},
 'man friday': {'n_is_sb': '0'},
 'man in the street': {'n_is_sb': '0'},
 'man jack': {'n_is_sb': '0'},
 'man of action': {'n_is_sb': '0'},
 'man of affairs': {'n_is_sb': '0'},
 'man of deeds': {'n_is_sb': '0'},
 'man of letters': {'n_is_sb': '0'},
 'man of means': {'n_is_sb': '0'},
 'man of science': {'n_is_sb': '0'},
 'man of the cloth': {'n_is_sb': '0'},
 'man of the world': {'n_is_sb': '0'},
 'man-about-town': {'n_is_sb': '0'},
 'man-at-arms': {'n_is_sb': '0'},
 'man-child': {'n_is_sb': '0'},
 'man-eater': {'n_is_sb': '0'},
 'man-eating shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'man-of-war bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'management consultant': {'n_is_sb': '0'},
 'manageress': {'n_is_sb': '0'},
 'managing director': {'n_is_sb': '0'},
 'managing editor': {'n_is_sb': '0'},
 'manakin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'manannan': {'n_is_sb': '0'},
 'manawydan': {'n_is_sb': '0'},
 'manawyddan': {'n_is_sb': '0'},
 'manchester terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mancunian': {'n_is_sb': '0', 'cap_word': 'Mancunian'},
 'mandaean': {'n_is_sb': '0'},
 'mandarin duck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mandatary': {'n_is_sb': '0'},
 'mandator': {'n_is_sb': '0'},
 'mandean': {'n_is_sb': '0'},
 'mandela': {'n_is_sb': '0'},
 'mandelbrot': {'n_is_sb': '0'},
 'mandelshtam': {'n_is_sb': '0'},
 'mandelstam': {'n_is_sb': '0'},
 'mandrillus leucophaeus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mandrillus sphinx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'manduca quinquemaculata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'manduca sexta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'manduca': {'n_is_sb': '0'},
 'maned sheep': {'n_is_sb': '3', 'n_is_sth': '3'},
 'maned wolf': {'n_is_sb': '3', 'n_is_sth': '3'},
 'manet': {'n_is_sb': '0'},
 'maneuverer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'manfred eigen': {'n_is_sb': '0'},
 'mangabey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mangrove snapper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'manic-depressive': {'n_is_sb': '0'},
 'manichaean': {'n_is_sb': '0'},
 'manichean': {'n_is_sb': '0'},
 'manichee': {'n_is_sb': '0'},
 'manicurist': {'n_is_sb': '0'},
 'manikin': {'n_is_sb': '2', 'n_is_sth': '2'},
 'maniraptora': {'n_is_sb': '3', 'n_is_sth': '3'},
 'maniraptor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'manis': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mannequin': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mannikin': {'n_is_sb': '0'},
 'mann': {'n_is_sb': '0'},
 'manoeuvrer': {'n_is_sb': '0'},
 'mansart': {'n_is_sb': '0'},
 'mansfield': {'n_is_sb': '0'},
 'mansi': {'n_is_sb': '0'},
 'manslayer': {'n_is_sb': '0'},
 'manson': {'n_is_sb': '0'},
 'manta birostris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'manta ray': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mantegna': {'n_is_sb': '0'},
 'mantell': {'n_is_sb': '0'},
 'mantichora': {'n_is_sb': '0'},
 'manticora': {'n_is_sb': '0'},
 'manticore': {'n_is_sb': '0'},
 'mantid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mantiger': {'n_is_sb': '0'},
 'mantis crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mantis prawn': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mantis religioso': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mantis shrimp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mantispid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mantled ground squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mantophasmatodea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mantrap': {'n_is_sb': '2', 'n_is_sth': '2'},
 'manual laborer': {'n_is_sb': '0'},
 'manuel de falla': {'n_is_sb': '0'},
 'manul': {'n_is_sb': '2', 'n_is_sth': '2'},
 'manumitter': {'n_is_sb': '0'},
 'manx cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'manx shearwater': {'n_is_sb': '3', 'n_is_sth': '3'},
 'manzoni': {'n_is_sb': '0'},
 'mao tsetung': {'n_is_sb': '0'},
 'mao zedong': {'n_is_sb': '0'},
 'maoist': {'n_is_sb': '0'},
 'maori hen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mao': {'n_is_sb': '2', 'n_is_sth': '2'},
 'map maker': {'n_is_sb': '0'},
 'map-reader': {'n_is_sb': '0'},
 'mapinguari': {'n_is_sb': '0'},
 'mapper': {'n_is_sb': '2', 'n_is_sth': '2'},
 'maquisard': {'n_is_sb': '0'},
 'maquis': {'n_is_sb': '0'},
 'marabou stork': {'n_is_sb': '3', 'n_is_sth': '3'},
 'marabout': {'n_is_sb': '0'},
 'marabou': {'n_is_sb': '3', 'n_is_sth': '3'},
 'maraco': {'n_is_sb': '2', 'n_is_sth': '2'},
 'maratha': {'n_is_sb': '0'},
 'marathon runner': {'n_is_sb': '0'},
 'marathoner': {'n_is_sb': '0'},
 'marat': {'n_is_sb': '0'},
 'marauder': {'n_is_sb': '0'},
 'mara': {'n_is_sb': '0'},
 'marburg virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'marc blitzstein': {'n_is_sb': '0'},
 'marc chagall': {'n_is_sb': '0'},
 'marceau': {'n_is_sb': '0'},
 'marcel duchamp': {'n_is_sb': '0'},
 'marcel lajos breuer': {'n_is_sb': '0'},
 'marcel marceau': {'n_is_sb': '0'},
 'marcel proust': {'n_is_sb': '0'},
 'marcello malpighi': {'n_is_sb': '0'},
 'marcher': {'n_is_sb': '0'},
 'marchioness': {'n_is_sb': '0'},
 'marciano': {'n_is_sb': '0'},
 'marco polo sheep': {'n_is_sb': '3', 'n_is_sth': '3'},
 "marco polo's sheep": {'n_is_sb': '3', 'n_is_sth': '3'},
 'marco polo': {'n_is_sb': '0'},
 'marcus annius verus': {'n_is_sb': '0'},
 'marcus antonius': {'n_is_sb': '0'},
 'marcus aurelius antoninus': {'n_is_sb': '0'},
 'marcus aurelius': {'n_is_sb': '0'},
 'marcus cocceius nerva': {'n_is_sb': '0'},
 'marcus junius brutus': {'n_is_sb': '0'},
 'marcus terentius varro': {'n_is_sb': '0'},
 'marcus tullius cicero': {'n_is_sb': '0'},
 'marcus ulpius traianus': {'n_is_sb': '0'},
 'marcus vipsanius agrippa': {'n_is_sb': '0'},
 'marcus whitman': {'n_is_sb': '0'},
 'marcuse': {'n_is_sb': '0'},
 'marduk': {'n_is_sb': '0'},
 'margaret court': {'n_is_sb': '0'},
 'margaret higgins sanger': {'n_is_sb': '0'},
 'margaret hilda thatcher': {'n_is_sb': '0'},
 'margaret mead': {'n_is_sb': '0'},
 'margaret mitchell': {'n_is_sb': '0'},
 'margaret munnerlyn mitchell': {'n_is_sb': '0'},
 'margaret sanger': {'n_is_sb': '0'},
 'margaret thatcher': {'n_is_sb': '0'},
 'margarete gertrud zelle': {'n_is_sb': '0'},
 'margate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'margay cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'margay': {'n_is_sb': '3', 'n_is_sth': '3'},
 'marguerite radclyffe hall': {'n_is_sb': '0'},
 'maria callas': {'n_is_sb': '0'},
 'maria luigi carlo zenobio cherubini': {'n_is_sb': '0'},
 'maria magdalene von losch': {'n_is_sb': '0'},
 'maria meneghini callas': {'n_is_sb': '0'},
 'maria mitchell': {'n_is_sb': '0'},
 'maria montesorri': {'n_is_sb': '0'},
 'maria tallchief': {'n_is_sb': '0'},
 'marian anderson': {'n_is_sb': '0'},
 'marianne craig moore': {'n_is_sb': '0'},
 'marianne moore': {'n_is_sb': '0'},
 'maricopa': {'n_is_sb': '2', 'n_is_sth': '2'},
 "marie anne charlotte corday d'armont": {'n_is_sb': '0'},
 'marie antoinette': {'n_is_sb': '0'},
 'marie charlotte carmichael stopes': {'n_is_sb': '0'},
 'marie curie': {'n_is_sb': '0'},
 'marie dolores eliza rosanna gilbert': {'n_is_sb': '0'},
 'marie goeppert mayer': {'n_is_sb': '0'},
 'marie grosholtz': {'n_is_sb': '0'},
 'marie henri beyle': {'n_is_sb': '0'},
 'marie jeanne becu': {'n_is_sb': '0'},
 'marie joseph paul yves roch gilbert du motier': {'n_is_sb': '0'},
 'marie louise elisabeth vigee-lebrun': {'n_is_sb': '0'},
 'marie stopes': {'n_is_sb': '0'},
 'marie tussaud': {'n_is_sb': '0'},
 'marilyn monroe': {'n_is_sb': '0'},
 'marine animal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'marine creature': {'n_is_sb': '3', 'n_is_sth': '3'},
 'marine engineer': {'n_is_sb': '0'},
 'marine iguana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'marine mussel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'marine turtle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'marini': {'n_is_sb': '0'},
 'marino': {'n_is_sb': '0'},
 'mario vargas llosa': {'n_is_sb': '0'},
 'mari': {'n_is_sb': '0'},
 'mark anthony': {'n_is_sb': '0'},
 'mark antony': {'n_is_sb': '0'},
 'mark clark': {'n_is_sb': '0'},
 'mark hopkins': {'n_is_sb': '0'},
 'mark rothko': {'n_is_sb': '0'},
 'mark tobey': {'n_is_sb': '0'},
 'mark twain': {'n_is_sb': '0'},
 'mark wayne clark': {'n_is_sb': '0'},
 'market analyst': {'n_is_sb': '0'},
 'market keeper': {'n_is_sb': '0'},
 'market strategist': {'n_is_sb': '0'},
 'marketer': {'n_is_sb': '0'},
 'markhoor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'markhor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'markoff': {'n_is_sb': '2', 'n_is_sth': '2'},
 'markova': {'n_is_sb': '0'},
 'markov': {'n_is_sb': '0'},
 'marlene dietrich': {'n_is_sb': '0'},
 'marley': {'n_is_sb': '0'},
 'marlin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'marlowe': {'n_is_sb': '0'},
 'marmoset': {'n_is_sb': '3', 'n_is_sth': '3'},
 'marmota caligata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'marmota flaviventris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'marmota monax': {'n_is_sb': '3', 'n_is_sth': '3'},
 'marmota': {'n_is_sb': '2', 'n_is_sth': '2'},
 'marquand': {'n_is_sb': '0'},
 'marquette': {'n_is_sb': '0'},
 'marquis de lafayette': {'n_is_sb': '0'},
 'marquis de laplace': {'n_is_sb': '0'},
 'marquis de sade': {'n_is_sb': '0'},
 'marquise de maintenon': {'n_is_sb': '0'},
 'marquise de montespan': {'n_is_sb': '0'},
 'marquise de pompdour': {'n_is_sb': '0'},
 'marrano': {'n_is_sb': '0'},
 'marriage broker': {'n_is_sb': '0'},
 'married man': {'n_is_sb': '0'},
 'married person': {'n_is_sb': '0'},
 'married woman': {'n_is_sb': '0'},
 'marsh hare': {'n_is_sb': '3', 'n_is_sth': '3'},
 'marsh harrier': {'n_is_sb': '2', 'n_is_sth': '2'},
 'marsh hawk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'marsh hen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'marsh wren': {'n_is_sb': '3', 'n_is_sth': '3'},
 'marshal saxe': {'n_is_sb': '0'},
 'marshal tito': {'n_is_sb': '0'},
 'marshall mcluhan': {'n_is_sb': '0'},
 'marshall': {'n_is_sb': '0'},
 'marstan': {'n_is_sb': '0'},
 'marsupial mole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'marsupial mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'marsupial rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'marsupial': {'n_is_sb': '3', 'n_is_sth': '3'},
 'marta brigit nilsson': {'n_is_sb': '0'},
 'marten cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'martes americana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'martes foina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'martes martes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'martes pennanti': {'n_is_sb': '3', 'n_is_sth': '3'},
 'martes zibellina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'martes': {'n_is_sb': '2', 'n_is_sth': '2'},
 'martha beatrice potter webb': {'n_is_sb': '0'},
 'martha graham': {'n_is_sb': '0'},
 'martha jane burke': {'n_is_sb': '0'},
 'martha jane burk': {'n_is_sb': '0'},
 'martial': {'n_is_sb': '2', 'n_is_sth': '2'},
 'martian': {'n_is_sb': '0'},
 'martin buber': {'n_is_sb': '0'},
 'martin cline': {'n_is_sb': '0'},
 'martin heidegger': {'n_is_sb': '0'},
 'martin heinrich klaproth': {'n_is_sb': '0'},
 'martin luther king jr.': {'n_is_sb': '0'},
 'martin luther king': {'n_is_sb': '0'},
 'martin luther': {'n_is_sb': '0'},
 'martin scorsese': {'n_is_sb': '0'},
 'martin van buren': {'n_is_sb': '0'},
 'martina navratilova': {'n_is_sb': '0'},
 'martinet': {'n_is_sb': '2', 'n_is_sth': '2'},
 'marti': {'n_is_sb': '0'},
 'marut': {'n_is_sb': '0'},
 'marveller': {'n_is_sb': '0'},
 'marvell': {'n_is_sb': '0'},
 'marvin neil simon': {'n_is_sb': '0'},
 'marxist': {'n_is_sb': '0', 'cap_word': 'Marxist'},
 'marx': {'n_is_sb': '0'},
 'mary ann evans': {'n_is_sb': '0'},
 'mary ashton rice livermore': {'n_is_sb': '0'},
 'mary augusta arnold ward': {'n_is_sb': '0'},
 'mary baker eddy': {'n_is_sb': '0'},
 'mary douglas leakey': {'n_is_sb': '0'},
 "mary flannery o'connor": {'n_is_sb': '0'},
 'mary godwin wollstonecraft shelley': {'n_is_sb': '0'},
 'mary harris jones': {'n_is_sb': '0'},
 'mary ii': {'n_is_sb': '0'},
 'mary i': {'n_is_sb': '0'},
 'mary leakey': {'n_is_sb': '0'},
 'mary leontyne price': {'n_is_sb': '0'},
 'mary ludwig hays mccauley': {'n_is_sb': '0'},
 'mary magdalene': {'n_is_sb': '0'},
 'mary magdalen': {'n_is_sb': '0'},
 'mary mallon': {'n_is_sb': '0'},
 'mary martin': {'n_is_sb': '0'},
 'mary mccarthy': {'n_is_sb': '0'},
 'mary mccauley': {'n_is_sb': '0'},
 'mary mcleod bethune': {'n_is_sb': '0'},
 'mary morse baker eddy': {'n_is_sb': '0'},
 'mary pickford': {'n_is_sb': '0'},
 'mary queen of scots': {'n_is_sb': '0'},
 'mary shelley': {'n_is_sb': '0'},
 'mary stuart': {'n_is_sb': '0'},
 'mary therese mccarthy': {'n_is_sb': '0'},
 'mary tudor': {'n_is_sb': '0'},
 'mary wollstonecraft godwin': {'n_is_sb': '0'},
 'mary wollstonecraft shelley': {'n_is_sb': '0'},
 'mary wollstonecraft': {'n_is_sb': '0'},
 'marya sklodowska': {'n_is_sb': '0'},
 'maryland yellowthroat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'masefield': {'n_is_sb': '0'},
 'masher': {'n_is_sb': '2', 'n_is_sth': '2'},
 'masked shrew': {'n_is_sb': '0'},
 'masker': {'n_is_sb': '0'},
 'masochist': {'n_is_sb': '0'},
 'mason bee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mason wasp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'masorete': {'n_is_sb': '0'},
 'masorite': {'n_is_sb': '0'},
 'masoud': {'n_is_sb': '0'},
 'masquerader': {'n_is_sb': '0'},
 'masquer': {'n_is_sb': '0'},
 'mass murderer': {'n_is_sb': '0'},
 'massachuset': {'n_is_sb': '0'},
 'massager': {'n_is_sb': '2', 'n_is_sth': '2'},
 'massasauga rattler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'massasauga': {'n_is_sb': '3', 'n_is_sth': '3'},
 'massasoit': {'n_is_sb': '0'},
 'massenet': {'n_is_sb': '0'},
 'masseuse': {'n_is_sb': '0'},
 'massine': {'n_is_sb': '0'},
 'massorete': {'n_is_sb': '0'},
 'master of ceremonies': {'n_is_sb': '0'},
 'master sergeant': {'n_is_sb': '0'},
 'master-at-arms': {'n_is_sb': '0'},
 'masticophis bilineatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'masticophis flagellum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'masticophis lateralis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mastiff bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mastigophoran': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mastigophore': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mastigoproctus giganteus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mastigoproctus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mastodont': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mastotermes darwiniensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mastotermes electrodominicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mastotermes electromexicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'masturbator': {'n_is_sb': '0'},
 'mata hari': {'n_is_sb': '0'},
 'matador': {'n_is_sb': '2', 'n_is_sth': '2'},
 'matcher': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mater turrita': {'n_is_sb': '0'},
 'materfamilias': {'n_is_sb': '0'},
 'material witness': {'n_is_sb': '0'},
 'materialist': {'n_is_sb': '0'},
 'math teacher': {'n_is_sb': '0'},
 'mathematical statistician': {'n_is_sb': '0'},
 'mathematics teacher': {'n_is_sb': '0'},
 'mathew b. brady': {'n_is_sb': '0'},
 'mathias': {'n_is_sb': '0'},
 'matinee idol': {'n_is_sb': '0'},
 'matisse': {'n_is_sb': '0'},
 'matman': {'n_is_sb': '0'},
 'matoaka': {'n_is_sb': '0'},
 'matriarch': {'n_is_sb': '0'},
 'matricide': {'n_is_sb': '2', 'n_is_sth': '2'},
 'matriculate': {'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'matrikin': {'n_is_sb': '0'},
 'matrilineal kin': {'n_is_sb': '0'},
 'matrilineal sib': {'n_is_sb': '0'},
 'matrisib': {'n_is_sb': '0'},
 'matron of honor': {'n_is_sb': '0'},
 'matthew arnold': {'n_is_sb': '0'},
 'matthew calbraith perry': {'n_is_sb': '0'},
 'matthew flinders': {'n_is_sb': '0'},
 'matthew': {'n_is_sb': '0'},
 'matthias schleiden': {'n_is_sb': '0'},
 'mattole': {'n_is_sb': '0'},
 'maud gonne': {'n_is_sb': '0'},
 'maugham': {'n_is_sb': '0'},
 'mauldin': {'n_is_sb': '0'},
 'maupassant': {'n_is_sb': '0'},
 'maureen catherine connolly': {'n_is_sb': '0'},
 'mauriac': {'n_is_sb': '0'},
 'maurice barrymore': {'n_is_sb': '0'},
 'maurice chevalier': {'n_is_sb': '0'},
 'maurice de vlaminck': {'n_is_sb': '0'},
 'maurice hugh frederick wilkins': {'n_is_sb': '0'},
 'maurice ravel': {'n_is_sb': '0'},
 'maurice utrillo': {'n_is_sb': '0'},
 'maurice wilkins': {'n_is_sb': '0'},
 'mauritanian': {'n_is_sb': '0'},
 'mauritian': {'n_is_sb': '0'},
 'maurois': {'n_is_sb': '0'},
 'maverick': {'n_is_sb': '0'},
 'mavis': {'n_is_sb': '0'},
 'max beerbohm': {'n_is_sb': '0'},
 'max born': {'n_is_sb': '0'},
 'max bruch': {'n_is_sb': '0'},
 'max delbruck': {'n_is_sb': '0'},
 'max ernst': {'n_is_sb': '0'},
 'max ferdinand perutz': {'n_is_sb': '0'},
 'max karl ernst ludwig planck': {'n_is_sb': '0'},
 'max muller': {'n_is_sb': '0'},
 'max perutz': {'n_is_sb': '0'},
 'max planck': {'n_is_sb': '0'},
 'max weber': {'n_is_sb': '0'},
 'maxfield frederick parrish': {'n_is_sb': '0'},
 'maxfield parrish': {'n_is_sb': '0'},
 'maxim gorki': {'n_is_sb': '0'},
 'maximilien paul emile littre': {'n_is_sb': '0'},
 'maxmilien de bethune': {'n_is_sb': '0'},
 'maxmillien marie isidore de robespierre': {'n_is_sb': '0'},
 'maxostoma': {'n_is_sb': '3', 'n_is_sth': '3'},
 'maxwell anderson': {'n_is_sb': '0'},
 "maxwell's demon": {'n_is_sb': '0'},
 'may beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'may bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'may fish': {'n_is_sb': '0'},
 'may queen': {'n_is_sb': '0'},
 'maya lin': {'n_is_sb': '0'},
 'mayakovski': {'n_is_sb': '0'},
 'mayan': {'n_is_sb': '2', 'cap_word': 'Mayan', 'n_is_sth': '2'},
 'maya': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mayer': {'n_is_sb': '0'},
 'mayetiola destructor': {'n_is_sb': '0'},
 'mayfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mayoress': {'n_is_sb': '0'},
 'mays': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mazzini': {'n_is_sb': '0'},
 'mccarthy': {'n_is_sb': '0'},
 'mccartney': {'n_is_sb': '0'},
 'mccauley': {'n_is_sb': '0'},
 'mccormick': {'n_is_sb': '0'},
 'mccullers': {'n_is_sb': '0'},
 'mcgraw': {'n_is_sb': '0'},
 'mcguffey': {'n_is_sb': '0'},
 'mckim': {'n_is_sb': '0'},
 'mckinley': {'n_is_sb': '0'},
 'mcluhan': {'n_is_sb': '0'},
 'mcmaster': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mcpherson': {'n_is_sb': '0'},
 'md': {'n_is_sb': '2', 'n_is_sth': '2'},
 'meade': {'n_is_sb': '0'},
 'meadow jumping mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'meadow mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'meadow pipit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'meadow spittlebug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'meadow vole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'meadowlark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mead': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mealworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mealy bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mealybug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'meanie': {'n_is_sb': '0'},
 'measurer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'measuring worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'meat packer': {'n_is_sb': '0'},
 'meatman': {'n_is_sb': '0'},
 'mechanical engineer': {'n_is_sb': '0'},
 'mechanist': {'n_is_sb': '0'},
 'mecopteran': {'n_is_sb': '3', 'n_is_sth': '3'},
 'medai guru': {'n_is_sb': '0'},
 'medal winner': {'n_is_sb': '0'},
 'medalist': {'n_is_sb': '0'},
 'medallist': {'n_is_sb': '0'},
 'medawar': {'n_is_sb': '0'},
 'meddler': {'n_is_sb': '0'},
 'medea': {'n_is_sb': '0'},
 'medfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'medgar evers': {'n_is_sb': '0'},
 'medgar wiley evers': {'n_is_sb': '0'},
 'media consultant': {'n_is_sb': '0'},
 'mediatrix': {'n_is_sb': '0'},
 'medical assistant': {'n_is_sb': '0'},
 'medical examiner': {'n_is_sb': '0'},
 'medical extern': {'n_is_sb': '0'},
 'medical intern': {'n_is_sb': '0'},
 'medical man': {'n_is_sb': '0'},
 'medical officer': {'n_is_sb': '0'},
 'medical practitioner': {'n_is_sb': '0'},
 'medical scientist': {'n_is_sb': '0'},
 'medical social worker': {'n_is_sb': '0'},
 'medical specialist': {'n_is_sb': '0'},
 'medical student': {'n_is_sb': '0'},
 'medicinal leech': {'n_is_sb': '3', 'n_is_sth': '3'},
 'medicine man': {'n_is_sb': '0'},
 'medieval schoolman': {'n_is_sb': '0'},
 'mediterranean anchovy': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mediterranean flour moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mediterranean fruit fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mediterranean water shrew': {'n_is_sb': '3', 'n_is_sth': '3'},
 'medusan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'meerkat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'meeter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'megaderma lyra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'megaera': {'n_is_sb': '0'},
 'megalobatrachus maximus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'megalobatrachus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'megalomaniac': {'n_is_sb': '0'},
 'megalosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'megalosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'megapode': {'n_is_sb': '3', 'n_is_sth': '3'},
 'megaptera novaeangliae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'megaptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'megathere': {'n_is_sb': '3', 'n_is_sth': '3'},
 'megatherian mammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'megatherian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'megatheriid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mehemet ali': {'n_is_sb': '0'},
 'meiji tenno': {'n_is_sb': '0'},
 'meir': {'n_is_sb': '0'},
 'meissner': {'n_is_sb': '0'},
 'meister eckhart': {'n_is_sb': '0'},
 'meitner': {'n_is_sb': '0'},
 'mel columcille gerard gibson': {'n_is_sb': '0'},
 'mel gibson': {'n_is_sb': '0'},
 'melancholiac': {'n_is_sb': '0'},
 'melancholic': {'n_is_sb': '0'},
 'melanchthon': {'n_is_sb': '0'},
 'melanerpes erythrocephalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'melanie klein': {'n_is_sb': '0'},
 'melanitta nigra': {'n_is_sb': '0'},
 'melanogrammus aeglefinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'melanotis caerulescens': {'n_is_sb': '3', 'n_is_sth': '3'},
 'melba': {'n_is_sb': '0'},
 'melchior': {'n_is_sb': '0'},
 'melchite': {'n_is_sb': '0'},
 'meleagris gallopavo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'meleagris': {'n_is_sb': '2', 'n_is_sth': '2'},
 'meles meles': {'n_is_sb': '3', 'n_is_sth': '3'},
 'meles': {'n_is_sb': '2', 'n_is_sth': '2'},
 'melina mercouri': {'n_is_sb': '0'},
 'meliorist': {'n_is_sb': '0'},
 'melkite': {'n_is_sb': '0'},
 'mellivora capensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mellon': {'n_is_sb': '0'},
 'melolontha melolontha': {'n_is_sb': '3', 'n_is_sth': '3'},
 'melolonthid beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'melophagus ovinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'melopsittacus undulatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'melospiza georgiana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'melospiza melodia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'melpomene': {'n_is_sb': '0'},
 'melter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'melursus ursinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'melursus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'melvil dewey': {'n_is_sb': '0'},
 'melville bell': {'n_is_sb': '0'},
 'melville louis kossuth dewey': {'n_is_sb': '0'},
 'melville': {'n_is_sb': '0'},
 'melvin calvin': {'n_is_sb': '0'},
 'member of parliament': {'n_is_sb': '0'},
 'memoriser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'memorizer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'memsahib': {'n_is_sb': '0'},
 'menachem begin': {'n_is_sb': '0'},
 'menander': {'n_is_sb': '0'},
 'mencken': {'n_is_sb': '0'},
 'mendeleev': {'n_is_sb': '0'},
 'mendeleyev': {'n_is_sb': '0'},
 'mendelsohn': {'n_is_sb': '0'},
 'mendelssohn': {'n_is_sb': '0'},
 'mendel': {'n_is_sb': '0'},
 'mender': {'n_is_sb': '0'},
 'mendicant': {'n_is_sb': '0'},
 'menelaus': {'n_is_sb': '0'},
 'menhaden': {'n_is_sb': '3', 'n_is_sth': '3'},
 'meniere': {'n_is_sb': '0'},
 'menippe mercenaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'menippe': {'n_is_sb': '0'},
 'menninger': {'n_is_sb': '0'},
 'mennonite': {'n_is_sb': '0'},
 'menominee whitefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'menominee': {'n_is_sb': '0'},
 'menomini': {'n_is_sb': '0'},
 'menopon gallinae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'menopon palladum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'menotti': {'n_is_sb': '0'},
 'mensch': {'n_is_sb': '0'},
 'menshevik': {'n_is_sb': '0'},
 'mensh': {'n_is_sb': '0'},
 'mental case': {'n_is_sb': '0'},
 'mental telepathist': {'n_is_sb': '0'},
 'menticirrhus americanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'menticirrhus littoralis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'menticirrhus saxatilis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'menticirrhus undulatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mentioner': {'n_is_sb': '0'},
 'menuhin': {'n_is_sb': '0'},
 'mephistopheles': {'n_is_sb': '0'},
 'mephitis macroura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mephitis mephitis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mercator': {'n_is_sb': '0'},
 'merce cunningham': {'n_is_sb': '0'},
 'mercenaria mercenaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mercenary': {'n_is_sb': '0'},
 'mercer': {'n_is_sb': '0'},
 'merchant-venturer': {'n_is_sb': '0'},
 'merckx': {'n_is_sb': '0'},
 'mercouri': {'n_is_sb': '0'},
 'meredith': {'n_is_sb': '0'},
 'merganser': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mergenthaler': {'n_is_sb': '0'},
 'mergus albellus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mergus merganser americanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mergus merganser': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mergus serrator': {'n_is_sb': '3', 'n_is_sth': '3'},
 'merino sheep': {'n_is_sb': '3', 'n_is_sth': '3'},
 'merino': {'n_is_sb': '2', 'n_is_sth': '2'},
 'meriones longifrons': {'n_is_sb': '3', 'n_is_sth': '3'},
 'meriones unguiculatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'meriwether lewis': {'n_is_sb': '0'},
 'merlangus merlangus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'merlangus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'merle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'merlin': {'n_is_sb': '0'},
 'merluccius bilinearis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'merluccius': {'n_is_sb': '2', 'n_is_sth': '2'},
 'merl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'merman': {'n_is_sb': '0'},
 'merodach': {'n_is_sb': '0'},
 'merops': {'n_is_sb': '2', 'n_is_sth': '2'},
 'merovingian': {'n_is_sb': '0'},
 'merozoite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'merry andrew': {'n_is_sb': '0'},
 'merrymaker': {'n_is_sb': '0'},
 'meryl streep': {'n_is_sb': '0'},
 'meshuggeneh': {'n_is_sb': '0'},
 'meshuggener': {'n_is_sb': '0'},
 'mesmerist': {'n_is_sb': '0'},
 'mesmer': {'n_is_sb': '0'},
 'mesne lord': {'n_is_sb': '0'},
 'mesoamerican': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mesocricetus auratus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mesocricetus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mesohippus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mesomorph': {'n_is_sb': '0'},
 'messenger boy': {'n_is_sb': '0'},
 'messiah': {'n_is_sb': '0'},
 'messmate': {'n_is_sb': '0'},
 'mestiza': {'n_is_sb': '0'},
 'metabola': {'n_is_sb': '0'},
 'metallurgical engineer': {'n_is_sb': '0'},
 'metallurgist': {'n_is_sb': '0'},
 'metalworker': {'n_is_sb': '0'},
 'metatherian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'metazoan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'metazoa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'metchnikoff': {'n_is_sb': '0'},
 'metchnikov': {'n_is_sb': '0'},
 'meteorologist': {'n_is_sb': '0'},
 'meter maid': {'n_is_sb': '0'},
 'methanogen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'methodist': {'n_is_sb': '0'},
 'methuselah': {'n_is_sb': '0'},
 'metic': {'n_is_sb': '0'},
 'metropolitan': {'n_is_sb': '0'},
 'metternich': {'n_is_sb': '0'},
 'mew gull': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mexican beaded lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mexican bean beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mexican freetail bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mexican hairless': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mexican pocket mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mexican-american': {'n_is_sb': '0'},
 'mexicano': {'n_is_sb': '0'},
 'meyer guggenheim': {'n_is_sb': '0'},
 'meyerbeer': {'n_is_sb': '0'},
 'meyerhof': {'n_is_sb': '0'},
 'micah': {'n_is_sb': '0'},
 'micawber': {'n_is_sb': '0'},
 'michael assat': {'n_is_sb': '0'},
 'michael ellis de bakey': {'n_is_sb': '0'},
 'michael faraday': {'n_is_sb': '0'},
 'michael gerald tyson': {'n_is_sb': '0'},
 'michael jackson': {'n_is_sb': '0'},
 'michael joe jackson': {'n_is_sb': '0'},
 'michael ondaatje': {'n_is_sb': '0'},
 'michael philip jagger': {'n_is_sb': '0'},
 'michael': {'n_is_sb': '0'},
 'micheas': {'n_is_sb': '0'},
 'michel de notredame': {'n_is_sb': '0'},
 'michel eyquem montaigne': {'n_is_sb': '0'},
 'michel montaigne': {'n_is_sb': '0'},
 'michel ney': {'n_is_sb': '0'},
 'michelangelo buonarroti': {'n_is_sb': '0'},
 'michelangelo merisi da caravaggio': {'n_is_sb': '0'},
 'michelangelo': {'n_is_sb': '0'},
 'michelson': {'n_is_sb': '0'},
 'michener': {'n_is_sb': '0'},
 'michigander': {'n_is_sb': '0'},
 'michinomiya hirohito': {'n_is_sb': '0'},
 'mick jagger': {'n_is_sb': '0'},
 'mickey charles mantle': {'n_is_sb': '0'},
 'mickey mantle': {'n_is_sb': '0'},
 'mickey mouse': {'n_is_sb': '0'},
 'mickey spillane': {'n_is_sb': '0'},
 'mick': {'n_is_sb': '0'},
 'micmac': {'n_is_sb': '2', 'n_is_sth': '2'},
 'microbat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'microbiologist': {'n_is_sb': '3', 'n_is_sth': '3'},
 'microcentrum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'micrococcus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'microdipodops': {'n_is_sb': '3', 'n_is_sth': '3'},
 'microeconomic expert': {'n_is_sb': '0'},
 'microeconomist': {'n_is_sb': '0'},
 'micromyx minutus': {'n_is_sb': '0'},
 'micromyx': {'n_is_sb': '2', 'n_is_sth': '2'},
 'micropogonias undulatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'micropogonias': {'n_is_sb': '3', 'n_is_sth': '3'},
 'micropterus dolomieu': {'n_is_sb': '3', 'n_is_sth': '3'},
 'micropterus pseudoplites': {'n_is_sb': '3', 'n_is_sth': '3'},
 'micropterus salmoides': {'n_is_sb': '3', 'n_is_sth': '3'},
 'microscopist': {'n_is_sb': '0'},
 'microsporidian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'microstomus kitt': {'n_is_sb': '3', 'n_is_sth': '3'},
 'microtus ochrogaster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'microtus pennsylvaticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'microtus richardsoni': {'n_is_sb': '3', 'n_is_sth': '3'},
 'micruroides euryxanthus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'micrurus fulvius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'midas': {'n_is_sb': '2', 'n_is_sth': '2'},
 'middle of the roader': {'n_is_sb': '0'},
 'middle-aged man': {'n_is_sb': '0'},
 'middlebrow': {'n_is_sb': '0'},
 'middleton': {'n_is_sb': '0'},
 'middleweight': {'n_is_sb': '0'},
 'midinette': {'n_is_sb': '0'},
 'midshipman': {'n_is_sb': '0'},
 'midwife toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mierkat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mies van der rohe': {'n_is_sb': '0'},
 'mighty mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'migrant shrike': {'n_is_sb': '3', 'n_is_sth': '3'},
 'migratory grasshopper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'migratory locust': {'n_is_sb': '3', 'n_is_sth': '3'},
 'migratory quail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'migrator': {'n_is_sb': '0'},
 'miguel de cervantes saavedra': {'n_is_sb': '0'},
 'miguel de cervantes': {'n_is_sb': '0'},
 'miguel jose serra': {'n_is_sb': '0'},
 'mike tyson': {'n_is_sb': '0'},
 'mikhail aleksandrovich bakunin': {'n_is_sb': '0'},
 'mikhail bakunin': {'n_is_sb': '0'},
 'mikhail baryshnikov': {'n_is_sb': '0'},
 'mikhail glinka': {'n_is_sb': '0'},
 'mikhail gorbachev': {'n_is_sb': '0'},
 'mikhail ilarionovich kutuzov': {'n_is_sb': '0'},
 'mikhail ivanovich glinka': {'n_is_sb': '0'},
 'mikhail ivanovich kalinin': {'n_is_sb': '0'},
 'mikhail kalinin': {'n_is_sb': '0'},
 'mikhail sergeyevich gorbachev': {'n_is_sb': '0'},
 'mikhail yurievich lermontov': {'n_is_sb': '0'},
 'mikolaj kopernik': {'n_is_sb': '0'},
 'milch cow': {'n_is_sb': '2', 'n_is_sth': '2'},
 'milcher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mildred ella didrikson zaharias': {'n_is_sb': '0'},
 'mildred ella didrikson': {'n_is_sb': '0'},
 'miler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'miles davis': {'n_is_sb': '0'},
 'miles dewey davis jr.': {'n_is_sb': '0'},
 'miles gloriosus': {'n_is_sb': '0'},
 'miles standish': {'n_is_sb': '0'},
 'milhaud': {'n_is_sb': '0'},
 'military adviser': {'n_is_sb': '0'},
 'military advisor': {'n_is_sb': '0'},
 'military attache': {'n_is_sb': '0'},
 'military chaplain': {'n_is_sb': '0'},
 'military engineer': {'n_is_sb': '0'},
 'military governor': {'n_is_sb': '0'},
 'military leader': {'n_is_sb': '0'},
 'military man': {'n_is_sb': '0'},
 'military officer': {'n_is_sb': '0'},
 'military personnel': {'n_is_sb': '0'},
 'military policeman': {'n_is_sb': '0'},
 'military volunteer': {'n_is_sb': '0'},
 'milk adder': {'n_is_sb': '0'},
 'milk cow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'milk snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'milking shorthorn': {'n_is_sb': '3', 'n_is_sth': '3'},
 'milkmaid': {'n_is_sb': '0'},
 'milkman': {'n_is_sb': '0'},
 'milksop': {'n_is_sb': '0'},
 'milkweed butterfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mill agent': {'n_is_sb': '0'},
 'mill-girl': {'n_is_sb': '0'},
 'mill-hand': {'n_is_sb': '0'},
 'millais': {'n_is_sb': '0'},
 'millard fillmore': {'n_is_sb': '0'},
 'millay': {'n_is_sb': '0'},
 'millenarian': {'n_is_sb': '0'},
 'millenarist': {'n_is_sb': '0'},
 'millepede': {'n_is_sb': '3', 'n_is_sth': '3'},
 "miller's-thumb": {'n_is_sb': '3', 'n_is_sth': '3'},
 'millikan': {'n_is_sb': '0'},
 'milliner': {'n_is_sb': '0'},
 'millionairess': {'n_is_sb': '0'},
 'millipede': {'n_is_sb': '3', 'n_is_sth': '3'},
 'milliped': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mills': {'n_is_sb': '0'},
 'millwright': {'n_is_sb': '0'},
 'milne': {'n_is_sb': '0'},
 'milquetoast': {'n_is_sb': '0'},
 'miltiades': {'n_is_sb': '0'},
 'milton friedman': {'n_is_sb': '0'},
 'milton snavely hershey': {'n_is_sb': '0'},
 'milton': {'n_is_sb': '0'},
 'milvus migrans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'milvus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mimer': {'n_is_sb': '0'},
 'mimicker': {'n_is_sb': '0'},
 'mimir': {'n_is_sb': '0'},
 'mimus polyglotktos': {'n_is_sb': '0'},
 'minah': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mina': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mind reader': {'n_is_sb': '0'},
 'minder': {'n_is_sb': '0'},
 "miner's cat": {'n_is_sb': '3', 'n_is_sth': '3'},
 'mineralogist': {'n_is_sb': '0'},
 'minerva': {'n_is_sb': '0'},
 'mineworker': {'n_is_sb': '0'},
 'miniature pinscher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'miniature poodle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'miniature schnauzer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'miniaturist': {'n_is_sb': '0'},
 'minimalist': {'n_is_sb': '0'},
 'mining bee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mining engineer': {'n_is_sb': '0'},
 'minister of finance': {'n_is_sb': '0'},
 'minister plenipotentiary': {'n_is_sb': '0'},
 'ministrant': {'n_is_sb': '0'},
 'minke whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'minkowski': {'n_is_sb': '0'},
 'minnesotan': {'n_is_sb': '0'},
 'minnewit': {'n_is_sb': '0'},
 'minnie mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'minnow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'minoan': {'n_is_sb': '0'},
 'minor leaguer': {'n_is_sb': '0'},
 'minority leader': {'n_is_sb': '0'},
 'minos': {'n_is_sb': '0'},
 'minotaur': {'n_is_sb': '0'},
 'minter': {'n_is_sb': '0'},
 'minuit': {'n_is_sb': '0'},
 'minx': {'n_is_sb': '0'},
 'min': {'n_is_sb': '0'},
 'mirabeau': {'n_is_sb': '0'},
 'miracle man': {'n_is_sb': '0'},
 'miracle worker': {'n_is_sb': '0'},
 'mirid bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mirid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mirounga': {'n_is_sb': '2', 'n_is_sth': '2'},
 'miro': {'n_is_sb': '0'},
 'mirror carp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'misanthrope': {'n_is_sb': '0'},
 'misanthropist': {'n_is_sb': '0'},
 'misbeliever': {'n_is_sb': '0'},
 'mischief-maker': {'n_is_sb': '0'},
 'misfit': {'n_is_sb': '0'},
 'misleader': {'n_is_sb': '0'},
 'misogamist': {'n_is_sb': '0'},
 'misogynist': {'n_is_sb': '0'},
 'missel thrush': {'n_is_sb': '3', 'n_is_sth': '3'},
 'missing link': {'n_is_sb': '0'},
 'missioner': {'n_is_sb': '0'},
 'mississippian': {'n_is_sb': '0'},
 'missis': {'n_is_sb': '0'},
 'missourian': {'n_is_sb': '0'},
 'mistle thrush': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mistletoe thrush': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mitchell': {'n_is_sb': '0'},
 'mitchum': {'n_is_sb': '0'},
 'mitford': {'n_is_sb': '0'},
 'mithan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mithraist': {'n_is_sb': '0'},
 'mithras': {'n_is_sb': '0'},
 'mithra': {'n_is_sb': '0'},
 'mithridates the great': {'n_is_sb': '0'},
 'mithridates vi': {'n_is_sb': '0'},
 'mithridates': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mitra': {'n_is_sb': '0'},
 'mitterand': {'n_is_sb': '0'},
 'miwok': {'n_is_sb': '0'},
 'mixed-blood': {'n_is_sb': '0'},
 'mixologist': {'n_is_sb': '0'},
 'mnemonist': {'n_is_sb': '0'},
 'mnemosyne': {'n_is_sb': '0'},
 'moaner': {'n_is_sb': '0'},
 'moa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mobius': {'n_is_sb': '0'},
 'mobula hypostoma': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mobula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mocker': {'n_is_sb': '0'},
 'mocking thrush': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mockingbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'modeler': {'n_is_sb': '0'},
 'modeller': {'n_is_sb': '0'},
 'moderationist': {'n_is_sb': '0'},
 'modern man': {'n_is_sb': '0'},
 'modernist': {'n_is_sb': '0'},
 'modest moussorgsky': {'n_is_sb': '0'},
 'modest mussorgsky': {'n_is_sb': '0'},
 'modest petrovich moussorgsky': {'n_is_sb': '0'},
 'modest petrovich mussorgsky': {'n_is_sb': '0'},
 'modigliani': {'n_is_sb': '0'},
 'modiste': {'n_is_sb': '0'},
 'mod': {'n_is_sb': '0'},
 'moghul': {'n_is_sb': '0'},
 'mohammad': {'n_is_sb': '0'},
 'mohammed ali': {'n_is_sb': '0'},
 'mohammed reza pahlavi': {'n_is_sb': '0'},
 'mohammed reza pahlevi': {'n_is_sb': '0'},
 'mohammedan': {'n_is_sb': '0'},
 'mohammed': {'n_is_sb': '0'},
 'mohandas karamchand gandhi': {'n_is_sb': '0'},
 'mohave': {'n_is_sb': '0'},
 'mohawk': {'n_is_sb': '0'},
 'mohican': {'n_is_sb': '0'},
 'moira shearer': {'n_is_sb': '0'},
 'moirae': {'n_is_sb': '0'},
 'moirai': {'n_is_sb': '0'},
 'mojarra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mojave rattlesnake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mojave': {'n_is_sb': '0'},
 'moke': {'n_is_sb': '0'},
 'mola lanceolata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mole cricket': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mole rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mole salamander': {'n_is_sb': '3', 'n_is_sth': '3'},
 'molech': {'n_is_sb': '0'},
 'molecular biologist': {'n_is_sb': '0'},
 'molester': {'n_is_sb': '0'},
 'moliere': {'n_is_sb': '0'},
 'mollah': {'n_is_sb': '0'},
 'mollie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mollusc': {'n_is_sb': '3', 'n_is_sth': '3'},
 'molly miller': {'n_is_sb': '3', 'n_is_sth': '3'},
 'molly pitcher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mollycoddler': {'n_is_sb': '0'},
 'mollycoddle': {'n_is_sb': '0'},
 'mollymawk': {'n_is_sb': '0'},
 'molly': {'n_is_sb': '0'},
 'moll': {'n_is_sb': '0'},
 'molnar': {'n_is_sb': '0'},
 'moloch horridus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'molotov': {'n_is_sb': '0'},
 'molter': {'n_is_sb': '0'},
 'molva molva': {'n_is_sb': '0'},
 'momma': {'n_is_sb': '0'},
 'mommsen': {'n_is_sb': '0'},
 'mommy': {'n_is_sb': '0'},
 'momos': {'n_is_sb': '0'},
 'momotus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'momot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'momus': {'n_is_sb': '0'},
 'monal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'monarch butterfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'monarchist': {'n_is_sb': '0'},
 'monaul': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mondrian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'monegasque': {'n_is_sb': '0'},
 'moneran': {'n_is_sb': '3', 'n_is_sth': '3'},
 'monera': {'n_is_sb': '2', 'n_is_sth': '2'},
 'monetarist': {'n_is_sb': '0'},
 'monet': {'n_is_sb': '0'},
 'money changer': {'n_is_sb': '0'},
 'money cowrie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'money dealer': {'n_is_sb': '0'},
 'money handler': {'n_is_sb': '0'},
 'moneyer': {'n_is_sb': '0'},
 'moneygrubber': {'n_is_sb': '0'},
 'moneylender': {'n_is_sb': '0'},
 'moneymaker': {'n_is_sb': '0'},
 'moneyman': {'n_is_sb': '0'},
 'mongol tatar': {'n_is_sb': '0'},
 'mongolian race': {'n_is_sb': '0'},
 'mongoloid race': {'n_is_sb': '0'},
 'monica seles': {'n_is_sb': '0'},
 'monitor lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'monitrice': {'n_is_sb': '2', 'n_is_sth': '2'},
 'monkey dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'monkey pinscher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'monnet': {'n_is_sb': '0'},
 'monochromat': {'n_is_sb': '0'},
 'monodon monoceros': {'n_is_sb': '3', 'n_is_sth': '3'},
 'monod': {'n_is_sb': '0'},
 'monogamist': {'n_is_sb': '0'},
 'monogynist': {'n_is_sb': '0'},
 'monologist': {'n_is_sb': '0'},
 'monomaniac': {'n_is_sb': '0'},
 'monomorium minimum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'monomorium pharaonis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mononychus olecranus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'monophthalmos': {'n_is_sb': '0'},
 'monophysite': {'n_is_sb': '0'},
 'monoplane flying fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'monopoliser': {'n_is_sb': '0'},
 'monopolist': {'n_is_sb': '0'},
 'monopolizer': {'n_is_sb': '0'},
 'monotheist': {'n_is_sb': '0'},
 'monotreme': {'n_is_sb': '3', 'n_is_sth': '3'},
 'monozygotic twin': {'n_is_sb': '0'},
 'monozygous twin': {'n_is_sb': '0'},
 'monroe': {'n_is_sb': '0'},
 'monsignor': {'n_is_sb': '0'},
 "montagu's harrier": {'n_is_sb': '3', 'n_is_sth': '3'},
 'montagu': {'n_is_sb': '0'},
 'montaigne': {'n_is_sb': '0'},
 'montanan': {'n_is_sb': '0'},
 'montespan': {'n_is_sb': '0'},
 'montesquieu': {'n_is_sb': '0'},
 'montessori': {'n_is_sb': '0'},
 'monteverdi': {'n_is_sb': '0'},
 'montezuma ii': {'n_is_sb': '0'},
 'montez': {'n_is_sb': '0'},
 'montfort': {'n_is_sb': '0'},
 'montgolfier': {'n_is_sb': '2', 'n_is_sth': '2'},
 'montgomery ward': {'n_is_sb': '0'},
 'montserratian': {'n_is_sb': '0'},
 'mon': {'n_is_sb': '2', 'n_is_sth': '2'},
 'moo-cow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'moody': {'n_is_sb': '0', 'jj_to_jjr': 'moodier', 'jj_to_jjs': 'moodiest'},
 'moon curser': {'n_is_sb': '0'},
 'moon shell': {'n_is_sb': '3', 'n_is_sth': '3'},
 'moon-curser': {'n_is_sb': '0'},
 'moonfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'moonie': {'n_is_sb': '0'},
 'moonshell': {'n_is_sb': '3', 'n_is_sth': '3'},
 'moonshiner': {'n_is_sb': '0'},
 'moor-bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'moorbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'moorcock': {'n_is_sb': '3', 'n_is_sth': '3'},
 'moore': {'n_is_sb': '0'},
 'moorfowl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'moorgame': {'n_is_sb': '3', 'n_is_sth': '3'},
 'moorhen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mopper': {'n_is_sb': '0'},
 'moralist': {'n_is_sb': '0'},
 'moray eel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mordecai richler': {'n_is_sb': '0'},
 'mordva': {'n_is_sb': '0'},
 'mordvinian': {'n_is_sb': '0'},
 'mordvin': {'n_is_sb': '0'},
 'morelia spilotes variegatus': {'n_is_sb': '0'},
 'morgan le fay': {'n_is_sb': '0'},
 "morlett's crocodile": {'n_is_sb': '3', 'n_is_sth': '3'},
 'morley': {'n_is_sb': '0'},
 'mormon cricket': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mormon': {'n_is_sb': '0'},
 'moroccan': {'n_is_sb': '0', 'cap_word': 'Moroccan'},
 'morone americana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'morone interrupta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'morone': {'n_is_sb': '3', 'n_is_sth': '3'},
 'morosoph': {'n_is_sb': '0'},
 'moro': {'n_is_sb': '0'},
 'morpheus': {'n_is_sb': '0'},
 'morrigan': {'n_is_sb': '0'},
 'morrigu': {'n_is_sb': '0'},
 'morris dancer': {'n_is_sb': '0'},
 'morrison': {'n_is_sb': '0'},
 'morris': {'n_is_sb': '0'},
 'morse': {'n_is_sb': '0'},
 'mors': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mortal enemy': {'n_is_sb': '0'},
 'morta': {'n_is_sb': '0'},
 'mortgage holder': {'n_is_sb': '0'},
 'mortgagee': {'n_is_sb': '0'},
 'mortgager': {'n_is_sb': '0'},
 'mortgagor': {'n_is_sb': '0'},
 'mortician': {'n_is_sb': '0'},
 'mortimer': {'n_is_sb': '0'},
 'morton': {'n_is_sb': '0'},
 'mosander': {'n_is_sb': '0'},
 'moschus moschiferus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'moschus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'moses maimonides': {'n_is_sb': '0'},
 'moses': {'n_is_sb': '0'},
 'moshe dayan': {'n_is_sb': '0'},
 'mosquito hawk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mosquitofish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'moss animal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'moss hart': {'n_is_sb': '0'},
 'moss-trooper': {'n_is_sb': '0'},
 'mossbauer': {'n_is_sb': '0'},
 'most valuable player': {'n_is_sb': '0'},
 'moth miller': {'n_is_sb': '0'},
 "mother carey's chicken": {'n_is_sb': '3', 'n_is_sth': '3'},
 "mother carey's hen": {'n_is_sb': '3', 'n_is_sth': '3'},
 'mother figure': {'n_is_sb': '0'},
 'mother fucker': {'n_is_sb': '0'},
 'mother goose': {'n_is_sb': '0'},
 'mother hen': {'n_is_sb': '0'},
 'mother jones': {'n_is_sb': '0'},
 'mother seton': {'n_is_sb': '0'},
 'mother superior': {'n_is_sb': '0'},
 'mother teresa': {'n_is_sb': '0'},
 'mother theresa': {'n_is_sb': '0'},
 "mother's boy": {'n_is_sb': '0'},
 "mother's daughter": {'n_is_sb': '0'},
 "mother's son": {'n_is_sb': '0'},
 'motherfucker': {'n_is_sb': '0', 'dirtyword': ''},
 'motherwell': {'n_is_sb': '0'},
 'motile': {'n_is_sb': '0'},
 'motion-picture fan': {'n_is_sb': '0'},
 'motley fool': {'n_is_sb': '0'},
 'motmot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'motorcycle cop': {'n_is_sb': '0'},
 'motorcycle policeman': {'n_is_sb': '0'},
 'motorcyclist': {'n_is_sb': '0'},
 'motorist': {'n_is_sb': '0'},
 'motorman': {'n_is_sb': '0'},
 'motormouth': {'n_is_sb': '0'},
 'mott': {'n_is_sb': '2', 'n_is_sth': '2'},
 'moufflon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mouflon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'moujik': {'n_is_sb': '2', 'n_is_sth': '2'},
 'moulter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mound bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mound builder': {'n_is_sb': '0'},
 'mound-bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mountain beaver': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mountain blacksnake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mountain chinchilla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mountain climber': {'n_is_sb': '0'},
 'mountain devil': {'n_is_sb': '0'},
 'mountain goat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mountain gorilla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mountain lion': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mountain man': {'n_is_sb': '0'},
 'mountain nyala': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mountain paca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mountain partridge': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mountain quail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mountain sheep': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mountain skink': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mountain viscacha': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mountain zebra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mountaineer': {'n_is_sb': '0'},
 'mounter': {'n_is_sb': '0'},
 'mourner': {'n_is_sb': '0'},
 'mourning cloak butterfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mourning cloak': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mourning dove': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mouse deer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mouse hare': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mouse-eared bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mouser': {'n_is_sb': '0'},
 'moussorgsky': {'n_is_sb': '0'},
 'mouthbreeder': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mover and shaker': {'n_is_sb': '0'},
 'mover': {'n_is_sb': '2', 'n_is_sth': '2'},
 'movie actor': {'n_is_sb': '0'},
 'movie maker': {'n_is_sb': '0'},
 'movie star': {'n_is_sb': '0'},
 'moviegoer': {'n_is_sb': '0'},
 'mozambican': {'n_is_sb': '0'},
 'mr. moto': {'n_is_sb': '0'},
 'mrs. gandhi': {'n_is_sb': '0'},
 'mrs. henry wood': {'n_is_sb': '0'},
 'mrs. humphrey ward': {'n_is_sb': '0'},
 'mrs. simpson': {'n_is_sb': '0'},
 'mrs': {'n_is_sb': '0'},
 'mr': {'n_is_sb': '0'},
 'ms.': {'n_is_sb': '0'},
 'muadhdhin': {'n_is_sb': '0'},
 'muammar al-qaddafi': {'n_is_sb': '0'},
 'muammar el-qaddafi': {'n_is_sb': '0'},
 'muazzin': {'n_is_sb': '0'},
 'mubarak': {'n_is_sb': '0'},
 'mud dauber': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mud digger': {'n_is_sb': '0'},
 'mud hen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mud puppy': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mud turtle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mudcat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mudskipper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mudslinger': {'n_is_sb': '0'},
 'mudspringer': {'n_is_sb': '0'},
 'muezzin': {'n_is_sb': '0'},
 'muffin man': {'n_is_sb': '0'},
 'muggee': {'n_is_sb': '0'},
 'mugger': {'n_is_sb': '0'},
 'muggins': {'n_is_sb': '0'},
 'mugil cephalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mugil curema': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mugil liza': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mugwump': {'n_is_sb': '0'},
 'muhammad ali jinnah': {'n_is_sb': '0'},
 'muhammad ali': {'n_is_sb': '0'},
 'muhammadan': {'n_is_sb': '0'},
 'muhammad': {'n_is_sb': '0'},
 'muhammedan': {'n_is_sb': '0'},
 'muir': {'n_is_sb': '0'},
 'muishond': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mujahid': {'n_is_sb': '0'},
 'mujik': {'n_is_sb': '0'},
 'mujtihad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mule deer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mule driver': {'n_is_sb': '0'},
 'mule skinner': {'n_is_sb': '0'},
 'muleteer': {'n_is_sb': '0'},
 'mullah mohammed omar': {'n_is_sb': '0'},
 'mullah omar': {'n_is_sb': '0'},
 'mullah': {'n_is_sb': '0'},
 'mulla': {'n_is_sb': '0'},
 'muller': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mulloidichthys martinicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mulloway': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mullus auratus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mullus surmuletus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mumbler': {'n_is_sb': '0'},
 'mummer': {'n_is_sb': '0'},
 'mummichog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'munchausen': {'n_is_sb': '2', 'n_is_sth': '2'},
 'muncher': {'n_is_sb': '0'},
 'munchhausen': {'n_is_sb': '0'},
 'munch': {'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'mungo park': {'n_is_sb': '0'},
 'munro': {'n_is_sb': '0'},
 'muntjac': {'n_is_sb': '3', 'n_is_sth': '3'},
 'muralist': {'n_is_sb': '0'},
 'murder suspect': {'n_is_sb': '0'},
 'murderee': {'n_is_sb': '0'},
 'murderess': {'n_is_sb': '0'},
 'murdoch': {'n_is_sb': '0'},
 'muriel sarah spark': {'n_is_sb': '0'},
 'muriel spark': {'n_is_sb': '0'},
 'murillo': {'n_is_sb': '2', 'n_is_sth': '2'},
 'murine': {'n_is_sb': '0'},
 'muroidea': {'n_is_sb': '2', 'n_is_sth': '2'},
 'murray gell-mann': {'n_is_sb': '0'},
 'murre': {'n_is_sb': '0'},
 'murrow': {'n_is_sb': '0'},
 'mus musculus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'musca domestica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'muscardinus avellanarius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'muscicapa grisola': {'n_is_sb': '3', 'n_is_sth': '3'},
 'muscicapa striata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'muscivora-forficata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'muscle builder': {'n_is_sb': '0'},
 'muscle-builder': {'n_is_sb': '0'},
 'musclebuilder': {'n_is_sb': '0'},
 'muscovite': {'n_is_sb': '0'},
 'muscovy duck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'muser': {'n_is_sb': '0'},
 'muse': {'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'musher': {'n_is_sb': '0'},
 'mushroom coral': {'n_is_sb': '3', 'n_is_sth': '3'},
 'musial': {'n_is_sb': '0'},
 'music critic': {'n_is_sb': '0'},
 'music director': {'n_is_sb': '0'},
 'music lover': {'n_is_sb': '0'},
 'music teacher': {'n_is_sb': '0'},
 'musicologist': {'n_is_sb': '0'},
 'musk deer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'musk duck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'musk hog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'musk kangaroo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'musk ox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'musk sheep': {'n_is_sb': '3', 'n_is_sth': '3'},
 'musk turtle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'muskellunge': {'n_is_sb': '3', 'n_is_sth': '3'},
 'muskhogean': {'n_is_sb': '0'},
 'muskogean': {'n_is_sb': '0'},
 'muskogee': {'n_is_sb': '2', 'n_is_sth': '2'},
 'muslimah': {'n_is_sb': '0'},
 'musquash': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mussel shrimp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'musset': {'n_is_sb': '0'},
 'mussorgsky': {'n_is_sb': '0'},
 'mustafa kemal': {'n_is_sb': '0'},
 'mustela erminea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mustela frenata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mustela nigripes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mustela nivalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mustela putorius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mustela rixosa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mustela vison': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mustela': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mustelid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'musteline mammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'musteline': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mustelus canis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mustelus mustelus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mustelus norrisi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mute swan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mutilator': {'n_is_sb': '0'},
 'mutineer': {'n_is_sb': '0'},
 'mutsuhito': {'n_is_sb': '0'},
 'mutterer': {'n_is_sb': '0'},
 'mutton snapper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'muttonfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'muttonhead': {'n_is_sb': '0'},
 'muybridge': {'n_is_sb': '0'},
 'muzhik': {'n_is_sb': '0'},
 'muzjik': {'n_is_sb': '0'},
 'muzzler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mvp': {'n_is_sb': '0'},
 'mya arenaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myacidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mya': {'n_is_sb': '0'},
 'mycobacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mycobacterium leprae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mycobacterium tuberculosis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mycobacterium': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mycologist': {'n_is_sb': '0'},
 'mycophagist': {'n_is_sb': '0'},
 'mycoplasma': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mycteria americana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mycteroperca bonaci': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myles standish': {'n_is_sb': '0'},
 'mylitta': {'n_is_sb': '0'},
 'mylodontid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mylodon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myna bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mynah bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myna': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myocastor coypus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myope': {'n_is_sb': '0'},
 'myotis leucifugus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myotis velifer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myrdal': {'n_is_sb': '0'},
 'myriapod': {'n_is_sb': '0'},
 'myrmecia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myrmecobius fasciatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myrmecobius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myrmecophaga jubata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myrmecophile': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myrmidon': {'n_is_sb': '0'},
 'myrtle bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myrtle warbler': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mysis': {'n_is_sb': '2', 'n_is_sth': '2'},
 'mystic jewel': {'n_is_sb': '0'},
 'mystic': {'n_is_sb': '0'},
 'mythical being': {'n_is_sb': '0'},
 'mythical creature': {'n_is_sb': '0'},
 'mythical monster': {'n_is_sb': '0'},
 'mythologist': {'n_is_sb': '0'},
 'mytilid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'mytilus edulis': {'n_is_sb': '2', 'n_is_sth': '2'},
 'myxine glutinosa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myxine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myxinikela siroka': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myxinikela': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myxinoidei': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myxobacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myxobacterium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myxobacter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myxocephalus aenaeus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myxoma virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myxosporidian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myxosporidia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'myxovirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nabob': {'n_is_sb': '0'},
 'nabokov': {'n_is_sb': '0'},
 'nabu': {'n_is_sb': '0'},
 'nadine gordimer': {'n_is_sb': '0'},
 'naemorhedus goral': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nagger': {'n_is_sb': '0'},
 'nahuatl': {'n_is_sb': '0'},
 'nahum': {'n_is_sb': '0'},
 'naiad': {'n_is_sb': '0'},
 'nail-tailed kangaroo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nail-tailed wallaby': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nailer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'naismith': {'n_is_sb': '0'},
 'naja haje': {'n_is_sb': '3', 'n_is_sth': '3'},
 'naja hannah': {'n_is_sb': '0'},
 'naja naja': {'n_is_sb': '3', 'n_is_sth': '3'},
 'naja nigricollis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'naked mole rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'namby-pamby': {'n_is_sb': '0'},
 'name dropper': {'n_is_sb': '0'},
 'namer': {'n_is_sb': '0'},
 'namesake': {'n_is_sb': '0'},
 'namibian': {'n_is_sb': '0'},
 'nammu': {'n_is_sb': '0'},
 'namtaru': {'n_is_sb': '3', 'n_is_sth': '3'},
 'namtar': {'n_is_sb': '0'},
 'nanak': {'n_is_sb': '0'},
 'nance': {'n_is_sb': '0'},
 'nancy freeman mitford': {'n_is_sb': '0'},
 'nancy mitford': {'n_is_sb': '0'},
 'nancy witcher astor': {'n_is_sb': '0'},
 'nandu': {'n_is_sb': '0'},
 'nanna': {'n_is_sb': '0'},
 'nanny-goat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nanomia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nansen': {'n_is_sb': '0'},
 'nanticoke': {'n_is_sb': '0'},
 'nanus': {'n_is_sb': '0'},
 'nan': {'n_is_sb': '0'},
 'naomi': {'n_is_sb': '0'},
 'napaea': {'n_is_sb': '0'},
 'napea': {'n_is_sb': '0'},
 'napier': {'n_is_sb': '2', 'n_is_sth': '2'},
 'napoleon bonaparte': {'n_is_sb': '0'},
 'napoleon iii': {'n_is_sb': '0'},
 'napoleon i': {'n_is_sb': '0'},
 'naprapath': {'n_is_sb': '0'},
 'napu': {'n_is_sb': '3', 'n_is_sth': '3'},
 'narcist': {'n_is_sb': '0'},
 'narcoleptic': {'n_is_sb': '0'},
 'narcotics agent': {'n_is_sb': '0'},
 'nark': {'n_is_sb': '0'},
 'narwal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'narwhale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'narwhal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nasalis larvatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nasalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nash': {'n_is_sb': '0'},
 'nasser': {'n_is_sb': '0'},
 'nast': {'n_is_sb': '0'},
 'nasua narica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nat turner': {'n_is_sb': '0'},
 'natalie wood': {'n_is_sb': '0'},
 'natator': {'n_is_sb': '0'},
 'nathan bailey': {'n_is_sb': '0'},
 'nathan birnbaum': {'n_is_sb': '0'},
 'nathan hale': {'n_is_sb': '0'},
 'nathaniel bailey': {'n_is_sb': '0'},
 'nathaniel bowditch': {'n_is_sb': '0'},
 'nathaniel currier': {'n_is_sb': '0'},
 'nathaniel hawthorne': {'n_is_sb': '0'},
 'national leader': {'n_is_sb': '0'},
 'nationalist leader': {'n_is_sb': '0'},
 'nationalist': {'n_is_sb': '0'},
 'native alaskan': {'n_is_sb': '0'},
 'native american': {'n_is_sb': '0'},
 'native australian': {'n_is_sb': '0'},
 'native bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'native cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'native hawaiian': {'n_is_sb': '0'},
 'native speaker': {'n_is_sb': '0'},
 'nativist': {'n_is_sb': '0'},
 'natrix maura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'natrix natrix': {'n_is_sb': '3', 'n_is_sth': '3'},
 'natrix sipedon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'natta': {'n_is_sb': '0'},
 'natterjack': {'n_is_sb': '3', 'n_is_sth': '3'},
 'natural scientist': {'n_is_sb': '0'},
 'naturalist': {'n_is_sb': '0'},
 'naturist': {'n_is_sb': '0'},
 'naturopath': {'n_is_sb': '0'},
 'naucrates ductor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nauruan': {'n_is_sb': '0'},
 'nautch girl': {'n_is_sb': '0'},
 'navaho': {'n_is_sb': '0'},
 'navajo': {'n_is_sb': '0', 'cap_word': 'Navajo'},
 'naval attache': {'n_is_sb': '0'},
 'naval commander': {'n_is_sb': '0'},
 'naval engineer': {'n_is_sb': '0'},
 'naval officer': {'n_is_sb': '0'},
 'navratilova': {'n_is_sb': '0'},
 'navvy': {'n_is_sb': '2', 'n_is_sth': '2'},
 'navy man': {'n_is_sb': '0'},
 'navy seal': {'n_is_sb': '0'},
 'nawab': {'n_is_sb': '0'},
 'naysayer': {'n_is_sb': '0'},
 'nazimova': {'n_is_sb': '0'},
 "ne'er-do-well": {'n_is_sb': '0'},
 'neandertal man': {'n_is_sb': '0'},
 'neandertal': {'n_is_sb': '0'},
 'neanderthal man': {'n_is_sb': '0'},
 'neanderthal': {'n_is_sb': '0'},
 'nebbech': {'n_is_sb': '0'},
 'nebbish': {'n_is_sb': '0'},
 'nebo': {'n_is_sb': '0'},
 'nebraskan': {'n_is_sb': '0'},
 'nebuchadnezzar ii': {'n_is_sb': '0'},
 'nebuchadnezzar': {'n_is_sb': '0'},
 'nebuchadrezzar ii': {'n_is_sb': '0'},
 'nebuchadrezzar': {'n_is_sb': '0'},
 'necessitarian': {'n_is_sb': '0'},
 'necker': {'n_is_sb': '0'},
 'necturus maculosus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'needer': {'n_is_sb': '0'},
 'needlefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'needlewoman': {'n_is_sb': '0'},
 'needleworker': {'n_is_sb': '0'},
 'neel': {'n_is_sb': '0'},
 'nefertiti': {'n_is_sb': '0'},
 'neftali ricardo reyes': {'n_is_sb': '0'},
 'negaprion brevirostris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'negativist': {'n_is_sb': '0'},
 'neglecter': {'n_is_sb': '0'},
 'negotiant': {'n_is_sb': '0'},
 'negotiator': {'n_is_sb': '0'},
 'negotiatress': {'n_is_sb': '0'},
 'negotiatrix': {'n_is_sb': '0'},
 'negress': {'n_is_sb': '0'},
 'negro race': {'n_is_sb': '0'},
 'negroid race': {'n_is_sb': '0'},
 'negroid': {'n_is_sb': '0'},
 'nehru': {'n_is_sb': '0'},
 'neil armstrong': {'n_is_sb': '0'},
 'neil simon': {'n_is_sb': '0'},
 'neisseria gonorrhoeae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nekton': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nell gwynne': {'n_is_sb': '0'},
 'nell gwynn': {'n_is_sb': '0'},
 'nell gywn': {'n_is_sb': '0'},
 'nellie bly': {'n_is_sb': '0'},
 'nellie ross': {'n_is_sb': '0'},
 'nellie tayloe ross': {'n_is_sb': '0'},
 'nelson algren': {'n_is_sb': '0'},
 'nelson mandela': {'n_is_sb': '0'},
 'nelson rolihlahla mandela': {'n_is_sb': '0'},
 'nelson': {'n_is_sb': '0'},
 'nematode worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nematode': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nemean lion': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nemertean': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nemertine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'neoceratodus forsteri': {'n_is_sb': '3', 'n_is_sth': '3'},
 'neoceratodus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'neoclassicist': {'n_is_sb': '0'},
 'neoconservative': {'n_is_sb': '0'},
 'neocon': {'n_is_sb': '0'},
 'neofiber alleni': {'n_is_sb': '3', 'n_is_sth': '3'},
 'neoliberal': {'n_is_sb': '0'},
 'neologist': {'n_is_sb': '0'},
 'neomys anomalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'neomys fodiens': {'n_is_sb': '3', 'n_is_sth': '3'},
 'neonate': {'n_is_sb': '0'},
 'neophron percnopterus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'neophron': {'n_is_sb': '3', 'n_is_sth': '3'},
 'neoplatonist': {'n_is_sb': '0'},
 'neopolitan': {'n_is_sb': '0'},
 'neotoma cinerea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'neotoma floridana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'neotoma fuscipes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nepalese': {'n_is_sb': '0'},
 'nephrops norvegicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nephthys': {'n_is_sb': '0'},
 'nereid': {'n_is_sb': '0'},
 'nereus': {'n_is_sb': '0'},
 'nergal': {'n_is_sb': '0'},
 'nerita peloronta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'neritid gastropod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'neritid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nernst': {'n_is_sb': '0'},
 'nero claudius caesar drusus germanicus': {'n_is_sb': '0'},
 'nerodia sipedon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nero': {'n_is_sb': '0'},
 'nerthus': {'n_is_sb': '0'},
 'neruda': {'n_is_sb': '0'},
 'nerva': {'n_is_sb': '2', 'n_is_sth': '2'},
 'nervi': {'n_is_sb': '2', 'n_is_sth': '2'},
 'nessie': {'n_is_sb': '0'},
 'nester': {'n_is_sb': '0'},
 'nestor notabilis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nestorius': {'n_is_sb': '0'},
 'netherlander': {'n_is_sb': '0'},
 'netkeeper': {'n_is_sb': '0'},
 'netminder': {'n_is_sb': '0'},
 'neumann': {'n_is_sb': '0'},
 'neurasthenic': {'n_is_sb': '0'},
 'neurobiologist': {'n_is_sb': '0'},
 'neurolinguist': {'n_is_sb': '0'},
 'neurologist': {'n_is_sb': '0'},
 'neuropteran': {'n_is_sb': '3', 'n_is_sth': '3'},
 'neuropteron': {'n_is_sb': '3', 'n_is_sth': '3'},
 'neuropterous insect': {'n_is_sb': '3', 'n_is_sth': '3'},
 'neuroscientist': {'n_is_sb': '0'},
 'neurosurgeon': {'n_is_sb': '0'},
 'neurotic': {'n_is_sb': '0'},
 'neurotrichus gibbsii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'neutralist': {'n_is_sb': '0'},
 'nevadan': {'n_is_sb': '0'},
 'nevelson': {'n_is_sb': '0'},
 'nevil shute norway': {'n_is_sb': '0'},
 'nevil shute': {'n_is_sb': '0'},
 'neville chamberlain': {'n_is_sb': '0'},
 'new dealer': {'n_is_sb': '0'},
 'new englander': {'n_is_sb': '0'},
 'new hampshirite': {'n_is_sb': '0'},
 'new jerseyan': {'n_is_sb': '0'},
 'new jerseyite': {'n_is_sb': '0'},
 'new waver': {'n_is_sb': '0'},
 'new world anteater': {'n_is_sb': '3', 'n_is_sth': '3'},
 'new world beaver': {'n_is_sb': '3', 'n_is_sth': '3'},
 'new world blackbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'new world chat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'new world coral snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'new world flycatcher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'new world goldfinch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'new world jay': {'n_is_sb': '3', 'n_is_sth': '3'},
 'new world least weasel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'new world monkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'new world mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'new world opah': {'n_is_sb': '3', 'n_is_sth': '3'},
 'new world oriole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'new world porcupine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'new world sparrow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'new world tapir': {'n_is_sb': '3', 'n_is_sth': '3'},
 'new world vulture': {'n_is_sb': '3', 'n_is_sth': '3'},
 'new world warbler': {'n_is_sb': '3', 'n_is_sth': '3'},
 'new yorker': {'n_is_sb': '0'},
 'new zealand wren': {'n_is_sb': '3', 'n_is_sth': '3'},
 'new zealander': {'n_is_sb': '0'},
 'newborn baby': {'n_is_sb': '0'},
 'newborn infant': {'n_is_sb': '0'},
 'newcomb': {'n_is_sb': '0'},
 'newfoundland': {'n_is_sb': '2', 'n_is_sth': '2'},
 'newman': {'n_is_sb': '0'},
 'news reader': {'n_is_sb': '2', 'n_is_sth': '2'},
 'newsagent': {'n_is_sb': '0'},
 'newscaster': {'n_is_sb': '0'},
 'newsdealer': {'n_is_sb': '0'},
 'newsmonger': {'n_is_sb': '0'},
 'newspaper columnist': {'n_is_sb': '0'},
 'newspaper critic': {'n_is_sb': '0'},
 'newspaper editor': {'n_is_sb': '0'},
 'newspaper publisher': {'n_is_sb': '0'},
 'newspaperwoman': {'n_is_sb': '0'},
 'newsreader': {'n_is_sb': '0'},
 'newsstand operator': {'n_is_sb': '0'},
 'newsvendor': {'n_is_sb': '0'},
 'newswoman': {'n_is_sb': '0'},
 'newswriter': {'n_is_sb': '0'},
 'newtonian': {'n_is_sb': '0', 'cap_word': 'Newtonian'},
 'next friend': {'n_is_sb': '0'},
 'next of kin': {'n_is_sb': '0'},
 'ney': {'n_is_sb': '2', 'n_is_sth': '2'},
 'nez perce': {'n_is_sb': '0'},
 'ngaio marsh': {'n_is_sb': '0'},
 'nganasan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'nguyen tat thanh': {'n_is_sb': '0'},
 'nibelung': {'n_is_sb': '0'},
 'nicaraguan': {'n_is_sb': '0'},
 'niccolo machiavelli': {'n_is_sb': '0'},
 'niccolo paganini': {'n_is_sb': '0'},
 'nicholas ii': {'n_is_sb': '0'},
 'nicholas i': {'n_is_sb': '0'},
 'nicholas vachel lindsay': {'n_is_sb': '0'},
 'nicholas': {'n_is_sb': '0'},
 'nicklaus': {'n_is_sb': '0'},
 'nicola amati': {'n_is_sb': '0'},
 'nicola sacco': {'n_is_sb': '0'},
 'nicolas de malebranche': {'n_is_sb': '0'},
 'nicolas leonard sadi carnot': {'n_is_sb': '0'},
 'nicolas poussin': {'n_is_sb': '0'},
 'nicolaus copernicus': {'n_is_sb': '0'},
 'nicolo amati': {'n_is_sb': '0'},
 'nicolson': {'n_is_sb': '0'},
 'niebuhr': {'n_is_sb': '0'},
 'niels abel': {'n_is_sb': '0'},
 'niels bohr': {'n_is_sb': '0'},
 'niels henrik abel': {'n_is_sb': '0'},
 'niels henrik david bohr': {'n_is_sb': '0'},
 'nielson': {'n_is_sb': '0'},
 'nietzsche': {'n_is_sb': '0'},
 'nigerian': {'n_is_sb': '0', 'cap_word': 'Nigerian'},
 'nigerien': {'n_is_sb': '0'},
 'niggard': {'n_is_sb': '0'},
 'nigga': {'n_is_sb': '0'},
 'niggler': {'n_is_sb': '0'},
 'night bird': {'n_is_sb': '0'},
 'night heron': {'n_is_sb': '3', 'n_is_sth': '3'},
 'night lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'night owl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'night porter': {'n_is_sb': '0'},
 'night raven': {'n_is_sb': '3', 'n_is_sth': '3'},
 'night rider': {'n_is_sb': '0'},
 'night snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'night watchman': {'n_is_sb': '0'},
 'nightbird': {'n_is_sb': '0'},
 'nightcrawler': {'n_is_sb': '0'},
 'nightjar': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nightrider': {'n_is_sb': '0'},
 'nightwalker': {'n_is_sb': '0'},
 'nigra': {'n_is_sb': '0'},
 'nihilist': {'n_is_sb': '0'},
 'nijinsky': {'n_is_sb': '0'},
 'nike': {'n_is_sb': '2', 'n_is_sth': '2'},
 'nikita khrushchev': {'n_is_sb': '0'},
 'nikita sergeyevich khrushchev': {'n_is_sb': '0'},
 'nikola tesla': {'n_is_sb': '0'},
 'nikolaas tinbergen': {'n_is_sb': '0'},
 'nikolai andreyevich rimski-korsakov': {'n_is_sb': '0'},
 'nikolai andreyevich rimsky-korsakov': {'n_is_sb': '0'},
 'nikolai ivanovich bukharin': {'n_is_sb': '0'},
 'nikolai ivanovich lobachevsky': {'n_is_sb': '0'},
 'nikolai lenin': {'n_is_sb': '0'},
 'nikolai vasilievich gogol': {'n_is_sb': '0'},
 'nile crocodile': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nilgai': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nilsson': {'n_is_sb': '0'},
 'nimby': {'n_is_sb': '0'},
 'nimitz': {'n_is_sb': '0'},
 'nimravus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'nimrod': {'n_is_sb': '0'},
 'nina': {'n_is_sb': '2', 'n_is_sth': '2'},
 'nine-banded armadillo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ningal': {'n_is_sb': '0'},
 'ningirsu': {'n_is_sb': '0'},
 'ningishzida': {'n_is_sb': '0'},
 'ninhursag': {'n_is_sb': '0'},
 'ninib': {'n_is_sb': '0'},
 'ninigino-mikoto': {'n_is_sb': '0'},
 'ninigi': {'n_is_sb': '0'},
 'ninja': {'n_is_sb': '0'},
 'ninkharsag': {'n_is_sb': '0'},
 'ninkhursag': {'n_is_sb': '0'},
 'nintoo': {'n_is_sb': '0'},
 'nintu': {'n_is_sb': '0'},
 'ninurta': {'n_is_sb': '0'},
 'nipponese': {'n_is_sb': '0'},
 'niqaabi': {'n_is_sb': '0'},
 'nitella': {'n_is_sb': '0'},
 'nitpicker': {'n_is_sb': '0'},
 'nitrate bacterium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nitric bacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nitric bacterium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nitrite bacterium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nitrobacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nitrobacterium': {'n_is_sb': '2', 'n_is_sth': '2'},
 'nitrosobacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nitrosomonas': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nitrous bacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nitrous bacterium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'njord': {'n_is_sb': '0'},
 'njorth': {'n_is_sb': '0'},
 'no-see-um': {'n_is_sb': '3', 'n_is_sth': '3'},
 'no-show': {'n_is_sb': '0'},
 'noah webster': {'n_is_sb': '0'},
 'noah': {'n_is_sb': '0'},
 'noam chomsky': {'n_is_sb': '0'},
 'nobel laureate': {'n_is_sb': '0'},
 'nobelist': {'n_is_sb': '0'},
 'noblewoman': {'n_is_sb': '0'},
 'noctambulist': {'n_is_sb': '0'},
 'noctiluca miliaris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'noctiluca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'noctuid moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'noctuid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'noc': {'n_is_sb': '2', 'n_is_sth': '2'},
 'noel coward': {'n_is_sb': '0'},
 'noemi': {'n_is_sb': '0'},
 'noether': {'n_is_sb': '0'},
 'noguchi': {'n_is_sb': '0'},
 'nomia melanderi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nominal head': {'n_is_sb': '0'},
 'nominator': {'n_is_sb': '0'},
 'nominee': {'n_is_sb': '0'},
 'non-catholic': {'n_is_sb': '0'},
 'non-christian priest': {'n_is_sb': '0'},
 'non-jew': {'n_is_sb': '0'},
 'non-resistant': {'n_is_sb': '0'},
 'nonachiever': {'n_is_sb': '0'},
 'nonagenarian': {'n_is_sb': '0'},
 'nonattender': {'n_is_sb': '0'},
 'nona': {'n_is_sb': '0'},
 'nonbeliever': {'n_is_sb': '0'},
 'noncandidate': {'n_is_sb': '0'},
 'noncitizen': {'n_is_sb': '0'},
 'noncombatant': {'n_is_sb': '0'},
 'noncommissioned officer': {'n_is_sb': '0'},
 'noncompliant': {'n_is_sb': '0'},
 'noncom': {'n_is_sb': '0'},
 'nonconformist': {'n_is_sb': '0'},
 'nondrinker': {'n_is_sb': '0'},
 'nondriver': {'n_is_sb': '0'},
 'nonmember': {'n_is_sb': '0'},
 'nonpareil': {'n_is_sb': '2', 'n_is_sth': '2'},
 'nonparticipant': {'n_is_sb': '0'},
 'nonpasserine bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nonperson': {'n_is_sb': '0'},
 'nonreader': {'n_is_sb': '0'},
 'nonreligious person': {'n_is_sb': '0'},
 'nonsmoker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'nonstarter': {'n_is_sb': '0'},
 'nonsuch': {'n_is_sb': '2', 'n_is_sth': '2'},
 'nonworker': {'n_is_sb': '0'},
 'nootka': {'n_is_sb': '0'},
 'norbert wiener': {'n_is_sb': '0'},
 'norfolk terrier': {'n_is_sb': '0'},
 'norma jean baker': {'n_is_sb': '0'},
 'normal dwarf': {'n_is_sb': '0'},
 'normaliser': {'n_is_sb': '0'},
 'normalizer': {'n_is_sb': '0'},
 'norman jewison': {'n_is_sb': '0'},
 'norman mailer': {'n_is_sb': '0'},
 'norman mattoon thomas': {'n_is_sb': '0'},
 'norman rockwell': {'n_is_sb': '0'},
 'norman thomas': {'n_is_sb': '0'},
 'norman': {'n_is_sb': '0'},
 'norn': {'n_is_sb': '0'},
 'norrish': {'n_is_sb': '0'},
 'norris': {'n_is_sb': '0'},
 'norse deity': {'n_is_sb': '0'},
 'norseman': {'n_is_sb': '0'},
 'norse': {'n_is_sb': '2', 'n_is_sth': '2'},
 'north american indian': {'n_is_sb': '0'},
 'north american': {'n_is_sb': '0'},
 'north carolinian': {'n_is_sb': '0'},
 'north dakotan': {'n_is_sb': '0'},
 'north korean': {'n_is_sb': '0'},
 'northern baptist': {'n_is_sb': '0'},
 'northern bobwhite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'northern bog lemming': {'n_is_sb': '3', 'n_is_sth': '3'},
 'northern casque-headed frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'northern cricket frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'northern flying squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'northern harrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'northern lobster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'northern mammoth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'northern oriole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'northern parula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'northern phalarope': {'n_is_sb': '3', 'n_is_sth': '3'},
 'northern pike': {'n_is_sb': '3', 'n_is_sth': '3'},
 'northern pocket gopher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'northern porgy': {'n_is_sb': '3', 'n_is_sth': '3'},
 'northern scup': {'n_is_sb': '3', 'n_is_sth': '3'},
 'northern sea robin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'northern shrike': {'n_is_sb': '3', 'n_is_sth': '3'},
 'northern snakehead': {'n_is_sb': '3', 'n_is_sth': '3'},
 'northern storm petrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'northern whiting': {'n_is_sb': '3', 'n_is_sth': '3'},
 'northerner': {'n_is_sb': '0'},
 'northman': {'n_is_sb': '0'},
 'northrop frye': {'n_is_sb': '0'},
 'northrop': {'n_is_sb': '0'},
 'norway lobster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'norway rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'norwegian elkhound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'norwich terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nosey-parker': {'n_is_sb': '0'},
 'nosher': {'n_is_sb': '0'},
 'nostradamus': {'n_is_sb': '0'},
 'nosy-parker': {'n_is_sb': '0'},
 'notability': {'n_is_sb': '0'},
 'notary public': {'n_is_sb': '0'},
 'notechis scutatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'notemigonus crysoleucas': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nothosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'noticer': {'n_is_sb': '0'},
 'notomys': {'n_is_sb': '3', 'n_is_sth': '3'},
 'notonecta undulata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'notonecta': {'n_is_sb': '2', 'n_is_sth': '2'},
 'notophthalmus viridescens': {'n_is_sb': '3', 'n_is_sth': '3'},
 'notornis mantelli': {'n_is_sb': '3', 'n_is_sth': '3'},
 'notornis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'notoryctus typhlops': {'n_is_sb': '3', 'n_is_sth': '3'},
 'notropis atherinoides': {'n_is_sb': '3', 'n_is_sth': '3'},
 'notropis cornutus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nouveau-riche': {'n_is_sb': '0'},
 'novillero': {'n_is_sb': '0'},
 'nox': {'n_is_sb': '2', 'n_is_sth': '2'},
 'noyes': {'n_is_sb': '0'},
 'np': {'n_is_sb': '2', 'n_is_sth': '2'},
 'nubian': {'n_is_sb': '0'},
 'nucifraga caryocatactes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nucifraga columbiana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nuclear chemist': {'n_is_sb': '0'},
 'nuclear physicist': {'n_is_sb': '0'},
 'nuda': {'n_is_sb': '2', 'n_is_sth': '2'},
 'nude mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nude person': {'n_is_sb': '0'},
 'nude': {'n_is_sb': '2', 'n_is_sth': '2'},
 'nudger': {'n_is_sb': '2', 'n_is_sth': '2'},
 'nudibranch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nudist': {'n_is_sb': '0'},
 'nudnick': {'n_is_sb': '0'},
 'nudnik': {'n_is_sb': '0'},
 'nuffield': {'n_is_sb': '0'},
 'nullifier': {'n_is_sb': '0'},
 'nullipara': {'n_is_sb': '0'},
 'numbat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'number cruncher': {'n_is_sb': '0'},
 'number one': {'n_is_sb': '2', 'n_is_sth': '2'},
 'number theorist': {'n_is_sb': '0'},
 'numbfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'numenius arquata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'numenius borealis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'numen': {'n_is_sb': '0'},
 'numerologist': {'n_is_sb': '0'},
 'numida meleagris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'numidian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'numismatist': {'n_is_sb': '0'},
 'numismatologist': {'n_is_sb': '0'},
 'nummulite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'numskull': {'n_is_sb': '0'},
 'nureyev': {'n_is_sb': '0'},
 'nurse clinician': {'n_is_sb': '0'},
 'nurse practitioner': {'n_is_sb': '0'},
 'nurse shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 "nurse's aide": {'n_is_sb': '0'},
 'nurse-midwife': {'n_is_sb': '0'},
 'nurseling': {'n_is_sb': '2', 'n_is_sth': '2'},
 'nursemaid': {'n_is_sb': '0'},
 'nurseryman': {'n_is_sb': '0'},
 'nurser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'nursing aide': {'n_is_sb': '0'},
 'nursling': {'n_is_sb': '2', 'n_is_sth': '2'},
 'nusku': {'n_is_sb': '0'},
 'nut case': {'n_is_sb': '0'},
 'nutcase': {'n_is_sb': '0'},
 'nuthatch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nutritionist': {'n_is_sb': '0'},
 'nutter': {'n_is_sb': '0'},
 'nyala': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nyctanassa violacea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nyctereutes procyonides': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nyctereutes': {'n_is_sb': '2', 'n_is_sth': '2'},
 'nycticebus pygmaeus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nycticebus tardigradua': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nycticorax nycticorax': {'n_is_sb': '2', 'n_is_sth': '2'},
 'nylghai': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nylghau': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nymphalid butterfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nymphalid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nymphalis antiopa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nymphet': {'n_is_sb': '0'},
 'nymphicus hollandicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'nympholept': {'n_is_sb': '0'},
 'nymphomaniac': {'n_is_sb': '0'},
 'nympho': {'n_is_sb': '0'},
 'nyx': {'n_is_sb': '0'},
 "o'brien": {'n_is_sb': '0'},
 "o'casey": {'n_is_sb': '0'},
 "o'connor": {'n_is_sb': '0'},
 "o'flaherty": {'n_is_sb': '0'},
 "o'hara": {'n_is_sb': '0'},
 "o'keeffe": {'n_is_sb': '0'},
 "o'neill": {'n_is_sb': '0'},
 "o'toole": {'n_is_sb': '0'},
 'o. henry': {'n_is_sb': '0'},
 'oakley': {'n_is_sb': '2', 'n_is_sth': '2'},
 'oarfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oarsman': {'n_is_sb': '0'},
 'oarswoman': {'n_is_sb': '0'},
 'oates': {'n_is_sb': '0'},
 'obadiah': {'n_is_sb': '0'},
 'objector': {'n_is_sb': '0'},
 'oblate': {'n_is_sb': '0'},
 'obligate anaerobe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'obliger': {'n_is_sb': '0'},
 'oboist': {'n_is_sb': '0'},
 'obscurantist': {'n_is_sb': '0'},
 'obstetrical toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'obstetrician': {'n_is_sb': '0'},
 'obstructer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'obstructionist': {'n_is_sb': '0'},
 'obstructor': {'n_is_sb': '2', 'n_is_sth': '2'},
 'occam': {'n_is_sb': '0'},
 'occultist': {'n_is_sb': '0'},
 'occupant': {'n_is_sb': '0'},
 'occupier': {'n_is_sb': '0'},
 'ocean perch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ocean pout': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ocean sunfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oceanaut': {'n_is_sb': '0'},
 'oceanic bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oceanic bonito': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oceanic whitetip shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oceanid': {'n_is_sb': '0'},
 'oceanites oceanicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oceanographer': {'n_is_sb': '0'},
 'oceanus': {'n_is_sb': '0'},
 'ocellated turkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ochoa': {'n_is_sb': '0'},
 'ochotona collaris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ochotona princeps': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ochs': {'n_is_sb': '0'},
 'ockham': {'n_is_sb': '0'},
 'octavian': {'n_is_sb': '0'},
 'octogenarian': {'n_is_sb': '0'},
 'octopod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'octoroon': {'n_is_sb': '0'},
 'oculist': {'n_is_sb': '0'},
 'ocyurus chrysurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'odalisque': {'n_is_sb': '0'},
 'odd fellow': {'n_is_sb': '0'},
 'odd fish': {'n_is_sb': '0'},
 'odd hassel': {'n_is_sb': '0'},
 'odd man out': {'n_is_sb': '2', 'n_is_sth': '2'},
 'odd-job man': {'n_is_sb': '0'},
 'odd-toed ungulate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'odds-maker': {'n_is_sb': '0'},
 'odets': {'n_is_sb': '0'},
 'odin': {'n_is_sb': '0'},
 'odo of lagery': {'n_is_sb': '0'},
 'odoacer': {'n_is_sb': '0'},
 'odobenus divergens': {'n_is_sb': '3', 'n_is_sth': '3'},
 'odobenus rosmarus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'odocoileus hemionus columbianus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'odocoileus hemionus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'odocoileus virginianus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'odonate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'odontaspis taurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'odovacar': {'n_is_sb': '0'},
 'odovakar': {'n_is_sb': '0'},
 'odysseus': {'n_is_sb': '0'},
 'oecanthus fultoni': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oedipus rex': {'n_is_sb': '0'},
 'oedipus': {'n_is_sb': '0'},
 'oengus': {'n_is_sb': '0'},
 'oenologist': {'n_is_sb': '0'},
 'oenophile': {'n_is_sb': '0'},
 'oenophilist': {'n_is_sb': '0'},
 'oersted': {'n_is_sb': '0'},
 'oestrus ovis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oestrus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'offenbach': {'n_is_sb': '0'},
 'offerer': {'n_is_sb': '0'},
 'offeror': {'n_is_sb': '0'},
 'office boy': {'n_is_sb': '0'},
 'office-bearer': {'n_is_sb': '0'},
 'official emissary': {'n_is_sb': '0'},
 'ofo': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ogalala': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ogden nash': {'n_is_sb': '0'},
 'ogden': {'n_is_sb': '0'},
 'oglala': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ogler': {'n_is_sb': '0'},
 'ogress': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ogre': {'n_is_sb': '0'},
 'ohioan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'oil beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oil geologist': {'n_is_sb': '0'},
 'oil painter': {'n_is_sb': '0'},
 'oil rigger': {'n_is_sb': '0'},
 'oil tycoon': {'n_is_sb': '0'},
 'oil-industry analyst': {'n_is_sb': '0'},
 'oilbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oilfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oilman': {'n_is_sb': '0'},
 'ojibway': {'n_is_sb': '0'},
 'ojibwa': {'n_is_sb': '0'},
 'okapia johnstoni': {'n_is_sb': '3', 'n_is_sth': '3'},
 'okapi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'okenfuss': {'n_is_sb': '0'},
 'oken': {'n_is_sb': '0'},
 'olaf ii': {'n_is_sb': '0'},
 'olav ii': {'n_is_sb': '0'},
 'old bag': {'n_is_sb': '2', 'n_is_sth': '2'},
 'old boy': {'n_is_sb': '0'},
 'old bullion': {'n_is_sb': '0'},
 'old catholic': {'n_is_sb': '0'},
 'old codger': {'n_is_sb': '0'},
 'old english sheepdog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'old geezer': {'n_is_sb': '0'},
 'old hand': {'n_is_sb': '0'},
 'old hickory': {'n_is_sb': '2', 'n_is_sth': '2'},
 'old lady': {'n_is_sb': '0'},
 'old maid': {'n_is_sb': '0'},
 'old man': {'n_is_sb': '0'},
 'old master': {'n_is_sb': '0'},
 'old nick': {'n_is_sb': '0'},
 'old person': {'n_is_sb': '0'},
 'old salt': {'n_is_sb': '2', 'n_is_sth': '2'},
 'old squaw': {'n_is_sb': '3', 'n_is_sth': '3'},
 'old stager': {'n_is_sb': '0'},
 'old woman': {'n_is_sb': '0'},
 'old world beaver': {'n_is_sb': '3', 'n_is_sth': '3'},
 'old world buffalo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'old world chat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'old world coot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'old world coral snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'old world crayfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'old world flycatcher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'old world jay': {'n_is_sb': '3', 'n_is_sth': '3'},
 'old world least weasel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'old world monkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'old world oriole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'old world porcupine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'old world quail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'old world rabbit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'old world robin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'old world scops owl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'old world vulture': {'n_is_sb': '3', 'n_is_sth': '3'},
 'old world warbler': {'n_is_sb': '3', 'n_is_sth': '3'},
 'old world white pelican': {'n_is_sb': '3', 'n_is_sth': '3'},
 'old-age pensioner': {'n_is_sb': '0'},
 'oldenberg': {'n_is_sb': '0'},
 'oldfield': {'n_is_sb': '0'},
 'oldtimer': {'n_is_sb': '0'},
 'oldwench': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oldwife': {'n_is_sb': '2', 'n_is_sth': '2'},
 'olga korbut': {'n_is_sb': '0'},
 'oligochaete worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oligochaete': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oligoplites': {'n_is_sb': '0'},
 'olive ridley': {'n_is_sb': '0'},
 'oliver cromwell': {'n_is_sb': '0'},
 'oliver goldsmith': {'n_is_sb': '0'},
 'oliver hardy': {'n_is_sb': '0'},
 'oliver hazard perry': {'n_is_sb': '0'},
 'oliver heaviside': {'n_is_sb': '0'},
 'oliver stone': {'n_is_sb': '0'},
 'oliver wendell holmes jr.': {'n_is_sb': '0'},
 'oliver wendell holmes': {'n_is_sb': '0'},
 'oliver': {'n_is_sb': '0'},
 'olivier': {'n_is_sb': '0'},
 'olmec': {'n_is_sb': '0'},
 'olmsted': {'n_is_sb': '0'},
 'olm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'olympian': {'n_is_sb': '0', 'cap_word': 'Olympian'},
 'olympic god': {'n_is_sb': '0'},
 'olympic salamander': {'n_is_sb': '3', 'n_is_sth': '3'},
 'omaha': {'n_is_sb': '2', 'n_is_sth': '2'},
 'omani': {'n_is_sb': '0'},
 'omar bradley': {'n_is_sb': '0'},
 'omar khayyam': {'n_is_sb': '0'},
 'omar nelson bradley': {'n_is_sb': '0'},
 'ombudsman': {'n_is_sb': '0'},
 'omomyid group': {'n_is_sb': '0'},
 'onager': {'n_is_sb': '2', 'n_is_sth': '2'},
 'onanist': {'n_is_sb': '0'},
 'onchorynchus kisutch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'onchorynchus nerka': {'n_is_sb': '3', 'n_is_sth': '3'},
 'onchorynchus tshawtscha': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oncologist': {'n_is_sb': '0'},
 'ondaatje': {'n_is_sb': '0'},
 'ondatra zibethica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'one of the boys': {'n_is_sb': '0'},
 'oneida': {'n_is_sb': '2', 'n_is_sth': '2'},
 'oneiromancer': {'n_is_sb': '0'},
 'onion louse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'onion thrips': {'n_is_sb': '3', 'n_is_sth': '3'},
 'onion yellow-dwarf virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'onomancer': {'n_is_sb': '0'},
 'onondaga': {'n_is_sb': '0'},
 'ono': {'n_is_sb': '0'},
 'onsager': {'n_is_sb': '0'},
 'onychogalea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oom paul kruger': {'n_is_sb': '0'},
 'oort': {'n_is_sb': '0'},
 'opah': {'n_is_sb': '3', 'n_is_sth': '3'},
 'opel': {'n_is_sb': '0'},
 'openbill': {'n_is_sb': '3', 'n_is_sth': '3'},
 'opera star': {'n_is_sb': '0'},
 'operagoer': {'n_is_sb': '0'},
 'operatic star': {'n_is_sb': '0'},
 'operating surgeon': {'n_is_sb': '0'},
 'opheodrys aestivus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'opheodrys vernalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ophidian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ophidia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ophiodon elongatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ophiodon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ophiophagus hannan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ophisaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ophthalmologist': {'n_is_sb': '0'},
 'opisthocomus hoazin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'opium addict': {'n_is_sb': '0'},
 'opium taker': {'n_is_sb': '0'},
 'opossum rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'opossum shrimp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'opossum': {'n_is_sb': '2', 'n_is_sth': '2'},
 'oppenheimer': {'n_is_sb': '0'},
 'opportunist': {'n_is_sb': '0'},
 'opposer': {'n_is_sb': '0'},
 'opsanus tau': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ops': {'n_is_sb': '0'},
 'optician': {'n_is_sb': '0'},
 'optimist': {'n_is_sb': '0'},
 'optometrist': {'n_is_sb': '0'},
 'oral roberts': {'n_is_sb': '0'},
 'orange bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'orange horseshoe bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'orange tortrix': {'n_is_sb': '3', 'n_is_sth': '3'},
 'orangeman': {'n_is_sb': '0'},
 'orangutang': {'n_is_sb': '3', 'n_is_sth': '3'},
 'orbison': {'n_is_sb': '0'},
 'orca': {'n_is_sb': '0'},
 'orchard oriole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'orchestrator': {'n_is_sb': '0'},
 'orcinus orca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'orcus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'orczy': {'n_is_sb': '0'},
 'ord kangaroo rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ordainer': {'n_is_sb': '0'},
 'order actinaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order actiniaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order actinomycetales': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order actinomyxidia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order aepyorniformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order alcyonaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order amoebida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order amoebina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order amphipoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order anacanthini': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order anaspida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order anguilliformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order anoplura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order anostraca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order anseriformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order anura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order aplacophora': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order apodes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order apodiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order apterygiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order araneae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order araneida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order artiodactyla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order batoidei': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order batrachia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order belemnoidea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order berycomorphi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order branchiura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order caprimulgiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order carnivora': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order casuariiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order caudata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order cestida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order cetacea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order charadriiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order charales': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order chelonethida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order chelonia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order chiroptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order chlorococcales': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order ciconiiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order cilioflagellata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order coccidia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order coleoptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order collembola': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order columbiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order colymbiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order conodonta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order conodontophorida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order coraciiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order corrodentia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order crocodilia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order crocodylia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order cuculiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order cyclostomata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order cydippea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order cydippida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order cydippidea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order cypriniformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order decapoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order dermaptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order dermoptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order dictyoptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order dinocerata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order dinoflagellata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order dinornithiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order diptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order discocephali': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order edentata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order embiodea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order embioptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order ephemerida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order ephemeroptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order eubacteriales': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order euphausiacea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order eurypterida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order exocycloida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order falconiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order foraminifera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order fucales': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order gadiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order galliformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order ganoidei': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order gaviiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order geophilomorpha': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order gregarinida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order gruiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order gymnophiona': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order haemosporidia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order haplosporidia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order heliozoa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order hemiptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order heterosomata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order heterotrichales': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order hymenoptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order hypermastigina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order hyracoidea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order ichthyosauria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order ictodosauria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order insectivora': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order insessores': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order isopoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order isoptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order isospondyli': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order lagomorpha': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order laminariales': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order lepidoptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order lobata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order loricata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order madreporaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order mallophaga': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order mantophasmatodea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order marsupialia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order mecoptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order monotremata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order myaceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order mycoplasmatales': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order mycrosporidia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order mysidacea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order myxobacterales': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order myxobacteriales': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order myxobacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order myxosporidia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order neuroptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order notostraca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order nudibranchia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order octopoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order odonata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order oedogoniales': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order opiliones': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order ornithischia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order orthoptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order ostariophysi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order ostracodermi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order passeriformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order pectinibranchia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order pediculati': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order pedipalpi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order pelecaniformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order pelycosauria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order perciformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order percomorphi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order perissodactyla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order phalangida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order phasmatodea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order phasmida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order pholidota': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order picariae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order piciformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order platyctenea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order plecoptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order plectognathi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order pleuronectiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order podicipediformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order podicipitiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order polymastigina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order primates': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order proboscidea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order procellariiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order protura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order pseudomonadales': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order pseudoscorpiones': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order pseudoscorpionida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order psittaciformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order psocoptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order pterosauria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order pulmonata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order pycnogonida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order radiolaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order rajiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order raptores': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order rheiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order rhynchocephalia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order rickettsiales': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order rodentia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order salientia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order sarcosporidia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order saurischia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order sauropterygia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order scandentia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order scleroparei': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order scorpionida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order siluriformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order siphonaptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order siphonophora': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order sirenia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order solenichthyes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order solenogastres': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order spatangoida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order sphenisciformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order spirochaetales': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order squamata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order stegocephalia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order stereospondyli': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order stomatopoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order strigiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order struthioniformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order synentognathi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order temnospondyli': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order testacea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order testudinata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order testudines': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order tetraodontiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order thecodontia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order therapsida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order thysanoptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order thysanura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order tinamiformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order torpediniformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order trichoptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order trogoniformes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order tubulidentata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order ulvales': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order urodella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order uropygi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order volvocales': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order xiphosura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order zeomorphi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order zygnemales': {'n_is_sb': '3', 'n_is_sth': '3'},
 'order zygnematales': {'n_is_sb': '3', 'n_is_sth': '3'},
 'orderer': {'n_is_sb': '0'},
 'orderly sergeant': {'n_is_sb': '0'},
 'ordinand': {'n_is_sb': '0'},
 'oread': {'n_is_sb': '0'},
 'oreamnos americanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'orectolobus barbatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'orectolobus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'oregonian': {'n_is_sb': '0'},
 'oreortyx picta palmeri': {'n_is_sb': '3', 'n_is_sth': '3'},
 'orestes': {'n_is_sb': '0'},
 'orff': {'n_is_sb': '0'},
 'organ donor': {'n_is_sb': '0'},
 'organ-grinder': {'n_is_sb': '0'},
 'organiser': {'n_is_sb': '0'},
 'organist': {'n_is_sb': '0'},
 'organization man': {'n_is_sb': '0'},
 'organizer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'oriental beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oriental cockroach': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oriental person': {'n_is_sb': '0'},
 'oriental roach': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oriental scops owl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'orientalist': {'n_is_sb': '0'},
 'oriental': {'n_is_sb': '0'},
 'origen': {'n_is_sb': '0'},
 'oriolus oriolus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oriya': {'n_is_sb': '0'},
 'orlando di lasso': {'n_is_sb': '0'},
 'orleanist': {'n_is_sb': '0'},
 'ormandy': {'n_is_sb': '0'},
 'ormazd': {'n_is_sb': '0'},
 'ormer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ormuzd': {'n_is_sb': '0'},
 'ornamentalist': {'n_is_sb': '0'},
 'ornithischian dinosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ornithischian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ornithologist': {'n_is_sb': '0'},
 'ornithomimida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ornithopod dinosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ornithopod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ornithorhynchus anatinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ornithorhynchus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'orozco': {'n_is_sb': '0'},
 'orpheus': {'n_is_sb': '0'},
 'orpington': {'n_is_sb': '3', 'n_is_sth': '3'},
 'orr': {'n_is_sb': '0'},
 'orson welles': {'n_is_sb': '0'},
 'ortega y gasset': {'n_is_sb': '0'},
 'ortega': {'n_is_sb': '0'},
 'orthodontist': {'n_is_sb': '0'},
 'orthodox jew': {'n_is_sb': '0'},
 'orthoepist': {'n_is_sb': '0'},
 'orthomyxovirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'orthopaedist': {'n_is_sb': '0'},
 'orthopedist': {'n_is_sb': '0'},
 'orthopristis chrysopterus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'orthopteran': {'n_is_sb': '3', 'n_is_sth': '3'},
 'orthopteron': {'n_is_sb': '3', 'n_is_sth': '3'},
 'orthopterous insect': {'n_is_sb': '3', 'n_is_sth': '3'},
 'orthoptist': {'n_is_sb': '0'},
 'orthotomus sutorius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'orthotomus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ortilis vetula macalli': {'n_is_sb': '0'},
 'ortolan bunting': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ortolan': {'n_is_sb': '0'},
 'ortygan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'orville wright': {'n_is_sb': '0'},
 'orwell': {'n_is_sb': '0'},
 'orycteropus afer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oryctolagus cuniculus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oryctolagus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oryx gazella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oryzomys palustris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'osage': {'n_is_sb': '0'},
 'osama bin laden': {'n_is_sb': '0'},
 'osborne': {'n_is_sb': '0'},
 'oscan': {'n_is_sb': '0'},
 "oscar fingal o'flahertie wills wilde": {'n_is_sb': '0'},
 'oscar hammerstein ii': {'n_is_sb': '0'},
 'oscar hammerstein': {'n_is_sb': '0'},
 'oscar palmer robertson': {'n_is_sb': '0'},
 'oscar robertson': {'n_is_sb': '0'},
 'oscar wilde': {'n_is_sb': '0'},
 'oscine bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oscines': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oscine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'osculator': {'n_is_sb': '2', 'n_is_sth': '2'},
 'osip emilevich mandelstam': {'n_is_sb': '0'},
 'osip mandelstam': {'n_is_sb': '0'},
 'osiris': {'n_is_sb': '0'},
 'osman i': {'n_is_sb': '0'},
 'osmanli': {'n_is_sb': '0'},
 'osmerus eperlanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'osmerus mordax': {'n_is_sb': '3', 'n_is_sth': '3'},
 'osteopathist': {'n_is_sb': '0'},
 'osteopath': {'n_is_sb': '0'},
 'osteostracan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ostiarius': {'n_is_sb': '0'},
 'ostiary': {'n_is_sb': '0'},
 'ostracod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ostrea gigas': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ostrogoth': {'n_is_sb': '0'},
 'ostwald': {'n_is_sb': '0'},
 'ostyak-samoyed': {'n_is_sb': '0'},
 'ostyak': {'n_is_sb': '0'},
 'oswald spengler': {'n_is_sb': '0'},
 'oswald veblen': {'n_is_sb': '0'},
 'oswald': {'n_is_sb': '0'},
 'otaria byronia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'othman i': {'n_is_sb': '0'},
 'otho i': {'n_is_sb': '0'},
 'otides': {'n_is_sb': '3', 'n_is_sth': '3'},
 'otididae': {'n_is_sb': '2', 'n_is_sth': '2'},
 'otis skinner': {'n_is_sb': '0'},
 'otis tarda': {'n_is_sb': '0'},
 'otis': {'n_is_sb': '0'},
 'otoe': {'n_is_sb': '0'},
 'otolaryngologist': {'n_is_sb': '0'},
 'otologist': {'n_is_sb': '0'},
 'otorhinolaryngologist': {'n_is_sb': '0'},
 'oto': {'n_is_sb': '0'},
 'otter hound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'otter shrew': {'n_is_sb': '3', 'n_is_sth': '3'},
 'otterhound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ottmar mergenthaler': {'n_is_sb': '0'},
 'otto frisch': {'n_is_sb': '0'},
 'otto fritz meyerhof': {'n_is_sb': '0'},
 'otto hahn': {'n_is_sb': '0'},
 'otto heinrich warburg': {'n_is_sb': '0'},
 'otto i': {'n_is_sb': '0'},
 'otto jespersen': {'n_is_sb': '0'},
 'otto loewi': {'n_is_sb': '0'},
 'otto meyerhof': {'n_is_sb': '0'},
 'otto neumann sverdrup': {'n_is_sb': '0'},
 'otto robert frisch': {'n_is_sb': '0'},
 'otto the great': {'n_is_sb': '0'},
 'otto von bismarck': {'n_is_sb': '0'},
 'otto wagner': {'n_is_sb': '0'},
 'ottoman turk': {'n_is_sb': '0'},
 'ottoman': {'n_is_sb': '0'},
 'ottorino respighi': {'n_is_sb': '0'},
 'otus asio': {'n_is_sb': '3', 'n_is_sth': '3'},
 'otus scops': {'n_is_sb': '3', 'n_is_sth': '3'},
 'otus sunia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ouranopithecus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ouranos': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ousel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'out-and-outer': {'n_is_sb': '0'},
 'outcaste': {'n_is_sb': '0'},
 'outdoor man': {'n_is_sb': '0'},
 'outdoorsman': {'n_is_sb': '0'},
 'outdoorswoman': {'n_is_sb': '0'},
 'outfielder': {'n_is_sb': '0'},
 'outfitter': {'n_is_sb': '0'},
 'outgoer': {'n_is_sb': '0'},
 'outpatient': {'n_is_sb': '0'},
 'outrider': {'n_is_sb': '0'},
 'ouzel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ovalipes ocellatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ovenbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'overachiever': {'n_is_sb': '0'},
 'overcomer': {'n_is_sb': '0'},
 'overnighter': {'n_is_sb': '0'},
 'ovibos moschatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ovid': {'n_is_sb': '0'},
 'ovis ammon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ovis aries': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ovis canadensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ovis montana dalli': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ovis musimon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ovis poli': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ovis vignei': {'n_is_sb': '3', 'n_is_sth': '3'},
 'owen glendower': {'n_is_sb': '0'},
 'owen wister': {'n_is_sb': '0'},
 'owens': {'n_is_sb': '0'},
 'owlet moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'owlet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'owner-driver': {'n_is_sb': '0'},
 'owner-occupier': {'n_is_sb': '0'},
 'oxonian': {'n_is_sb': '0'},
 'oxylebius pictus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oxyura jamaicensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oxyuranus scutellatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oyabun': {'n_is_sb': '0'},
 'oyster catcher': {'n_is_sb': '0'},
 'oyster crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oyster fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oyster shell': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oyster-fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oystercatcher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'oysterfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ozawa': {'n_is_sb': '0'},
 'p. g. wodehouse': {'n_is_sb': '0'},
 'p. p. von mauser': {'n_is_sb': '0'},
 'p. t. barnum': {'n_is_sb': '0'},
 'p.o.': {'n_is_sb': '0'},
 'pablo casals': {'n_is_sb': '0'},
 'pablo neruda': {'n_is_sb': '0'},
 'pablo picasso': {'n_is_sb': '0'},
 'pacer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pacha': {'n_is_sb': '0'},
 'pachuco': {'n_is_sb': '0'},
 'pachycephalosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pachycephalosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pachyderm': {'n_is_sb': '0'},
 'pacific bonito': {'n_is_sb': '0'},
 'pacific bottlenose dolphin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pacific cod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pacific giant salamander': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pacific halibut': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pacific herring': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pacific newt': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pacific ridley': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pacific sardine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pacific spiny dogfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pacific sturgeon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pacific tree toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pacific tripletail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pacific walrus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pacificist': {'n_is_sb': '0'},
 'pacifier': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pacifist': {'n_is_sb': '0'},
 'pack animal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pack rat': {'n_is_sb': '0'},
 'packhorse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'packman': {'n_is_sb': '0'},
 'packrat': {'n_is_sb': '2', 'n_is_sth': '2'},
 'padda oryzivora': {'n_is_sb': '3', 'n_is_sth': '3'},
 'padder': {'n_is_sb': '2', 'n_is_sth': '2'},
 'paddlefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'paddler': {'n_is_sb': '0'},
 'paddymelon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pademelon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'paderewski': {'n_is_sb': '0'},
 'paederast': {'n_is_sb': '0'},
 'paediatrician': {'n_is_sb': '0'},
 'paedophile': {'n_is_sb': '0'},
 'paganini': {'n_is_sb': '0'},
 'pageboy': {'n_is_sb': '0'},
 'pagellus centrodontus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'paget': {'n_is_sb': '0'},
 'pagophila eburnea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pagophilus groenlandicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pagrus pagrus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pahlavi': {'n_is_sb': '0'},
 'pahlevi': {'n_is_sb': '0'},
 'paige': {'n_is_sb': '0'},
 'pain in the neck': {'n_is_sb': '0'},
 'paine': {'n_is_sb': '0'},
 'painted beauty': {'n_is_sb': '3', 'n_is_sth': '3'},
 'painted greenling': {'n_is_sb': '3', 'n_is_sth': '3'},
 'painted sandgrouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'painted terrapin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'painted tortoise': {'n_is_sb': '3', 'n_is_sth': '3'},
 'painted turtle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'paiute': {'n_is_sb': '0'},
 'pakistani': {'n_is_sb': '0', 'cap_word': 'Pakistani'},
 'palaemon australis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'palaemon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'palaeontologist': {'n_is_sb': '0'},
 'palatine': {'n_is_sb': '0'},
 'pale chrysanthemum aphid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'paleacrita vernata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'paleacrita': {'n_is_sb': '3', 'n_is_sth': '3'},
 'paleo-american': {'n_is_sb': '0'},
 'paleo-amerind': {'n_is_sb': '0'},
 'paleo-indian': {'n_is_sb': '0'},
 'paleontologist': {'n_is_sb': '0'},
 'palestinian arab': {'n_is_sb': '0'},
 'palestinian': {'n_is_sb': '0', 'cap_word': 'Palestinian'},
 'palestrina': {'n_is_sb': '0'},
 'palfrey': {'n_is_sb': '2', 'n_is_sth': '2'},
 'palgrave': {'n_is_sb': '0'},
 'palinurus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'palladio': {'n_is_sb': '0'},
 'pallas athena': {'n_is_sb': '0'},
 'pallas athene': {'n_is_sb': '0'},
 "pallas's cat": {'n_is_sb': '3', 'n_is_sth': '3'},
 "pallas's sandgrouse": {'n_is_sb': '3', 'n_is_sth': '3'},
 'pallas': {'n_is_sb': '0'},
 'pallbearer': {'n_is_sb': '0'},
 'pallid bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'palm cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'palm civet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'palmer': {'n_is_sb': '0'},
 'palmister': {'n_is_sb': '0'},
 'palmist': {'n_is_sb': '0'},
 'palometa simillima': {'n_is_sb': '3', 'n_is_sth': '3'},
 'palometa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'palomino': {'n_is_sb': '0'},
 'palsgrave': {'n_is_sb': '0'},
 'pamlico': {'n_is_sb': '0'},
 'pamperer': {'n_is_sb': '0'},
 'pamphleteer': {'n_is_sb': '0'},
 'pan paniscus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pan troglodytes schweinfurthii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pan troglodytes troglodytes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pan troglodytes verus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pan troglodytes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'panamanian': {'n_is_sb': '0'},
 'pancake turtle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'panchen lama': {'n_is_sb': '0'},
 'pancho villa': {'n_is_sb': '0'},
 'panda bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pandar': {'n_is_sb': '0'},
 'panderer': {'n_is_sb': '0'},
 'pander': {'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'pandion haliaetus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pandion': {'n_is_sb': '0'},
 'pandora': {'n_is_sb': '0'},
 'panegyrist': {'n_is_sb': '0'},
 'panelist': {'n_is_sb': '0'},
 'panellist': {'n_is_sb': '0'},
 'pangloss': {'n_is_sb': '0'},
 'pangolin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'panini': {'n_is_sb': '0'},
 'panjabi': {'n_is_sb': '2', 'n_is_sth': '2'},
 'panjandrum': {'n_is_sb': '0'},
 'panofsky': {'n_is_sb': '0'},
 'panonychus ulmi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'panonychus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pansexual': {'n_is_sb': '0'},
 'pantaloon': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pantheist': {'n_is_sb': '0'},
 'panther cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'panthera leo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'panthera onca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'panthera pardus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'panthera tigris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'panthera uncia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pantomimer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pantomimist': {'n_is_sb': '0'},
 'pantryman': {'n_is_sb': '0'},
 'pantywaist': {'n_is_sb': '2', 'n_is_sth': '2'},
 'paola caliari': {'n_is_sb': '0'},
 'paolo veronese': {'n_is_sb': '0'},
 'papa doc': {'n_is_sb': '0'},
 'papal nuncio': {'n_is_sb': '0'},
 'paparazzo': {'n_is_sb': '0'},
 'paper nautilus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'paper wasp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'paper-pusher': {'n_is_sb': '0'},
 'paperer': {'n_is_sb': '0'},
 'paperhanger': {'n_is_sb': '0'},
 'papillon': {'n_is_sb': '0'},
 'papio ursinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'papio': {'n_is_sb': '0'},
 'papist': {'n_is_sb': '0'},
 'papoose': {'n_is_sb': '0'},
 'papovavirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pappa': {'n_is_sb': '0'},
 'pappoose': {'n_is_sb': '0'},
 'paprilus alepidotus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'para i': {'n_is_sb': '0'},
 'paracelsus': {'n_is_sb': '0'},
 'paracheirodon axelrodi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'parachute jumper': {'n_is_sb': '0'},
 'parachuter': {'n_is_sb': '0'},
 'parader': {'n_is_sb': '0'},
 'paradisaeidae': {'n_is_sb': '2', 'n_is_sth': '2'},
 'paradoxurus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'paragrapher': {'n_is_sb': '0'},
 'paraguayan': {'n_is_sb': '0'},
 'parainfluenza virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'parakeet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'paralegal': {'n_is_sb': '0'},
 'paralichthys dentatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'paralichthys lethostigmus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'paralithodes camtschatica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'paralytic': {'n_is_sb': '0'},
 'paramecia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'paramecium': {'n_is_sb': '2', 'n_is_sth': '2'},
 'paramedical': {'n_is_sb': '0'},
 'paramedic': {'n_is_sb': '0'},
 'paramyxovirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'paranoiac': {'n_is_sb': '0'},
 'paranoid': {'n_is_sb': '0'},
 'paranthias furcifer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'paranthropus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'paraplegic': {'n_is_sb': '0'},
 'paraprofessional': {'n_is_sb': '0'},
 'parapsychologist': {'n_is_sb': '0'},
 'paraquet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'parascalops breweri': {'n_is_sb': '3', 'n_is_sth': '3'},
 'parashurama': {'n_is_sb': '0'},
 'parasitic jaeger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'parasitic worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'parazoan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'parazoa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'para': {'n_is_sb': '2', 'n_is_sth': '2'},
 'parcae': {'n_is_sb': '0'},
 'pardner': {'n_is_sb': '0'},
 'pardoner': {'n_is_sb': '0'},
 'parer': {'n_is_sb': '0'},
 'paretic': {'n_is_sb': '0'},
 'pareto': {'n_is_sb': '0'},
 'pariah dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'parishioner': {'n_is_sb': '0'},
 'parisian': {'n_is_sb': '0', 'cap_word': 'Parisian'},
 'parjanya': {'n_is_sb': '0'},
 'park commissioner': {'n_is_sb': '0'},
 'parka squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'parker': {'n_is_sb': '0'},
 'parkinson': {'n_is_sb': '0'},
 'parliamentary agent': {'n_is_sb': '0'},
 'parlormaid': {'n_is_sb': '0'},
 'parlourmaid': {'n_is_sb': '0'},
 'parmenides': {'n_is_sb': '0'},
 'parnell': {'n_is_sb': '0'},
 'parodist': {'n_is_sb': '0'},
 'parolee': {'n_is_sb': '0'},
 'parophrys vitulus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'paroquet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'parrakeet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'parricide': {'n_is_sb': '2', 'n_is_sth': '2'},
 'parrish': {'n_is_sb': '0'},
 'parroket': {'n_is_sb': '3', 'n_is_sth': '3'},
 'parroquet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'parrotfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'parr': {'n_is_sb': '0'},
 'parsee': {'n_is_sb': '0'},
 'parsi': {'n_is_sb': '0'},
 'parsons': {'n_is_sb': '0'},
 'part-owner': {'n_is_sb': '0'},
 'partaker': {'n_is_sb': '0'},
 'parthian': {'n_is_sb': '0'},
 'partitionist': {'n_is_sb': '0'},
 'partner in crime': {'n_is_sb': '0'},
 'party boss': {'n_is_sb': '0'},
 'party girl': {'n_is_sb': '0'},
 'party liner': {'n_is_sb': '0'},
 'party man': {'n_is_sb': '0'},
 'party pooper': {'n_is_sb': '0'},
 'party whip': {'n_is_sb': '0'},
 'partygoer': {'n_is_sb': '0'},
 'parula americana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'parula warbler': {'n_is_sb': '3', 'n_is_sth': '3'},
 'parus atricapillus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'parus bicolor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'parus caeruleus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'parus carolinensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'parus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'parvati': {'n_is_sb': '0'},
 'parvovirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'parvo': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pasang': {'n_is_sb': '0'},
 'pascal': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pasha': {'n_is_sb': '0'},
 'pashtoon': {'n_is_sb': '0'},
 'pashtun': {'n_is_sb': '0'},
 'pasiphae': {'n_is_sb': '0'},
 'pass catcher': {'n_is_sb': '0'},
 'pass receiver': {'n_is_sb': '0'},
 'passamaquody': {'n_is_sb': '0'},
 'passenger pigeon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'passer domesticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'passer montanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'passeriform bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'passerina cyanea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'passerina': {'n_is_sb': '2', 'n_is_sth': '2'},
 'passerine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'passive resister': {'n_is_sb': '0'},
 'passive source': {'n_is_sb': '0'},
 'past master': {'n_is_sb': '0'},
 'pasternak': {'n_is_sb': '0'},
 'pasteur': {'n_is_sb': '0'},
 'pastor roseus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pastor sturnus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pastry cook': {'n_is_sb': '0'},
 'patas': {'n_is_sb': '3', 'n_is_sth': '3'},
 'patella vulgata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'patentee': {'n_is_sb': '0'},
 'paterfamilias': {'n_is_sb': '0'},
 'paterson': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pathan': {'n_is_sb': '0'},
 'pathfinder': {'n_is_sb': '0'},
 'pathologist': {'n_is_sb': '0'},
 'paton': {'n_is_sb': '0'},
 'patrial': {'n_is_sb': '0'},
 'patrician': {'n_is_sb': '0'},
 'patricide': {'n_is_sb': '0'},
 'patrick henry': {'n_is_sb': '0'},
 'patrick victor martindale white': {'n_is_sb': '0'},
 'patrick white': {'n_is_sb': '0'},
 'patrick': {'n_is_sb': '0'},
 'patrikin': {'n_is_sb': '0'},
 'patrilineal kin': {'n_is_sb': '0'},
 'patrilineal sib': {'n_is_sb': '0'},
 'patrioteer': {'n_is_sb': '0'},
 'patrisib': {'n_is_sb': '0'},
 'patroclus': {'n_is_sb': '0'},
 'patroller': {'n_is_sb': '0'},
 'patrolman': {'n_is_sb': '0'},
 'patron saint': {'n_is_sb': '0'},
 'patroness': {'n_is_sb': '0'},
 'patronne': {'n_is_sb': '0'},
 'patternmaker': {'n_is_sb': '0'},
 'patwin': {'n_is_sb': '0'},
 'patzer': {'n_is_sb': '0'},
 'paul adrien maurice dirac': {'n_is_sb': '0'},
 'paul bunyan': {'n_is_sb': '0'},
 'paul bustill robeson': {'n_is_sb': '0'},
 'paul cezanne': {'n_is_sb': '0'},
 'paul dukas': {'n_is_sb': '0'},
 'paul ehrlich': {'n_is_sb': '0'},
 'paul gauguin': {'n_is_sb': '0'},
 'paul hermann muller': {'n_is_sb': '0'},
 'paul heyse': {'n_is_sb': '0'},
 'paul hindemith': {'n_is_sb': '0'},
 'paul johann ludwig von heyse': {'n_is_sb': '0'},
 'paul johannes tillich': {'n_is_sb': '0'},
 'paul john flory': {'n_is_sb': '0'},
 'paul joseph goebbels': {'n_is_sb': '0'},
 'paul klee': {'n_is_sb': '0'},
 'paul ludwig von beneckendorff und von hindenburg': {'n_is_sb': '0'},
 'paul mccartney': {'n_is_sb': '0'},
 'paul newman': {'n_is_sb': '0'},
 'paul revere': {'n_is_sb': '0'},
 'paul robeson': {'n_is_sb': '0'},
 'paul simon': {'n_is_sb': '0'},
 'paul the apostle': {'n_is_sb': '0'},
 'paul tillich': {'n_is_sb': '0'},
 'paul verlaine': {'n_is_sb': '0'},
 'paul vernier': {'n_is_sb': '0'},
 'paul von hindenburg': {'n_is_sb': '0'},
 'pauling': {'n_is_sb': '0'},
 'pauli': {'n_is_sb': '0'},
 'pavarotti': {'n_is_sb': '0'},
 'pavement artist': {'n_is_sb': '0'},
 'pavlova': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pavo cristatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pavo muticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pawer': {'n_is_sb': '0'},
 'pawnbroker': {'n_is_sb': '0'},
 'pawnee': {'n_is_sb': '0'},
 'paxton': {'n_is_sb': '0'},
 'payee': {'n_is_sb': '0'},
 'paynim': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pea crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pea weevil': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pea-chick': {'n_is_sb': '3', 'n_is_sth': '3'},
 'peabody': {'n_is_sb': '2', 'n_is_sth': '2'},
 'peace officer': {'n_is_sb': '0'},
 'peacekeeper': {'n_is_sb': '0'},
 'peacenik': {'n_is_sb': '0'},
 'peachick': {'n_is_sb': '0'},
 'peacock butterfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'peahen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'peanut worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pearl bailey': {'n_is_sb': '0'},
 'pearl buck': {'n_is_sb': '0'},
 'pearl diver': {'n_is_sb': '0'},
 'pearl mae bailey': {'n_is_sb': '0'},
 'pearl oyster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pearl sydenstricker buck': {'n_is_sb': '0'},
 'pearl-fish': {'n_is_sb': '0'},
 'pearler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pearlfish': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pearly nautilus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pearly razorfish': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pearly-shelled mussel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'peary': {'n_is_sb': '0'},
 'peba': {'n_is_sb': '3', 'n_is_sth': '3'},
 'peccari angulatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pecten irradians': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pecten magellanicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pectoral sandpiper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'peculator': {'n_is_sb': '0'},
 'pedaler': {'n_is_sb': '0'},
 'pedaller': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pederast': {'n_is_sb': '0'},
 'pediatrician': {'n_is_sb': '0'},
 'pediatrist': {'n_is_sb': '0'},
 'pediculus capitis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pediculus corporis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pediculus humanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pediculus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pedioecetes phasianellus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pedioecetes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pedionomus torquatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pedipalpi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pedlar': {'n_is_sb': '0'},
 'pedodontist': {'n_is_sb': '0'},
 'pedophile': {'n_is_sb': '0'},
 'pedro calderon de la barca': {'n_is_sb': '0'},
 'peeler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'peeping tom': {'n_is_sb': '0'},
 'peer of the realm': {'n_is_sb': '0'},
 'peeress': {'n_is_sb': '0'},
 'peewit': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pegasus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'peirce': {'n_is_sb': '0'},
 'pei': {'n_is_sb': '0'},
 'pekan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'peke': {'n_is_sb': '3', 'n_is_sth': '3'},
 'peking man': {'n_is_sb': '0'},
 'pelagic bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pelecaniform seabird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pelecanus erythrorhynchos': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pelecanus onocrotalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pelecanus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pelecypod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'peleus': {'n_is_sb': '0'},
 'pelham grenville wodehouse': {'n_is_sb': '0'},
 'pelter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'peludo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pelvic fin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pelycosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pembroke welsh corgi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pen pal': {'n_is_sb': '0'},
 'pen-friend': {'n_is_sb': '0'},
 'pen-tailed tree shrew': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pen-tail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pencil pusher': {'n_is_sb': '0'},
 'pendragon': {'n_is_sb': '0'},
 'peneidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'penelope': {'n_is_sb': '0'},
 'penetrator': {'n_is_sb': '0'},
 'peneus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'penicillin-resistant bacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'penitent': {'n_is_sb': '0'},
 'pennatula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pennon': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pennsylvanian': {'n_is_sb': '0'},
 'penny pincher': {'n_is_sb': '0'},
 'penn': {'n_is_sb': '0'},
 'penobscot': {'n_is_sb': '0'},
 'penologist': {'n_is_sb': '0'},
 'penpusher': {'n_is_sb': '0'},
 'pensionary': {'n_is_sb': '0'},
 'pentail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pentastomid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pentathlete': {'n_is_sb': '0'},
 'pentecostalist': {'n_is_sb': '0'},
 'pentecostal': {'n_is_sb': '0', 'cap_word': 'Pentecostal'},
 'penutian': {'n_is_sb': '0'},
 'pepys': {'n_is_sb': '0'},
 'perca flavescens': {'n_is_sb': '3', 'n_is_sth': '3'},
 'perca fluviatilis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'perca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'perceiver': {'n_is_sb': '0'},
 'percher': {'n_is_sb': '0'},
 'perching bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'percina tanasi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'percival lowell': {'n_is_sb': '0'},
 'percoid fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'percoidean': {'n_is_sb': '3', 'n_is_sth': '3'},
 'percoid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'percussionist': {'n_is_sb': '0'},
 'percy aldridge grainger': {'n_is_sb': '0'},
 'percy bysshe shelley': {'n_is_sb': '0'},
 'percy grainger': {'n_is_sb': '0'},
 'percy': {'n_is_sb': '0'},
 'perdix perdix': {'n_is_sb': '3', 'n_is_sth': '3'},
 "pere david's deer": {'n_is_sb': '0'},
 'pere jacques marquette': {'n_is_sb': '0'},
 'peregrine falcon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'perfecter': {'n_is_sb': '0'},
 'perfectionist': {'n_is_sb': '0'},
 'performing artist': {'n_is_sb': '0'},
 'perfumer': {'n_is_sb': '0'},
 'pericles': {'n_is_sb': '0'},
 'peridinian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'peridiniidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'peridinium': {'n_is_sb': '2', 'n_is_sth': '2'},
 'perinatologist': {'n_is_sb': '0'},
 'periodical cicada': {'n_is_sb': '3', 'n_is_sth': '3'},
 'periodontist': {'n_is_sb': '0'},
 'periophthalmus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'peripatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'periplaneta americana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'periplaneta australasiae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'perisher': {'n_is_sb': '0'},
 'perisoreus canadensis capitalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'perisoreus canadensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'perissodactyl mammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'perissodactyla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'perissodactyl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'peristedion miniatum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'perjurer': {'n_is_sb': '0'},
 'pernis apivorus': {'n_is_sb': '0'},
 'pernis': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pernyi moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'perodicticus potto': {'n_is_sb': '3', 'n_is_sth': '3'},
 'perognathus flavescens': {'n_is_sb': '3', 'n_is_sth': '3'},
 'perognathus flavus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'perognathus hispidus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'peromyscus eremicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'peromyscus gossypinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'peromyscus leucopus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'peromyscus maniculatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'peromyscus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'peron': {'n_is_sb': '0'},
 'peroxide blonde': {'n_is_sb': '0'},
 'peroxide blond': {'n_is_sb': '0'},
 'perpetrator': {'n_is_sb': '0'},
 'perry mason': {'n_is_sb': '0'},
 'perry': {'n_is_sb': '2', 'n_is_sth': '2'},
 'persecutor': {'n_is_sb': '0'},
 'persephone': {'n_is_sb': '0'},
 'perseus': {'n_is_sb': '0'},
 'pershing': {'n_is_sb': '2', 'n_is_sth': '2'},
 'persian cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'persian deity': {'n_is_sb': '0'},
 'persian lamb': {'n_is_sb': '3', 'n_is_sth': '3'},
 'person of color': {'n_is_sb': '0'},
 'person of colour': {'n_is_sb': '0'},
 'persona grata': {'n_is_sb': '0'},
 'persona non grata': {'n_is_sb': '0'},
 'personal representative': {'n_is_sb': '0'},
 'perspirer': {'n_is_sb': '0'},
 'perutz': {'n_is_sb': '0'},
 'peruvian': {'n_is_sb': '0'},
 'pervert': {'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'peshmerga': {'n_is_sb': '0'},
 'pessimist': {'n_is_sb': '0'},
 'pesterer': {'n_is_sb': '0'},
 'pet sitter': {'n_is_sb': '0'},
 'petaurista petaurista': {'n_is_sb': '3', 'n_is_sth': '3'},
 'petaurus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'petchary': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pete seeger': {'n_is_sb': '0'},
 'peter abelard': {'n_is_sb': '0'},
 'peter alexander ustinov': {'n_is_sb': '0'},
 'peter behrens': {'n_is_sb': '0'},
 'peter carl faberge': {'n_is_sb': '0'},
 'peter carl goldmark': {'n_is_sb': '0'},
 'peter cooper': {'n_is_sb': '0'},
 'peter goldmark': {'n_is_sb': '0'},
 'peter ilich tchaikovsky': {'n_is_sb': '0'},
 'peter i': {'n_is_sb': '0'},
 'peter lorre': {'n_is_sb': '0'},
 'peter mark roget': {'n_is_sb': '0'},
 'peter medawar': {'n_is_sb': '0'},
 'peter minnewit': {'n_is_sb': '0'},
 'peter minuit': {'n_is_sb': '0'},
 "peter o'toole": {'n_is_sb': '0'},
 'peter pan': {'n_is_sb': '0'},
 'peter paul mauser': {'n_is_sb': '0'},
 'peter paul rubens': {'n_is_sb': '0'},
 "peter seamus o'toole": {'n_is_sb': '0'},
 'peter seeger': {'n_is_sb': '0'},
 'peter sellers': {'n_is_sb': '0'},
 'peter stuyvesant': {'n_is_sb': '0'},
 'peter tchaikovsky': {'n_is_sb': '0'},
 'peter the great': {'n_is_sb': '0'},
 'petit bourgeois': {'n_is_sb': '0'},
 'petit juror': {'n_is_sb': '0'},
 'petrarca': {'n_is_sb': '0'},
 'petrarch': {'n_is_sb': '0'},
 'petrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'petrogale': {'n_is_sb': '2', 'n_is_sth': '2'},
 'petroleum geologist': {'n_is_sb': '0'},
 'petromyzon marinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'petromyzon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'petronius arbiter': {'n_is_sb': '0'},
 'petronius': {'n_is_sb': '0'},
 'petrus stuyvesant': {'n_is_sb': '0'},
 'petter': {'n_is_sb': '0'},
 'pettifogger': {'n_is_sb': '0'},
 'petty juror': {'n_is_sb': '0'},
 'petty officer': {'n_is_sb': '0'},
 'pewee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pewit gull': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pewit': {'n_is_sb': '0'},
 'peyton rous': {'n_is_sb': '0'},
 'pezophaps solitaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pezophaps': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phaethon': {'n_is_sb': '0'},
 'phalacrocorax carbo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phalacrocorax': {'n_is_sb': '2', 'n_is_sth': '2'},
 'phalaenoptilus nuttallii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phalanger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phalangida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phalangium opilio': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phalangium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phalarope': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phalaropus fulicarius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phantasma': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pharaoh ant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pharaoh of egypt': {'n_is_sb': '0'},
 "pharaoh's ant": {'n_is_sb': '3', 'n_is_sth': '3'},
 "pharaoh's chicken": {'n_is_sb': '3', 'n_is_sth': '3'},
 'pharmaceutical chemist': {'n_is_sb': '0'},
 'pharmacologist': {'n_is_sb': '0'},
 'pharomacrus mocino': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phascolarctos cinereus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phascolarctos': {'n_is_sb': '2', 'n_is_sth': '2'},
 'phasianus colchicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phasmid insect': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phasmida': {'n_is_sb': '2', 'n_is_sth': '2'},
 'phasmid': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pheasant coucal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pheasant cuckoo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pheidias': {'n_is_sb': '0'},
 'phenacomys': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phidias': {'n_is_sb': '0'},
 'phil anderson': {'n_is_sb': '0'},
 'philaenus spumarius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'philanderer': {'n_is_sb': '0'},
 'philatelist': {'n_is_sb': '0'},
 'philemon': {'n_is_sb': '2', 'n_is_sth': '2'},
 'philhellene': {'n_is_sb': '0'},
 'philhellenist': {'n_is_sb': '0'},
 "philibert de l'orme": {'n_is_sb': '0'},
 'philibert delorme': {'n_is_sb': '0'},
 'philip anderson': {'n_is_sb': '0'},
 'philip augustus': {'n_is_sb': '0'},
 'philip dormer stanhope': {'n_is_sb': '0'},
 'philip ii of macedon': {'n_is_sb': '0'},
 'philip ii of spain': {'n_is_sb': '0'},
 'philip ii': {'n_is_sb': '0'},
 'philip marlowe': {'n_is_sb': '0'},
 'philip michael ondaatje': {'n_is_sb': '0'},
 'philip milton roth': {'n_is_sb': '0'},
 'philip of valois': {'n_is_sb': '0'},
 'philip roth': {'n_is_sb': '0'},
 'philip vi': {'n_is_sb': '0'},
 'philip v': {'n_is_sb': '0'},
 'philip warren anderson': {'n_is_sb': '0'},
 'philipp lenard': {'n_is_sb': '0'},
 'philipp melanchthon': {'n_is_sb': '0'},
 'philipp schwarzerd': {'n_is_sb': '0'},
 'philippian': {'n_is_sb': '0'},
 'philippus aureolus paracelsus': {'n_is_sb': '0'},
 'philip': {'n_is_sb': '0'},
 'phillis wheatley': {'n_is_sb': '0'},
 'philohela minor': {'n_is_sb': '0'},
 'philohela': {'n_is_sb': '3', 'n_is_sth': '3'},
 'philologist': {'n_is_sb': '0'},
 'philologue': {'n_is_sb': '0'},
 'philomachus pugnax': {'n_is_sb': '3', 'n_is_sth': '3'},
 'philophylla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'philosophiser': {'n_is_sb': '0'},
 'philosophizer': {'n_is_sb': '0'},
 'phineas taylor barnum': {'n_is_sb': '0'},
 'phintias': {'n_is_sb': '0'},
 'phiz': {'n_is_sb': '2', 'n_is_sth': '2'},
 'phlebotomus papatasii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phoca vitulina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phocaena phocaena': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phocaena sinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phocaena': {'n_is_sb': '2', 'n_is_sth': '2'},
 'phoebe bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phoebe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phoebus apollo': {'n_is_sb': '0'},
 'phoenician': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pholas': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pholis gunnellus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phone tapper': {'n_is_sb': '0'},
 'phoner': {'n_is_sb': '0'},
 'phonetician': {'n_is_sb': '0'},
 'phonologist': {'n_is_sb': '0'},
 'phoronid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'photoblepharon palpebratus': {'n_is_sb': '3', 'n_is_sth': '3'},
 "photographer's model": {'n_is_sb': '0'},
 'photojournalist': {'n_is_sb': '0'},
 'photometrician': {'n_is_sb': '0'},
 'photometrist': {'n_is_sb': '0'},
 'phototrophic bacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phototropic bacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phoxinus phoxinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phragmacone': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phragmocone': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phrenologist': {'n_is_sb': '0'},
 'phrygian deity': {'n_is_sb': '0'},
 'phrygian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'phrynosoma cornutum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phrynosoma': {'n_is_sb': '2', 'n_is_sth': '2'},
 'phthirius pubis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phthirius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phthirus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'phthorimaea operculella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phthorimaea': {'n_is_sb': '2', 'n_is_sth': '2'},
 'phycobilin': {'n_is_sb': '2', 'n_is_sth': '2'},
 'phycocyanin': {'n_is_sb': '2', 'n_is_sth': '2'},
 'phycoerythrin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phylloscopus sibilatrix': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phyllostomus hastatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phylloxera vitifoleae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'phylloxera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'physa': {'n_is_sb': '2', 'n_is_sth': '2'},
 'physeter catodon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'physical therapist': {'n_is_sb': '0'},
 'physiotherapist': {'n_is_sb': '0'},
 'phytologist': {'n_is_sb': '0'},
 'phytoplankton': {'n_is_sb': '3', 'n_is_sth': '3'},
 'piaf': {'n_is_sb': '0'},
 'piaget': {'n_is_sb': '0'},
 'piano maker': {'n_is_sb': '0'},
 'piano player': {'n_is_sb': '0'},
 'piano teacher': {'n_is_sb': '0'},
 'piano tuner': {'n_is_sb': '0'},
 'pica pica hudsonia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pica pica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'picador': {'n_is_sb': '0'},
 'picaninny': {'n_is_sb': '0'},
 'pica': {'n_is_sb': '0'},
 'piccaninny': {'n_is_sb': '0'},
 'pichiciago': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pichiciego': {'n_is_sb': '3', 'n_is_sth': '3'},
 'picidae': {'n_is_sb': '2', 'n_is_sth': '2'},
 'piciform bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pickaninny': {'n_is_sb': '0'},
 'pickerel frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pickerel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pickett': {'n_is_sb': '0'},
 'pickford': {'n_is_sb': '0'},
 'picklepuss': {'n_is_sb': '0'},
 'picknicker': {'n_is_sb': '0'},
 'picnicker': {'n_is_sb': '0'},
 'picornavirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'piculet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'picumnus': {'n_is_sb': '0'},
 'picus viridis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'picus': {'n_is_sb': '0'},
 'piddock': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pie-dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pied lemming': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pied-billed grebe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pier luigi nervi': {'n_is_sb': '0'},
 'pierce': {'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'n_is_sth': '2'},
 'pierid butterfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pierid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pieris brassicae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pieris protodice': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pieris rapae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pieris': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pierre abelard': {'n_is_sb': '0'},
 'pierre athanase larousse': {'n_is_sb': '0'},
 'pierre auguste renoir': {'n_is_sb': '0'},
 'pierre boulez': {'n_is_sb': '0'},
 "pierre charles l'enfant": {'n_is_sb': '0'},
 'pierre corneille': {'n_is_sb': '0'},
 'pierre curie': {'n_is_sb': '0'},
 'pierre de fermat': {'n_is_sb': '0'},
 'pierre de terrail': {'n_is_sb': '0'},
 'pierre joseph proudhon': {'n_is_sb': '0'},
 'pierre larousse': {'n_is_sb': '0'},
 'pierre simon de laplace': {'n_is_sb': '0'},
 'pierre teilhard de chardin': {'n_is_sb': '0'},
 'pierre terrail': {'n_is_sb': '0'},
 'pierre-paul broca': {'n_is_sb': '0'},
 'pierrot': {'n_is_sb': '0'},
 'piet mondrian': {'n_is_sb': '0'},
 'pieter breughel': {'n_is_sb': '0'},
 'pieter bruegel': {'n_is_sb': '0'},
 'pieter brueghel the elder': {'n_is_sb': '0'},
 'pieter brueghel': {'n_is_sb': '0'},
 'pieter zeeman': {'n_is_sb': '0'},
 'pigeon guillemot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pigeon hawk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pigfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'piggy': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pigman': {'n_is_sb': '0'},
 'pigmy': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pika': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pike perch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pike-perch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pikeblenny': {'n_is_sb': '3', 'n_is_sth': '3'},
 'piked whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pilchard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pilferer': {'n_is_sb': '0'},
 'pilgrim father': {'n_is_sb': '0'},
 'pill bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pill head': {'n_is_sb': '0'},
 'pill pusher': {'n_is_sb': '0'},
 'pill roller': {'n_is_sb': '0'},
 'pillager': {'n_is_sb': '0'},
 'pillar of strength': {'n_is_sb': '0'},
 'pillock': {'n_is_sb': '0'},
 'pilot blacksnake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pilot whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pilotfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'piltdown hoax': {'n_is_sb': '0'},
 'piltdown man': {'n_is_sb': '0'},
 'pima': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pin-tailed duck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pin-tailed grouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pin-tailed sandgrouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pin-up': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pincer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pinch hitter': {'n_is_sb': '0'},
 'pinchas zukerman': {'n_is_sb': '0'},
 'pinche': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pinchgut': {'n_is_sb': '0'},
 'pinctada margaritifera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pincus': {'n_is_sb': '0'},
 'pindar': {'n_is_sb': '0'},
 'pine finch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pine grosbeak': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pine leaf aphid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pine lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pine marten': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pine mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pine sawyer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pine siskin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pine snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pine spittlebug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pine vole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pineus pinifoliae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pinfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pinguinus impennis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pinicola enucleator': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pink bollworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pink cockatoo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pinko': {'n_is_sb': '0'},
 'pinnatiped': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pinniped mammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pinnotheres ostreum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pinscher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pintado': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pintail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pinter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pinworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pip-squeak': {'n_is_sb': '0'},
 'pipa americana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pipa pipa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pipa': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pipe fitter': {'n_is_sb': '0'},
 'pipe major': {'n_is_sb': '0'},
 'pipe smoker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pipefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'piper': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pipilo erythrophthalmus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'piping crow-shrike': {'n_is_sb': '3', 'n_is_sth': '3'},
 'piping crow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'piping guan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'piping plover': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pipistrelle': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pipistrellus pipistrellus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pipistrellus subflavus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pipistrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pipit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pipra': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pirana': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pirandello': {'n_is_sb': '0'},
 'piranga flava hepatica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'piranga ludoviciana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'piranga olivacea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'piranga rubra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'piranga': {'n_is_sb': '3', 'n_is_sth': '3'},
 'piranha': {'n_is_sb': '3', 'n_is_sth': '3'},
 'piroplasm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pisanosaurus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pisanosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pisces': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pismire': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pisser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pistol shrimp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pistoleer': {'n_is_sb': '0'},
 'pit bull terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pit viper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pitching coach': {'n_is_sb': '0'},
 'pithecanthropus erectus': {'n_is_sb': '0'},
 'pithecanthropus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pitt the elder': {'n_is_sb': '0'},
 'pitt the younger': {'n_is_sb': '0'},
 'pitta': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pitt': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pituophis melanoleucus': {'n_is_sb': '0'},
 'pitymys pinetorum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pius ii': {'n_is_sb': '0'},
 'pius vii': {'n_is_sb': '0'},
 'pius v': {'n_is_sb': '0'},
 'pius xii': {'n_is_sb': '0'},
 'pius xi': {'n_is_sb': '0'},
 'pius x': {'n_is_sb': '0'},
 'piute': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pivot man': {'n_is_sb': '0'},
 'pixie': {'n_is_sb': '0'},
 'pixy': {'n_is_sb': '0'},
 'pizarro': {'n_is_sb': '0'},
 'place-kicker': {'n_is_sb': '0'},
 'placeholder': {'n_is_sb': '2', 'n_is_sth': '2'},
 'placekicker': {'n_is_sb': '0'},
 'placeman': {'n_is_sb': '0'},
 'placental mammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'placental': {'n_is_sb': '3', 'n_is_sth': '3'},
 'placer miner': {'n_is_sb': '0'},
 'placeseeker': {'n_is_sb': '0'},
 'placido domingo': {'n_is_sb': '0'},
 'placoderm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'placuna placenta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plagiariser': {'n_is_sb': '0'},
 'plagiarizer': {'n_is_sb': '0'},
 'plaice': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plain turkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plain wanderer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plainclothesman': {'n_is_sb': '0'},
 'plains indian': {'n_is_sb': '0'},
 'plains pocket gopher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plains pocket mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plains spadefoot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plainsman': {'n_is_sb': '0'},
 'plaintiff in error': {'n_is_sb': '0'},
 'plaiter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'planarian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'planaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'planck': {'n_is_sb': '0'},
 'planococcus citri': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plant bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plant hopper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plant louse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plant scientist': {'n_is_sb': '0'},
 'plant virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plantation owner': {'n_is_sb': '0'},
 'plantation walking horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'planthopper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plantigrade mammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plantlike flagellate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plantsman': {'n_is_sb': '0'},
 'planula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plasmodium vivax': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plaster saint': {'n_is_sb': '0'},
 'plastic surgeon': {'n_is_sb': '0'},
 'platalea leucorodia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plataleidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plateau striped whiptail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'platelayer': {'n_is_sb': '0'},
 'plater': {'n_is_sb': '0'},
 'plath': {'n_is_sb': '0'},
 'platichthys flesus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'platitudinarian': {'n_is_sb': '0'},
 'platonist': {'n_is_sb': '0'},
 'platyctenean': {'n_is_sb': '3', 'n_is_sth': '3'},
 'platyhelminthes': {'n_is_sb': '2', 'n_is_sth': '2'},
 'platyhelminth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'platypoecilus maculatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'platypoecilus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'platyrrhine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'platyrrhini': {'n_is_sb': '2', 'n_is_sth': '2'},
 'platy': {'n_is_sb': '2', 'n_is_sth': '2'},
 'plautus alle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plautus': {'n_is_sb': '0'},
 'play-actor': {'n_is_sb': '0'},
 'playactor': {'n_is_sb': '0'},
 'playfellow': {'n_is_sb': '0'},
 'pleaser': {'n_is_sb': '0'},
 'pleasure seeker': {'n_is_sb': '0'},
 'plebeian': {'n_is_sb': '0'},
 'plebe': {'n_is_sb': '0'},
 'pleb': {'n_is_sb': '0'},
 'plecopteran': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plecotus townsendi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plectognath fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plectognath': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plectophera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plectrophenax nivalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pledge taker': {'n_is_sb': '0'},
 'pledgee': {'n_is_sb': '0'},
 'pledger': {'n_is_sb': '0'},
 'pleiades': {'n_is_sb': '2', 'n_is_sth': '2'},
 'plenipotentiary': {'n_is_sb': '0'},
 'plesianthropus': {'n_is_sb': '0'},
 'plesiosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plesiosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plethodon cinereus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plethodon vehiculum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pleurobrachia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pleurobrachiidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pleurodont': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pleuronectes platessa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pleuronectidae': {'n_is_sb': '0'},
 'pleuropneumonialike organism': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plicatoperipatus jamaicensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plier': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pliny the elder': {'n_is_sb': '0'},
 'pliny the younger': {'n_is_sb': '0'},
 'pliny': {'n_is_sb': '0'},
 'ploceus philippinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plodder': {'n_is_sb': '0'},
 'plotinus': {'n_is_sb': '0'},
 'plott hound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plough horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ploughboy': {'n_is_sb': '0'},
 'ploughwright': {'n_is_sb': '0'},
 'plow horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plowboy': {'n_is_sb': '0'},
 'plower': {'n_is_sb': '0'},
 'plowwright': {'n_is_sb': '0'},
 'plug-ugly': {'n_is_sb': '0'},
 'plumage': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plumed scorpionfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plumule': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plunderer': {'n_is_sb': '0'},
 'pluralist': {'n_is_sb': '0'},
 'plutarch': {'n_is_sb': '0'},
 'pluto': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pluvianus aegyptius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pluvianus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'plyer': {'n_is_sb': '0'},
 'plymouth rock': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pneumococcus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'poacher': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pocahontas': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pochard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pocket gopher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pocket mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pocket rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pocketed bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pocketed freetail bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'podiatrist': {'n_is_sb': '0'},
 'podiceps cristatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'podiceps grisegena': {'n_is_sb': '3', 'n_is_sth': '3'},
 'podiceps nigricollis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'podiceps ruficollis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'podicipitiform seabird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'podilymbus podiceps': {'n_is_sb': '3', 'n_is_sth': '3'},
 'poeciliid fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'poecilocapsus lineatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'poecilogale albinucha': {'n_is_sb': '3', 'n_is_sth': '3'},
 'poecilogale': {'n_is_sb': '2', 'n_is_sth': '2'},
 'poephila castanotis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'poet laureate': {'n_is_sb': '0'},
 'poet-singer': {'n_is_sb': '0'},
 'poetess': {'n_is_sb': '0'},
 'poetiser': {'n_is_sb': '0'},
 'poetizer': {'n_is_sb': '0'},
 'poe': {'n_is_sb': '0'},
 'pogge': {'n_is_sb': '0'},
 'pogonophoran': {'n_is_sb': '3', 'n_is_sth': '3'},
 'poikilotherm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'poinsettia strain': {'n_is_sb': '3', 'n_is_sth': '3'},
 'point man': {'n_is_sb': '0'},
 'point woman': {'n_is_sb': '0'},
 'pointilist': {'n_is_sb': '0'},
 'pointsman': {'n_is_sb': '0'},
 'poisoner': {'n_is_sb': '0', 'nn_to_vb': 'poison', 'nn_to_jj': 'poisonous', 'nn_to_rb': 'poisonously'},
 'poitier': {'n_is_sb': '0'},
 'polack': {'n_is_sb': '0'},
 'polar bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polar hare': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pole horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pole jumper': {'n_is_sb': '0'},
 'pole vaulter': {'n_is_sb': '0'},
 'polemist': {'n_is_sb': '0'},
 'poler': {'n_is_sb': '0'},
 'police captain': {'n_is_sb': '0'},
 'police chief': {'n_is_sb': '0'},
 'police commissioner': {'n_is_sb': '0'},
 'police constable': {'n_is_sb': '0'},
 'police detective': {'n_is_sb': '0'},
 'police dog': {'n_is_sb': '0'},
 'police lieutenant': {'n_is_sb': '0'},
 'police matron': {'n_is_sb': '0'},
 'police officer': {'n_is_sb': '0'},
 'police sergeant': {'n_is_sb': '0'},
 'policeman bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'policewoman': {'n_is_sb': '0', 'nc_typical': ''},
 'policy maker': {'n_is_sb': '0'},
 'poliovirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polistes annularis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polistes': {'n_is_sb': '2', 'n_is_sth': '2'},
 'political boss': {'n_is_sb': '0'},
 'political commissar': {'n_is_sb': '0'},
 'political detainee': {'n_is_sb': '0'},
 'political dissident': {'n_is_sb': '0'},
 'political hack': {'n_is_sb': '0'},
 'political leader': {'n_is_sb': '0'},
 'political prisoner': {'n_is_sb': '0'},
 'political scientist': {'n_is_sb': '0'},
 'polk': {'n_is_sb': '0'},
 'poll parrot': {'n_is_sb': '0'},
 'poll taker': {'n_is_sb': '0'},
 'pollachius pollachius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pollack': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pollinator': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polliwog': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pollock': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pollster': {'n_is_sb': '0'},
 'polluter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'polly fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pollywog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polo pony': {'n_is_sb': '3', 'n_is_sth': '3'},
 'poltergeist': {'n_is_sb': '0'},
 'polyandrist': {'n_is_sb': '0'},
 'polyborus cheriway audubonii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polyborus plancus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polyborus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polychaete worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polychaete': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polychete worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polychete': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polydactylus virginicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polyergus rufescens': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polygamist': {'n_is_sb': '0'},
 'polyglot': {'n_is_sb': '2', 'n_is_sth': '2'},
 'polygonia comma': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polygynist': {'n_is_sb': '0'},
 'polyhymnia': {'n_is_sb': '0'},
 'polymastigote': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polymath': {'n_is_sb': '0'},
 'polynesian tattler': {'n_is_sb': '0'},
 'polynesian': {'n_is_sb': '0'},
 'polyodon spathula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polyoma virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polyoma': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polyphemus moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polyplacophore': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polyploid': {'n_is_sb': '0'},
 'polyprion americanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polyzoan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'polyzoa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pol': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pomace fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pomacentrus leucostictus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pomatomus saltatrix': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pomatomus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pomeranian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pommy': {'n_is_sb': '0'},
 'pomolobus pseudoharengus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pomolobus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pomoxis annularis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pomoxis nigromaculatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pomo': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pompadour': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pompano': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pompey the great': {'n_is_sb': '0'},
 'pompey': {'n_is_sb': '0'},
 'pom': {'n_is_sb': '0'},
 'ponca': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ponce': {'n_is_sb': '0'},
 'pond scum': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pond-skater': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ponderer': {'n_is_sb': '0'},
 'pongid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pongo pygmaeus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ponka': {'n_is_sb': '0'},
 'pontiac': {'n_is_sb': '0'},
 'pontifex': {'n_is_sb': '0'},
 'pontos': {'n_is_sb': '0'},
 'pontus': {'n_is_sb': '0'},
 'poodle dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'poodle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pooecetes gramineus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'poof': {'n_is_sb': '0'},
 'pooh-bah': {'n_is_sb': '0'},
 'pool player': {'n_is_sb': '0'},
 'pooler': {'n_is_sb': '0'},
 'poor devil': {'n_is_sb': '0'},
 'poor fish': {'n_is_sb': '0'},
 'poor man': {'n_is_sb': '0'},
 'poor person': {'n_is_sb': '0'},
 'poor speller': {'n_is_sb': '0'},
 'poor white trash': {'n_is_sb': '0'},
 'poor white': {'n_is_sb': '0'},
 'poorwill': {'n_is_sb': '3', 'n_is_sth': '3'},
 'poove': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pope alexander vi': {'n_is_sb': '0'},
 'popillia japonica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'populariser': {'n_is_sb': '0'},
 'popularizer': {'n_is_sb': '0'},
 'population scientist': {'n_is_sb': '0'},
 'populist': {'n_is_sb': '0'},
 'porbeagle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'porcellio': {'n_is_sb': '3', 'n_is_sth': '3'},
 'porcupine fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'porcupinefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'poriferan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'porifera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pork butcher': {'n_is_sb': '0'},
 'pork-fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'porker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'porkfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'porn merchant': {'n_is_sb': '0'},
 'pornographer': {'n_is_sb': '0'},
 'poronotus triacanthus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'poronotus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'porphyra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'porphyrio porphyrio': {'n_is_sb': '3', 'n_is_sth': '3'},
 'porphyrula martinica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'porphyrula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'port watcher': {'n_is_sb': '0'},
 'portrait painter': {'n_is_sb': '0'},
 'portraitist': {'n_is_sb': '0'},
 'portrayer': {'n_is_sb': '0'},
 'portuguese man-of-war': {'n_is_sb': '3', 'n_is_sth': '3'},
 'portunus puber': {'n_is_sb': '3', 'n_is_sth': '3'},
 'portwatcher': {'n_is_sb': '0'},
 'porzana porzana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'poseur': {'n_is_sb': '0'},
 'poseuse': {'n_is_sb': '0'},
 'positivist': {'n_is_sb': '0'},
 'posseman': {'n_is_sb': '0'},
 'possum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'post doc': {'n_is_sb': '0'},
 'post horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'post-impressionist': {'n_is_sb': '2', 'n_is_sth': '2'},
 'postal clerk': {'n_is_sb': '0'},
 'postdoc': {'n_is_sb': '0'},
 'poster boy': {'n_is_sb': '0'},
 'poster child': {'n_is_sb': '0'},
 'poster girl': {'n_is_sb': '0'},
 'postilion': {'n_is_sb': '0'},
 'postillion': {'n_is_sb': '0'},
 'postimpressionist': {'n_is_sb': '0'},
 'postmaster general': {'n_is_sb': '0'},
 'postmaster': {'n_is_sb': '0'},
 'postmature infant': {'n_is_sb': '0'},
 'postmistress': {'n_is_sb': '0'},
 'postponer': {'n_is_sb': '0'},
 'postulant': {'n_is_sb': '0'},
 'potamogale velox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'potamogale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'potamophis striatula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'potato beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'potato bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'potato moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'potato scab bacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'potato tuber moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'potato tuberworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'potato worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'potato yellow-dwarf virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'potawatomi': {'n_is_sb': '2', 'n_is_sth': '2'},
 'potboy': {'n_is_sb': '0'},
 'pothead': {'n_is_sb': '2', 'n_is_sth': '2'},
 'potholer': {'n_is_sb': '0'},
 'pothunter': {'n_is_sb': '0'},
 'potman': {'n_is_sb': '0'},
 'potoroo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'potos caudivolvulus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'potos flavus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'potter bee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'potter wasp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'potterer': {'n_is_sb': '0'},
 'potto': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pouched mole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pouched mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pouched rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'poulenc': {'n_is_sb': '0'},
 'poulterer': {'n_is_sb': '0'},
 'poultryman': {'n_is_sb': '0'},
 'poussin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pouter pigeon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pouter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'powder monkey': {'n_is_sb': '0'},
 'powder-post termite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'powderer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'powell': {'n_is_sb': '0'},
 'power broker': {'n_is_sb': '0'},
 'power user': {'n_is_sb': '0'},
 'power worker': {'n_is_sb': '0'},
 'power-station worker': {'n_is_sb': '0'},
 'powerbroker': {'n_is_sb': '0'},
 'powhatan': {'n_is_sb': '0'},
 'pow': {'n_is_sb': '2', 'n_is_sth': '2'},
 'poxvirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'poyou': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pplo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pr man': {'n_is_sb': '0'},
 'practical joker': {'n_is_sb': '0'},
 'practical nurse': {'n_is_sb': '0'},
 'practice teacher': {'n_is_sb': '0'},
 'practician': {'n_is_sb': '0'},
 'praetorian guard': {'n_is_sb': '0'},
 'praetor': {'n_is_sb': '0'},
 'pragmatist': {'n_is_sb': '0'},
 'prairie chicken': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prairie dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prairie fowl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prairie fox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prairie grouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prairie marmot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prairie rattler': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prairie rattlesnake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prairie vole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prairie wolf': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prajapati': {'n_is_sb': '0'},
 'prancer': {'n_is_sb': '0'},
 'prankster': {'n_is_sb': '0'},
 'prater': {'n_is_sb': '0'},
 'pratincole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prattler': {'n_is_sb': '0'},
 'praunus': {'n_is_sb': '0'},
 'praxiteles': {'n_is_sb': '0'},
 'praya': {'n_is_sb': '2', 'n_is_sth': '2'},
 'praying mantid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'praying mantis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pre-emptor': {'n_is_sb': '0'},
 'pre-raphaelite': {'n_is_sb': '0', 'cap_word': 'Pre-Raphaelite'},
 'preacher man': {'n_is_sb': '0'},
 'prebendary': {'n_is_sb': '0'},
 'precentor': {'n_is_sb': '0'},
 'preceptor': {'n_is_sb': '0'},
 'predatory animal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'predator': {'n_is_sb': '2', 'n_is_sth': '2'},
 'predestinarian': {'n_is_sb': '0'},
 'predestinationist': {'n_is_sb': '0'},
 'predictor': {'n_is_sb': '2', 'n_is_sth': '2'},
 'preemptor': {'n_is_sb': '0'},
 'premature baby': {'n_is_sb': '0'},
 'premature infant': {'n_is_sb': '0'},
 'premie': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pres young': {'n_is_sb': '0'},
 'presbyope': {'n_is_sb': '2', 'n_is_sth': '2'},
 'presbyterian': {'n_is_sb': '0', 'cap_word': 'Presbyterian'},
 'presbyter': {'n_is_sb': '0'},
 'presbytes entellus': {'n_is_sb': '0'},
 'presbytes': {'n_is_sb': '0'},
 'preschooler': {'n_is_sb': '0'},
 'presenter': {'n_is_sb': '0'},
 'presentist': {'n_is_sb': '0'},
 'preservationist': {'n_is_sb': '0'},
 'preserver': {'n_is_sb': '0'},
 'president abraham lincoln': {'n_is_sb': '0'},
 'president adams': {'n_is_sb': '0'},
 'president andrew johnson': {'n_is_sb': '0'},
 'president arthur': {'n_is_sb': '0'},
 'president benjamin harrison': {'n_is_sb': '0'},
 'president buchanan': {'n_is_sb': '0'},
 'president bush': {'n_is_sb': '0'},
 'president carter': {'n_is_sb': '0'},
 'president cleveland': {'n_is_sb': '0'},
 'president clinton': {'n_is_sb': '0'},
 'president coolidge': {'n_is_sb': '0'},
 'president eisenhower': {'n_is_sb': '0'},
 'president fillmore': {'n_is_sb': '0'},
 'president ford': {'n_is_sb': '0'},
 'president franklin roosevelt': {'n_is_sb': '0'},
 'president garfield': {'n_is_sb': '0'},
 'president george w. bush': {'n_is_sb': '0'},
 'president grant': {'n_is_sb': '0'},
 'president harding': {'n_is_sb': '0'},
 'president harrison': {'n_is_sb': '0'},
 'president hayes': {'n_is_sb': '0'},
 'president hoover': {'n_is_sb': '0'},
 'president jefferson': {'n_is_sb': '0'},
 'president john adams': {'n_is_sb': '0'},
 'president john f. kennedy': {'n_is_sb': '0'},
 'president john quincy adams': {'n_is_sb': '0'},
 'president johnson': {'n_is_sb': '0'},
 'president kennedy': {'n_is_sb': '0'},
 'president lincoln': {'n_is_sb': '0'},
 'president lyndon johnson': {'n_is_sb': '0'},
 'president madison': {'n_is_sb': '0'},
 'president mckinley': {'n_is_sb': '0'},
 'president monroe': {'n_is_sb': '0'},
 'president nixon': {'n_is_sb': '0'},
 'president of the united states': {'n_is_sb': '0'},
 'president pierce': {'n_is_sb': '0'},
 'president polk': {'n_is_sb': '0'},
 'president reagan': {'n_is_sb': '0'},
 'president roosevelt': {'n_is_sb': '0'},
 'president taft': {'n_is_sb': '0'},
 'president taylor': {'n_is_sb': '0'},
 'president theodore roosevelt': {'n_is_sb': '0'},
 'president truman': {'n_is_sb': '0'},
 'president tyler': {'n_is_sb': '0'},
 'president van buren': {'n_is_sb': '0'},
 'president washington': {'n_is_sb': '0'},
 'president william henry harrison': {'n_is_sb': '0'},
 'president wilson': {'n_is_sb': '0'},
 'presiding officer': {'n_is_sb': '0'},
 'presley': {'n_is_sb': '0'},
 'press agent': {'n_is_sb': '0'},
 'press lord': {'n_is_sb': '0'},
 'press photographer': {'n_is_sb': '0'},
 'preteenager': {'n_is_sb': '0'},
 'preteen': {'n_is_sb': '0'},
 'preterist': {'n_is_sb': '0'},
 'preterm baby': {'n_is_sb': '0'},
 'preterm infant': {'n_is_sb': '0'},
 'pretor': {'n_is_sb': '0'},
 'prevailing party': {'n_is_sb': '0'},
 'prevaricator': {'n_is_sb': '0'},
 'priacanthus arenatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'priacanthus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'priam': {'n_is_sb': '0'},
 'priapus': {'n_is_sb': '0'},
 'pricket': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prickleback': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prickteaser': {'n_is_sb': '0'},
 'priest-doctor': {'n_is_sb': '0'},
 'priestley': {'n_is_sb': '0'},
 'prig': {'n_is_sb': '0'},
 'prima ballerina': {'n_is_sb': '0'},
 'prima donna': {'n_is_sb': '0'},
 'primary care physician': {'n_is_sb': '0'},
 'primates': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prime minister': {'n_is_sb': '0'},
 'prime mover': {'n_is_sb': '2', 'n_is_sth': '2'},
 'primigravida': {'n_is_sb': '0'},
 'primipara': {'n_is_sb': '0'},
 'primitive person': {'n_is_sb': '0'},
 'primogenitor': {'n_is_sb': '0'},
 'primordial dwarf': {'n_is_sb': '0'},
 'primus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'prince albert': {'n_is_sb': '2', 'n_is_sth': '2'},
 'prince charles': {'n_is_sb': '0'},
 'prince charming': {'n_is_sb': '0'},
 'prince consort': {'n_is_sb': '0'},
 'prince edward': {'n_is_sb': '0'},
 'prince eugene of savoy': {'n_is_sb': '0'},
 'prince fumimaro konoe': {'n_is_sb': '0'},
 'prince fumimaro konoye': {'n_is_sb': '0'},
 'prince klemens wenzel nepomuk lothar von metternich': {'n_is_sb': '0'},
 'prince of darkness': {'n_is_sb': '0'},
 'prince of smolensk': {'n_is_sb': '0'},
 'prince of wales': {'n_is_sb': '0'},
 'prince otto eduard leopold von bismarck': {'n_is_sb': '0'},
 'prince otto von bismarck': {'n_is_sb': '0'},
 'prince peter kropotkin': {'n_is_sb': '0'},
 'prince philip': {'n_is_sb': '0'},
 'prince rupert': {'n_is_sb': '0'},
 'princess diana': {'n_is_sb': '0'},
 'princess grace of monaco': {'n_is_sb': '0'},
 'princess of wales': {'n_is_sb': '0'},
 'princess royal': {'n_is_sb': '0'},
 'principal investigator': {'n_is_sb': '0'},
 'prinia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'print seller': {'n_is_sb': '0'},
 "printer's devil": {'n_is_sb': '0'},
 'printmaker': {'n_is_sb': '0'},
 'priodontes giganteus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prionace glauca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prionotus carolinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prioress': {'n_is_sb': '0'},
 'prison chaplain': {'n_is_sb': '0'},
 'prison guard': {'n_is_sb': '0'},
 'prisoner of war': {'n_is_sb': '0'},
 'pristis pectinatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'private detective': {'n_is_sb': '0'},
 'private eye': {'n_is_sb': '0'},
 'private instructor': {'n_is_sb': '0'},
 'private investigator': {'n_is_sb': '0'},
 'privateersman': {'n_is_sb': '0'},
 'privateer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'prize winner': {'n_is_sb': '0'},
 'prizefighter': {'n_is_sb': '0'},
 'pro-lifer': {'n_is_sb': '0'},
 'probability theorist': {'n_is_sb': '0'},
 'probation officer': {'n_is_sb': '0'},
 'problem solver': {'n_is_sb': '0'},
 'proboscidean': {'n_is_sb': '3', 'n_is_sth': '3'},
 'proboscis monkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'procaryote': {'n_is_sb': '3', 'n_is_sth': '3'},
 'procavia capensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'procellaria aequinoctialis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'procellariiform seabird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'process-server': {'n_is_sb': '2', 'n_is_sth': '2'},
 'prociphilus tessellatus': {'n_is_sb': '0'},
 'procnias': {'n_is_sb': '3', 'n_is_sth': '3'},
 'proconsul': {'n_is_sb': '0'},
 'procrastinator': {'n_is_sb': '0'},
 'procrustes': {'n_is_sb': '0'},
 'proctologist': {'n_is_sb': '0'},
 'procurer': {'n_is_sb': '0'},
 'procuress': {'n_is_sb': '0'},
 'procyon cancrivorus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'procyon lotor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'procyonid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'professional dancer': {'n_is_sb': '0'},
 'professional golfer': {'n_is_sb': '0'},
 'professional person': {'n_is_sb': '0'},
 'professional tennis player': {'n_is_sb': '0'},
 'profit taker': {'n_is_sb': '0'},
 'progne subis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'progne': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prognosticator': {'n_is_sb': '0'},
 'prohibitionist': {'n_is_sb': '0'},
 'projectionist': {'n_is_sb': '0'},
 'prokaryote': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prokhorov': {'n_is_sb': '0'},
 'prokofiev': {'n_is_sb': '0'},
 'prometheus': {'n_is_sb': '0'},
 'promisee': {'n_is_sb': '0'},
 'promiser': {'n_is_sb': '0'},
 'promisor': {'n_is_sb': '0'},
 'promoter': {'n_is_sb': '0'},
 'prompter': {'n_is_sb': '0'},
 'promulgator': {'n_is_sb': '0'},
 'prongbuck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pronghorn antelope': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pronghorn': {'n_is_sb': '3', 'n_is_sth': '3'},
 'propagator': {'n_is_sb': '0'},
 'property man': {'n_is_sb': '0'},
 'property master': {'n_is_sb': '0'},
 'property owner': {'n_is_sb': '0'},
 'prophetess': {'n_is_sb': '0'},
 'propman': {'n_is_sb': '0'},
 'proponent': {'n_is_sb': '0'},
 'proposer': {'n_is_sb': '0'},
 'propositus': {'n_is_sb': '0'},
 'proprietress': {'n_is_sb': '0'},
 'prosecuting attorney': {'n_is_sb': '0'},
 'prosecuting officer': {'n_is_sb': '0'},
 'proselyte': {'n_is_sb': '0'},
 'proserpina': {'n_is_sb': '0'},
 'proserpine': {'n_is_sb': '0'},
 'prosimian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prosopium cylindraceum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prosopium williamsonii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prosopium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prospector': {'n_is_sb': '0'},
 'prosper meniere': {'n_is_sb': '0'},
 'prosthetist': {'n_is_sb': '0'},
 'prosthodontist': {'n_is_sb': '0'},
 'protectionist': {'n_is_sb': '0'},
 'protective covering': {'n_is_sb': '0'},
 'protector of boundaries': {'n_is_sb': '0'},
 'protegee': {'n_is_sb': '0'},
 'proteles cristata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'proteles': {'n_is_sb': '3', 'n_is_sth': '3'},
 'proterochampsa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'protestant deacon': {'n_is_sb': '0'},
 'protestant': {'n_is_sb': '0', 'cap_word': 'Protestant'},
 'protester': {'n_is_sb': '0'},
 'proteus anguinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'proteus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'protistan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'protista': {'n_is_sb': '3', 'n_is_sth': '3'},
 'protist': {'n_is_sb': '3', 'n_is_sth': '3'},
 'protoavis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'protoceratops': {'n_is_sb': '3', 'n_is_sth': '3'},
 'protoctist': {'n_is_sb': '3', 'n_is_sth': '3'},
 'protohippus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'protomammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prototherian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'protozoa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'protozoologist': {'n_is_sb': '0'},
 'protozoon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'proturan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'proudhon': {'n_is_sb': '0'},
 'proust': {'n_is_sb': '0'},
 'provider': {'n_is_sb': '0', 'nn_to_vb': 'provide'},
 'provisioner': {'n_is_sb': '0'},
 'provoked': {'n_is_sb': '0', 'sb_be_jj': '', 'vbd_eq_vbn': ''},
 'provoker': {'n_is_sb': '0'},
 'provost marshal': {'n_is_sb': '0'},
 'prude': {'n_is_sb': '0'},
 'prunella modularis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'prunella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pruner': {'n_is_sb': '2', 'n_is_sth': '2'},
 'prussian': {'n_is_sb': '2', 'cap_word': 'Prussian', 'n_is_sth': '2'},
 "przevalski's horse": {'n_is_sb': '3', 'n_is_sth': '3'},
 "przewalski's horse": {'n_is_sb': '3', 'n_is_sth': '3'},
 'psaltriparus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'psenes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'psephologist': {'n_is_sb': '0'},
 'psephurus gladis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'psetta maxima': {'n_is_sb': '3', 'n_is_sth': '3'},
 'psettichthys melanostichus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pseudaletia unipuncta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pseudechis porphyriacus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pseudemys concinna': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pseudemys rubriventris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pseudemys scripta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pseudococcus comstocki': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pseudococcus fragilis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pseudohermaphrodite': {'n_is_sb': '0'},
 'pseudomonad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pseudomonas pyocanea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pseudomonas solanacearum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pseudomonas': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pseudomonodaceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pseudopleuronectes americanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pseudoryx nghetinhensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pseudoscorpion': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pseudo': {'n_is_sb': '0'},
 'pseud': {'n_is_sb': '0'},
 'psittacosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'psittacosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'psittacula krameri': {'n_is_sb': '3', 'n_is_sth': '3'},
 'psittacula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'psittacus erithacus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'psittacus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'psocid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'psocopterous insect': {'n_is_sb': '3', 'n_is_sth': '3'},
 'psophia crepitans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'psychiatrist': {'n_is_sb': '0'},
 'psychoanalyst': {'n_is_sb': '0'},
 'psychodid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'psycholinguist': {'n_is_sb': '0'},
 'psychologist': {'n_is_sb': '0', 'nn_to_jj': 'psychological', 'nn_to_rb': 'psychologically'},
 'psychoneurotic': {'n_is_sb': '0'},
 'psychopath': {'n_is_sb': '0'},
 'psychophysicist': {'n_is_sb': '0'},
 'psychopomp': {'n_is_sb': '0'},
 'psychotherapist': {'n_is_sb': '0'},
 'psychotic person': {'n_is_sb': '0'},
 'psychotic': {'n_is_sb': '0'},
 'psycho': {'n_is_sb': '0'},
 'psylla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'psyllid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ptah': {'n_is_sb': '0'},
 'pteridologist': {'n_is_sb': '0'},
 'pternohyla fodiens': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pternohyla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pterocles alchata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pterocles indicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pterocles': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pteroclididae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pterocnemia pennata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pterocnemia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pterodactylidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pterois': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pteropus capestratus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pteropus hypomelanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pterosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ptilocercus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ptilocrinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ptilonorhynchidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ptilonorhynchus violaceus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ptilonorhynchus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ptloris paradisea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ptloris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ptolemy ii': {'n_is_sb': '0'},
 'ptolemy i': {'n_is_sb': '0'},
 'ptolemy': {'n_is_sb': '0'},
 'ptyas mucosus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ptychozoon homalocephalum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ptychozoon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pubic louse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'public defender': {'n_is_sb': '0'},
 'public executioner': {'n_is_sb': '0'},
 'public figure': {'n_is_sb': '0'},
 'public prosecutor': {'n_is_sb': '0'},
 'public relations man': {'n_is_sb': '0'},
 'public relations person': {'n_is_sb': '0'},
 'public servant': {'n_is_sb': '0'},
 'public speaker': {'n_is_sb': '0'},
 'publican': {'n_is_sb': '0'},
 'publiciser': {'n_is_sb': '0'},
 'publicist': {'n_is_sb': '0'},
 'publicity man': {'n_is_sb': '0'},
 'publicizer': {'n_is_sb': '0'},
 'publius aelius hadrianus': {'n_is_sb': '0'},
 'publius cornelius scipio africanus major': {'n_is_sb': '0'},
 'publius cornelius scipio': {'n_is_sb': '0'},
 'publius ovidius naso': {'n_is_sb': '0'},
 'publius terentius afer': {'n_is_sb': '0'},
 'publius vergilius maro': {'n_is_sb': '0'},
 'puccini': {'n_is_sb': '0'},
 'pudden-head': {'n_is_sb': '0'},
 'pudding head': {'n_is_sb': '0'},
 'pudding-wife': {'n_is_sb': '3', 'n_is_sth': '3'},
 'puddingwife': {'n_is_sb': '3', 'n_is_sth': '3'},
 'puddler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pudge': {'n_is_sb': '0'},
 'puerpera': {'n_is_sb': '0'},
 'puerto rican': {'n_is_sb': '0'},
 'puff adder': {'n_is_sb': '3', 'n_is_sth': '3'},
 'puffbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'puffinus puffinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'puffinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'puffin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pug-dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pugin': {'n_is_sb': '0'},
 'puku': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pulex irritans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pulicidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pulitzer': {'n_is_sb': '0'},
 'puller': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pullet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pullman porter': {'n_is_sb': '0'},
 'pumpkinseed': {'n_is_sb': '3', 'n_is_sth': '3'},
 'punching bag': {'n_is_sb': '2', 'n_is_sth': '2'},
 'punjabi': {'n_is_sb': '2', 'n_is_sth': '2'},
 'punk rocker': {'n_is_sb': '0'},
 'punkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'punkie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'punky': {'n_is_sb': '3', 'n_is_sth': '3', 'jj_to_jjr': 'punkier', 'jj_to_jjs': 'punkiest'},
 'punster': {'n_is_sb': '0'},
 'puppet leader': {'n_is_sb': '0'},
 'puppet ruler': {'n_is_sb': '0'},
 'puppeteer': {'n_is_sb': '0'},
 'purcell': {'n_is_sb': '0'},
 'purchasing agent': {'n_is_sb': '0'},
 'pureblood': {'n_is_sb': '3', 'n_is_sth': '3'},
 'purist': {'n_is_sb': '0'},
 'purkinje': {'n_is_sb': '0'},
 'purple bacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'purple emperor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'purple finch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'purple gallinule': {'n_is_sb': '3', 'n_is_sth': '3'},
 'purple grackle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'purple martin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pursued': {'n_is_sb': '0', 'vbd_to_vb': 'pursue', 'vbn_to_vb': 'pursue', 'vbn_to_vbg': 'pursuing', 'vbd_eq_vbn': ''},
 'purveyor': {'n_is_sb': '0'},
 'pusey': {'n_is_sb': '0'},
 'pushan': {'n_is_sb': '0'},
 'pushkin': {'n_is_sb': '0'},
 'pushover': {'n_is_sb': '0'},
 'pushtun': {'n_is_sb': '0'},
 'pussycat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'putin': {'n_is_sb': '0'},
 'putterer': {'n_is_sb': '0'},
 'putter': {'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'putz': {'n_is_sb': '2', 'n_is_sth': '2'},
 'pycnogonid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pye-dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pygmalion': {'n_is_sb': '0'},
 'pygmy chimpanzee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pygmy marmoset': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pygmy mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pygmy sperm whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pygopus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pygoscelis adeliae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pygoscelis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pylodictus olivaris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pylodictus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pynchon': {'n_is_sb': '0'},
 'pyotr alexeyevich kropotkin': {'n_is_sb': '0'},
 'pyotr ilych tchaikovsky': {'n_is_sb': '0'},
 'pyotr tchaikovsky': {'n_is_sb': '0'},
 'pyralid moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pyralid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pyralis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pyrausta nubilalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pyrausta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pyrocephalus rubinus mexicanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pyrocephalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pyrographer': {'n_is_sb': '0'},
 'pyromancer': {'n_is_sb': '0'},
 'pyromaniac': {'n_is_sb': '0'},
 'pyrophorus noctiluca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pyrophorus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pyrrhula pyrrhula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pyrrhula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pyrrhuloxia sinuata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pyrrhuloxia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pyrrhus': {'n_is_sb': '0'},
 'pythagoras': {'n_is_sb': '0'},
 'pythias': {'n_is_sb': '0'},
 'pythia': {'n_is_sb': '0'},
 'pythius': {'n_is_sb': '0'},
 'python molurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'python reticulatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'python sebae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'python variegatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pythoness': {'n_is_sb': '0'},
 'pythonidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'pythoninae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'qaddafi': {'n_is_sb': '0'},
 'qadhafi': {'n_is_sb': '0'},
 'qadi': {'n_is_sb': '0'},
 'qatari': {'n_is_sb': '0'},
 'quack-quack': {'n_is_sb': '3', 'n_is_sth': '3'},
 'quadripara': {'n_is_sb': '0'},
 'quadriplegic': {'n_is_sb': '0'},
 'quadruplet': {'n_is_sb': '0'},
 'quad': {'n_is_sb': '2', 'n_is_sth': '2'},
 'quaestor': {'n_is_sb': '0'},
 'quaffer': {'n_is_sb': '0'},
 'quagga': {'n_is_sb': '3', 'n_is_sth': '3'},
 'quahaug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'quahog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'quaker': {'n_is_sb': '0', 'cap_word': 'Quaker'},
 'qualifier': {'n_is_sb': '2', 'n_is_sth': '2'},
 'quapaw': {'n_is_sb': '0'},
 'quarreler': {'n_is_sb': '0'},
 'quarreller': {'n_is_sb': '0'},
 'quarrier': {'n_is_sb': '0'},
 'quarryman': {'n_is_sb': '0'},
 'quarter horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'quarterback': {'n_is_sb': '0'},
 'quartermaster general': {'n_is_sb': '0'},
 'quebecois': {'n_is_sb': '0'},
 'quechua': {'n_is_sb': '2', 'n_is_sth': '2'},
 'queen bee': {'n_is_sb': '0'},
 'queen consort': {'n_is_sb': '0'},
 'queen dowager': {'n_is_sb': '0'},
 'queen mother': {'n_is_sb': '0'},
 'queen of england': {'n_is_sb': '0'},
 'queen of the may': {'n_is_sb': '0'},
 'queen regent': {'n_is_sb': '0'},
 'queen regnant': {'n_is_sb': '0'},
 'queen triggerfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'queen victoria': {'n_is_sb': '0'},
 "queen's counsel": {'n_is_sb': '0'},
 'queenfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'queer bird': {'n_is_sb': '0'},
 'queer duck': {'n_is_sb': '0'},
 'queer': {'n_is_sb': '2', 'n_is_sth': '2', 'jj_to_jjr': 'queerer', 'jj_to_jjs': 'queerest'},
 'quentin jerome tarantino': {'n_is_sb': '0'},
 'quentin tarantino': {'n_is_sb': '0'},
 'querier': {'n_is_sb': '2', 'n_is_sth': '2'},
 'quester': {'n_is_sb': '0'},
 'question master': {'n_is_sb': '0'},
 'quetzal bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'quetzalcoatl': {'n_is_sb': '0'},
 'quetzal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'quiaquia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'quibbler': {'n_is_sb': '0'},
 'quiche': {'n_is_sb': '2', 'n_is_sth': '2'},
 'quick study': {'n_is_sb': '0'},
 'quietist': {'n_is_sb': '0'},
 'quincy': {'n_is_sb': '0'},
 'quine': {'n_is_sb': '0'},
 'quinnat salmon': {'n_is_sb': '0'},
 'quintipara': {'n_is_sb': '0'},
 'quintuplet': {'n_is_sb': '0'},
 'quintus septimius florens tertullianus': {'n_is_sb': '0'},
 'quint': {'n_is_sb': '2', 'n_is_sth': '2'},
 'quin': {'n_is_sb': '2', 'n_is_sth': '2'},
 'quiscalus quiscula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'quizmaster': {'n_is_sb': '0'},
 'quizzer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'quoter': {'n_is_sb': '0'},
 'r. b. cattell': {'n_is_sb': '0'},
 'r. buckminster fuller': {'n_is_sb': '0'},
 'r. j. mitchell': {'n_is_sb': '0'},
 'rabbi moses ben maimon': {'n_is_sb': '0'},
 'rabbit bandicoot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rabbit-eared bandicoot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rabbitfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rabble-rouser': {'n_is_sb': '0'},
 'rabelais': {'n_is_sb': '0'},
 'raccoon dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'raccoon fox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'race driver': {'n_is_sb': '2', 'n_is_sth': '2'},
 'race horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'race runner': {'n_is_sb': '3', 'n_is_sth': '3'},
 'racerunner': {'n_is_sb': '3', 'n_is_sth': '3'},
 'racetrack tout': {'n_is_sb': '0'},
 'rachel carson': {'n_is_sb': '0'},
 'rachel louise carson': {'n_is_sb': '0'},
 'rachmaninoff': {'n_is_sb': '0'},
 'rachmaninov': {'n_is_sb': '0'},
 'rachycentron canadum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'racialist': {'n_is_sb': '0'},
 'racine': {'n_is_sb': '0'},
 'racist': {'n_is_sb': '0'},
 'racker': {'n_is_sb': '0'},
 'raconteur': {'n_is_sb': '0'},
 'racoon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'radclyffe hall': {'n_is_sb': '0'},
 'radhakrishnan': {'n_is_sb': '0'},
 'radio announcer': {'n_is_sb': '0'},
 'radio operator': {'n_is_sb': '0'},
 'radiochemist': {'n_is_sb': '0'},
 'radiographer': {'n_is_sb': '0'},
 'radiolarian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'radiolaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'radiologic technologist': {'n_is_sb': '0'},
 'radiologist': {'n_is_sb': '0'},
 'radiotherapist': {'n_is_sb': '0'},
 'raffaello santi': {'n_is_sb': '0'},
 'raffaello sanzio': {'n_is_sb': '0'},
 'raffles': {'n_is_sb': '0'},
 'raftman': {'n_is_sb': '0'},
 'raftsman': {'n_is_sb': '0'},
 'ragnar anton kittil frisch': {'n_is_sb': '0'},
 'ragnar frisch': {'n_is_sb': '0'},
 'ragpicker': {'n_is_sb': '0'},
 'ragsorter': {'n_is_sb': '0'},
 'rahu': {'n_is_sb': '0'},
 'raider': {'n_is_sb': '0'},
 'rail-splitter': {'n_is_sb': '0'},
 'railbird': {'n_is_sb': '0'},
 'railroad engineer': {'n_is_sb': '0'},
 'railroad man': {'n_is_sb': '0'},
 'railroad worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'railroader': {'n_is_sb': '0'},
 'railway man': {'n_is_sb': '0'},
 'railwayman': {'n_is_sb': '0'},
 'rain-giver': {'n_is_sb': '0'},
 'rain-in-the-face': {'n_is_sb': '0'},
 'rainbow fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rainbow lorikeet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rainbow perch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rainbow runner': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rainbow seaperch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rainbow smelt': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rainbow trout': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rainer maria rilke': {'n_is_sb': '0'},
 'rainmaker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'raisin moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'raja batis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'raja erinacea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'raja laevis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'raja radiata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rajpoot': {'n_is_sb': '0'},
 'rajput': {'n_is_sb': '0'},
 'ralegh': {'n_is_sb': '0'},
 'ralph barton perry': {'n_is_sb': '0'},
 'ralph bunche': {'n_is_sb': '0'},
 'ralph ellison': {'n_is_sb': '0'},
 'ralph johnson bunche': {'n_is_sb': '0'},
 'ralph richardson': {'n_is_sb': '0'},
 'ralph vaughan williams': {'n_is_sb': '0'},
 'ralph waldo ellison': {'n_is_sb': '0'},
 'ralph waldo emerson': {'n_is_sb': '0'},
 'ramachandra': {'n_is_sb': '0'},
 'rama': {'n_is_sb': '0'},
 'rambouillet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rameau': {'n_is_sb': '0'},
 'rameses ii': {'n_is_sb': '0'},
 'rameses the great': {'n_is_sb': '0'},
 'rameses': {'n_is_sb': '0'},
 'ramesses ii': {'n_is_sb': '0'},
 'ramesses the great': {'n_is_sb': '0'},
 'ramesses': {'n_is_sb': '0'},
 'ramman': {'n_is_sb': '0'},
 'ramon lully': {'n_is_sb': '0'},
 'ramon y cajal': {'n_is_sb': '0'},
 'ramphomicron': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ramses ii': {'n_is_sb': '0'},
 'ramses the great': {'n_is_sb': '0'},
 'ramses': {'n_is_sb': '0'},
 'rana cascadae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rana catesbeiana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rana clamitans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rana goliath': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rana palustris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rana pipiens': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rana sylvatica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rana tarahumarae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rana temporaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ranatra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rana': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ranch hand': {'n_is_sb': '0'},
 'rancher': {'n_is_sb': '0'},
 'randall jarrell': {'n_is_sb': '0'},
 'ranee': {'n_is_sb': '0'},
 'range animal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ranger': {'n_is_sb': '0'},
 'rangifer arcticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rangifer caribou': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rangifer tarandus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rangifer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ranid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ranker': {'n_is_sb': '0'},
 'rankin': {'n_is_sb': '0'},
 'ranter': {'n_is_sb': '0'},
 'raoul dufy': {'n_is_sb': '0'},
 'rape suspect': {'n_is_sb': '0'},
 'raphicerus campestris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'raphus cucullatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'raptores': {'n_is_sb': '3', 'n_is_sth': '3'},
 'raptorial bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rara avis': {'n_is_sb': '2', 'n_is_sth': '2'},
 'rare bird': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ras tafari makonnen': {'n_is_sb': '0'},
 'ras tafari': {'n_is_sb': '0'},
 'raskolnikov': {'n_is_sb': '0'},
 'rask': {'n_is_sb': '0'},
 'rasmus christian rask': {'n_is_sb': '0'},
 'rasmussen': {'n_is_sb': '0'},
 'rasputin': {'n_is_sb': '0'},
 'rastafarian': {'n_is_sb': '0'},
 'rasta': {'n_is_sb': '0'},
 'rat chinchilla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rat kangaroo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rat snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rat terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rat-catcher': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ratbite fever bacterium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ratel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ratepayer': {'n_is_sb': '0'},
 'ratifier': {'n_is_sb': '0'},
 'ratiocinator': {'n_is_sb': '0'},
 'rationalist': {'n_is_sb': '0'},
 'ratite bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ratite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rattail fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rattail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ratter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'rattigan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'rattus norvegicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rattus rattus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rattus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'raver': {'n_is_sb': '0'},
 'ravi shankar': {'n_is_sb': '0'},
 'ravisher': {'n_is_sb': '0'},
 'raw recruit': {'n_is_sb': '0'},
 'ray bradbury': {'n_is_sb': '0'},
 'ray cattell': {'n_is_sb': '0'},
 'ray douglas bradbury': {'n_is_sb': '0'},
 'ray m. dolby': {'n_is_sb': '0'},
 'ray robinson': {'n_is_sb': '0'},
 'rayleigh': {'n_is_sb': '0'},
 'raymond b. cattell': {'n_is_sb': '0'},
 'raymond bernard cattell': {'n_is_sb': '0'},
 'raymond chandler': {'n_is_sb': '0'},
 'raymond lully': {'n_is_sb': '0'},
 'raymond thornton chandler': {'n_is_sb': '0'},
 'razor clam': {'n_is_sb': '3', 'n_is_sth': '3'},
 'razor fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'razor-billed auk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'razor-fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'razorback hog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'razorbacked hog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'razorbill': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ra': {'n_is_sb': '2', 'n_is_sth': '2'},
 'rea silvia': {'n_is_sb': '0'},
 'reading teacher': {'n_is_sb': '0'},
 'reagan': {'n_is_sb': '0'},
 'real estate agent': {'n_is_sb': '0'},
 'real estate broker': {'n_is_sb': '0'},
 'realist': {'n_is_sb': '0'},
 'realtor': {'n_is_sb': '0'},
 'rear admiral': {'n_is_sb': '0'},
 'reasoner': {'n_is_sb': '0'},
 'reaumur': {'n_is_sb': '2', 'n_is_sth': '2'},
 'rebecca rolfe': {'n_is_sb': '0'},
 'rebecca west': {'n_is_sb': '0'},
 'rebecca': {'n_is_sb': '0'},
 'rebekah': {'n_is_sb': '0'},
 'rebuker': {'n_is_sb': '0'},
 'rebutter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'reb': {'n_is_sb': '0'},
 'recitalist': {'n_is_sb': '0'},
 'reciter': {'n_is_sb': '0'},
 'reckoner': {'n_is_sb': '2', 'n_is_sth': '2'},
 'reconciler': {'n_is_sb': '0'},
 'record-breaker': {'n_is_sb': '0'},
 'record-holder': {'n_is_sb': '0'},
 'record-keeper': {'n_is_sb': '0'},
 'recorder player': {'n_is_sb': '2', 'n_is_sth': '2'},
 'recoverer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'recreant': {'n_is_sb': '0'},
 'recruiter': {'n_is_sb': '0'},
 'recruiting-sergeant': {'n_is_sb': '0'},
 'rectifier': {'n_is_sb': '2', 'n_is_sth': '2'},
 'recusant': {'n_is_sb': '0'},
 'red admiral': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red algae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red cloud': {'n_is_sb': '0'},
 'red coral': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red deer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red drum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red eft': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red fox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red goatfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red grouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red indian': {'n_is_sb': '0'},
 'red jungle fowl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red laver': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red man': {'n_is_sb': '0'},
 'red mullet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red panda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red phalarope': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red poll': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red porgy': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red rat snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red rockfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red salmon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red setter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red siskin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red snapper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red spider mite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red spider': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red underwing': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red wolf': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red-backed lemming': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red-backed mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red-backed sandpiper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red-bellied snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red-bellied terrapin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red-bellied turtle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red-breasted merganser': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red-breasted nuthatch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red-breasted sapsucker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red-breasted snipe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red-eyed vireo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red-header': {'n_is_sb': '0'},
 'red-legged partridge': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red-necked grebe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red-shafted flicker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red-shouldered hawk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red-spotted purple': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red-tailed hawk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'red-winged blackbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'redactor': {'n_is_sb': '0'},
 'redact': {'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'redback vole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'redbelly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'redbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'redbone': {'n_is_sb': '3', 'n_is_sth': '3'},
 'redbreast': {'n_is_sb': '3', 'n_is_sth': '3'},
 'redbug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'redcap': {'n_is_sb': '0'},
 'redcoat': {'n_is_sb': '0'},
 'redeemer': {'n_is_sb': '0'},
 'redfin pickerel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'redfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'redford': {'n_is_sb': '0'},
 'redheaded woodpecker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'redheader': {'n_is_sb': '2', 'n_is_sth': '2'},
 'redhead': {'n_is_sb': '0'},
 'redhorse sucker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'redhorse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'redpoll': {'n_is_sb': '3', 'n_is_sth': '3'},
 'redshank': {'n_is_sb': '3', 'n_is_sth': '3'},
 'redskin': {'n_is_sb': '0'},
 'redstart': {'n_is_sb': '3', 'n_is_sth': '3'},
 'redtail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'reduviid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'redwing': {'n_is_sb': '3', 'n_is_sth': '3'},
 'reed bunting': {'n_is_sb': '3', 'n_is_sth': '3'},
 'reedbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'reef squirrelfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'reef whitetip shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'reeler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'reeve': {'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'refiner': {'n_is_sb': '2', 'n_is_sth': '2'},
 'refinisher': {'n_is_sb': '0'},
 'reform jew': {'n_is_sb': '0'},
 'reformer': {'n_is_sb': '0'},
 'refuse collector': {'n_is_sb': '2', 'n_is_sth': '2'},
 'refuter': {'n_is_sb': '0'},
 'ref': {'n_is_sb': '0'},
 'regalecus glesne': {'n_is_sb': '3', 'n_is_sth': '3'},
 'reginald carey harrison': {'n_is_sb': '0'},
 'reginald joseph mitchell': {'n_is_sb': '0'},
 'reginald marsh': {'n_is_sb': '0'},
 'regiomontanus': {'n_is_sb': '0'},
 'registered nurse': {'n_is_sb': '0'},
 'registered representative': {'n_is_sb': '0'},
 'registrant': {'n_is_sb': '0'},
 'regius professor': {'n_is_sb': '0'},
 'regulus calendula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'regulus regulus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'regulus satrata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rehnquist': {'n_is_sb': '0'},
 'reichstein': {'n_is_sb': '0'},
 'reid': {'n_is_sb': '0'},
 'reinhold niebuhr': {'n_is_sb': '0'},
 'reiter': {'n_is_sb': '0'},
 'relative-in-law': {'n_is_sb': '0'},
 'relief pitcher': {'n_is_sb': '0'},
 'reliever': {'n_is_sb': '2', 'n_is_sth': '2'},
 'religionist': {'n_is_sb': '0'},
 'religious leader': {'n_is_sb': '0'},
 'religious mystic': {'n_is_sb': '0'},
 'religious outcast': {'n_is_sb': '0'},
 'religious person': {'n_is_sb': '0'},
 'rembrandt harmensz van rijn': {'n_is_sb': '0'},
 'rembrandt van rijn': {'n_is_sb': '0'},
 'rembrandt van ryn': {'n_is_sb': '0'},
 'rembrandt': {'n_is_sb': '0'},
 'remilegia australis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'remittance man': {'n_is_sb': '0'},
 'remora': {'n_is_sb': '3', 'n_is_sth': '3'},
 'remount': {'n_is_sb': '3', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_sth': '3'},
 'remunerator': {'n_is_sb': '0'},
 'remus': {'n_is_sb': '0'},
 'renaissance man': {'n_is_sb': '0'},
 'renata tebaldi': {'n_is_sb': '0'},
 'rene antoine ferchault de reaumur': {'n_is_sb': '0'},
 'rene descartes': {'n_is_sb': '0'},
 'rene magritte': {'n_is_sb': '0'},
 'rene-robert cavelier': {'n_is_sb': '0'},
 'renoir': {'n_is_sb': '0'},
 'renovator': {'n_is_sb': '0'},
 'rent collector': {'n_is_sb': '0'},
 'rentier': {'n_is_sb': '0'},
 'reoviridae': {'n_is_sb': '0'},
 'reovirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'repairer': {'n_is_sb': '0'},
 'repatriate': {'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'reproacher': {'n_is_sb': '0'},
 'reprover': {'n_is_sb': '0'},
 'reptile family': {'n_is_sb': '2', 'n_is_sth': '2'},
 'reptilia': {'n_is_sb': '2', 'n_is_sth': '2'},
 'rep': {'n_is_sb': '2', 'n_is_sth': '2'},
 'requiem shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'research director': {'n_is_sb': '0'},
 'research worker': {'n_is_sb': '0'},
 'reservist': {'n_is_sb': '0'},
 'resident commissioner': {'n_is_sb': '0'},
 'resident physician': {'n_is_sb': '0'},
 'resister': {'n_is_sb': '2', 'n_is_sth': '2'},
 'respecter': {'n_is_sb': '0'},
 'respighi': {'n_is_sb': '0'},
 'respiratory syncytial virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'resplendent quetzel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'resplendent trogon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'responder': {'n_is_sb': '2', 'n_is_sth': '2'},
 'restaurant attendant': {'n_is_sb': '0'},
 'restauranter': {'n_is_sb': '0'},
 'restaurateur': {'n_is_sb': '0'},
 'rester': {'n_is_sb': '0'},
 'restorer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'restrainer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'retail merchant': {'n_is_sb': '0'},
 'retaliator': {'n_is_sb': '0'},
 'reticulated python': {'n_is_sb': '3', 'n_is_sth': '3'},
 'reticulitermes flanipes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'reticulitermes lucifugus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'reticulitermes': {'n_is_sb': '2', 'n_is_sth': '2'},
 'retired person': {'n_is_sb': '0'},
 'retiree': {'n_is_sb': '0'},
 'retreatant': {'n_is_sb': '0'},
 'retriever': {'n_is_sb': '0'},
 'retrovirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'returning officer': {'n_is_sb': '0'},
 'reuben lucius goldberg': {'n_is_sb': '0'},
 'reuben': {'n_is_sb': '0'},
 'reveler': {'n_is_sb': '0'},
 'reveller': {'n_is_sb': '0'},
 'revenant': {'n_is_sb': '0'},
 'revenuer': {'n_is_sb': '0'},
 'reverend dodgson': {'n_is_sb': '0'},
 'revere': {'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'n_is_sth': '2'},
 'reversioner': {'n_is_sb': '0'},
 'reversionist': {'n_is_sb': '0'},
 'revisionist': {'n_is_sb': '0'},
 'revivalist': {'n_is_sb': '0'},
 'revolutionist': {'n_is_sb': '0', 'nn_to_vb': 'revolutionise', 'nn_to_jj': 'revolutionary'},
 'rewrite man': {'n_is_sb': '0'},
 'rewriter': {'n_is_sb': '0'},
 'rex harrison': {'n_is_sb': '0'},
 'reyes': {'n_is_sb': '0'},
 'reynard': {'n_is_sb': '0'},
 'reynolds': {'n_is_sb': '0'},
 'rhabdomancer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'rhabdovirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rhadamnathus': {'n_is_sb': '0'},
 'rhagoletis pomonella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rhea americana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rhea silvia': {'n_is_sb': '0'},
 'rhesus monkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rhetorician': {'n_is_sb': '0'},
 'rheumatic': {'n_is_sb': '2', 'n_is_sth': '2'},
 'rheumatologist': {'n_is_sb': '0'},
 'rhibhus': {'n_is_sb': '0'},
 'rhincodon typus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rhinoceros antiquitatis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rhinoceros beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rhinoceros family': {'n_is_sb': '2', 'n_is_sth': '2'},
 'rhinoceros unicornis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rhinolaryngologist': {'n_is_sb': '0'},
 'rhinonicteris aurantius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rhinoptera bonasus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rhinovirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rhiptoglossa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rhizobium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rhizopodan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rhizopod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rhode island red': {'n_is_sb': '2', 'n_is_sth': '2'},
 'rhode islander': {'n_is_sb': '0'},
 'rhodes scholar': {'n_is_sb': '0'},
 'rhodesian man': {'n_is_sb': '0'},
 'rhodesian ridgeback': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rhodes': {'n_is_sb': '2', 'cap_word': 'Rhodes', 'n_is_sth': '2'},
 'rhodymenia palmata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rhyacotriton olympicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rhymer': {'n_is_sb': '0'},
 'rhymester': {'n_is_sb': '0'},
 'rhynchoelaps australis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rhynchoelaps': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rhythm and blues musician': {'n_is_sb': '0'},
 'ribald': {'n_is_sb': '0'},
 'ribbed toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ribbon snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ribbon worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ribbonfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ribhus': {'n_is_sb': '0'},
 'ricardo': {'n_is_sb': '0'},
 'rice rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rice weevil': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ricebird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rich man': {'n_is_sb': '0'},
 'rich person': {'n_is_sb': '0'},
 'richard adolph zsigmondy': {'n_is_sb': '0'},
 'richard august carl emil erlenmeyer': {'n_is_sb': '0'},
 'richard brinsley sheridan': {'n_is_sb': '0'},
 'richard buckminster fuller': {'n_is_sb': '0'},
 'richard burbage': {'n_is_sb': '0'},
 'richard burdon haldane': {'n_is_sb': '0'},
 'richard burton': {'n_is_sb': '0'},
 'richard coeur de lion': {'n_is_sb': '0'},
 "richard d'oyly carte": {'n_is_sb': '0'},
 'richard d. fosbury': {'n_is_sb': '0'},
 'richard e. byrd': {'n_is_sb': '0'},
 'richard e. smalley': {'n_is_sb': '0'},
 'richard errett smalley': {'n_is_sb': '0'},
 'richard erskine leakey': {'n_is_sb': '0'},
 'richard evelyn byrd': {'n_is_sb': '0'},
 'richard feynman': {'n_is_sb': '0'},
 'richard haldane': {'n_is_sb': '0'},
 'richard henry lee': {'n_is_sb': '0'},
 'richard henry tawney': {'n_is_sb': '0'},
 'richard hooker': {'n_is_sb': '0'},
 'richard horatio edgar wallace': {'n_is_sb': '0'},
 'richard iii': {'n_is_sb': '0'},
 'richard ii': {'n_is_sb': '0'},
 'richard i': {'n_is_sb': '0'},
 'richard j. roberts': {'n_is_sb': '0'},
 'richard john roberts': {'n_is_sb': '0'},
 'richard jordan gatling': {'n_is_sb': '0'},
 'richard kuhn': {'n_is_sb': '0'},
 'richard leakey': {'n_is_sb': '0'},
 'richard lovelace': {'n_is_sb': '0'},
 'richard m. nixon': {'n_is_sb': '0'},
 'richard milhous nixon': {'n_is_sb': '0'},
 'richard morris hunt': {'n_is_sb': '0'},
 'richard neville': {'n_is_sb': '0'},
 'richard nixon': {'n_is_sb': '0'},
 'richard phillips feynman': {'n_is_sb': '0'},
 'richard rodgers': {'n_is_sb': '0'},
 'richard roe': {'n_is_sb': '0'},
 'richard smalley': {'n_is_sb': '0'},
 'richard starkey': {'n_is_sb': '0'},
 'richard strauss': {'n_is_sb': '0'},
 'richard the lion-hearted': {'n_is_sb': '0'},
 'richard the lionheart': {'n_is_sb': '0'},
 'richard trevithick': {'n_is_sb': '0'},
 'richard upjohn': {'n_is_sb': '0'},
 'richard von krafft-ebing': {'n_is_sb': '0'},
 'richard wagner': {'n_is_sb': '0'},
 'richard wright': {'n_is_sb': '0'},
 'richardson ground squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'richardson vole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'richardson': {'n_is_sb': '0'},
 'richards': {'n_is_sb': '0'},
 'richelieu': {'n_is_sb': '2', 'n_is_sth': '2'},
 'richler': {'n_is_sb': '0'},
 'richmondena cardinalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'richmondena': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rickenbacker': {'n_is_sb': '0'},
 'rickettsias': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rickettsia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rickover': {'n_is_sb': '0'},
 'rider haggard': {'n_is_sb': '0'},
 'ridgeling': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ridgel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ridgil': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ridgling': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ridiculer': {'n_is_sb': '0'},
 'riding horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'riding master': {'n_is_sb': '0'},
 'ridley': {'n_is_sb': '3', 'n_is_sth': '3'},
 'riemann': {'n_is_sb': '0'},
 'riesman': {'n_is_sb': '0'},
 'riffian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'riflebird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rifleman bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'right fielder': {'n_is_sb': '0'},
 'right hander': {'n_is_sb': '2', 'n_is_sth': '2'},
 'right whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'right-hand man': {'n_is_sb': '0'},
 'right-handed pitcher': {'n_is_sb': '0'},
 'right-hander': {'n_is_sb': '0'},
 'right-winger': {'n_is_sb': '0'},
 'righteye flounder': {'n_is_sb': '3', 'n_is_sth': '3'},
 'righteyed flounder': {'n_is_sb': '3', 'n_is_sth': '3'},
 'righthander': {'n_is_sb': '0'},
 'rightist': {'n_is_sb': '0', 'nn_to_vb': 'right', 'nn_to_jj': 'rightful', 'nn_to_rb': 'rightfully'},
 'riley b king': {'n_is_sb': '0'},
 'riley': {'n_is_sb': '0'},
 'rilke': {'n_is_sb': '0'},
 'rimbaud': {'n_is_sb': '0'},
 'rimski-korsakov': {'n_is_sb': '0'},
 'rimsky-korsakov': {'n_is_sb': '0'},
 'ring blackbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ring girl': {'n_is_sb': '0'},
 'ring lardner': {'n_is_sb': '0'},
 'ring ouzel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ring snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ring thrush': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ring-necked parakeet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ring-necked pheasant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ring-necked snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ring-tailed cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ring-tailed lemur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ringdove': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ringed snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ringgold wilmer lardner': {'n_is_sb': '0'},
 'ringhals': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ringlet butterfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ringling': {'n_is_sb': '0'},
 'ringmaster': {'n_is_sb': '0'},
 'ringneck snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ringo starr': {'n_is_sb': '0'},
 'ringtail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rinkhals': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rioter': {'n_is_sb': '0'},
 'rip van winkle': {'n_is_sb': '0'},
 'riparia riparia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'riser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'risk taker': {'n_is_sb': '0'},
 'rissa': {'n_is_sb': '0'},
 'rittenhouse': {'n_is_sb': '0'},
 'ritualist': {'n_is_sb': '0'},
 'ritz': {'n_is_sb': '2', 'n_is_sth': '2'},
 'river cooter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'river dolphin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'river horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'river limpet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'river otter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'river prawn': {'n_is_sb': '3', 'n_is_sth': '3'},
 'river shad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rivetter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'rn': {'n_is_sb': '2', 'n_is_sth': '2'},
 'road agent': {'n_is_sb': '0'},
 'road builder': {'n_is_sb': '2', 'n_is_sth': '2'},
 'road hog': {'n_is_sb': '0'},
 'road mender': {'n_is_sb': '0'},
 'road runner': {'n_is_sb': '0'},
 'roadhog': {'n_is_sb': '0'},
 'roadman': {'n_is_sb': '0'},
 'roadrunner': {'n_is_sb': '3', 'n_is_sth': '3'},
 'roald amundsen': {'n_is_sb': '0'},
 'roald hoffmann': {'n_is_sb': '0'},
 'roan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'roarer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'rob roy': {'n_is_sb': '0'},
 'robber fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'robber frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'robbery suspect': {'n_is_sb': '0'},
 'robbins': {'n_is_sb': '0'},
 'robert a. heinlein': {'n_is_sb': '0'},
 'robert abram bartlett': {'n_is_sb': '0'},
 'robert adam': {'n_is_sb': '0'},
 'robert alexander schumann': {'n_is_sb': '0'},
 'robert andrews millikan': {'n_is_sb': '0'},
 'robert anson heinlein': {'n_is_sb': '0'},
 'robert barany': {'n_is_sb': '0'},
 'robert bartlett': {'n_is_sb': '0'},
 'robert benchley': {'n_is_sb': '0'},
 'robert boyle': {'n_is_sb': '0'},
 'robert browning': {'n_is_sb': '0'},
 'robert brown': {'n_is_sb': '0'},
 'robert bruce mathias': {'n_is_sb': '0'},
 'robert bunsen': {'n_is_sb': '0'},
 'robert burns woodward': {'n_is_sb': '0'},
 'robert burns': {'n_is_sb': '0'},
 'robert charles benchley': {'n_is_sb': '0'},
 'robert charles venturi': {'n_is_sb': '0'},
 'robert clive': {'n_is_sb': '0'},
 'robert curl': {'n_is_sb': '0'},
 'robert de niro': {'n_is_sb': '0'},
 'robert e. lee': {'n_is_sb': '0'},
 'robert e. peary': {'n_is_sb': '0'},
 'robert edward lee': {'n_is_sb': '0'},
 'robert edwin peary': {'n_is_sb': '0'},
 'robert emmet sherwood': {'n_is_sb': '0'},
 'robert f. curl': {'n_is_sb': '0'},
 'robert falcon scott': {'n_is_sb': '0'},
 'robert floyd curl jr.': {'n_is_sb': '0'},
 'robert frost': {'n_is_sb': '0'},
 'robert fulton': {'n_is_sb': '0'},
 'robert graves': {'n_is_sb': '0'},
 'robert gray': {'n_is_sb': '0'},
 'robert herrick': {'n_is_sb': '0'},
 'robert hooke': {'n_is_sb': '0'},
 'robert hutchings goddard': {'n_is_sb': '0'},
 'robert i': {'n_is_sb': '0'},
 'robert james fischer': {'n_is_sb': '0'},
 'robert jemison van de graaff': {'n_is_sb': '0'},
 'robert joffrey': {'n_is_sb': '0'},
 'robert king merton': {'n_is_sb': '0'},
 'robert koch': {'n_is_sb': '0'},
 'robert lee frost': {'n_is_sb': '0'},
 'robert louis balfour stevenson': {'n_is_sb': '0'},
 'robert louis stevenson': {'n_is_sb': '0'},
 'robert lowell': {'n_is_sb': '0'},
 'robert m. yerkes': {'n_is_sb': '0'},
 'robert macgregor': {'n_is_sb': '0'},
 'robert maynard hutchins': {'n_is_sb': '0'},
 'robert mearns yerkes': {'n_is_sb': '0'},
 'robert merton': {'n_is_sb': '0'},
 'robert mills': {'n_is_sb': '0'},
 'robert mitchum': {'n_is_sb': '0'},
 'robert morris': {'n_is_sb': '0'},
 'robert motherwell': {'n_is_sb': '0'},
 'robert nesta marley': {'n_is_sb': '0'},
 'robert oppenheimer': {'n_is_sb': '0'},
 'robert orr': {'n_is_sb': '0'},
 'robert owen': {'n_is_sb': '0'},
 'robert peary': {'n_is_sb': '0'},
 'robert peel': {'n_is_sb': '0'},
 'robert penn warren': {'n_is_sb': '0'},
 'robert r. livingston': {'n_is_sb': '0'},
 'robert ranke graves': {'n_is_sb': '0'},
 'robert redford': {'n_is_sb': '0'},
 'robert robinson': {'n_is_sb': '0'},
 'robert schumann': {'n_is_sb': '0'},
 'robert scott': {'n_is_sb': '0'},
 'robert southey': {'n_is_sb': '0'},
 'robert the bruce': {'n_is_sb': '0'},
 'robert traill spence lowell jr.': {'n_is_sb': '0'},
 'robert treat paine': {'n_is_sb': '0'},
 'robert tyre jones': {'n_is_sb': '0'},
 'robert van de graaff': {'n_is_sb': '0'},
 'robert venturi': {'n_is_sb': '0'},
 'robert walpole': {'n_is_sb': '0'},
 'robert wilhelm bunsen': {'n_is_sb': '0'},
 'robert william service': {'n_is_sb': '0'},
 'robert woodrow wilson': {'n_is_sb': '0'},
 "robert's rules of order": {'n_is_sb': '0'},
 'roberto francesco romolo bellarmine': {'n_is_sb': '0'},
 'robertson': {'n_is_sb': '0'},
 'robeson': {'n_is_sb': '0'},
 'robespierre': {'n_is_sb': '0'},
 'robin goodfellow': {'n_is_sb': '0'},
 'robin hood': {'n_is_sb': '0'},
 'robin redbreast': {'n_is_sb': '3', 'n_is_sth': '3'},
 'robinson crusoe': {'n_is_sb': '0'},
 'robinson jeffers': {'n_is_sb': '0'},
 'robinson': {'n_is_sb': '0'},
 'robolo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rocco marciano': {'n_is_sb': '0'},
 'roccus saxatilis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rochambeau': {'n_is_sb': '0'},
 "rock 'n' roll musician": {'n_is_sb': '0'},
 'rock barnacle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock bass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock beauty': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock climber': {'n_is_sb': '0'},
 'rock cornish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock dove': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock gunnel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock hind': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock hopper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock hyrax': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock kangaroo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock lobster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock partridge': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock pigeon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock python': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock rabbit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock rattlesnake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock sea bass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock star': {'n_is_sb': '0'},
 'rock sunfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock wallaby': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rock wren': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rockchuck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rockefeller': {'n_is_sb': '0'},
 'rocket engineer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'rocket scientist': {'n_is_sb': '0'},
 'rockfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rockingham': {'n_is_sb': '0'},
 'rockweed': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rockwell kent': {'n_is_sb': '0'},
 'rockwell': {'n_is_sb': '0'},
 'rocky marciano': {'n_is_sb': '0'},
 'rocky mountain bighorn': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rocky mountain goat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rocky mountain jay': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rocky mountain sheep': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rocky mountain whitefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rod laver': {'n_is_sb': '0'},
 'rodent': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rodeo rider': {'n_is_sb': '0'},
 'rodgers': {'n_is_sb': '0'},
 'rodin': {'n_is_sb': '0'},
 'rodney george laver': {'n_is_sb': '0'},
 'rodolia cardinalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rodrigo borgia': {'n_is_sb': '0'},
 'rodya raskolnikov': {'n_is_sb': '0'},
 'roe deer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'roebling': {'n_is_sb': '0'},
 'roger bacon': {'n_is_sb': '0'},
 'roger bannister': {'n_is_sb': '0'},
 'roger brooke taney': {'n_is_sb': '0'},
 'roger de mortimer': {'n_is_sb': '0'},
 'roger eliot fry': {'n_is_sb': '0'},
 'roger fry': {'n_is_sb': '0'},
 'roger huntington sessions': {'n_is_sb': '0'},
 'roger sessions': {'n_is_sb': '0'},
 'roger sherman': {'n_is_sb': '0'},
 'roger taney': {'n_is_sb': '0'},
 'roger williams': {'n_is_sb': '0'},
 'rogers': {'n_is_sb': '0'},
 'roget': {'n_is_sb': '0'},
 'rogue elephant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'roisterer': {'n_is_sb': '0'},
 'roland de lassus': {'n_is_sb': '0'},
 'role model': {'n_is_sb': '0'},
 'role player': {'n_is_sb': '0'},
 'rolf': {'n_is_sb': '0'},
 'roller-skater': {'n_is_sb': '0'},
 'rollo': {'n_is_sb': '0'},
 'roman catholic pope': {'n_is_sb': '0'},
 'roman catholic': {'n_is_sb': '0'},
 'roman deity': {'n_is_sb': '0'},
 'roman emperor': {'n_is_sb': '0'},
 'roman jakobson': {'n_is_sb': '0'},
 'roman osipovich jakobson': {'n_is_sb': '0'},
 'romanticist': {'n_is_sb': '0'},
 'romberg': {'n_is_sb': '0'},
 'romeo': {'n_is_sb': '0'},
 'rommany': {'n_is_sb': '0'},
 'rommel': {'n_is_sb': '0'},
 'romper': {'n_is_sb': '0'},
 'romulus': {'n_is_sb': '0'},
 'ronald george wreyford norrish': {'n_is_sb': '0'},
 'ronald reagan': {'n_is_sb': '0'},
 'ronald wilson reagan': {'n_is_sb': '0'},
 'rontgen': {'n_is_sb': '2', 'n_is_sth': '2'},
 'roof rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'room clerk': {'n_is_sb': '0'},
 'room decorator': {'n_is_sb': '0'},
 'roomer': {'n_is_sb': '0'},
 'rooter skunk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rope-maker': {'n_is_sb': '0'},
 'ropedancer': {'n_is_sb': '0'},
 'ropemaker': {'n_is_sb': '0'},
 'roper': {'n_is_sb': '0'},
 'ropewalker': {'n_is_sb': '0'},
 'rorqual': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rosa parks': {'n_is_sb': '0'},
 'rose beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rose bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rose chafer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rose louise hovick': {'n_is_sb': '0'},
 'rose-colored pastor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rose-colored starling': {'n_is_sb': '3', 'n_is_sth': '3'},
 'roseate spoonbill': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rosebud': {'n_is_sb': '2', 'n_is_sth': '2'},
 'rosefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rossetti': {'n_is_sb': '0'},
 'ross': {'n_is_sb': '0'},
 'rostand': {'n_is_sb': '0'},
 'rosy boa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rotarian': {'n_is_sb': '0'},
 'rotavirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rothko': {'n_is_sb': '0'},
 'rothschild': {'n_is_sb': '0'},
 'roth': {'n_is_sb': '0'},
 'rotifera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rotifer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rottweiler': {'n_is_sb': '3', 'n_is_sth': '3'},
 'roue': {'n_is_sb': '0'},
 'rough fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rough green snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rough rider': {'n_is_sb': '0'},
 'rough-legged hawk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rough-skinned newt': {'n_is_sb': '3', 'n_is_sth': '3'},
 'roughleg': {'n_is_sb': '3', 'n_is_sth': '3'},
 'roughrider': {'n_is_sb': '0'},
 'roughtail stingray': {'n_is_sb': '3', 'n_is_sth': '3'},
 'round clam': {'n_is_sb': '3', 'n_is_sth': '3'},
 'round scad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'round whitefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'round-tailed muskrat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'roundhead': {'n_is_sb': '0'},
 'roundsman': {'n_is_sb': '0'},
 'rouser': {'n_is_sb': '0'},
 'rousseau': {'n_is_sb': '0'},
 'roustabout': {'n_is_sb': '0'},
 'rous': {'n_is_sb': '0'},
 'router': {'n_is_sb': '2', 'n_is_sth': '2'},
 'rove beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rower': {'n_is_sb': '0'},
 'roy chapman andrews': {'n_is_sb': '0'},
 'roy lichtenstein': {'n_is_sb': '0'},
 'roy orbison': {'n_is_sb': '0'},
 'roy wilkins': {'n_is_sb': '0'},
 'royal stag': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rubber boa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rube goldberg': {'n_is_sb': '0'},
 'rubens': {'n_is_sb': '0'},
 'rubinstein': {'n_is_sb': '0'},
 'ruby-crowned kinglet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ruby-crowned wren': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rudapithecus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rudderfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ruddy duck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ruddy turnstone': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rudd': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rudolf bultmann': {'n_is_sb': '0'},
 'rudolf christian karl diesel': {'n_is_sb': '0'},
 'rudolf diesel': {'n_is_sb': '0'},
 'rudolf hess': {'n_is_sb': '0'},
 'rudolf karl bultmann': {'n_is_sb': '0'},
 'rudolf karl virchow': {'n_is_sb': '0'},
 'rudolf ludwig mossbauer': {'n_is_sb': '0'},
 'rudolf nureyev': {'n_is_sb': '0'},
 'rudolf serkin': {'n_is_sb': '0'},
 'rudolf virchow': {'n_is_sb': '0'},
 'rudolf wurlitzer': {'n_is_sb': '0'},
 'rudolph laban': {'n_is_sb': '0'},
 'rudra': {'n_is_sb': '0'},
 'rudyard kipling': {'n_is_sb': '0'},
 'ruffed grouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ruff': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rug merchant': {'n_is_sb': '0'},
 'ruholla khomeini': {'n_is_sb': '0'},
 'ruiner': {'n_is_sb': '2', 'n_is_sth': '2'},
 'rumanian': {'n_is_sb': '0'},
 'ruminant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ruminator': {'n_is_sb': '0'},
 'rumormonger': {'n_is_sb': '0'},
 'rumourmonger': {'n_is_sb': '0'},
 'rumpelstiltskin': {'n_is_sb': '0'},
 'rumrunner': {'n_is_sb': '0'},
 'rundstedt': {'n_is_sb': '0'},
 'running back': {'n_is_sb': '0'},
 'running mate': {'n_is_sb': '0'},
 'runt': {'n_is_sb': '3', 'n_is_sth': '3'},
 'runyon': {'n_is_sb': '0'},
 'rupert brooke': {'n_is_sb': '0'},
 'rupert murdoch': {'n_is_sb': '0'},
 'rupert': {'n_is_sb': '0'},
 'rupicapra rupicapra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rupicola peruviana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rupicola rupicola': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rupicola': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ruralist': {'n_is_sb': '0'},
 'ruritanian': {'n_is_sb': '0'},
 'rushdie': {'n_is_sb': '0'},
 'rusher': {'n_is_sb': '0'},
 'ruskin': {'n_is_sb': '0'},
 'russel crouse': {'n_is_sb': '0'},
 'russell': {'n_is_sb': '0'},
 'russian wolfhound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rust mite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rusty blackbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rusty grackle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ruth benedict': {'n_is_sb': '0'},
 'ruth fulton': {'n_is_sb': '0'},
 'ruth saint denis': {'n_is_sb': '0'},
 'ruth st. denis': {'n_is_sb': '0'},
 'rutherford b. hayes': {'n_is_sb': '0'},
 'rutherford birchard hayes': {'n_is_sb': '0'},
 'rutilus rutilus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rutilus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ruvettus pretiosus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'rwandan': {'n_is_sb': '0'},
 'ryukyuan': {'n_is_sb': '0'},
 's. s. van dine': {'n_is_sb': '0'},
 's. smith stevens': {'n_is_sb': '0'},
 'saarinen': {'n_is_sb': '0'},
 'sabahan': {'n_is_sb': '0'},
 'sabbatarian': {'n_is_sb': '0'},
 'saber-toothed tiger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sabertooth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sabin': {'n_is_sb': '0'},
 'sable antelope': {'n_is_sb': '3', 'n_is_sth': '3'},
 'saboteur': {'n_is_sb': '0'},
 'sabra': {'n_is_sb': '0'},
 'sacco': {'n_is_sb': '0'},
 'sacramento sturgeon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sacred cow': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sacred ibis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sacred trinity': {'n_is_sb': '0'},
 'sacrificer': {'n_is_sb': '0'},
 'sacristan': {'n_is_sb': '0'},
 'sad sack': {'n_is_sb': '0'},
 'sadat': {'n_is_sb': '0'},
 'saddam bin hussein at-takriti': {'n_is_sb': '0'},
 'saddam hussein': {'n_is_sb': '0'},
 'saddam': {'n_is_sb': '0'},
 'saddhu': {'n_is_sb': '0'},
 'saddle horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'saddle oyster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'saddlebill': {'n_is_sb': '3', 'n_is_sth': '3'},
 'saddler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sadducee': {'n_is_sb': '0'},
 'sade': {'n_is_sb': '0'},
 'sadhu': {'n_is_sb': '0'},
 'sadi carnot': {'n_is_sb': '0'},
 'sadist': {'n_is_sb': '0'},
 'sadomasochist': {'n_is_sb': '0'},
 'safebreaker': {'n_is_sb': '0'},
 'sagamore': {'n_is_sb': '0'},
 'sage grouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sage hen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sagebrush lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sagittarius serpentarius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sagittarius': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sahaptino': {'n_is_sb': '0'},
 'sahaptin': {'n_is_sb': '0'},
 'saiga tatarica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'saiga': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sailing master': {'n_is_sb': '0'},
 'sailmaker': {'n_is_sb': '0'},
 'sailor boy': {'n_is_sb': '0'},
 "sailor's-choice": {'n_is_sb': '3', 'n_is_sth': '3'},
 'sailors choice': {'n_is_sb': '3', 'n_is_sth': '3'},
 'saimiri sciureus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'saint ambrose': {'n_is_sb': '0'},
 'saint andrew the apostle': {'n_is_sb': '0'},
 'saint andrew': {'n_is_sb': '0'},
 'saint anselm': {'n_is_sb': '0'},
 'saint athanasius': {'n_is_sb': '0'},
 'saint augustine': {'n_is_sb': '0'},
 'saint baeda': {'n_is_sb': '0'},
 'saint beda': {'n_is_sb': '0'},
 'saint bede': {'n_is_sb': '0'},
 'saint benedict': {'n_is_sb': '0'},
 'saint bernard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'saint boniface': {'n_is_sb': '0'},
 'saint bride': {'n_is_sb': '0'},
 'saint bridget': {'n_is_sb': '0'},
 'saint brigid': {'n_is_sb': '0'},
 'saint bruno': {'n_is_sb': '0'},
 'saint christopher': {'n_is_sb': '2', 'n_is_sth': '2'},
 'saint crispin': {'n_is_sb': '0'},
 'saint david': {'n_is_sb': '0'},
 'saint denis': {'n_is_sb': '2', 'n_is_sth': '2'},
 'saint dominic': {'n_is_sb': '0'},
 'saint edward the confessor': {'n_is_sb': '0'},
 'saint edward the martyr': {'n_is_sb': '0'},
 'saint elizabeth ann bayley seton': {'n_is_sb': '0'},
 'saint francis of assisi': {'n_is_sb': '0'},
 'saint francis xavier': {'n_is_sb': '0'},
 'saint francis': {'n_is_sb': '0'},
 'saint george': {'n_is_sb': '2', 'n_is_sth': '2'},
 'saint gregory i': {'n_is_sb': '0'},
 'saint ignatius of loyola': {'n_is_sb': '0'},
 'saint ignatius': {'n_is_sb': '0'},
 'saint james the apostle': {'n_is_sb': '0'},
 'saint james': {'n_is_sb': '0'},
 'saint jerome': {'n_is_sb': '0'},
 'saint joan': {'n_is_sb': '0'},
 'saint john the apostle': {'n_is_sb': '0'},
 'saint jude': {'n_is_sb': '0'},
 'saint lawrence': {'n_is_sb': '2', 'n_is_sth': '2'},
 'saint louis': {'n_is_sb': '2', 'n_is_sth': '2'},
 'saint luke': {'n_is_sb': '0'},
 'saint mark': {'n_is_sb': '0'},
 'saint matthew the apostle': {'n_is_sb': '0'},
 'saint matthew': {'n_is_sb': '0'},
 'saint nicholas': {'n_is_sb': '0'},
 'saint nick': {'n_is_sb': '0'},
 'saint olaf': {'n_is_sb': '0'},
 'saint olav': {'n_is_sb': '0'},
 'saint patrick': {'n_is_sb': '0'},
 'saint paul': {'n_is_sb': '2', 'n_is_sth': '2'},
 'saint peter the apostle': {'n_is_sb': '0'},
 'saint peter': {'n_is_sb': '0'},
 'saint thomas a becket': {'n_is_sb': '0'},
 'saint thomas aquinas': {'n_is_sb': '0'},
 'saint thomas': {'n_is_sb': '0'},
 'saint-saens': {'n_is_sb': '0'},
 'sakharov': {'n_is_sb': '0'},
 'saki': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sakti': {'n_is_sb': '0'},
 'saladin': {'n_is_sb': '0'},
 'salah-ad-din yusuf ibn-ayyub': {'n_is_sb': '0'},
 'salamandra atra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salamandra maculosa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salamandra salamandra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salamandra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sales demonstrator': {'n_is_sb': '0'},
 'salesgirl': {'n_is_sb': '0', 'nc_typical': ''},
 'saleslady': {'n_is_sb': '0'},
 'saleswoman': {'n_is_sb': '0', 'nc_typical': ''},
 'salian frank': {'n_is_sb': '0'},
 'salian': {'n_is_sb': '0'},
 'salientian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salim': {'n_is_sb': '0'},
 'salinger': {'n_is_sb': '0'},
 'salish': {'n_is_sb': '0'},
 'salk': {'n_is_sb': '0'},
 'salmacis': {'n_is_sb': '0'},
 'salman rushdie': {'n_is_sb': '0'},
 'salmo gairdneri': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salmo salar': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salmo trutta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salmon trout': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salmonella enteritidis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salmonella typhimurium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salmonella typhi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salmonella typhosa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salmonid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salome': {'n_is_sb': '0'},
 'salomon': {'n_is_sb': '0'},
 'saloon keeper': {'n_is_sb': '0'},
 'salpa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salpinctes obsoletus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salpinctes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salt merchant': {'n_is_sb': '0'},
 'saluki': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salutatorian': {'n_is_sb': '0'},
 'salutatory speaker': {'n_is_sb': '0'},
 'saluter': {'n_is_sb': '0'},
 'salvadoran': {'n_is_sb': '0'},
 'salvadorean': {'n_is_sb': '0'},
 'salvadorian': {'n_is_sb': '0'},
 'salvager': {'n_is_sb': '0'},
 'salvelinus alpinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salvelinus fontinalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salvelinus namaycush': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salvelinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'salvidor dali': {'n_is_sb': '0'},
 'salvor': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sam adams': {'n_is_sb': '0'},
 'sam goldwyn': {'n_is_sb': '0'},
 'sam houston': {'n_is_sb': '0'},
 'sam shepard': {'n_is_sb': '0'},
 'sam snead': {'n_is_sb': '0'},
 'samaritan': {'n_is_sb': '0'},
 'sambar': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sambur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'samia cynthia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'samia walkeri': {'n_is_sb': '3', 'n_is_sth': '3'},
 'samia': {'n_is_sb': '0'},
 'samnite': {'n_is_sb': '0'},
 'samoan': {'n_is_sb': '0'},
 'samoyede': {'n_is_sb': '0'},
 'samoyed': {'n_is_sb': '3', 'n_is_sth': '3'},
 'samson': {'n_is_sb': '0'},
 'samuel adams': {'n_is_sb': '0'},
 'samuel barber': {'n_is_sb': '0'},
 'samuel beckett': {'n_is_sb': '0'},
 'samuel dashiell hammett': {'n_is_sb': '0'},
 'samuel de champlain': {'n_is_sb': '0'},
 'samuel f. b. morse': {'n_is_sb': '0'},
 'samuel finley breese morse': {'n_is_sb': '0'},
 'samuel goldwyn': {'n_is_sb': '0'},
 'samuel gompers': {'n_is_sb': '0'},
 'samuel houston': {'n_is_sb': '0'},
 'samuel huntington': {'n_is_sb': '0'},
 'samuel jackson snead': {'n_is_sb': '0'},
 'samuel johnson': {'n_is_sb': '0'},
 'samuel langhorne clemens': {'n_is_sb': '0'},
 'samuel morse': {'n_is_sb': '0'},
 'samuel pepys': {'n_is_sb': '0'},
 'samuel pierpoint langley': {'n_is_sb': '0'},
 'samuel rawson gardiner': {'n_is_sb': '0'},
 'samuel rosenstock': {'n_is_sb': '0'},
 'samuel taylor coleridge': {'n_is_sb': '0'},
 'samuel wiesenthal': {'n_is_sb': '0'},
 'samuel wilder': {'n_is_sb': '0'},
 'samuel': {'n_is_sb': '0'},
 'san jose scale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'san marinese': {'n_is_sb': '0'},
 'sanchez': {'n_is_sb': '0'},
 'sand badger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sand cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sand cricket': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sand dab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sand dollar': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sand eel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sand flea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sand fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sand grouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sand hopper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sand lance': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sand launce': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sand lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sand martin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sand rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sand shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sand snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sand sole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sand tiger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sand viper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sandbagger': {'n_is_sb': '0'},
 'sandbar shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sandboy': {'n_is_sb': '0'},
 'sandburg': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sanderling': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sandfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sandfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sandgrouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sandhopper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sandman': {'n_is_sb': '0'},
 'sandor kellner': {'n_is_sb': '0'},
 'sandro botticelli': {'n_is_sb': '0'},
 'sandwichman': {'n_is_sb': '0'},
 'sanger': {'n_is_sb': '0'},
 'sangoma': {'n_is_sb': '0'},
 'sanguinary ant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sannup': {'n_is_sb': '0'},
 'sannyasin': {'n_is_sb': '0'},
 'sannyasi': {'n_is_sb': '0'},
 'santa ana': {'n_is_sb': '2', 'n_is_sth': '2'},
 'santa anna': {'n_is_sb': '0'},
 'santa claus': {'n_is_sb': '0'},
 'santa gertrudis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'santee dakota': {'n_is_sb': '0'},
 'santee sioux': {'n_is_sb': '0'},
 'santee': {'n_is_sb': '0'},
 'santiago ramon y cajal': {'n_is_sb': '0'},
 'sanyasi': {'n_is_sb': '0'},
 'saphead': {'n_is_sb': '0'},
 'sapir': {'n_is_sb': '0'},
 'sapper': {'n_is_sb': '0'},
 'sappho': {'n_is_sb': '0'},
 'sapsucker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sara teasdale': {'n_is_sb': '0'},
 'saracen': {'n_is_sb': '0'},
 'sarah bernhardt': {'n_is_sb': '0'},
 'sarah kemble siddons': {'n_is_sb': '0'},
 'sarah siddons': {'n_is_sb': '0'},
 'sarah vaughan': {'n_is_sb': '0'},
 'sarah': {'n_is_sb': '0'},
 'sarasvati': {'n_is_sb': '0'},
 'saratoga spittlebug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sarawakian': {'n_is_sb': '0'},
 'sarazen': {'n_is_sb': '0'},
 'sarcocystidean': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sarcocystieian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sarcodine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sarcodinian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sarcophaga carnaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sarcophaga': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sarcophilus hariisi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sarcophilus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sarcoptid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sarcorhamphus papa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sarcorhamphus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sarcosporidian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sarda chiliensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sarda lineolata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sarda sarda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sarda': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sardina pilchardus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sardina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sardinian': {'n_is_sb': '0'},
 'sardinops caerulea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sargasso': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sargassum bacciferum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sargassum fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sargassum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sargent': {'n_is_sb': '0'},
 'sarnoff': {'n_is_sb': '0'},
 'saroyan': {'n_is_sb': '0'},
 'sarpanitu': {'n_is_sb': '0'},
 'sarpedon': {'n_is_sb': '0'},
 'sartre': {'n_is_sb': '0'},
 'sarvepalli radhakrishnan': {'n_is_sb': '0'},
 'sassaby': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sassenach': {'n_is_sb': '0'},
 'satanist': {'n_is_sb': '0'},
 'satchel paige': {'n_is_sb': '0'},
 'satchmo': {'n_is_sb': '0'},
 'satie': {'n_is_sb': '0'},
 'satin bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'satin bowerbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'satirist': {'n_is_sb': '0'},
 'saturnia pavonia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'saturniid moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'saturniid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'satyendra n. bose': {'n_is_sb': '0'},
 'satyendra nath bose': {'n_is_sb': '0'},
 'satyr': {'n_is_sb': '2', 'n_is_sth': '2'},
 'saudi arabian': {'n_is_sb': '0'},
 'saudi': {'n_is_sb': '0'},
 'sauk': {'n_is_sb': '0'},
 'saul bellow': {'n_is_sb': '0'},
 'saul of tarsus': {'n_is_sb': '0'},
 'saul steinberg': {'n_is_sb': '0'},
 'saul': {'n_is_sb': '0'},
 'saunterer': {'n_is_sb': '0'},
 'saurel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'saurian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'saurischian dinosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sauromalus obesus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sauromalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sauropod dinosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sauropod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'saurosuchus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'saury': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sausage dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sausage hound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'saussure': {'n_is_sb': '0'},
 'savara': {'n_is_sb': '3', 'n_is_sth': '3'},
 'savitar': {'n_is_sb': '0'},
 'savonarola': {'n_is_sb': '0'},
 'savoyard': {'n_is_sb': '0'},
 'sawbill': {'n_is_sb': '0'},
 'sawbones': {'n_is_sb': '0'},
 'sawfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sawfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sawyer beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sawyer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'saxe': {'n_is_sb': '2', 'n_is_sth': '2'},
 'saxicola rubetra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'saxicola torquata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'saxist': {'n_is_sb': '0'},
 'saxo grammaticus': {'n_is_sb': '0'},
 'saxon': {'n_is_sb': '0'},
 'saxophonist': {'n_is_sb': '0'},
 'sax': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sayers': {'n_is_sb': '0'},
 'sayornis phoebe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sayornis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scale insect': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scallywag': {'n_is_sb': '0'},
 'scaly anteater': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scammer': {'n_is_sb': '0'},
 'scandalmonger': {'n_is_sb': '0'},
 'scandinavian': {'n_is_sb': '0', 'cap_word': 'Scandinavian'},
 'scapegrace': {'n_is_sb': '0'},
 'scaphiopus bombifrons': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scaphiopus hammondii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scaphiopus multiplicatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scaphopod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scarabaean': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scarabaeid beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scarabaeid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scarabaeus sacer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scarabaeus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scaramouche': {'n_is_sb': '0'},
 'scaramouch': {'n_is_sb': '0'},
 'scardinius erythrophthalmus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scaremonger': {'n_is_sb': '0'},
 'scarface': {'n_is_sb': '0'},
 'scarlet tanager': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scartella cristata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scartella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scatterbrain': {'n_is_sb': '0'},
 'scattergood': {'n_is_sb': '0'},
 'scaup duck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scaup': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sceloglaux albifacies': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sceloporus graciosus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sceloporus occidentalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sceloporus undulatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scene painter': {'n_is_sb': '0'},
 'scene-stealer': {'n_is_sb': '0'},
 'sceneshifter': {'n_is_sb': '0'},
 'scenic artist': {'n_is_sb': '0'},
 'sceptic': {'n_is_sb': '0'},
 'scheele': {'n_is_sb': '0'},
 'schiaparelli': {'n_is_sb': '0'},
 'schipperke': {'n_is_sb': '3', 'n_is_sth': '3'},
 'schistosoma': {'n_is_sb': '3', 'n_is_sth': '3'},
 'schistosome': {'n_is_sb': '3', 'n_is_sth': '3'},
 'schizomycetes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'schizophrenic': {'n_is_sb': '0'},
 'schizopoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'schleiden': {'n_is_sb': '0'},
 'schlemiel': {'n_is_sb': '0'},
 'schlesinger': {'n_is_sb': '0'},
 'schliemann': {'n_is_sb': '0'},
 'schlimazel': {'n_is_sb': '0'},
 'schlockmeister': {'n_is_sb': '0'},
 'schmidt': {'n_is_sb': '0'},
 'schmoozer': {'n_is_sb': '0'},
 'schnabel': {'n_is_sb': '0'},
 'schnauzer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'schoenberg': {'n_is_sb': '0'},
 'scholarly person': {'n_is_sb': '0'},
 'scholastic': {'n_is_sb': '0'},
 'scholiast': {'n_is_sb': '0'},
 'schonbein': {'n_is_sb': '0'},
 'schonberg': {'n_is_sb': '0'},
 'school principal': {'n_is_sb': '0'},
 'school superintendent': {'n_is_sb': '0'},
 'school teacher': {'n_is_sb': '0'},
 'school-age child': {'n_is_sb': '0'},
 'schoolcraft': {'n_is_sb': '0'},
 'schoolfellow': {'n_is_sb': '0'},
 'schoolfriend': {'n_is_sb': '0'},
 "schoolma'am": {'n_is_sb': '0'},
 'schoolman': {'n_is_sb': '0'},
 'schoolmarm': {'n_is_sb': '0'},
 'schoolmistress': {'n_is_sb': '0'},
 'schopenhauer': {'n_is_sb': '0'},
 'schrodinger': {'n_is_sb': '0'},
 'schrod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'schubert': {'n_is_sb': '0'},
 'schulz': {'n_is_sb': '0'},
 'schumann-heink': {'n_is_sb': '0'},
 'schumann': {'n_is_sb': '0'},
 'schumpeter': {'n_is_sb': '0'},
 'schwann': {'n_is_sb': '0'},
 'schweitzer': {'n_is_sb': '0'},
 'sciaena antarctica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sciaena aquila': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sciaenid fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sciaenid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sciaenops ocellatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sciara': {'n_is_sb': '0'},
 'sciaridae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sciarid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'science teacher': {'n_is_sb': '0'},
 'scincella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scincid lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scincid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sciolist': {'n_is_sb': '0'},
 'scipio africanus major': {'n_is_sb': '0'},
 'scipio africanus': {'n_is_sb': '0'},
 'scipio the elder': {'n_is_sb': '0'},
 'scipio': {'n_is_sb': '0'},
 'scissortailed flycatcher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scissortail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sciurus carolinensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sciurus griseus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sciurus hudsonicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sciurus niger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sciurus vulgaris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scleroparei': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scoffer': {'n_is_sb': '0'},
 'scofflaw': {'n_is_sb': '0'},
 'scolder': {'n_is_sb': '0'},
 'scollop': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scolopax rusticola': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scolytus multistriatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scomber colias': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scomber japonicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scomber scombrus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scomberesocidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scomberesox saurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scomberesox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scomberomorus cavalla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scomberomorus maculatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scomberomorus regalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scomberomorus sierra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scomberomorus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scomber': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scombroid fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scombroid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scophthalmus aquosus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scophthalmus rhombus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scops owl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scorekeeper': {'n_is_sb': '0'},
 'scorner': {'n_is_sb': '0'},
 'scorpaena grandicornis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scorpaenid fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scorpaenid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scorpaenoid fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scorpaenoidea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scorpaenoid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scorpion fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scorpion fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scorpion shell': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scorpionfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scorsese': {'n_is_sb': '0'},
 'scotch terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scotchman': {'n_is_sb': '0'},
 'scotchwoman': {'n_is_sb': '0'},
 'scoter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scotswoman': {'n_is_sb': '0'},
 'scott joplin': {'n_is_sb': '0'},
 'scottie': {'n_is_sb': '2', 'n_is_sth': '2'},
 'scottish deerhound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scottish highlander': {'n_is_sb': '0'},
 'scottish terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scott': {'n_is_sb': '0'},
 'scourer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'scourge of god': {'n_is_sb': '0'},
 'scourge of the gods': {'n_is_sb': '2', 'n_is_sth': '2'},
 'scourger': {'n_is_sb': '2', 'n_is_sth': '2'},
 'scouter': {'n_is_sb': '0'},
 'scoutmaster': {'n_is_sb': '0'},
 'scrambler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'scratcher': {'n_is_sb': '2', 'n_is_sth': '2'},
 'scrawler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'screamer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'screech owl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'screecher': {'n_is_sb': '2', 'n_is_sth': '2'},
 'screen actor': {'n_is_sb': '0'},
 'screener': {'n_is_sb': '2', 'n_is_sth': '2'},
 'screwballer': {'n_is_sb': '0'},
 'scriabin': {'n_is_sb': '0'},
 'scribbler': {'n_is_sb': '0'},
 'scrimshanker': {'n_is_sb': '0'},
 'scripps': {'n_is_sb': '0'},
 'scrounger': {'n_is_sb': '0'},
 'scrub bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scrub fowl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scrub nurse': {'n_is_sb': '0'},
 'scrub-bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scrubbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scrutineer': {'n_is_sb': '0'},
 'scrutiniser': {'n_is_sb': '0'},
 'scrutinizer': {'n_is_sb': '0'},
 'scuba diver': {'n_is_sb': '0'},
 'sculler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'scullion': {'n_is_sb': '0'},
 'sculpin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sculptress': {'n_is_sb': '0'},
 'sculpturer': {'n_is_sb': '0'},
 'scum bag': {'n_is_sb': '2', 'n_is_sth': '2'},
 'scup': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scutigera coleoptrata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scutigera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scutigerella immaculata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scutigerella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scutigeridae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scylla': {'n_is_sb': '2', 'n_is_sth': '2'},
 'scyphozoan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'scythian': {'n_is_sb': '0'},
 'sea anemone': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea animal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea bass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea bream': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea captain': {'n_is_sb': '0'},
 'sea catfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea chub': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea cow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea cradle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea crawfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea creature': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea cucumber': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea dog': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sea duck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea eagle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea elephant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea fan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea feather': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea gooseberry': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea gull': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea hare': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea king': {'n_is_sb': '0'},
 'sea lamprey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea lawyer': {'n_is_sb': '0'},
 'sea lettuce': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea lily': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea lion': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea louse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea mat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea mew': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea moss': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea nymph': {'n_is_sb': '0'},
 'sea otter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea pen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea poacher': {'n_is_sb': '0'},
 'sea poker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea raven': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea robber': {'n_is_sb': '0'},
 'sea robin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea rover': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sea scallop': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea scorpion': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea scout': {'n_is_sb': '0'},
 'sea serpent': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea slater': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea slug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea snail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea spider': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea squirt': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea star': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea swallow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea tangle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea tang': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea trout': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea turtle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea urchin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea wolf': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea wrack': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea-ear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sea-god': {'n_is_sb': '0'},
 'sea-lettuce family': {'n_is_sb': '3', 'n_is_sth': '3'},
 'seaborg': {'n_is_sb': '0'},
 'seafowl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'seagrass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'seahorse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sealyham terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sealyham': {'n_is_sb': '3', 'n_is_sth': '3'},
 'seamster': {'n_is_sb': '0'},
 'seamstress': {'n_is_sb': '0'},
 "sean o'casey": {'n_is_sb': '0'},
 'searcher beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'searobin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'seasnail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'seasoner': {'n_is_sb': '2', 'n_is_sth': '2'},
 'seattle slew': {'n_is_sb': '0'},
 'sebastian cabot': {'n_is_sb': '0'},
 'sebastian vizcaino': {'n_is_sb': '0'},
 'sebastodes caurinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sebastodes marinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sebastodes miniatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sebastodes ruberrimus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'secessionist': {'n_is_sb': '0'},
 'second adventist': {'n_is_sb': '0'},
 'second banana': {'n_is_sb': '0'},
 'second baseman': {'n_is_sb': '0'},
 'second best': {'n_is_sb': '0'},
 'second cousin': {'n_is_sb': '0'},
 'second earl grey': {'n_is_sb': '0'},
 'second earl of chatham': {'n_is_sb': '0'},
 'second earl of guilford': {'n_is_sb': '0'},
 'second fiddle': {'n_is_sb': '0'},
 'second hand': {'n_is_sb': '2', 'n_is_sth': '2'},
 'second lieutenant': {'n_is_sb': '0'},
 'second marquis of rockingham': {'n_is_sb': '0'},
 'second sacker': {'n_is_sb': '0'},
 'second-in-command': {'n_is_sb': '0'},
 'second-rater': {'n_is_sb': '2', 'n_is_sth': '2'},
 'seconder': {'n_is_sb': '0'},
 'secret agent': {'n_is_sb': '0'},
 'secretarial assistant': {'n_is_sb': '0'},
 'secretary bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'secretary general': {'n_is_sb': '0'},
 'secretary of agriculture': {'n_is_sb': '0'},
 'secretary of commerce': {'n_is_sb': '0'},
 'secretary of defense': {'n_is_sb': '0'},
 'secretary of education': {'n_is_sb': '0'},
 'secretary of energy': {'n_is_sb': '0'},
 'secretary of health and human services': {'n_is_sb': '0'},
 'secretary of housing and urban development': {'n_is_sb': '0'},
 'secretary of labor': {'n_is_sb': '0'},
 'secretary of state for the home department': {'n_is_sb': '0'},
 'secretary of state': {'n_is_sb': '0'},
 'secretary of the interior': {'n_is_sb': '0'},
 'secretary of the treasury': {'n_is_sb': '0'},
 'secretary of transportation': {'n_is_sb': '0'},
 'secretary of veterans affairs': {'n_is_sb': '0'},
 'sectarian': {'n_is_sb': '0'},
 'sectarist': {'n_is_sb': '0'},
 'sectary': {'n_is_sb': '0'},
 'section eight': {'n_is_sb': '0'},
 'section hand': {'n_is_sb': '0'},
 'section man': {'n_is_sb': '0'},
 'secularist': {'n_is_sb': '0'},
 'secundigravida': {'n_is_sb': '0'},
 'securer': {'n_is_sb': '0'},
 'securities analyst': {'n_is_sb': '0'},
 'security consultant': {'n_is_sb': '0'},
 'security director': {'n_is_sb': '0'},
 'security guard': {'n_is_sb': '0'},
 'sedge bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sedge warbler': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sedge wren': {'n_is_sb': '3', 'n_is_sth': '3'},
 'seducer': {'n_is_sb': '0'},
 'seed beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'seed oyster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'seed shrimp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'seed weevil': {'n_is_sb': '3', 'n_is_sth': '3'},
 'seeded player': {'n_is_sb': '0'},
 'seeder': {'n_is_sb': '2', 'n_is_sth': '2'},
 'seedman': {'n_is_sb': '0'},
 'seedsman': {'n_is_sb': '0'},
 'seeger': {'n_is_sb': '0'},
 'seeing-eye dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'segal': {'n_is_sb': '0'},
 'segmented worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'segovia': {'n_is_sb': '0'},
 'segregationist': {'n_is_sb': '0'},
 'segregator': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sei whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'seigneur de bayard': {'n_is_sb': '0'},
 'seignior': {'n_is_sb': '0'},
 'seiji ozawa': {'n_is_sb': '0'},
 'seismologist': {'n_is_sb': '0'},
 'seismosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'seismosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'seiurus aurocapillus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'seizer': {'n_is_sb': '0'},
 'seizure-alert dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sekhet': {'n_is_sb': '0'},
 'selachian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'selar crumenophthalmus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'selcraig': {'n_is_sb': '0'},
 'selectman': {'n_is_sb': '0'},
 'selector': {'n_is_sb': '2', 'nn_to_vb': 'select', 'nn_to_jj': 'selective', 'nn_to_rb': 'selectively', 'n_is_sth': '2'},
 'selectwoman': {'n_is_sb': '0'},
 'selenarctos thibetanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'selene setapinnis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'selene vomer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'selene': {'n_is_sb': '0'},
 'seles': {'n_is_sb': '0'},
 'seleucus i nicator': {'n_is_sb': '0'},
 'seleucus i': {'n_is_sb': '0'},
 'seleucus': {'n_is_sb': '0'},
 'self-employed person': {'n_is_sb': '0'},
 'self-seeker': {'n_is_sb': '0'},
 'self-starter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'selfish person': {'n_is_sb': '0'},
 'selkirk': {'n_is_sb': '2', 'n_is_sth': '2'},
 'selkup': {'n_is_sb': '0'},
 'selling agent': {'n_is_sb': '0'},
 'selznick': {'n_is_sb': '0'},
 'semanticist': {'n_is_sb': '0'},
 'semifinalist': {'n_is_sb': '0'},
 'seminarian': {'n_is_sb': '0'},
 'seminarist': {'n_is_sb': '0'},
 'seminole': {'n_is_sb': '0'},
 'semiotician': {'n_is_sb': '0'},
 'semiprofessional': {'n_is_sb': '0'},
 'semipro': {'n_is_sb': '0'},
 'semite': {'n_is_sb': '0'},
 'semitic deity': {'n_is_sb': '0'},
 'semnopithecus entellus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sempstress': {'n_is_sb': '0'},
 'sendee': {'n_is_sb': '0'},
 'seneca': {'n_is_sb': '0'},
 'senefelder': {'n_is_sb': '0'},
 'senegalese': {'n_is_sb': '0'},
 'seneschal': {'n_is_sb': '0'},
 'senhor': {'n_is_sb': '0'},
 'senior citizen': {'n_is_sb': '0'},
 'senior pilot': {'n_is_sb': '0'},
 'senior vice president': {'n_is_sb': '0'},
 'sennacherib': {'n_is_sb': '0'},
 'sennett': {'n_is_sb': '0'},
 'sensationalist': {'n_is_sb': '0'},
 'sensualist': {'n_is_sb': '0'},
 'sentimentalist': {'n_is_sb': '0'},
 'separationist': {'n_is_sb': '0'},
 'separatist': {'n_is_sb': '0', 'nn_to_vb': 'separate', 'nn_to_jj': 'separate', 'nn_to_rb': 'separately'},
 'sephardic jew': {'n_is_sb': '0'},
 'sephardi': {'n_is_sb': '0'},
 'septuagenarian': {'n_is_sb': '0'},
 'sequoyah': {'n_is_sb': '0'},
 'sequoya': {'n_is_sb': '0'},
 'serbian': {'n_is_sb': '0', 'cap_word': 'Serbian'},
 'serb': {'n_is_sb': '0'},
 'serge koussevitzky': {'n_is_sb': '0'},
 'sergeant at arms': {'n_is_sb': '0'},
 'sergeant first class': {'n_is_sb': '0'},
 'sergeant fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sergeant major': {'n_is_sb': '0'},
 'sergeant-at-law': {'n_is_sb': '0'},
 'sergei aleksandrovich koussevitzky': {'n_is_sb': '0'},
 'sergei diaghilev': {'n_is_sb': '0'},
 'sergei eisenstein': {'n_is_sb': '0'},
 'sergei mikhailovich eisenstein': {'n_is_sb': '0'},
 'sergei pavlovich diaghilev': {'n_is_sb': '0'},
 'sergei rachmaninoff': {'n_is_sb': '0'},
 'sergei rachmaninov': {'n_is_sb': '0'},
 'sergei sergeyevich prokofiev': {'n_is_sb': '0'},
 'sergei vasilievich rachmaninoff': {'n_is_sb': '0'},
 'sergei vasilievich rachmaninov': {'n_is_sb': '0'},
 'serial killer': {'n_is_sb': '0'},
 'serial murderer': {'n_is_sb': '0'},
 'sericulturist': {'n_is_sb': '0'},
 'seriema': {'n_is_sb': '3', 'n_is_sth': '3'},
 'serinus canaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'serin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'seriola dorsalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'seriola grandis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'seriola zonata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'seriphus politus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'serjeant-at-arms': {'n_is_sb': '0'},
 'serjeant-at-law': {'n_is_sb': '0'},
 'serjeant': {'n_is_sb': '0'},
 'serkin': {'n_is_sb': '0'},
 'sermoniser': {'n_is_sb': '0'},
 'sermonizer': {'n_is_sb': '0'},
 'serologist': {'n_is_sb': '0'},
 'serotine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'serow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'serpent star': {'n_is_sb': '3', 'n_is_sth': '3'},
 'serranid fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'serranid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'serranus subligarius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'serrated wrack': {'n_is_sb': '3', 'n_is_sth': '3'},
 'serratia marcescens': {'n_is_sb': '3', 'n_is_sth': '3'},
 'serra': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sertularian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sertularia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'serval': {'n_is_sb': '3', 'n_is_sth': '3'},
 'servant girl': {'n_is_sb': '0'},
 'service man': {'n_is_sb': '0'},
 'serving girl': {'n_is_sb': '0'},
 'servitor': {'n_is_sb': '0'},
 'seth thomas': {'n_is_sb': '0'},
 'seth': {'n_is_sb': '0'},
 'seton': {'n_is_sb': '2', 'n_is_sth': '2'},
 'setophaga ruticilla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'setting hen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'seurat': {'n_is_sb': '0'},
 'seventeen-year locust': {'n_is_sb': '3', 'n_is_sth': '3'},
 'severo ochoa': {'n_is_sb': '0'},
 'seward': {'n_is_sb': '0'},
 'sewellel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sewer rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sewing-machine operator': {'n_is_sb': '0'},
 'sex bomb': {'n_is_sb': '0'},
 'sex kitten': {'n_is_sb': '0'},
 'sex object': {'n_is_sb': '0'},
 'sex offender': {'n_is_sb': '0'},
 'sexagenarian': {'n_is_sb': '0'},
 'sexist': {'n_is_sb': '0'},
 'sexpot': {'n_is_sb': '0'},
 'sexton': {'n_is_sb': '0'},
 'seychellois': {'n_is_sb': '0'},
 'seymour': {'n_is_sb': '0'},
 'sga infant': {'n_is_sb': '0'},
 'shadower': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shaft louse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shah jahan': {'n_is_sb': '0'},
 'shah of iran': {'n_is_sb': '0'},
 'shah palavi': {'n_is_sb': '0'},
 'shahaptian': {'n_is_sb': '0'},
 'shaheed': {'n_is_sb': '0'},
 'shahn': {'n_is_sb': '0'},
 'shah': {'n_is_sb': '0'},
 'shaitan': {'n_is_sb': '0'},
 'shakspere': {'n_is_sb': '0'},
 'shaktist': {'n_is_sb': '0'},
 'shakti': {'n_is_sb': '0'},
 'shalom asch': {'n_is_sb': '0'},
 'shamash': {'n_is_sb': '0'},
 'shammer': {'n_is_sb': '0'},
 'shanghaier': {'n_is_sb': '0'},
 'shankar': {'n_is_sb': '0'},
 'shannon': {'n_is_sb': '0'},
 'shanny': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shapley': {'n_is_sb': '0'},
 'sharecrop farmer': {'n_is_sb': '0'},
 'sharecropper': {'n_is_sb': '0'},
 'sharer': {'n_is_sb': '0'},
 'sharksucker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sharp-tailed grouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sharper': {'n_is_sb': '0'},
 'sharptail mola': {'n_is_sb': '0'},
 'sharpy': {'n_is_sb': '2', 'n_is_sth': '2'},
 'shasta salamander': {'n_is_sb': '0'},
 'shasta': {'n_is_sb': '2', 'n_is_sth': '2'},
 'shavian': {'n_is_sb': '0'},
 'shawnee': {'n_is_sb': '0'},
 'shawn': {'n_is_sb': '0'},
 'shaytan': {'n_is_sb': '0'},
 'she-devil': {'n_is_sb': '0'},
 'she-goat': {'n_is_sb': '0'},
 'shearer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sheatfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shedder': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sheeny': {'n_is_sb': '0'},
 'sheep botfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sheep dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sheep frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sheep gadfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sheep ked': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sheep tick': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sheep-tick': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sheepdog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sheepman': {'n_is_sb': '0'},
 'sheepshead porgy': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sheepshead': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shegetz': {'n_is_sb': '0'},
 'sheika': {'n_is_sb': '0'},
 'sheikha': {'n_is_sb': '0'},
 'shel silverstein': {'n_is_sb': '0'},
 'shelby silverstein': {'n_is_sb': '0'},
 'sheldrake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shelduck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shell parakeet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shelley': {'n_is_sb': '0'},
 'shelton jackson lee': {'n_is_sb': '0'},
 'shelver': {'n_is_sb': '0'},
 'shem': {'n_is_sb': '0'},
 'shen-pao': {'n_is_sb': '2', 'n_is_sth': '2'},
 'shepard': {'n_is_sb': '0'},
 'shepherd dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shepherdess': {'n_is_sb': '0'},
 'sheridan': {'n_is_sb': '0'},
 'sheriff': {'n_is_sb': '0'},
 'sherlock holmes': {'n_is_sb': '0'},
 'sherlock': {'n_is_sb': '0'},
 'sherman': {'n_is_sb': '0'},
 'sherpa': {'n_is_sb': '0'},
 'sherrington': {'n_is_sb': '0'},
 'sherwood anderson': {'n_is_sb': '0'},
 'sherwood': {'n_is_sb': '0'},
 'shetland pony': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shetland sheep dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shetland sheepdog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shevchenko': {'n_is_sb': '0'},
 "shi'ite muslim": {'n_is_sb': '0'},
 "shi'ite": {'n_is_sb': '0'},
 'shia muslim': {'n_is_sb': '0'},
 'shielder': {'n_is_sb': '0'},
 'shiga bacillus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shigella dysentariae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shigella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shih-tzu': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shiite muslim': {'n_is_sb': '0'},
 'shiite': {'n_is_sb': '0'},
 'shiksa': {'n_is_sb': '0'},
 'shikse': {'n_is_sb': '0'},
 'shingler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'shintoist': {'n_is_sb': '0'},
 'ship broker': {'n_is_sb': '0'},
 'ship builder': {'n_is_sb': '0'},
 'ship chandler': {'n_is_sb': '0'},
 "ship's chandler": {'n_is_sb': '0'},
 "ship's officer": {'n_is_sb': '0'},
 'ship-breaker': {'n_is_sb': '0'},
 'shipboard soldier': {'n_is_sb': '0'},
 'shipbuilder': {'n_is_sb': '0'},
 'shipmate': {'n_is_sb': '0'},
 'shipping agent': {'n_is_sb': '0'},
 'shipping clerk': {'n_is_sb': '0'},
 'shipworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shipwreck survivor': {'n_is_sb': '0'},
 'shipwright': {'n_is_sb': '0'},
 'shire horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shirer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shirker': {'n_is_sb': '0'},
 'shirley temple black': {'n_is_sb': '0'},
 'shirley temple': {'n_is_sb': '0'},
 'shirtlifter': {'n_is_sb': '0'},
 'shirtmaker': {'n_is_sb': '0'},
 'shithead': {'n_is_sb': '0', 'dirtyword': ''},
 'shitter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'shivaist': {'n_is_sb': '0'},
 'shiva': {'n_is_sb': '0'},
 'shlemiel': {'n_is_sb': '0'},
 'shlimazel': {'n_is_sb': '0'},
 'shlockmeister': {'n_is_sb': '0'},
 'shmo': {'n_is_sb': '2', 'n_is_sth': '2'},
 'shmuck': {'n_is_sb': '0'},
 'shnook': {'n_is_sb': '0'},
 'shoat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shockley': {'n_is_sb': '0'},
 'shoebill': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shoebird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shoeblack': {'n_is_sb': '0'},
 'shogun': {'n_is_sb': '0'},
 'sholem asch': {'n_is_sb': '0'},
 'sholom asch': {'n_is_sb': '0'},
 'shoofly': {'n_is_sb': '2', 'n_is_sth': '2'},
 'shop assistant': {'n_is_sb': '0'},
 'shop boy': {'n_is_sb': '0'},
 'shop clerk': {'n_is_sb': '0'},
 'shop girl': {'n_is_sb': '0'},
 'shop mechanic': {'n_is_sb': '0'},
 'shop steward': {'n_is_sb': '0'},
 'shopaholic': {'n_is_sb': '0'},
 'shopwalker': {'n_is_sb': '0'},
 'shorebird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'short-billed marsh wren': {'n_is_sb': '3', 'n_is_sth': '3'},
 'short-horned grasshopper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'short-tailed shrew': {'n_is_sb': '3', 'n_is_sth': '3'},
 'short-toed eagle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shortfin mako': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shorthand typist': {'n_is_sb': '0'},
 'shortstop': {'n_is_sb': '0'},
 'shorttail weasel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shoshone': {'n_is_sb': '0'},
 'shoshoni': {'n_is_sb': '0'},
 'shostakovich': {'n_is_sb': '0'},
 'shot putter': {'n_is_sb': '0'},
 'shouter': {'n_is_sb': '0'},
 'shoveler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'shovelhead': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shoveller': {'n_is_sb': '0'},
 'shovelnose catfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shover': {'n_is_sb': '2', 'n_is_sth': '2'},
 'showgirl': {'n_is_sb': '0'},
 'showman': {'n_is_sb': '0'},
 'shrew mole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shrewmouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shrimp-fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shrimpfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'shrinking violet': {'n_is_sb': '0'},
 'shudra': {'n_is_sb': '0'},
 'shuffler': {'n_is_sb': '0'},
 'shut-in': {'n_is_sb': '0'},
 'shutterbug': {'n_is_sb': '0'},
 'shy person': {'n_is_sb': '0'},
 'shylock': {'n_is_sb': '0'},
 'sialis lutaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'siamang': {'n_is_sb': '3', 'n_is_sth': '3'},
 'siamese cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'siamese twin': {'n_is_sb': '0'},
 'sibelius': {'n_is_sb': '0'},
 'siberian husky': {'n_is_sb': '3', 'n_is_sth': '3'},
 'siberian': {'n_is_sb': '0', 'cap_word': 'Siberian'},
 'sibyl': {'n_is_sb': '0'},
 'sicilian': {'n_is_sb': '0'},
 'sick person': {'n_is_sb': '0'},
 'sid caesar': {'n_is_sb': '0'},
 'siddhartha': {'n_is_sb': '0'},
 'siddons': {'n_is_sb': '0'},
 'side judge': {'n_is_sb': '0'},
 'side-blotched lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sidesman': {'n_is_sb': '0'},
 'sidney caesar': {'n_is_sb': '0'},
 'sidney james webb': {'n_is_sb': '0'},
 'sidney poitier': {'n_is_sb': '0'},
 'sidney webb': {'n_is_sb': '0'},
 'sidney': {'n_is_sb': '0'},
 'sidonie-gabrielle claudine colette': {'n_is_sb': '0'},
 'sidonie-gabrielle colette': {'n_is_sb': '0'},
 'siegfried': {'n_is_sb': '0'},
 'siemens': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sierra leonean': {'n_is_sb': '0'},
 'sierra leonian': {'n_is_sb': '0'},
 'sieur de lasalle': {'n_is_sb': '0'},
 'sif': {'n_is_sb': '0'},
 'sightreader': {'n_is_sb': '0'},
 'sigmodon hispidus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sigmund freud': {'n_is_sb': '0'},
 'sigmund romberg': {'n_is_sb': '0'},
 'sign painter': {'n_is_sb': '0'},
 'signal caller': {'n_is_sb': '0'},
 'signaler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'signaller': {'n_is_sb': '2', 'n_is_sth': '2'},
 'signatory': {'n_is_sb': '0'},
 'signer': {'n_is_sb': '0'},
 'significant other': {'n_is_sb': '0'},
 'signior': {'n_is_sb': '0'},
 'signorina': {'n_is_sb': '0'},
 'sigrid undset': {'n_is_sb': '0'},
 'sigurd': {'n_is_sb': '0'},
 'sigyn': {'n_is_sb': '0'},
 'sika': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sikh': {'n_is_sb': '0', 'cap_word': 'Sikh'},
 'sikorsky': {'n_is_sb': '0'},
 'sild': {'n_is_sb': '3', 'n_is_sth': '3'},
 'silent partner': {'n_is_sb': '0'},
 'silent person': {'n_is_sb': '0'},
 'silenus': {'n_is_sb': '0'},
 'silkworm moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'silkworm seed': {'n_is_sb': '3', 'n_is_sth': '3'},
 'silky anteater': {'n_is_sb': '3', 'n_is_sth': '3'},
 'silky pocket mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'silky tamarin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'silky terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sillaginidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sills': {'n_is_sb': '0'},
 'silurid fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'silurid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'siluriform fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'silurus glanis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'silvanus': {'n_is_sb': '0'},
 'silvan': {'n_is_sb': '0'},
 'silver fox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'silver hake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'silver jenny': {'n_is_sb': '3', 'n_is_sth': '3'},
 'silver perch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'silver salmon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'silver-tip': {'n_is_sb': '3', 'n_is_sth': '3'},
 'silver-worker': {'n_is_sb': '0'},
 'silverback': {'n_is_sb': '3', 'n_is_sth': '3'},
 'silversides': {'n_is_sb': '3', 'n_is_sth': '3'},
 'silverside': {'n_is_sb': '3', 'n_is_sth': '3'},
 'silverspot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'silverstein': {'n_is_sb': '0'},
 'silvertip': {'n_is_sb': '3', 'n_is_sth': '3'},
 'silverworker': {'n_is_sb': '0'},
 'silvia atricapilla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'silvia': {'n_is_sb': '0'},
 'simenon': {'n_is_sb': '0'},
 'simeon': {'n_is_sb': '0'},
 'simon bolivar': {'n_is_sb': '0'},
 'simon de montfort': {'n_is_sb': '0'},
 'simon kuznets': {'n_is_sb': '0'},
 'simon legree': {'n_is_sb': '0'},
 'simon marks': {'n_is_sb': '0'},
 'simon newcomb': {'n_is_sb': '0'},
 'simon peter': {'n_is_sb': '0'},
 'simon the canaanite': {'n_is_sb': '0'},
 'simon the zealot': {'n_is_sb': '0'},
 'simon zelotes': {'n_is_sb': '0'},
 'simone de beauvoir': {'n_is_sb': '0'},
 'simone weil': {'n_is_sb': '0'},
 'simperer': {'n_is_sb': '0'},
 'simpson': {'n_is_sb': '0'},
 'sinanthropus': {'n_is_sb': '0'},
 'sinatra': {'n_is_sb': '0'},
 'sinbad the sailor': {'n_is_sb': '0'},
 'sinbad': {'n_is_sb': '0'},
 'sinclair lewis': {'n_is_sb': '0'},
 'sinclair': {'n_is_sb': '0'},
 'singaporean': {'n_is_sb': '0'},
 'singhalese': {'n_is_sb': '0'},
 'sinologist': {'n_is_sb': '0'},
 'sinornis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'siouan': {'n_is_sb': '0'},
 'sioux': {'n_is_sb': '0'},
 'siphonaptera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'siphonophore': {'n_is_sb': '0'},
 'sipper': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sipuncula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sipunculid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'siqueiros': {'n_is_sb': '0'},
 'sir alan lloyd hodgkin': {'n_is_sb': '0'},
 'sir alec guinness': {'n_is_sb': '0'},
 'sir alexander fleming': {'n_is_sb': '0'},
 'sir alexander korda': {'n_is_sb': '0'},
 'sir alexander mackenzie': {'n_is_sb': '0'},
 'sir alexander robertus todd': {'n_is_sb': '0'},
 'sir alfred charles bernard lovell': {'n_is_sb': '0'},
 'sir alfred hitchcock': {'n_is_sb': '0'},
 'sir angus wilson': {'n_is_sb': '0'},
 'sir anthony hopkins': {'n_is_sb': '0'},
 'sir anthony philip hopkins': {'n_is_sb': '0'},
 'sir anthony vandyke': {'n_is_sb': '0'},
 'sir arthur conan doyle': {'n_is_sb': '0'},
 'sir arthur john evans': {'n_is_sb': '0'},
 'sir arthur stanley eddington': {'n_is_sb': '0'},
 'sir arthur sullivan': {'n_is_sb': '0'},
 'sir arthur travers harris': {'n_is_sb': '0'},
 'sir barton': {'n_is_sb': '0'},
 'sir bernanrd williams': {'n_is_sb': '0'},
 'sir bernard law montgomery': {'n_is_sb': '0'},
 'sir bernard lovell': {'n_is_sb': '0'},
 'sir charles leonard woolley': {'n_is_sb': '0'},
 'sir charles scott sherrington': {'n_is_sb': '0'},
 'sir charles spencer chaplin': {'n_is_sb': '0'},
 'sir charles wheatstone': {'n_is_sb': '0'},
 'sir charles william siemens': {'n_is_sb': '0'},
 'sir christopher wren': {'n_is_sb': '0'},
 'sir clive marles sinclair': {'n_is_sb': '0'},
 'sir david alexander cecil low': {'n_is_sb': '0'},
 'sir david bruce': {'n_is_sb': '0'},
 'sir david low': {'n_is_sb': '0'},
 'sir edmund hillary': {'n_is_sb': '0'},
 'sir edmund percival hillary': {'n_is_sb': '0'},
 'sir edward elgar': {'n_is_sb': '0'},
 'sir edward victor appleton': {'n_is_sb': '0'},
 'sir edward william elgar': {'n_is_sb': '0'},
 'sir edwin landseer luytens': {'n_is_sb': '0'},
 'sir edwin lutyens': {'n_is_sb': '0'},
 'sir ernst boris chain': {'n_is_sb': '0'},
 'sir francis bacon': {'n_is_sb': '0'},
 'sir francis drake': {'n_is_sb': '0'},
 'sir francis galton': {'n_is_sb': '0'},
 'sir fred hoyle': {'n_is_sb': '0'},
 'sir frederick ashton': {'n_is_sb': '0'},
 'sir frederick gowland hopkins': {'n_is_sb': '0'},
 'sir frederick grant banting': {'n_is_sb': '0'},
 'sir frederick william herschel': {'n_is_sb': '0'},
 'sir galahad': {'n_is_sb': '0'},
 'sir gawain': {'n_is_sb': '0'},
 'sir geoffrey wilkinson': {'n_is_sb': '0'},
 'sir george otto trevelyan': {'n_is_sb': '0'},
 'sir george paget thomson': {'n_is_sb': '0'},
 'sir geraint': {'n_is_sb': '0'},
 'sir hans adolf krebs': {'n_is_sb': '0'},
 'sir harold george nicolson': {'n_is_sb': '0'},
 'sir harold walter kroto': {'n_is_sb': '0'},
 'sir harry maclennan lauder': {'n_is_sb': '0'},
 'sir henry bessemer': {'n_is_sb': '0'},
 'sir henry joseph wood': {'n_is_sb': '0'},
 'sir henry maxmilian beerbohm': {'n_is_sb': '0'},
 'sir henry morgan': {'n_is_sb': '0'},
 'sir henry morton stanley': {'n_is_sb': '0'},
 'sir henry percy': {'n_is_sb': '0'},
 'sir henry rider haggard': {'n_is_sb': '0'},
 'sir henry wood': {'n_is_sb': '0'},
 'sir herbert beerbohm tree': {'n_is_sb': '0'},
 'sir hiram stevens maxim': {'n_is_sb': '0'},
 'sir howard walter florey': {'n_is_sb': '0'},
 'sir humphrey davy': {'n_is_sb': '0'},
 'sir humphrey gilbert': {'n_is_sb': '0'},
 'sir isaac newton': {'n_is_sb': '0'},
 'sir isaac pitman': {'n_is_sb': '0'},
 'sir jack hobbs': {'n_is_sb': '0'},
 'sir jacob epstein': {'n_is_sb': '0'},
 'sir james augustus henry murray': {'n_is_sb': '0'},
 'sir james augustus murray': {'n_is_sb': '0'},
 'sir james clark ross': {'n_is_sb': '0'},
 'sir james dewar': {'n_is_sb': '0'},
 'sir james george frazer': {'n_is_sb': '0'},
 'sir james matthew barrie': {'n_is_sb': '0'},
 'sir james murray': {'n_is_sb': '0'},
 'sir james paget': {'n_is_sb': '0'},
 'sir james paul mccartney': {'n_is_sb': '0'},
 'sir james young simpson': {'n_is_sb': '0'},
 'sir john carew eccles': {'n_is_sb': '0'},
 'sir john cockcroft': {'n_is_sb': '0'},
 'sir john cowdery kendrew': {'n_is_sb': '0'},
 'sir john douglas cockcroft': {'n_is_sb': '0'},
 'sir john everett millais': {'n_is_sb': '0'},
 'sir john falstaff': {'n_is_sb': '0'},
 'sir john frederick william herschel': {'n_is_sb': '0'},
 'sir john gielgud': {'n_is_sb': '0'},
 'sir john hawkins': {'n_is_sb': '0'},
 'sir john hawkyns': {'n_is_sb': '0'},
 'sir john herschel': {'n_is_sb': '0'},
 'sir john ross': {'n_is_sb': '0'},
 'sir john suckling': {'n_is_sb': '0'},
 'sir john tenniel': {'n_is_sb': '0'},
 'sir john vanbrigh': {'n_is_sb': '0'},
 'sir joseph banks': {'n_is_sb': '0'},
 'sir joseph john thomson': {'n_is_sb': '0'},
 'sir joseph paxton': {'n_is_sb': '0'},
 'sir joshua reynolds': {'n_is_sb': '0'},
 'sir lancelot': {'n_is_sb': '0'},
 'sir laurence kerr olivier': {'n_is_sb': '0'},
 'sir leonard hutton': {'n_is_sb': '0'},
 'sir leonard woolley': {'n_is_sb': '0'},
 'sir leslie stephen': {'n_is_sb': '0'},
 'sir martin frobisher': {'n_is_sb': '0'},
 'sir matthew flinders': {'n_is_sb': '0'},
 'sir mortimer wheeler': {'n_is_sb': '0'},
 'sir noel pierce coward': {'n_is_sb': '0'},
 'sir oliver joseph lodge': {'n_is_sb': '0'},
 'sir oliver lodge': {'n_is_sb': '0'},
 'sir patrick manson': {'n_is_sb': '0'},
 'sir paul gavrilovich vinogradoff': {'n_is_sb': '0'},
 'sir peter brian medawar': {'n_is_sb': '0'},
 'sir peter paul rubens': {'n_is_sb': '0'},
 'sir peter ustinov': {'n_is_sb': '0'},
 'sir philip sidney': {'n_is_sb': '0'},
 'sir ralph david richardson': {'n_is_sb': '0'},
 'sir rex harrison': {'n_is_sb': '0'},
 'sir richard burton': {'n_is_sb': '0'},
 'sir richard francis burton': {'n_is_sb': '0'},
 'sir richard owen': {'n_is_sb': '0'},
 'sir richrd steele': {'n_is_sb': '0'},
 'sir robert eric mortimer wheeler': {'n_is_sb': '0'},
 'sir robert peel': {'n_is_sb': '0'},
 'sir robert robinson': {'n_is_sb': '0'},
 'sir robert walpole': {'n_is_sb': '0'},
 'sir roger gilbert bannister': {'n_is_sb': '0'},
 'sir ronald ross': {'n_is_sb': '0'},
 'sir sarvepalli radhakrishnan': {'n_is_sb': '0'},
 'sir seretse khama': {'n_is_sb': '0'},
 'sir stephen harold spender': {'n_is_sb': '0'},
 'sir terence mervyn rattigan': {'n_is_sb': '0'},
 'sir thomas gresham': {'n_is_sb': '0'},
 'sir thomas lawrence': {'n_is_sb': '0'},
 'sir thomas malory': {'n_is_sb': '0'},
 'sir thomas more': {'n_is_sb': '0'},
 'sir thomas raffles': {'n_is_sb': '0'},
 'sir thomas stamford raffles': {'n_is_sb': '0'},
 'sir thomas wyatt': {'n_is_sb': '0'},
 'sir thomas wyat': {'n_is_sb': '0'},
 'sir tim rice': {'n_is_sb': '0'},
 'sir tom stoppard': {'n_is_sb': '0'},
 'sir walter norman haworth': {'n_is_sb': '0'},
 'sir walter ralegh': {'n_is_sb': '0'},
 'sir walter raleigh': {'n_is_sb': '0'},
 'sir walter scott': {'n_is_sb': '0'},
 'sir william alexander craigie': {'n_is_sb': '0'},
 'sir william chambers': {'n_is_sb': '0'},
 'sir william crookes': {'n_is_sb': '0'},
 'sir william gerald golding': {'n_is_sb': '0'},
 'sir william gilbert': {'n_is_sb': '0'},
 'sir william herschel': {'n_is_sb': '0'},
 'sir william huggins': {'n_is_sb': '0'},
 'sir william rowan hamilton': {'n_is_sb': '0'},
 'sir william turner walton': {'n_is_sb': '0'},
 'sir william wallace': {'n_is_sb': '0'},
 'sir william walton': {'n_is_sb': '0'},
 'sir winston leonard spenser churchill': {'n_is_sb': '0'},
 'sir yehudi menuhin': {'n_is_sb': '0'},
 'siraj-ud-daula': {'n_is_sb': '0'},
 'sirdar': {'n_is_sb': '0'},
 'sirenian mammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sirenian': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sirenidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sirrah': {'n_is_sb': '0'},
 'sistrurus catenatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sistrurus miliaris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sisyphus': {'n_is_sb': '0'},
 'sis': {'n_is_sb': '0'},
 'sitar player': {'n_is_sb': '0'},
 'sita': {'n_is_sb': '0'},
 'sitophylus oryzae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sitotroga cerealella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sitta canadensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sitta carolinensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sitta europaea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sitter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sitting bull': {'n_is_sb': '0'},
 'sitting duck': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sitwell': {'n_is_sb': '0'},
 'sivapithecus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'siva': {'n_is_sb': '0'},
 'six-footer': {'n_is_sb': '0'},
 'six-gilled shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'six-lined racerunner': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sixth baron byron of rochdale': {'n_is_sb': '0'},
 'sixth-former': {'n_is_sb': '0'},
 'skagit': {'n_is_sb': '0'},
 'skanda': {'n_is_sb': '0'},
 'skateboarder': {'n_is_sb': '0'},
 'skater': {'n_is_sb': '0'},
 'skeat': {'n_is_sb': '0'},
 'skeeter hawk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'skeleton shrimp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'skeptic': {'n_is_sb': '0'},
 'sketcher': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ski jumper': {'n_is_sb': '0'},
 'skidder': {'n_is_sb': '2', 'n_is_sth': '2'},
 'skier': {'n_is_sb': '0'},
 'skilled worker': {'n_is_sb': '0'},
 'skillet fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'skilletfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'skin and bones': {'n_is_sb': '0'},
 'skin doctor': {'n_is_sb': '0'},
 'skin-diver': {'n_is_sb': '0'},
 'skinhead': {'n_is_sb': '0'},
 'skinnerian': {'n_is_sb': '0'},
 'skipjack tuna': {'n_is_sb': '3', 'n_is_sth': '3'},
 'skipjack': {'n_is_sb': '3', 'n_is_sth': '3'},
 'skirmisher': {'n_is_sb': '0'},
 'skirt chaser': {'n_is_sb': '0'},
 'skivvy': {'n_is_sb': '2', 'n_is_sth': '2'},
 'skua': {'n_is_sb': '3', 'n_is_sth': '3'},
 'skuld': {'n_is_sb': '0'},
 'skulker': {'n_is_sb': '0'},
 'skunk bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sky marshal': {'n_is_sb': '0'},
 'sky pilot': {'n_is_sb': '0'},
 'skycap': {'n_is_sb': '0'},
 'skydiver': {'n_is_sb': '0'},
 'skye terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'slanderer': {'n_is_sb': '0'},
 'slant-eye': {'n_is_sb': '0'},
 'slapper': {'n_is_sb': '2', 'n_is_sth': '2'},
 'slasher': {'n_is_sb': '2', 'n_is_sth': '2'},
 'slate-colored junco': {'n_is_sb': '3', 'n_is_sth': '3'},
 'slater': {'n_is_sb': '2', 'n_is_sth': '2'},
 'slattern': {'n_is_sb': '0'},
 'slave ant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'slave dealer': {'n_is_sb': '0'},
 'slave driver': {'n_is_sb': '0'},
 'slave owner': {'n_is_sb': '0'},
 'slave trader': {'n_is_sb': '0'},
 'slave-maker': {'n_is_sb': '0'},
 'slave-making ant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'slaver': {'n_is_sb': '2', 'nn_to_vb': 'slave', 'vb_to_nn': 'slave', 'n_is_sth': '2'},
 'slavey': {'n_is_sb': '0'},
 'slavic people': {'n_is_sb': '0'},
 'slavic race': {'n_is_sb': '0'},
 'sled dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sledder': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sledge dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sleeper goby': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sleeping beauty': {'n_is_sb': '0'},
 'sleeping partner': {'n_is_sb': '0'},
 'sleepless person': {'n_is_sb': '0'},
 'sleepwalker': {'n_is_sb': '0'},
 'sleepyhead': {'n_is_sb': '0'},
 'slender loris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'slender salamander': {'n_is_sb': '3', 'n_is_sth': '3'},
 'slender-tailed meerkat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sleuthhound': {'n_is_sb': '2', 'n_is_sth': '2'},
 'slicer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'slider': {'n_is_sb': '2', 'n_is_sth': '2'},
 'slime bacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'slime eels': {'n_is_sb': '3', 'n_is_sth': '3'},
 'slippery dick': {'n_is_sb': '3', 'n_is_sth': '3'},
 'slobberer': {'n_is_sb': '0'},
 'sloganeer': {'n_is_sb': '0'},
 'slogger': {'n_is_sb': '0'},
 'slop-seller': {'n_is_sb': '0'},
 'slopseller': {'n_is_sb': '0'},
 'sloth bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sloucher': {'n_is_sb': '0'},
 'slovene': {'n_is_sb': '0'},
 'slovenian': {'n_is_sb': '0'},
 'slovenly person': {'n_is_sb': '0'},
 'slovenly woman': {'n_is_sb': '0'},
 'sloven': {'n_is_sb': '0'},
 'slow loris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'slow virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'slowcoach': {'n_is_sb': '0'},
 'slowworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'slugabed': {'n_is_sb': '0'},
 'sluggard': {'n_is_sb': '0'},
 'slugger': {'n_is_sb': '0'},
 'slumberer': {'n_is_sb': '0'},
 'slyboots': {'n_is_sb': '0'},
 'small businessman': {'n_is_sb': '0'},
 'small civet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'small farmer': {'n_is_sb': '0'},
 'small fry': {'n_is_sb': '0'},
 'small person': {'n_is_sb': '0'},
 'small white': {'n_is_sb': '3', 'n_is_sth': '3'},
 'small-for-gestational-age infant': {'n_is_sb': '0'},
 'smalleye hammerhead': {'n_is_sb': '3', 'n_is_sth': '3'},
 'smalley': {'n_is_sb': '0'},
 'smallholder': {'n_is_sb': '0'},
 'smallmouth bass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'smallmouth black bass': {'n_is_sb': '0'},
 'smallmouthed bass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'smallmouthed black bass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'smallmouth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'smallpox virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'smalltooth sawfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'smart aleck': {'n_is_sb': '0'},
 'smarta': {'n_is_sb': '0'},
 'smasher': {'n_is_sb': '2', 'n_is_sth': '2'},
 'smelt': {'n_is_sb': '3', 'nn_to_vb': 'smell', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'n_is_sth': '3', 'vbd_eq_vbn': ''},
 'smetana': {'n_is_sb': '0'},
 'smew': {'n_is_sb': '3', 'n_is_sth': '3'},
 'smiledon californicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'smiledon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'smiler': {'n_is_sb': '0'},
 'smirker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'smitty stevens': {'n_is_sb': '0'},
 'smollett': {'n_is_sb': '0'},
 'smooth dogfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'smooth green snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'smooth hammerhead': {'n_is_sb': '3', 'n_is_sth': '3'},
 'smooth softshell': {'n_is_sb': '3', 'n_is_sth': '3'},
 'smooth-haired fox terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'smoothhound shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'smoothhound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'smoothie': {'n_is_sb': '2', 'n_is_sth': '2'},
 'smoothy': {'n_is_sb': '0'},
 'smotherer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'snacker': {'n_is_sb': '0'},
 'snail darter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snailfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snake charmer': {'n_is_sb': '0'},
 'snake doctor': {'n_is_sb': '0'},
 'snake feeder': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snake god': {'n_is_sb': '0'},
 'snake in the grass': {'n_is_sb': '2', 'n_is_sth': '2'},
 'snake mackerel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snake muishond': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snake-fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snakebird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snakeblenny': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snakefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snakefly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snapping beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snapping shrimp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snapping turtle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snarer': {'n_is_sb': '0'},
 'snatcher': {'n_is_sb': '0'},
 'snead': {'n_is_sb': '0'},
 'sneak thief': {'n_is_sb': '0'},
 'sneaker': {'n_is_sb': '2', 'nc_typical': '', 'n_is_sth': '2'},
 'sneerer': {'n_is_sb': '0'},
 'sneezer': {'n_is_sb': '0'},
 'snellen': {'n_is_sb': '0'},
 'sniffer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sniffler': {'n_is_sb': '0'},
 'snipefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snitcher': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sniveler': {'n_is_sb': '0'},
 'sniveller': {'n_is_sb': '0'},
 'snook': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snooper': {'n_is_sb': '0'},
 'snoopy': {'n_is_sb': '0'},
 'snoop': {'n_is_sb': '0', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'snorer': {'n_is_sb': '0'},
 'snorter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'snout beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snow bunting': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snow goose': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snow leopard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snowbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snowshoe hare': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snowshoe rabbit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snowy egret': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snowy heron': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snowy tree cricket': {'n_is_sb': '3', 'n_is_sth': '3'},
 'snuff user': {'n_is_sb': '0'},
 'snuffer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'snuffler': {'n_is_sb': '0'},
 'soapfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sob sister': {'n_is_sb': '0'},
 'sobersides': {'n_is_sb': '0'},
 'soccer player': {'n_is_sb': '0'},
 'social anthropologist': {'n_is_sb': '0'},
 'social climber': {'n_is_sb': '0'},
 'social dancer': {'n_is_sb': '0'},
 'social drinker': {'n_is_sb': '0'},
 'social lion': {'n_is_sb': '0'},
 'social scientist': {'n_is_sb': '0'},
 'social secretary': {'n_is_sb': '0'},
 'social worker': {'n_is_sb': '0'},
 'socialiser': {'n_is_sb': '0'},
 'socialist': {'n_is_sb': '0'},
 'socializer': {'n_is_sb': '0'},
 'socinian': {'n_is_sb': '0'},
 'socinus': {'n_is_sb': '0'},
 'sociobiologist': {'n_is_sb': '0'},
 'sociolinguist': {'n_is_sb': '0'},
 'sociologist': {'n_is_sb': '0'},
 'sociopath': {'n_is_sb': '0'},
 'sockeye salmon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sockeye': {'n_is_sb': '3', 'n_is_sth': '3'},
 'soda jerker': {'n_is_sb': '0'},
 'soda jerk': {'n_is_sb': '0'},
 'sodalist': {'n_is_sb': '0'},
 'sodbuster': {'n_is_sb': '0'},
 'soddy': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sodomist': {'n_is_sb': '0'},
 'sodomite': {'n_is_sb': '0'},
 'sofia scicolone': {'n_is_sb': '0'},
 'soft scale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'soft tick': {'n_is_sb': '3', 'n_is_sth': '3'},
 'soft touch': {'n_is_sb': '0'},
 'soft-coated wheaten terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'soft-finned fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'soft-shell clam': {'n_is_sb': '3', 'n_is_sth': '3'},
 'soft-shell crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'soft-shelled crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'soft-shelled turtle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'softie': {'n_is_sb': '0'},
 'software engineer': {'n_is_sb': '0'},
 'softy': {'n_is_sb': '0'},
 'sojourner truth': {'n_is_sb': '0'},
 'sojourner': {'n_is_sb': '0'},
 'sol hurok': {'n_is_sb': '0'},
 'solan goose': {'n_is_sb': '3', 'n_is_sth': '3'},
 'solant goose': {'n_is_sb': '3', 'n_is_sth': '3'},
 'solan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'solderer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'soldier of fortune': {'n_is_sb': '0'},
 'soldier-fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'soldierfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'solea lascaris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'solea solea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'solea': {'n_is_sb': '2', 'n_is_sth': '2'},
 'solenidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'solicitor general': {'n_is_sb': '0'},
 'solitaire': {'n_is_sb': '2', 'n_is_sth': '2'},
 'solitary vireo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'solitudinarian': {'n_is_sb': '0'},
 'solo man': {'n_is_sb': '0'},
 'soloist': {'n_is_sb': '0'},
 'solomon guggenheim': {'n_is_sb': '0'},
 'solomon hurok': {'n_is_sb': '0'},
 'solvay': {'n_is_sb': '0'},
 'solver': {'n_is_sb': '2', 'n_is_sth': '2'},
 'solzhenitsyn': {'n_is_sb': '0'},
 'somalian': {'n_is_sb': '0'},
 'somerset maugham': {'n_is_sb': '0'},
 'sommelier': {'n_is_sb': '0'},
 'somnambulist': {'n_is_sb': '0'},
 'somniloquist': {'n_is_sb': '0'},
 'son of a bitch': {'n_is_sb': '0'},
 'sondheim': {'n_is_sb': '0'},
 'song sparrow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'song thrush': {'n_is_sb': '3', 'n_is_sth': '3'},
 'songstress': {'n_is_sb': '0'},
 'songwriter': {'n_is_sb': '0'},
 'sonneteer': {'n_is_sb': '0'},
 'sonny boy': {'n_is_sb': '0'},
 'sonny liston': {'n_is_sb': '0'},
 'sonora semiannulata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sonoran lyre snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sonoran whipsnake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sontag': {'n_is_sb': '2', 'n_is_sth': '2'},
 'soothsayer': {'n_is_sb': '0'},
 'sophia loren': {'n_is_sb': '0'},
 'sophie tucker': {'n_is_sb': '0'},
 'sophisticate': {'n_is_sb': '0', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'sophist': {'n_is_sb': '0'},
 'sophocles': {'n_is_sb': '0'},
 'sophomore': {'n_is_sb': '0'},
 'sophonias': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sorbian': {'n_is_sb': '0'},
 'soren aabye kierkegaard': {'n_is_sb': '0'},
 'soren kierkegaard': {'n_is_sb': '0'},
 'soren peter lauritz sorensen': {'n_is_sb': '0'},
 'sorensen': {'n_is_sb': '0'},
 'sorex araneus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sorex cinereus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sorex palustris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sorrower': {'n_is_sb': '2', 'n_is_sth': '2'},
 'soufflot': {'n_is_sb': '0'},
 'soul brother': {'n_is_sb': '0'},
 'soul mate': {'n_is_sb': '0'},
 'sounding board': {'n_is_sb': '2', 'n_is_sth': '2'},
 'soundman': {'n_is_sb': '0'},
 'soup-fin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'soupfin shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'soupfin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sourpuss': {'n_is_sb': '0'},
 'sousa': {'n_is_sb': '0'},
 'souse': {'n_is_sb': '2', 'n_is_sth': '2'},
 'souslik': {'n_is_sb': '3', 'n_is_sth': '3'},
 'south african': {'n_is_sb': '0'},
 'south american bullfrog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'south american indian': {'n_is_sb': '0'},
 'south american poison toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'south american sea lion': {'n_is_sb': '3', 'n_is_sth': '3'},
 'south american': {'n_is_sb': '0'},
 'south carolinian': {'n_is_sb': '0'},
 'south dakotan': {'n_is_sb': '0'},
 'south korean': {'n_is_sb': '0'},
 'southeastern pocket gopher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'southern baptist': {'n_is_sb': '0'},
 'southern bog lemming': {'n_is_sb': '3', 'n_is_sth': '3'},
 'southern cabbage butterfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'southern flounder': {'n_is_sb': '3', 'n_is_sth': '3'},
 'southern flying squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'southern porgy': {'n_is_sb': '3', 'n_is_sth': '3'},
 'southern scup': {'n_is_sb': '3', 'n_is_sth': '3'},
 'southern spadefoot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'southerner': {'n_is_sb': '0'},
 'southey': {'n_is_sb': '0'},
 'southwestern toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'soutine': {'n_is_sb': '0'},
 'sow bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sow': {'n_is_sb': '3', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'n_is_sth': '3'},
 'space cadet': {'n_is_sb': '0'},
 'space writer': {'n_is_sb': '0'},
 'spacewalker': {'n_is_sb': '0'},
 'spadefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spadefoot toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spadefoot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spalax': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spallanzani': {'n_is_sb': '0'},
 'spammer': {'n_is_sb': '0'},
 'spanish american': {'n_is_sb': '0'},
 'spanish fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spanish grunt': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spanish mackerel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spanish people': {'n_is_sb': '0'},
 'spanish pointer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spanker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sparer': {'n_is_sb': '0'},
 'sparid fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sparid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sparling': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sparring mate': {'n_is_sb': '0'},
 'sparring partner': {'n_is_sb': '0'},
 'sparrow hawk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spartan': {'n_is_sb': '0'},
 'spassky': {'n_is_sb': '0'},
 'spastic': {'n_is_sb': '0'},
 'spawner': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spear carrier': {'n_is_sb': '0'},
 'spearfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spearnose bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'special agent': {'n_is_sb': '0'},
 'specialiser': {'n_is_sb': '0'},
 'specializer': {'n_is_sb': '0'},
 'specifier': {'n_is_sb': '2', 'n_is_sth': '2'},
 'speckled rattlesnake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'speckled trout': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spectacled caiman': {'n_is_sb': '3', 'n_is_sth': '3'},
 'speculator': {'n_is_sb': '0'},
 'speech therapist': {'n_is_sb': '0'},
 'speechifier': {'n_is_sb': '0'},
 'speechmaker': {'n_is_sb': '0'},
 'speechwriter': {'n_is_sb': '0'},
 'speed cop': {'n_is_sb': '0'},
 'speed demon': {'n_is_sb': '0'},
 'speed freak': {'n_is_sb': '0'},
 'speed skater': {'n_is_sb': '0'},
 'speedskater': {'n_is_sb': '0'},
 'speer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'speke': {'n_is_sb': '0'},
 'spelaeologist': {'n_is_sb': '0'},
 'speleologist': {'n_is_sb': '0'},
 'spellbinder': {'n_is_sb': '2', 'n_is_sth': '2'},
 'speller': {'n_is_sb': '2', 'n_is_sth': '2'},
 'spelunker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'spencer tracy': {'n_is_sb': '0'},
 'spend-all': {'n_is_sb': '0'},
 'spender': {'n_is_sb': '0'},
 'spengler': {'n_is_sb': '0'},
 'spenser': {'n_is_sb': '0'},
 'sperm whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spermophile': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sperry': {'n_is_sb': '0'},
 'spewer': {'n_is_sb': '0'},
 'sphecius speciosis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sphecoid wasp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sphecoid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spheniscidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sphenisciform seabird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spheniscus demersus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sphenodon punctatum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sphenodon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sphingid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sphinx moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sphyraena barracuda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sphyraena': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sphyrapicus varius ruber': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sphyrapicus varius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sphyrna tiburo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sphyrna tudes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sphyrna zygaena': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spick': {'n_is_sb': '0'},
 'spic': {'n_is_sb': '0'},
 'spider crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spider mite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spider monkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spielberg': {'n_is_sb': '0'},
 'spike lee': {'n_is_sb': '0'},
 'spik': {'n_is_sb': '0'},
 'spillane': {'n_is_sb': '0'},
 'spiller': {'n_is_sb': '0'},
 'spilogale putorius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spin doctor': {'n_is_sb': '0'},
 'spindle horn': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spindlelegs': {'n_is_sb': '0'},
 'spindleshanks': {'n_is_sb': '0'},
 'spinmeister': {'n_is_sb': '0'},
 'spinoza': {'n_is_sb': '0'},
 'spinus pinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spinus tristis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spiny anteater': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spiny dogfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spiny lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spiny lobster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spiny puffer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spiny softshell': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spiny-finned fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spiny-headed worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spipistrellus hesperus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spirilla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spirillum minus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spirillum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spirit rapper': {'n_is_sb': '0'},
 'spiritual being': {'n_is_sb': '2', 'n_is_sth': '2'},
 'spiritual jewel': {'n_is_sb': '0'},
 'spiritual leader': {'n_is_sb': '0'},
 'spiritualist': {'n_is_sb': '0'},
 'spirochaeta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spirochaete': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spirogyra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spirula peronii': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spirula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spitfire': {'n_is_sb': '2', 'n_is_sth': '2'},
 'spitter': {'n_is_sb': '0'},
 'spitting cobra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spitting snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spittle insect': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spittlebug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spitz': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spizella arborea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spizella passerina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spizella pusilla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spizella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'splicer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'split end': {'n_is_sb': '2', 'n_is_sth': '2'},
 'splitworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spock': {'n_is_sb': '0'},
 'spode': {'n_is_sb': '2', 'n_is_sth': '2'},
 'spodoptera exigua': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spodoptera frugiperda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spoiler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'spoilsport': {'n_is_sb': '0'},
 'spokeswoman': {'n_is_sb': '0', 'nc_typical': ''},
 'spongefly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sponger': {'n_is_sb': '2', 'n_is_sth': '2'},
 'spongillafly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spoonbill catfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spoonbill': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sporozoan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sporozoa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sporozoite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sport fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sporting dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sporting lady': {'n_is_sb': '0'},
 'sporting man': {'n_is_sb': '0'},
 'sports announcer': {'n_is_sb': '0'},
 'sports commentator': {'n_is_sb': '0'},
 'sports editor': {'n_is_sb': '0'},
 'sports fan': {'n_is_sb': '0'},
 'sports writer': {'n_is_sb': '0'},
 'sportscaster': {'n_is_sb': '0'},
 'sportswriter': {'n_is_sb': '0'},
 'spot welder': {'n_is_sb': '2', 'n_is_sth': '2'},
 'spot-welder': {'n_is_sb': '2', 'n_is_sth': '2'},
 'spotted antbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spotted bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spotted black bass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spotted crake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spotted eagle ray': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spotted flycatcher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spotted hyena': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spotted lynx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spotted owl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spotted ray': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spotted salamander': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spotted sandpiper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spotted sea trout': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spotted skunk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spotted squeateague': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spotted sunfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spotted weakfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spousal equivalent': {'n_is_sb': '0'},
 'spouse equivalent': {'n_is_sb': '0'},
 'spouter': {'n_is_sb': '0'},
 'sprat': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sprawler': {'n_is_sb': '0'},
 'spree killer': {'n_is_sb': '0'},
 'sprig tail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sprigger': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sprigtail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spring cankerworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spring chicken': {'n_is_sb': '2', 'n_is_sth': '2'},
 'spring frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spring peeper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'springbuck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'springer spaniel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'springer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'springing cow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'springtail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sprinter': {'n_is_sb': '0'},
 'sprog': {'n_is_sb': '0'},
 'spruce bark beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spruce gall aphid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spruce grouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spruce squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spurner': {'n_is_sb': '0'},
 'spyeria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'spymaster': {'n_is_sb': '0'},
 'squalus acanthias': {'n_is_sb': '3', 'n_is_sth': '3'},
 'squalus suckleyi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'squalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'squanderer': {'n_is_sb': '0'},
 'square dancer': {'n_is_sb': '0'},
 'square shooter': {'n_is_sb': '0'},
 'square toes': {'n_is_sb': '2', 'n_is_sth': '2'},
 'squareflipper square flipper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'squaretail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'squash bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'squatina squatina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'squatter': {'n_is_sb': '0'},
 'squaw man': {'n_is_sb': '0'},
 'squawker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'squaw': {'n_is_sb': '0'},
 'squealer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'squilla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'squint-eye': {'n_is_sb': '0'},
 'squinter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'squirmer': {'n_is_sb': '0'},
 'squirrel monkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'squirrelfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sri frederick handley page': {'n_is_sb': '0'},
 'sri lankan': {'n_is_sb': '0'},
 'st bernard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'st. ambrose': {'n_is_sb': '0'},
 'st. andrew': {'n_is_sb': '0'},
 'st. anselm': {'n_is_sb': '0'},
 'st. athanasius': {'n_is_sb': '0'},
 'st. augustine': {'n_is_sb': '0'},
 'st. baeda': {'n_is_sb': '0'},
 'st. basil the great': {'n_is_sb': '0'},
 'st. basil': {'n_is_sb': '0'},
 'st. beda': {'n_is_sb': '0'},
 'st. bede': {'n_is_sb': '0'},
 'st. benedict': {'n_is_sb': '0'},
 'st. boniface': {'n_is_sb': '0'},
 'st. bride': {'n_is_sb': '0'},
 'st. bridget': {'n_is_sb': '0'},
 'st. brigid': {'n_is_sb': '0'},
 'st. bruno': {'n_is_sb': '0'},
 'st. christopher': {'n_is_sb': '0'},
 'st. crispin': {'n_is_sb': '0'},
 'st. david': {'n_is_sb': '0'},
 'st. denis': {'n_is_sb': '2', 'n_is_sth': '2'},
 'st. dominic': {'n_is_sb': '0'},
 'st. edward the confessor': {'n_is_sb': '0'},
 'st. edward the martyr': {'n_is_sb': '0'},
 'st. francis of assisi': {'n_is_sb': '0'},
 'st. francis': {'n_is_sb': '0'},
 'st. george': {'n_is_sb': '2', 'n_is_sth': '2'},
 'st. gregory i': {'n_is_sb': '0'},
 'st. gregory of nazianzen': {'n_is_sb': '0'},
 'st. ignatius of loyola': {'n_is_sb': '0'},
 'st. ignatius': {'n_is_sb': '0'},
 'st. james the apostle': {'n_is_sb': '0'},
 'st. james': {'n_is_sb': '0'},
 'st. jerome': {'n_is_sb': '0'},
 'st. john chrysostom': {'n_is_sb': '0'},
 'st. john the apostle': {'n_is_sb': '0'},
 'st. john the baptist': {'n_is_sb': '0'},
 'st. john': {'n_is_sb': '0'},
 'st. jude': {'n_is_sb': '0'},
 'st. lawrence': {'n_is_sb': '2', 'n_is_sth': '2'},
 'st. leo i': {'n_is_sb': '0'},
 'st. louis': {'n_is_sb': '2', 'n_is_sth': '2'},
 'st. luke': {'n_is_sb': '0'},
 'st. mark': {'n_is_sb': '0'},
 'st. martin': {'n_is_sb': '2', 'n_is_sth': '2'},
 'st. mary magdalene': {'n_is_sb': '0'},
 'st. mary magdalen': {'n_is_sb': '0'},
 'st. matthew the apostle': {'n_is_sb': '0'},
 'st. matthew': {'n_is_sb': '0'},
 'st. nicholas': {'n_is_sb': '0'},
 'st. nick': {'n_is_sb': '0'},
 'st. olaf': {'n_is_sb': '0'},
 'st. olav': {'n_is_sb': '0'},
 'st. patrick': {'n_is_sb': '0'},
 'st. paul': {'n_is_sb': '0'},
 'st. peter the apostle': {'n_is_sb': '0'},
 'st. peter': {'n_is_sb': '0'},
 'st. simon': {'n_is_sb': '0'},
 'st. thomas a becket': {'n_is_sb': '0'},
 'st. thomas aquinas': {'n_is_sb': '0'},
 'st. thomas': {'n_is_sb': '0'},
 'st. vitus': {'n_is_sb': '0'},
 'stable companion': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stableboy': {'n_is_sb': '0'},
 'stableman': {'n_is_sb': '0'},
 'stablemate': {'n_is_sb': '0'},
 'stacker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'stael': {'n_is_sb': '0'},
 'staff member': {'n_is_sb': '0'},
 'staff officer': {'n_is_sb': '0'},
 'staff sergeant': {'n_is_sb': '0'},
 'staffordshire bullterrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'staffordshire terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'staffordshite bull terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stag beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 "stag's-horn coral": {'n_is_sb': '3', 'n_is_sth': '3'},
 'stage director': {'n_is_sb': '0'},
 'stage manager': {'n_is_sb': '0'},
 'stage technician': {'n_is_sb': '0'},
 'stagehand': {'n_is_sb': '0'},
 'staggerer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'staghorn coral': {'n_is_sb': '3', 'n_is_sth': '3'},
 'staghound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stag': {'n_is_sb': '2', 'n_is_sth': '2'},
 'stainer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'stake driver': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stakeholder': {'n_is_sb': '0'},
 'stalinist': {'n_is_sb': '0'},
 'stalker': {'n_is_sb': '0'},
 'stalwart': {'n_is_sb': '0'},
 'stammerer': {'n_is_sb': '0'},
 'stamp collector': {'n_is_sb': '0'},
 'stamp dealer': {'n_is_sb': '0'},
 'stan laurel': {'n_is_sb': '0'},
 'stan musial': {'n_is_sb': '0'},
 'stan the man': {'n_is_sb': '0'},
 'standard poodle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'standard schnauzer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'standardiser': {'n_is_sb': '0'},
 'standardizer': {'n_is_sb': '0'},
 'standee': {'n_is_sb': '0'},
 'stander': {'n_is_sb': '2', 'n_is_sth': '2'},
 'standish': {'n_is_sb': '2', 'n_is_sth': '2'},
 'standup comedian': {'n_is_sb': '0'},
 'stanford white': {'n_is_sb': '0'},
 'stanislavsky': {'n_is_sb': '0'},
 'stanley baldwin': {'n_is_sb': '0'},
 'stanley frank musial': {'n_is_sb': '0'},
 'stanley kubrick': {'n_is_sb': '0'},
 'stanley smith stevens': {'n_is_sb': '0'},
 'stanley': {'n_is_sb': '0'},
 'stanton': {'n_is_sb': '2', 'n_is_sth': '2'},
 'staphylococci': {'n_is_sb': '3', 'n_is_sth': '3'},
 'staph': {'n_is_sb': '3', 'n_is_sth': '3'},
 'star-nosed mole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'starer': {'n_is_sb': '0'},
 'starets': {'n_is_sb': '0'},
 'starlet': {'n_is_sb': '2', 'n_is_sth': '2'},
 'starling': {'n_is_sb': '2', 'n_is_sth': '2'},
 'starnose mole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'starr': {'n_is_sb': '0'},
 'starting pitcher': {'n_is_sb': '0'},
 'starveling': {'n_is_sb': '0'},
 'state attorney': {'n_is_sb': '0'},
 'state senator': {'n_is_sb': '0'},
 'state treasurer': {'n_is_sb': '0'},
 'state trooper': {'n_is_sb': '0'},
 "state's attorney": {'n_is_sb': '0'},
 'stateless person': {'n_is_sb': '0'},
 'stater': {'n_is_sb': '2', 'n_is_sth': '2'},
 'stateswoman': {'n_is_sb': '0', 'nc_typical': ''},
 'station agent': {'n_is_sb': '0'},
 'station keeper': {'n_is_sb': '0'},
 'stationery seller': {'n_is_sb': '0'},
 'statue maker': {'n_is_sb': '0'},
 'staurikosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'staurikosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stay-at-home': {'n_is_sb': '0'},
 'stayer': {'n_is_sb': '0'},
 'steamer clam': {'n_is_sb': '3', 'n_is_sth': '3'},
 'steamfitter': {'n_is_sb': '0'},
 'steatornis caripensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'steele': {'n_is_sb': '0'},
 'steelmaker': {'n_is_sb': '0'},
 'steelman': {'n_is_sb': '0'},
 'steelworker': {'n_is_sb': '0'},
 'steenbok': {'n_is_sb': '3', 'n_is_sth': '3'},
 'steeplechaser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'steeplejack': {'n_is_sb': '0'},
 'steerer': {'n_is_sb': '0', 'nn_to_vb': 'steer', 'nn_to_jj': 'steerable', 'nn_to_rb': 'steered'},
 'stefan wyszynski': {'n_is_sb': '0'},
 'stefan zweig': {'n_is_sb': '0'},
 'steffens': {'n_is_sb': '0'},
 'steffi graf': {'n_is_sb': '0'},
 'steganopus tricolor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stegocephalia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stegosaur stenops': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stegosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stegosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'steichen': {'n_is_sb': '0'},
 'steinbeck': {'n_is_sb': '0'},
 'steinberg': {'n_is_sb': '0'},
 'steinbok': {'n_is_sb': '3', 'n_is_sth': '3'},
 'steinem': {'n_is_sb': '0'},
 'steinman': {'n_is_sb': '0'},
 'steinmetz': {'n_is_sb': '0'},
 'steinway': {'n_is_sb': '0'},
 'stein': {'n_is_sb': '2', 'n_is_sth': '2'},
 "stellar's sea eagle": {'n_is_sb': '3', 'n_is_sth': '3'},
 'stella': {'n_is_sb': '0'},
 'steller sea lion': {'n_is_sb': '3', 'n_is_sth': '3'},
 "steller's sea cow": {'n_is_sb': '3', 'n_is_sth': '3'},
 "steller's sea lion": {'n_is_sb': '3', 'n_is_sth': '3'},
 'steller': {'n_is_sb': '0'},
 'stemmer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'stendhal': {'n_is_sb': '0'},
 'stengel': {'n_is_sb': '0'},
 'stenopelmatidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stenopelmatus fuscus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stenopelmatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stenopterygius quadrisicissus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stenopterygius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stenotomus aculeatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stenotomus chrysops': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stenotomus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stentor': {'n_is_sb': '2', 'n_is_sth': '2'},
 'stepbrother': {'n_is_sb': '0'},
 'stepdaughter': {'n_is_sb': '0'},
 'stephane grappelli': {'n_is_sb': '0'},
 'stephane mallarme': {'n_is_sb': '0'},
 'stephanie graf': {'n_is_sb': '0'},
 'stephanus johannes paulus kruger': {'n_is_sb': '0'},
 'stephen a. douglas': {'n_is_sb': '0'},
 'stephen arnold douglas': {'n_is_sb': '0'},
 'stephen butler leacock': {'n_is_sb': '0'},
 'stephen collins foster': {'n_is_sb': '0'},
 'stephen crane': {'n_is_sb': '0'},
 'stephen decatur': {'n_is_sb': '0'},
 'stephen foster': {'n_is_sb': '0'},
 'stephen girard': {'n_is_sb': '0'},
 'stephen grover cleveland': {'n_is_sb': '0'},
 'stephen hawking': {'n_is_sb': '0'},
 'stephen jay gould': {'n_is_sb': '0'},
 'stephen leacock': {'n_is_sb': '0'},
 'stephen michael reich': {'n_is_sb': '0'},
 'stephen samuel wise': {'n_is_sb': '0'},
 'stephen sondheim': {'n_is_sb': '0'},
 'stephen spender': {'n_is_sb': '0'},
 'stephen vincent benet': {'n_is_sb': '0'},
 'stephen william hawking': {'n_is_sb': '0'},
 'stephenson': {'n_is_sb': '0'},
 'stephen': {'n_is_sb': '0'},
 'stepparent': {'n_is_sb': '0'},
 'stepper': {'n_is_sb': '2', 'n_is_sth': '2'},
 'stepsister': {'n_is_sb': '0'},
 'stercorariidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stercorarius parasiticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stereospondyli': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sterna hirundo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sterne': {'n_is_sb': '0'},
 'sterninae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sternotherus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sterope': {'n_is_sb': '2', 'n_is_sth': '2'},
 'steuben': {'n_is_sb': '0'},
 'steve martin': {'n_is_sb': '0'},
 'steve reich': {'n_is_sb': '0'},
 'stevedore': {'n_is_sb': '0'},
 'steven spielberg': {'n_is_sb': '0'},
 'steven weinberg': {'n_is_sb': '0'},
 'stevenson': {'n_is_sb': '0'},
 'stevens': {'n_is_sb': '0'},
 'stewardess': {'n_is_sb': '0', 'nc_typical': ''},
 'stewart': {'n_is_sb': '0'},
 'stheno': {'n_is_sb': '0'},
 'stick insect': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stick-in-the-mud': {'n_is_sb': '0'},
 'stickleback': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stickler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sticktight flea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sticktight': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stickup man': {'n_is_sb': '0'},
 'stictomys': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stictopelia cuneata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stictopelia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stieglitz': {'n_is_sb': '0'},
 'stifler': {'n_is_sb': '0'},
 'stifle': {'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'n_is_sth': '2'},
 'stigmatic': {'n_is_sb': '0'},
 'stigmatist': {'n_is_sb': '0'},
 'stillborn infant': {'n_is_sb': '0'},
 'stilt plover': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stiltbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stilwell': {'n_is_sb': '0'},
 'stingray': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stink fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stinkbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stinkpot': {'n_is_sb': '2', 'n_is_sth': '2'},
 'stinter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'stipendiary magistrate': {'n_is_sb': '0'},
 'stipendiary': {'n_is_sb': '0'},
 'stippler': {'n_is_sb': '0'},
 'stirk': {'n_is_sb': '2', 'n_is_sth': '2'},
 'stizostedion vitreum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stoat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stock breeder': {'n_is_sb': '0'},
 'stock farmer': {'n_is_sb': '0'},
 'stock raiser': {'n_is_sb': '0'},
 'stock trader': {'n_is_sb': '0'},
 'stockbroker': {'n_is_sb': '0'},
 'stocker': {'n_is_sb': '0'},
 'stockholder of record': {'n_is_sb': '0'},
 'stockist': {'n_is_sb': '0'},
 'stockjobber': {'n_is_sb': '2', 'n_is_sth': '2'},
 'stockton': {'n_is_sb': '2', 'n_is_sth': '2'},
 'stoic': {'n_is_sb': '0'},
 'stokowski': {'n_is_sb': '0'},
 'stomatopod crustacean': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stomatopoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stomatopod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stomper': {'n_is_sb': '0'},
 'stone bass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stone breaker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'stone crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stone curlew': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stone fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stone marten': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stonechat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stonefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stonefly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stoner': {'n_is_sb': '2', 'n_is_sth': '2'},
 'stonewall jackson': {'n_is_sb': '0'},
 'stonewaller': {'n_is_sb': '0'},
 'stonewort': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stony coral': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stoolie': {'n_is_sb': '0'},
 'stoolpigeon': {'n_is_sb': '0'},
 'stooper': {'n_is_sb': '0'},
 'stopes': {'n_is_sb': '0'},
 'stoppard': {'n_is_sb': '0'},
 'store detective': {'n_is_sb': '0'},
 'storeria occipitamaculata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'storm petrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'storm trooper': {'n_is_sb': '0'},
 'stormy petrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'storyteller': {'n_is_sb': '0'},
 'stowaway': {'n_is_sb': '0'},
 'stowe': {'n_is_sb': '0'},
 'strachey': {'n_is_sb': '0'},
 'stradivarius': {'n_is_sb': '2', 'n_is_sth': '2'},
 'stradivari': {'n_is_sb': '2', 'n_is_sth': '2'},
 'strafer': {'n_is_sb': '0'},
 'straggler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'straight arrow': {'n_is_sb': '0'},
 'straight man': {'n_is_sb': '0'},
 'straight person': {'n_is_sb': '0'},
 'straight shooter': {'n_is_sb': '0'},
 'strand wolf': {'n_is_sb': '3', 'n_is_sth': '3'},
 'strangler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'straphanger': {'n_is_sb': '0'},
 'strapper': {'n_is_sb': '0'},
 'strategian': {'n_is_sb': '0'},
 'strauss the elder': {'n_is_sb': '0'},
 'strauss the younger': {'n_is_sb': '0'},
 'strauss': {'n_is_sb': '0'},
 'stravinsky': {'n_is_sb': '0'},
 'straw boss': {'n_is_sb': '0'},
 'straw man': {'n_is_sb': '2', 'n_is_sth': '2'},
 'strawman': {'n_is_sb': '0'},
 'strawworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'strayer': {'n_is_sb': '0'},
 'streaker': {'n_is_sb': '0'},
 'streep': {'n_is_sb': '0'},
 'street arab': {'n_is_sb': '0'},
 'street child': {'n_is_sb': '0'},
 'street cleaner': {'n_is_sb': '0'},
 'street fighter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'street girl': {'n_is_sb': '0'},
 'street person': {'n_is_sb': '0'},
 'street sweeper': {'n_is_sb': '2', 'n_is_sth': '2'},
 'street urchin': {'n_is_sb': '0'},
 'streisand': {'n_is_sb': '0'},
 'strepera': {'n_is_sb': '3', 'n_is_sth': '3'},
 'strepsiceros': {'n_is_sb': '3', 'n_is_sth': '3'},
 'streptobacillus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'streptococci': {'n_is_sb': '3', 'n_is_sth': '3'},
 'streptococcus anhemolyticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'streptomyces erythreus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'streptomyces griseus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'streptomyces scabies': {'n_is_sb': '3', 'n_is_sth': '3'},
 'streptomyces': {'n_is_sb': '3', 'n_is_sth': '3'},
 'streptopelia risoria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'streptopelia turtur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'streptopelia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'strep': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stretcher-bearer': {'n_is_sb': '0'},
 'strickland': {'n_is_sb': '0'},
 'strider': {'n_is_sb': '2', 'n_is_sth': '2'},
 'strike leader': {'n_is_sb': '0'},
 'strikebreaker': {'n_is_sb': '0'},
 'strindberg': {'n_is_sb': '0'},
 'stringer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'strip miner': {'n_is_sb': '0'},
 'striped bass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'striped button quail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'striped drum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'striped hyena': {'n_is_sb': '3', 'n_is_sth': '3'},
 'striped killifish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'striped marlin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'striped muishond': {'n_is_sb': '3', 'n_is_sth': '3'},
 'striped mullet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'striped racer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'striped skunk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'striped squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'striper': {'n_is_sb': '2', 'n_is_sth': '2'},
 'stripper': {'n_is_sb': '2', 'n_is_sth': '2'},
 'striptease artist': {'n_is_sb': '0'},
 'stripteaser': {'n_is_sb': '0'},
 'strix aluco': {'n_is_sb': '3', 'n_is_sth': '3'},
 'strix nebulosa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'strix occidentalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'strix varia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'strix': {'n_is_sb': '2', 'n_is_sth': '2'},
 'strizostedion vitreum glaucum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stroheim': {'n_is_sb': '0'},
 'stromateid fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stromateidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stromateid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'strombus gigas': {'n_is_sb': '3', 'n_is_sth': '3'},
 'strong-armer': {'n_is_sb': '0'},
 'strumpet': {'n_is_sb': '0'},
 'struthio camelus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'struthiomimus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'struthio': {'n_is_sb': '3', 'n_is_sth': '3'},
 'strymon melinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stuart davis': {'n_is_sb': '0'},
 'stuart': {'n_is_sb': '2', 'n_is_sth': '2'},
 'stubbs': {'n_is_sb': '0'},
 'stud mare': {'n_is_sb': '3', 'n_is_sth': '3'},
 'student nurse': {'n_is_sb': '0'},
 'student teacher': {'n_is_sb': '0'},
 'studhorse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stuffed shirt': {'n_is_sb': '0'},
 'stumblebum': {'n_is_sb': '0'},
 'stumbler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'stumpknocker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stunner': {'n_is_sb': '2', 'n_is_sth': '2'},
 'stunt flier': {'n_is_sb': '0'},
 'stunt man': {'n_is_sb': '0'},
 'stunt pilot': {'n_is_sb': '0'},
 'stunt woman': {'n_is_sb': '0'},
 'stupid person': {'n_is_sb': '0'},
 'sturnella magna': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sturnella neglecta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sturnus vulgaris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'stutterer': {'n_is_sb': '0'},
 'stuyvesant': {'n_is_sb': '0'},
 'styler': {'n_is_sb': '0'},
 'stylite': {'n_is_sb': '0'},
 'styracosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'styracosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'styron': {'n_is_sb': '2', 'n_is_sth': '2'},
 'subcontractor': {'n_is_sb': '0'},
 'subdeacon': {'n_is_sb': '0'},
 'subdivider': {'n_is_sb': '0'},
 'subduer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'subeditor': {'n_is_sb': '0'},
 'subgenus chen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'subgenus pastor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'subjectivist': {'n_is_sb': '0'},
 'subjugator': {'n_is_sb': '0'},
 'subkingdom metazoa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'subkingdom parazoa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sublieutenant': {'n_is_sb': '0'},
 'submariner': {'n_is_sb': '0'},
 'submitter': {'n_is_sb': '0'},
 'subnormal': {'n_is_sb': '0'},
 'suborder carnosaura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'suborder ceratosaura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'suborder lari': {'n_is_sb': '2', 'n_is_sth': '2'},
 'suborder limicolae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'suborder ornithomimida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'suborder pachycephalosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'suborder scorpaenoidea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'suborner': {'n_is_sb': '0'},
 'subphylum cephalochordata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'subphylum craniata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'subphylum pentastomida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'subphylum tunicata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'subphylum urochordata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'subphylum urochorda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'subphylum vertebrata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'subsidiser': {'n_is_sb': '0'},
 'subsidizer': {'n_is_sb': '0'},
 'subsister': {'n_is_sb': '0'},
 'substance abuser': {'n_is_sb': '0'},
 'subtracter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'suburbanite': {'n_is_sb': '0'},
 'subversive': {'n_is_sb': '0'},
 'subverter': {'n_is_sb': '0'},
 'subvocaliser': {'n_is_sb': '0'},
 'subvocalizer': {'n_is_sb': '0'},
 'succeeder': {'n_is_sb': '0'},
 'succorer': {'n_is_sb': '0'},
 'succourer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'succuba': {'n_is_sb': '0'},
 'suckerfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sucking fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sucking louse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sucking pig': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sudanese': {'n_is_sb': '0'},
 'sudra': {'n_is_sb': '0'},
 'suer': {'n_is_sb': '0'},
 'sue': {'n_is_sb': '0', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'suffragan bishop': {'n_is_sb': '0'},
 'suffragan': {'n_is_sb': '0'},
 'suffragette': {'n_is_sb': '0'},
 'suffragist': {'n_is_sb': '0'},
 'sufi': {'n_is_sb': '0'},
 'sugar daddy': {'n_is_sb': '0'},
 'sugar ray robinson': {'n_is_sb': '0'},
 'suggester': {'n_is_sb': '0'},
 'suharto': {'n_is_sb': '0'},
 'suicide bomber': {'n_is_sb': '0'},
 'sukarno': {'n_is_sb': '0'},
 'sula bassana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sulfur bacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sulfur bottom': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sulfur butterfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sulla': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sullivan': {'n_is_sb': '0'},
 'sully': {'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'n_is_sth': '2'},
 'sulphur bacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sulphur butterfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sulphur-crested cockatoo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sultan of swat': {'n_is_sb': '0'},
 'sumatran': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sumerian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'summer duck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'summer flounder': {'n_is_sb': '3', 'n_is_sth': '3'},
 'summer redbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'summer tanager': {'n_is_sb': '3', 'n_is_sth': '3'},
 'summercaters': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sumner': {'n_is_sb': '0'},
 'sumo wrestler': {'n_is_sb': '0'},
 'sun king': {'n_is_sb': '0'},
 'sun myung moon': {'n_is_sb': '0'},
 'sun worshiper': {'n_is_sb': '0'},
 'sun yat-sen': {'n_is_sb': '0'},
 'sun yixian': {'n_is_sb': '0'},
 'sun-god': {'n_is_sb': '0'},
 'sunbather': {'n_is_sb': '0'},
 'sunni muslim': {'n_is_sb': '0'},
 'sunnite': {'n_is_sb': '0'},
 'sunni': {'n_is_sb': '0'},
 'super heavyweight': {'n_is_sb': '0'},
 'superbug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'supercargo': {'n_is_sb': '0'},
 'superfamily muroidea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'superfamily muscoidea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'supergrass': {'n_is_sb': '0'},
 'superior general': {'n_is_sb': '0'},
 'supermarketeer': {'n_is_sb': '0'},
 'supermarketer': {'n_is_sb': '0'},
 'supermex': {'n_is_sb': '0'},
 'supermodel': {'n_is_sb': '0'},
 'supermom': {'n_is_sb': '0'},
 'supernatural being': {'n_is_sb': '0'},
 'superordinate': {'n_is_sb': '2', 'be_jj_to_vbg': '', 'n_is_sth': '2'},
 'superslasher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'super': {'n_is_sb': '2', 'n_is_sth': '2'},
 'supplanter': {'n_is_sb': '0'},
 'suppliant': {'n_is_sb': '0'},
 'supplicant': {'n_is_sb': '0'},
 'supply officer': {'n_is_sb': '0'},
 'suppresser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'supremacist': {'n_is_sb': '0'},
 'suprematist': {'n_is_sb': '0'},
 'supreme authority': {'n_is_sb': '0'},
 'supreme being': {'n_is_sb': '0'},
 'surf fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'surfbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'surfboarder': {'n_is_sb': '2', 'n_is_sth': '2'},
 'surfer': {'n_is_sb': '0'},
 'surffish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'surfperch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'surgeon general': {'n_is_sb': '0'},
 'surgeonfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'suricata suricatta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'suricata tetradactyla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'suricata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'suricate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'surinam toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'surmounter': {'n_is_sb': '0'},
 'surmullet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'surnia ulula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'surnia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'surpriser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'surrealist': {'n_is_sb': '0'},
 'surrenderer': {'n_is_sb': '0'},
 'surrogate mother': {'n_is_sb': '0'},
 'survivalist': {'n_is_sb': '0'},
 'surya': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sus scrofa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'susan anthony': {'n_is_sb': '0'},
 'susan b. anthony': {'n_is_sb': '0'},
 'susan brownell anthony': {'n_is_sb': '0'},
 'susan sontag': {'n_is_sb': '0'},
 'suslik': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sussex spaniel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sustainer': {'n_is_sb': '2', 'nn_to_vb': 'sustain', 'nn_to_jj': 'sustained', 'n_is_sth': '2'},
 'sus': {'n_is_sb': '0', 'v_compcl': ''},
 'sutherland': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sutler': {'n_is_sb': '0'},
 'svante august arrhenius': {'n_is_sb': '0'},
 'svedberg': {'n_is_sb': '0'},
 'svengali': {'n_is_sb': '0'},
 'sverdrup': {'n_is_sb': '0'},
 'swaggerer': {'n_is_sb': '0'},
 'swaggie': {'n_is_sb': '0'},
 'swain': {'n_is_sb': '0'},
 'swallow shrike': {'n_is_sb': '3', 'n_is_sth': '3'},
 'swallow-tailed hawk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'swallow-tailed kite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'swammerdam': {'n_is_sb': '0'},
 'swamp hare': {'n_is_sb': '3', 'n_is_sth': '3'},
 'swamp rabbit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'swamp sparrow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'swamphen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'swanson': {'n_is_sb': '2', 'n_is_sth': '2'},
 'swayer': {'n_is_sb': '0'},
 'swazi': {'n_is_sb': '2', 'n_is_sth': '2'},
 'swearer': {'n_is_sb': '0'},
 'sweater girl': {'n_is_sb': '0'},
 'swedenborg': {'n_is_sb': '0'},
 'swede': {'n_is_sb': '2', 'n_is_sth': '2'},
 'swedish nightingale': {'n_is_sb': '0'},
 'sweeney todd': {'n_is_sb': '0'},
 'sweet talker': {'n_is_sb': '0'},
 'sweet-potato whitefly': {'n_is_sb': '0'},
 'swellhead': {'n_is_sb': '0'},
 'swiftlet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'swimming crab': {'n_is_sb': '3', 'n_is_sth': '3'},
 'swinburne': {'n_is_sb': '0'},
 'swineherd': {'n_is_sb': '0'},
 'swing voter': {'n_is_sb': '0'},
 'swinger': {'n_is_sb': '2', 'n_is_sth': '2'},
 'swiss people': {'n_is_sb': '0'},
 'switch-hitter': {'n_is_sb': '0'},
 'switchboard operator': {'n_is_sb': '0'},
 'switcher': {'n_is_sb': '2', 'n_is_sth': '2'},
 'switchman': {'n_is_sb': '0'},
 'swordtail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'swot': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sybarite': {'n_is_sb': '0'},
 'sydenham': {'n_is_sb': '0'},
 'sydney pollack': {'n_is_sb': '0'},
 'sydney silky': {'n_is_sb': '3', 'n_is_sth': '3'},
 'syllogiser': {'n_is_sb': '0'},
 'syllogist': {'n_is_sb': '0'},
 'syllogizer': {'n_is_sb': '0'},
 'sylph': {'n_is_sb': '0'},
 'sylvanus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'sylvan': {'n_is_sb': '0'},
 'sylvia communis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sylvia curruca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sylvia plath': {'n_is_sb': '0'},
 'sylvilagus aquaticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sylvilagus floridanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sylvilagus palustris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'sylvilagus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'symbion pandora': {'n_is_sb': '3', 'n_is_sth': '3'},
 'symboliser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'symbolist': {'n_is_sb': '0', 'nn_to_vb': 'symbolise', 'nn_to_jj': 'symbolic', 'nn_to_rb': 'symbolically'},
 'symbolizer': {'n_is_sb': '0'},
 'symonds': {'n_is_sb': '0'},
 'symons': {'n_is_sb': '0'},
 'sympathiser': {'n_is_sb': '0'},
 'sympathizer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'symphalangus syndactylus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'symphilid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'synagrops bellus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'synanceja verrucosa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'synanceja': {'n_is_sb': '3', 'n_is_sth': '3'},
 'synapsid reptile': {'n_is_sb': '3', 'n_is_sth': '3'},
 'synaptomys borealis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'synaptomys cooperi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'synaptomys': {'n_is_sb': '3', 'n_is_sth': '3'},
 'syncopator': {'n_is_sb': '0'},
 'syndicalist': {'n_is_sb': '0'},
 'syndicator': {'n_is_sb': '0'},
 'syndic': {'n_is_sb': '0'},
 'synentognathi': {'n_is_sb': '2', 'n_is_sth': '2'},
 'synercus caffer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'synercus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'synge': {'n_is_sb': '0'},
 'syngnathus hildebrandi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'synodontidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'synonymist': {'n_is_sb': '0'},
 'syntactician': {'n_is_sb': '0'},
 'synthesiser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'synthesist': {'n_is_sb': '0'},
 'synthesizer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'syphilitic': {'n_is_sb': '0'},
 'syrian bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'syrian hamster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'syrian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'syrrhaptes paradoxus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'system administrator': {'n_is_sb': '0'},
 'systematiser': {'n_is_sb': '0'},
 'systematist': {'n_is_sb': '0'},
 'systematizer': {'n_is_sb': '0'},
 'systemiser': {'n_is_sb': '0'},
 'systemizer': {'n_is_sb': '0'},
 'systems analyst': {'n_is_sb': '0'},
 'szell': {'n_is_sb': '0'},
 'szent-gyorgyi': {'n_is_sb': '0'},
 'szilard': {'n_is_sb': '0'},
 't-man': {'n_is_sb': '0'},
 't. e. lawrence': {'n_is_sb': '0'},
 't. h. white': {'n_is_sb': '0'},
 't. s. eliot': {'n_is_sb': '0'},
 'tabby cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tabby': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tablemate': {'n_is_sb': '0'},
 'tachina fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tacker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tackler': {'n_is_sb': '0'},
 'taco': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tadarida brasiliensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tadarida': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tadeus reichstein': {'n_is_sb': '0'},
 'tadeusz andrzej bonawentura kosciuszko': {'n_is_sb': '0'},
 'tadirida femorosacca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tadorna': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tadpole shrimp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'taenia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'taft': {'n_is_sb': '0'},
 'tagalong': {'n_is_sb': '0'},
 'taguan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tahitian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tailback': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tailed frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tailed toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tailgater': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tailless tenrec': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tailorbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'taipan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'taira': {'n_is_sb': '2', 'n_is_sth': '2'},
 'taiwanese': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tai': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tajik': {'n_is_sb': '2', 'n_is_sth': '2'},
 'takahe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'takelma': {'n_is_sb': '2', 'n_is_sth': '2'},
 'taker': {'n_is_sb': '0'},
 'takin': {'n_is_sb': '2', 'n_is_sth': '2'},
 'talapoin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'talcott parsons': {'n_is_sb': '0'},
 'talebearer': {'n_is_sb': '0'},
 'talent agent': {'n_is_sb': '0'},
 'talent scout': {'n_is_sb': '0'},
 'taleteller': {'n_is_sb': '0'},
 'talking head': {'n_is_sb': '0'},
 'tallchief': {'n_is_sb': '0'},
 'talleyrand': {'n_is_sb': '0'},
 'tallis': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tallulah bankhead': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tally clerk': {'n_is_sb': '0'},
 'tallyman': {'n_is_sb': '0'},
 'tamandua tetradactyla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tamandua': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tamandu': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tamanoir': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tamara karsavina': {'n_is_sb': '0'},
 'tamarao': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tamarau': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tamarin': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tamarisk gerbil': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tamburlaine': {'n_is_sb': '0'},
 'tamerlane': {'n_is_sb': '0'},
 'tamer': {'n_is_sb': '0', 'nn_to_vb': 'tame', 'nn_to_jj': 'tame'},
 'tamias striatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tamiasciurus douglasi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tamiasciurus hudsonicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tamiasciurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tamias': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tamil': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tammuz': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tammy wynetter pugh': {'n_is_sb': '0'},
 'tammy wynette': {'n_is_sb': '0'},
 'tamm': {'n_is_sb': '0'},
 'tanager': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tancred': {'n_is_sb': '0'},
 'taney': {'n_is_sb': '0'},
 'tange': {'n_is_sb': '0'},
 'tanguy': {'n_is_sb': '0'},
 'tank driver': {'n_is_sb': '0'},
 'tantaliser': {'n_is_sb': '0'},
 'tantalizer': {'n_is_sb': '0'},
 'tantalus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tantilla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tantrist': {'n_is_sb': '0'},
 'tanzanian': {'n_is_sb': '0'},
 'taoist trinity': {'n_is_sb': '0'},
 'taos': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tap dancer': {'n_is_sb': '0'},
 'tapestry moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tapirus indicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tapirus terrestris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tappan': {'n_is_sb': '0'},
 'tapster': {'n_is_sb': '0'},
 'taracahitian': {'n_is_sb': '0'},
 'tarahumara frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tarahumara': {'n_is_sb': '0'},
 'tarantino': {'n_is_sb': '0'},
 'taras grigoryevich shevchenko': {'n_is_sb': '0'},
 'tardigrade': {'n_is_sb': '3', 'n_is_sth': '3'},
 'taricha granulosa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'taricha torosa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'taricha': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tarkovsky': {'n_is_sb': '0'},
 'tarnished plant bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tarpan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tarpon atlanticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tarpon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tarquin the proud': {'n_is_sb': '0'},
 'tarquinius superbus': {'n_is_sb': '0'},
 'tarquinius': {'n_is_sb': '0'},
 'tarquin': {'n_is_sb': '0'},
 'tarsier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tarsius glis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tarsius syrichta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tartufe': {'n_is_sb': '0'},
 'tartuffe': {'n_is_sb': '0'},
 'tarzan of the apes': {'n_is_sb': '0'},
 'tarzan': {'n_is_sb': '0'},
 'tashmitum': {'n_is_sb': '0'},
 'tashmit': {'n_is_sb': '0'},
 'tashunca-uitco': {'n_is_sb': '0'},
 'taskmistress': {'n_is_sb': '0'},
 'tasmanian devil': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tasmanian tiger': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tasmanian wolf': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tasman': {'n_is_sb': '0'},
 'tasso': {'n_is_sb': '0'},
 'taste tester': {'n_is_sb': '0'},
 'taste-maker': {'n_is_sb': '0'},
 'taste-tester': {'n_is_sb': '0'},
 'tate': {'n_is_sb': '0'},
 'tati': {'n_is_sb': '0'},
 'tatouay': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tatou': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tatterdemalion': {'n_is_sb': '0'},
 'tattler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tatum': {'n_is_sb': '0'},
 'tatu': {'n_is_sb': '2', 'n_is_sth': '2'},
 'taurotragus derbianus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'taurotragus oryx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'taurotragus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tautoga onitis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tautoga': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tautogolabrus adspersus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tautog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tavern keeper': {'n_is_sb': '0'},
 'tawney': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tawny eagle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tawny owl': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tax assessor': {'n_is_sb': '0'},
 'tax collector': {'n_is_sb': '0'},
 'taxer': {'n_is_sb': '0'},
 'taxi dancer': {'n_is_sb': '0'},
 'taxidea taxus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'taxidermist': {'n_is_sb': '0'},
 'taxidriver': {'n_is_sb': '0'},
 'taximan': {'n_is_sb': '0'},
 'taxman': {'n_is_sb': '0'},
 'taxonomer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'taxonomist': {'n_is_sb': '0'},
 'tayassu angulatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tayassu pecari': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tayassu tajacu': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tayassuidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'taylor': {'n_is_sb': '0'},
 'tayra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tchotchke': {'n_is_sb': '2', 'n_is_sth': '2'},
 'te kanawa': {'n_is_sb': '0'},
 'tea tortrix': {'n_is_sb': '3', 'n_is_sth': '3'},
 "teacher's pet": {'n_is_sb': '0'},
 'teaching fellow': {'n_is_sb': '0'},
 'teach': {'n_is_sb': '0', 'v_compcl': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_at': '', 'vb_to_vbz': 'teaches', 'vb_to_vbd': 'teached', 'vb_to_vbn': 'teached', 'vb_to_nn': 'teacher', 'vb_to_vbg': 'teaching'},
 'teal': {'n_is_sb': '2', 'n_is_sth': '2'},
 'teamster': {'n_is_sb': '0'},
 'tearaway': {'n_is_sb': '0'},
 'teasdale': {'n_is_sb': '0'},
 'tebaldi': {'n_is_sb': '0'},
 'techie': {'n_is_sb': '0'},
 'technical sergeant': {'n_is_sb': '0'},
 'technocrat': {'n_is_sb': '0'},
 'technophile': {'n_is_sb': '0'},
 'technophobe': {'n_is_sb': '0'},
 'tecumseh': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tecumtha': {'n_is_sb': '0'},
 'tec': {'n_is_sb': '0'},
 'ted hughes': {'n_is_sb': '0'},
 'ted shawn': {'n_is_sb': '0'},
 'ted williams': {'n_is_sb': '0'},
 'teddy boy': {'n_is_sb': '0'},
 'ted': {'n_is_sb': '0'},
 'teetotaler': {'n_is_sb': '0'},
 'teetotalist': {'n_is_sb': '0'},
 'teetotaller': {'n_is_sb': '0'},
 'teg': {'n_is_sb': '3', 'n_is_sth': '3'},
 'teiid lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'teiidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'teiid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'teilhard de chardin': {'n_is_sb': '0'},
 'teju': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tekki': {'n_is_sb': '0'},
 'telecaster': {'n_is_sb': '0'},
 'telegraph operator': {'n_is_sb': '0'},
 'telegraphist': {'n_is_sb': '0'},
 'telemann': {'n_is_sb': '0'},
 'teleologist': {'n_is_sb': '0'},
 'teleost fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'teleostan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'teleostei': {'n_is_sb': '3', 'n_is_sth': '3'},
 'teleost': {'n_is_sb': '3', 'n_is_sth': '3'},
 'telepathist': {'n_is_sb': '0'},
 'telephone operator': {'n_is_sb': '0'},
 'telephoner': {'n_is_sb': '0'},
 'telephonist': {'n_is_sb': '0'},
 'televangelist': {'n_is_sb': '0'},
 'television announcer': {'n_is_sb': '0'},
 'television newscaster': {'n_is_sb': '0'},
 'television reporter': {'n_is_sb': '0'},
 'television star': {'n_is_sb': '0'},
 'tellurian': {'n_is_sb': '0'},
 'tellus': {'n_is_sb': '0'},
 'tell': {'n_is_sb': '0', 'nn_to_jj': 'telling', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_about': '', 'v_of': '', 'v_against': '', 'vb_to_vbz': 'tells', 'vb_to_vbd': 'told', 'vb_to_vbn': 'told', 'vb_to_jj': 'telling', 'v_n_whcl': '', 'vb_to_vbg': 'telling', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'telsontail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'telugu': {'n_is_sb': '2', 'n_is_sth': '2'},
 'temporary worker': {'n_is_sb': '0'},
 'temporiser': {'n_is_sb': '0'},
 'temporizer': {'n_is_sb': '0'},
 'tempter': {'n_is_sb': '0', 'nn_to_vb': 'tempt', 'nn_to_jj': 'tempting'},
 'temptress': {'n_is_sb': '0'},
 'ten-spined stickleback': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tenant farmer': {'n_is_sb': '0'},
 'tendrac': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tenebrionid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'teng hsiao-ping': {'n_is_sb': '0'},
 'teng hsiaoping': {'n_is_sb': '0'},
 'tennessean': {'n_is_sb': '0'},
 'tennessee walker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tennessee walking horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tennessee williams': {'n_is_sb': '0'},
 'tenniel': {'n_is_sb': '0'},
 'tennis coach': {'n_is_sb': '0'},
 'tennis player': {'n_is_sb': '0'},
 'tennis pro': {'n_is_sb': '0'},
 'tenno': {'n_is_sb': '0'},
 'tennyson': {'n_is_sb': '0'},
 'tenor saxophonist': {'n_is_sb': '0'},
 'tenorist': {'n_is_sb': '0'},
 'tenpounder': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tenrec ecaudatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tenrec': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tent caterpillar': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tent-caterpillar moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tentmaker': {'n_is_sb': '0'},
 'tenzing norgay': {'n_is_sb': '0'},
 'teodor josef konrad korzeniowski': {'n_is_sb': '0'},
 'teras': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tercelet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'terebellidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'teredinid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'teredo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'terence rattigan': {'n_is_sb': '0'},
 'terence': {'n_is_sb': '0'},
 'teresa': {'n_is_sb': '0'},
 'tereshkova': {'n_is_sb': '0'},
 'term infant': {'n_is_sb': '0'},
 'termer': {'n_is_sb': '0'},
 'termes': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tern': {'n_is_sb': '2', 'n_is_sth': '2'},
 'terpsichore': {'n_is_sb': '0'},
 'terrapene ornata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'terrapene': {'n_is_sb': '3', 'n_is_sth': '3'},
 'terrapin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'territorial': {'n_is_sb': '0'},
 'terry': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tertigravida': {'n_is_sb': '0'},
 'tertullian': {'n_is_sb': '0'},
 'tesla': {'n_is_sb': '2', 'n_is_sth': '2'},
 'test driver': {'n_is_sb': '0'},
 'test pilot': {'n_is_sb': '0'},
 'test-tube baby': {'n_is_sb': '0'},
 'testacean': {'n_is_sb': '3', 'n_is_sth': '3'},
 'testacea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'testate': {'n_is_sb': '0'},
 'testator': {'n_is_sb': '0'},
 'testatrix': {'n_is_sb': '0'},
 'testee': {'n_is_sb': '0'},
 'testifier': {'n_is_sb': '0'},
 'testudinata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'testudo graeca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tethyidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tethys': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tetrahymena': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tetranychid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tetrao urogallus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tetrao': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tetrapod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tetra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tettigoniid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'teutonic deity': {'n_is_sb': '0'},
 'teuton': {'n_is_sb': '0'},
 'texan': {'n_is_sb': '0', 'cap_word': 'Texan'},
 'texas armadillo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'texas chachalaca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'texas horned lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'texas longhorn': {'n_is_sb': '3', 'n_is_sth': '3'},
 'texas ranger': {'n_is_sb': '0'},
 'texas toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'texas tortoise': {'n_is_sb': '3', 'n_is_sth': '3'},
 'text editor': {'n_is_sb': '2', 'n_is_sth': '2'},
 'thackeray': {'n_is_sb': '0'},
 'thaddaeus': {'n_is_sb': '0'},
 'thaddeus kosciusko': {'n_is_sb': '0'},
 'thalarctos maritimus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thalarctos': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thalassoma bifasciatum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thales of miletus': {'n_is_sb': '0'},
 'thales': {'n_is_sb': '0'},
 'thalia': {'n_is_sb': '0'},
 'thamnophis proximus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thamnophis sauritus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thamnophis sirtalis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thamnophis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thanatos': {'n_is_sb': '2', 'n_is_sth': '2'},
 'thane': {'n_is_sb': '0'},
 'thankless wretch': {'n_is_sb': '0'},
 'tharp': {'n_is_sb': '0'},
 'thatcherite': {'n_is_sb': '0'},
 'thatcher': {'n_is_sb': '0'},
 'the admirable crichton': {'n_is_sb': '0'},
 'the bard': {'n_is_sb': '0'},
 'the boy orator of the platte': {'n_is_sb': '0'},
 'the british': {'n_is_sb': '0'},
 'the buddha': {'n_is_sb': '0'},
 'the devil': {'n_is_sb': '0'},
 'the english hippocrates': {'n_is_sb': '0'},
 'the english': {'n_is_sb': '0'},
 'the fates': {'n_is_sb': '0'},
 'the father of radio': {'n_is_sb': '0'},
 'the gloomy dean': {'n_is_sb': '0'},
 'the goat god': {'n_is_sb': '0'},
 'the great commoner': {'n_is_sb': '0'},
 'the great compromiser': {'n_is_sb': '0'},
 'the great elector': {'n_is_sb': '0'},
 'the irish': {'n_is_sb': '0'},
 'the iron duke': {'n_is_sb': '0'},
 'the jersey lillie': {'n_is_sb': '0'},
 'the king of swing': {'n_is_sb': '0'},
 'the kingmaker': {'n_is_sb': '0'},
 'the lady with the lamp': {'n_is_sb': '0'},
 'the little corporal': {'n_is_sb': '0'},
 'the little giant': {'n_is_sb': '0'},
 'the living dead': {'n_is_sb': '0'},
 'the manassa mauler': {'n_is_sb': '0'},
 'the march king': {'n_is_sb': '0'},
 'the nazarene': {'n_is_sb': '0'},
 'the sailor king': {'n_is_sb': '0'},
 'the say hey kid': {'n_is_sb': '0'},
 'the swiss': {'n_is_sb': '0'},
 'the tempter': {'n_is_sb': '0'},
 'the three weird sisters': {'n_is_sb': '0'},
 'the venerable bede': {'n_is_sb': '0'},
 'the virgin': {'n_is_sb': '0'},
 'the weird sisters': {'n_is_sb': '0'},
 'theater critic': {'n_is_sb': '0'},
 'theater director': {'n_is_sb': '0'},
 'theater prompter': {'n_is_sb': '0'},
 'theatergoer': {'n_is_sb': '0'},
 'theatre director': {'n_is_sb': '0'},
 'theatregoer': {'n_is_sb': '0'},
 'theatrical agent': {'n_is_sb': '0'},
 'theatrical producer': {'n_is_sb': '0'},
 'thea': {'n_is_sb': '0'},
 'theban': {'n_is_sb': '0'},
 'thecodont reptile': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thecodont': {'n_is_sb': '3', 'n_is_sth': '3'},
 'theia': {'n_is_sb': '0'},
 'theist': {'n_is_sb': '0'},
 'thelonious monk': {'n_is_sb': '0'},
 'thelonious sphere monk': {'n_is_sb': '0'},
 'themistocles': {'n_is_sb': '0'},
 'themis': {'n_is_sb': '0'},
 'theodor mommsen': {'n_is_sb': '0'},
 'theodor schwann': {'n_is_sb': '0'},
 'theodor seuss geisel': {'n_is_sb': '0'},
 'theodore dreiser': {'n_is_sb': '0'},
 'theodore dwight weld': {'n_is_sb': '0'},
 'theodore harold white': {'n_is_sb': '0'},
 'theodore herman albert dreiser': {'n_is_sb': '0'},
 'theodore roosevelt': {'n_is_sb': '0'},
 'theodore samuel williams': {'n_is_sb': '0'},
 'theologiser': {'n_is_sb': '0'},
 'theologist': {'n_is_sb': '0'},
 'theologizer': {'n_is_sb': '0'},
 'theophrastus philippus aureolus bombastus von hohenheim': {'n_is_sb': '0'},
 'theophrastus': {'n_is_sb': '0'},
 'theoriser': {'n_is_sb': '0'},
 'theorizer': {'n_is_sb': '0'},
 'theosophist': {'n_is_sb': '0'},
 'therapist': {'n_is_sb': '0'},
 'therapsid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'theresa': {'n_is_sb': '0'},
 'theridiid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thermoacidophile': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thermobia domestica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'theropod dinosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'theropod': {'n_is_sb': '3', 'n_is_sth': '3'},
 'theseus': {'n_is_sb': '0'},
 'thespian': {'n_is_sb': '0'},
 'thespis': {'n_is_sb': '0'},
 'thessalonian': {'n_is_sb': '0'},
 'thetis': {'n_is_sb': '0'},
 'thick skin': {'n_is_sb': '0'},
 'thick-billed murre': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thick-knee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thickhead': {'n_is_sb': '0'},
 'thin person': {'n_is_sb': '0'},
 'thin-shelled mussel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thiobacillus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thiobacteriaceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thiobacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'third baron rayleigh': {'n_is_sb': '0'},
 'third baseman': {'n_is_sb': '0'},
 'third party': {'n_is_sb': '2', 'n_is_sth': '2'},
 'third sacker': {'n_is_sb': '0'},
 'third-rater': {'n_is_sb': '0'},
 'thirster': {'n_is_sb': '0'},
 'thomas a becket': {'n_is_sb': '0'},
 'thomas a kempis': {'n_is_sb': '0'},
 'thomas alva edison': {'n_is_sb': '0'},
 'thomas aquinas': {'n_is_sb': '0'},
 'thomas augustus watson': {'n_is_sb': '0'},
 'thomas babington macaulay': {'n_is_sb': '0'},
 'thomas bayes': {'n_is_sb': '0'},
 'thomas bowdler': {'n_is_sb': '0'},
 'thomas bradley': {'n_is_sb': '0'},
 'thomas carew': {'n_is_sb': '0'},
 'thomas carlyle': {'n_is_sb': '0'},
 'thomas chippendale': {'n_is_sb': '0'},
 'thomas clayton wolfe': {'n_is_sb': '0'},
 'thomas crawford': {'n_is_sb': '0'},
 'thomas de quincey': {'n_is_sb': '0'},
 'thomas decker': {'n_is_sb': '0'},
 'thomas dekker': {'n_is_sb': '0'},
 'thomas edison': {'n_is_sb': '0'},
 'thomas edward lawrence': {'n_is_sb': '0'},
 'thomas gainsborough': {'n_is_sb': '0'},
 'thomas gray': {'n_is_sb': '0'},
 'thomas hardy': {'n_is_sb': '0'},
 'thomas hart benton': {'n_is_sb': '0'},
 'thomas hastings': {'n_is_sb': '0'},
 'thomas henry huxley': {'n_is_sb': '0'},
 'thomas higginson': {'n_is_sb': '0'},
 'thomas hobbes': {'n_is_sb': '0'},
 'thomas hodgkin': {'n_is_sb': '0'},
 'thomas hopkins gallaudet': {'n_is_sb': '0'},
 'thomas hunt morgan': {'n_is_sb': '0'},
 'thomas huxley': {'n_is_sb': '0'},
 'thomas j. hanks': {'n_is_sb': '0'},
 'thomas j. jackson': {'n_is_sb': '0'},
 'thomas jackson': {'n_is_sb': '0'},
 'thomas jefferson': {'n_is_sb': '0'},
 'thomas jonathan jackson': {'n_is_sb': '0'},
 'thomas kennerly wolfe jr.': {'n_is_sb': '0'},
 'thomas kid': {'n_is_sb': '0'},
 'thomas kyd': {'n_is_sb': '0'},
 'thomas lanier williams': {'n_is_sb': '0'},
 'thomas malory': {'n_is_sb': '0'},
 'thomas malthus': {'n_is_sb': '0'},
 'thomas mann': {'n_is_sb': '0'},
 'thomas merton': {'n_is_sb': '0'},
 'thomas middleton': {'n_is_sb': '0'},
 'thomas moore': {'n_is_sb': '0'},
 'thomas more': {'n_is_sb': '0'},
 'thomas nast': {'n_is_sb': '0'},
 'thomas nelson page': {'n_is_sb': '0'},
 'thomas paine': {'n_is_sb': '0'},
 'thomas pynchon': {'n_is_sb': '0'},
 'thomas reid': {'n_is_sb': '0'},
 'thomas robert malthus': {'n_is_sb': '0'},
 'thomas stearns eliot': {'n_is_sb': '0'},
 'thomas straussler': {'n_is_sb': '0'},
 'thomas sully': {'n_is_sb': '0'},
 'thomas sydenham': {'n_is_sb': '0'},
 'thomas tallis': {'n_is_sb': '0'},
 'thomas the doubting apostle': {'n_is_sb': '0'},
 'thomas wentworth storrow higginson': {'n_is_sb': '0'},
 'thomas wolfe': {'n_is_sb': '0'},
 'thomas woodrow wilson': {'n_is_sb': '0'},
 'thomas wright waller': {'n_is_sb': '0'},
 'thomas young': {'n_is_sb': '0'},
 'thomas': {'n_is_sb': '0'},
 'thomomys bottae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thomomys talpoides': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thompson': {'n_is_sb': '0'},
 "thomson's gazelle": {'n_is_sb': '3', 'n_is_sth': '3'},
 'thomson': {'n_is_sb': '0'},
 'thor hyerdahl': {'n_is_sb': '0'},
 'thoreau': {'n_is_sb': '0'},
 'thornbill': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thorndike': {'n_is_sb': '0'},
 'thornton niven wilder': {'n_is_sb': '0'},
 'thornton wilder': {'n_is_sb': '0'},
 'thornton': {'n_is_sb': '0'},
 'thorny skate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thoroughbred': {'n_is_sb': '2', 'jj_ed': '', 'n_is_sth': '2'},
 'thorstein bunde veblen': {'n_is_sb': '0'},
 'thorstein veblen': {'n_is_sb': '0'},
 'thor': {'n_is_sb': '0'},
 'thoth': {'n_is_sb': '0'},
 'thought-reader': {'n_is_sb': '0'},
 'thraupidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thread maker': {'n_is_sb': '0'},
 'thread-fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'threadfin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'threadfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'threadworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'three-banded armadillo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'three-spined stickleback': {'n_is_sb': '3', 'n_is_sth': '3'},
 'three-toed sloth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thresher shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'threskiornis aethiopica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thripid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thrips tobaci': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thrips': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thrip': {'n_is_sb': '3', 'n_is_sth': '3'},
 'throstle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'throttler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'throwaway': {'n_is_sb': '2', 'n_is_sth': '2'},
 'throwster': {'n_is_sb': '0'},
 'thrush nightingale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thryothorus ludovicianus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thryothorus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thucydides': {'n_is_sb': '0'},
 'thunder lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thunder snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thunderbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thunderer': {'n_is_sb': '0'},
 'thunnus alalunga': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thunnus albacares': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thunnus thynnus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thunnus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thurber': {'n_is_sb': '0'},
 'thurifer': {'n_is_sb': '0'},
 'thwarter': {'n_is_sb': '0'},
 'thylacine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thylacinus cynocephalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thylacinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thylogale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thyreophoran': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thyreophora': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thysanopteron': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thysanopterous insect': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thysanopter': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thysanuran insect': {'n_is_sb': '3', 'n_is_sth': '3'},
 'thysanuron': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tiamat': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tiberius claudius drusus nero germanicus': {'n_is_sb': '0'},
 'tiberius claudius nero caesar augustus': {'n_is_sb': '0'},
 'tiberius': {'n_is_sb': '0'},
 'tibetan mastiff': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tibetan terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tibetan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tibicen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tichodroma muriaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tichodroma': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tichodrome': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ticket agent': {'n_is_sb': '0'},
 'ticket collector': {'n_is_sb': '0'},
 'ticket holder': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ticket taker': {'n_is_sb': '0'},
 'ticket tout': {'n_is_sb': '0'},
 'tiddler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tien-pao': {'n_is_sb': '0'},
 'tiepolo': {'n_is_sb': '0'},
 'tier up': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tiercel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tiger beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tiger cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tiger cowrie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tiger cub': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tiger moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tiger rattlesnake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tiger salamander': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tiger shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tiger snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tight end': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tightrope walker': {'n_is_sb': '0'},
 'tiglon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tigon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tike': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tilapia nilotica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tilapia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tilden': {'n_is_sb': '0'},
 'tilefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tillich': {'n_is_sb': '0'},
 'tilter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tim leary': {'n_is_sb': '0'},
 'timalia': {'n_is_sb': '0'},
 'timber rattlesnake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'timber wolf': {'n_is_sb': '3', 'n_is_sth': '3'},
 'timberman': {'n_is_sb': '0'},
 'timeserver': {'n_is_sb': '0'},
 'timorese': {'n_is_sb': '0'},
 'timothy francis leary': {'n_is_sb': '0'},
 'timothy leary': {'n_is_sb': '0'},
 'timothy miles bindon rice': {'n_is_sb': '0'},
 'timothy': {'n_is_sb': '3', 'n_is_sth': '3'},
 'timpanist': {'n_is_sb': '0'},
 'timucu': {'n_is_sb': '3', 'n_is_sth': '3'},
 'timur lenk': {'n_is_sb': '0'},
 'timur': {'n_is_sb': '0'},
 'tinamou': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tinbergen': {'n_is_sb': '0'},
 'tinca tinca': {'n_is_sb': '0'},
 'tindale': {'n_is_sb': '0'},
 'tindal': {'n_is_sb': '0'},
 'tinea pellionella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tineid moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tineid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tineoid moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tineoid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tineola bisselliella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tineola': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tinkerer': {'n_is_sb': '0'},
 'tinner': {'n_is_sb': '0'},
 'tinsmith': {'n_is_sb': '0'},
 'tinter': {'n_is_sb': '0'},
 'tintoretto': {'n_is_sb': '0'},
 'tipper': {'n_is_sb': '0'},
 'tipster': {'n_is_sb': '0'},
 'tiresias': {'n_is_sb': '0'},
 'tiro': {'n_is_sb': '0'},
 'tirso de molina': {'n_is_sb': '0'},
 'tisiphone': {'n_is_sb': '0'},
 'titaness': {'n_is_sb': '0'},
 'titania': {'n_is_sb': '0'},
 'titanosaurian': {'n_is_sb': '0'},
 'titanosauridae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'titanosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'titanosaur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tither': {'n_is_sb': '0'},
 'titi monkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'titian': {'n_is_sb': '2', 'n_is_sth': '2'},
 'titi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'titlark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'title-holder': {'n_is_sb': '0'},
 'titmouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tito': {'n_is_sb': '0'},
 'titterer': {'n_is_sb': '0'},
 'titus flavius domitianus': {'n_is_sb': '0'},
 'titus flavius sabinus vespasianus': {'n_is_sb': '0'},
 'titus flavius vespasianus': {'n_is_sb': '0'},
 'titus livius': {'n_is_sb': '0'},
 'titus lucretius carus': {'n_is_sb': '0'},
 'titus maccius plautus': {'n_is_sb': '0'},
 'titus oates': {'n_is_sb': '0'},
 'titus vespasianus augustus': {'n_is_sb': '0'},
 'titus': {'n_is_sb': '0'},
 'tiu': {'n_is_sb': '0'},
 'tiziano vecellio': {'n_is_sb': '0'},
 'tjalling charles koopmans': {'n_is_sb': '0'},
 'tjalling koopmans': {'n_is_sb': '0'},
 'tlingit': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tmv': {'n_is_sb': '3', 'n_is_sth': '3'},
 'toad frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'toadfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'toast mistress': {'n_is_sb': '0'},
 'tobacco budworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tobacco hornworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tobacco mosaic virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tobacco moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tobacco thrips': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tobacco user': {'n_is_sb': '0'},
 'tobacconist': {'n_is_sb': '0'},
 'tobagonian': {'n_is_sb': '0'},
 'tobey': {'n_is_sb': '0'},
 'tobias george smollett': {'n_is_sb': '0'},
 'tobias smollett': {'n_is_sb': '0'},
 'tobin': {'n_is_sb': '0'},
 'tobogganist': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tocqueville': {'n_is_sb': '0'},
 'toda': {'n_is_sb': '2', 'n_is_sth': '2'},
 'toddler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'todd': {'n_is_sb': '0'},
 'tody': {'n_is_sb': '3', 'n_is_sth': '3'},
 'togavirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'togolese': {'n_is_sb': '0'},
 'toiler': {'n_is_sb': '0'},
 'tojo eiki': {'n_is_sb': '0'},
 'tojo hideki': {'n_is_sb': '0'},
 'tojo': {'n_is_sb': '0'},
 'toklas': {'n_is_sb': '0'},
 'tolkien': {'n_is_sb': '0'},
 'toll agent': {'n_is_sb': '0'},
 'toll collector': {'n_is_sb': '2', 'n_is_sth': '2'},
 'toll taker': {'n_is_sb': '0'},
 'toller': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tollgatherer': {'n_is_sb': '0'},
 'tollkeeper': {'n_is_sb': '0'},
 'tollman': {'n_is_sb': '0'},
 'tolypeutes tricinctus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tom bradley': {'n_is_sb': '0'},
 'tom hanks': {'n_is_sb': '0'},
 'tom paine': {'n_is_sb': '0'},
 'tom sawyer': {'n_is_sb': '0'},
 'tom stoppard': {'n_is_sb': '0'},
 'tom thumb': {'n_is_sb': '0'},
 'tom turkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tom wolfe': {'n_is_sb': '0'},
 'tomas de torquemada': {'n_is_sb': '0'},
 'tomato fruitworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tomato hornworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tomato worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tombaugh': {'n_is_sb': '0'},
 'tomboy': {'n_is_sb': '0'},
 'tomcat': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tomfool': {'n_is_sb': '0'},
 'tomistoma schlegeli': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tomtate': {'n_is_sb': '0'},
 'tomtit': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tom': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tonegawa susumu': {'n_is_sb': '0'},
 'tongan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tongue worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tongue-fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tonguefish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tongueless frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'toni morrison': {'n_is_sb': '0'},
 'tony blair': {'n_is_sb': '0'},
 'tooth doctor': {'n_is_sb': '0'},
 'tooth fairy': {'n_is_sb': '0'},
 'tooth shell': {'n_is_sb': '3', 'n_is_sth': '3'},
 'toothed whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'top banana': {'n_is_sb': '0'},
 'top dog': {'n_is_sb': '0'},
 'top executive': {'n_is_sb': '0'},
 'toper': {'n_is_sb': '0'},
 'topi': {'n_is_sb': '2', 'n_is_sth': '2'},
 'topminnow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'topper': {'n_is_sb': '2', 'n_is_sth': '2'},
 'torch singer': {'n_is_sb': '0'},
 'torchbearer': {'n_is_sb': '0'},
 'toreador': {'n_is_sb': '0'},
 'torero': {'n_is_sb': '0'},
 'tormenter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tormentor': {'n_is_sb': '2', 'n_is_sth': '2'},
 'torquato tasso': {'n_is_sb': '0'},
 'torquemada': {'n_is_sb': '0'},
 'torricelli': {'n_is_sb': '2', 'n_is_sth': '2'},
 'torsk': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tort-feasor': {'n_is_sb': '0'},
 'tortfeasor': {'n_is_sb': '0'},
 'tortoiseshell butterfly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tortoiseshell turtle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tortoiseshell-cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tortricid moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tortricid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tortrix': {'n_is_sb': '3', 'n_is_sth': '3'},
 'torturer': {'n_is_sb': '0'},
 'toscanini': {'n_is_sb': '0'},
 'tosser': {'n_is_sb': '0'},
 'toter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'totterer': {'n_is_sb': '0'},
 'toucanet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'touch-typist': {'n_is_sb': '0'},
 'toucher': {'n_is_sb': '0', 'nn_to_vb': 'touch', 'nn_to_jj': 'touchable'},
 'tough guy': {'n_is_sb': '0'},
 'toulouse-lautrec': {'n_is_sb': '0'},
 'tour guide': {'n_is_sb': '0'},
 'touraco': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tourette': {'n_is_sb': '2', 'n_is_sth': '2'},
 'touter': {'n_is_sb': '0'},
 'tovarich': {'n_is_sb': '0'},
 'tow-headed snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tower of strength': {'n_is_sb': '0'},
 'towhee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'town clerk': {'n_is_sb': '0'},
 'town crier': {'n_is_sb': '0'},
 'townee': {'n_is_sb': '0'},
 'towner': {'n_is_sb': '0'},
 'townsend harris': {'n_is_sb': '0'},
 'townsend': {'n_is_sb': '0'},
 'towny': {'n_is_sb': '0'},
 'toxicologist': {'n_is_sb': '0'},
 'toxostoma rufums': {'n_is_sb': '3', 'n_is_sth': '3'},
 'toxotes jaculatrix': {'n_is_sb': '3', 'n_is_sth': '3'},
 'toy dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'toy manchester terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'toy manchester': {'n_is_sb': '3', 'n_is_sth': '3'},
 'toy poodle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'toy spaniel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'toy terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'toynbee': {'n_is_sb': '0'},
 'trachinotus carolinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trachinotus falcatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trachipteridae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trachipterus arcticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trachodont': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trachodon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trachurus symmetricus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trachurus trachurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'track star': {'n_is_sb': '0'},
 'tracklayer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tractarian': {'n_is_sb': '0'},
 'tracy': {'n_is_sb': '0'},
 'trade rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trade unionist': {'n_is_sb': '0'},
 'tradescant': {'n_is_sb': '0'},
 'traditionalist': {'n_is_sb': '0', 'nn_to_jj': 'traditional', 'nn_to_rb': 'traditionally'},
 'traducer': {'n_is_sb': '0'},
 'traffic cop': {'n_is_sb': '0'},
 'tragedian': {'n_is_sb': '0'},
 'tragedienne': {'n_is_sb': '0'},
 'tragelaphus angasi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tragelaphus buxtoni': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tragelaphus eurycerus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tragelaphus imberbis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tragelaphus scriptus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tragelaphus strepsiceros': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tragelaphus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tragopan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tragulus javanicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tragulus kanchil': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tragulus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trail boss': {'n_is_sb': '0'},
 'train dispatcher': {'n_is_sb': '0'},
 'trainbandsman': {'n_is_sb': '0'},
 'trainbearer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'trained nurse': {'n_is_sb': '0'},
 'trained worker': {'n_is_sb': '0'},
 'trainman': {'n_is_sb': '0'},
 'trainmaster': {'n_is_sb': '0'},
 'traitress': {'n_is_sb': '0'},
 'trajan': {'n_is_sb': '0'},
 'tramper': {'n_is_sb': '2', 'n_is_sth': '2'},
 'trampler': {'n_is_sb': '0'},
 'transactor': {'n_is_sb': '0'},
 'transalpine': {'n_is_sb': '0'},
 'transcendentalist': {'n_is_sb': '0'},
 'transcriber': {'n_is_sb': '2', 'n_is_sth': '2'},
 'transexual': {'n_is_sb': '0'},
 'transferee': {'n_is_sb': '0'},
 'transferer': {'n_is_sb': '0'},
 'transferor': {'n_is_sb': '0'},
 'transferrer': {'n_is_sb': '0'},
 'transmigrante': {'n_is_sb': '0'},
 'transplanter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'transportation secretary': {'n_is_sb': '0'},
 'transsexual': {'n_is_sb': '0'},
 'transvestite': {'n_is_sb': '0'},
 'trap-door spider': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trapper': {'n_is_sb': '2', 'n_is_sth': '2'},
 'trappist': {'n_is_sb': '0'},
 'trapshooter': {'n_is_sb': '0'},
 'traubel': {'n_is_sb': '0'},
 'travel agent': {'n_is_sb': '0'},
 'traveling salesman': {'n_is_sb': '0'},
 'travelling salesman': {'n_is_sb': '0'},
 'traverser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'trawler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'treasonist': {'n_is_sb': '0'},
 'treasury secretary': {'n_is_sb': '0'},
 'treater': {'n_is_sb': '2', 'nn_to_vb': 'treat', 'nn_to_jj': 'treated', 'n_is_sth': '2'},
 'tree creeper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tree cricket': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tree farmer': {'n_is_sb': '0'},
 'tree frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tree hugger': {'n_is_sb': '0'},
 'tree kangaroo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tree lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tree martin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tree shrew': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tree sloth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tree sparrow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tree squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tree surgeon': {'n_is_sb': '0'},
 'tree swallow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tree swift': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tree toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tree wallaby': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tree-frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'treehopper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trekker': {'n_is_sb': '0'},
 'trematoda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trematode worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trematode': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trencher': {'n_is_sb': '2', 'n_is_sth': '2'},
 'trend-setter': {'n_is_sb': '0'},
 'trepang': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trephritidae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'treponemataceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'treponema': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trespasser': {'n_is_sb': '0'},
 'trevelyan': {'n_is_sb': '0'},
 'trevino': {'n_is_sb': '0'},
 'trevithick': {'n_is_sb': '0'},
 'triaenodon obseus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trial attorney': {'n_is_sb': '0'},
 'trial judge': {'n_is_sb': '0'},
 'trial lawyer': {'n_is_sb': '0'},
 'trialeurodes vaporariorum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tribade': {'n_is_sb': '0'},
 'tribal chief': {'n_is_sb': '0'},
 'tribal sheikh': {'n_is_sb': '0'},
 'tribal sheik': {'n_is_sb': '0'},
 'tribe bovini': {'n_is_sb': '0'},
 'tribe bubalus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tribe synercus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tribesman': {'n_is_sb': '0'},
 'tribologist': {'n_is_sb': '0'},
 'tribonemaceae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'triceratops': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trichechus manatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trichina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trichinella spiralis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trichoglossus moluccanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trichoglossus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trichomonad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trichophaga tapetzella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trichopteran': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trichopteron': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trichopterous insect': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trichosurus vulpecula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trichys lipura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tridacna gigas': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trifler': {'n_is_sb': '0'},
 'triggerfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trigla lucerna': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trigonometrician': {'n_is_sb': '0'},
 'trilby': {'n_is_sb': '2', 'n_is_sth': '2'},
 'trilling': {'n_is_sb': '2', 'n_is_sth': '2'},
 'trimmer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'trimorphodon lambda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trinectes maculatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trinectes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tringa flavipes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tringa melanoleuca': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tringa nebularia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tringa totanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trinidadian': {'n_is_sb': '0'},
 'trinil man': {'n_is_sb': '0'},
 'trinitarian': {'n_is_sb': '0'},
 'trionyx muticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trionyx spiniferus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trionyx': {'n_is_sb': '3', 'n_is_sth': '3'},
 'triops': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tripletail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tripper': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tristan tzara': {'n_is_sb': '0'},
 'tristan': {'n_is_sb': '0'},
 'tristram': {'n_is_sb': '0'},
 'tritheist': {'n_is_sb': '0'},
 'triturus vulgaris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'triturus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'triumvir': {'n_is_sb': '0'},
 'trofim denisovich lysenko': {'n_is_sb': '0'},
 'trogium pulsatorium': {'n_is_sb': '3', 'n_is_sth': '3'},
 'troglodytes aedon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'troglodytes troglodytes': {'n_is_sb': '2', 'n_is_sth': '2'},
 'troglodytes': {'n_is_sb': '2', 'n_is_sth': '2'},
 'trogon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trojan': {'n_is_sb': '0', 'cap_word': 'Trojan'},
 'troller': {'n_is_sb': '2', 'n_is_sth': '2'},
 'trollope': {'n_is_sb': '0'},
 'trombiculiid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trombidiid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trombone player': {'n_is_sb': '0'},
 'trombonist': {'n_is_sb': '0'},
 'trophozoite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trophy wife': {'n_is_sb': '0'},
 'tropic bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tropical prawn': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tropidoclonion lineatum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trotskyist': {'n_is_sb': '0'},
 'trotskyite': {'n_is_sb': '0'},
 'trotsky': {'n_is_sb': '0'},
 'trotter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'trotting horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'troubadour': {'n_is_sb': '0'},
 'trouble maker': {'n_is_sb': '0'},
 'trouble shooter': {'n_is_sb': '0'},
 'troubler': {'n_is_sb': '0'},
 'troubleshooter': {'n_is_sb': '0'},
 'truant': {'n_is_sb': '0'},
 'truck driver': {'n_is_sb': '0'},
 'truckler': {'n_is_sb': '0'},
 'trudger': {'n_is_sb': '0'},
 'true bacteria': {'n_is_sb': '3', 'n_is_sth': '3'},
 'true bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'true cat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'true dwarf': {'n_is_sb': '0'},
 'true flycatcher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'true frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'true lobster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'true marmoset': {'n_is_sb': '3', 'n_is_sth': '3'},
 'true seal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'true sparrow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'true vampire bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'true warbler': {'n_is_sb': '3', 'n_is_sth': '3'},
 'truffaut': {'n_is_sb': '0'},
 'truman': {'n_is_sb': '0'},
 'trumbo': {'n_is_sb': '0'},
 'trumbull': {'n_is_sb': '0'},
 'trumpeter swan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trumpetfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trunkfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'trustbuster': {'n_is_sb': '0'},
 'truster': {'n_is_sb': '0'},
 'trygve halvden lie': {'n_is_sb': '0'},
 'trygve lie': {'n_is_sb': '0'},
 'tsarina': {'n_is_sb': '0'},
 'tsaritsa': {'n_is_sb': '0'},
 'tsetse fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tsetse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tsimshian': {'n_is_sb': '0'},
 'tsine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tsung dao lee': {'n_is_sb': '0'},
 'tswana': {'n_is_sb': '0'},
 'tuareg': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tuatara': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tuatha de danann': {'n_is_sb': '0'},
 'tuatha de': {'n_is_sb': '0'},
 'tub gurnard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tub-thumper': {'n_is_sb': '0'},
 'tube-nosed bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tube-nosed fruit bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tubercle bacillus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tubman': {'n_is_sb': '0'},
 'tuchman': {'n_is_sb': '0'},
 'tudor': {'n_is_sb': '2', 'cap_word': 'Tudor', 'n_is_sth': '2'},
 'tufted puffin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tufted titmouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tugger': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tully': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tulu': {'n_is_sb': '0'},
 'tumblebug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tumbler pigeon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tumor virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tundra swan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tuner': {'n_is_sb': '2', 'nn_to_vb': 'tune', 'nn_to_jj': 'tuneless', 'nn_to_rb': 'tunelessly', 'n_is_sth': '2'},
 'tunga penetrans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tungus': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tunisian': {'n_is_sb': '0'},
 'tunker': {'n_is_sb': '0'},
 'tunney': {'n_is_sb': '0'},
 'tunny': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tupaia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tupi': {'n_is_sb': '0'},
 'tup': {'n_is_sb': '3', 'n_is_sth': '3'},
 'turacou': {'n_is_sb': '3', 'n_is_sth': '3'},
 'turaco': {'n_is_sb': '3', 'n_is_sth': '3'},
 'turakoo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'turbatrix aceti': {'n_is_sb': '3', 'n_is_sth': '3'},
 'turbot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'turcoman': {'n_is_sb': '0'},
 'turdus grayi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'turdus iliacus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'turdus merula': {'n_is_sb': '3', 'n_is_sth': '3'},
 'turdus migratorius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'turdus philomelos': {'n_is_sb': '3', 'n_is_sth': '3'},
 'turdus pilaris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'turdus torquatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'turdus viscivorus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'turgenev': {'n_is_sb': '0'},
 'turgot': {'n_is_sb': '0'},
 'turing': {'n_is_sb': '2', 'cap_word': 'Turing', 'n_is_sth': '2'},
 'turkey buzzard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'turkey cock': {'n_is_sb': '2', 'n_is_sth': '2'},
 'turkey vulture': {'n_is_sb': '3', 'n_is_sth': '3'},
 'turki': {'n_is_sb': '0'},
 'turkoman': {'n_is_sb': '0'},
 'turncock': {'n_is_sb': '2', 'n_is_sth': '2'},
 'turnix sylvatica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'turnstone': {'n_is_sb': '3', 'n_is_sth': '3'},
 'turpin': {'n_is_sb': '0'},
 'tursiops gilli': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tursiops truncatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'turtledove': {'n_is_sb': '2', 'n_is_sth': '2'},
 'turtler': {'n_is_sb': '0'},
 'tuscan': {'n_is_sb': '0'},
 'tuscarora': {'n_is_sb': '0'},
 'tussah': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tussaud': {'n_is_sb': '0'},
 'tusseh': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tusser': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tussock caterpillar': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tussock moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tussore': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tussur': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tutankhamen': {'n_is_sb': '0'},
 'tutee': {'n_is_sb': '0'},
 'tutelo': {'n_is_sb': '0'},
 'tutsi': {'n_is_sb': '0'},
 'tutu': {'n_is_sb': '2', 'n_is_sth': '2'},
 'tv announcer': {'n_is_sb': '0'},
 'tv newsman': {'n_is_sb': '0'},
 'tv reporter': {'n_is_sb': '0'},
 'tv star': {'n_is_sb': '0'},
 'twaddler': {'n_is_sb': '0'},
 'twat': {'n_is_sb': '2', 'n_is_sth': '2', 'dirtyword': ''},
 'twerp': {'n_is_sb': '0'},
 'twiddler': {'n_is_sb': '0'},
 'twiner': {'n_is_sb': '3', 'n_is_sth': '3'},
 'twirler': {'n_is_sb': '0'},
 'twirp': {'n_is_sb': '0'},
 'twitterer': {'n_is_sb': '0'},
 'two-spotted ladybug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'two-toed anteater': {'n_is_sb': '3', 'n_is_sth': '3'},
 'two-toed sloth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'two-wing flying fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'two-winged insects': {'n_is_sb': '3', 'n_is_sth': '3'},
 'twyla tharp': {'n_is_sb': '0'},
 'tyche': {'n_is_sb': '0'},
 'tylenchus tritici': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tyler': {'n_is_sb': '0'},
 'tympanist': {'n_is_sb': '0'},
 'tympanuchus cupido cupido': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tympanuchus cupido': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tympanuchus pallidicinctus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tympanuchus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tyndale': {'n_is_sb': '0'},
 'tyndall': {'n_is_sb': '0'},
 'typesetter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'typhoeus': {'n_is_sb': '0'},
 'typhoid bacillus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'typhoid bacteriophage': {'n_is_sb': '3', 'n_is_sth': '3'},
 'typhoid mary': {'n_is_sb': '0'},
 'typhon': {'n_is_sb': '2', 'n_is_sth': '2'},
 'typical jerboa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'typographer': {'n_is_sb': '0'},
 'tyrannosaurus rex': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tyrannosaurus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tyrannus domenicensis domenicensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tyrannus tyrannus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tyrannus vociferans': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tyrant bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tyrant flycatcher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tyrr': {'n_is_sb': '0'},
 'tyr': {'n_is_sb': '0'},
 'tyson': {'n_is_sb': '0'},
 'tyto alba': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tzara': {'n_is_sb': '0'},
 'tzarina': {'n_is_sb': '0'},
 'tzar': {'n_is_sb': '0'},
 'tzetze fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'tzetze': {'n_is_sb': '3', 'n_is_sth': '3'},
 'uakari': {'n_is_sb': '3', 'n_is_sth': '3'},
 'uca': {'n_is_sb': '2', 'n_is_sth': '2'},
 'udmurt': {'n_is_sb': '0'},
 'ugandan': {'n_is_sb': '0'},
 'ugly duckling': {'n_is_sb': '2', 'n_is_sth': '2'},
 'ugo buoncompagni': {'n_is_sb': '0'},
 'uhland': {'n_is_sb': '0'},
 'uighur': {'n_is_sb': '0'},
 'uigur': {'n_is_sb': '0'},
 'uintathere': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ukranian': {'n_is_sb': '0'},
 'ulanova': {'n_is_sb': '0'},
 'ulfilas': {'n_is_sb': '0'},
 'ulfila': {'n_is_sb': '0'},
 'ullr': {'n_is_sb': '0'},
 'ull': {'n_is_sb': '0'},
 'ulrich zwingli': {'n_is_sb': '0'},
 'ultraconservative': {'n_is_sb': '0'},
 'ultramontane': {'n_is_sb': '0'},
 'ulva': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ulysses grant': {'n_is_sb': '0'},
 'ulysses s. grant': {'n_is_sb': '0'},
 'ulysses simpson grant': {'n_is_sb': '0'},
 'uma notata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'uma': {'n_is_sb': '0'},
 'umbrella bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'umbrina roncador': {'n_is_sb': '3', 'n_is_sth': '3'},
 'umbrina': {'n_is_sb': '3', 'n_is_sth': '3'},
 'unau': {'n_is_sb': '3', 'n_is_sth': '3'},
 'uncle joe': {'n_is_sb': '0'},
 'uncle sam': {'n_is_sb': '0'},
 'uncle tom': {'n_is_sb': '0'},
 'underachiever': {'n_is_sb': '0'},
 'underclassman': {'n_is_sb': '0'},
 'undercover agent': {'n_is_sb': '0'},
 'underdog': {'n_is_sb': '2', 'n_is_sth': '2'},
 'undergrad': {'n_is_sb': '2', 'n_is_sth': '2'},
 'underperformer': {'n_is_sb': '0'},
 'underseller': {'n_is_sb': '0'},
 'undertaker': {'n_is_sb': '0'},
 'underwater diver': {'n_is_sb': '0'},
 'underwing': {'n_is_sb': '3', 'n_is_sth': '3'},
 'underwriter': {'n_is_sb': '0'},
 'undesirable': {'n_is_sb': '0'},
 'undine': {'n_is_sb': '0'},
 'undoer': {'n_is_sb': '0'},
 'undset': {'n_is_sb': '0'},
 'uneducated person': {'n_is_sb': '0'},
 'unemotional person': {'n_is_sb': '0'},
 'unemployed person': {'n_is_sb': '0'},
 'unfastener': {'n_is_sb': '0'},
 'unfortunate person': {'n_is_sb': '0'},
 'unfortunate': {'n_is_sb': '0', 'jj_to_rb': 'unfortunately'},
 'ungrateful person': {'n_is_sb': '0'},
 'unguiculate mammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'unguiculate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ungulate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'uniate christian': {'n_is_sb': '0'},
 'uniate': {'n_is_sb': '0'},
 'uniat': {'n_is_sb': '0'},
 'unicyclist': {'n_is_sb': '0'},
 'unilateralist': {'n_is_sb': '0'},
 'uniocular dichromat': {'n_is_sb': '0'},
 'union member': {'n_is_sb': '0'},
 'union representative': {'n_is_sb': '0'},
 'union soldier': {'n_is_sb': '0'},
 'unionist': {'n_is_sb': '0'},
 'unitarian': {'n_is_sb': '0'},
 'united states attorney general': {'n_is_sb': '0'},
 'united states president': {'n_is_sb': '0'},
 'univalve': {'n_is_sb': '3', 'n_is_sth': '3'},
 'universal agent': {'n_is_sb': '0'},
 'universal donor': {'n_is_sb': '0'},
 'university student': {'n_is_sb': '0'},
 'unix guru': {'n_is_sb': '0'},
 'unkind person': {'n_is_sb': '0'},
 'unknown soldier': {'n_is_sb': '0'},
 'unmarried man': {'n_is_sb': '0'},
 'unmarried woman': {'n_is_sb': '0'},
 'unnerved': {'n_is_sb': '0', 'sb_be_jj': '', 'vbd_eq_vbn': ''},
 'unpaid worker': {'n_is_sb': '0'},
 'unperson': {'n_is_sb': '0'},
 'unpleasant person': {'n_is_sb': '0'},
 'unpleasant woman': {'n_is_sb': '0'},
 'unraveler': {'n_is_sb': '0'},
 'unraveller': {'n_is_sb': '0'},
 'unskilled person': {'n_is_sb': '0'},
 'unsuccessful person': {'n_is_sb': '0'},
 'untermeyer': {'n_is_sb': '0'},
 'untier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'untouchable': {'n_is_sb': '2', 'n_is_sth': '2'},
 'unusual person': {'n_is_sb': '0'},
 'unwelcome guest': {'n_is_sb': '0'},
 'unwelcome person': {'n_is_sb': '0'},
 'upbraider': {'n_is_sb': '0'},
 'updike': {'n_is_sb': '0'},
 'upholder': {'n_is_sb': '2', 'n_is_sth': '2'},
 'upholsterer': {'n_is_sb': '0'},
 'upjohn': {'n_is_sb': '0'},
 'upland plover': {'n_is_sb': '3', 'n_is_sth': '3'},
 'upland sandpiper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'uprooter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'upsetter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'upstager': {'n_is_sb': '0'},
 'upton beall sinclair': {'n_is_sb': '0'},
 'upton sinclair': {'n_is_sb': '0'},
 'upupa epops': {'n_is_sb': '3', 'n_is_sth': '3'},
 'urania': {'n_is_sb': '2', 'n_is_sth': '2'},
 'uranologist': {'n_is_sb': '0'},
 'urban guerrilla': {'n_is_sb': '0'},
 'urban ii': {'n_is_sb': '0'},
 'urban vi': {'n_is_sb': '0'},
 'urd': {'n_is_sb': '3', 'n_is_sth': '3'},
 'urey': {'n_is_sb': '0'},
 'uria aalge': {'n_is_sb': '3', 'n_is_sth': '3'},
 'uria lomvia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'urial': {'n_is_sb': '3', 'n_is_sth': '3'},
 'uria': {'n_is_sb': '2', 'n_is_sth': '2'},
 'urinator': {'n_is_sb': '0'},
 'urochordata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'urochordate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'urochorda': {'n_is_sb': '3', 'n_is_sth': '3'},
 'urochord': {'n_is_sb': '3', 'n_is_sth': '3'},
 'urocyon cinereoargenteus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'urodella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'urologist': {'n_is_sb': '0'},
 'uropsilus soricipes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'urosaurus ornatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ursine dasyure': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ursus americanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ursus arctos horribilis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ursus arctos middendorffi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ursus arctos syriacus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ursus arctos': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ursus horribilis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ursus maritimus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ursus middendorffi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ursus thibetanus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ursus ursinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'urth': {'n_is_sb': '0'},
 'uruguayan': {'n_is_sb': '0'},
 'us attorney general': {'n_is_sb': '0'},
 'usama bin laden': {'n_is_sb': '0'},
 'usbeg': {'n_is_sb': '0'},
 'usbek': {'n_is_sb': '0'},
 'ushas': {'n_is_sb': '0'},
 'usherette': {'n_is_sb': '0'},
 'ussher': {'n_is_sb': '0'},
 'ustinov': {'n_is_sb': '0'},
 'usufructuary': {'n_is_sb': '0'},
 'usurer': {'n_is_sb': '0'},
 'usurper': {'n_is_sb': '0'},
 'uta stansburiana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'utahan': {'n_is_sb': '0'},
 'utahraptor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'uta': {'n_is_sb': '0'},
 'ute': {'n_is_sb': '0'},
 'utiliser': {'n_is_sb': '0'},
 'utilitarian': {'n_is_sb': '0'},
 'utility man': {'n_is_sb': '0'},
 'utilizer': {'n_is_sb': '0'},
 'utnapishtim': {'n_is_sb': '0'},
 'utopian': {'n_is_sb': '0'},
 'utrillo': {'n_is_sb': '0'},
 'utterer': {'n_is_sb': '0'},
 'utug': {'n_is_sb': '0'},
 'utu': {'n_is_sb': '2', 'n_is_sth': '2'},
 'uxor': {'n_is_sb': '0'},
 'ux': {'n_is_sb': '0'},
 'uygur': {'n_is_sb': '0'},
 'uzbak': {'n_is_sb': '0'},
 'uzbeg': {'n_is_sb': '0'},
 'v.p.': {'n_is_sb': '0'},
 'vacationer': {'n_is_sb': '0'},
 'vacationist': {'n_is_sb': '0'},
 'vaccinator': {'n_is_sb': '2', 'n_is_sth': '2'},
 'vaccinee': {'n_is_sb': '2', 'n_is_sth': '2'},
 'vachel lindsay': {'n_is_sb': '0'},
 'vacillator': {'n_is_sb': '0'},
 'vaclav havel': {'n_is_sb': '0'},
 'vagn walfrid ekman': {'n_is_sb': '0'},
 'vaishnava': {'n_is_sb': '0'},
 'vaisya': {'n_is_sb': '0'},
 'valedictorian': {'n_is_sb': '0'},
 'valedictory speaker': {'n_is_sb': '0'},
 'valentina tereshkova': {'n_is_sb': '0'},
 'valentina vladmirovna tereshkova': {'n_is_sb': '0'},
 'valet de chambre': {'n_is_sb': '0'},
 'valetudinarian': {'n_is_sb': '0'},
 'vali': {'n_is_sb': '0'},
 'valkyrie': {'n_is_sb': '0'},
 'valley girl': {'n_is_sb': '2', 'n_is_sth': '2'},
 'valley pocket gopher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'valuator': {'n_is_sb': '0', 'nn_to_vb': 'value', 'nn_to_jj': 'valuable', 'nn_to_rb': 'valuably'},
 'valuer': {'n_is_sb': '0', 'nn_to_vb': 'value', 'nn_to_jj': 'valuable', 'nn_to_rb': 'valuably'},
 'vamper': {'n_is_sb': '0'},
 'vampire bat': {'n_is_sb': '2', 'n_is_sth': '2'},
 'van allen': {'n_is_sb': '0'},
 'van beethoven': {'n_is_sb': '0'},
 'van buren': {'n_is_sb': '0'},
 'van de graaff': {'n_is_sb': '0'},
 'van de velde': {'n_is_sb': '0'},
 'van der waals': {'n_is_sb': '0'},
 'van doren': {'n_is_sb': '0'},
 'van dyck': {'n_is_sb': '0'},
 'van eyck': {'n_is_sb': '0'},
 'van gogh': {'n_is_sb': '0'},
 'van vleck': {'n_is_sb': '0'},
 'van wyck brooks': {'n_is_sb': '0'},
 'vanbrugh': {'n_is_sb': '0'},
 'vandal': {'n_is_sb': '0'},
 'vanderbilt': {'n_is_sb': '0'},
 'vandyke': {'n_is_sb': '2', 'n_is_sth': '2'},
 'vanellus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vanessa atalanta': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vanessa bell': {'n_is_sb': '0'},
 'vanessa stephen': {'n_is_sb': '0'},
 'vanessa virginiensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vanessa': {'n_is_sb': '0'},
 'vanir': {'n_is_sb': '0'},
 'vanisher': {'n_is_sb': '0'},
 'vannevar bush': {'n_is_sb': '0'},
 'vanzetti': {'n_is_sb': '0'},
 'vaquero': {'n_is_sb': '0'},
 'vaquita': {'n_is_sb': '3', 'n_is_sth': '3'},
 'varanus komodoensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'varanus niloticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'varan': {'n_is_sb': '2', 'n_is_sth': '2'},
 'varese': {'n_is_sb': '0'},
 'vargas llosa': {'n_is_sb': '0'},
 'vargas': {'n_is_sb': '0'},
 'varicella zoster virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'varied lorikeet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'variola major virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'variola minor virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'variola virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'varment': {'n_is_sb': '3', 'n_is_sth': '3'},
 'varnisher': {'n_is_sb': '2', 'n_is_sth': '2'},
 'varro': {'n_is_sb': '0'},
 'varuna': {'n_is_sb': '0'},
 'varying hare': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vasarely': {'n_is_sb': '0'},
 'vasari': {'n_is_sb': '0'},
 'vasco da gamma': {'n_is_sb': '0'},
 'vasco nunez de balboa': {'n_is_sb': '0'},
 'vaslav nijinsky': {'n_is_sb': '0'},
 'vaticinator': {'n_is_sb': '0'},
 'vaudevillian': {'n_is_sb': '0'},
 'vaughan williams': {'n_is_sb': '0'},
 'vaughan': {'n_is_sb': '0'},
 'vaulter': {'n_is_sb': '0'},
 'vaunter': {'n_is_sb': '0'},
 'vaux': {'n_is_sb': '0'},
 'vayu': {'n_is_sb': '0'},
 'veblen': {'n_is_sb': '0'},
 'vedalia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vedist': {'n_is_sb': '0'},
 'veery': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vegan': {'n_is_sb': '0'},
 'velazquez': {'n_is_sb': '0'},
 'velociraptor': {'n_is_sb': '3', 'n_is_sth': '3'},
 'velvet ant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'velvet worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'venerator': {'n_is_sb': '0'},
 'venezuelan': {'n_is_sb': '0'},
 'venn': {'n_is_sb': '0'},
 'venomous lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'ventner': {'n_is_sb': '0'},
 'ventriloquist': {'n_is_sb': '0'},
 'venture capitalist': {'n_is_sb': '0'},
 'venturer': {'n_is_sb': '0'},
 'venturi': {'n_is_sb': '2', 'n_is_sth': '2'},
 'venus mercenaria': {'n_is_sb': '3', 'n_is_sth': '3'},
 "venus's flower basket": {'n_is_sb': '3', 'n_is_sth': '3'},
 "venus's girdle": {'n_is_sb': '3', 'n_is_sth': '3'},
 'vepse': {'n_is_sb': '2', 'n_is_sth': '2'},
 'vepsian': {'n_is_sb': '0'},
 'veps': {'n_is_sb': '0'},
 'verbaliser': {'n_is_sb': '0'},
 'verbalizer': {'n_is_sb': '0'},
 'verdandi': {'n_is_sb': '0'},
 'verdin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'verdi': {'n_is_sb': '0'},
 'verger': {'n_is_sb': '0'},
 'vergil': {'n_is_sb': '0'},
 'verifier': {'n_is_sb': '2', 'n_is_sth': '2'},
 'verlaine': {'n_is_sb': '0'},
 'vermeer': {'n_is_sb': '0'},
 'vermillion flycatcher': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vermillion rockfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vermonter': {'n_is_sb': '0'},
 'verner': {'n_is_sb': '0'},
 'verne': {'n_is_sb': '0'},
 'vernier': {'n_is_sb': '2', 'n_is_sth': '2'},
 'veronese': {'n_is_sb': '0'},
 'verrazano': {'n_is_sb': '0'},
 'verrazzano': {'n_is_sb': '0'},
 'versace': {'n_is_sb': '0'},
 'versifier': {'n_is_sb': '0'},
 'verthandi': {'n_is_sb': '0'},
 'vervet monkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vervet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'verwoerd': {'n_is_sb': '0'},
 'very important person': {'n_is_sb': '0'},
 'vesalius': {'n_is_sb': '0'},
 'vesey': {'n_is_sb': '0'},
 'vesiculovirus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vespa crabro': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vespasian': {'n_is_sb': '0'},
 'vesper mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vesper sparrow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vespertilian bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vespertilio murinus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vespertilionid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vespid wasp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vespid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vespucci': {'n_is_sb': '0'},
 'vespula maculata': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vespula maculifrons': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vespula vulgaris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vestal virgin': {'n_is_sb': '0'},
 'vesta': {'n_is_sb': '2', 'n_is_sth': '2'},
 'vestris': {'n_is_sb': '0'},
 'vestryman': {'n_is_sb': '0'},
 'vestrywoman': {'n_is_sb': '0'},
 'vetchworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'veteran soldier': {'n_is_sb': '0'},
 'veterinary surgeon': {'n_is_sb': '0'},
 'vexed': {'n_is_sb': '', 'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'vexer': {'n_is_sb': '0'},
 'vibist': {'n_is_sb': '2', 'n_is_sth': '2'},
 'vibraphonist': {'n_is_sb': '0'},
 'vibrio comma': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vibrio fetus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vibrion': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vicar apostolic': {'n_is_sb': '0'},
 'vicar of christ': {'n_is_sb': '0'},
 'vicar-general': {'n_is_sb': '0'},
 'vice admiral': {'n_is_sb': '0'},
 'vice chairman': {'n_is_sb': '0'},
 'vice chancellor': {'n_is_sb': '0'},
 'vice president': {'n_is_sb': '0'},
 'vice-regent': {'n_is_sb': '0'},
 'vicegerent': {'n_is_sb': '0'},
 'vicereine': {'n_is_sb': '0'},
 'vicomte de chateaubriand': {'n_is_sb': '0'},
 'vicomte ferdinand marie de lesseps': {'n_is_sb': '0'},
 'victimiser': {'n_is_sb': '0'},
 'victimizer': {'n_is_sb': '0'},
 'victor emanuel iii': {'n_is_sb': '0'},
 'victor emanuel ii': {'n_is_sb': '0'},
 'victor franz hess': {'n_is_sb': '0'},
 'victor herbert': {'n_is_sb': '0'},
 'victor hess': {'n_is_sb': '0'},
 'victor horta': {'n_is_sb': '0'},
 'victor hugo': {'n_is_sb': '0'},
 'victor-marie hugo': {'n_is_sb': '0'},
 'victoria clafin woodhull': {'n_is_sb': '0'},
 'victorian': {'n_is_sb': '2', 'cap_word': 'Victorian', 'n_is_sth': '2'},
 'victualer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'victualler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'vicugna vicugna': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vicugna': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vicuna': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vidal': {'n_is_sb': '0'},
 'vidar': {'n_is_sb': '0'},
 'vigdis finnbogadottir': {'n_is_sb': '0'},
 'vigee-lebrun': {'n_is_sb': '0'},
 'vigilance man': {'n_is_sb': '0'},
 'vigilante': {'n_is_sb': '0'},
 'viking': {'n_is_sb': '2', 'n_is_sth': '2'},
 'viktor korchnoi': {'n_is_sb': '0'},
 'viktor lvovich korchnoi': {'n_is_sb': '0'},
 'viktor vasarely': {'n_is_sb': '0'},
 'vilfredo pareto': {'n_is_sb': '0'},
 'vilifier': {'n_is_sb': '0'},
 'villa-lobos': {'n_is_sb': '0'},
 'villainess': {'n_is_sb': '0'},
 'villard': {'n_is_sb': '0'},
 'villein': {'n_is_sb': '0'},
 'villon': {'n_is_sb': '0'},
 'vincent van gogh': {'n_is_sb': '0'},
 'vincenzo bellini': {'n_is_sb': '0'},
 'vindicator': {'n_is_sb': '0'},
 'vine snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vinegar eel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vinegar fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vinegar joe stilwell': {'n_is_sb': '0'},
 'vinegar worm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vinegarroon': {'n_is_sb': '0'},
 'vinogradoff': {'n_is_sb': '0'},
 'vinson': {'n_is_sb': '0'},
 'vintager': {'n_is_sb': '0'},
 'vintner': {'n_is_sb': '0'},
 'violator': {'n_is_sb': '0', 'nn_to_vb': 'violate', 'nn_to_jj': 'violable', 'nn_to_rb': 'violably'},
 'violin maker': {'n_is_sb': '0'},
 'violinist': {'n_is_sb': '0', 'nc_typical': ''},
 'violist': {'n_is_sb': '0'},
 'vipera aspis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vipera berus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'viperine grass snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'virchow': {'n_is_sb': '0'},
 'vireo olivaceous': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vireo solitarius solitarius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vireo solitarius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vireo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'virgil garnett thomson': {'n_is_sb': '0'},
 'virgil thomson': {'n_is_sb': '0'},
 'virgil': {'n_is_sb': '0'},
 'virgin mary': {'n_is_sb': '0'},
 'virginia deer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'virginia mcmath': {'n_is_sb': '0'},
 'virginia oyster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'virginia wade': {'n_is_sb': '0'},
 'virginia woolf': {'n_is_sb': '0'},
 'virginian': {'n_is_sb': '0'},
 'virion': {'n_is_sb': '3', 'n_is_sth': '3'},
 'viroid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'virologist': {'n_is_sb': '0'},
 'virusoid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'visayan': {'n_is_sb': '0'},
 'viscacha': {'n_is_sb': '3', 'n_is_sth': '3'},
 'visconti': {'n_is_sb': '0'},
 'viscount nelson': {'n_is_sb': '0'},
 'viscount northcliffe': {'n_is_sb': '0'},
 'viscount st. albans': {'n_is_sb': '0'},
 'viscountess astor': {'n_is_sb': '0'},
 'viscountess': {'n_is_sb': '0'},
 'vishnu': {'n_is_sb': '0'},
 'visigoth': {'n_is_sb': '0'},
 'visitant': {'n_is_sb': '2', 'n_is_sth': '2'},
 'visiting fireman': {'n_is_sb': '0'},
 'visiting nurse': {'n_is_sb': '0'},
 'visiting professor': {'n_is_sb': '0'},
 'visualiser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'visualizer': {'n_is_sb': '2', 'nn_to_vb': 'visualise', 'nn_to_jj': 'visual', 'nn_to_rb': 'visually', 'n_is_sth': '2'},
 'visually handicapped person': {'n_is_sb': '0'},
 'vitaliser': {'n_is_sb': '0'},
 'vitalist': {'n_is_sb': '0'},
 'vitalizer': {'n_is_sb': '0'},
 'vitharr': {'n_is_sb': '0'},
 'vithar': {'n_is_sb': '0'},
 'viticulturist': {'n_is_sb': '0'},
 'vittorio de sica': {'n_is_sb': '0'},
 'vitus behring': {'n_is_sb': '0'},
 'vitus bering': {'n_is_sb': '0'},
 'vitus': {'n_is_sb': '0'},
 'vivaldi': {'n_is_sb': '0'},
 'viverra zibetha': {'n_is_sb': '3', 'n_is_sth': '3'},
 'viverricula indica': {'n_is_sb': '3', 'n_is_sth': '3'},
 'viverricula malaccensis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'viverrine mammal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'viverrine': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vivien leigh': {'n_is_sb': '0'},
 'viviparous eelpout': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vivisectionist': {'n_is_sb': '0'},
 'vizcaino': {'n_is_sb': '0'},
 'vizla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vladimir horowitz': {'n_is_sb': '0'},
 'vladimir ilich lenin': {'n_is_sb': '0'},
 'vladimir ilich ulyanov': {'n_is_sb': '0'},
 'vladimir ilyich lenin': {'n_is_sb': '0'},
 'vladimir ilyich ulyanov': {'n_is_sb': '0'},
 'vladimir kosma zworykin': {'n_is_sb': '0'},
 'vladimir lenin': {'n_is_sb': '0'},
 'vladimir nabokov': {'n_is_sb': '0'},
 'vladimir putin': {'n_is_sb': '0'},
 'vladimir vladimirovich mayakovski': {'n_is_sb': '0'},
 'vladimir vladimirovich nabokov': {'n_is_sb': '0'},
 'vladimir vladimirovich putin': {'n_is_sb': '0'},
 'vlaminck': {'n_is_sb': '0'},
 'vocaliser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'vocalizer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'vociferator': {'n_is_sb': '0'},
 'vogul': {'n_is_sb': '0'},
 'voicer': {'n_is_sb': '0'},
 'voider': {'n_is_sb': '2', 'n_is_sth': '2'},
 'volleyball player': {'n_is_sb': '0'},
 'voltaire': {'n_is_sb': '0'},
 'volta': {'n_is_sb': '0'},
 'volund': {'n_is_sb': '0'},
 'voluptuary': {'n_is_sb': '0'},
 'volvox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vomiter': {'n_is_sb': '0'},
 'von bismarck': {'n_is_sb': '0'},
 'von braun': {'n_is_sb': '0'},
 'von mauser': {'n_is_sb': '0'},
 'von neumann': {'n_is_sb': '0'},
 'von rundstedt': {'n_is_sb': '0'},
 'von sternberg': {'n_is_sb': '0'},
 'von willebrand': {'n_is_sb': '0'},
 'vonnegut': {'n_is_sb': '0'},
 'vorticella': {'n_is_sb': '3', 'n_is_sth': '3'},
 'votary': {'n_is_sb': '0'},
 'vote counter': {'n_is_sb': '0'},
 'votyak': {'n_is_sb': '0'},
 'vouchee': {'n_is_sb': '0'},
 'vower': {'n_is_sb': '0'},
 'voyager': {'n_is_sb': '0'},
 'voyeur': {'n_is_sb': '0'},
 'voznesenski': {'n_is_sb': '0'},
 'vuillard': {'n_is_sb': '0'},
 'vulcaniser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'vulcanizer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'vulgariser': {'n_is_sb': '0'},
 'vulgarizer': {'n_is_sb': '0'},
 'vulpes fulva': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vulpes macrotis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vulpes velox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vulpes vulpes': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vultur gryphus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'vultur': {'n_is_sb': '2', 'n_is_sth': '2'},
 'vyacheslav mikhailovich molotov': {'n_is_sb': '0'},
 'w. b. yeats': {'n_is_sb': '0'},
 'w. c. fields': {'n_is_sb': '0'},
 'w. c. handy': {'n_is_sb': '0'},
 'w. e. b. du bois': {'n_is_sb': '0'},
 'w. h. auden': {'n_is_sb': '0'},
 'w. h. hudson': {'n_is_sb': '0'},
 'w. k. kellogg': {'n_is_sb': '0'},
 'w. somerset maugham': {'n_is_sb': '0'},
 'w. v. quine': {'n_is_sb': '0'},
 'w. w. jacobs': {'n_is_sb': '0'},
 'wacko': {'n_is_sb': '0'},
 'wac': {'n_is_sb': '0'},
 'waddler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wader': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wading bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'waffler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wage earner': {'n_is_sb': '0'},
 'wagerer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'waggoner': {'n_is_sb': '2', 'n_is_sth': '2'},
 'waggonwright': {'n_is_sb': '0'},
 'wagner': {'n_is_sb': '0'},
 'wagonwright': {'n_is_sb': '0'},
 'wagtail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wahabi': {'n_is_sb': '0'},
 'wahhabi': {'n_is_sb': '0'},
 'wahoo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wahunsonacock': {'n_is_sb': '0'},
 'wahvey': {'n_is_sb': '0'},
 'wailer': {'n_is_sb': '0'},
 'wainwright': {'n_is_sb': '0'},
 'wain': {'n_is_sb': '2', 'n_is_sth': '2'},
 "waiter's assistant": {'n_is_sb': '0'},
 'wajda': {'n_is_sb': '0'},
 'wakashan': {'n_is_sb': '0'},
 'waker': {'n_is_sb': '0'},
 'walapai': {'n_is_sb': '0'},
 'waldheim': {'n_is_sb': '0'},
 'walesa': {'n_is_sb': '0'},
 'walk-in': {'n_is_sb': '2', 'n_is_sth': '2'},
 'walk-on': {'n_is_sb': '0'},
 'walker foxhound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'walker hound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'walker percy': {'n_is_sb': '0'},
 'walker smith': {'n_is_sb': '0'},
 'walker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'walking delegate': {'n_is_sb': '0'},
 'walking horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'walking leaf': {'n_is_sb': '3', 'n_is_sth': '3'},
 'walking stick': {'n_is_sb': '3', 'n_is_sth': '3'},
 'walkingstick': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wall creeper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wall-paperer': {'n_is_sb': '0'},
 'wallace carothers': {'n_is_sb': '0'},
 'wallace hume carothers': {'n_is_sb': '0'},
 'wallace stevens': {'n_is_sb': '0'},
 'wallace': {'n_is_sb': '0'},
 'wallah': {'n_is_sb': '0'},
 'wallenstein': {'n_is_sb': '0'},
 'waller': {'n_is_sb': '0'},
 'walleyed pike': {'n_is_sb': '3', 'n_is_sth': '3'},
 'walleye': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wallflower': {'n_is_sb': '0'},
 'wallis warfield simpson': {'n_is_sb': '0'},
 'wallis warfield windsor': {'n_is_sb': '0'},
 'walloon': {'n_is_sb': '0'},
 'walloper': {'n_is_sb': '0'},
 'wallpaperer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'walpole': {'n_is_sb': '0'},
 'walt disney': {'n_is_sb': '0'},
 'walt whitman': {'n_is_sb': '0'},
 'walter de la mare': {'n_is_sb': '0'},
 'walter elias disney': {'n_is_sb': '0'},
 'walter gropius': {'n_is_sb': '0'},
 'walter hess': {'n_is_sb': '0'},
 'walter john de la mare': {'n_is_sb': '0'},
 'walter lippmann': {'n_is_sb': '0'},
 'walter mitty': {'n_is_sb': '0'},
 'walter piston': {'n_is_sb': '0'},
 'walter ralegh': {'n_is_sb': '0'},
 'walter raleigh': {'n_is_sb': '0'},
 'walter reed': {'n_is_sb': '0'},
 'walter rudolf hess': {'n_is_sb': '0'},
 'walter scott': {'n_is_sb': '0'},
 'walter william skeat': {'n_is_sb': '0'},
 'walter': {'n_is_sb': '0'},
 'walther hermann nernst': {'n_is_sb': '0'},
 'walther richard rudolf hess': {'n_is_sb': '0'},
 'walton': {'n_is_sb': '0'},
 'waltzer': {'n_is_sb': '0'},
 'wampanoag': {'n_is_sb': '0'},
 'wanamaker': {'n_is_sb': '0'},
 'wanda landowska': {'n_is_sb': '0'},
 'wandering albatross': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wandering jew': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wangler': {'n_is_sb': '0'},
 'wanker': {'n_is_sb': '0'},
 'wannabee': {'n_is_sb': '0'},
 'wannabe': {'n_is_sb': '0'},
 'wanter': {'n_is_sb': '0'},
 'war admiral': {'n_is_sb': '0'},
 'war baby': {'n_is_sb': '0'},
 'war bride': {'n_is_sb': '0'},
 'war correspondent': {'n_is_sb': '0'},
 'war criminal': {'n_is_sb': '0'},
 'war god': {'n_is_sb': '0'},
 'war hawk': {'n_is_sb': '0'},
 'war widow': {'n_is_sb': '0'},
 'warble fly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'warburg': {'n_is_sb': '0'},
 'ward-heeler': {'n_is_sb': '0'},
 'warder': {'n_is_sb': '0'},
 'wardress': {'n_is_sb': '0'},
 'warehouser': {'n_is_sb': '0'},
 'warhol': {'n_is_sb': '0'},
 'warhorse': {'n_is_sb': '0'},
 'warner': {'n_is_sb': '2', 'n_is_sth': '2'},
 'warragal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'warrant officer': {'n_is_sb': '0'},
 'warrantee': {'n_is_sb': '0'},
 'warranter': {'n_is_sb': '0'},
 'warrantor': {'n_is_sb': '0'},
 'warren gamaliel harding': {'n_is_sb': '0'},
 'warren harding': {'n_is_sb': '0'},
 'warrener': {'n_is_sb': '0'},
 'warrigal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'warthog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'warwick': {'n_is_sb': '0'},
 'washerman': {'n_is_sb': '0'},
 'washerwoman': {'n_is_sb': '0'},
 'washington irving': {'n_is_sb': '0'},
 'washingtonian': {'n_is_sb': '0'},
 'washwoman': {'n_is_sb': '0'},
 'waslaw nijinsky': {'n_is_sb': '0'},
 'wassailer': {'n_is_sb': '0'},
 'wassermann': {'n_is_sb': '0'},
 'wassily kandinsky': {'n_is_sb': '0'},
 'wassily leontief': {'n_is_sb': '0'},
 'watchmaker': {'n_is_sb': '0'},
 'water beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'water bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'water boatman': {'n_is_sb': '3', 'n_is_sth': '3'},
 'water boy': {'n_is_sb': '0'},
 'water buffalo': {'n_is_sb': '3', 'n_is_sth': '3'},
 'water bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'water chevrotain': {'n_is_sb': '3', 'n_is_sth': '3'},
 'water deer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'water dog': {'n_is_sb': '2', 'n_is_sth': '2'},
 'water flea': {'n_is_sb': '3', 'n_is_sth': '3'},
 'water hen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'water moccasin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'water nymph': {'n_is_sb': '2', 'n_is_sth': '2'},
 'water ouzel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'water ox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'water rat': {'n_is_sb': '2', 'n_is_sth': '2'},
 'water scorpion': {'n_is_sb': '3', 'n_is_sth': '3'},
 'water shrew': {'n_is_sb': '3', 'n_is_sth': '3'},
 'water skater': {'n_is_sb': '3', 'n_is_sth': '3'},
 'water snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'water spaniel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'water sprite': {'n_is_sb': '0'},
 'water strider': {'n_is_sb': '3', 'n_is_sth': '3'},
 'water thrush': {'n_is_sb': '3', 'n_is_sth': '3'},
 'water turkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'water vole': {'n_is_sb': '3', 'n_is_sth': '3'},
 'water witch': {'n_is_sb': '2', 'n_is_sth': '2'},
 'waterbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'waterbuck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'watercolorist': {'n_is_sb': '0'},
 'watercolourist': {'n_is_sb': '0'},
 'waterdog': {'n_is_sb': '2', 'n_is_sth': '2'},
 'waterer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'watson': {'n_is_sb': '0'},
 'watteau': {'n_is_sb': '0'},
 'watusi': {'n_is_sb': '0'},
 'watutsi': {'n_is_sb': '0'},
 'waugh': {'n_is_sb': '0'},
 'wavell': {'n_is_sb': '0'},
 'waverer': {'n_is_sb': '0'},
 'wax insect': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wax moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wax-chandler': {'n_is_sb': '0'},
 'waxwing': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wayland the smith': {'n_is_sb': '0'},
 'wayland': {'n_is_sb': '0'},
 'wayne gretzky': {'n_is_sb': '0'},
 'wayne': {'n_is_sb': '0'},
 'weakfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wealthy man': {'n_is_sb': '0'},
 'wealthy person': {'n_is_sb': '0'},
 'wearer': {'n_is_sb': '0'},
 'weary willie': {'n_is_sb': '0'},
 'weather forecaster': {'n_is_sb': '0'},
 'weatherman': {'n_is_sb': '0'},
 'weaver finch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'weaverbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'weaver': {'n_is_sb': '0', 'nn_to_vb': 'weave', 'nn_to_jj': 'woven'},
 'web spinner': {'n_is_sb': '3', 'n_is_sth': '3'},
 'web-toed salamander': {'n_is_sb': '3', 'n_is_sth': '3'},
 'webbing clothes moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'webbing moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'webb': {'n_is_sb': '0'},
 'weber': {'n_is_sb': '0'},
 'webfoot': {'n_is_sb': '2', 'n_is_sth': '2'},
 'webster': {'n_is_sb': '0'},
 'webworm moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'webworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wedding guest': {'n_is_sb': '0'},
 'wedgwood': {'n_is_sb': '0'},
 'weeder': {'n_is_sb': '2', 'nn_to_vb': 'weed', 'nn_to_jj': 'weedless', 'n_is_sth': '2'},
 'weekend warrior': {'n_is_sb': '0'},
 'weekender': {'n_is_sb': '0'},
 'weeper': {'n_is_sb': '0'},
 'wegener': {'n_is_sb': '0'},
 'weight gainer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'weightlifter': {'n_is_sb': '0'},
 'weill': {'n_is_sb': '0'},
 'weil': {'n_is_sb': '0'},
 'weimaraner': {'n_is_sb': '3', 'n_is_sth': '3'},
 'weinberg': {'n_is_sb': '0'},
 'weird sisters': {'n_is_sb': '0'},
 'weirdie': {'n_is_sb': '2', 'n_is_sth': '2'},
 'weirdy': {'n_is_sb': '0'},
 'weisenheimer': {'n_is_sb': '0'},
 'weismann': {'n_is_sb': '0'},
 'weizmann': {'n_is_sb': '0'},
 'weka': {'n_is_sb': '3', 'n_is_sth': '3'},
 'welcher': {'n_is_sb': '0'},
 'welcomer': {'n_is_sb': '0'},
 'welfare worker': {'n_is_sb': '0'},
 'well-wisher': {'n_is_sb': '0'},
 'welles': {'n_is_sb': '0'},
 'welsh black': {'n_is_sb': '3', 'n_is_sth': '3'},
 'welsh corgi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'welsh pony': {'n_is_sb': '3', 'n_is_sth': '3'},
 'welsh springer spaniel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'welsh terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'welsher': {'n_is_sb': '0'},
 'welterweight': {'n_is_sb': '0'},
 'welty': {'n_is_sb': '0'},
 "wen ch'ang": {'n_is_sb': '0'},
 'wen-ti': {'n_is_sb': '0'},
 'wencher': {'n_is_sb': '0'},
 'werfel': {'n_is_sb': '0'},
 'werner karl heisenberg': {'n_is_sb': '0'},
 'wernher magnus maximilian von braun': {'n_is_sb': '0'},
 'wernher von braun': {'n_is_sb': '0'},
 'wernicke': {'n_is_sb': '0'},
 'wesleyan': {'n_is_sb': '0'},
 'wesley': {'n_is_sb': '0'},
 'west berliner': {'n_is_sb': '0'},
 'west highland white terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'west indian': {'n_is_sb': '0'},
 'west nile encephalitis virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'west nile virus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'west saxon': {'n_is_sb': '0'},
 'west virginian': {'n_is_sb': '0'},
 'west-sider': {'n_is_sb': '0'},
 'western big-eared bat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western black-legged tick': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western blind snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western box turtle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western chimpanzee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western coral snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western diamondback rattlesnake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western diamondback': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western fence lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western gray squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western kingbird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western lowland gorilla': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western meadowlark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western narrow-mouthed toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western pipistrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western rattlesnake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western red-backed salamander': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western ribbon snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western skink': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western spadefoot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western tanager': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western whiptail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'western wood pewee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'westerner': {'n_is_sb': '0'},
 'westinghouse': {'n_is_sb': '0'},
 'weston': {'n_is_sb': '0'},
 'wet blanket': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wet nurse': {'n_is_sb': '0'},
 'wet-nurse': {'n_is_sb': '0'},
 'wetback': {'n_is_sb': '0'},
 'wetnurse': {'n_is_sb': '0'},
 'wetter': {'n_is_sb': '2', 'n_is_sth': '2'},
 'whale louse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whale shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whale sucker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whalebone whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whaler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'whalesucker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wharf rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wharton': {'n_is_sb': '0'},
 'wheat eelworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wheat eel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wheatear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wheatley': {'n_is_sb': '0'},
 'wheatstone': {'n_is_sb': '0'},
 'wheatworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wheedler': {'n_is_sb': '0'},
 'wheel bug': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wheel horse': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wheeler dealer': {'n_is_sb': '0'},
 'wheeler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wheelwright': {'n_is_sb': '0'},
 'whelp': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whidah': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whiffer': {'n_is_sb': '0'},
 'whig': {'n_is_sb': '0', 'cap_word': 'Whig'},
 'whinchat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whiner': {'n_is_sb': '0'},
 'whip scorpion': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whip snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whip-scorpion': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whip-snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whipper-in': {'n_is_sb': '0'},
 'whippersnapper': {'n_is_sb': '0'},
 'whipper': {'n_is_sb': '2', 'nn_to_vb': 'whip', 'nn_to_jj': 'whipped', 'n_is_sth': '2'},
 'whippet': {'n_is_sb': '2', 'n_is_sth': '2'},
 'whipping boy': {'n_is_sb': '0'},
 'whiptail lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whiptail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whirler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'whirligig beetle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whirling dervish': {'n_is_sb': '0'},
 'whisker jack': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whisperer': {'n_is_sb': '0'},
 'whistle blower': {'n_is_sb': '0'},
 'whistle-blower': {'n_is_sb': '0'},
 'whistleblower': {'n_is_sb': '0'},
 'whistler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'whistling marmot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whistling swan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white admiral': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white anglo-saxon protestant': {'n_is_sb': '0'},
 'white ant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white crappie': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white croaker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white elephant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white fox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white friar': {'n_is_sb': '0'},
 'white hope': {'n_is_sb': '0'},
 'white man': {'n_is_sb': '0'},
 'white marlin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white mullet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white pelican': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white people': {'n_is_sb': '0'},
 'white perch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white person': {'n_is_sb': '0'},
 'white race': {'n_is_sb': '0'},
 'white rhinoceros': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white russian': {'n_is_sb': '0'},
 'white separatist': {'n_is_sb': '0'},
 'white shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white sheep': {'n_is_sb': '2', 'n_is_sth': '2'},
 'white slaver': {'n_is_sb': '0'},
 'white slave': {'n_is_sb': '0'},
 'white stork': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white sturgeon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white supremacist': {'n_is_sb': '0'},
 'white trash': {'n_is_sb': '0'},
 'white whale': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white wolf': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white woman': {'n_is_sb': '0'},
 'white-bellied swallow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white-breasted nuthatch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white-chinned petrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white-crowned sparrow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white-faced hornet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white-footed mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white-headed stilt': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white-lipped peccary': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white-rumped shrike': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white-tailed deer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white-tailed jackrabbit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white-tailed kite': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white-tailed sea eagle': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white-throated sparrow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'white-tipped shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whitebait': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whited sepulcher': {'n_is_sb': '0'},
 'whited sepulchre': {'n_is_sb': '0'},
 'whiteface': {'n_is_sb': '2', 'n_is_sth': '2'},
 'whitefly': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whitehead': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whitetail antelope squirrel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whitetail deer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whitetail jackrabbit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whitetail prairie dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whitetail': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whitethroat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whitetip shark': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whitey': {'n_is_sb': '0'},
 'whitman': {'n_is_sb': '0'},
 'whitney moore young jr.': {'n_is_sb': '0'},
 'whitney young': {'n_is_sb': '0'},
 'whitney': {'n_is_sb': '0'},
 'whittier': {'n_is_sb': '0'},
 'whittler': {'n_is_sb': '0'},
 'whiz-kid': {'n_is_sb': '0'},
 'whizz-kid': {'n_is_sb': '0'},
 'whizz': {'n_is_sb': '2', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'n_is_sth': '2'},
 'whole snipe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whooper swan': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whooper': {'n_is_sb': '2', 'n_is_sth': '2'},
 'whooping crane': {'n_is_sb': '3', 'n_is_sth': '3'},
 'whoremaster': {'n_is_sb': '0'},
 'whoremonger': {'n_is_sb': '0'},
 'whoreson': {'n_is_sb': '0'},
 'whydah': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wichita': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wicket-keeper': {'n_is_sb': '0'},
 'wickliffe': {'n_is_sb': '0'},
 'wiclif': {'n_is_sb': '0'},
 'widgeon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'widow bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'widow woman': {'n_is_sb': '0'},
 'widowman': {'n_is_sb': '0'},
 'wieland': {'n_is_sb': '0'},
 'wiener': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wiesel': {'n_is_sb': '0'},
 'wiesenthal': {'n_is_sb': '0'},
 'wigeon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wiggler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wigmaker': {'n_is_sb': '0'},
 'wigner': {'n_is_sb': '0'},
 'wilbur wright': {'n_is_sb': '0'},
 'wild ass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wild bill hickock': {'n_is_sb': '0'},
 'wild boar': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wild cavy': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wild dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wild duck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wild goat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wild horse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wild man': {'n_is_sb': '0'},
 'wild ox': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wild sheep': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wild wilkworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wildcatter': {'n_is_sb': '0'},
 'wilder': {'n_is_sb': '0'},
 'wilde': {'n_is_sb': '0'},
 'wiley post': {'n_is_sb': '0'},
 'wilhelm apollinaris de kostrowitzki': {'n_is_sb': '0'},
 'wilhelm eduard weber': {'n_is_sb': '0'},
 'wilhelm grimm': {'n_is_sb': '0'},
 'wilhelm ii': {'n_is_sb': '0'},
 'wilhelm karl grimm': {'n_is_sb': '0'},
 'wilhelm konrad roentgen': {'n_is_sb': '0'},
 'wilhelm konrad rontgen': {'n_is_sb': '0'},
 'wilhelm ostwald': {'n_is_sb': '0'},
 'wilhelm reich': {'n_is_sb': '0'},
 'wilhelm richard wagner': {'n_is_sb': '0'},
 'wilhelm von opel': {'n_is_sb': '0'},
 'wilkes': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wilkie collins': {'n_is_sb': '0'},
 'wilkins micawber': {'n_is_sb': '0'},
 'wilkinson': {'n_is_sb': '0'},
 'wilkins': {'n_is_sb': '0'},
 'will durant': {'n_is_sb': '0'},
 'will hays': {'n_is_sb': '0'},
 'will keith kellog': {'n_is_sb': '0'},
 'will rogers': {'n_is_sb': '0'},
 'willa cather': {'n_is_sb': '0'},
 'willa sibert cather': {'n_is_sb': '0'},
 'willard frank libby': {'n_is_sb': '0'},
 'willard huntington wright': {'n_is_sb': '0'},
 'willard van orman quine': {'n_is_sb': '0'},
 'willard': {'n_is_sb': '0'},
 'willebrand': {'n_is_sb': '0'},
 'willem de kooning': {'n_is_sb': '0'},
 'willem de sitter': {'n_is_sb': '0'},
 'willem einthoven': {'n_is_sb': '0'},
 'willet': {'n_is_sb': '2', 'n_is_sth': '2'},
 'william a. craigie': {'n_is_sb': '0'},
 'william augustus': {'n_is_sb': '0'},
 'william averell harriman': {'n_is_sb': '0'},
 'william beaumont': {'n_is_sb': '0'},
 'william benjamin hogan': {'n_is_sb': '0'},
 'william blake': {'n_is_sb': '0'},
 'william bligh': {'n_is_sb': '0'},
 'william bradford shockley': {'n_is_sb': '0'},
 'william bradford': {'n_is_sb': '0'},
 'william burroughs': {'n_is_sb': '0'},
 'william butler yeats': {'n_is_sb': '0'},
 'william butterfield': {'n_is_sb': '0'},
 'william byrd': {'n_is_sb': '0'},
 'william carlos williams': {'n_is_sb': '0'},
 'william caxton': {'n_is_sb': '0'},
 'william chambers': {'n_is_sb': '0'},
 'william christopher handy': {'n_is_sb': '0'},
 'william claire menninger': {'n_is_sb': '0'},
 'william clark gable': {'n_is_sb': '0'},
 'william clark': {'n_is_sb': '0'},
 'william claude dukenfield': {'n_is_sb': '0'},
 'william cowper': {'n_is_sb': '0'},
 'william crawford gorgas': {'n_is_sb': '0'},
 'william crookes': {'n_is_sb': '0'},
 'william curtis': {'n_is_sb': '0'},
 'william cuthbert faulkner': {'n_is_sb': '0'},
 'william dawes': {'n_is_sb': '0'},
 'william dean howells': {'n_is_sb': '0'},
 'william dudley haywood': {'n_is_sb': '0'},
 'william edward burghardt du bois': {'n_is_sb': '0'},
 'william ewart gladstone': {'n_is_sb': '0'},
 'william f. cody': {'n_is_sb': '0'},
 'william falkner': {'n_is_sb': '0'},
 'william faulkner': {'n_is_sb': '0'},
 'william felton russell': {'n_is_sb': '0'},
 'william franklin graham': {'n_is_sb': '0'},
 'william frederick cody': {'n_is_sb': '0'},
 'william fulbright': {'n_is_sb': '0'},
 'william gilbert': {'n_is_sb': '0'},
 'william gladstone': {'n_is_sb': '0'},
 'william golding': {'n_is_sb': '0'},
 'william graham sumner': {'n_is_sb': '0'},
 'william green': {'n_is_sb': '0'},
 'william h. bonney': {'n_is_sb': '0'},
 'william harrison dempsey': {'n_is_sb': '0'},
 'william harrison hays': {'n_is_sb': '0'},
 'william harvey': {'n_is_sb': '0'},
 'william hazlitt': {'n_is_sb': '0'},
 'william henry beveridge': {'n_is_sb': '0'},
 'william henry fox talbot': {'n_is_sb': '0'},
 'william henry gates': {'n_is_sb': '0'},
 'william henry harrison': {'n_is_sb': '0'},
 'william henry hoover': {'n_is_sb': '0'},
 'william henry hudson': {'n_is_sb': '0'},
 'william henry mauldin': {'n_is_sb': '0'},
 'william henry pratt': {'n_is_sb': '0'},
 'william henry seward': {'n_is_sb': '0'},
 'william henry': {'n_is_sb': '0'},
 'william herschel': {'n_is_sb': '0'},
 'william hogarth': {'n_is_sb': '0'},
 'william holman hunt': {'n_is_sb': '0'},
 'william holmes mcguffey': {'n_is_sb': '0'},
 'william hoover': {'n_is_sb': '0'},
 'william howard taft': {'n_is_sb': '0'},
 'william hubbs rehnquist': {'n_is_sb': '0'},
 'william hyde wollaston': {'n_is_sb': '0'},
 'william iii': {'n_is_sb': '0'},
 'william ii': {'n_is_sb': '0'},
 'william inge': {'n_is_sb': '0'},
 'william iv': {'n_is_sb': '0'},
 'william i': {'n_is_sb': '0'},
 'william james durant': {'n_is_sb': '0'},
 'william james': {'n_is_sb': '0'},
 'william jefferson clinton': {'n_is_sb': '0'},
 'william jennings bryan': {'n_is_sb': '0'},
 'william john clifton haley jr.': {'n_is_sb': '0'},
 'william kidd': {'n_is_sb': '0'},
 'william lawrence shirer': {'n_is_sb': '0'},
 'william le baron jenny': {'n_is_sb': '0'},
 'william lloyd garrison': {'n_is_sb': '0'},
 'william makepeace thackeray': {'n_is_sb': '0'},
 'william maxwell aitken': {'n_is_sb': '0'},
 'william mckinley': {'n_is_sb': '0'},
 'william menninger': {'n_is_sb': '0'},
 'william mitchell': {'n_is_sb': '0'},
 'william morris': {'n_is_sb': '0'},
 'william nunn lipscom jr.': {'n_is_sb': '0'},
 'william of occam': {'n_is_sb': '0'},
 'william of ockham': {'n_is_sb': '0'},
 'william of orange': {'n_is_sb': '0'},
 'william of wykeham': {'n_is_sb': '0'},
 'william patterson': {'n_is_sb': '0'},
 'william penn adair rogers': {'n_is_sb': '0'},
 'william penn': {'n_is_sb': '0'},
 'william pitt': {'n_is_sb': '0'},
 'william ralph inge': {'n_is_sb': '0'},
 'william randolph hearst': {'n_is_sb': '0'},
 'william rehnquist': {'n_is_sb': '0'},
 'william richard morris': {'n_is_sb': '0'},
 'william rose benet': {'n_is_sb': '0'},
 'william rowan hamilton': {'n_is_sb': '0'},
 'william rufus': {'n_is_sb': '0'},
 'william s. burroughs': {'n_is_sb': '0'},
 'william s. gilbert': {'n_is_sb': '0'},
 'william saroyan': {'n_is_sb': '0'},
 'william schwenk gilbert': {'n_is_sb': '0'},
 'william seward burroughs': {'n_is_sb': '0'},
 'william shakespeare': {'n_is_sb': '0'},
 'william shakspere': {'n_is_sb': '0'},
 'william shockley': {'n_is_sb': '0'},
 'william somerset maugham': {'n_is_sb': '0'},
 'william stanley jevons': {'n_is_sb': '0'},
 'william strickland': {'n_is_sb': '0'},
 'william stubbs': {'n_is_sb': '0'},
 'william styron': {'n_is_sb': '0'},
 'william sydney porter': {'n_is_sb': '0'},
 'william tatem tilden jr.': {'n_is_sb': '0'},
 'william tecumseh sherman': {'n_is_sb': '0'},
 'william tell': {'n_is_sb': '0'},
 'william the conqueror': {'n_is_sb': '0'},
 'william thompson': {'n_is_sb': '0'},
 'william thornton': {'n_is_sb': '0'},
 'william tindale': {'n_is_sb': '0'},
 'william tindal': {'n_is_sb': '0'},
 'william tyndale': {'n_is_sb': '0'},
 'william wilkie collins': {'n_is_sb': '0'},
 'william wordsworth': {'n_is_sb': '0'},
 'william wycherley': {'n_is_sb': '0'},
 'william wyler': {'n_is_sb': '0'},
 'william wymark jacobs': {'n_is_sb': '0'},
 'williams': {'n_is_sb': '0'},
 'willie howard mays jr.': {'n_is_sb': '0'},
 'willie mays': {'n_is_sb': '0'},
 'willy brandt': {'n_is_sb': '0'},
 'wilmut': {'n_is_sb': '0'},
 "wilson's blackcap": {'n_is_sb': '3', 'n_is_sth': '3'},
 "wilson's phalarope": {'n_is_sb': '3', 'n_is_sth': '3'},
 "wilson's snipe": {'n_is_sb': '3', 'n_is_sth': '3'},
 "wilson's thrush": {'n_is_sb': '3', 'n_is_sth': '3'},
 "wilson's warbler": {'n_is_sb': '3', 'n_is_sth': '3'},
 'wilsonia pusilla': {'n_is_sb': '0'},
 'wilson': {'n_is_sb': '0'},
 'winckelmann': {'n_is_sb': '0'},
 'windaus': {'n_is_sb': '0'},
 'window cleaner': {'n_is_sb': '2', 'n_is_sth': '2'},
 'window dresser': {'n_is_sb': '0'},
 'window oyster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'window trimmer': {'n_is_sb': '0'},
 'window washer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'windowpane oyster': {'n_is_sb': '3', 'n_is_sth': '3'},
 'windtalker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wine lover': {'n_is_sb': '0'},
 'wine maker': {'n_is_sb': '0'},
 'wine merchant': {'n_is_sb': '0'},
 'wine steward': {'n_is_sb': '0'},
 'wine taster': {'n_is_sb': '0'},
 'wine waiter': {'n_is_sb': '0'},
 'winemaker': {'n_is_sb': '0'},
 'winfield scott': {'n_is_sb': '0'},
 'winfred': {'n_is_sb': '0'},
 'wing commander': {'n_is_sb': '0'},
 'wingback': {'n_is_sb': '0'},
 'winger': {'n_is_sb': '0'},
 'winker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'winkle': {'n_is_sb': '3', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'n_is_sth': '3'},
 'winnebago': {'n_is_sb': '0'},
 'winslow homer': {'n_is_sb': '0'},
 'winslow': {'n_is_sb': '0'},
 'winston churchill': {'n_is_sb': '0'},
 'winston s. churchill': {'n_is_sb': '0'},
 'winter flounder': {'n_is_sb': '3', 'n_is_sth': '3'},
 'winter wren': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wintun': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wire-haired fox terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wire-haired pointing griffon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wire-haired terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wire-puller': {'n_is_sb': '0'},
 'wirehaired terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wirehair': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wireman': {'n_is_sb': '0'},
 'wirer': {'n_is_sb': '0'},
 'wiretapper': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wireworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wisconsinite': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wise guy': {'n_is_sb': '0'},
 'wise man': {'n_is_sb': '0'},
 'wiseacre': {'n_is_sb': '0'},
 'wisenheimer': {'n_is_sb': '0'},
 'wisent': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wishful thinker': {'n_is_sb': '0'},
 'wister': {'n_is_sb': '0'},
 'witch doctor': {'n_is_sb': '0'},
 'witch-hunter': {'n_is_sb': '0'},
 'withdrawer': {'n_is_sb': '0'},
 'witherspoon': {'n_is_sb': '0'},
 'withholder': {'n_is_sb': '2', 'n_is_sth': '2'},
 'withstander': {'n_is_sb': '0'},
 'witnesser': {'n_is_sb': '2', 'n_is_sth': '2'},
 'witold gombrowicz': {'n_is_sb': '0'},
 'wittgenstein': {'n_is_sb': '0'},
 'wivern': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wobbly': {'n_is_sb': '0'},
 'wodan': {'n_is_sb': '0'},
 'wodehouse': {'n_is_sb': '0'},
 'woden': {'n_is_sb': '0'},
 'wog': {'n_is_sb': '0'},
 'wolf boy': {'n_is_sb': '0'},
 'wolf cub': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wolf fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wolf pup': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wolf spider': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wolfe': {'n_is_sb': '0'},
 'wolffish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wolff': {'n_is_sb': '0'},
 'wolfgang amadeus mozart': {'n_is_sb': '0'},
 'wolfgang pauli': {'n_is_sb': '0'},
 'wolfhound': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wolfman': {'n_is_sb': '0'},
 'wollaston': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wollstonecraft': {'n_is_sb': '0'},
 'woman chaser': {'n_is_sb': '0'},
 'woman hater': {'n_is_sb': '0'},
 'woman of the house': {'n_is_sb': '0'},
 'woman of the street': {'n_is_sb': '0'},
 "woman's doctor": {'n_is_sb': '0'},
 'womaniser': {'n_is_sb': '0'},
 'womanizer': {'n_is_sb': '0'},
 'wombat': {'n_is_sb': '3', 'n_is_sth': '3'},
 "women's liberationist": {'n_is_sb': '0'},
 "women's rightist": {'n_is_sb': '0'},
 'wonder boy': {'n_is_sb': '0'},
 'wonder child': {'n_is_sb': '0'},
 'wonder woman': {'n_is_sb': '0'},
 'wonderer': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wood ant': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wood drake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wood duck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wood frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wood hen': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wood hoopoe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wood ibis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wood mouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wood nymph': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wood pewee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wood pigeon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wood pussy': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wood rabbit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wood rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wood stork': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wood swallow': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wood thrush': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wood tick': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wood warbler': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wood widgeon': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wood-creeper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wood-frog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wood-rat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'woodborer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'woodbury': {'n_is_sb': '2', 'n_is_sth': '2'},
 'woodcarver': {'n_is_sb': '0'},
 'woodcock snipe': {'n_is_sb': '3', 'n_is_sth': '3'},
 'woodcreeper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'woodhewer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'woodhull': {'n_is_sb': '0'},
 'woodland caribou': {'n_is_sb': '3', 'n_is_sth': '3'},
 'woodlouse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'woodrow charles herman': {'n_is_sb': '0'},
 'woodrow wilson guthrie': {'n_is_sb': '0'},
 'woodrow wilson': {'n_is_sb': '0'},
 'woodsman': {'n_is_sb': '0'},
 'woodward': {'n_is_sb': '0'},
 'woodworm': {'n_is_sb': '3', 'n_is_sth': '3'},
 'woody allen': {'n_is_sb': '0'},
 'woody guthrie': {'n_is_sb': '0'},
 'woody herman': {'n_is_sb': '0'},
 'wooer': {'n_is_sb': '0'},
 'wool stapler': {'n_is_sb': '0'},
 'woolf': {'n_is_sb': '0'},
 'woolgatherer': {'n_is_sb': '0'},
 'woollcott': {'n_is_sb': '0'},
 'woolley': {'n_is_sb': '2', 'n_is_sth': '2'},
 'woolly adelgid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'woolly alder aphid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'woolly aphid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'woolly apple aphid': {'n_is_sb': '3', 'n_is_sth': '3'},
 'woolly bear caterpillar': {'n_is_sb': '3', 'n_is_sth': '3'},
 'woolly bear moth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'woolly bear': {'n_is_sb': '3', 'n_is_sth': '3'},
 'woolly indris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'woolly mammoth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'woolly monkey': {'n_is_sb': '3', 'n_is_sth': '3'},
 'woolly plant louse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'woolly rhinoceros': {'n_is_sb': '3', 'n_is_sth': '3'},
 'woolsorter': {'n_is_sb': '0'},
 'woolworth': {'n_is_sb': '0'},
 'wop': {'n_is_sb': '0'},
 'worcester': {'n_is_sb': '2', 'n_is_sth': '2'},
 'word-painter': {'n_is_sb': '0'},
 'wordmonger': {'n_is_sb': '0'},
 'wordsmith': {'n_is_sb': '0'},
 'wordsworth': {'n_is_sb': '0'},
 'work animal': {'n_is_sb': '3', 'n_is_sth': '3'},
 'worker bee': {'n_is_sb': '3', 'n_is_sth': '3'},
 'workfellow': {'n_is_sb': '0'},
 'working dog': {'n_is_sb': '3', 'n_is_sth': '3'},
 'working girl': {'n_is_sb': '0'},
 'working man': {'n_is_sb': '0'},
 'working person': {'n_is_sb': '0'},
 'world traveler': {'n_is_sb': '0'},
 'world-beater': {'n_is_sb': '0'},
 'worm fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'worm lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'worm salamander': {'n_is_sb': '3', 'n_is_sth': '3'},
 'worm snake': {'n_is_sb': '3', 'n_is_sth': '3'},
 'worrier': {'n_is_sb': '2', 'n_is_sth': '2'},
 'worrywart': {'n_is_sb': '0'},
 'worshiper': {'n_is_sb': '0'},
 'worshipper': {'n_is_sb': '0', 'nn_to_vb': 'worship', 'nn_to_jj': 'worshipful', 'nn_to_rb': 'worshipfully'},
 'wotan': {'n_is_sb': '0'},
 'wouk': {'n_is_sb': '0'},
 'wound tumor virus': {'n_is_sb': '0'},
 'wrangler': {'n_is_sb': '0'},
 'wrasse': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wrecker': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wreckfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wren warbler': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wren-tit': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wrester': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wrestler': {'n_is_sb': '0'},
 'wriggler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'write-in candidate': {'n_is_sb': '0'},
 'write-in': {'n_is_sb': '0'},
 'wrymouth': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wryneck': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wtv': {'n_is_sb': '3', 'n_is_sth': '3'},
 'wulfila': {'n_is_sb': '0'},
 'wurlitzer': {'n_is_sb': '0'},
 'wuss': {'n_is_sb': '0'},
 'wyatt': {'n_is_sb': '0'},
 'wyat': {'n_is_sb': '0'},
 'wycherley': {'n_is_sb': '0'},
 'wycliffe': {'n_is_sb': '0'},
 'wyclif': {'n_is_sb': '0'},
 'wyeth': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wykehamist': {'n_is_sb': '0'},
 'wykeham': {'n_is_sb': '0'},
 'wyler': {'n_is_sb': '2', 'n_is_sth': '2'},
 'wylie': {'n_is_sb': '0'},
 'wynette': {'n_is_sb': '0'},
 'wynfrith': {'n_is_sb': '0'},
 'wyomingite': {'n_is_sb': '0'},
 'wyrd': {'n_is_sb': '0'},
 'wystan hugh auden': {'n_is_sb': '0'},
 'wyszynski': {'n_is_sb': '0'},
 'wyvern': {'n_is_sb': '3', 'n_is_sth': '3'},
 'xanthomonad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'xavier': {'n_is_sb': '0'},
 'xenarthra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'xenicus gilviventris': {'n_is_sb': '3', 'n_is_sth': '3'},
 'xenophanes': {'n_is_sb': '0'},
 'xenophon': {'n_is_sb': '0'},
 'xenopus laevis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'xenopus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'xenorhyncus asiaticus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'xenorhyncus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'xenosauridae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'xerobates': {'n_is_sb': '3', 'n_is_sth': '3'},
 'xerxes i': {'n_is_sb': '0'},
 'xerxes the great': {'n_is_sb': '0'},
 'xestobium rufovillosum': {'n_is_sb': '3', 'n_is_sth': '3'},
 'xiphias gladius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'xiphosurus polyphemus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'xylocopa': {'n_is_sb': '3', 'n_is_sth': '3'},
 'xylophonist': {'n_is_sb': '0'},
 'xyphophorus helleri': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yachtsman': {'n_is_sb': '0'},
 'yachtswoman': {'n_is_sb': '0'},
 'yahi': {'n_is_sb': '2', 'n_is_sth': '2'},
 'yahoo': {'n_is_sb': '2', 'n_is_sth': '2'},
 'yahveh': {'n_is_sb': '0'},
 'yahve': {'n_is_sb': '0'},
 'yahweh': {'n_is_sb': '0'},
 'yahwe': {'n_is_sb': '0'},
 'yakut': {'n_is_sb': '2', 'n_is_sth': '2'},
 'yakuza': {'n_is_sb': '0'},
 'yale': {'n_is_sb': '2', 'n_is_sth': '2'},
 'yamamoto': {'n_is_sb': '0'},
 'yamani': {'n_is_sb': '0'},
 'yana': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yang chen ning': {'n_is_sb': '0'},
 'yankee-doodle': {'n_is_sb': '0'},
 'yankee': {'n_is_sb': '0'},
 'yanker': {'n_is_sb': '0'},
 'yank': {'n_is_sb': '2', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'n_is_sth': '2'},
 'yardbird parker': {'n_is_sb': '0'},
 'yardie': {'n_is_sb': '0'},
 'yardman': {'n_is_sb': '0'},
 'yardmaster': {'n_is_sb': '0'},
 'yasser arafat': {'n_is_sb': '0'},
 'yastrzemski': {'n_is_sb': '0'},
 'yavapai': {'n_is_sb': '0'},
 'yawner': {'n_is_sb': '2', 'n_is_sth': '2'},
 'yearner': {'n_is_sb': '0'},
 'yeats': {'n_is_sb': '0'},
 'yehudi menuhin': {'n_is_sb': '0'},
 'yeller': {'n_is_sb': '0'},
 'yellow bass': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellow bunting': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellow goatfish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellow gurnard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellow hornet': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellow jacket': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellow jack': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellow man': {'n_is_sb': '0'},
 'yellow perch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellow race': {'n_is_sb': '0'},
 'yellow warbler': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellow woman': {'n_is_sb': '0'},
 'yellow-bellied sapsucker': {'n_is_sb': '0'},
 'yellow-bellied terrapin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellow-breasted bunting': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellow-breasted chat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellow-crowned night heron': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellow-fever mosquito': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellow-green algae': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellow-shafted flicker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellow-throated marten': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellowbelly marmot': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellowfin croaker': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellowfin mojarra': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellowfin tuna': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellowfin': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellowhammer': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellowlegs': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellowtail flounder': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellowtail snapper': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yellowtail': {'n_is_sb': '2', 'n_is_sth': '2'},
 'yellowthroat': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yemeni': {'n_is_sb': '0'},
 'yeniseian': {'n_is_sb': '0'},
 'yeoman of the guard': {'n_is_sb': '0'},
 'yerkes': {'n_is_sb': '0'},
 'yersinia pestis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yersin': {'n_is_sb': '0'},
 'yevgeni aleksandrovich yevtushenko': {'n_is_sb': '0'},
 'yevgeni yevtushenko': {'n_is_sb': '0'},
 'yevtushenko': {'n_is_sb': '0'},
 'ygdrasil': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yggdrasil': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yhvh': {'n_is_sb': '0'},
 'yhwh': {'n_is_sb': '0'},
 'yielder': {'n_is_sb': '0'},
 'ymir': {'n_is_sb': '0'},
 'yobbo': {'n_is_sb': '0'},
 'yobo': {'n_is_sb': '0'},
 'yob': {'n_is_sb': '0'},
 'yodeller': {'n_is_sb': '0'},
 'yogi berra': {'n_is_sb': '0'},
 'yogi': {'n_is_sb': '0'},
 'yoko ono': {'n_is_sb': '0'},
 'yokuts': {'n_is_sb': '0'},
 'yorkshire terrier': {'n_is_sb': '3', 'n_is_sth': '3'},
 'yoruba': {'n_is_sb': '0'},
 'yosemite toad': {'n_is_sb': '3', 'n_is_sth': '3'},
 'young bird': {'n_is_sb': '3', 'n_is_sth': '3'},
 'young buck': {'n_is_sb': '2', 'n_is_sth': '2'},
 'young carnivore': {'n_is_sb': '3', 'n_is_sth': '3'},
 'young fish': {'n_is_sb': '3', 'n_is_sth': '3'},
 'young girl': {'n_is_sb': '0'},
 'young lady': {'n_is_sb': '0'},
 'young mammal': {'n_is_sb': '0'},
 'young man': {'n_is_sb': '0'},
 'young person': {'n_is_sb': '0'},
 'young turk': {'n_is_sb': '0'},
 'young woman': {'n_is_sb': '0'},
 'younker': {'n_is_sb': '0'},
 'yucateco': {'n_is_sb': '0'},
 'yucatec': {'n_is_sb': '0'},
 'yugoslavian': {'n_is_sb': '0'},
 'yugoslav': {'n_is_sb': '0'},
 'yukawa': {'n_is_sb': '0'},
 'yuma': {'n_is_sb': '0'},
 'yuri alekseyevich gagarin': {'n_is_sb': '0'},
 'yuri gagarin': {'n_is_sb': '0'},
 'yves tanguy': {'n_is_sb': '0'},
 'zacharias': {'n_is_sb': '0'},
 'zachary taylor': {'n_is_sb': '0'},
 'zaharias': {'n_is_sb': '0'},
 'zairean': {'n_is_sb': '0'},
 'zairese': {'n_is_sb': '0'},
 'zalophus californianus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'zalophus californicus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'zalophus lobatus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'zalophus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'zambian': {'n_is_sb': '0'},
 'zane grey': {'n_is_sb': '0'},
 'zangwill': {'n_is_sb': '0'},
 'zanuck': {'n_is_sb': '0'},
 'zapata': {'n_is_sb': '0'},
 'zapotecan': {'n_is_sb': '0'},
 'zapotec': {'n_is_sb': '0'},
 'zapus hudsonius': {'n_is_sb': '3', 'n_is_sth': '3'},
 'zarathustra': {'n_is_sb': '0'},
 'zarpanit': {'n_is_sb': '0'},
 'zealander': {'n_is_sb': '2', 'n_is_sth': '2'},
 'zealot': {'n_is_sb': '0'},
 'zebra finch': {'n_is_sb': '3', 'n_is_sth': '3'},
 'zebra mussel': {'n_is_sb': '3', 'n_is_sth': '3'},
 'zebra-tailed lizard': {'n_is_sb': '3', 'n_is_sth': '3'},
 'zebu': {'n_is_sb': '3', 'n_is_sth': '3'},
 'zechariah': {'n_is_sb': '0'},
 'zeeman': {'n_is_sb': '0'},
 'zen buddhist': {'n_is_sb': '0'},
 'zenaidura macroura': {'n_is_sb': '3', 'n_is_sth': '3'},
 'zeno of citium': {'n_is_sb': '0'},
 'zeno of elea': {'n_is_sb': '0'},
 'zeno': {'n_is_sb': '0'},
 'zeomorphi': {'n_is_sb': '3', 'n_is_sth': '3'},
 'zephaniah': {'n_is_sb': '2', 'n_is_sth': '2'},
 'zeppelin': {'n_is_sb': '2', 'n_is_sth': '2'},
 'zeppo': {'n_is_sb': '0'},
 'zeus faber': {'n_is_sb': '2', 'n_is_sth': '2'},
 'zhou en-lai': {'n_is_sb': '0'},
 'zhukov': {'n_is_sb': '0'},
 'ziegfeld': {'n_is_sb': '0'},
 'ziegler': {'n_is_sb': '0'},
 'zimbabwean': {'n_is_sb': '0'},
 'zimbalist': {'n_is_sb': '0'},
 'zinjanthropus': {'n_is_sb': '0'},
 'zinnemann': {'n_is_sb': '0'},
 'zinsser': {'n_is_sb': '0'},
 'zinzendorf': {'n_is_sb': '0'},
 'zionist': {'n_is_sb': '0'},
 'zirbanit': {'n_is_sb': '0'},
 'zoarces viviparus': {'n_is_sb': '3', 'n_is_sth': '3'},
 'zola': {'n_is_sb': '0'},
 'zombie': {'n_is_sb': '0'},
 'zombi': {'n_is_sb': '0'},
 'zonotrichia albicollis': {'n_is_sb': '3', 'n_is_sth': '3'},
 'zonotrichia leucophrys': {'n_is_sb': '3', 'n_is_sth': '3'},
 'zonotrichia': {'n_is_sb': '3', 'n_is_sth': '3'},
 'zoo keeper': {'n_is_sb': '0'},
 'zooflagellate': {'n_is_sb': '3', 'n_is_sth': '3'},
 'zoomastigote': {'n_is_sb': '3', 'n_is_sth': '3'},
 'zoril': {'n_is_sb': '3', 'n_is_sth': '3'},
 'zoroaster': {'n_is_sb': '0'},
 'zoroastrian': {'n_is_sb': '0'},
 'zsigmondy': {'n_is_sb': '0'},
 'zubird': {'n_is_sb': '0'},
 'zukerman': {'n_is_sb': '0'},
 'zulu': {'n_is_sb': '0'},
 'zuni': {'n_is_sb': '0'},
 'zurvan': {'n_is_sb': '0'},
 'zu': {'n_is_sb': '0'},
 'zweig': {'n_is_sb': '0'},
 'zwingli': {'n_is_sb': '0'},
 'zworykin': {'n_is_sb': '0'},
 'zygnemales': {'n_is_sb': '3', 'n_is_sth': '3'},
 'some of the scientific researchers': {'n_is_sb': '0'},
 'college students': {'n_is_sb': '0'},
 'Mr_Wang': {'n_is_sb': '0'},
 'my_sister': {'n_is_sb': '0'},
 'the_aged': {'n_is_sb': '0'},
 'his_son': {'n_is_sb': '0'},
 'dave': {'n_is_sb': '0'},
 'the_workers': {'n_is_sb': '0'},
 'a_healthy_4-kilogram_baby': {'n_is_sb': '0'},
 'her_husband': {'n_is_sb': '0'},
 'my_father': {'n_is_sb': '0'},
 'jim': {'n_is_sb': '0'},
 '_dt _jj competitors': {'n_is_sb': '0'},
 'him_n': {'n_is_sb': '0'},
 'isles': {'nns_to_nn': 'isle'},
 'accustomization': {'nn_to_vb': 'accustom'},
 'adjacence': {'nn_to_vb': 'adjacent', 'nn_to_jj': 'adjacent', 'nn_to_rb': 'adjacently'},
 'affordance': {'nn_to_vb': 'afford', 'nn_to_jj': 'affordable'},
 'authoring': {'nn_to_vb': 'author'},
 'awakeness': {'nn_to_vb': 'awaken', 'nn_to_jj': 'awake'},
 'baring': {'nn_to_vb': 'bare', 'nn_to_jj': 'bare', 'vbg_to_vb': 'bar', 'vbg_to_vbn': 'barred'},
 'blacken': {'nn_to_vb': 'black', 'nn_to_jj': 'black', 'nn_to_rb': 'blackly', 'vb_to_rb': 'blackly', 'vb_to_nn': 'blackness', 'vb_to_jj': 'black', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'cleaness': {'nn_to_vb': 'clean', 'nn_to_jj': 'clean', 'nn_to_rb': 'cleanly'},
 'comprisal': {'nn_to_vb': 'comprise'},
 'denotation': {'nn_to_vb': 'denote', 'nn_to_jj': 'denotive'},
 'dismission': {'nn_to_vb': 'dismiss', 'nn_to_jj': 'dismissive'},
 'ensurance': {'nn_to_vb': 'ensure'},
 'facilitation': {'nn_to_vb': 'facilitate', 'nn_to_jj': 'facilitative'},
 'fanciness': {'nn_to_vb': 'fancy', 'nn_to_jj': 'fancy', 'nn_to_rb': 'fancily'},
 'flatten': {'nn_to_vb': 'flat', 'nn_to_jj': 'flat', 'nn_to_rb': 'flat', 'vb_to_rb': 'flat', 'vb_to_nn': 'flat', 'vb_to_jj': 'flat', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'gravely': {'nn_to_vb': 'grave', 'nn_to_jj': 'grave', 'rb_to_nn': 'grave', 'rb_to_jj': 'grave', 'rb_to_vb': 'grave'},
 'highlighting': {'nn_to_vb': 'highlight', 'nn_to_jj': 'highlighted', 'vbg_to_vb': 'highlight', 'vbg_to_vbn': 'highlighted'},
 'initialization': {'nn_to_vb': 'initialize', 'nn_to_jj': 'initial'},
 'kneeling': {'nn_to_vb': 'kneel'},
 'maximisation': {'nn_to_vb': 'maximise', 'nn_to_jj': 'maximum'},
 'negate': {'nn_to_vb': 'nagate', 'nn_to_jj': 'negative', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'offendence': {'nn_to_vb': 'offend', 'nn_to_jj': 'offensive', 'nn_to_rb': 'offensively'},
 'predictability': {'nn_to_vb': 'predict', 'nn_to_jj': 'predictable', 'nn_to_rb': 'predictably'},
 'prioritisation': {'nn_to_vb': 'prioritise'},
 'pronounciation': {'nn_to_vb': 'pronounce'},
 'prospection': {'nn_to_vb': 'prospect', 'nn_to_jj': 'prospective', 'nn_to_rb': 'prospectively'},
 'rationalisation': {'nn_to_vb': 'rationalise', 'nn_to_jj': 'rational', 'nn_to_rb': 'rationally'},
 'realisation': {'nn_to_vb': 'realize'},
 'responsiveness': {'nn_to_vb': 'respond', 'nn_to_jj': 'respondent'},
 'satisfication': {'nn_to_vb': 'satisfy', 'nn_to_jj': 'satisfactory'},
 'senselessness': {'nn_to_vb': 'sense', 'nn_to_jj': 'sensible', 'nn_to_rb': 'sensibly'},
 'seperation': {'nn_to_vb': 'separate', 'nn_to_jj': 'separate', 'nn_to_rb': 'separately'},
 'sexism': {'nn_to_vb': 'sex', 'nn_to_jj': 'sexual', 'nn_to_rb': 'sexually'},
 'shallowness': {'nn_to_vb': 'shallow', 'nn_to_jj': 'shallow', 'nn_to_rb': 'shallowly'},
 'silveriness': {'nn_to_vb': 'silver', 'nn_to_jj': 'silverish'},
 'simpleness': {'nn_to_vb': 'simplify', 'nn_to_jj': 'simple', 'nn_to_rb': 'simply'},
 'simulating': {'nn_to_vb': 'simulate', 'nn_to_jj': 'simulate', 'nn_to_rb': 'simulatedly'},
 'sank': {'nn_to_vb': 'sink', 'nn_to_jj': 'sunk', 'vbd_to_vb': 'sink', 'vbd_to_vbn': 'sunk'},
 'skinning': {'nn_to_vb': 'skin', 'nn_to_jj': 'skinned', 'vbg_to_vb': 'skin', 'vbg_to_vbn': 'skinned'},
 'slowing': {'nn_to_vb': 'slow', 'nn_to_jj': 'slow', 'nn_to_rb': 'slowly', 'vbg_to_vb': 'slow', 'vbg_to_vbn': 'slowed'},
 'smelling': {'nn_to_vb': 'smell', 'vbg_to_vb': 'smell', 'vbg_to_vbn': 'smelled,smelt'},
 'smoothing': {'nn_to_vb': 'smooth', 'nn_to_jj': 'smoothed', 'nn_to_rb': 'smoothly'},
 'softening': {'nn_to_vb': 'soften', 'nn_to_jj': 'softened', 'nn_to_rb': 'softly'},
 'soiling': {'nn_to_vb': 'soil', 'nn_to_jj': 'soiled'},
 'solidifying': {'nn_to_vb': 'solidify', 'nn_to_jj': 'solidified', 'nn_to_rb': 'solidly'},
 'souring': {'nn_to_vb': 'sour', 'nn_to_jj': 'sour', 'nn_to_rb': 'sourly'},
 'sowing': {'nn_to_vb': 'sow'},
 'specifies': {'nn_to_vb': 'specify', 'nn_to_jj': 'specifiable', 'vbz_to_vb': 'specify'},
 'specifying': {'nn_to_vb': 'specify', 'nn_to_jj': 'specifiable', 'vbg_to_vb': 'specify', 'vbg_to_vbn': 'specified'},
 'spelt': {'nn_to_vb': 'spell', 'vbd_eq_vbn': ''},
 'sporter': {'nn_to_vb': 'sport', 'nn_to_jj': 'sporting'},
 'spotting': {'nn_to_vb': 'spot', 'nn_to_jj': 'spotted', 'nn_to_rb': 'spot', 'vbg_to_vb': 'spot', 'vbg_to_vbn': 'spotted'},
 'sprang': {'nn_to_vb': 'spring', 'nn_to_jj': 'sprung'},
 'springing': {'nn_to_vb': 'spring', 'nn_to_jj': 'sprung'},
 'squarest': {'nn_to_vb': 'square', 'nn_to_jj': 'square', 'nn_to_rb': 'squarely', 'vb_to_rb': 'squarely', 'vb_to_nn': 'square', 'vb_to_jj': 'square'},
 'squarer': {'nn_to_vb': 'square', 'nn_to_jj': 'square', 'nn_to_rb': 'squarely'},
 'stabilisation': {'nn_to_vb': 'stable', 'nn_to_jj': 'stable'},
 'stabilizing': {'nn_to_vb': 'stable', 'nn_to_jj': 'stable'},
 'stabilising': {'nn_to_vb': 'stable', 'nn_to_jj': 'stable'},
 'staining': {'nn_to_vb': 'stain', 'nn_to_jj': 'stained'},
 'stamping': {'nn_to_vb': 'stamp', 'nn_to_jj': 'stamped', 'vbg_to_vb': 'stamp', 'vbg_to_vbn': 'stampped'},
 'starring': {'nn_to_vb': 'star', 'nn_to_jj': 'star'},
 'stating': {'nn_to_vb': 'state', 'nn_to_jj': 'state', 'vbg_to_vb': 'state', 'vbg_to_vbn': 'stated'},
 'staying': {'nn_to_vb': 'stay', 'vbg_to_vb': 'stay', 'vbg_to_vbn': 'stayed'},
 'stole': {'nn_to_vb': 'steal', 'nn_to_jj': 'stolen', 'vbd_to_vb': 'steal', 'vbd_to_vbn': 'stolen'},
 'stepping': {'nn_to_vb': 'step'},
 'stiffening': {'nn_to_vb': 'stiff', 'nn_to_jj': 'stiff', 'nn_to_rb': 'stiff'},
 'stiller': {'nn_to_vb': 'still', 'nn_to_jj': 'still', 'nn_to_rb': 'still'},
 'stoning': {'nn_to_vb': 'stone', 'nn_to_jj': 'stone', 'nn_to_rb': 'stonily'},
 'storming': {'nn_to_vb': 'storm'},
 'straightening': {'nn_to_vb': 'straighten', 'nn_to_jj': 'straight', 'nn_to_rb': 'straight'},
 'streaming': {'nn_to_vb': 'stream'},
 'strengthening': {'nn_to_vb': 'strengthen', 'vbg_to_vb': 'strengthen', 'vbg_to_vbn': 'strengthened'},
 'stretching': {'nn_to_vb': 'stretch', 'nn_to_jj': 'stretch', 'vbg_to_vb': 'stretch', 'vbg_to_vbn': 'stretched'},
 'stringing': {'nn_to_vb': 'string', 'nn_to_jj': 'stringed'},
 'stripping': {'nn_to_vb': 'strip', 'nn_to_jj': 'stripped'},
 'styling': {'nn_to_vb': 'style', 'nn_to_jj': 'stylized', 'nn_to_rb': 'stylishly'},
 'substituting': {'nn_to_vb': 'substitute', 'nn_to_jj': 'substitutive'},
 'supportin': {'nn_to_vb': 'support', 'nn_to_jj': 'supported'},
 'supposal': {'nn_to_vb': 'suppose', 'nn_to_jj': 'supposed', 'nn_to_rb': 'supposedly'},
 'surfacing': {'nn_to_vb': 'surface', 'nn_to_jj': 'surface', 'nn_to_rb': 'surficially'},
 'survivability': {'nn_to_vb': 'survive', 'nn_to_jj': 'survived'},
 'suspending': {'nn_to_vb': 'suspend', 'nn_to_jj': 'suspended'},
 'suspiciousness': {'nn_to_vb': 'suspicion', 'nn_to_jj': 'suspicious', 'nn_to_rb': 'suspiciously'},
 'sustainability': {'nn_to_vb': 'sustain', 'nn_to_jj': 'sustained'},
 'swallowing': {'nn_to_vb': 'swallow'},
 'swearing': {'nn_to_vb': 'swear', 'nn_to_jj': 'sworn', 'vbg_to_vb': 'swear', 'vbg_to_vbn': 'sworn'},
 'sweating': {'nn_to_vb': 'sweat', 'nn_to_jj': 'sweated'},
 'tailoring': {'nn_to_vb': 'tailor', 'nn_to_jj': 'tailored'},
 'taming': {'nn_to_vb': 'tame', 'nn_to_jj': 'tame'},
 'taping': {'nn_to_vb': 'tape', 'nn_to_jj': 'taped'},
 'targeting': {'nn_to_vb': 'target', 'nn_to_jj': 'targeted'},
 'tastelessness': {'nn_to_vb': 'taste', 'nn_to_jj': 'tasteless'},
 'tasting': {'nn_to_vb': 'taste', 'nn_to_jj': 'tasteless', 'vbg_to_vb': 'taste', 'vbg_to_vbn': 'tasted'},
 'tore': {'nn_to_vb': 'tear', 'nn_to_jj': 'tearing', 'vbd_to_vb': 'tear', 'vbd_to_vbn': 'torn'},
 'torn': {'nn_to_vb': 'tear', 'nn_to_jj': 'tearing', 'vbn_to_vb': 'tear', 'vbn_to_vbd': 'tore', 'vbn_to_vbg': 'tearing'},
 'terminating': {'nn_to_vb': 'terminate', 'nn_to_jj': 'terminate'},
 'thanking': {'nn_to_vb': 'thank', 'nn_to_jj': 'thankful', 'nn_to_rb': 'thankfully', 'vbg_to_vb': 'thank', 'vbg_to_vbn': 'thanked'},
 'theatrics': {'nn_to_vb': 'theatricalize', 'nn_to_jj': 'theatrical', 'nn_to_rb': 'theatrically'},
 'thinness': {'nn_to_vb': 'thin', 'nn_to_jj': 'thin', 'nn_to_rb': 'thinly'},
 'thinned': {'nn_to_vb': 'thin', 'nn_to_jj': 'thin', 'nn_to_rb': 'thinly', 'vbd_eq_vbn': ''},
 'threatener': {'nn_to_vb': 'threat', 'nn_to_jj': 'threatened'},
 'timelessness': {'nn_to_vb': 'time', 'nn_to_jj': 'timeless', 'nn_to_rb': 'timely'},
 'totalizer': {'nn_to_vb': 'totalize', 'nn_to_jj': 'total', 'nn_to_rb': 'totally'},
 'totalizator': {'nn_to_vb': 'totalize', 'nn_to_jj': 'total', 'nn_to_rb': 'totally'},
 'transferability': {'nn_to_vb': 'transfer', 'nn_to_jj': 'transferable'},
 'transformat': {'nn_to_vb': 'transform', 'nn_to_jj': 'transformational', 'nn_to_rb': 'transformationally'},
 'transmitting': {'nn_to_vb': 'transmit', 'nn_to_jj': 'transmissive', 'nn_to_rb': 'transmissively'},
 'entrustment': {'nn_to_vb': 'trust', 'nn_to_jj': 'trustable'},
 'uglifier': {'nn_to_vb': 'uglify', 'nn_to_jj': 'ugly', 'nn_to_rb': 'uglily'},
 'uglification': {'nn_to_vb': 'uglify', 'nn_to_jj': 'ugly', 'nn_to_rb': 'uglily'},
 'uniformitarian': {'nn_to_vb': 'uniform', 'nn_to_jj': 'uniform', 'nn_to_rb': 'uniformly'},
 'utilisation': {'nn_to_vb': 'utilize', 'nn_to_jj': 'utilisable'},
 'virtualization': {'nn_to_vb': 'virtualize', 'nn_to_jj': 'virtual', 'nn_to_rb': 'virtually'},
 'virtuality': {'nn_to_vb': 'virtualize', 'nn_to_jj': 'virtual', 'nn_to_rb': 'virtually'},
 'virtuousness': {'nn_to_vb': 'virtue', 'nn_to_jj': 'virtuous', 'nn_to_rb': 'virtuously'},
 'visualisation': {'nn_to_vb': 'visualise', 'nn_to_jj': 'visual', 'nn_to_rb': 'visually'},
 'visualizing': {'nn_to_vb': 'visualise', 'nn_to_jj': 'visual', 'nn_to_rb': 'visually'},
 'voyageur': {'nn_to_vb': 'voyage', 'nn_to_jj': 'voyageable'},
 'wastefulness': {'nn_to_vb': 'wast', 'nn_to_jj': 'wasteful', 'nn_to_rb': 'wastefully'},
 'wearability': {'nn_to_vb': 'wear', 'nn_to_jj': 'wearable', 'nn_to_rb': 'wearily'},
 'wideness': {'nn_to_vb': 'widen', 'nn_to_jj': 'wide', 'nn_to_rb': 'widely'},
 'wiseness': {'nn_to_vb': 'wisen', 'nn_to_jj': 'wise', 'nn_to_rb': 'wisely'},
 'worthiness': {'nn_to_vb': 'worth', 'nn_to_jj': 'worthy', 'nn_to_rb': 'worthily'},
 'annoy': {'nn_to_jj': 'annoying', 'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'annoys', 'vb_to_vbd': 'annoyed', 'vb_to_vbn': 'annoyed', 'vb_to_vbg': 'annoying', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'append': {'nn_to_jj': 'appendant', 'vb_to_nn': 'appendix', 'vb_to_jj': 'appendant', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'argue': {'nn_to_jj': 'arguable', 'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_for': '', 'v_against': '', 'vb_to_vbz': 'argues', 'vb_to_vbd': 'argued', 'vb_to_vbn': 'argued', 'vb_to_nn': 'argument', 'vb_to_jj': 'arguable', 'vb_to_vbg': 'arguing', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'arise': {'nn_to_jj': 'arisen', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'arises', 'vb_to_vbd': 'arised', 'vb_to_vbn': 'arised', 'vb_to_jj': 'arisen', 'vb_to_vbg': 'arising', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_pass_non': ''},
 'arrive': {'nn_to_jj': 'arrived', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_in': '', 'vb_to_vbz': 'arrives', 'vb_to_vbd': 'arrived', 'vb_to_vbn': 'arrived', 'vb_to_nn': 'arrival', 'vb_to_jj': 'arrived', 'vb_to_vbg': 'arriving', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'bake': {'nn_to_jj': 'baking', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'bakes', 'vb_to_vbd': 'baked', 'vb_to_vbn': 'baked', 'vb_to_jj': 'baking', 'vb_to_vbg': 'baking', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'bind': {'nn_to_jj': 'binding', 'vb_to_jj': 'binding', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'bless': {'nn_to_jj': 'blessed', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'blesses', 'vb_to_vbd': 'blessed', 'vb_to_vbn': 'blessed', 'vb_to_nn': 'blessing', 'vb_to_jj': 'blessed', 'vb_to_vbg': 'blessing', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'brighten': {'nn_to_jj': 'bright', 'nn_to_rb': 'brightly', 'vb_to_rb': 'brightly', 'vb_to_nn': 'brightness', 'vb_to_jj': 'bright', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'bury': {'nn_to_jj': 'buried', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'buries', 'vb_to_vbd': 'buried', 'vb_to_vbn': 'buried', 'vb_to_nn': 'burying', 'vb_to_jj': 'buried', 'vb_to_vbg': 'burying', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'cleverly': {'nn_to_jj': 'clever', 'rb_to_nn': 'cleverness', 'rb_to_jj': 'clever'},
 'coldness': {'nn_to_jj': 'cold', 'nn_to_rb': 'coldly'},
 'confine': {'nn_to_jj': 'confined', 'vb_to_jj': 'confined', 'v_compcl_non': '', 'v_whcl_non': ''},
 'die': {'nn_to_jj': 'dead', 'nn_to_rb': 'deadly', 'v_to_vb': '', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'v_of': '', 'v_from': '', 'vb_to_vbz': 'dies', 'vb_to_vbd': 'died', 'vb_to_vbn': 'died', 'vb_to_rb': 'deadly', 'vb_to_jj': 'dead', 'vb_to_vbg': 'dying', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'decrease': {'nn_to_jj': 'decreasing', 'v_n': '', 'nsubjpass': '', 'v_in': '', 'v_with': '', 'v_for': '', 'vb_to_jj': 'decreasing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'define': {'nn_to_jj': 'definable', 'vb_to_nn': 'definition', 'vb_to_jj': 'definable', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'definitiveness': {'nn_to_jj': 'definite', 'nn_to_rb': 'definitely'},
 'deliver': {'nn_to_jj': 'delivered', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'delivers', 'vb_to_vbd': 'delivered', 'vb_to_vbn': 'delivered', 'vb_to_nn': 'delivery', 'vb_to_jj': 'delivered', 'vb_to_vbg': 'delivering', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'derive': {'nn_to_jj': 'derivative', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'derives', 'vb_to_vbd': 'derived', 'vb_to_vbn': 'derived', 'vb_to_nn': 'derivation', 'vb_to_jj': 'derivative', 'vb_to_vbg': 'deriving', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'differ': {'nn_to_jj': 'different', 'v_to_vbg': '', 'nsubjpass': '', 'v_on': '', 'v_with': '', 'v_about': '', 'v_from': '', 'v_to': '', 'vb_to_nn': 'difference', 'vb_to_jj': 'different', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'vi_typical': ''},
 'dispose': {'nn_to_jj': 'disposable', 'vb_to_nn': 'disposal', 'vb_to_jj': 'disposable', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'drown': {'nn_to_jj': 'drowning', 'vb_to_jj': 'drowning', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_n_in_n': ''},
 'earliness': {'nn_to_jj': 'early', 'nn_to_rb': 'early'},
 'edit': {'nn_to_jj': 'editorial', 'vb_to_nn': 'edition', 'vb_to_jj': 'editorial', 'vbd_eq_vbn': ''},
 'ethnicity': {'nn_to_jj': 'ethnic', 'nn_to_rb': 'ethnically'},
 'fail': {'nn_to_jj': 'failed', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'fails', 'vb_to_vbd': 'failed', 'vb_to_vbn': 'failed', 'vb_to_nn': 'failure', 'vb_to_jj': 'failed', 'vb_to_vbg': 'failing', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'flavour': {'nn_to_jj': 'flavoured', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'flavours', 'vb_to_vbd': 'flavoured', 'vb_to_vbn': 'flavoured', 'vb_to_jj': 'flavoured', 'vb_to_vbg': 'flavouring', 'vbd_eq_vbn': ''},
 'follow': {'nn_to_jj': 'following', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_from': '', 'vb_to_vbz': 'follows', 'vb_to_vbd': 'followed', 'vb_to_vbn': 'followed', 'vb_to_jj': 'following', 'vb_to_vbg': 'following', 'vbd_eq_vbn': ''},
 'gayness': {'nn_to_jj': 'gay'},
 'getting': {'nn_to_jj': 'get', 'vbg_to_vb': 'get', 'vbg_to_vbn': 'gotten'},
 'go': {'nn_to_jj': 'gone', 'v_to_vb': '', 'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'vbe': '', 'vdo': '', 'v_at': '', 'v_with': '', 'v_about': '', 'vb_to_vbz': 'goes', 'vb_to_vbd': 'went', 'vb_to_vbn': 'gone', 'vb_to_jj': 'gone', 'vb_to_vbg': 'going', 'v_vbg': '', 'vi_typical': '', 'vbd_eq_vbn': ''},
 'govern': {'nn_to_jj': 'governing', 'vb_to_vbz': 'governs', 'vb_to_vbd': 'governed', 'vb_to_vbn': 'governed', 'vb_to_nn': 'government', 'vb_to_jj': 'governing', 'vb_to_vbg': 'governing', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'gratefulness': {'nn_to_jj': 'grateful', 'nn_to_rb': 'gratefully'},
 'grow': {'nn_to_jj': 'grown', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vbe': '', 'vdo': '', 'v_in': '', 'v_from': '', 'vb_to_vbz': 'grows', 'vb_to_vbd': 'grew', 'vb_to_vbn': 'grown', 'vb_to_nn': 'growth', 'vb_to_jj': 'grown', 'vb_to_vbg': 'growing', 'vi_typical': '', 'v_prprtcl_non': ''},
 'heal': {'nn_to_jj': 'healing', 'vb_to_nn': 'healing', 'vb_to_jj': 'healing', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'illy': {'nn_to_jj': 'ill', 'rb_to_nn': 'illness', 'rb_to_jj': 'ill'},
 'immenseness': {'nn_to_jj': 'immense', 'nn_to_rb': 'immensely'},
 'implicity': {'nn_to_jj': 'implicit', 'nn_to_rb': 'implicitly'},
 'imply': {'nn_to_jj': 'implied', 'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'implies', 'vb_to_vbd': 'implied', 'vb_to_vbn': 'implied', 'vb_to_vbg': 'implying', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'inherence': {'nn_to_jj': 'inherent', 'nn_to_rb': 'inherently'},
 'interact': {'nn_to_jj': 'interactive', 'vb_to_nn': 'interaction', 'vb_to_jj': 'interactive', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'lateness': {'nn_to_jj': 'late', 'nn_to_rb': 'lately'},
 'lend': {'nn_to_jj': 'lending', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'lends', 'vb_to_vbd': 'lent', 'vb_to_vbn': 'lent', 'vb_to_nn': 'lending', 'vb_to_jj': 'lending', 'vb_to_vbg': 'lending', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'listen': {'nn_to_jj': 'listening', 'v_to_vbg': '', 'v_to_n': '', 'vdo': '', 'v_in': '', 'v_for': '', 'v_to': '', 'v_to_vb': '', 'vb_to_vbz': 'listens', 'vb_to_vbd': 'listened', 'vb_to_vbn': 'listened', 'vb_to_jj': 'listening', 'vb_to_vbg': 'listening', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_pass_non': '', 'nn_vbg_confu': 'listening'},
 'loosen': {'nn_to_jj': 'loose', 'nn_to_rb': 'loose', 'vb_to_rb': 'loose', 'vb_to_nn': 'loose', 'vb_to_jj': 'loose', 'v_compcl_non': ''},
 'lose': {'nn_to_jj': 'lost', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'loses', 'vb_to_vbd': 'lost', 'vb_to_vbn': 'lost', 'vb_to_nn': 'losing', 'vb_to_jj': 'lost', 'vb_to_vbg': 'losing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'marry': {'nn_to_jj': 'married', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'marries', 'vb_to_vbd': 'married', 'vb_to_vbn': 'married', 'vb_to_nn': 'marriage', 'vb_to_jj': 'married', 'vb_to_vbg': 'marrying', 'vt_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'melt': {'nn_to_jj': 'melted', 'vb_to_jj': 'melted', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'merriness': {'nn_to_jj': 'merry', 'nn_to_rb': 'merrily'},
 'niceness': {'nn_to_jj': 'nice', 'nn_to_rb': 'nicely'},
 'obtain': {'nn_to_jj': 'obtainable', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'obtains', 'vb_to_vbd': 'obtained', 'vb_to_vbn': 'obtained', 'vb_to_vbg': 'obtaining', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'obviousness': {'nn_to_jj': 'obvious'},
 'pinkness': {'nn_to_jj': 'pink', 'nn_to_rb': 'pinkly'},
 'politer': {'nn_to_jj': 'polite', 'nn_to_rb': 'politely'},
 'professionalism': {'nn_to_jj': 'professional', 'nn_to_rb': 'professionally'},
 'purposiveness': {'nn_to_jj': 'purposive', 'nn_to_rb': 'purposively'},
 'rareness': {'nn_to_jj': 'rare', 'nn_to_rb': 'rarely'},
 'resist': {'nn_to_jj': 'resistible', 'v_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'resists', 'vb_to_vbd': 'resisted', 'vb_to_vbn': 'resisted', 'vb_to_jj': 'resistible', 'vb_to_vbg': 'resisting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'sacredness': {'nn_to_jj': 'sacred'},
 'safeness': {'nn_to_jj': 'safe', 'nn_to_rb': 'safely'},
 'select': {'nn_to_jj': 'selective', 'nn_to_rb': 'selectively', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'selects', 'vb_to_vbd': 'selected', 'vb_to_vbn': 'selected', 'vb_to_rb': 'selectively', 'vb_to_jj': 'selective', 'vb_to_vbg': 'selecting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'severeness': {'nn_to_jj': 'severe', 'nn_to_rb': 'severely'},
 'singling': {'nn_to_jj': 'single'},
 'six': {'nn_to_jj': 'sixteenth', 'nn_to_rb': 'sixthly'},
 'sixties': {'nn_to_jj': 'sixteenth', 'nn_to_rb': 'sixthly'},
 'smooth': {'nn_to_jj': 'smoothed', 'nn_to_rb': 'smoothly', 'vb_to_rb': 'smoothly', 'vb_to_jj': 'smoothed', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'jj_to_jjr': 'smoother', 'jj_to_jjs': 'smoothest'},
 'sorriness': {'nn_to_jj': 'sorry'},
 'sourcing': {'nn_to_jj': 'sourced'},
 'spend': {'nn_to_jj': 'spent', 'v_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_to_vbz': 'spends', 'vb_to_vbd': 'spent', 'vb_to_vbn': 'spent', 'vb_to_jj': 'spent', 'vb_to_vbg': 'spending', 'v_n_vbg': ''},
 'suffer': {'nn_to_jj': 'suffering', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'suffers', 'vb_to_vbd': 'suffered', 'vb_to_vbn': 'suffered', 'vb_to_jj': 'suffering', 'vb_to_vbg': 'suffering', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'swear': {'nn_to_jj': 'sworn', 'v_compcl': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'v_on': '', 'v_in': '', 'v_to': '', 'vb_to_vbz': 'swears', 'vb_to_vbd': 'swore', 'vb_to_vbn': 'sworn', 'vb_to_jj': 'sworn', 'vb_to_vbg': 'swearing', 'v_prprtcl_non': ''},
 'systematicness': {'nn_to_jj': 'systematic', 'nn_to_rb': 'systematically'},
 'take': {'nn_to_jj': 'taking', 'v_vbg': '', 'v_to_n': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_n': '', 'v_n_to_n': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_against': '', 'vb_to_vbz': 'takes', 'vb_to_vbd': 'took', 'vb_to_vbn': 'taken', 'vb_to_jj': 'taking', 'vb_to_vbg': 'taking', 'v_compcl_non': '', 'vt_typical': ''},
 'ten': {'nn_to_jj': 'tenth'},
 'terribleness': {'nn_to_jj': 'terrible', 'nn_to_rb': 'terribly'},
 'thank': {'nn_to_jj': 'thankful', 'nn_to_rb': 'thankfully', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'thanks', 'vb_to_vbd': 'thanked', 'vb_to_vbn': 'thanked', 'vb_to_rb': 'thankfully', 'vb_to_jj': 'thankful', 'vb_to_nn': 'thanks', 'vb_to_vbg': 'thanking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'thirteen': {'nn_to_jj': 'thirteenth'},
 'thronbush': {'nn_to_jj': 'thronlike'},
 'three': {'nn_to_jj': 'third', 'nn_to_rb': 'thirdly'},
 'thunderball': {'nn_to_jj': 'thunderous', 'nn_to_rb': 'thunderously'},
 'traditionalism': {'nn_to_jj': 'traditional', 'nn_to_rb': 'traditionally'},
 'twelve': {'nn_to_jj': 'twelfth'},
 'twenty': {'nn_to_jj': 'twentieth'},
 'universalization': {'nn_to_jj': 'universal', 'nn_to_rb': 'universally'},
 'variousness': {'nn_to_jj': 'various', 'nn_to_rb': 'variously'},
 'vary': {'nn_to_jj': 'variable', 'nn_to_rb': 'variably', 'v_from_n_to_n': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_with': '', 'v_from': '', 'vb_to_vbz': 'varies', 'vb_to_vbd': 'varied', 'vb_to_vbn': 'varied', 'vb_to_rb': 'variably', 'vb_to_jj': 'variable', 'vb_to_vbg': 'varying', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'victorinism': {'nn_to_jj': 'victorious', 'nn_to_rb': 'victoriously'},
 'weigh': {'nn_to_jj': 'weighable', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_against': '', 'vb_to_vbz': 'weighs', 'vb_to_vbd': 'weighed', 'vb_to_vbn': 'weighed', 'vb_to_jj': 'weighable', 'vb_to_vbg': 'weighing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'wildlife': {'nn_to_jj': 'wild', 'nn_to_rb': 'wildly'},
 'accept': {'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'accepts', 'vb_to_vbd': 'accepted', 'vb_to_vbn': 'accepted', 'vb_to_rb': 'acceptably', 'vb_to_nn': 'acceptance', 'vb_to_jj': 'acceptable', 'vb_to_vbg': 'accepting', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'acknowledge': {'v_compcl': '', 'v_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'acknowledges', 'vb_to_vbd': 'acknowledged', 'vb_to_vbn': 'acknowledged', 'vb_to_nn': 'acknowledgement', 'vb_to_vbg': 'acknowledging', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'add': {'v_compcl': '', 'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_in': '', 'vb_to_vbz': 'adds', 'vb_to_vbd': 'added', 'vb_to_vbn': 'added', 'vb_to_nn': 'addition', 'vb_to_jj': 'additive', 'vb_to_vbg': 'adding', 'vbd_eq_vbn': '', 'v_whcl_non': ''},
 'admit': {'v_compcl': '', 'v_vbg': '', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'admits', 'vb_to_vbd': 'admitted', 'vb_to_vbn': 'admitted', 'vb_to_nn': 'admission', 'vb_to_jj': 'admitted', 'vb_to_vbg': 'admitting', 'vbd_eq_vbn': ''},
 'advise': {'v_compcl': '', 'v_vbg': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_about': '', 'v_of': '', 'v_against': '', 'vb_to_vbz': 'advises', 'vb_to_vbd': 'advised', 'vb_to_vbn': 'advised', 'vb_to_jj': 'advisory', 'vb_to_vbg': 'advising', 'vbd_eq_vbn': '', 'vt_typical': '', 'v_n_to_vb': '', 'vb_to_nn': 'advice', 'v_that_n_vb': ''},
 'agree': {'v_compcl': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'agrees', 'vb_to_vbd': 'agreed', 'vb_to_vbn': 'agreed', 'vb_to_nn': 'agreement', 'vb_to_jj': 'agreeable', 'vb_to_vbg': 'agreeing', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'allow': {'v_compcl': '', 'v_vbg': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'v_of': '', 'vb_to_vbz': 'allows', 'vb_to_vbd': 'allowed', 'vb_to_vbn': 'allowed', 'vb_to_rb': 'allowably', 'vb_to_nn': 'allowance', 'vb_to_jj': 'allowable', 'vb_to_vbg': 'allowing', 'vbd_eq_vbn': '', 'v_whcl_non': '', 'vt_typical': ''},
 'announce': {'v_compcl': '', 'v_to_n': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'announces', 'vb_to_vbd': 'announced', 'vb_to_vbn': 'announced', 'vb_to_vbg': 'announcing', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vt_typical': ''},
 'anticipate': {'v_compcl': '', 'v_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'anticipates', 'vb_to_vbd': 'anticipated', 'vb_to_vbn': 'anticipated', 'vb_to_rb': 'anticipatively', 'vb_to_nn': 'anticipation', 'vb_to_jj': 'anticipative', 'vb_to_vbg': 'anticipating', 'vbd_eq_vbn': ''},
 'appreciate': {'v_compcl': '', 'v_vbg': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'appreciates', 'vb_to_vbd': 'appreciated', 'vb_to_vbn': 'appreciated', 'vb_to_rb': 'appreciably', 'vb_to_nn': 'appreciation', 'vb_to_jj': 'appreciable', 'vb_to_vbg': 'appreciating', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vt_typical': ''},
 'arrange': {'v_compcl': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_for': '', 'vb_to_vbz': 'arranges', 'vb_to_vbd': 'arranged', 'vb_to_vbn': 'arranged', 'vb_to_nn': 'arrangement', 'vb_to_jj': 'arranged', 'vb_to_vbg': 'arranging', 'vbd_eq_vbn': ''},
 'assume': {'v_compcl': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'assumes', 'vb_to_vbd': 'assumed', 'vb_to_vbn': 'assumed', 'vb_to_nn': 'assumption', 'vb_to_jj': 'assumed', 'vb_to_vbg': 'assuming', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'vt_typical': ''},
 'beg': {'v_compcl': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'v_for': '', 'v_of': '', 'v_from': '', 'vbd_eq_vbn': '', 'v_pass_non': ''},
 'believe': {'v_compcl': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'believes', 'vb_to_vbd': 'believed', 'vb_to_vbn': 'believed', 'vb_to_nn': 'belief', 'vb_to_jj': 'believing', 'vb_to_vbg': 'believing', 'vbd_eq_vbn': '', 'vbg_non': ''},
 'calculate': {'v_compcl': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'vb_to_vbz': 'calculates', 'vb_to_vbd': 'calculated', 'vb_to_vbn': 'calculated', 'vb_to_nn': 'calculation', 'vb_to_jj': 'calculating', 'vb_to_vbg': 'calculating', 'vbd_eq_vbn': ''},
 'choose': {'v_compcl': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_n': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'chooses', 'vb_to_vbd': 'chose', 'vb_to_vbn': 'chosen', 'vb_to_rb': 'choicely', 'vb_to_nn': 'choice', 'vb_to_jj': 'choice', 'vb_to_vbg': 'choosing'},
 'complain': {'v_compcl': '', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_with': '', 'v_for': '', 'v_against': '', 'vb_to_vbz': 'complains', 'vb_to_vbd': 'complained', 'vb_to_vbn': 'complained', 'vb_to_nn': 'complaint', 'vb_to_jj': 'complaining', 'vb_to_vbg': 'complaining', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'conclude': {'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_from': '', 'vb_to_vbz': 'concludes', 'vb_to_vbd': 'concluded', 'vb_to_vbn': 'concluded', 'vb_to_nn': 'conclusion', 'vb_to_jj': 'conclusive', 'vb_to_vbg': 'concluding', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'confirm': {'v_compcl': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vb_to_nn': 'confirmation', 'vb_to_jj': 'confirmed', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'see': {'v_vb': '', 'v_compcl': '', 'v_vbg': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'v_n_vb': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'sees', 'vb_to_vbd': 'saw', 'vb_to_vbn': 'seen', 'v_n_vbg': '', 'vb_to_vbg': 'seeing'},
 'consider': {'v_compcl': '', 'v_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_n': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'considers', 'vb_to_vbd': 'considered', 'vb_to_vbn': 'considered', 'vb_to_nn': 'consideration', 'vb_to_jj': 'considerable', 'vb_to_vbg': 'considering', 'vbd_eq_vbn': ''},
 'contribute': {'v_compcl': '', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'contributes', 'vb_to_vbd': 'contributed', 'vb_to_vbn': 'contributed', 'vb_to_nn': 'contribution', 'vb_to_jj': 'contributed', 'vb_to_vbg': 'contributing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'decide': {'v_compcl': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_against': '', 'vb_to_vbz': 'decides', 'vb_to_vbd': 'decided', 'vb_to_vbn': 'decided', 'vb_to_nn': 'deception', 'vb_to_jj': 'decided', 'vb_to_vbg': 'deciding', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'declare': {'v_compcl': '', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'declares', 'vb_to_vbd': 'declared', 'vb_to_vbn': 'declared', 'vb_to_nn': 'declaration', 'vb_to_jj': 'declared', 'vb_to_vbg': 'declaring', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'demonstrate': {'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'v_against': '', 'v_to': '', 'vb_to_vbz': 'demonstrates', 'vb_to_vbd': 'demonstrated', 'vb_to_vbn': 'demonstrated', 'vb_to_nn': 'demonstration', 'vb_to_jj': 'demonstrable', 'vb_to_vbg': 'demonstrating', 'vbd_eq_vbn': ''},
 'deny': {'v_compcl': '', 'v_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'denies', 'vb_to_vbd': 'denied', 'vb_to_vbn': 'denied', 'vb_to_nn': 'denial', 'vb_to_jj': 'deniable', 'vb_to_vbg': 'denying', 'vbd_eq_vbn': ''},
 'determine': {'v_compcl': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'determines', 'vb_to_vbd': 'determined', 'vb_to_vbn': 'determined', 'vb_to_nn': 'determination', 'vb_to_jj': 'determinate', 'vb_to_vbg': 'determining', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'discover': {'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'discovers', 'vb_to_vbd': 'discovered', 'vb_to_vbn': 'discovered', 'vb_to_nn': 'discovery', 'vb_to_vbg': 'discovering', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'discuss': {'v_compcl': '', 'v_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'discusses', 'vb_to_vbd': 'discussed', 'vb_to_vbn': 'discussed', 'vb_to_nn': 'discussion', 'vb_to_vbg': 'discussing', 'vt_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'ensure': {'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'ensures', 'vb_to_vbd': 'ensured', 'vb_to_vbn': 'ensured', 'vb_to_nn': 'ensurance', 'vb_to_jj': 'sure', 'v_vbg': '', 'vb_to_vbg': 'ensuring', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'establish': {'v_compcl': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'establishes', 'vb_to_vbd': 'established', 'vb_to_vbn': 'established', 'vb_to_nn': 'establishment', 'vb_to_jj': 'established', 'vb_to_vbg': 'establishing', 'vbd_eq_vbn': ''},
 'expect': {'v_compcl': '', 'v_to_vb': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'expects', 'vb_to_vbd': 'expected', 'vb_to_vbn': 'expected', 'vb_to_nn': 'expectation', 'vb_to_jj': 'expected', 'vb_to_vbg': 'expecting', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'vt_typical': ''},
 'explain': {'v_compcl': '', 'v_to_n': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_about': '', 'v_to': '', 'vb_to_vbz': 'explains', 'vb_to_vbd': 'explained', 'vb_to_vbn': 'explained', 'vb_to_nn': 'explanation', 'vb_to_jj': 'explanatory', 'vb_to_vbg': 'explaining', 'vbd_eq_vbn': ''},
 'fi\x1dgure': {'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'fi\x1dgures', 'vb_to_vbd': 'fi\x1dgured', 'vb_to_vbn': 'fi\x1dgured', 'vb_to_vbg': 'fi\x1dguring', 'vbd_eq_vbn': ''},
 'forget': {'v_compcl': '', 'v_vbg': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_about': '', 'vb_to_vbz': 'forgets', 'vb_to_vbd': 'forgot', 'vb_to_vbn': 'forgotten', 'vb_to_vbg': 'forgeting', 'vbd_eq_vbn': ''},
 'hear': {'v_compcl': '', 'v_vbg': '', 'v_to_vb': '', 'v_n': '', 'v_n_vb': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_vb': '', 'vb_to_vbz': 'hears', 'vb_to_vbd': 'heard', 'vb_to_vbn': 'heard', 'v_n_vbg': '', 'vb_to_vbg': 'hearing'},
 'imagine': {'v_compcl': '', 'v_vbg': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'imagines', 'vb_to_vbd': 'imagined', 'vb_to_vbn': 'imagined', 'vb_to_nn': 'imagination', 'vb_to_jj': 'imaginative', 'vb_to_vbg': 'imagining', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'indicate': {'v_compcl': '', 'v_vbg': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'indicates', 'vb_to_vbd': 'indicated', 'vb_to_vbn': 'indicated', 'vb_to_nn': 'indication', 'vb_to_jj': 'indicative', 'vb_to_vbg': 'indicating', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'insist': {'v_compcl': '', 'v_to_vbg': '', 'vdo': '', 'v_on': '', 'vb_to_vbz': 'insists', 'vb_to_vbd': 'insisted', 'vb_to_vbn': 'insisted', 'vb_to_vbg': 'insisting', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'v_that_n_vb': ''},
 'intend': {'v_compcl': '', 'v_vbg': '', 'v_to_vb': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'intends', 'vb_to_vbd': 'intended', 'vb_to_vbn': 'intended', 'vb_to_nn': 'intention', 'vb_to_jj': 'intent', 'vb_to_vbg': 'intending', 'vbd_eq_vbn': '', 'v_whcl_non': '', 'vbg_non': '', 'vt_typical': ''},
 'investigate': {'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'investigates', 'vb_to_vbd': 'investigated', 'vb_to_vbn': 'investigated', 'vb_to_nn': 'investigation', 'vb_to_jj': 'investigative', 'vb_to_vbg': 'investigating', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'know': {'v_compcl': '', 'v_to_vb': '', 'v_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'knows', 'vb_to_vbd': 'knew', 'vb_to_vbn': 'known', 'vb_to_nn': 'knowing', 'vb_to_jj': 'known', 'vb_to_vbg': 'knowing', 'v_prprtcl_non': ''},
 'learn': {'v_compcl': '', 'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_about': '', 'v_of': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'learns', 'vb_to_vbd': 'learned,learnt', 'vb_to_vbn': 'learned,learnt', 'vb_to_nn': 'learning', 'vb_to_jj': 'learned', 'vb_to_vbg': 'learning'},
 'maintain': {'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'maintains', 'vb_to_vbd': 'maintained', 'vb_to_vbn': 'maintained', 'vb_to_nn': 'maintenance', 'vb_to_jj': 'maintained', 'vb_to_vbg': 'maintaining', 'vbd_eq_vbn': ''},
 'observe': {'v_compcl': '', 'v_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_vb': '', 'vb_to_vbz': 'observes', 'vb_to_vbd': 'observed', 'vb_to_vbn': 'observed', 'v_n_vb': '', 'v_n_vbg': '', 'vb_to_vbg': 'observing', 'vbd_eq_vbn': ''},
 'perceive': {'v_compcl': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_n': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'perceives', 'vb_to_vbd': 'perceived', 'vb_to_vbn': 'perceived', 'vb_to_nn': 'perception', 'vb_to_vbg': 'perceiving', 'vbd_eq_vbn': '', 'vbg_non': ''},
 'predict': {'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'predicts', 'vb_to_vbd': 'predicted', 'vb_to_vbn': 'predicted', 'vb_to_rb': 'predictably', 'vb_to_nn': 'predictability', 'vb_to_jj': 'predictable', 'vb_to_vbg': 'predicting', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'vt_typical': ''},
 'prefer': {'v_compcl': '', 'v_vbg': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'prefers', 'vb_to_vbd': 'prefered', 'vb_to_vbn': 'prefered', 'vb_to_rb': 'preferably', 'vb_to_nn': 'preference', 'vb_to_jj': 'preferable', 'vb_to_vbg': 'prefering', 'vbd_eq_vbn': '', 'vbg_non': '', 'vt_typical': ''},
 'presume': {'v_compcl': '', 'v_to_vb': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_to': '', 'vb_to_vbz': 'presumes', 'vb_to_vbd': 'presumed', 'vb_to_vbn': 'presumed', 'vb_to_rb': 'presumably', 'vb_to_nn': 'presumption', 'vb_to_jj': 'presumable', 'vb_to_vbg': 'presuming', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'pretend': {'v_compcl': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'pretends', 'vb_to_vbd': 'pretended', 'vb_to_vbn': 'pretended', 'vb_to_nn': 'pretence', 'vb_to_vbg': 'pretending', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'pronounce': {'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'v_on': '', 'v_for': '', 'v_against': '', 'vb_to_nn': 'pronounciation', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'propose': {'v_compcl': '', 'v_vbg': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'proposes', 'vb_to_vbd': 'proposed', 'vb_to_vbn': 'proposed', 'vb_to_nn': 'proposal', 'vb_to_vbg': 'proposing', 'vbd_eq_vbn': ''},
 'prove': {'v_compcl': '', 'v_n': '', 'v_n_n': '', 'v_n_to_n': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vbe': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'proves', 'vb_to_vbd': 'proved', 'vb_to_vbn': 'proven', 'vb_to_vbg': 'proving', 'vi_typical': '', 'vbd_eq_vbn': ''},
 'provide': {'v_compcl': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'v_against': '', 'vb_to_vbz': 'provides', 'vb_to_vbd': 'provided', 'vb_to_vbn': 'provided', 'vb_to_nn': 'provider', 'vb_to_vbg': 'providing', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'realise': {'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vb_to_jj': 'realistic', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'realize': {'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'vb_to_vbz': 'realizes', 'vb_to_vbd': 'realized', 'vb_to_vbn': 'realized', 'vb_to_nn': 'realisation', 'vb_to_jj': 'realistic', 'vb_to_vbg': 'realizing', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'reckon': {'v_compcl': '', 'v_to_vb': '', 'v_n': '', 'v_n_jj': '', 'vdo': '', 'v_on': '', 'v_with': '', 'vb_to_vbz': 'reckons', 'vb_to_vbd': 'reckoned', 'vb_to_vbn': 'reckoned', 'vb_to_vbg': 'reckoning', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'recognise': {'v_compcl': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'v_prprtcl_non': '', 'vt_typical': ''},
 'recognize': {'v_compcl': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'recognizes', 'vb_to_vbd': 'recognized', 'vb_to_vbn': 'recognized', 'vb_to_nn': 'recognition', 'vb_to_vbg': 'recognizing', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'vt_typical': ''},
 'recommend': {'v_compcl': '', 'v_vbg': '', 'v_n': '', 'v_n_n': '', 'v_n_to_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'recommends', 'vb_to_vbd': 'recommended', 'vb_to_vbn': 'recommended', 'vb_to_nn': 'recommendation', 'vb_to_vbg': 'recommending', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'reflect': {'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'vb_to_vbz': 'reflects', 'vb_to_vbd': 'reflected', 'vb_to_vbn': 'reflected', 'vb_to_rb': 'reflectively', 'vb_to_nn': 'reflection', 'vb_to_jj': 'reflective', 'vb_to_vbg': 'reflecting', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'relate': {'v_compcl': '', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'relates', 'vb_to_vbd': 'related', 'vb_to_vbn': 'related', 'vb_to_nn': 'relationship', 'vb_to_vbg': 'relating', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'remember': {'v_compcl': '', 'v_vbg': '', 'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'remembers', 'vb_to_vbd': 'remembered', 'vb_to_vbn': 'remembered', 'vb_to_vbg': 'remembering', 'vbd_eq_vbn': ''},
 'represent': {'v_compcl': '', 'v_n': '', 'v_n_n': '', 'v_n_to_n': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'represents', 'vb_to_vbd': 'represented', 'vb_to_vbn': 'represented', 'vb_to_rb': 'representively', 'vb_to_nn': 'representation', 'vb_to_jj': 'representative', 'vb_to_vbg': 'representing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'require': {'v_compcl': '', 'v_vbg': '', 'v_to_vb': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'requires', 'vb_to_vbd': 'required', 'vb_to_vbn': 'required', 'vb_to_nn': 'requirement', 'vb_to_vbg': 'requiring', 'vbd_eq_vbn': '', 'v_whcl_non': '', 'vt_typical': '', 'v_that_n_vb': ''},
 'reveal': {'v_compcl': '', 'v_to_n': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'reveals', 'vb_to_vbd': 'revealed', 'vb_to_vbn': 'revealed', 'vb_to_vbg': 'revealing', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'settle': {'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_with': '', 'v_for': '', 'vb_to_vbz': 'settles', 'vb_to_vbd': 'settled', 'vb_to_vbn': 'settled', 'vb_to_nn': 'settlement', 'vb_to_vbg': 'settling', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'specify': {'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'specifies', 'vb_to_vbd': 'specified', 'vb_to_vbn': 'specified', 'vb_to_nn': 'specifies', 'vb_to_jj': 'specifiable', 'vb_to_vbg': 'specifying', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vbg_non': ''},
 'submit': {'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'submits', 'vb_to_vbd': 'submitted', 'vb_to_vbn': 'submitted', 'vb_to_nn': 'submission', 'vb_to_vbg': 'submiting', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'suggest': {'v_compcl': '', 'v_vbg': '', 'v_n': '', 'v_n_n': '', 'v_n_to_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'suggests', 'vb_to_vbd': 'suggested', 'vb_to_vbn': 'suggested', 'vb_to_nn': 'suggestion', 'vb_to_jj': 'suggested', 'vb_to_vbg': 'suggesting', 'vbd_eq_vbn': '', 'vt_typical': '', 'v_that_n_vb': ''},
 'understand': {'v_compcl': '', 'v_vbg': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_to_vbz': 'understands', 'vb_to_vbd': 'understood', 'vb_to_vbn': 'understood', 'vb_to_vbg': 'understanding'},
 'undertake': {'v_compcl': '', 'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'undertakes', 'vb_to_vbd': 'undertook', 'vb_to_vbn': 'undertaken', 'vb_to_vbg': 'undertaking'},
 'misunderstand': {'v_compcl': '', 'v_n': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'confess': {'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_n': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'v_to': '', 'vb_to_nn': 'confession', 'vb_to_jj': 'confessed', 'vbd_eq_vbn': '', 'v_pass_non': ''},
 'contemplate': {'v_compcl': '', 'v_vbg': '', 'v_n': ''},
 'write': {'v_compcl': '', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_about': '', 'v_of': '', 'vb_to_vbz': 'writes', 'vb_to_vbd': 'wrote', 'vb_to_vbn': 'written', 'vb_to_vbg': 'writing'},
 'warn': {'v_compcl': '', 'v_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'warns', 'vb_to_vbd': 'warned', 'vb_to_vbn': 'warned', 'vb_to_vbg': 'warning', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_n_to_vb': ''},
 'verify': {'v_compcl': ''},
 'testify': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'suss': {'v_compcl': ''},
 'stipulate': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'speculate': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'signify': {'v_compcl': '', 'vb_to_rb': 'significantly', 'vb_to_nn': 'significance', 'vb_to_jj': 'significant', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vbg_non': ''},
 'satisfy': {'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'satisfies', 'vb_to_vbd': 'satisfied', 'vb_to_vbn': 'satisfied', 'vb_to_nn': 'satisfication', 'vb_to_jj': 'satisfactory', 'vb_to_vbg': 'satisfying', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'remind': {'v_compcl': '', 'v_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_n_of_n': '', 'vb_to_vbz': 'reminds', 'vb_to_vbd': 'reminded', 'vb_to_vbn': 'reminded', 'vb_to_nn': 'reminder', 'vb_to_vbg': 'reminding', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'vt_typical': ''},
 'rejoin': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'reiterate': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'recoup': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'reconstruct': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'recollect': {'v_compcl': '', 'v_vbg': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'recap': {'v_compcl': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'reassure': {'v_compcl': '', 'vbd_eq_vbn': ''},
 'reaffirm': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'prophesy': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'prognosticate': {'v_compcl': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'profess': {'v_compcl': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'proclaim': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'presuppose': {'v_compcl': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'prescribe': {'v_compcl': ''},
 'prefigure': {'v_compcl': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'pre-ordain': {'v_compcl': ''},
 'pray': {'v_compcl': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'v_to': '', 'vb_to_vbz': 'prays', 'vb_to_vbd': 'prayed', 'vb_to_vbn': 'prayed', 'vb_to_nn': 'prayer', 'vb_to_vbg': 'praying', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'ponder': {'v_compcl': '', 'v_vbg': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'persuade': {'v_compcl': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'persuades', 'vb_to_vbd': 'persuaded', 'vb_to_vbn': 'persuaded', 'vb_to_rb': 'persuasively', 'vb_to_nn': 'persuasion', 'vb_to_jj': 'persuasive', 'vb_to_vbg': 'persuading', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'ordain': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'notify': {'v_compcl': '', 'vbd_eq_vbn': ''},
 'misread': {'v_compcl': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'vbd_eq_vbn': ''},
 'misquote': {'v_compcl': '', 'vbd_eq_vbn': ''},
 'misjudge': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'misinterpret': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'mishear': {'v_compcl': ''},
 'misconstrue': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'miscalculate': {'v_compcl': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'iterate': {'v_compcl': ''},
 'intuit': {'v_compcl': ''},
 'interject': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'insure': {'v_compcl': '', 'vb_to_nn': 'insurance', 'vb_to_jj': 'insured', 'v_whcl_non': ''},
 'insinuate': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'inquire': {'v_compcl': '', 'vb_to_nn': 'inquiry', 'vb_to_jj': 'inquiring', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'inform': {'v_compcl': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_against': '', 'vb_to_vbz': 'informs', 'vb_to_vbd': 'informed', 'vb_to_vbn': 'informed', 'vb_to_nn': 'information', 'vb_to_jj': 'informing', 'vb_to_vbg': 'informing', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'infer': {'v_compcl': '', 'vb_to_nn': 'inference', 'vb_to_jj': 'inferred', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'hypothesize': {'v_compcl': '', 'vb_to_nn': 'hypothesis', 'vb_to_jj': 'hypothetical', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'hypothesise': {'v_compcl': ''},
 'glean': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'forewarn': {'v_compcl': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'foretell': {'v_compcl': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'foresee': {'v_compcl': '', 'vbg_non': '', 'vt_typical': ''},
 'foreordain': {'v_compcl': ''},
 'flatter': {'v_compcl': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'fantasize': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'fantasise': {'v_compcl': ''},
 'exclaim': {'v_compcl': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'envisage': {'v_compcl': '', 'v_vbg': '', 'vbd_eq_vbn': ''},
 'enquire': {'v_compcl': ''},
 'enjoin': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'enact': {'v_compcl': '', 'vbd_eq_vbn': ''},
 'emphasize': {'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'emphasizes', 'vb_to_vbd': 'emphasized', 'vb_to_vbn': 'emphasized', 'vb_to_nn': 'emphasis', 'vb_to_jj': 'emphatic', 'vb_to_vbg': 'emphasizing', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'emphasise': {'v_compcl': ''},
 'divulge': {'v_compcl': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'disclose': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'describe': {'v_compcl': '', 'v_to_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'describes', 'vb_to_vbd': 'described', 'vb_to_vbn': 'described', 'vb_to_nn': 'description', 'vb_to_jj': 'descriptive', 'vb_to_vbg': 'describing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'deprecate': {'v_compcl': '', 'v_vbg': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'depose': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'denote': {'v_compcl': '', 'vb_to_nn': 'denotation', 'vb_to_jj': 'denotive', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'deliberate': {'v_compcl': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'deem': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_whcl_non': '', 'vbg_non': ''},
 'deduce': {'v_compcl': '', 'vb_to_nn': 'deduction', 'vb_to_jj': 'deducible', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'decipher': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'convince': {'v_compcl': '', 'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'convinces', 'vb_to_vbd': 'convinced', 'vb_to_vbn': 'convinced', 'vb_to_vbg': 'convincing', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'convey': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vt_typical': ''},
 'contend': {'v_compcl': '', 'vb_to_nn': 'contention', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'construe': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'connote': {'v_compcl': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'confide': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'conceive': {'v_compcl': '', 'vb_to_nn': 'conception', 'vb_to_jj': 'conceivable', 'vbd_eq_vbn': '', 'vbg_non': ''},
 'concede': {'v_compcl': '', 'vbd_eq_vbn': ''},
 'comprehend': {'v_compcl': '', 'vb_to_nn': 'comprehension', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'certify': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'aver': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'assure': {'v_compcl': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_of': '', 'vb_to_vbz': 'assures', 'vb_to_vbd': 'assured', 'vb_to_vbn': 'assured', 'vb_to_nn': 'assurance', 'vb_to_jj': 'assured', 'vb_to_vbg': 'assuring', 'vbd_eq_vbn': ''},
 'asseverate': {'v_compcl': ''},
 'assert': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'ask': {'v_compcl': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_about': '', 'v_for': '', 'vb_to_vbz': 'asks', 'vb_to_vbd': 'asked', 'vb_to_vbn': 'asked', 'vb_to_vbg': 'asking', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'ascertain': {'v_compcl': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'apprehend': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'allege': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_whcl_non': ''},
 'affirm': {'v_compcl': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'adjudicate': {'v_compcl': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'adjudge': {'v_compcl': '', 'vbd_eq_vbn': ''},
 'avoid': {'v_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'avoids', 'vb_to_vbd': 'avoided', 'vb_to_vbn': 'avoided', 'vb_to_nn': 'avoidance', 'vb_to_jj': 'avoidable', 'vb_to_vbg': 'avoiding', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'continue': {'v_vbg': '', 'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_for': '', 'vb_to_vbz': 'continues', 'vb_to_vbd': 'continued', 'vb_to_vbn': 'continued', 'vb_to_nn': 'continuity', 'vb_to_jj': 'continuous', 'vb_to_vbg': 'continuing', 'vbd_eq_vbn': '', 'v_pass_non': '', 'vbe': ''},
 'devote': {'v_vbg': '', 'nsubjpass': '', 'vb_to_nn': 'devotion', 'vb_to_jj': 'devoted', 'v_n_to_vbg': '', 'v_n_to_n': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'enjoy': {'v_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'enjoys', 'vb_to_vbd': 'enjoyed', 'vb_to_vbn': 'enjoyed', 'vb_to_nn': 'enjoyment', 'vb_to_jj': 'enjoyable', 'vb_to_vbg': 'enjoying', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vt_typical': ''},
 'forgive': {'v_vbg': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'forgives', 'vb_to_vbd': 'forgave', 'vb_to_vbn': 'forgiven', 'vb_to_nn': 'forgiveness', 'vb_to_jj': 'forgiving', 'vb_to_vbg': 'forgiving', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'include': {'v_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'includes', 'vb_to_vbd': 'included', 'vb_to_vbn': 'included', 'vb_to_nn': 'inclusion', 'vb_to_jj': 'inclusive', 'vb_to_vbg': 'including', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'vt_typical': ''},
 'involve': {'v_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'involves', 'vb_to_vbd': 'involved', 'vb_to_vbn': 'involved', 'vb_to_nn': 'involvement', 'vb_to_jj': 'involved', 'vb_to_vbg': 'involving', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'justify': {'v_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'justifies', 'vb_to_vbd': 'justified', 'vb_to_vbn': 'justified', 'vb_to_nn': 'justification', 'vb_to_jj': 'justifiable', 'vb_to_vbg': 'justifying', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vbg_non': ''},
 'practise': {'v_vbg': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_for': '', 'vb_to_vbz': 'practises', 'vb_to_vbd': 'practised', 'vb_to_vbn': 'practised', 'vb_to_nn': 'practice', 'vb_to_vbg': 'practising', 'vbd_eq_vbn': ''},
 'prevent': {'v_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'prevents', 'vb_to_vbd': 'prevented', 'vb_to_vbn': 'prevented', 'vb_to_nn': 'prevention', 'vb_to_jj': 'preventable', 'v_n_vbg': '', 'vb_to_vbg': 'preventing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'quit': {'v_vbg': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'vb_to_vbz': 'quits', 'vb_to_vbd': 'quit,quitted', 'vb_to_vbn': 'quit,quitted', 'vb_to_vbg': 'quiting', 'v_compcl_non': '', 'v_pass_non': ''},
 'forbid': {'v_vbg': '', 'v_to_vbg': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'v_from': '', 'vt_typical': ''},
 'detest': {'v_vbg': '', 'v_to_vbg': '', 'v_n': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'postpone': {'v_vbg': '', 'v_to_vbg': '', 'v_n': '', 'v_for': '', 'v_from': '', 'v_to': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'resent': {'v_vbg': '', 'v_to_vbg': '', 'v_n': '', 'vbd_eq_vbn': '', 'vbg_non': ''},
 'commence': {'v_vbg': '', 'v_n': '', 'v_with': '', 'vb_to_nn': 'commencement', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vbg_non': ''},
 'defer': {'v_vbg': '', 'v_n': '', 'v_for': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'discourage': {'v_vbg': '', 'v_n': '', 'v_from': '', 'v_infcl_non': '', 'vt_typical': ''},
 'endure': {'v_vbg': '', 'v_to_vb': '', 'v_n': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'loathe': {'v_vbg': '', 'v_n': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'tolerate': {'v_vbg': '', 'v_n': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'omit': {'v_vbg': '', 'v_to_vb': '', 'v_n': '', 'v_from': '', 'vb_to_nn': 'omission', 'vbd_eq_vbn': '', 'vbg_non': ''},
 'prohibit': {'v_vbg': '', 'v_n': '', 'nsubjpass': '', 'v_from': '', 'vb_to_rb': 'prohibitively', 'vb_to_nn': 'prohibition', 'vb_to_jj': 'prohibitive', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'a\x1effect': {'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'a\x1effects', 'vb_to_vbd': 'a\x1effected', 'vb_to_vbn': 'a\x1effected', 'vb_to_vbg': 'a\x1effecting', 'vbd_eq_vbn': ''},
 'afford': {'v_to_vb': '', 'v_n': '', 'v_n_to_n': '', 'v_to': '', 'vb_to_nn': 'affordance', 'vb_to_jj': 'affordable', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vbg_non': '', 'vt_typical': ''},
 'appear': {'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vbe': '', 'vdo': '', 'v_at': '', 'vb_to_vbz': 'appears', 'vb_to_vbd': 'appeared', 'vb_to_vbn': 'appeared', 'vb_to_nn': 'appearance', 'vb_to_vbg': 'appearing', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_pass_non': ''},
 'apply': {'v_to_vb': '', 'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'applies', 'vb_to_vbd': 'applied', 'vb_to_vbn': 'applied', 'vb_to_rb': 'applicably', 'vb_to_nn': 'application', 'vb_to_jj': 'applicable', 'vb_to_vbg': 'applying', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'come': {'v_to_vb': '', 'v_to_vbg': '', 'v_to_n': '', 'vbe': '', 'vdo': '', 'vb_eq_vbn': '', 'v_in': '', 'v_about': '', 'v_to': '', 'vb_to_vbz': 'comes', 'vb_to_vbd': 'came', 'vb_to_nn': 'coming', 'vb_to_jj': 'coming', 'vbn_to_vbg': 'coming', 'vbn_to_vbd': 'came', 'vb_to_vbg': 'coming', 'vi_typical': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'compete': {'v_to_vb': '', 'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'competes', 'vb_to_vbd': 'competed', 'vb_to_vbn': 'competed', 'vb_to_nn': 'competition', 'vb_to_jj': 'competing', 'vb_to_vbg': 'competing', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'deserve': {'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'deserves', 'vb_to_vbd': 'deserved', 'vb_to_vbn': 'deserved', 'v_vbg': '', 'vb_to_vbg': 'deserving', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'engage': {'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_with': '', 'vb_to_vbz': 'engages', 'vb_to_vbd': 'engaged', 'vb_to_vbn': 'engaged', 'vb_to_vbg': 'engaging', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'happen': {'v_to_vb': '', 'v_to_vbg': '', 'v_to_n': '', 'vdo': '', 'v_on': '', 'v_to': '', 'vb_to_vbz': 'happens', 'vb_to_vbd': 'happened', 'vb_to_vbn': 'happened', 'vb_to_vbg': 'happening', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'hesitate': {'v_to_vb': '', 'v_to_vbg': '', 'vdo': '', 'v_at': '', 'v_about': '', 'vb_to_vbz': 'hesitates', 'vb_to_vbd': 'hesitated', 'vb_to_vbn': 'hesitated', 'vb_to_nn': 'hesitation', 'vb_to_jj': 'hesitating', 'vb_to_vbg': 'hesitating', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'manage': {'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_with': '', 'v_to': '', 'vb_to_vbz': 'manages', 'vb_to_vbd': 'managed', 'vb_to_vbn': 'managed', 'vb_to_nn': 'management', 'vb_to_jj': 'managing', 'vb_to_vbg': 'managing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'operate': {'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_at': '', 'v_in': '', 'v_from': '', 'vb_to_vbz': 'operates', 'vb_to_vbd': 'operated', 'vb_to_vbn': 'operated', 'vb_to_nn': 'operation', 'vb_to_jj': 'operational', 'vb_to_vbg': 'operating', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'prepare': {'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'prepares', 'vb_to_vbd': 'prepared', 'vb_to_vbn': 'prepared', 'vb_to_nn': 'preparation', 'vb_to_vbg': 'preparing', 'vt_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'proceed': {'v_to_vb': '', 'v_to_vbg': '', 'vdo': '', 'v_with': '', 'v_against': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'proceeds', 'vb_to_vbd': 'proceded', 'vb_to_vbn': 'proceded', 'vb_to_rb': 'procedurally', 'vb_to_nn': 'procedure', 'vb_to_jj': 'procedural', 'vb_to_vbg': 'proceeding', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'remain': {'v_to_vb': '', 'v_to_vbg': '', 'vbe': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'remains', 'vb_to_vbd': 'remained', 'vb_to_vbn': 'remained', 'vb_to_nn': 'remainder', 'vb_to_vbg': 'remaining', 'vi_typical': '', 'vbd_eq_vbn': '', 'vbg_non': '', 'v_pass_non': ''},
 'seek': {'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'seeks', 'vb_to_vbd': 'sought', 'vb_to_vbn': 'sought', 'vb_to_vbg': 'seeking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'seem': {'v_to_vb': '', 'v_to_vbg': '', 'nsubjpass': '', 'vbe': '', 'vdo': '', 'vb_to_vbz': 'seems', 'vb_to_vbd': 'seemed', 'vb_to_vbn': 'seemed', 'vb_to_vbg': 'seeming', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'send': {'v_to_vb': '', 'v_n': '', 'v_n_to_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_for': '', 'vb_to_vbz': 'sends', 'vb_to_vbd': 'sent', 'vb_to_vbn': 'sent', 'v_n_vbg': '', 'vb_to_vbg': 'sending', 'v_whcl_non': ''},
 'tend': {'v_to_vb': '', 'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'tends', 'vb_to_vbd': 'tended', 'vb_to_vbn': 'tended', 'vb_to_nn': 'tendency', 'vb_to_vbg': 'tending', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'threaten': {'v_to_vb': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'threatens', 'vb_to_vbd': 'threatened', 'vb_to_vbn': 'threatened', 'vb_to_nn': 'threat', 'vb_to_jj': 'threatened', 'vb_to_vbg': 'threatening', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'long': {'v_to_vb': '', 'v_to_vbg': '', 'v_for': '', 'vbd_eq_vbn': '', 'jj_to_jjr': 'longer', 'jj_to_jjs': 'longest', 'rb_to_rbr': 'longer', 'rb_to_rbs': 'longest'},
 'endeavour': {'v_to_vb': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'advertise': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'v_for': '', 'vb_to_jj': 'advertising', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'apologize': {'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'apologizes', 'vb_to_vbd': 'apologized', 'vb_to_vbn': 'apologized', 'vb_to_rb': 'apologetically', 'vb_to_nn': 'apology', 'vb_to_jj': 'apologetical', 'vb_to_vbg': 'apologizing', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'approve': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_of': '', 'vb_to_vbz': 'approves', 'vb_to_vbd': 'approved', 'vb_to_vbn': 'approved', 'vb_to_nn': 'approval', 'vb_to_jj': 'approving', 'vb_to_vbg': 'approving', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'attend': {'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'attends', 'vb_to_vbd': 'attended', 'vb_to_vbn': 'attended', 'vb_to_nn': 'attendance', 'vb_to_jj': 'attendant', 'vb_to_vbg': 'attending', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'behave': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'behaves', 'vb_to_vbd': 'behaved', 'vb_to_vbn': 'behaved', 'vb_to_nn': 'behaviour', 'vb_to_vbg': 'behaving', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'belong': {'v_to_vbg': '', 'v_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_to': '', 'vb_to_vbz': 'belongs', 'vb_to_vbd': 'belonged', 'vb_to_vbn': 'belonged', 'vb_to_vbg': 'belonging', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bleed': {'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'v_from': '', 'vbd_eq_vbn': ''},
 'breathe': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'breathes', 'vb_to_vbd': 'breathed', 'vb_to_vbn': 'breathed', 'vb_to_nn': 'breath', 'vb_to_jj': 'breathing', 'vb_to_vbg': 'breathing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'communicate': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_to': '', 'vb_to_vbz': 'communicates', 'vb_to_vbd': 'communicated', 'vb_to_vbn': 'communicated', 'vb_to_nn': 'communication', 'vb_to_jj': 'communicative', 'vb_to_vbg': 'communicating', 'vbd_eq_vbn': ''},
 'connect': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_to': '', 'vb_to_vbz': 'connects', 'vb_to_vbd': 'connected', 'vb_to_vbn': 'connected', 'vb_to_nn': 'connection', 'vb_to_jj': 'connected', 'vb_to_vbg': 'connecting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'consult': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_about': '', 'vb_to_vbz': 'consults', 'vb_to_vbd': 'consulted', 'vb_to_vbn': 'consulted', 'vb_to_nn': 'consultation', 'vb_to_jj': 'consultative', 'vb_to_vbg': 'consulting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'develop': {'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'develops', 'vb_to_vbd': 'developed', 'vb_to_vbn': 'developed', 'vb_to_nn': 'development', 'vb_to_jj': 'developed', 'vb_to_vbg': 'developing', 'vbd_eq_vbn': ''},
 'disagree': {'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_with': '', 'v_about': '', 'vb_to_vbz': 'disagrees', 'vb_to_vbd': 'disagreed', 'vb_to_vbn': 'disagreed', 'vb_to_vbg': 'disagreing', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'vi_typical': ''},
 'distinguish': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'distinguishes', 'vb_to_vbd': 'distinguished', 'vb_to_vbn': 'distinguished', 'vb_to_vbg': 'distinguishing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'emerge': {'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'emerges', 'vb_to_vbd': 'emerged', 'vb_to_vbn': 'emerged', 'vb_to_nn': 'emergence', 'vb_to_jj': 'emergent', 'vb_to_vbg': 'emerging', 'vbd_eq_vbn': '', 'v_pass_non': ''},
 'exist': {'v_to_vbg': '', 'vdo': '', 'vb_to_vbz': 'exists', 'vb_to_vbd': 'existed', 'vb_to_vbn': 'existed', 'vb_to_nn': 'existence', 'vb_to_jj': 'existent', 'vb_to_vbg': 'existing', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_pass_non': ''},
 'expand': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'expands', 'vb_to_vbd': 'expanded', 'vb_to_vbn': 'expanded', 'vb_to_nn': 'expansion', 'vb_to_jj': 'expansive', 'vb_to_vbg': 'expanding', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'explode': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'v_with': '', 'vb_to_rb': 'explosively', 'vb_to_nn': 'explosion', 'vb_to_jj': 'explosive', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'fi\x1dght': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_about': '', 'v_for': '', 'v_against': '', 'vb_to_vbz': 'fi\x1dghts', 'vb_to_vbd': 'fought', 'vb_to_vbn': 'fought', 'vb_to_vbg': 'fi\x1dghting', 'vbd_eq_vbn': ''},
 'fi\x1dsh': {'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_about': '', 'v_for': '', 'vb_to_vbz': 'fi\x1dshes', 'vb_to_vbd': 'fi\x1dshed', 'vb_to_vbn': 'fi\x1dshed', 'vb_to_vbg': 'fi\x1dshing', 'vbd_eq_vbn': ''},
 'interpret': {'v_to_vbg': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'interprets', 'vb_to_vbd': 'interpreted', 'vb_to_vbn': 'interpreted', 'vb_to_nn': 'interpretation', 'vb_to_jj': 'interpretive', 'vb_to_vbg': 'interpreting', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'invest': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'invests', 'vb_to_vbd': 'invested', 'vb_to_vbn': 'invested', 'vb_to_nn': 'investment', 'vb_to_vbg': 'investing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'locate': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'locates', 'vb_to_vbd': 'located', 'vb_to_vbn': 'located', 'vb_to_nn': 'location', 'vb_to_vbg': 'locating', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'negotiate': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_with': '', 'v_for': '', 'vb_to_vbz': 'negotiates', 'vb_to_vbd': 'negotiated', 'vb_to_vbn': 'negotiated', 'vb_to_vbg': 'negotiating', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'occur': {'v_to_vbg': '', 'v_to_n': '', 'vdo': '', 'v_in': '', 'v_to': '', 'vb_to_vbz': 'occurs', 'vb_to_vbd': 'occured', 'vb_to_vbn': 'occured', 'vb_to_nn': 'occurrence', 'vb_to_jj': 'occurent', 'vb_to_vbg': 'occuring', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'owe': {'v_to_vbg': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'owes', 'vb_to_vbd': 'owed', 'vb_to_vbn': 'owed', 'vb_to_vbg': 'owing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'participate': {'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'participates', 'vb_to_vbd': 'participated', 'vb_to_vbn': 'participated', 'vb_to_nn': 'participation', 'vb_to_jj': 'participatory', 'vb_to_vbg': 'participating', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': '', 'vi_typical': ''},
 'perform': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'performs', 'vb_to_vbd': 'performed', 'vb_to_vbn': 'performed', 'vb_to_vbg': 'performing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'pour': {'v_to_vbg': '', 'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'pours', 'vb_to_vbd': 'poured', 'vb_to_vbn': 'poured', 'vb_to_vbg': 'pouring', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'qualify': {'v_to_vbg': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'qualifies', 'vb_to_vbd': 'qualified', 'vb_to_vbn': 'qualified', 'vb_to_nn': 'qualification', 'vb_to_vbg': 'qualifying', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'react': {'v_to_vbg': '', 'v_to_n': '', 'vdo': '', 'v_on': '', 'v_with': '', 'v_against': '', 'v_to': '', 'vb_to_vbz': 'reacts', 'vb_to_vbd': 'reacted', 'vb_to_vbn': 'reacted', 'vb_to_vbg': 'reacting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': '', 'vi_typical': ''},
 'recite': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'recover': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'recovers', 'vb_to_vbd': 'recovered', 'vb_to_vbn': 'recovered', 'vb_to_nn': 'recovery', 'vb_to_jj': 'recoverable', 'vb_to_vbg': 'recovering', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'refer': {'v_to_vbg': '', 'v_to_n': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'refers', 'vb_to_vbd': 'referred', 'vb_to_vbn': 'referred', 'vb_to_nn': 'reference', 'vb_to_vbg': 'refering', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'relax': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'relaxes', 'vb_to_vbd': 'relaxed', 'vb_to_vbn': 'relaxed', 'vb_to_nn': 'relaxation', 'vb_to_vbg': 'relaxing', 'vbd_eq_vbn': ''},
 'rely': {'v_to_vbg': '', 'vdo': '', 'v_on': '', 'vb_to_vbz': 'relies', 'vb_to_vbd': 'relied', 'vb_to_vbn': 'relied', 'vb_to_rb': 'reliably', 'vb_to_nn': 'reliability', 'vb_to_jj': 'reliable', 'vb_to_vbg': 'relying', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vi_typical': ''},
 'resign': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'resigns', 'vb_to_vbd': 'resigned', 'vb_to_vbn': 'resigned', 'vb_to_vbg': 'resigning', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'respond': {'v_to_vbg': '', 'v_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_to': '', 'vb_to_vbz': 'responds', 'vb_to_vbd': 'responded', 'vb_to_vbn': 'responded', 'vb_to_nn': 'response', 'vb_to_jj': 'respondent', 'vb_to_vbg': 'responding', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'retire': {'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'retires', 'vb_to_vbd': 'retired', 'vb_to_vbn': 'retired', 'vb_to_nn': 'retirement', 'vb_to_vbg': 'retiring', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'run': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vbe': '', 'vdo': '', 'vb_eq_vbn': '', 'v_on': '', 'v_in': '', 'v_with': '', 'v_for': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'runs', 'vb_to_vbd': 'runned', 'vb_to_vbn': 'runned', 'vb_to_nn': 'runner', 'vb_to_vbg': 'runing', 'vi_typical': '', 'vbd_eq_vbn': ''},
 'sew': {'v_to_vbg': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'sews', 'vb_to_vbd': 'sewed', 'vb_to_vbn': 'sewn', 'vb_to_vbg': 'sewing', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'sit': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_on': '', 'v_in': '', 'vb_to_vbz': 'sits', 'vb_to_vbd': 'sat', 'vb_to_vbn': 'sat', 'vb_to_nn': 'sitting', 'vb_to_jj': 'sitting', 'vb_to_vbg': 'sitting', 'vi_typical': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'speak': {'v_to_vbg': '', 'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'v_for': '', 'vb_to_vbz': 'speaks', 'vb_to_vbd': 'spoke', 'vb_to_vbn': 'spoken', 'vb_to_nn': 'speaker', 'vb_to_jj': 'speaking', 'vb_to_vbg': 'speaking', 'v_prprtcl_non': '', 'v_to': ''},
 'starve': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'starves', 'vb_to_vbd': 'starved', 'vb_to_vbn': 'starved', 'vb_to_vbg': 'starving', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'succeed': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'succeeds', 'vb_to_vbd': 'succeeded', 'vb_to_vbn': 'succeeded', 'vb_to_rb': 'successfully', 'vb_to_nn': 'success', 'vb_to_jj': 'succeeding', 'vb_to_vbg': 'succeeding', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'survive': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_from': '', 'vb_to_vbz': 'survives', 'vb_to_vbd': 'survived', 'vb_to_vbn': 'survived', 'vb_to_nn': 'survival', 'vb_to_jj': 'survived', 'vb_to_vbg': 'surviving', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'swap': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'swaps', 'vb_to_vbd': 'swapped', 'vb_to_vbn': 'swapped', 'vb_to_vbg': 'swapping', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'translate': {'v_to_vbg': '', 'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'v_from': '', 'vb_to_vbz': 'translates', 'vb_to_vbd': 'translated', 'vb_to_vbn': 'translated', 'vb_to_vbg': 'translating', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'wander': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_about': '', 'v_from': '', 'vb_to_vbz': 'wanders', 'vb_to_vbd': 'wandered', 'vb_to_vbn': 'wandered', 'vb_to_vbg': 'wandering', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'withdraw': {'v_to_vbg': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'withdraws', 'vb_to_vbd': 'withdrew', 'vb_to_vbn': 'withdrawn', 'vb_to_vbg': 'withdrawing', 'v_compcl_non': ''},
 'adjust': {'v_to_n': '', 'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'v_to': '', 'vb_to_vbz': 'adjusts', 'vb_to_vbd': 'adjusted', 'vb_to_vbn': 'adjusted', 'vb_to_rb': 'adjustable', 'vb_to_nn': 'adjustment', 'vb_to_jj': 'adjusted', 'vb_to_vbg': 'adjusting', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'absorb': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'absorbs', 'vb_to_vbd': 'absorbed', 'vb_to_vbn': 'absorbed', 'vb_to_vbg': 'absorbing', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vt_typical': ''},
 'accompany': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'accompanies', 'vb_to_vbd': 'accompanied', 'vb_to_vbn': 'accompanied', 'vb_to_nn': 'accompaniment', 'vb_to_vbg': 'accompanying', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'accuse': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_of': '', 'vb_to_vbz': 'accuses', 'vb_to_vbd': 'accused', 'vb_to_vbn': 'accused', 'vb_to_nn': 'accusation', 'vb_to_vbg': 'accusing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'achieve': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'achieves', 'vb_to_vbd': 'achieved', 'vb_to_vbn': 'achieved', 'vb_to_nn': 'achievement', 'vb_to_jj': 'achievable', 'vb_to_vbg': 'achieving', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vt_typical': ''},
 'acquire': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'acquires', 'vb_to_vbd': 'acquired', 'vb_to_vbn': 'acquired', 'vb_to_nn': 'acquisition', 'vb_to_jj': 'acquisitive', 'vb_to_vbg': 'acquiring', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'adapt': {'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'adapts', 'vb_to_vbd': 'adapted', 'vb_to_vbn': 'adapted', 'vb_to_nn': 'adaptation', 'vb_to_jj': 'adaptable', 'vb_to_vbg': 'adapting', 'v_to_vbg': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'admire': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_about': '', 'v_for': '', 'vb_to_vbz': 'admires', 'vb_to_vbd': 'admired', 'vb_to_vbn': 'admired', 'vb_to_nn': 'admiration', 'vb_to_jj': 'admirable', 'vb_to_vbg': 'admiring', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'adopt': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'adopts', 'vb_to_vbd': 'adopted', 'vb_to_vbn': 'adopted', 'vb_to_nn': 'adoption', 'vb_to_jj': 'adoptive', 'vb_to_vbg': 'adopting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'alter': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'alters', 'vb_to_vbd': 'altered', 'vb_to_vbn': 'altered', 'vb_to_rb': 'alterably', 'vb_to_nn': 'alteration', 'vb_to_jj': 'alterable', 'vb_to_vbg': 'altering', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'amaze': {'v_n': '', 'nsubjpass': '', 'v_prprtcl_non': '', 'vt_typical': ''},
 'analyse': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'analyses', 'vb_to_vbd': 'analysed', 'vb_to_vbn': 'analysed', 'vb_to_nn': 'analysis', 'vb_to_jj': 'analytic', 'vb_to_vbg': 'analysing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'appoint': {'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'appoints', 'vb_to_vbd': 'appointed', 'vb_to_vbn': 'appointed', 'vb_to_nn': 'appointment', 'vb_to_jj': 'appointive', 'vb_to_vbg': 'appointing', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'assess': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'vb_to_vbz': 'assesses', 'vb_to_vbd': 'assessed', 'vb_to_vbn': 'assessed', 'vb_to_nn': 'assessment', 'vb_to_jj': 'assessable', 'vb_to_vbg': 'assessing', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'attach': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'attaches', 'vb_to_vbd': 'attached', 'vb_to_vbn': 'attached', 'vb_to_nn': 'attachment', 'vb_to_jj': 'attaching', 'vb_to_vbg': 'attaching', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'attract': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'attracts', 'vb_to_vbd': 'attracted', 'vb_to_vbn': 'attracted', 'vb_to_rb': 'attractively', 'vb_to_nn': 'attraction', 'vb_to_jj': 'attractive', 'vb_to_vbg': 'attracting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'become': {'v_n': '', 'nsubjpass': '', 'vbe': '', 'vdo': '', 'vb_eq_vbn': '', 'vb_to_vbz': 'becomes', 'vb_to_vbd': 'became', 'vb_to_nn': 'becoming', 'vb_to_jj': 'becoming', 'vbn_to_vbd': 'became', 'vb_to_vbg': 'becoming', 'vbn_to_vbg': 'becoming', 'vi_typical': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_pass_non': '', 'vbd_eq_vbn': ''},
 'bring': {'v_n': '', 'v_n_to_vb': '', 'v_n_to_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'v_on': '', 'v_in': '', 'v_about': '', 'vb_to_vbz': 'brings', 'vb_to_vbd': 'brought', 'vb_to_vbn': 'brought', 'v_n_vbg': '', 'vb_to_vbg': 'bringing', 'vt_typical': '', 'v_compcl_non': '', 'v_sb_n': ''},
 'cancel': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'cancels', 'vb_to_vbd': 'canceled', 'vb_to_vbn': 'canceled', 'vb_to_vbg': 'canceling', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'celebrate': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'celebrates', 'vb_to_vbd': 'celebrated', 'vb_to_vbn': 'celebrated', 'vb_to_vbg': 'celebrating', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'commit': {'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'commits', 'vb_to_vbd': 'commited', 'vb_to_vbn': 'commited', 'vb_to_nn': 'commitment', 'vb_to_jj': 'committed', 'vb_to_vbg': 'commiting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'comprise': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_of': '', 'vb_to_vbz': 'comprises', 'vb_to_vbd': 'comprised', 'vb_to_vbn': 'comprised', 'vb_to_nn': 'comprisal', 'vb_to_vbg': 'comprising', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'con\x1dfirm': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'con\x1dfirms', 'vb_to_vbd': 'con\x1dfirmed', 'vb_to_vbn': 'con\x1dfirmed', 'vb_to_vbg': 'con\x1dfirming', 'vbd_eq_vbn': ''},
 'confuse': {'v_n': '', 'nsubjpass': '', 'v_with': '', 'vb_to_nn': 'confusion', 'vb_to_jj': 'confusing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'constitute': {'v_n': '', 'v_n_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'constitutes', 'vb_to_vbd': 'constituted', 'vb_to_vbn': 'constituted', 'vb_to_nn': 'constitution', 'vb_to_jj': 'constitutive', 'vb_to_vbg': 'constituting', 'vbd_eq_vbn': '', 'vbg_non': ''},
 'contain': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'contains', 'vb_to_vbd': 'contained', 'vb_to_vbn': 'contained', 'vb_to_nn': 'containing', 'vb_to_jj': 'containing', 'vb_to_vbg': 'containing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'create': {'v_n': '', 'v_n_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'creates', 'vb_to_vbd': 'created', 'vb_to_vbn': 'created', 'vb_to_rb': 'creatively', 'vb_to_nn': 'creation', 'vb_to_jj': 'creative', 'vb_to_vbg': 'creating', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'criticize': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'criticizes', 'vb_to_vbd': 'criticized', 'vb_to_vbn': 'criticized', 'vb_to_vbg': 'criticizing', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'decorate': {'v_n': '', 'nsubjpass': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'defend': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_against': '', 'vb_to_vbz': 'defends', 'vb_to_vbd': 'defended', 'vb_to_vbn': 'defended', 'vb_to_nn': 'defence', 'vb_to_jj': 'defending', 'vb_to_vbg': 'defending', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'defi\x1dne': {'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'defi\x1dnes', 'vb_to_vbd': 'defi\x1dned', 'vb_to_vbn': 'defi\x1dned', 'vb_to_vbg': 'defi\x1dning', 'vbd_eq_vbn': ''},
 'destroy': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'destroys', 'vb_to_vbd': 'destroyed', 'vb_to_vbn': 'destroyed', 'vb_to_vbg': 'destroying', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'detect': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'detects', 'vb_to_vbd': 'detected', 'vb_to_vbn': 'detected', 'vb_to_nn': 'detection', 'vb_to_jj': 'detectable', 'vb_to_vbg': 'detecting', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'disappoint': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'disappoints', 'vb_to_vbd': 'disappointed', 'vb_to_vbn': 'disappointed', 'vb_to_nn': 'disappointment', 'vb_to_jj': 'disappointing', 'vb_to_vbg': 'disappointing', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'dismiss': {'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'dismisses', 'vb_to_vbd': 'dismissed', 'vb_to_vbn': 'dismissed', 'vb_to_nn': 'dismission', 'vb_to_jj': 'dismissive', 'vb_to_vbg': 'dismissing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'distribute': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'distributes', 'vb_to_vbd': 'distributed', 'vb_to_vbn': 'distributed', 'vb_to_nn': 'distribution', 'vb_to_jj': 'distributive', 'vb_to_vbg': 'distributing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'disturb': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'disturbs', 'vb_to_vbd': 'disturbed', 'vb_to_vbn': 'disturbed', 'vb_to_nn': 'disturbance', 'vb_to_jj': 'disturbing', 'vb_to_vbg': 'disturbing', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vt_typical': ''},
 'dominate': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'dominates', 'vb_to_vbd': 'dominated', 'vb_to_vbn': 'dominated', 'vb_to_nn': 'domination', 'vb_to_jj': 'dominant', 'vb_to_vbg': 'dominating', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'earn': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'earns', 'vb_to_vbd': 'earned', 'vb_to_vbn': 'earned', 'vb_to_vbg': 'earning', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'eat': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_at': '', 'v_in': '', 'vb_to_vbz': 'eats', 'vb_to_vbd': 'ate', 'vb_to_vbn': 'eaten', 'vb_to_nn': 'eating', 'vb_to_jj': 'eating', 'vb_to_vbg': 'eating', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'educate': {'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'v_at': '', 'vb_to_nn': 'education', 'vb_to_jj': 'educational', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'e\x1effect': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'e\x1effects', 'vb_to_vbd': 'e\x1effected', 'vb_to_vbn': 'e\x1effected', 'vb_to_vbg': 'e\x1effecting', 'vbd_eq_vbn': ''},
 'embarrass': {'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'enable': {'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'enables', 'vb_to_vbd': 'enabled', 'vb_to_vbn': 'enabled', 'vb_to_vbg': 'enabling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'encourage': {'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'vb_to_vbz': 'encourages', 'vb_to_vbd': 'encouraged', 'vb_to_vbn': 'encouraged', 'vb_to_nn': 'encouragement', 'vb_to_jj': 'encouraging', 'vb_to_vbg': 'encouraging', 'vbd_eq_vbn': '', 'v_whcl_non': '', 'vt_typical': ''},
 'enhance': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'enhances', 'vb_to_vbd': 'enhanced', 'vb_to_vbn': 'enhanced', 'vb_to_nn': 'enhancement', 'vb_to_jj': 'enhanced', 'vb_to_vbg': 'enhancing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'enter': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'enters', 'vb_to_vbd': 'entered', 'vb_to_vbn': 'entered', 'vb_to_nn': 'entrance', 'vb_to_jj': 'entered', 'vb_to_vbg': 'entering', 'vt_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'entitle': {'v_n': '', 'v_n_to_vb': '', 'v_n_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'entitles', 'vb_to_vbd': 'entitled', 'vb_to_vbn': 'entitled', 'vb_to_vbg': 'entitling', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'evaluate': {'v_n': '', 'nsubjpass': '', 'vb_to_nn': 'evaluation', 'vb_to_jj': 'evaluative', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'examine': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'examines', 'vb_to_vbd': 'examined', 'vb_to_vbn': 'examined', 'vb_to_nn': 'examination', 'vb_to_jj': 'examining', 'vb_to_vbg': 'examining', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'excite': {'v_n': '', 'v_n_to_vb': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vb_to_nn': 'excitement', 'vb_to_jj': 'excited', 'vt_typical': ''},
 'exclude': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'excludes', 'vb_to_vbd': 'excluded', 'vb_to_vbn': 'excluded', 'vb_to_nn': 'exclusion', 'vb_to_jj': 'exclusive', 'vb_to_vbg': 'excluding', 'vbd_eq_vbn': ''},
 'explore': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_for': '', 'vb_to_vbz': 'explores', 'vb_to_vbd': 'explored', 'vb_to_vbn': 'explored', 'vb_to_nn': 'exploration', 'vb_to_jj': 'exploratory', 'vb_to_vbg': 'exploring', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'extend': {'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'v_to': '', 'vb_to_vbz': 'extends', 'vb_to_vbd': 'extended', 'vb_to_vbn': 'extended', 'vb_to_rb': 'extensively', 'vb_to_nn': 'extension', 'vb_to_jj': 'extensive', 'vb_to_vbg': 'extending', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'fetch': {'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'fetches', 'vb_to_vbd': 'fetched', 'vb_to_vbn': 'fetched', 'vb_to_vbg': 'fetching', 'vt_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'fi\x1deld': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'fi\x1delds', 'vb_to_vbd': 'fi\x1delded', 'vb_to_vbn': 'fi\x1delded', 'vb_to_vbg': 'fi\x1delding', 'vbd_eq_vbn': ''},
 'fi\x1dle': {'v_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_with': '', 'v_for': '', 'vb_to_vbz': 'fi\x1dles', 'vb_to_vbd': 'fi\x1dled', 'vb_to_vbn': 'fi\x1dled', 'vb_to_vbg': 'fi\x1dling', 'vbd_eq_vbn': ''},
 'fi\x1drm': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'fi\x1drms', 'vb_to_vbd': 'fi\x1drmed', 'vb_to_vbn': 'fi\x1drmed', 'vb_to_vbg': 'fi\x1drming', 'vbd_eq_vbn': ''},
 'fi\x1dx': {'v_n': '', 'v_n_to_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'fi\x1dxes', 'vb_to_vbd': 'fi\x1dxed', 'vb_to_vbn': 'fi\x1dxed', 'vb_to_vbg': 'fi\x1dxing', 'vbd_eq_vbn': ''},
 'found': {'v_n': '', 'nsubjpass': '', 'v_on': '', 'vb_to_nn': 'founding', 'vb_to_jj': 'founding', 'vbd_eq_vbn': '', 'vbg_non': '', 'vt_typical': ''},
 'frighten': {'v_n': '', 'nsubjpass': '', 'vb_to_jj': 'frightened', 'vb_to_vbn': 'frightened', 'v_prprtcl_non': '', 'vt_typical': ''},
 'generate': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'generates', 'vb_to_vbd': 'generated', 'vb_to_vbn': 'generated', 'vb_to_nn': 'generation', 'vb_to_jj': 'generative', 'vb_to_vbg': 'generating', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'identify': {'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'v_with': '', 'vb_to_vbz': 'identifies', 'vb_to_vbd': 'identified', 'vb_to_vbn': 'identified', 'vb_to_nn': 'identification', 'vb_to_jj': 'identifiable', 'vb_to_vbg': 'identifying', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'ignore': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'ignores', 'vb_to_vbd': 'ignored', 'vb_to_vbn': 'ignored', 'vb_to_nn': 'ignorance', 'vb_to_jj': 'ignorant', 'vb_to_vbg': 'ignoring', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vt_typical': ''},
 'illustrate': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'illustrates', 'vb_to_vbd': 'illustrated', 'vb_to_vbn': 'illustrated', 'vb_to_nn': 'illustration', 'vb_to_jj': 'illustrative', 'vb_to_vbg': 'illustrating', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'impose': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'vb_to_vbz': 'imposses', 'vb_to_vbd': 'imposed', 'vb_to_vbn': 'imposed', 'vb_to_nn': 'imposition', 'vb_to_jj': 'imposed', 'vb_to_vbg': 'imposing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'improve': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'v_in': '', 'vb_to_vbz': 'improves', 'vb_to_vbd': 'improved', 'vb_to_vbn': 'improved', 'vb_to_nn': 'improvement', 'vb_to_jj': 'improving', 'vb_to_vbg': 'improving', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'injure': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'injures', 'vb_to_vbd': 'injured', 'vb_to_vbn': 'injured', 'vb_to_nn': 'injury', 'vb_to_jj': 'injured', 'vb_to_vbg': 'injuring', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'vt_typical': ''},
 'inspect': {'v_n': '', 'nsubjpass': '', 'vb_to_nn': 'inspection', 'vb_to_jj': 'inspected', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'install': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'installs', 'vb_to_vbd': 'installed', 'vb_to_vbn': 'installed', 'vb_to_vbg': 'installing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'instruct': {'v_n': '', 'v_n_to_be_jj': '', 'nsubjpass': '', 'vb_to_nn': 'instruction', 'vb_to_jj': 'instructive', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'vt_typical': ''},
 'introduce': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'introduces', 'vb_to_vbd': 'introduced', 'vb_to_vbn': 'introduced', 'vb_to_rb': 'introductory', 'vb_to_nn': 'introduction', 'vb_to_vbg': 'introducing', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'invent': {'v_n': '', 'nsubjpass': '', 'vb_to_nn': 'invention', 'vb_to_jj': 'invented', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'obey': {'v_n': '', 'nsubjpass': '', 'vb_to_rb': 'obediently', 'vb_to_nn': 'obedience', 'vb_to_jj': 'obedient', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'occupy': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'occupies', 'vb_to_vbd': 'occupied', 'vb_to_vbn': 'occupied', 'vb_to_nn': 'occupation', 'vb_to_jj': 'occupantional', 'vb_to_vbg': 'occupying', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'oppose': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'opposes', 'vb_to_vbd': 'opposed', 'vb_to_vbn': 'opposed', 'vb_to_vbg': 'opposing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'organise': {'v_n': '', 'nsubjpass': ''},
 'organize': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'organizes', 'vb_to_vbd': 'organized', 'vb_to_vbn': 'organized', 'vb_to_nn': 'organisation', 'vb_to_jj': 'organisational', 'vb_to_vbg': 'organizing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'overcome': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_eq_vbn': '', 'vb_to_vbz': 'overcomes', 'vb_to_vbd': 'overcame', 'vbn_to_vbd': 'overcame', 'vb_to_vbg': 'overcoming', 'vbn_to_vbg': 'overcoming'},
 'pollute': {'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'possess': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'possesses', 'vb_to_vbd': 'possessed', 'vb_to_vbn': 'possessed', 'vb_to_nn': 'possession', 'vb_to_vbg': 'possessing', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'vbg_non': '', 'vt_typical': ''},
 'promote': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'promotes', 'vb_to_vbd': 'promoted', 'vb_to_vbn': 'promoted', 'vb_to_nn': 'promotion', 'vb_to_vbg': 'promoting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'protect': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'protects', 'vb_to_vbd': 'protected', 'vb_to_vbn': 'protected', 'vb_to_rb': 'protectively', 'vb_to_nn': 'protection', 'vb_to_jj': 'protective', 'vb_to_vbg': 'protecting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'publish': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'publishes', 'vb_to_vbd': 'published', 'vb_to_vbn': 'published', 'vb_to_nn': 'publisher', 'vb_to_vbg': 'publishing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'punish': {'v_n': '', 'nsubjpass': '', 'vb_to_nn': 'punishment', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'pursue': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'pursues', 'vb_to_vbd': 'pursued', 'vb_to_vbn': 'pursued', 'vb_to_nn': 'pursuit', 'vb_to_vbg': 'pursuing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'receive': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_to': '', 'vb_to_vbz': 'receives', 'vb_to_vbd': 'received', 'vb_to_vbn': 'received', 'vb_to_nn': 'reception', 'vb_to_vbg': 'receiving', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'recycle': {'v_n': '', 'nsubjpass': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'reduce': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'reduces', 'vb_to_vbd': 'reduced', 'vb_to_vbn': 'reduced', 'vb_to_nn': 'reduction', 'vb_to_vbg': 'reducing', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'reinforce': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'reinforces', 'vb_to_vbd': 'reinforced', 'vb_to_vbn': 'reinforced', 'vb_to_nn': 'reinforcement', 'vb_to_vbg': 'reinforcing', 'vbd_eq_vbn': ''},
 'relieve': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'relieves', 'vb_to_vbd': 'relieved', 'vb_to_vbn': 'relieved', 'vb_to_nn': 'relief', 'vb_to_vbg': 'relieving', 'vbd_eq_vbn': ''},
 'replace': {'v_n': '', 'v_n_n': '', 'v_n_jj': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'replaces', 'vb_to_vbd': 'replaced', 'vb_to_vbn': 'replaced', 'vb_to_nn': 'replacement', 'vb_to_jj': 'replaceable', 'vb_to_vbg': 'replacing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'restore': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'restores', 'vb_to_vbd': 'restored', 'vb_to_vbn': 'restored', 'vb_to_nn': 'restoration', 'vb_to_vbg': 'restoring', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'restrict': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'restricts', 'vb_to_vbd': 'restricted', 'vb_to_vbn': 'restricted', 'vb_to_rb': 'restrictively', 'vb_to_nn': 'restriction', 'vb_to_jj': 'restrictive', 'vb_to_vbg': 'restricting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'retain': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'retains', 'vb_to_vbd': 'retained', 'vb_to_vbn': 'retained', 'vb_to_nn': 'retainer', 'vb_to_vbg': 'retaining', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'retell': {'v_n': '', 'nsubjpass': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'vt_typical': ''},
 'rob': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'robs', 'vb_to_vbd': 'robbed', 'vb_to_vbn': 'robbed', 'vb_to_nn': 'robbery', 'vb_to_vbg': 'robbing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'seize': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'v_on': '', 'vb_to_vbz': 'seizes', 'vb_to_vbd': 'seized', 'vb_to_vbn': 'seized', 'vb_to_vbg': 'seizing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vt_typical': ''},
 'shut': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vbd_eq_vbn': '', 'vb_eq_vbn': '', 'vb_eq_vbd': '', 'vb_to_vbz': 'shuts', 'vb_to_vbd': 'shutted,shut', 'vb_to_vbn': 'shutted,shut', 'vb_to_vbg': 'shutting', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'simplify': {'v_n': '', 'nsubjpass': '', 'vb_to_rb': 'simply', 'vb_to_nn': 'simpleness', 'vb_to_jj': 'simple', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'solve': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'solves', 'vb_to_vbd': 'solved', 'vb_to_vbn': 'solved', 'vb_to_nn': 'solution', 'vb_to_jj': 'solved', 'vb_to_vbg': 'solving', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'strengthen': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'strengthens', 'vb_to_vbd': 'strengthened', 'vb_to_vbn': 'strengthened', 'vb_to_nn': 'strength', 'vb_to_vbg': 'strengthening', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'sustain': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'sustains', 'vb_to_vbd': 'sustained', 'vb_to_vbn': 'sustained', 'vb_to_nn': 'sustainability', 'vb_to_jj': 'sustained', 'vb_to_vbg': 'sustaining', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'transform': {'v_n': '', 'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'transforms', 'vb_to_vbd': 'transformed', 'vb_to_vbn': 'transformed', 'vb_to_rb': 'transformationally', 'vb_to_nn': 'transformat', 'vb_to_jj': 'transformational', 'vb_to_vbg': 'transforming', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'please': {'v_n': '', 'vb_to_vbz': 'pleases', 'vb_to_vbd': 'pleased', 'vb_to_vbn': 'pleased', 'v_vb': '', 'vb_to_vbg': 'pleasing', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'overlook': {'v_n': '', 'v_from': '', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vt_typical': ''},
 'borrow': {'nsubjpass': '', 'vdo': '', 'v_from': '', 'vb_to_vbz': 'borrows', 'vb_to_vbd': 'borrowed', 'vb_to_vbn': 'borrowed', 'vb_to_nn': 'borrowing', 'vb_to_jj': 'borrowed', 'vb_to_vbg': 'borrowing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'characterize': {'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'characterizes', 'vb_to_vbd': 'characterized', 'vb_to_vbn': 'characterized', 'vb_to_nn': 'character', 'vb_to_jj': 'characteristic', 'vb_to_vbg': 'characterizing', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'consist': {'nsubjpass': '', 'vdo': '', 'v_in': '', 'v_of': '', 'vb_to_vbz': 'consists', 'vb_to_vbd': 'consisted', 'vb_to_vbn': 'consisted', 'vb_to_nn': 'consistency', 'vb_to_jj': 'consistent', 'vb_to_vbg': 'consisting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'vi_typical': ''},
 'depend': {'nsubjpass': '', 'vdo': '', 'v_on': '', 'vb_to_vbz': 'depends', 'vb_to_vbd': 'depended', 'vb_to_vbn': 'depended', 'vb_to_nn': 'dependent', 'vb_to_jj': 'dependent', 'vb_to_vbg': 'depending', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'disappear': {'nsubjpass': '', 'vdo': '', 'vb_to_vbz': 'disappears', 'vb_to_vbd': 'disappeared', 'vb_to_vbn': 'disappeared', 'vb_to_vbg': 'disappearing', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'look at': {'v_vb': '', 'v_n_vb': '', 'v_n_vbg': ''},
 'look_at': {'v_vb': ''},
 'listen to': {'v_vb': '', 'v_n_vb': '', 'v_n_vbg': ''},
 'listen_to': {'v_vb': ''},
 'clain': {'v_to_vb': ''},
 'derserve': {'v_to_vb': ''},
 'strive': {'v_to_vb': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'advert': {'vb_to_vbz': 'adverts', 'vb_to_vbd': 'adverted', 'vb_to_vbn': 'adverted', 'vb_to_vbg': 'adverting', 'vbd_eq_vbn': ''},
 'a\x1efford': {'vb_to_vbz': 'a\x1effords', 'vb_to_vbd': 'a\x1efforded', 'vb_to_vbn': 'a\x1efforded', 'vb_to_vbg': 'a\x1effording', 'vbd_eq_vbn': ''},
 'benefi\x1dt': {'vb_to_vbz': 'benefi\x1dts', 'vb_to_vbd': 'benefi\x1dted', 'vb_to_vbn': 'benefi\x1dted', 'vb_to_vbg': 'benefi\x1dting', 'vbd_eq_vbn': ''},
 'di\x1effer': {'vb_to_vbz': 'di\x1effers', 'vb_to_vbd': 'di\x1effered', 'vb_to_vbn': 'di\x1effered', 'vb_to_vbg': 'di\x1effering', 'vbd_eq_vbn': ''},
 'fi\x1dll': {'vb_to_vbz': 'fi\x1dlls', 'vb_to_vbd': 'fi\x1dlled', 'vb_to_vbn': 'fi\x1dlled', 'vb_to_vbg': 'fi\x1dlling', 'vbd_eq_vbn': ''},
 'fi\x1dlm': {'vb_to_vbz': 'fi\x1dlms', 'vb_to_vbd': 'fi\x1dlmed', 'vb_to_vbn': 'fi\x1dlmed', 'vb_to_vbg': 'fi\x1dlming', 'vbd_eq_vbn': ''},
 'fi\x1dnd': {'vb_to_vbz': 'fi\x1dnds', 'vb_to_vbd': 'fi\x1dnded', 'vb_to_vbn': 'fi\x1dnded', 'vb_to_vbg': 'fi\x1dnding', 'vbd_eq_vbn': ''},
 '\x1dfinish': {'vb_to_vbz': '\x1dfinishes', 'vb_to_vbd': '\x1dfinished', 'vb_to_vbn': '\x1dfinished', 'vb_to_vbg': '\x1dfinishing', 'vbd_eq_vbn': ''},
 'fi\x1dre': {'vb_to_vbz': 'fi\x1dres', 'vb_to_vbd': 'fi\x1dred', 'vb_to_vbn': 'fi\x1dred', 'vb_to_vbg': 'fi\x1dring', 'vbd_eq_vbn': ''},
 'fi\x1dt': {'vb_to_vbz': 'fi\x1dts', 'vb_to_vbd': 'fi\x1dtted,fit', 'vb_to_vbn': 'fi\x1dtted,fit', 'vb_to_vbg': 'fi\x1dtting', 'vbd_eq_vbn': ''},
 'shuts': {'vbz_to_vb': 'shut'},
 'shoves': {'vbz_to_vb': 'shove'},
 'shines': {'vbz_to_vb': 'shine'},
 'shapes': {'vbz_to_vb': 'shape'},
 'sews': {'vbz_to_vb': 'sew'},
 'settles': {'vbz_to_vb': 'settle'},
 'sends': {'vbz_to_vb': 'send'},
 'sells': {'vbz_to_vb': 'sell'},
 'selects': {'vbz_to_vb': 'select'},
 'seizes': {'vbz_to_vb': 'seize'},
 'seems': {'vbz_to_vb': 'seem'},
 'seeks': {'vbz_to_vb': 'seek'},
 'sees': {'vbz_to_vb': 'see'},
 'secures': {'vbz_to_vb': 'secure'},
 'scales': {'vbz_to_vb': 'scale'},
 'satisfies': {'vbz_to_vb': 'satisfy'},
 'salts': {'vbz_to_vb': 'salt'},
 'rushes': {'vbz_to_vb': 'rush'},
 'runs': {'vbz_to_vb': 'run'},
 'ruins': {'vbz_to_vb': 'ruin'},
 'rubs': {'vbz_to_vb': 'rub'},
 'ropes': {'vbz_to_vb': 'rope'},
 'robs': {'vbz_to_vb': 'rob'},
 'risks': {'vbz_to_vb': 'risk'},
 'rises': {'vbz_to_vb': 'rise'},
 'reviews': {'vbz_to_vb': 'review'},
 'reveals': {'vbz_to_vb': 'reveal'},
 'retires': {'vbz_to_vb': 'retire'},
 'retains': {'vbz_to_vb': 'retain'},
 'results': {'vbz_to_vb': 'result'},
 'restricts': {'vbz_to_vb': 'restrict'},
 'restores': {'vbz_to_vb': 'restore'},
 'rests': {'vbz_to_vb': 'rest'},
 'responds': {'vbz_to_vb': 'respond'},
 'respects': {'vbz_to_vb': 'respect'},
 'resolves': {'vbz_to_vb': 'resolve'},
 'resists': {'vbz_to_vb': 'resist'},
 'resigns': {'vbz_to_vb': 'resign'},
 'rescues': {'vbz_to_vb': 'rescue'},
 'requires': {'vbz_to_vb': 'require'},
 'represents': {'vbz_to_vb': 'represent'},
 'replaces': {'vbz_to_vb': 'replace'},
 'reminds': {'vbz_to_vb': 'remind'},
 'remembers': {'vbz_to_vb': 'remember'},
 'remarks': {'vbz_to_vb': 'remark'},
 'relies': {'vbz_to_vb': 'rely'},
 'relieves': {'vbz_to_vb': 'relieve'},
 'relaxes': {'vbz_to_vb': 'relax'},
 'relates': {'vbz_to_vb': 'relate'},
 'reinforces': {'vbz_to_vb': 'reinforce'},
 'regrets': {'vbz_to_vb': 'regret'},
 'registers': {'vbz_to_vb': 'register'},
 'refuses': {'vbz_to_vb': 'refuse'},
 'reforms': {'vbz_to_vb': 'reform'},
 'reflects': {'vbz_to_vb': 'reflect'},
 'refers': {'vbz_to_vb': 'refer'},
 'reduces': {'vbz_to_vb': 'reduce'},
 'recovers': {'vbz_to_vb': 'recover'},
 'recommends': {'vbz_to_vb': 'recommend'},
 'recognizes': {'vbz_to_vb': 'recognize'},
 'reckons': {'vbz_to_vb': 'reckon'},
 'receives': {'vbz_to_vb': 'receive'},
 'realizes': {'vbz_to_vb': 'realize'},
 'reads': {'vbz_to_vb': 'read'},
 'reacts': {'vbz_to_vb': 'react'},
 'reaches': {'vbz_to_vb': 'reach'},
 'ranges': {'vbz_to_vb': 'range'},
 'rains': {'vbz_to_vb': 'rain', 'nns_to_nn': 'rain'},
 'quits': {'vbz_to_vb': 'quit'},
 'qualifies': {'vbz_to_vb': 'qualify'},
 'puts': {'vbz_to_vb': 'put'},
 'pushes': {'vbz_to_vb': 'push'},
 'pursues': {'vbz_to_vb': 'pursue'},
 'purchases': {'vbz_to_vb': 'purchase'},
 'pulls': {'vbz_to_vb': 'pull'},
 'publishes': {'vbz_to_vb': 'publish'},
 'provides': {'vbz_to_vb': 'provide'},
 'proves': {'vbz_to_vb': 'prove'},
 'protects': {'vbz_to_vb': 'protect'},
 'proposes': {'vbz_to_vb': 'propose'},
 'promotes': {'vbz_to_vb': 'promote'},
 'promises': {'vbz_to_vb': 'promise'},
 'produces': {'vbz_to_vb': 'produce'},
 'prevents': {'vbz_to_vb': 'prevent'},
 'pretends': {'vbz_to_vb': 'pretend'},
 'presumes': {'vbz_to_vb': 'presume'},
 'prepares': {'vbz_to_vb': 'prepare'},
 'prefers': {'vbz_to_vb': 'prefer'},
 'predicts': {'vbz_to_vb': 'predict'},
 'prays': {'vbz_to_vb': 'pray'},
 'practises': {'vbz_to_vb': 'practise'},
 'pours': {'vbz_to_vb': 'pour'},
 'possesses': {'vbz_to_vb': 'possess'},
 'pleases': {'vbz_to_vb': 'please'},
 'plays': {'vbz_to_vb': 'play'},
 'picks': {'vbz_to_vb': 'pick'},
 'persuades': {'vbz_to_vb': 'persuade'},
 'performs': {'vbz_to_vb': 'perform'},
 'perceives': {'vbz_to_vb': 'perceive'},
 'pays': {'vbz_to_vb': 'pay'},
 'participates': {'vbz_to_vb': 'participate'},
 'paints': {'vbz_to_vb': 'paint'},
 'owns': {'vbz_to_vb': 'own'},
 'owes': {'vbz_to_vb': 'owe'},
 'overcomes': {'vbz_to_vb': 'overcome'},
 'organizes': {'vbz_to_vb': 'organize'},
 'opposes': {'vbz_to_vb': 'oppose'},
 'operates': {'vbz_to_vb': 'operate'},
 'opens': {'vbz_to_vb': 'open'},
 'occurs': {'vbz_to_vb': 'occur'},
 'occupies': {'vbz_to_vb': 'occupy'},
 'obtains': {'vbz_to_vb': 'obtain'},
 'observes': {'vbz_to_vb': 'observe'},
 'nods': {'vbz_to_vb': 'nod'},
 'negotiates': {'vbz_to_vb': 'negotiate'},
 'needs': {'vbz_to_vb': 'need'},
 'mixes': {'vbz_to_vb': 'mix'},
 'misses': {'vbz_to_vb': 'miss'},
 'minds': {'vbz_to_vb': 'mind'},
 'mentions': {'vbz_to_vb': 'mention'},
 'meets': {'vbz_to_vb': 'meet'},
 'matters': {'vbz_to_vb': 'matter'},
 'marries': {'vbz_to_vb': 'marry'},
 'marches': {'vbz_to_vb': 'march'},
 'manages': {'vbz_to_vb': 'manage'},
 'maintains': {'vbz_to_vb': 'maintain'},
 'lowers': {'vbz_to_vb': 'lower'},
 'loses': {'vbz_to_vb': 'lose'},
 'looks': {'vbz_to_vb': 'look'},
 'locates': {'vbz_to_vb': 'locate'},
 'listens': {'vbz_to_vb': 'listen'},
 'lights': {'vbz_to_vb': 'light'},
 'licks': {'vbz_to_vb': 'lick'},
 'lets': {'vbz_to_vb': 'let'},
 'lends': {'vbz_to_vb': 'lend'},
 'learns': {'vbz_to_vb': 'learn'},
 'leans': {'vbz_to_vb': 'lean'},
 'leafs': {'vbz_to_vb': 'leaf'},
 'leads': {'vbz_to_vb': 'lead'},
 'lambs': {'vbz_to_vb': 'lamb'},
 'lacks': {'vbz_to_vb': 'lack'},
 'labours': {'vbz_to_vb': 'labour'},
 'knows': {'vbz_to_vb': 'know'},
 'kits': {'vbz_to_vb': 'kit'},
 'justifies': {'vbz_to_vb': 'justify'},
 'jams': {'vbz_to_vb': 'jam'},
 'involves': {'vbz_to_vb': 'involve'},
 'invites': {'vbz_to_vb': 'invite'},
 'investigates': {'vbz_to_vb': 'investigate'},
 'invests': {'vbz_to_vb': 'invest'},
 'introduces': {'vbz_to_vb': 'introduce'},
 'interprets': {'vbz_to_vb': 'interpret'},
 'intends': {'vbz_to_vb': 'intend'},
 'installs': {'vbz_to_vb': 'install'},
 'insists': {'vbz_to_vb': 'insist'},
 'inputs': {'vbz_to_vb': 'input'},
 'injures': {'vbz_to_vb': 'injure'},
 'informs': {'vbz_to_vb': 'inform'},
 'influences': {'vbz_to_vb': 'influence'},
 'indicates': {'vbz_to_vb': 'indicate'},
 'incorporates': {'vbz_to_vb': 'incorporate'},
 'includes': {'vbz_to_vb': 'include'},
 'improves': {'vbz_to_vb': 'improve'},
 'impresses': {'vbz_to_vb': 'impress'},
 'imposses': {'vbz_to_vb': 'impose'},
 'implies': {'vbz_to_vb': 'imply'},
 'impacts': {'vbz_to_vb': 'impact'},
 'imagines': {'vbz_to_vb': 'imagine'},
 'illustrates': {'vbz_to_vb': 'illustrate'},
 'ignores': {'vbz_to_vb': 'ignore'},
 'identifies': {'vbz_to_vb': 'identify'},
 'hurts': {'vbz_to_vb': 'hurt'},
 'hurries': {'vbz_to_vb': 'hurry'},
 'hopes': {'vbz_to_vb': 'hope'},
 'honours': {'vbz_to_vb': 'honour'},
 'holds': {'vbz_to_vb': 'hold'},
 'hires': {'vbz_to_vb': 'hire'},
 'hesitates': {'vbz_to_vb': 'hesitate'},
 'heats': {'vbz_to_vb': 'heat'},
 'hears': {'vbz_to_vb': 'hear'},
 'hates': {'vbz_to_vb': 'hate'},
 'harms': {'vbz_to_vb': 'harm'},
 'happens': {'vbz_to_vb': 'happen'},
 'hangs': {'vbz_to_vb': 'hang'},
 'grows': {'vbz_to_vb': 'grow'},
 'governs': {'vbz_to_vb': 'govern'},
 'goes': {'vbz_to_vb': 'go'},
 'glances': {'vbz_to_vb': 'glance'},
 'gives': {'vbz_to_vb': 'give'},
 'gets': {'vbz_to_vb': 'get'},
 'generates': {'vbz_to_vb': 'generate'},
 'gases': {'vbz_to_vb': 'gas'},
 'fusses': {'vbz_to_vb': 'fuss'},
 'fulls': {'vbz_to_vb': 'full'},
 'fuels': {'vbz_to_vb': 'fuel'},
 'frees': {'vbz_to_vb': 'free'},
 'forwards': {'vbz_to_vb': 'forward'},
 'forgives': {'vbz_to_vb': 'forgive'},
 'forgets': {'vbz_to_vb': 'forget'},
 'forces': {'vbz_to_vb': 'force'},
 'follows': {'vbz_to_vb': 'follow'},
 'flows': {'vbz_to_vb': 'flow'},
 'fleshes': {'vbz_to_vb': 'flesh'},
 'flavours': {'vbz_to_vb': 'flavour'},
 'fi\x1dxes': {'vbz_to_vb': 'fi\x1dx'},
 'fi\x1dts': {'vbz_to_vb': 'fi\x1dt'},
 'fi\x1dshes': {'vbz_to_vb': 'fi\x1dsh'},
 'fi\x1drms': {'vbz_to_vb': 'fi\x1drm'},
 'fi\x1dres': {'vbz_to_vb': 'fi\x1dre'},
 '\x1dfinishes': {'vbz_to_vb': '\x1dfinish'},
 'fi\x1dnds': {'vbz_to_vb': 'fi\x1dnd'},
 'fi\x1dlms': {'vbz_to_vb': 'fi\x1dlm'},
 'fi\x1dlls': {'vbz_to_vb': 'fi\x1dll'},
 'fi\x1dles': {'vbz_to_vb': 'fi\x1dle'},
 'fi\x1dgures': {'vbz_to_vb': 'fi\x1dgure'},
 'fi\x1dghts': {'vbz_to_vb': 'fi\x1dght'},
 'fi\x1delds': {'vbz_to_vb': 'fi\x1deld'},
 'fetches': {'vbz_to_vb': 'fetch'},
 'feels': {'vbz_to_vb': 'feel'},
 'feeds': {'vbz_to_vb': 'feed'},
 'fears': {'vbz_to_vb': 'fear'},
 'favours': {'vbz_to_vb': 'favour'},
 'fashions': {'vbz_to_vb': 'fashion'},
 'fails': {'vbz_to_vb': 'fail'},
 'extends': {'vbz_to_vb': 'extend'},
 'explores': {'vbz_to_vb': 'explore'},
 'explains': {'vbz_to_vb': 'explain'},
 'expects': {'vbz_to_vb': 'expect'},
 'expands': {'vbz_to_vb': 'expand'},
 'exists': {'vbz_to_vb': 'exist'},
 'excludes': {'vbz_to_vb': 'exclude'},
 'exchanges': {'vbz_to_vb': 'exchange'},
 'examines': {'vbz_to_vb': 'examine'},
 'establishes': {'vbz_to_vb': 'establish'},
 'escapes': {'vbz_to_vb': 'escape'},
 'entitles': {'vbz_to_vb': 'entitle'},
 'enters': {'vbz_to_vb': 'enter'},
 'ensures': {'vbz_to_vb': 'ensure'},
 'enjoys': {'vbz_to_vb': 'enjoy'},
 'enhances': {'vbz_to_vb': 'enhance'},
 'engages': {'vbz_to_vb': 'engage'},
 'encourages': {'vbz_to_vb': 'encourage'},
 'enables': {'vbz_to_vb': 'enable'},
 'empties': {'vbz_to_vb': 'empty'},
 'emploies': {'vbz_to_vb': 'employ'},
 'emphasizes': {'vbz_to_vb': 'emphasize'},
 'emerges': {'vbz_to_vb': 'emerge'},
 'elects': {'vbz_to_vb': 'elect'},
 'e\x1effects': {'vbz_to_vb': 'e\x1effect'},
 'eases': {'vbz_to_vb': 'ease'},
 'earths': {'vbz_to_vb': 'earth'},
 'earns': {'vbz_to_vb': 'earn'},
 'dusts': {'vbz_to_vb': 'dust'},
 'dulls': {'vbz_to_vb': 'dull'},
 'ducks': {'vbz_to_vb': 'duck'},
 'dries': {'vbz_to_vb': 'dry'},
 'drives': {'vbz_to_vb': 'drive'},
 'dresses': {'vbz_to_vb': 'dress'},
 'drags': {'vbz_to_vb': 'drag'},
 'dominates': {'vbz_to_vb': 'dominate'},
 'disturbs': {'vbz_to_vb': 'disturb'},
 'distributes': {'vbz_to_vb': 'distribute'},
 'distinguishes': {'vbz_to_vb': 'distinguish'},
 'disputes': {'vbz_to_vb': 'dispute'},
 'displaies': {'vbz_to_vb': 'display'},
 'dismisses': {'vbz_to_vb': 'dismiss'},
 'discusses': {'vbz_to_vb': 'discuss'},
 'discovers': {'vbz_to_vb': 'discover'},
 'disappoints': {'vbz_to_vb': 'disappoint'},
 'disappears': {'vbz_to_vb': 'disappear'},
 'disagrees': {'vbz_to_vb': 'disagree'},
 'dirties': {'vbz_to_vb': 'dirty'},
 'directs': {'vbz_to_vb': 'direct'},
 'di\x1effers': {'vbz_to_vb': 'di\x1effer'},
 'dies': {'vbz_to_vb': 'die'},
 'develops': {'vbz_to_vb': 'develop'},
 'determines': {'vbz_to_vb': 'determine'},
 'detects': {'vbz_to_vb': 'detect'},
 'destroys': {'vbz_to_vb': 'destroy'},
 'desires': {'vbz_to_vb': 'desire'},
 'deserves': {'vbz_to_vb': 'deserve'},
 'describes': {'vbz_to_vb': 'describe'},
 'derives': {'vbz_to_vb': 'derive'},
 'depends': {'vbz_to_vb': 'depend'},
 'denies': {'vbz_to_vb': 'deny'},
 'demonstrates': {'vbz_to_vb': 'demonstrate'},
 'delivers': {'vbz_to_vb': 'deliver'},
 'delays': {'vbz_to_vb': 'delay'},
 'defi\x1dnes': {'vbz_to_vb': 'defi\x1dne'},
 'defends': {'vbz_to_vb': 'defend'},
 'defeats': {'vbz_to_vb': 'defeat'},
 'declares': {'vbz_to_vb': 'declare'},
 'decides': {'vbz_to_vb': 'decide'},
 'deals': {'vbz_to_vb': 'deal'},
 'dares': {'vbz_to_vb': 'dare'},
 'crosses': {'vbz_to_vb': 'cross'},
 'criticizes': {'vbz_to_vb': 'criticize'},
 'creates': {'vbz_to_vb': 'create'},
 'cottons': {'vbz_to_vb': 'cotton'},
 'cools': {'vbz_to_vb': 'cool'},
 'convinces': {'vbz_to_vb': 'convince'},
 'contributes': {'vbz_to_vb': 'contribute'},
 'continues': {'vbz_to_vb': 'continue'},
 'contains': {'vbz_to_vb': 'contain'},
 'contacts': {'vbz_to_vb': 'contact'},
 'consults': {'vbz_to_vb': 'consult'},
 'constitutes': {'vbz_to_vb': 'constitute'},
 'consists': {'vbz_to_vb': 'consist'},
 'considers': {'vbz_to_vb': 'consider'},
 'consents': {'vbz_to_vb': 'consent'},
 'connects': {'vbz_to_vb': 'connect'},
 'con\x1dfirms': {'vbz_to_vb': 'con\x1dfirm'},
 'conducts': {'vbz_to_vb': 'conduct'},
 'concludes': {'vbz_to_vb': 'conclude'},
 'comprises': {'vbz_to_vb': 'comprise'},
 'complicateds': {'vbz_to_vb': 'complicated'},
 'completes': {'vbz_to_vb': 'complete'},
 'complains': {'vbz_to_vb': 'complain'},
 'competes': {'vbz_to_vb': 'compete'},
 'compares': {'vbz_to_vb': 'compare'},
 'communicates': {'vbz_to_vb': 'communicate'},
 'commits': {'vbz_to_vb': 'commit'},
 'comes': {'vbz_to_vb': 'come'},
 'collapses': {'vbz_to_vb': 'collapse'},
 'clears': {'vbz_to_vb': 'clear'},
 'chucks': {'vbz_to_vb': 'chuck'},
 'chops': {'vbz_to_vb': 'chop'},
 'chooses': {'vbz_to_vb': 'choose'},
 'checks': {'vbz_to_vb': 'check'},
 'characterizes': {'vbz_to_vb': 'characterize'},
 'changes': {'vbz_to_vb': 'change'},
 'celebrates': {'vbz_to_vb': 'celebrate'},
 'ceases': {'vbz_to_vb': 'cease'},
 'catches': {'vbz_to_vb': 'catch'},
 'cashes': {'vbz_to_vb': 'cash'},
 'cares': {'vbz_to_vb': 'care'},
 'captures': {'vbz_to_vb': 'capture'},
 'caps': {'vbz_to_vb': 'cap'},
 'cancels': {'vbz_to_vb': 'cancel'},
 'campaigns': {'vbz_to_vb': 'campaign'},
 'calms': {'vbz_to_vb': 'calm'},
 'calls': {'vbz_to_vb': 'call'},
 'calculates': {'vbz_to_vb': 'calculate'},
 'buys': {'vbz_to_vb': 'buy'},
 'butters': {'vbz_to_vb': 'butter'},
 'butchers': {'vbz_to_vb': 'butcher'},
 'buries': {'vbz_to_vb': 'bury'},
 'bursts': {'vbz_to_vb': 'burst'},
 'bumps': {'vbz_to_vb': 'bump'},
 'builds': {'vbz_to_vb': 'build'},
 'bugs': {'vbz_to_vb': 'bug'},
 'budgets': {'vbz_to_vb': 'budget'},
 'bucks': {'vbz_to_vb': 'buck'},
 'brings': {'vbz_to_vb': 'bring'},
 'breathes': {'vbz_to_vb': 'breathe'},
 'breasts': {'vbz_to_vb': 'breast'},
 'bounces': {'vbz_to_vb': 'bounce'},
 'bothers': {'vbz_to_vb': 'bother'},
 'borrows': {'vbz_to_vb': 'borrow'},
 'boilings': {'vbz_to_vb': 'boiling'},
 'boils': {'vbz_to_vb': 'boil'},
 'boards': {'vbz_to_vb': 'board'},
 'blows': {'vbz_to_vb': 'blow'},
 'bloods': {'vbz_to_vb': 'blood'},
 'blinds': {'vbz_to_vb': 'blind'},
 'blesses': {'vbz_to_vb': 'bless'},
 'blames': {'vbz_to_vb': 'blame'},
 'bids': {'vbz_to_vb': 'bid'},
 'bicycles': {'vbz_to_vb': 'bicycle'},
 'betters': {'vbz_to_vb': 'better'},
 'bets': {'vbz_to_vb': 'bet'},
 'benefi\x1dts': {'vbz_to_vb': 'benefi\x1dt'},
 'belongs': {'vbz_to_vb': 'belong'},
 'believes': {'vbz_to_vb': 'believe'},
 'behaves': {'vbz_to_vb': 'behave'},
 'begins': {'vbz_to_vb': 'begin'},
 'becomes': {'vbz_to_vb': 'become'},
 'bans': {'vbz_to_vb': 'ban'},
 'bakes': {'vbz_to_vb': 'bake'},
 'awakes': {'vbz_to_vb': 'awake'},
 'avoids': {'vbz_to_vb': 'avoid'},
 'attracts': {'vbz_to_vb': 'attract'},
 'attends': {'vbz_to_vb': 'attend'},
 'attacks': {'vbz_to_vb': 'attack'},
 'attaches': {'vbz_to_vb': 'attach'},
 'assures': {'vbz_to_vb': 'assure'},
 'assumes': {'vbz_to_vb': 'assume'},
 'associates': {'vbz_to_vb': 'associate'},
 'assists': {'vbz_to_vb': 'assist'},
 'assesses': {'vbz_to_vb': 'assess'},
 'asks': {'vbz_to_vb': 'ask'},
 'articles': {'vbz_to_vb': 'article'},
 'arrives': {'vbz_to_vb': 'arrive'},
 'arrests': {'vbz_to_vb': 'arrest'},
 'arranges': {'vbz_to_vb': 'arrange'},
 'arises': {'vbz_to_vb': 'arise'},
 'argues': {'vbz_to_vb': 'argue'},
 'approximates': {'vbz_to_vb': 'approximate'},
 'approves': {'vbz_to_vb': 'approve'},
 'appropriates': {'vbz_to_vb': 'appropriate'},
 'appreciates': {'vbz_to_vb': 'appreciate'},
 'appoints': {'vbz_to_vb': 'appoint'},
 'applies': {'vbz_to_vb': 'apply'},
 'appears': {'vbz_to_vb': 'appear'},
 'appeals': {'vbz_to_vb': 'appeal'},
 'apologizes': {'vbz_to_vb': 'apologize'},
 'anticipates': {'vbz_to_vb': 'anticipate'},
 'annoys': {'vbz_to_vb': 'annoy'},
 'announces': {'vbz_to_vb': 'announce'},
 'alters': {'vbz_to_vb': 'alter'},
 'allows': {'vbz_to_vb': 'allow'},
 'alarms': {'vbz_to_vb': 'alarm'},
 'agrees': {'vbz_to_vb': 'agree'},
 'a\x1effords': {'vbz_to_vb': 'a\x1efford'},
 'a\x1effects': {'vbz_to_vb': 'a\x1effect'},
 'advises': {'vbz_to_vb': 'advise'},
 'adverts': {'vbz_to_vb': 'advert'},
 'advances': {'vbz_to_vb': 'advance'},
 'adopts': {'vbz_to_vb': 'adopt'},
 'admits': {'vbz_to_vb': 'admit'},
 'admires': {'vbz_to_vb': 'admire'},
 'adjusts': {'vbz_to_vb': 'adjust'},
 'adds': {'vbz_to_vb': 'add'},
 'adapts': {'vbz_to_vb': 'adapt'},
 'acquires': {'vbz_to_vb': 'acquire'},
 'acknowledges': {'vbz_to_vb': 'acknowledge'},
 'achieves': {'vbz_to_vb': 'achieve'},
 'accuses': {'vbz_to_vb': 'accuse'},
 'accompanies': {'vbz_to_vb': 'accompany'},
 'accesses': {'vbz_to_vb': 'access'},
 'accepts': {'vbz_to_vb': 'accept'},
 'abandons': {'vbz_to_vb': 'abandon'},
 'absorbs': {'vbz_to_vb': 'absorb'},
 'reinforced': {'vbd_to_vb': 'reinforce', 'vbn_to_vb': 'reinforce', 'vbn_to_vbg': 'reinforcing', 'vbd_eq_vbn': ''},
 'regretted': {'vbd_to_vb': 'regret', 'vbn_to_vb': 'regret', 'vbn_to_vbg': 'regreting', 'vbd_eq_vbn': ''},
 'registered': {'vbd_to_vb': 'register', 'vbn_to_vb': 'register', 'vbn_to_vbg': 'registering', 'vbd_eq_vbn': ''},
 'regarded': {'vbd_to_vb': 'regard', 'vbn_to_vb': 'regard', 'vbn_to_vbg': 'regarding', 'vbd_eq_vbn': ''},
 'refused': {'vbd_to_vb': 'refuse', 'vbn_to_vb': 'refuse', 'vbn_to_vbg': 'refusing', 'vbd_eq_vbn': ''},
 'reformed': {'vbd_to_vb': 'reform', 'vbn_to_vb': 'reform', 'vbn_to_vbg': 'reforming', 'vbd_eq_vbn': ''},
 'reflected': {'vbd_to_vb': 'reflect', 'vbn_to_vb': 'reflect', 'vbn_to_vbg': 'reflecting', 'vbd_eq_vbn': ''},
 'referred': {'vbd_to_vb': 'refer', 'vbn_to_vb': 'refer', 'vbn_to_vbg': 'refering', 'vbd_eq_vbn': ''},
 'recovered': {'vbd_to_vb': 'recover', 'vbn_to_vb': 'recover', 'vbn_to_vbg': 'recovering', 'vbd_eq_vbn': ''},
 'recorded': {'vbd_to_vb': 'record', 'vbn_to_vb': 'record', 'vbn_to_vbg': 'recording', 'vbd_eq_vbn': ''},
 'recommended': {'vbd_to_vb': 'recommend', 'vbn_to_vb': 'recommend', 'vbn_to_vbg': 'recommending', 'vbd_eq_vbn': ''},
 'recognized': {'vbd_to_vb': 'recognize', 'vbn_to_vb': 'recognize', 'vbn_to_vbg': 'recognizing', 'vbd_eq_vbn': ''},
 'reckoned': {'vbd_to_vb': 'reckon', 'vbn_to_vb': 'reckon', 'vbn_to_vbg': 'reckoning', 'vbd_eq_vbn': ''},
 'received': {'vbd_to_vb': 'receive', 'vbn_to_vb': 'receive', 'vbn_to_vbg': 'receiving', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'receipted': {'vbd_to_vb': 'receipt', 'vbn_to_vb': 'receipt', 'vbn_to_vbg': 'receipting', 'vbd_eq_vbn': ''},
 'recalled': {'vbd_to_vb': 'recall', 'vbn_to_vb': 'recall', 'vbn_to_vbg': 'recalling', 'vbd_eq_vbn': ''},
 'reasoned': {'vbd_to_vb': 'reason', 'vbn_to_vb': 'reason', 'vbn_to_vbg': 'reasoning', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'realized': {'vbd_to_vb': 'realize', 'vbn_to_vb': 'realize', 'vbn_to_vbg': 'realizing', 'vbd_eq_vbn': ''},
 'reacted': {'vbd_to_vb': 'react', 'vbn_to_vb': 'react', 'vbn_to_vbg': 'reacting', 'vbd_eq_vbn': ''},
 'reached': {'vbd_to_vb': 'reach', 'vbn_to_vb': 'reach', 'vbn_to_vbg': 'reaching', 'vbd_eq_vbn': ''},
 'rated': {'vbd_to_vb': 'rate', 'vbn_to_vb': 'rate', 'vbn_to_vbg': 'rating', 'vbd_eq_vbn': ''},
 'ranked': {'vbd_to_vb': 'rank', 'vbn_to_vb': 'rank', 'vbn_to_vbg': 'ranking', 'vbd_eq_vbn': ''},
 'ranged': {'vbd_to_vb': 'range', 'vbn_to_vb': 'range', 'vbn_to_vbg': 'ranging', 'vbd_eq_vbn': ''},
 'raised': {'vbd_to_vb': 'raise', 'vbn_to_vb': 'raise', 'vbn_to_vbg': 'raising', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'rained': {'vbd_to_vb': 'rain', 'vbn_to_vb': 'rain', 'vbn_to_vbg': 'raining', 'vbd_eq_vbn': ''},
 'railed': {'vbd_to_vb': 'rail', 'vbn_to_vb': 'rail', 'vbn_to_vbg': 'railing', 'vbd_eq_vbn': ''},
 'raced': {'vbd_to_vb': 'race', 'vbn_to_vb': 'race', 'vbn_to_vbg': 'racing', 'vbd_eq_vbn': ''},
 'quoted': {'vbd_to_vb': 'quote', 'vbn_to_vb': 'quote', 'vbn_to_vbg': 'quoting', 'vbd_eq_vbn': ''},
 'quit,quitted': {'vbd_to_vb': 'quit', 'vbn_to_vb': 'quit', 'vbn_to_vbg': 'quiting'},
 'questioned': {'vbd_to_vb': 'question', 'vbn_to_vb': 'question', 'vbn_to_vbg': 'questioning', 'vbd_eq_vbn': ''},
 'qualified': {'vbd_to_vb': 'qualify', 'vbn_to_vb': 'qualify', 'vbn_to_vbg': 'qualifying', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'pushed': {'vbd_to_vb': 'push', 'vbn_to_vb': 'push', 'vbn_to_vbg': 'pushing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'purchased': {'vbd_to_vb': 'purchase', 'vbn_to_vb': 'purchase', 'vbn_to_vbg': 'purchasing', 'vbd_eq_vbn': ''},
 'punched': {'vbd_to_vb': 'punch', 'vbn_to_vb': 'punch', 'vbn_to_vbg': 'punching', 'vbd_eq_vbn': ''},
 'pulled': {'vbd_to_vb': 'pull', 'vbn_to_vb': 'pull', 'vbn_to_vbg': 'pulling', 'vbd_eq_vbn': ''},
 'published': {'vbd_to_vb': 'publish', 'vbn_to_vb': 'publish', 'vbn_to_vbg': 'publishing', 'vbd_eq_vbn': ''},
 'proved': {'vbd_to_vb': 'prove', 'confu_pair': 'improved', 'vbd_to_vbn': 'proven', 'vbd_eq_vbn': ''},
 'protected': {'vbd_to_vb': 'protect', 'vbn_to_vb': 'protect', 'vbn_to_vbg': 'protecting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'proposed': {'vbd_to_vb': 'propose', 'vbn_to_vb': 'propose', 'vbn_to_vbg': 'proposing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'promoted': {'vbd_to_vb': 'promote', 'vbn_to_vb': 'promote', 'vbn_to_vbg': 'promoting', 'vbd_eq_vbn': ''},
 'promised': {'vbd_to_vb': 'promise', 'vbn_to_vb': 'promise', 'vbn_to_vbg': 'promising', 'vbd_eq_vbn': ''},
 'produced': {'vbd_to_vb': 'produce', 'vbn_to_vb': 'produce', 'vbn_to_vbg': 'producing', 'vbd_eq_vbn': ''},
 'proceded': {'vbd_to_vb': 'proceed', 'vbn_to_vb': 'proceed', 'vbn_to_vbg': 'proceeding'},
 'printed': {'vbd_to_vb': 'print', 'vbn_to_vb': 'print', 'vbn_to_vbg': 'printing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'prevented': {'vbd_to_vb': 'prevent', 'vbn_to_vb': 'prevent', 'vbn_to_vbg': 'preventing', 'vbd_eq_vbn': ''},
 'pretended': {'vbd_to_vb': 'pretend', 'vbn_to_vb': 'pretend', 'vbn_to_vbg': 'pretending', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'presumed': {'vbd_to_vb': 'presume', 'vbn_to_vb': 'presume', 'vbn_to_vbg': 'presuming', 'vbd_eq_vbn': ''},
 'pressed': {'vbd_to_vb': 'press', 'vbn_to_vb': 'press', 'vbn_to_vbg': 'pressing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'preserved': {'vbd_to_vb': 'preserve', 'vbn_to_vb': 'preserve', 'vbn_to_vbg': 'preserving', 'vbd_eq_vbn': ''},
 'presented': {'vbd_to_vb': 'present', 'vbn_to_vb': 'present', 'vbn_to_vbg': 'presenting', 'vbd_eq_vbn': ''},
 'prepared': {'vbd_to_vb': 'prepare', 'vbn_to_vb': 'prepare', 'vbn_to_vbg': 'preparing', 'jj_ed': '', 'be_jj_to_vb': '', 'vbd_eq_vbn': ''},
 'prefered': {'vbd_to_vb': 'prefer', 'vbn_to_vb': 'prefer', 'vbn_to_vbg': 'prefering'},
 'predicted': {'vbd_to_vb': 'predict', 'vbn_to_vb': 'predict', 'vbn_to_vbg': 'predicting', 'vbd_eq_vbn': ''},
 'prayed': {'vbd_to_vb': 'pray', 'vbn_to_vb': 'pray', 'vbn_to_vbg': 'praying', 'vbd_eq_vbn': ''},
 'practised': {'vbd_to_vb': 'practise', 'vbn_to_vb': 'practise', 'vbn_to_vbg': 'practising', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'poured': {'vbd_to_vb': 'pour', 'vbn_to_vb': 'pour', 'vbn_to_vbg': 'pouring', 'vbd_eq_vbn': ''},
 'posted': {'vbd_to_vb': 'post', 'vbn_to_vb': 'post', 'vbn_to_vbg': 'posting', 'vbd_eq_vbn': ''},
 'possessed': {'vbd_to_vb': 'possess', 'vbn_to_vb': 'possess', 'vbn_to_vbg': 'possessing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'posed': {'vbd_to_vb': 'pose', 'vbn_to_vb': 'pose', 'vbn_to_vbg': 'posing', 'vbd_eq_vbn': ''},
 'popped': {'vbd_to_vb': 'pop', 'vbn_to_vb': 'pop', 'vbn_to_vbg': 'popping', 'vbd_eq_vbn': ''},
 'pointed': {'vbd_to_vb': 'point', 'vbn_to_vb': 'point', 'vbn_to_vbg': 'pointing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'pleased': {'vbd_to_vb': 'please', 'vbn_to_vb': 'please', 'vbn_to_vbg': 'pleasing', 'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'played': {'vbd_to_vb': 'play', 'vbn_to_vb': 'play', 'vbn_to_vbg': 'playing', 'vbd_eq_vbn': ''},
 'planned': {'vbd_to_vb': 'plan', 'vbn_to_vb': 'plan', 'vbn_to_vbg': 'planing'},
 'placed': {'vbd_to_vb': 'place', 'vbn_to_vb': 'place', 'vbn_to_vbg': 'placing', 'vbd_eq_vbn': ''},
 'picked': {'vbd_to_vb': 'pick', 'vbn_to_vb': 'pick', 'vbn_to_vbg': 'picking', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'photocopied': {'vbd_to_vb': 'photocopy', 'vbn_to_vb': 'photocopy', 'vbn_to_vbg': 'photocopying', 'vbd_eq_vbn': ''},
 'phoned': {'vbd_to_vb': 'phone', 'vbn_to_vb': 'phone', 'vbn_to_vbg': 'phoning', 'vbd_eq_vbn': ''},
 'persuaded': {'vbd_to_vb': 'persuade', 'vbn_to_vb': 'persuade', 'vbn_to_vbg': 'persuading', 'vbd_eq_vbn': ''},
 'permitted': {'vbd_to_vb': 'permit', 'vbn_to_vb': 'permit', 'vbn_to_vbg': 'permiting', 'vbd_eq_vbn': ''},
 'performed': {'vbd_to_vb': 'perform', 'vbn_to_vb': 'perform', 'vbn_to_vbg': 'performing', 'vbd_eq_vbn': ''},
 'perceived': {'vbd_to_vb': 'perceive', 'vbn_to_vb': 'perceive', 'vbn_to_vbg': 'perceiving', 'vbd_eq_vbn': ''},
 'paused': {'vbd_to_vb': 'pause', 'vbn_to_vb': 'pause', 'vbn_to_vbg': 'pausing', 'vbd_eq_vbn': ''},
 'passed': {'vbd_to_vb': 'pass', 'vbn_to_vb': 'pass', 'vbn_to_vbg': 'passing', 'vbd_eq_vbn': ''},
 'participated': {'vbd_to_vb': 'participate', 'vbn_to_vb': 'participate', 'vbn_to_vbg': 'participating', 'vbd_eq_vbn': ''},
 'parked': {'vbd_to_vb': 'park', 'vbn_to_vb': 'park', 'vbn_to_vbg': 'parking', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'painted': {'vbd_to_vb': 'paint', 'vbn_to_vb': 'paint', 'vbn_to_vbg': 'painting', 'vbd_eq_vbn': ''},
 'packed': {'vbd_to_vb': 'pack', 'vbn_to_vb': 'pack', 'vbn_to_vbg': 'packing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'owned': {'vbd_to_vb': 'own', 'vbn_to_vb': 'own', 'vbn_to_vbg': 'owning', 'vbd_eq_vbn': ''},
 'owed': {'vbd_to_vb': 'owe', 'vbn_to_vb': 'owe', 'vbn_to_vbg': 'owing', 'vbd_eq_vbn': ''},
 'overcame': {'vbd_to_vb': 'overcome', 'vbd_to_vbn': 'overcome'},
 'organized': {'vbd_to_vb': 'organize', 'vbn_to_vb': 'organize', 'vbn_to_vbg': 'organizing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'ordered': {'vbd_to_vb': 'order', 'vbn_to_vb': 'order', 'vbn_to_vbg': 'ordering', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'opposed': {'vbd_to_vb': 'oppose', 'vbn_to_vb': 'oppose', 'vbn_to_vbg': 'opposing', 'be_vbn_to_vbg': '', 'jj_ed': '', 'be_jj_to_vbg': '', 'vbd_eq_vbn': ''},
 'operated': {'vbd_to_vb': 'operate', 'vbn_to_vb': 'operate', 'vbn_to_vbg': 'operating', 'vbd_eq_vbn': ''},
 'opened': {'vbd_to_vb': 'open', 'vbn_to_vb': 'open', 'vbn_to_vbg': 'opening', 'vbd_eq_vbn': ''},
 'offered': {'vbd_to_vb': 'offer', 'vbn_to_vb': 'offer', 'vbn_to_vbg': 'offering', 'vbd_eq_vbn': ''},
 'occured': {'vbd_to_vb': 'occur', 'vbn_to_vb': 'occur', 'vbn_to_vbg': 'occuring'},
 'occupied': {'vbd_to_vb': 'occupy', 'vbn_to_vb': 'occupy', 'vbn_to_vbg': 'occupying', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'obtained': {'vbd_to_vb': 'obtain', 'vbn_to_vb': 'obtain', 'vbn_to_vbg': 'obtaining', 'vbd_eq_vbn': ''},
 'observed': {'vbd_to_vb': 'observe', 'vbn_to_vb': 'observe', 'vbn_to_vbg': 'observing', 'vbd_eq_vbn': ''},
 'objected': {'vbd_to_vb': 'object', 'vbn_to_vb': 'object', 'vbn_to_vbg': 'objecting', 'vbd_eq_vbn': ''},
 'noticed': {'vbd_to_vb': 'notice', 'vbn_to_vb': 'notice', 'vbn_to_vbg': 'noticing', 'vbd_eq_vbn': ''},
 'noted': {'vbd_to_vb': 'note', 'vbn_to_vb': 'note', 'vbn_to_vbg': 'noting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'nodded': {'vbd_to_vb': 'nod', 'vbn_to_vb': 'nod', 'vbn_to_vbg': 'nodding', 'vbd_eq_vbn': ''},
 'negotiated': {'vbd_to_vb': 'negotiate', 'vbn_to_vb': 'negotiate', 'vbn_to_vbg': 'negotiating', 'vbd_eq_vbn': ''},
 'named': {'vbd_to_vb': 'name', 'vbn_to_vb': 'name', 'vbn_to_vbg': 'naming', 'vbd_eq_vbn': ''},
 'moved': {'vbd_to_vb': 'move', 'vbn_to_vb': 'move', 'jj_to_nn': 'move', 'vbn_to_vbg': 'moving', 'sb_be_jj': '', 'vbd_eq_vbn': ''},
 'monitored': {'vbd_to_vb': 'monitor', 'vbn_to_vb': 'monitor', 'vbn_to_vbg': 'monitoring', 'vbd_eq_vbn': ''},
 'missed': {'vbd_to_vb': 'miss', 'vbn_to_vb': 'miss', 'vbn_to_vbg': 'missing', 'vbd_eq_vbn': ''},
 'messed': {'vbd_to_vb': 'mess', 'vbn_to_vb': 'mess', 'vbn_to_vbg': 'messing', 'vbd_eq_vbn': ''},
 'met': {'vbd_to_vb': 'meet', 'vbn_to_vb': 'meet', 'vbn_to_vbg': 'meeting', 'vbd_eq_vbn': ''},
 'measured': {'vbd_to_vb': 'measure', 'vbn_to_vb': 'measure', 'vbn_to_vbg': 'measuring', 'vbd_eq_vbn': ''},
 'meaned': {'vbd_to_vb': 'mean', 'vbn_to_vb': 'mean', 'vbn_to_vbg': 'meaning'},
 'mattered': {'vbd_to_vb': 'matter', 'vbn_to_vb': 'matter', 'vbn_to_vbg': 'mattering', 'vbd_eq_vbn': ''},
 'marched': {'vbd_to_vb': 'march', 'vbn_to_vb': 'march', 'vbn_to_vbg': 'marching', 'vbd_eq_vbn': ''},
 'managed': {'vbd_to_vb': 'manage', 'vbn_to_vb': 'manage', 'vbn_to_vbg': 'managing', 'vbd_eq_vbn': ''},
 'made': {'vbd_to_vb': 'make', 'vbn_to_vb': 'make', 'vbn_to_vbg': 'making', 'vbd_eq_vbn': ''},
 'lowered': {'vbd_to_vb': 'lower', 'vbn_to_vb': 'lower', 'vbn_to_vbg': 'lowering', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'loved': {'vbd_to_vb': 'love', 'vbn_to_vb': 'love', 'vbn_to_vbg': 'loving', 'vbd_eq_vbn': ''},
 'looked': {'vbd_to_vb': 'look', 'vbn_to_vb': 'look', 'vbn_to_vbg': 'looking', 'vbd_eq_vbn': ''},
 'located': {'vbd_to_vb': 'locate', 'vbn_to_vb': 'locate', 'vbn_to_vbg': 'locating', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'lived': {'vbd_to_vb': 'live', 'vbn_to_vb': 'live', 'vbn_to_vbg': 'living'},
 'listened': {'vbd_to_vb': 'listen', 'vbn_to_vb': 'listen', 'vbn_to_vbg': 'listening', 'vbd_eq_vbn': ''},
 'lighted': {'vbd_to_vb': 'light', 'vbn_to_vb': 'light', 'vbn_to_vbg': 'lighting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'lifted': {'vbd_to_vb': 'lift', 'vbn_to_vb': 'lift', 'vbn_to_vbg': 'lifting', 'vbd_eq_vbn': ''},
 'lied': {'vbd_to_vb': 'lie', 'vbn_to_vb': 'lie', 'vbn_to_vbg': 'lying', 'vbd_eq_vbn': ''},
 'licked': {'vbd_to_vb': 'lick', 'vbn_to_vb': 'lick', 'vbn_to_vbg': 'licking', 'vbd_eq_vbn': ''},
 'left': {'vbd_to_vb': 'leave', 'vbn_to_vb': 'leave', 'vbn_to_vbg': 'leaving', 'vbd_eq_vbn': ''},
 'learned,learnt': {'vbd_to_vb': 'learn', 'vbn_to_vb': 'learn', 'vbn_to_vbg': 'learning'},
 'leaned': {'vbd_to_vb': 'lean', 'vbn_to_vb': 'lean', 'vbn_to_vbg': 'leaning', 'vbd_eq_vbn': ''},
 'leafed': {'vbd_to_vb': 'leaf', 'vbn_to_vb': 'leaf', 'vbn_to_vbg': 'leafing', 'vbd_eq_vbn': ''},
 'led': {'vbd_to_vb': 'lead', 'vbn_to_vb': 'lead', 'vbn_to_vbg': 'leading', 'vbd_eq_vbn': ''},
 'laid': {'vbd_to_vb': 'lay', 'vbn_to_vb': 'lay', 'vbn_to_vbg': 'laying', 'vbd_eq_vbn': ''},
 'launched': {'vbd_to_vb': 'launch', 'vbn_to_vb': 'launch', 'vbn_to_vbg': 'launching', 'vbd_eq_vbn': ''},
 'laughed': {'vbd_to_vb': 'laugh', 'vbn_to_vb': 'laugh', 'vbn_to_vbg': 'laughing', 'vbd_eq_vbn': ''},
 'lasted': {'vbd_to_vb': 'last', 'vbn_to_vb': 'last', 'vbn_to_vbg': 'lasting', 'vbd_eq_vbn': ''},
 'landscaped': {'vbd_to_vb': 'landscape', 'vbn_to_vb': 'landscape', 'vbn_to_vbg': 'landscaping', 'vbd_eq_vbn': ''},
 'lambed': {'vbd_to_vb': 'lamb', 'vbn_to_vb': 'lamb', 'vbn_to_vbg': 'lambing', 'vbd_eq_vbn': ''},
 'laddered': {'vbd_to_vb': 'ladder', 'vbn_to_vb': 'ladder', 'vbn_to_vbg': 'laddering', 'vbd_eq_vbn': ''},
 'lacked': {'vbd_to_vb': 'lack', 'vbn_to_vb': 'lack', 'vbn_to_vbg': 'lacking', 'vbd_eq_vbn': ''},
 'laboured': {'vbd_to_vb': 'labour', 'vbn_to_vb': 'labour', 'vbn_to_vbg': 'labouring', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'knew': {'vbd_to_vb': 'know', 'vbd_to_vbn': 'known'},
 'knocked': {'vbd_to_vb': 'knock', 'vbn_to_vb': 'knock', 'vbn_to_vbg': 'knocking', 'vbd_eq_vbn': ''},
 'kneed': {'vbd_to_vb': 'knee', 'vbn_to_vb': 'knee', 'vbn_to_vbg': 'kneeing', 'vbd_eq_vbn': ''},
 'kitted': {'vbd_to_vb': 'kit', 'vbn_to_vb': 'kit', 'vbn_to_vbg': 'kitting', 'vbd_eq_vbn': ''},
 'kissed': {'vbd_to_vb': 'kiss', 'vbn_to_vb': 'kiss', 'vbn_to_vbg': 'kissing', 'vbd_eq_vbn': ''},
 'kicked': {'vbd_to_vb': 'kick', 'vbn_to_vb': 'kick', 'vbn_to_vbg': 'kicking', 'vbd_eq_vbn': ''},
 'justified': {'vbd_to_vb': 'justify', 'vbn_to_vb': 'justify', 'vbn_to_vbg': 'justifying', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'jumped': {'vbd_to_vb': 'jump', 'vbn_to_vb': 'jump', 'vbn_to_vbg': 'jumping', 'vbd_eq_vbn': ''},
 'joked': {'vbd_to_vb': 'joke', 'vbn_to_vb': 'joke', 'vbn_to_vbg': 'joking', 'vbd_eq_vbn': ''},
 'joined': {'vbd_to_vb': 'join', 'vbn_to_vb': 'join', 'vbn_to_vbg': 'joining', 'vbd_eq_vbn': ''},
 'jammed': {'vbd_to_vb': 'jam', 'vbn_to_vb': 'jam', 'vbn_to_vbg': 'jamming', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'ironed': {'vbd_to_vb': 'iron', 'vbn_to_vb': 'iron', 'vbn_to_vbg': 'ironing', 'vbd_eq_vbn': ''},
 'invited': {'vbd_to_vb': 'invite', 'vbn_to_vb': 'invite', 'vbn_to_vbg': 'inviting', 'vbd_eq_vbn': ''},
 'investigated': {'vbd_to_vb': 'investigate', 'vbn_to_vb': 'investigate', 'vbn_to_vbg': 'investigating', 'vbd_eq_vbn': ''},
 'invested': {'vbd_to_vb': 'invest', 'vbn_to_vb': 'invest', 'vbn_to_vbg': 'investing', 'vbd_eq_vbn': ''},
 'introduced': {'vbd_to_vb': 'introduce', 'vbn_to_vb': 'introduce', 'vbn_to_vbg': 'introducing', 'vbd_eq_vbn': ''},
 'interviewed': {'vbd_to_vb': 'interview', 'vbn_to_vb': 'interview', 'vbn_to_vbg': 'interviewing', 'vbd_eq_vbn': ''},
 'interpreted': {'vbd_to_vb': 'interpret', 'vbn_to_vb': 'interpret', 'vbn_to_vbg': 'interpreting', 'vbd_eq_vbn': ''},
 'interested': {'vbd_to_vb': 'interest', 'vbn_to_vb': 'interest', 'vbn_to_vbg': 'interesting', 'sb_be_jj': '', 'jj_ed': '', 'be_jj_in_n': '', 'be_jj_to_vb': '', 'vbd_eq_vbn': ''},
 'intended': {'vbd_to_vb': 'intend', 'vbn_to_vb': 'intend', 'vbn_to_vbg': 'intending', 'vbd_eq_vbn': ''},
 'instituted': {'vbd_to_vb': 'institute', 'vbn_to_vb': 'institute', 'vbn_to_vbg': 'instituting', 'vbd_eq_vbn': ''},
 'instanced': {'vbd_to_vb': 'instance', 'vbn_to_vb': 'instance', 'vbn_to_vbg': 'instancing', 'vbd_eq_vbn': ''},
 'installed': {'vbd_to_vb': 'install', 'vbn_to_vb': 'install', 'vbn_to_vbg': 'installing', 'vbd_eq_vbn': ''},
 'insisted': {'vbd_to_vb': 'insist', 'vbn_to_vb': 'insist', 'vbn_to_vbg': 'insisting', 'vbd_eq_vbn': ''},
 'initialed': {'vbd_to_vb': 'initial', 'vbn_to_vb': 'initial', 'vbn_to_vbg': 'initialing', 'vbd_eq_vbn': ''},
 'informed': {'vbd_to_vb': 'inform', 'vbn_to_vb': 'inform', 'vbn_to_vbg': 'informing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'influenced': {'vbd_to_vb': 'influence', 'vbn_to_vb': 'influence', 'vbn_to_vbg': 'influencing', 'vbd_eq_vbn': ''},
 'indicated': {'vbd_to_vb': 'indicate', 'vbn_to_vb': 'indicate', 'vbn_to_vbg': 'indicating', 'vbd_eq_vbn': ''},
 'increased': {'vbd_to_vb': 'increase', 'vbn_to_vb': 'increase', 'vbn_to_vbg': 'increasing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'incorporated': {'vbd_to_vb': 'incorporate', 'vbn_to_vb': 'incorporate', 'vbn_to_vbg': 'incorporating', 'vbd_eq_vbn': ''},
 'included': {'vbd_to_vb': 'include', 'vbn_to_vb': 'include', 'vbn_to_vbg': 'including', 'vbd_eq_vbn': ''},
 'inched': {'vbd_to_vb': 'inch', 'vbn_to_vb': 'inch', 'vbn_to_vbg': 'inching', 'vbd_eq_vbn': ''},
 'improved': {'vbd_to_vb': 'improve', 'vbn_to_vb': 'improve', 'vbn_to_vbg': 'improving', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'impressed': {'vbd_to_vb': 'impress', 'vbn_to_vb': 'impress', 'vbn_to_vbg': 'impressing', 'sb_be_jj': '', 'vbd_eq_vbn': ''},
 'imported': {'vbd_to_vb': 'import', 'vbn_to_vb': 'import', 'vbn_to_vbg': 'importing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'imagined': {'vbd_to_vb': 'imagine', 'vbn_to_vb': 'imagine', 'vbn_to_vbg': 'imagining', 'vbd_eq_vbn': ''},
 'illustrated': {'vbd_to_vb': 'illustrate', 'vbn_to_vb': 'illustrate', 'vbn_to_vbg': 'illustrating', 'vbd_eq_vbn': ''},
 'ignored': {'vbd_to_vb': 'ignore', 'vbn_to_vb': 'ignore', 'vbn_to_vbg': 'ignoring', 'vbd_eq_vbn': ''},
 'identified': {'vbd_to_vb': 'identify', 'vbn_to_vb': 'identify', 'vbn_to_vbg': 'identifying', 'vbd_eq_vbn': ''},
 'hunted': {'vbd_to_vb': 'hunt', 'vbn_to_vb': 'hunt', 'vbn_to_vbg': 'hunting', 'vbd_eq_vbn': ''},
 'hosted': {'vbd_to_vb': 'host', 'vbn_to_vb': 'host', 'vbn_to_vbg': 'hosting', 'vbd_eq_vbn': ''},
 'horsed': {'vbd_to_vb': 'horse', 'vbn_to_vb': 'horse', 'vbn_to_vbg': 'hoping', 'vbd_eq_vbn': ''},
 'hoped': {'vbd_to_vb': 'hope', 'vbn_to_vb': 'hope', 'vbn_to_vbg': 'hoping', 'vbd_eq_vbn': ''},
 'honoured': {'vbd_to_vb': 'honour', 'vbn_to_vb': 'honour', 'vbn_to_vbg': 'honouring', 'vbd_eq_vbn': ''},
 'holed': {'vbd_to_vb': 'hole', 'vbn_to_vb': 'hole', 'vbn_to_vbg': 'holing', 'vbd_eq_vbn': ''},
 'held': {'vbd_to_vb': 'hold', 'vbn_to_vb': 'hold', 'vbn_to_vbg': 'holding', 'vbd_eq_vbn': ''},
 'hired': {'vbd_to_vb': 'hire', 'vbn_to_vb': 'hire', 'vbn_to_vbg': 'hiring', 'vbd_eq_vbn': ''},
 'hid': {'vbd_to_vb': 'hide', 'vbd_to_vbn': 'hidden'},
 'hesitated': {'vbd_to_vb': 'hesitate', 'vbn_to_vb': 'hesitate', 'vbn_to_vbg': 'hesitating', 'vbd_eq_vbn': ''},
 'helped': {'vbd_to_vb': 'help', 'vbn_to_vb': 'help', 'vbn_to_vbg': 'helping', 'vbd_eq_vbn': ''},
 'heard': {'vbd_to_vb': 'hear', 'vbn_to_vb': 'hear', 'vbn_to_vbg': 'hearing', 'vbd_eq_vbn': ''},
 'hated': {'vbd_to_vb': 'hate', 'vbn_to_vb': 'hate', 'vbn_to_vbg': 'hating', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'hatted': {'vbd_to_vb': 'hat', 'vbn_to_vb': 'hat', 'vbn_to_vbg': 'hating', 'vbd_eq_vbn': ''},
 'harmed': {'vbd_to_vb': 'harm', 'vbn_to_vb': 'harm', 'vbn_to_vbg': 'harming', 'vbd_eq_vbn': ''},
 'happened': {'vbd_to_vb': 'happen', 'vbn_to_vb': 'happen', 'vbn_to_vbg': 'happening', 'vbd_eq_vbn': ''},
 'hung': {'vbd_to_vb': 'hang', 'vbn_to_vb': 'hang', 'vbn_to_vbg': 'hanging', 'vbd_eq_vbn': ''},
 'handled': {'vbd_to_vb': 'handle', 'vbn_to_vb': 'handle', 'vbn_to_vbg': 'handling', 'vbd_eq_vbn': ''},
 'guided': {'vbd_to_vb': 'guide', 'vbn_to_vb': 'guide', 'vbn_to_vbg': 'guiding', 'vbd_eq_vbn': ''},
 'guessed': {'vbd_to_vb': 'guess', 'vbn_to_vb': 'guess', 'vbn_to_vbg': 'guessing', 'vbd_eq_vbn': ''},
 'guarded': {'vbd_to_vb': 'guard', 'vbn_to_vb': 'guard', 'vbn_to_vbg': 'guarding', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'grew': {'vbd_to_vb': 'grow', 'vbd_to_vbn': 'grown'},
 'graphed': {'vbd_to_vb': 'graph', 'vbn_to_vb': 'graph', 'vbn_to_vbg': 'graphing', 'vbd_eq_vbn': ''},
 'granted': {'vbd_to_vb': 'grant', 'vbn_to_vb': 'grant', 'vbn_to_vbg': 'granting', 'vbd_eq_vbn': ''},
 'graded': {'vbd_to_vb': 'grade', 'vbn_to_vb': 'grade', 'vbn_to_vbg': 'grading', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'grabbed': {'vbd_to_vb': 'grab', 'vbn_to_vb': 'grab', 'vbn_to_vbg': 'grabbing', 'vbd_eq_vbn': ''},
 'governed': {'vbd_to_vb': 'govern', 'vbn_to_vb': 'govern', 'vbn_to_vbg': 'governing', 'vbd_eq_vbn': ''},
 'went': {'vbd_to_vb': 'go', 'vbd_to_vbn': 'gone'},
 'gloved': {'vbd_to_vb': 'glove', 'vbn_to_vb': 'glove', 'vbn_to_vbg': 'gloving', 'vbd_eq_vbn': ''},
 'glassed': {'vbd_to_vb': 'glass', 'vbn_to_vb': 'glass', 'vbn_to_vbg': 'glassing', 'vbd_eq_vbn': ''},
 'glanced': {'vbd_to_vb': 'glance', 'vbn_to_vb': 'glance', 'vbn_to_vbg': 'glancing', 'vbd_eq_vbn': ''},
 'gave': {'vbd_to_vb': 'give', 'vbd_to_vbn': 'given'},
 'got': {'vbd_to_vb': 'get', 'vbd_to_vbn': 'gotten', 'vbd_eq_vbn': ''},
 'generated': {'vbd_to_vb': 'generate', 'vbn_to_vb': 'generate', 'vbn_to_vbg': 'generating', 'vbd_eq_vbn': ''},
 'gathered': {'vbd_to_vb': 'gather', 'vbn_to_vb': 'gather', 'vbn_to_vbg': 'gathering', 'vbd_eq_vbn': ''},
 'gassed': {'vbd_to_vb': 'gas', 'vbn_to_vb': 'gas', 'vbn_to_vbg': 'gasing', 'vbd_eq_vbn': ''},
 'gardened': {'vbd_to_vb': 'garden', 'vbn_to_vb': 'garden', 'vbn_to_vbg': 'gardening', 'vbd_eq_vbn': ''},
 'garaged': {'vbd_to_vb': 'garage', 'vbn_to_vb': 'garage', 'vbn_to_vbg': 'garaging', 'vbd_eq_vbn': ''},
 'ganged': {'vbd_to_vb': 'gang', 'vbn_to_vb': 'gang', 'vbn_to_vbg': 'ganging', 'vbd_eq_vbn': ''},
 'gained': {'vbd_to_vb': 'gain', 'vbn_to_vb': 'gain', 'vbn_to_vbg': 'gaining', 'vbd_eq_vbn': ''},
 'fussed': {'vbd_to_vb': 'fuss', 'vbn_to_vb': 'fuss', 'vbn_to_vbg': 'fussing', 'vbd_eq_vbn': ''},
 'funded': {'vbd_to_vb': 'fund', 'vbn_to_vb': 'fund', 'vbn_to_vbg': 'funding', 'vbd_eq_vbn': ''},
 'functioned': {'vbd_to_vb': 'function', 'vbn_to_vb': 'function', 'vbn_to_vbg': 'functioning', 'vbd_eq_vbn': ''},
 'fulled': {'vbd_to_vb': 'full', 'vbn_to_vb': 'full', 'vbn_to_vbg': 'fulling', 'vbd_eq_vbn': ''},
 'fueled': {'vbd_to_vb': 'fuel', 'vbn_to_vb': 'fuel', 'vbn_to_vbg': 'fueling', 'vbd_eq_vbn': ''},
 'fried': {'vbd_to_vb': 'fry', 'vbn_to_vb': 'fry', 'vbn_to_vbg': 'frying', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'fruited': {'vbd_to_vb': 'fruit', 'vbn_to_vb': 'fruit', 'vbn_to_vbg': 'fruiting', 'vbd_eq_vbn': ''},
 'fronted': {'vbd_to_vb': 'front', 'vbn_to_vb': 'front', 'vbn_to_vbg': 'fronting', 'vbd_eq_vbn': ''},
 'freezed': {'vbd_to_vb': 'freeze', 'vbn_to_vb': 'freeze', 'vbn_to_vbg': 'freezing'},
 'freed': {'vbd_to_vb': 'free', 'vbn_to_vb': 'free', 'vbn_to_vbg': 'freing', 'vbd_eq_vbn': ''},
 'forwarded': {'vbd_to_vb': 'forward', 'vbn_to_vb': 'forward', 'vbn_to_vbg': 'forwarding', 'vbd_eq_vbn': ''},
 'forked': {'vbd_to_vb': 'fork', 'vbn_to_vb': 'fork', 'vbn_to_vbg': 'forking', 'vbd_eq_vbn': ''},
 'forgave': {'vbd_to_vb': 'forgive', 'vbd_to_vbn': 'forgiven'},
 'forgot': {'vbd_to_vb': 'forget', 'vbd_to_vbn': 'forgotten'},
 'forced': {'vbd_to_vb': 'force', 'vbn_to_vb': 'force', 'vbn_to_vbg': 'forcing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'followed': {'vbd_to_vb': 'follow', 'vbn_to_vb': 'follow', 'vbn_to_vbg': 'following', 'vbd_eq_vbn': ''},
 'folded': {'vbd_to_vb': 'fold', 'vbn_to_vb': 'fold', 'vbn_to_vbg': 'folding', 'vbd_eq_vbn': ''},
 'flied': {'vbd_to_vb': 'fly', 'vbn_to_vb': 'fly', 'vbn_to_vbg': 'flying'},
 'flowered': {'vbd_to_vb': 'flower', 'vbn_to_vb': 'flower', 'vbn_to_vbg': 'flowering', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'flew': {'vbd_to_vb': 'flow', 'vbd_to_vbn': 'flown'},
 'floored': {'vbd_to_vb': 'floor', 'vbn_to_vb': 'floor', 'vbn_to_vbg': 'flooring', 'vbd_eq_vbn': ''},
 'fleshed': {'vbd_to_vb': 'flesh', 'vbn_to_vb': 'flesh', 'vbn_to_vbg': 'fleshing', 'vbd_eq_vbn': ''},
 'flashed': {'vbd_to_vb': 'flash', 'vbn_to_vb': 'flash', 'vbn_to_vbg': 'flashing', 'vbd_eq_vbn': ''},
 'fi\x1dxed': {'vbd_to_vb': 'fi\x1dx', 'vbn_to_vb': 'fi\x1dx', 'vbn_to_vbg': 'fi\x1dxing'},
 'fi\x1dtted,fit': {'vbd_to_vb': 'fi\x1dt', 'vbn_to_vb': 'fi\x1dt', 'vbn_to_vbg': 'fi\x1dtting'},
 'fi\x1dshed': {'vbd_to_vb': 'fi\x1dsh', 'vbn_to_vb': 'fi\x1dsh', 'vbn_to_vbg': 'fi\x1dshing'},
 'fi\x1drmed': {'vbd_to_vb': 'fi\x1drm', 'vbn_to_vb': 'fi\x1drm', 'vbn_to_vbg': 'fi\x1drming'},
 'fi\x1dred': {'vbd_to_vb': 'fi\x1dre', 'vbn_to_vb': 'fi\x1dre', 'vbn_to_vbg': 'fi\x1dring'},
 '\x1dfinished': {'vbd_to_vb': '\x1dfinish', 'vbn_to_vb': '\x1dfinish', 'vbn_to_vbg': '\x1dfinishing'},
 'fi\x1dnded': {'vbd_to_vb': 'fi\x1dnd', 'vbn_to_vb': 'fi\x1dnd', 'vbn_to_vbg': 'fi\x1dnding'},
 'fi\x1dlmed': {'vbd_to_vb': 'fi\x1dlm', 'vbn_to_vb': 'fi\x1dlm', 'vbn_to_vbg': 'fi\x1dlming'},
 'fi\x1dlled': {'vbd_to_vb': 'fi\x1dll', 'vbn_to_vb': 'fi\x1dll', 'vbn_to_vbg': 'fi\x1dlling'},
 'fi\x1dled': {'vbd_to_vb': 'fi\x1dle', 'vbn_to_vb': 'fi\x1dle', 'vbn_to_vbg': 'fi\x1dling'},
 'fi\x1dgured': {'vbd_to_vb': 'fi\x1dgure', 'vbn_to_vb': 'fi\x1dgure', 'vbn_to_vbg': 'fi\x1dguring'},
 'fought': {'vbd_to_vb': 'fi\x1dght', 'vbn_to_vb': 'fi\x1dght', 'vbn_to_vbg': 'fi\x1dghting', 'vbd_eq_vbn': ''},
 'fi\x1delded': {'vbd_to_vb': 'fi\x1deld', 'vbn_to_vb': 'fi\x1deld', 'vbn_to_vbg': 'fi\x1delding'},
 'fetched': {'vbd_to_vb': 'fetch', 'vbn_to_vb': 'fetch', 'vbn_to_vbg': 'fetching', 'vbd_eq_vbn': ''},
 'fenced': {'vbd_to_vb': 'fence', 'vbn_to_vb': 'fence', 'vbn_to_vbg': 'fencing', 'vbd_eq_vbn': ''},
 'feared': {'vbd_to_vb': 'fear', 'vbn_to_vb': 'fear', 'vbn_to_vbg': 'fearing', 'vbd_eq_vbn': ''},
 'favoured': {'vbd_to_vb': 'favour', 'vbn_to_vb': 'favour', 'vbn_to_vbg': 'favouring', 'vbd_eq_vbn': ''},
 'faulted': {'vbd_to_vb': 'fault', 'vbn_to_vb': 'fault', 'vbn_to_vbg': 'faulting', 'vbd_eq_vbn': ''},
 'fashioned': {'vbd_to_vb': 'fashion', 'vbn_to_vb': 'fashion', 'vbn_to_vbg': 'fashioning', 'vbd_eq_vbn': ''},
 'farmed': {'vbd_to_vb': 'farm', 'vbn_to_vb': 'farm', 'vbn_to_vbg': 'farming', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'falled': {'vbd_to_vb': 'fall', 'vbn_to_vb': 'fall', 'vbn_to_vbg': 'falling'},
 'extended': {'vbd_to_vb': 'extend', 'vbn_to_vb': 'extend', 'vbn_to_vbg': 'extending', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'expressed': {'vbd_to_vb': 'express', 'vbn_to_vb': 'express', 'vbn_to_vbg': 'expressing', 'vbd_eq_vbn': ''},
 'explored': {'vbd_to_vb': 'explore', 'vbn_to_vb': 'explore', 'vbn_to_vbg': 'exploring', 'vbd_eq_vbn': ''},
 'explained': {'vbd_to_vb': 'explain', 'vbn_to_vb': 'explain', 'vbn_to_vbg': 'explaining', 'vbd_eq_vbn': ''},
 'experimented': {'vbd_to_vb': 'experiment', 'vbn_to_vb': 'experiment', 'vbn_to_vbg': 'experimenting', 'vbd_eq_vbn': ''},
 'expanded': {'vbd_to_vb': 'expand', 'vbn_to_vb': 'expand', 'vbn_to_vbg': 'expanding', 'vbd_eq_vbn': ''},
 'exited': {'vbd_to_vb': 'exit', 'vbn_to_vb': 'exit', 'vbn_to_vbg': 'exiting', 'vbd_eq_vbn': ''},
 'existed': {'vbd_to_vb': 'exist', 'vbn_to_vb': 'exist', 'vbn_to_vbg': 'existing', 'vbd_eq_vbn': ''},
 'excused': {'vbd_to_vb': 'excuse', 'vbn_to_vb': 'excuse', 'vbn_to_vbg': 'excusing', 'vbd_eq_vbn': ''},
 'excluded': {'vbd_to_vb': 'exclude', 'vbn_to_vb': 'exclude', 'vbn_to_vbg': 'excluding', 'vbd_eq_vbn': ''},
 'exchanged': {'vbd_to_vb': 'exchange', 'vbn_to_vb': 'exchange', 'vbn_to_vbg': 'exchanging', 'vbd_eq_vbn': ''},
 'examined': {'vbd_to_vb': 'examine', 'vbn_to_vb': 'examine', 'vbn_to_vbg': 'examining', 'vbd_eq_vbn': ''},
 'equalled': {'vbd_to_vb': 'equal', 'vbn_to_vb': 'equal', 'vbn_to_vbg': 'equalling', 'vbd_eq_vbn': ''},
 'entranced': {'vbd_to_vb': 'entrance', 'vbn_to_vb': 'entrance', 'vbn_to_vbg': 'entrancing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'entitled': {'vbd_to_vb': 'entitle', 'vbn_to_vb': 'entitle', 'vbn_to_vbg': 'entitling', 'be_jj_to_vbg': '', 'vbd_eq_vbn': ''},
 'ensured': {'vbd_to_vb': 'ensure', 'vbn_to_vb': 'ensure', 'vbn_to_vbg': 'ensuring', 'vbd_eq_vbn': ''},
 'enjoyed': {'vbd_to_vb': 'enjoy', 'vbn_to_vb': 'enjoy', 'vbn_to_vbg': 'enjoying', 'vbd_eq_vbn': ''},
 'engineered': {'vbd_to_vb': 'engineer', 'vbn_to_vb': 'engineer', 'vbn_to_vbg': 'engineering', 'vbd_eq_vbn': ''},
 'engaged': {'vbd_to_vb': 'engage', 'vbn_to_vb': 'engage', 'vbn_to_vbg': 'engaging', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'encouraged': {'vbd_to_vb': 'encourage', 'vbn_to_vb': 'encourage', 'vbn_to_vbg': 'encouraging', 'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'encountered': {'vbd_to_vb': 'encounter', 'vbn_to_vb': 'encounter', 'vbn_to_vbg': 'encountering', 'vbd_eq_vbn': ''},
 'enabled': {'vbd_to_vb': 'enable', 'vbn_to_vb': 'enable', 'vbn_to_vbg': 'enabling', 'vbd_eq_vbn': ''},
 'emphasized': {'vbd_to_vb': 'emphasize', 'vbn_to_vb': 'emphasize', 'vbn_to_vbg': 'emphasizing', 'vbd_eq_vbn': ''},
 'emerged': {'vbd_to_vb': 'emerge', 'vbn_to_vb': 'emerge', 'vbn_to_vbg': 'emerging', 'vbd_eq_vbn': ''},
 'elected': {'vbd_to_vb': 'elect', 'vbn_to_vb': 'elect', 'vbn_to_vbg': 'electing', 'vbd_eq_vbn': ''},
 'egged': {'vbd_to_vb': 'egg', 'vbn_to_vb': 'egg', 'vbn_to_vbg': 'egging', 'vbd_eq_vbn': ''},
 'e\x1effected': {'vbd_to_vb': 'e\x1effect', 'vbn_to_vb': 'e\x1effect', 'vbn_to_vbg': 'e\x1effecting'},
 'edged': {'vbd_to_vb': 'edge', 'vbn_to_vb': 'edge', 'vbn_to_vbg': 'edging', 'vbd_eq_vbn': ''},
 'eased': {'vbd_to_vb': 'ease', 'vbn_to_vb': 'ease', 'vbn_to_vbg': 'easing', 'vbd_eq_vbn': ''},
 'earthed': {'vbd_to_vb': 'earth', 'vbn_to_vb': 'earth', 'vbn_to_vbg': 'earthing', 'vbd_eq_vbn': ''},
 'earned': {'vbd_to_vb': 'earn', 'vbn_to_vb': 'earn', 'vbn_to_vbg': 'earning', 'vbd_eq_vbn': ''},
 'dusted': {'vbd_to_vb': 'dust', 'vbn_to_vb': 'dust', 'vbn_to_vbg': 'dusting', 'vbd_eq_vbn': ''},
 'dumpped': {'vbd_to_vb': 'dump', 'vbn_to_vb': 'dump', 'vbn_to_vbg': 'dumping'},
 'dulled': {'vbd_to_vb': 'dull', 'vbn_to_vb': 'dull', 'vbn_to_vbg': 'dulling', 'vbd_eq_vbn': ''},
 'ducked': {'vbd_to_vb': 'duck', 'vbn_to_vb': 'duck', 'vbn_to_vbg': 'ducking', 'vbd_eq_vbn': ''},
 'dried': {'vbd_to_vb': 'dry', 'vbn_to_vb': 'dry', 'vbn_to_vbg': 'drying', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'drugged': {'vbd_to_vb': 'drug', 'vbn_to_vb': 'drug', 'vbn_to_vbg': 'druging', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'drived': {'vbd_to_vb': 'drive', 'vbn_to_vb': 'drive', 'vbn_to_vbg': 'driving'},
 'drank': {'vbd_to_vb': 'drink', 'vbd_to_vbn': 'drunk'},
 'dreamed,dreamt': {'vbd_to_vb': 'dream', 'vbn_to_vb': 'dream', 'vbn_to_vbg': 'dreaming'},
 'drawinged': {'vbd_to_vb': 'drawing', 'vbn_to_vb': 'drawing', 'vbn_to_vbg': 'drawinging'},
 'dragged': {'vbd_to_vb': 'drag', 'vbn_to_vb': 'drag', 'vbn_to_vbg': 'draging', 'vbd_eq_vbn': ''},
 'doubted': {'vbd_to_vb': 'doubt', 'vbn_to_vb': 'doubt', 'vbn_to_vbg': 'doubting', 'vbd_eq_vbn': ''},
 'doubled': {'vbd_to_vb': 'double', 'vbn_to_vb': 'double', 'vbn_to_vbg': 'doubling', 'vbd_eq_vbn': ''},
 'dotted': {'vbd_to_vb': 'dot', 'vbn_to_vb': 'dot', 'vbn_to_vbg': 'doting', 'vbd_eq_vbn': ''},
 'dominated': {'vbd_to_vb': 'dominate', 'vbn_to_vb': 'dominate', 'vbn_to_vbg': 'dominating', 'vbd_eq_vbn': ''},
 'doctored': {'vbd_to_vb': 'doctor', 'vbn_to_vb': 'doctor', 'vbn_to_vbg': 'doctoring', 'vbd_eq_vbn': ''},
 'divorced': {'vbd_to_vb': 'divorce', 'vbn_to_vb': 'divorce', 'vbn_to_vbg': 'divorcing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'disturbed': {'vbd_to_vb': 'disturb', 'vbn_to_vb': 'disturb', 'vbn_to_vbg': 'disturbing', 'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'distributed': {'vbd_to_vb': 'distribute', 'vbn_to_vb': 'distribute', 'vbn_to_vbg': 'distributing', 'vbd_eq_vbn': ''},
 'distinguished': {'vbd_to_vb': 'distinguish', 'vbn_to_vb': 'distinguish', 'vbn_to_vbg': 'distinguishing', 'vbd_eq_vbn': ''},
 'distanced': {'vbd_to_vb': 'distance', 'vbn_to_vb': 'distance', 'vbn_to_vbg': 'distancing', 'vbd_eq_vbn': ''},
 'disputed': {'vbd_to_vb': 'dispute', 'vbn_to_vb': 'dispute', 'vbn_to_vbg': 'disputing', 'vbd_eq_vbn': ''},
 'dismissed': {'vbd_to_vb': 'dismiss', 'vbn_to_vb': 'dismiss', 'vbn_to_vbg': 'dismissing', 'vbd_eq_vbn': ''},
 'dished': {'vbd_to_vb': 'dish', 'vbn_to_vb': 'dish', 'vbn_to_vbg': 'dishing', 'vbd_eq_vbn': ''},
 'discussed': {'vbd_to_vb': 'discuss', 'vbn_to_vb': 'discuss', 'vbn_to_vbg': 'discussing', 'vbd_eq_vbn': ''},
 'discovered': {'vbd_to_vb': 'discover', 'vbn_to_vb': 'discover', 'vbn_to_vbg': 'discovering', 'vbd_eq_vbn': ''},
 'discounted': {'vbd_to_vb': 'discount', 'vbn_to_vb': 'discount', 'vbn_to_vbg': 'discounting', 'vbd_eq_vbn': ''},
 'disciplined': {'vbd_to_vb': 'discipline', 'vbn_to_vb': 'discipline', 'vbn_to_vbg': 'disciplining', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'disappeared': {'vbd_to_vb': 'disappear', 'vbn_to_vb': 'disappear', 'vbn_to_vbg': 'disappearing', 'vbd_eq_vbn': ''},
 'disagreed': {'vbd_to_vb': 'disagree', 'vbn_to_vb': 'disagree', 'vbn_to_vbg': 'disagreing', 'vbd_eq_vbn': ''},
 'dirtied': {'vbd_to_vb': 'dirty', 'vbn_to_vb': 'dirty', 'vbn_to_vbg': 'dirtying', 'vbd_eq_vbn': ''},
 'digged': {'vbd_to_vb': 'dig', 'vbn_to_vb': 'dig', 'vbn_to_vbg': 'digging'},
 'di\x1effered': {'vbd_to_vb': 'di\x1effer', 'vbn_to_vb': 'di\x1effer', 'vbn_to_vbg': 'di\x1effering'},
 'died': {'vbd_to_vb': 'die', 'vbn_to_vb': 'die', 'vbn_to_vbg': 'dying', 'vbd_eq_vbn': ''},
 'diagramed': {'vbd_to_vb': 'diagram', 'vbn_to_vb': 'diagram', 'vbn_to_vbg': 'diagraming'},
 'determined': {'vbd_to_vb': 'determine', 'vbn_to_vb': 'determine', 'vbn_to_vbg': 'determining', 'jj_ed': '', 'be_jj_to_vb': '', 'vbd_eq_vbn': ''},
 'detected': {'vbd_to_vb': 'detect', 'vbn_to_vb': 'detect', 'vbn_to_vbg': 'detecting', 'vbd_eq_vbn': ''},
 'destroyed': {'vbd_to_vb': 'destroy', 'vbn_to_vb': 'destroy', 'vbn_to_vbg': 'destroying', 'vbd_eq_vbn': ''},
 'desired': {'vbd_to_vb': 'desire', 'vbn_to_vb': 'desire', 'vbn_to_vbg': 'desiring', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'deserved': {'vbd_to_vb': 'deserve', 'vbn_to_vb': 'deserve', 'vbn_to_vbg': 'deserving', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'described': {'vbd_to_vb': 'describe', 'vbn_to_vb': 'describe', 'vbn_to_vbg': 'describing', 'vbd_eq_vbn': ''},
 'derived': {'vbd_to_vb': 'derive', 'vbn_to_vb': 'derive', 'vbn_to_vbg': 'deriving', 'vbd_eq_vbn': ''},
 'deposited': {'vbd_to_vb': 'deposit', 'vbn_to_vb': 'deposit', 'vbn_to_vbg': 'depositing', 'vbd_eq_vbn': ''},
 'depended': {'vbd_to_vb': 'depend', 'vbn_to_vb': 'depend', 'vbn_to_vbg': 'depending', 'vbd_eq_vbn': ''},
 'denied': {'vbd_to_vb': 'deny', 'vbn_to_vb': 'deny', 'vbn_to_vbg': 'denying', 'vbd_eq_vbn': ''},
 'demonstrated': {'vbd_to_vb': 'demonstrate', 'vbn_to_vb': 'demonstrate', 'vbn_to_vbg': 'demonstrating', 'vbd_eq_vbn': ''},
 'demanded': {'vbd_to_vb': 'demand', 'vbn_to_vb': 'demand', 'vbn_to_vbg': 'demanding', 'vbd_eq_vbn': ''},
 'defi\x1dned': {'vbd_to_vb': 'defi\x1dne', 'vbn_to_vb': 'defi\x1dne', 'vbn_to_vbg': 'defi\x1dning'},
 'defended': {'vbd_to_vb': 'defend', 'vbn_to_vb': 'defend', 'vbn_to_vbg': 'defending', 'vbd_eq_vbn': ''},
 'declined': {'vbd_to_vb': 'decline', 'vbn_to_vb': 'decline', 'vbn_to_vbg': 'declining', 'vbd_eq_vbn': ''},
 'debated': {'vbd_to_vb': 'debate', 'vbn_to_vb': 'debate', 'vbn_to_vbg': 'debating', 'vbd_eq_vbn': ''},
 'dealt': {'vbd_to_vb': 'deal', 'vbn_to_vb': 'deal', 'vbn_to_vbg': 'dealing', 'vbd_eq_vbn': ''},
 'dared': {'vbd_to_vb': 'dare', 'vbn_to_vb': 'dare', 'vbn_to_vbg': 'daring', 'vbd_eq_vbn': ''},
 'danced': {'vbd_to_vb': 'dance', 'vbn_to_vb': 'dance', 'vbn_to_vbg': 'dancing', 'vbd_eq_vbn': ''},
 'damaged': {'vbd_to_vb': 'damage', 'vbn_to_vb': 'damage', 'vbn_to_vbg': 'damaging', 'vbd_eq_vbn': ''},
 'cycled': {'vbd_to_vb': 'cycle', 'vbn_to_vb': 'cycle', 'vbn_to_vbg': 'cycling', 'vbd_eq_vbn': ''},
 'cushioned': {'vbd_to_vb': 'cushion', 'vbn_to_vb': 'cushion', 'vbn_to_vbg': 'cushioning', 'vbd_eq_vbn': ''},
 'curtained': {'vbd_to_vb': 'curtain', 'vbn_to_vb': 'curtain', 'vbn_to_vbg': 'curtaining', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'cried': {'vbd_to_vb': 'cry', 'vbn_to_vb': 'cry', 'vbn_to_vbg': 'crying', 'vbd_eq_vbn': ''},
 'criticized': {'vbd_to_vb': 'criticize', 'vbn_to_vb': 'criticize', 'vbn_to_vbg': 'criticizing', 'vbd_eq_vbn': ''},
 'crewed': {'vbd_to_vb': 'crew', 'vbn_to_vb': 'crew', 'vbn_to_vbg': 'crewing', 'vbd_eq_vbn': ''},
 'credited': {'vbd_to_vb': 'credit', 'vbn_to_vb': 'credit', 'vbn_to_vbg': 'crediting', 'vbd_eq_vbn': ''},
 'created': {'vbd_to_vb': 'create', 'vbn_to_vb': 'create', 'vbn_to_vbg': 'creating', 'vbd_eq_vbn': ''},
 'cracked': {'vbd_to_vb': 'crack', 'vbn_to_vb': 'crack', 'vbn_to_vbg': 'cracking', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'cowed': {'vbd_to_vb': 'cow', 'vbn_to_vb': 'cow', 'vbn_to_vbg': 'cowing', 'vbd_eq_vbn': ''},
 'covered': {'vbd_to_vb': 'cover', 'vbn_to_vb': 'cover', 'vbn_to_vbg': 'covering', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'courted': {'vbd_to_vb': 'court', 'vbn_to_vb': 'court', 'vbn_to_vbg': 'courting', 'vbd_eq_vbn': ''},
 'coursed': {'vbd_to_vb': 'course', 'vbn_to_vb': 'course', 'vbn_to_vbg': 'coursing', 'vbd_eq_vbn': ''},
 'coupled': {'vbd_to_vb': 'couple', 'vbn_to_vb': 'couple', 'vbn_to_vbg': 'coupling', 'vbd_eq_vbn': ''},
 'countered': {'vbd_to_vb': 'counter', 'vbn_to_vb': 'counter', 'vbn_to_vbg': 'countering', 'vbd_eq_vbn': ''},
 'counted': {'vbd_to_vb': 'count', 'vbn_to_vb': 'count', 'vbn_to_vbg': 'counting', 'vbd_eq_vbn': ''},
 'cottoned': {'vbd_to_vb': 'cotton', 'vbn_to_vb': 'cotton', 'vbn_to_vbg': 'cottoning', 'vbd_eq_vbn': ''},
 'coped': {'vbd_to_vb': 'cope', 'vbn_to_vb': 'cope', 'vbn_to_vbg': 'coping', 'vbd_eq_vbn': ''},
 'cooled': {'vbd_to_vb': 'cool', 'vbn_to_vb': 'cool', 'vbn_to_vbg': 'cooling', 'vbd_eq_vbn': ''},
 'cooked': {'vbd_to_vb': 'cook', 'vbn_to_vb': 'cook', 'vbn_to_vbg': 'cooking', 'vbd_eq_vbn': ''},
 'convinced': {'vbd_to_vb': 'convince', 'vbn_to_vb': 'convince', 'vbn_to_vbg': 'convincing', 'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'converted': {'vbd_to_vb': 'convert', 'vbn_to_vb': 'convert', 'vbn_to_vbg': 'converting', 'vbd_eq_vbn': ''},
 'controled': {'vbd_to_vb': 'control', 'vbn_to_vb': 'control', 'vbn_to_vbg': 'controling'},
 'contrasted': {'vbd_to_vb': 'contrast', 'vbn_to_vb': 'contrast', 'vbn_to_vbg': 'contrasting', 'vbd_eq_vbn': ''},
 'continued': {'vbd_to_vb': 'continue', 'vbn_to_vb': 'continue', 'vbn_to_vbg': 'continuing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'contested': {'vbd_to_vb': 'contest', 'vbn_to_vb': 'contest', 'vbn_to_vbg': 'contesting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'contented': {'vbd_to_vb': 'content', 'vbn_to_vb': 'content', 'vbn_to_vbg': 'contenting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'contacted': {'vbd_to_vb': 'contact', 'vbn_to_vb': 'contact', 'vbn_to_vbg': 'contacting', 'vbd_eq_vbn': ''},
 'consulted': {'vbd_to_vb': 'consult', 'vbn_to_vb': 'consult', 'vbn_to_vbg': 'consulting', 'vbd_eq_vbn': ''},
 'constructed': {'vbd_to_vb': 'construct', 'vbn_to_vb': 'construct', 'vbn_to_vbg': 'constructing', 'vbd_eq_vbn': ''},
 'constituted': {'vbd_to_vb': 'constitute', 'vbn_to_vb': 'constitute', 'vbn_to_vbg': 'constituting', 'vbd_eq_vbn': ''},
 'consisted': {'vbd_to_vb': 'consist', 'vbn_to_vb': 'consist', 'vbn_to_vbg': 'consisting', 'vbd_eq_vbn': ''},
 'considered': {'vbd_to_vb': 'consider', 'vbn_to_vb': 'consider', 'vbn_to_vbg': 'considering', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'consented': {'vbd_to_vb': 'consent', 'vbn_to_vb': 'consent', 'vbn_to_vbg': 'consenting', 'vbd_eq_vbn': ''},
 'conflicted': {'vbd_to_vb': 'conflict', 'vbn_to_vb': 'conflict', 'vbn_to_vbg': 'conflicting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'con\x1dfirmed': {'vbd_to_vb': 'con\x1dfirm', 'vbn_to_vb': 'con\x1dfirm', 'vbn_to_vbg': 'con\x1dfirming'},
 'con\x1dfined': {'vbd_to_vb': 'con\x1dfine', 'vbn_to_vb': 'con\x1dfine', 'vbn_to_vbg': 'con\x1dfining'},
 'conducted': {'vbd_to_vb': 'conduct', 'vbn_to_vb': 'conduct', 'vbn_to_vbg': 'conducting', 'vbd_eq_vbn': ''},
 'conditioned': {'vbd_to_vb': 'condition', 'vbn_to_vb': 'condition', 'vbn_to_vbg': 'conditioning', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'concluded': {'vbd_to_vb': 'conclude', 'vbn_to_vb': 'conclude', 'vbn_to_vbg': 'concluding', 'vbd_eq_vbn': ''},
 'concerted': {'vbd_to_vb': 'concert', 'vbn_to_vb': 'concert', 'vbn_to_vbg': 'concerting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'comprised': {'vbd_to_vb': 'comprise', 'vbn_to_vb': 'comprise', 'vbn_to_vbg': 'comprising', 'vbd_eq_vbn': ''},
 'complicateded': {'vbd_to_vb': 'complicated', 'vbn_to_vb': 'complicated', 'vbn_to_vbg': 'complicateding'},
 'completed': {'vbd_to_vb': 'complete', 'vbn_to_vb': 'complete', 'vbn_to_vbg': 'completing', 'vbd_eq_vbn': ''},
 'complained': {'vbd_to_vb': 'complain', 'vbn_to_vb': 'complain', 'vbn_to_vbg': 'complaining', 'vbd_eq_vbn': ''},
 'competed': {'vbd_to_vb': 'compete', 'vbn_to_vb': 'compete', 'vbn_to_vbg': 'competing', 'vbd_eq_vbn': ''},
 'communicated': {'vbd_to_vb': 'communicate', 'vbn_to_vb': 'communicate', 'vbn_to_vbg': 'communicating', 'vbd_eq_vbn': ''},
 'commited': {'vbd_to_vb': 'commit', 'vbn_to_vb': 'commit', 'vbn_to_vbg': 'commiting'},
 'commissioned': {'vbd_to_vb': 'commission', 'vbn_to_vb': 'commission', 'vbn_to_vbg': 'commissioning', 'vbd_eq_vbn': ''},
 'commented': {'vbd_to_vb': 'comment', 'vbn_to_vb': 'comment', 'vbn_to_vbg': 'commenting', 'vbd_eq_vbn': ''},
 'commanded': {'vbd_to_vb': 'command', 'vbn_to_vb': 'command', 'vbn_to_vbg': 'commanding', 'vbd_eq_vbn': ''},
 'came': {'vbd_to_vb': 'come', 'vbd_to_vbn': 'come', 'vi_typical': ''},
 'coloured': {'vbd_to_vb': 'colour', 'vbn_to_vb': 'colour', 'vbn_to_vbg': 'colouring', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'collected': {'vbd_to_vb': 'collect', 'vbn_to_vb': 'collect', 'vbn_to_vbg': 'collecting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'collared': {'vbd_to_vb': 'collar', 'vbn_to_vb': 'collar', 'vbn_to_vbg': 'collaring', 'vbd_eq_vbn': ''},
 'collapsed': {'vbd_to_vb': 'collapse', 'vbn_to_vb': 'collapse', 'vbn_to_vbg': 'collapsing', 'vbd_eq_vbn': ''},
 'coined': {'vbd_to_vb': 'coin', 'vbn_to_vb': 'coin', 'vbn_to_vbg': 'coining', 'vbd_eq_vbn': ''},
 'coded': {'vbd_to_vb': 'code', 'vbn_to_vb': 'code', 'vbn_to_vbg': 'coding', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'coated': {'vbd_to_vb': 'coat', 'vbn_to_vb': 'coat', 'vbn_to_vbg': 'coating', 'vbd_eq_vbn': ''},
 'coasted': {'vbd_to_vb': 'coast', 'vbn_to_vb': 'coast', 'vbn_to_vbg': 'coasting', 'vbd_eq_vbn': ''},
 'coaled': {'vbd_to_vb': 'coal', 'vbn_to_vb': 'coal', 'vbn_to_vbg': 'coaling', 'vbd_eq_vbn': ''},
 'coached': {'vbd_to_vb': 'coach', 'vbn_to_vb': 'coach', 'vbn_to_vbg': 'coaching', 'vbd_eq_vbn': ''},
 'clued': {'vbd_to_vb': 'clue', 'vbn_to_vb': 'clue', 'vbn_to_vbg': 'cluing', 'vbd_eq_vbn': ''},
 'clouded': {'vbd_to_vb': 'cloud', 'vbn_to_vb': 'cloud', 'vbn_to_vbg': 'clouding', 'vbd_eq_vbn': ''},
 'closeted': {'vbd_to_vb': 'closet', 'vbn_to_vb': 'closet', 'vbn_to_vbg': 'closeting', 'vbd_eq_vbn': ''},
 'closed': {'vbd_to_vb': 'close', 'vbn_to_vb': 'close', 'vbn_to_vbg': 'closing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'clocked': {'vbd_to_vb': 'clock', 'vbn_to_vb': 'clock', 'vbn_to_vbg': 'clocking', 'vbd_eq_vbn': ''},
 'climbed': {'vbd_to_vb': 'climb', 'vbn_to_vb': 'climb', 'vbn_to_vbg': 'climbing', 'vbd_eq_vbn': ''},
 'clicked': {'vbd_to_vb': 'click', 'vbn_to_vb': 'click', 'vbn_to_vbg': 'clicking', 'vbd_eq_vbn': ''},
 'clerked': {'vbd_to_vb': 'clerk', 'vbn_to_vb': 'clerk', 'vbn_to_vbg': 'clerking', 'vbd_eq_vbn': ''},
 'claimed': {'vbd_to_vb': 'claim', 'vbn_to_vb': 'claim', 'vbn_to_vbg': 'claiming', 'vbd_eq_vbn': ''},
 'chucked': {'vbd_to_vb': 'chuck', 'vbn_to_vb': 'chuck', 'vbn_to_vbg': 'chucking', 'vbd_eq_vbn': ''},
 'choopped': {'vbd_to_vb': 'chop', 'vbn_to_vb': 'chop', 'vbn_to_vbg': 'chopping'},
 'chose': {'vbd_to_vb': 'choose', 'vbd_to_vbn': 'chosen', 'v_to_vb': ''},
 'cheated': {'vbd_to_vb': 'cheat', 'vbn_to_vb': 'cheat', 'vbn_to_vbg': 'cheating', 'vbd_eq_vbn': ''},
 'chased': {'vbd_to_vb': 'chase', 'vbn_to_vb': 'chase', 'vbn_to_vbg': 'chasing', 'vbd_eq_vbn': ''},
 'charged': {'vbd_to_vb': 'charge', 'vbn_to_vb': 'charge', 'vbn_to_vbg': 'charging', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'characterized': {'vbd_to_vb': 'characterize', 'vbn_to_vb': 'characterize', 'vbn_to_vbg': 'characterizing', 'vbd_eq_vbn': ''},
 'changed': {'vbd_to_vb': 'change', 'vbn_to_vb': 'change', 'vbn_to_vbg': 'changing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'challenged': {'vbd_to_vb': 'challenge', 'vbn_to_vb': 'challenge', 'vbn_to_vbg': 'challenging', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'celebrated': {'vbd_to_vb': 'celebrate', 'vbn_to_vb': 'celebrate', 'vbn_to_vbg': 'celebrating', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'ceased': {'vbd_to_vb': 'cease', 'vbn_to_vb': 'cease', 'vbn_to_vbg': 'ceasing', 'vbd_eq_vbn': ''},
 'caused': {'vbd_to_vb': 'cause', 'vbn_to_vb': 'cause', 'vbn_to_vbg': 'causing', 'vbd_eq_vbn': ''},
 'caught': {'vbd_to_vb': 'catch', 'vbn_to_vb': 'catch', 'vbn_to_vbg': 'catching', 'vbd_eq_vbn': ''},
 'casted': {'vbd_to_vb': 'cast', 'vbn_to_vb': 'cast', 'vbn_to_vbg': 'casting'},
 'cashed': {'vbd_to_vb': 'cash', 'vbn_to_vb': 'cash', 'vbn_to_vbg': 'cashing', 'vbd_eq_vbn': ''},
 'carried': {'vbd_to_vb': 'carry', 'vbn_to_vb': 'carry', 'vbn_to_vbg': 'carrying', 'vbd_eq_vbn': ''},
 'carpeted': {'vbd_to_vb': 'carpet', 'vbn_to_vb': 'carpet', 'vbn_to_vbg': 'carpeting', 'vbd_eq_vbn': ''},
 'cared': {'vbd_to_vb': 'care', 'vbn_to_vb': 'care', 'vbn_to_vbg': 'caring', 'vbd_eq_vbn': ''},
 'captured': {'vbd_to_vb': 'capture', 'vbn_to_vb': 'capture', 'vbn_to_vbg': 'capturing', 'vbd_eq_vbn': ''},
 'captained': {'vbd_to_vb': 'captain', 'vbn_to_vb': 'captain', 'vbn_to_vbg': 'captaining', 'vbd_eq_vbn': ''},
 'candied': {'vbd_to_vb': 'candy', 'vbn_to_vb': 'candy', 'vbn_to_vbg': 'candying', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'canceled': {'vbd_to_vb': 'cancel', 'vbn_to_vb': 'cancel', 'vbn_to_vbg': 'canceling', 'vbd_eq_vbn': ''},
 'campaigned': {'vbd_to_vb': 'campaign', 'vbn_to_vb': 'campaign', 'vbn_to_vbg': 'campaigning', 'vbd_eq_vbn': ''},
 'calmed': {'vbd_to_vb': 'calm', 'vbn_to_vb': 'calm', 'vbn_to_vbg': 'calming', 'vbd_eq_vbn': ''},
 'calendared': {'vbd_to_vb': 'calendar', 'vbn_to_vb': 'calendar', 'vbn_to_vbg': 'calendaring', 'vbd_eq_vbn': ''},
 'calculated': {'vbd_to_vb': 'calculate', 'vbn_to_vb': 'calculate', 'vbn_to_vbg': 'calculating', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'cabled': {'vbd_to_vb': 'cable', 'vbn_to_vb': 'cable', 'vbn_to_vbg': 'cabling', 'vbd_eq_vbn': ''},
 'bought': {'vbd_to_vb': 'buy', 'vbn_to_vb': 'buy', 'vbn_to_vbg': 'buying', 'vt_typical': '', 'vbd_eq_vbn': ''},
 'butchered': {'vbd_to_vb': 'butcher', 'vbn_to_vb': 'butcher', 'vbn_to_vbg': 'butchering', 'vbd_eq_vbn': ''},
 'bursted': {'vbd_to_vb': 'burst', 'vbn_to_vb': 'burst', 'vbn_to_vbg': 'bursting'},
 'burned': {'vbd_to_vb': 'burn', 'vbn_to_vb': 'burn', 'vbn_to_vbg': 'burning', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'bunched': {'vbd_to_vb': 'bunch', 'vbn_to_vb': 'bunch', 'vbn_to_vbg': 'bunching', 'vbd_eq_vbn': ''},
 'bumped': {'vbd_to_vb': 'bump', 'vbn_to_vb': 'bump', 'vbn_to_vbg': 'bumping', 'vbd_eq_vbn': ''},
 'built': {'vbd_to_vb': 'build', 'vbn_to_vb': 'build', 'vbn_to_vbg': 'building', 'vbd_eq_vbn': ''},
 'bugged': {'vbd_to_vb': 'bug', 'vbn_to_vb': 'bug', 'vbn_to_vbg': 'bugging', 'vbd_eq_vbn': ''},
 'budgeted': {'vbd_to_vb': 'budget', 'vbn_to_vb': 'budget', 'vbn_to_vbg': 'budgeting', 'vbd_eq_vbn': ''},
 'bucketed': {'vbd_to_vb': 'bucket', 'vbn_to_vb': 'bucket', 'vbn_to_vbg': 'bucketing', 'vbd_eq_vbn': ''},
 'bucked': {'vbd_to_vb': 'buck', 'vbn_to_vb': 'buck', 'vbn_to_vbg': 'bucking', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'brought': {'vbd_to_vb': 'bring', 'vbn_to_vb': 'bring', 'vbn_to_vbg': 'bringing', 'vbd_eq_vbn': ''},
 'bridged': {'vbd_to_vb': 'bridge', 'vbn_to_vb': 'bridge', 'vbn_to_vbg': 'bridging', 'vbd_eq_vbn': ''},
 'bricked': {'vbd_to_vb': 'brick', 'vbn_to_vb': 'brick', 'vbn_to_vbg': 'bricking', 'vbd_eq_vbn': ''},
 'breathed': {'vbd_to_vb': 'breathe', 'vbn_to_vb': 'breathe', 'vbn_to_vbg': 'breathing', 'vbd_eq_vbn': ''},
 'breasted': {'vbd_to_vb': 'breast', 'vbn_to_vb': 'breast', 'vbn_to_vbg': 'breasting', 'vbd_eq_vbn': ''},
 'broke': {'vbd_to_vb': 'break', 'vbd_to_vbn': 'broken'},
 'braved': {'vbd_to_vb': 'brave', 'vbn_to_vb': 'brave', 'vbn_to_vbg': 'braving', 'vbd_eq_vbn': ''},
 'branched': {'vbd_to_vb': 'branch', 'vbn_to_vb': 'branch', 'vbn_to_vbg': 'branching', 'vbd_eq_vbn': ''},
 'bowled': {'vbd_to_vb': 'bowl', 'vbn_to_vb': 'bowl', 'vbn_to_vbg': 'bowling', 'vbd_eq_vbn': ''},
 'bounced': {'vbd_to_vb': 'bounce', 'vbn_to_vb': 'bounce', 'vbn_to_vbg': 'bouncing', 'vbd_eq_vbn': ''},
 'bothered': {'vbd_to_vb': 'bother', 'vbn_to_vb': 'bother', 'vbn_to_vbg': 'bothering', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'bossed': {'vbd_to_vb': 'boss', 'vbn_to_vb': 'boss', 'vbn_to_vbg': 'bossing', 'vbd_eq_vbn': ''},
 'booted': {'vbd_to_vb': 'boot', 'vbn_to_vb': 'boot', 'vbn_to_vbg': 'booting', 'vbd_eq_vbn': ''},
 'booked': {'vbd_to_vb': 'book', 'vbn_to_vb': 'book', 'vbn_to_vbg': 'booking', 'vbd_eq_vbn': ''},
 'bombed': {'vbd_to_vb': 'bomb', 'vbn_to_vb': 'bomb', 'vbn_to_vbg': 'bombing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'boilinged': {'vbd_to_vb': 'boiling', 'vbn_to_vb': 'boiling'},
 'boiled': {'vbd_to_vb': 'boil', 'vbn_to_vb': 'boil', 'vbn_to_vbg': 'boiling', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'boated': {'vbd_to_vb': 'boat', 'vbn_to_vb': 'boat', 'vbn_to_vbg': 'boating', 'vbd_eq_vbn': ''},
 'boarded': {'vbd_to_vb': 'board', 'vbn_to_vb': 'board', 'vbn_to_vbg': 'boarding', 'vbd_eq_vbn': ''},
 'blued': {'vbd_to_vb': 'blue', 'vbn_to_vb': 'blue', 'vbn_to_vbg': 'bluing', 'vbd_eq_vbn': ''},
 'blew': {'vbd_to_vb': 'blow', 'vbd_to_vbn': 'blown'},
 'blooded': {'vbd_to_vb': 'blood', 'vbn_to_vb': 'blood', 'vbn_to_vbg': 'blooding', 'vbd_eq_vbn': ''},
 'blinded': {'vbd_to_vb': 'blind', 'vbn_to_vb': 'blind', 'vbn_to_vbg': 'blinding', 'vbd_eq_vbn': ''},
 'billed': {'vbd_to_vb': 'bill', 'vbn_to_vb': 'bill', 'vbn_to_vbg': 'billing', 'vbd_eq_vbn': ''},
 'biked': {'vbd_to_vb': 'bike', 'vbn_to_vb': 'bike', 'vbn_to_vbg': 'biking', 'vbd_eq_vbn': ''},
 'bid/bidden': {'vbd_to_vb': 'bid', 'vbn_to_vb': 'bid', 'vbn_to_vbg': 'bidding'},
 'bicycled': {'vbd_to_vb': 'bicycle', 'vbn_to_vb': 'bicycle', 'vbn_to_vbg': 'bicycling', 'vbd_eq_vbn': ''},
 'bettered': {'vbd_to_vb': 'better', 'vbn_to_vb': 'better', 'vbn_to_vbg': 'bettering', 'vbd_eq_vbn': ''},
 'benefi\x1dted': {'vbd_to_vb': 'benefi\x1dt', 'vbn_to_vb': 'benefi\x1dt', 'vbn_to_vbg': 'benefi\x1dting'},
 'belonged': {'vbd_to_vb': 'belong', 'vbn_to_vb': 'belong', 'vbn_to_vbg': 'belonging', 'vbd_eq_vbn': ''},
 'believed': {'vbd_to_vb': 'believe', 'vbn_to_vb': 'believe', 'vbn_to_vbg': 'believing', 'vbd_eq_vbn': ''},
 'behaved': {'vbd_to_vb': 'behave', 'vbn_to_vb': 'behave', 'vbn_to_vbg': 'behaving', 'vbd_eq_vbn': ''},
 'began': {'vbd_to_vb': 'begin', 'vbn_to_vb': 'begin', 'vbn_to_vbg': 'beginning'},
 'became': {'vbd_to_vb': 'become', 'vbd_to_vbn': 'become'},
 'beared': {'vbd_to_vb': 'bear', 'vbn_to_vb': 'bear', 'vbn_to_vbg': 'bearing'},
 'beached': {'vbd_to_vb': 'beach', 'vbn_to_vb': 'beach', 'vbn_to_vbg': 'beaching', 'vbd_eq_vbn': ''},
 'battled': {'vbd_to_vb': 'battle', 'vbn_to_vb': 'battle', 'vbn_to_vbg': 'battling', 'vbd_eq_vbn': ''},
 'batted': {'vbd_to_vb': 'bat', 'vbn_to_vb': 'bat', 'vbn_to_vbg': 'bating', 'vbd_eq_vbn': ''},
 'based': {'vbd_to_vb': 'base', 'vbn_to_vb': 'base', 'vbn_to_vbg': 'basing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'banged': {'vbd_to_vb': 'bang', 'vbn_to_vb': 'bang', 'vbn_to_vbg': 'banging', 'vbd_eq_vbn': ''},
 'banned': {'vbd_to_vb': 'ban', 'vbn_to_vb': 'ban', 'vbn_to_vbg': 'banning', 'vbd_eq_vbn': ''},
 'baked': {'vbd_to_vb': 'bake', 'vbn_to_vb': 'bake', 'vbn_to_vbg': 'baking', 'vbd_eq_vbn': ''},
 'awarded': {'vbd_to_vb': 'award', 'vbn_to_vb': 'award', 'vbn_to_vbg': 'awarding', 'vbd_eq_vbn': ''},
 'awaked': {'vbd_to_vb': 'awake', 'vbn_to_vb': 'awake', 'vbn_to_vbg': 'awaking', 'vbd_eq_vbn': ''},
 'avoided': {'vbd_to_vb': 'avoid', 'vbn_to_vb': 'avoid', 'vbn_to_vbg': 'avoiding', 'vbd_eq_vbn': ''},
 'attracted': {'vbd_to_vb': 'attract', 'vbn_to_vb': 'attract', 'vbn_to_vbg': 'attracting', 'vbd_eq_vbn': ''},
 'attended': {'vbd_to_vb': 'attend', 'vbn_to_vb': 'attend', 'vbn_to_vbg': 'attending', 'vbd_eq_vbn': ''},
 'attacked': {'vbd_to_vb': 'attack', 'vbn_to_vb': 'attack', 'vbn_to_vbg': 'attacking', 'vbd_eq_vbn': ''},
 'associated': {'vbd_to_vb': 'associate', 'vbn_to_vb': 'associate', 'vbn_to_vbg': 'associating', 'vbd_eq_vbn': ''},
 'assisted': {'vbd_to_vb': 'assist', 'vbn_to_vb': 'assist', 'vbn_to_vbg': 'assisting', 'vbd_eq_vbn': ''},
 'assessed': {'vbd_to_vb': 'assess', 'vbn_to_vb': 'assess', 'vbn_to_vbg': 'assessing', 'vbd_eq_vbn': ''},
 'asked': {'vbd_to_vb': 'ask', 'vbn_to_vb': 'ask', 'vbn_to_vbg': 'asking', 'vbd_eq_vbn': ''},
 'arrested': {'vbd_to_vb': 'arrest', 'vbn_to_vb': 'arrest', 'vbn_to_vbg': 'arresting', 'vbd_eq_vbn': ''},
 'arised': {'vbd_to_vb': 'arise', 'vbn_to_vb': 'arise', 'vbn_to_vbg': 'arising'},
 'argumented': {'vbd_to_vb': 'argument', 'vbn_to_vb': 'argument', 'vbn_to_vbg': 'argumenting', 'vbd_eq_vbn': ''},
 'argued': {'vbd_to_vb': 'argue', 'vbn_to_vb': 'argue', 'vbn_to_vbg': 'arguing', 'vbd_eq_vbn': ''},
 'approximated': {'vbd_to_vb': 'approximate', 'vbn_to_vb': 'approximate', 'vbn_to_vbg': 'approximating', 'vbd_eq_vbn': ''},
 'approved': {'vbd_to_vb': 'approve', 'vbn_to_vb': 'approve', 'vbn_to_vbg': 'approving', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'appropriated': {'vbd_to_vb': 'appropriate', 'vbn_to_vb': 'appropriate', 'vbn_to_vbg': 'appropriating', 'vbd_eq_vbn': ''},
 'approached': {'vbd_to_vb': 'approach', 'vbn_to_vb': 'approach', 'vbn_to_vbg': 'approaching', 'vbd_eq_vbn': ''},
 'appreciated': {'vbd_to_vb': 'appreciate', 'vbn_to_vb': 'appreciate', 'vbn_to_vbg': 'appreciating', 'vbd_eq_vbn': ''},
 'appointed': {'vbd_to_vb': 'appoint', 'vbn_to_vb': 'appoint', 'vbn_to_vbg': 'appointing', 'vbd_eq_vbn': ''},
 'appeared': {'vbd_to_vb': 'appear', 'vbn_to_vb': 'appear', 'vbn_to_vbg': 'appearing', 'vbd_eq_vbn': ''},
 'appealed': {'vbd_to_vb': 'appeal', 'vbn_to_vb': 'appeal', 'vbn_to_vbg': 'appealing', 'vbd_eq_vbn': ''},
 'apologized': {'vbd_to_vb': 'apologize', 'vbn_to_vb': 'apologize', 'vbn_to_vbg': 'apologizing', 'vbd_eq_vbn': ''},
 'anticipated': {'vbd_to_vb': 'anticipate', 'vbn_to_vb': 'anticipate', 'vbn_to_vbg': 'anticipating', 'vbd_eq_vbn': ''},
 'answered': {'vbd_to_vb': 'answer', 'vbn_to_vb': 'answer', 'vbn_to_vbg': 'answering', 'vbd_eq_vbn': ''},
 'announced': {'vbd_to_vb': 'announce', 'vbn_to_vb': 'announce', 'vbn_to_vbg': 'announcing', 'vbd_eq_vbn': ''},
 'analysed': {'vbd_to_vb': 'analyse', 'vbn_to_vb': 'analyse', 'vbn_to_vbg': 'analysing', 'vbd_eq_vbn': ''},
 'amounted': {'vbd_to_vb': 'amount', 'vbn_to_vb': 'amount', 'vbn_to_vbg': 'amounting', 'vbd_eq_vbn': ''},
 'altered': {'vbd_to_vb': 'alter', 'vbn_to_vb': 'alter', 'vbn_to_vbg': 'altering', 'vbd_eq_vbn': ''},
 'allowed': {'vbd_to_vb': 'allow', 'vbn_to_vb': 'allow', 'vbn_to_vbg': 'allowing', 'vbd_eq_vbn': ''},
 'alarmed': {'vbd_to_vb': 'alarm', 'vbn_to_vb': 'alarm', 'vbn_to_vbg': 'alarming', 'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'aired': {'vbd_to_vb': 'air', 'vbn_to_vb': 'air', 'vbn_to_vbg': 'airing', 'vbd_eq_vbn': ''},
 'aimed': {'vbd_to_vb': 'aim', 'vbn_to_vb': 'aim', 'vbn_to_vbg': 'aiming', 'vbd_eq_vbn': ''},
 'agreed': {'vbd_to_vb': 'agree', 'vbn_to_vb': 'agree', 'vbn_to_vbg': 'agreeing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'a\x1efforded': {'vbd_to_vb': 'a\x1efford', 'vbn_to_vb': 'a\x1efford', 'vbn_to_vbg': 'a\x1effording'},
 'a\x1effected': {'vbd_to_vb': 'a\x1effect', 'vbn_to_vb': 'a\x1effect', 'vbn_to_vbg': 'a\x1effecting'},
 'advised': {'vbd_to_vb': 'advise', 'vbn_to_vb': 'advise', 'vbn_to_vbg': 'advising', 'vbd_eq_vbn': ''},
 'adverted': {'vbd_to_vb': 'advert', 'vbn_to_vb': 'advert', 'vbn_to_vbg': 'adverting', 'vbd_eq_vbn': ''},
 'adopted': {'vbd_to_vb': 'adopt', 'vbn_to_vb': 'adopt', 'vbn_to_vbg': 'adopting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'admited': {'vbd_to_vb': 'admit', 'vbn_to_vb': 'admit', 'vbn_to_vbg': 'admiting'},
 'added': {'vbd_to_vb': 'add', 'vbn_to_vb': 'add', 'vbn_to_vbg': 'adding', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'adapted': {'vbd_to_vb': 'adapt', 'vbn_to_vb': 'adapt', 'vbn_to_vbg': 'adapting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'acted': {'vbd_to_vb': 'act', 'vbn_to_vb': 'act', 'vbn_to_vbg': 'acting', 'vbd_eq_vbn': ''},
 'acquired': {'vbd_to_vb': 'acquire', 'vbn_to_vb': 'acquire', 'vbn_to_vbg': 'acquiring', 'vbd_eq_vbn': ''},
 'acknowledged': {'vbd_to_vb': 'acknowledge', 'vbn_to_vb': 'acknowledge', 'vbn_to_vbg': 'acknowledging', 'vbd_eq_vbn': ''},
 'achieved': {'vbd_to_vb': 'achieve', 'vbn_to_vb': 'achieve', 'vbn_to_vbg': 'achieving', 'vbd_eq_vbn': ''},
 'accounted': {'vbd_to_vb': 'account', 'vbn_to_vb': 'account', 'vbn_to_vbg': 'accounting', 'vbd_eq_vbn': ''},
 'accompanied': {'vbd_to_vb': 'accompany', 'vbn_to_vb': 'accompany', 'vbn_to_vbg': 'accompanying', 'vbd_eq_vbn': ''},
 'accessed': {'vbd_to_vb': 'access', 'vbn_to_vb': 'access', 'vbn_to_vbg': 'accessing', 'vbd_eq_vbn': ''},
 'accepted': {'vbd_to_vb': 'accept', 'vbn_to_vb': 'accept', 'vbn_to_vbg': 'accepting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'abused': {'vbd_to_vb': 'abuse', 'vbn_to_vb': 'abuse', 'vbn_to_vbg': 'abusing', 'vbd_eq_vbn': ''},
 'absorbed': {'vbd_to_vb': 'absorb', 'vbn_to_vb': 'absorb', 'vbn_to_vbg': 'absorbing', 'vbd_eq_vbn': ''},
 'writes': {'vbz_to_vb': 'write'},
 'worries': {'vbz_to_vb': 'worry'},
 'wonders': {'vbz_to_vb': 'wonder'},
 'withdraws': {'vbz_to_vb': 'withdraw'},
 'wipes': {'vbz_to_vb': 'wipe'},
 'winds': {'vbz_to_vb': 'wind'},
 'whispers': {'vbz_to_vb': 'whisper'},
 'welcomes': {'vbz_to_vb': 'welcome'},
 'weighs': {'vbz_to_vb': 'weigh'},
 'wears': {'vbz_to_vb': 'wear'},
 'wastes': {'vbz_to_vb': 'waste'},
 'washes': {'vbz_to_vb': 'wash'},
 'warns': {'vbz_to_vb': 'warn'},
 'wants': {'vbz_to_vb': 'want'},
 'wanders': {'vbz_to_vb': 'wander'},
 'waits': {'vbz_to_vb': 'wait'},
 'varies': {'vbz_to_vb': 'vary'},
 'uses': {'vbz_to_vb': 'use'},
 'upsets': {'vbz_to_vb': 'upset'},
 'undertakes': {'vbz_to_vb': 'undertake'},
 'understands': {'vbz_to_vb': 'understand'},
 'tries': {'vbz_to_vb': 'try'},
 'trusts': {'vbz_to_vb': 'trust'},
 'travels': {'vbz_to_vb': 'travel'},
 'translates': {'vbz_to_vb': 'translate'},
 'transforms': {'vbz_to_vb': 'transform'},
 'transfers': {'vbz_to_vb': 'transfer'},
 'trades': {'vbz_to_vb': 'trade'},
 'touches': {'vbz_to_vb': 'touch'},
 'throws': {'vbz_to_vb': 'throw'},
 'threatens': {'vbz_to_vb': 'threaten'},
 'thinks': {'vbz_to_vb': 'think'},
 'tends': {'vbz_to_vb': 'tend'},
 'tells': {'vbz_to_vb': 'tell'},
 'teaches': {'vbz_to_vb': 'teach'},
 'tastes': {'vbz_to_vb': 'taste'},
 'takes': {'vbz_to_vb': 'take'},
 'tackles': {'vbz_to_vb': 'tackle'},
 'swings': {'vbz_to_vb': 'swing'},
 'swims': {'vbz_to_vb': 'swim'},
 'swears': {'vbz_to_vb': 'swear'},
 'swaps': {'vbz_to_vb': 'swap'},
 'sustains': {'vbz_to_vb': 'sustain'},
 'survives': {'vbz_to_vb': 'survive'},
 'surrounds': {'vbz_to_vb': 'surround'},
 'suppses': {'vbz_to_vb': 'suppose'},
 'suggests': {'vbz_to_vb': 'suggest'},
 'suffers': {'vbz_to_vb': 'suffer'},
 'succeeds': {'vbz_to_vb': 'succeed', 'vbz_to_nns': 'successes'},
 'submits': {'vbz_to_vb': 'submit'},
 'stuffs': {'vbz_to_vb': 'stuff'},
 'stretches': {'vbz_to_vb': 'stretch'},
 'strengthens': {'vbz_to_vb': 'strengthen'},
 'starves': {'vbz_to_vb': 'starve'},
 'stands': {'vbz_to_vb': 'stand'},
 'spreads': {'vbz_to_vb': 'spread'},
 'sprays': {'vbz_to_vb': 'spray'},
 'spoils': {'vbz_to_vb': 'spoil'},
 'spills': {'vbz_to_vb': 'spill'},
 'spends': {'vbz_to_vb': 'spend'},
 'speaks': {'vbz_to_vb': 'speak'},
 'solves': {'vbz_to_vb': 'solve'},
 'snapps': {'vbz_to_vb': 'snap'},
 'smokes': {'vbz_to_vb': 'smoke'},
 'slows': {'vbz_to_vb': 'slow'},
 'sleeps': {'vbz_to_vb': 'sleep', 'nns_to_nn': 'sleep'},
 'skins': {'vbz_to_vb': 'skin'},
 'sits': {'vbz_to_vb': 'sit'},
 'sins': {'vbz_to_vb': 'sin'},
 'silvers': {'vbz_to_vb': 'silver'},
 'activate': {'vb_to_rb': 'actively', 'vb_to_nn': 'activity', 'vb_to_jj': 'active', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'actualize': {'vb_to_rb': 'actually', 'vb_to_nn': 'actuality', 'vb_to_jj': 'actual', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'arbitrate': {'vb_to_rb': 'arbitrarily', 'vb_to_nn': 'arbitrariness', 'vb_to_jj': 'arbitrary', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'automate': {'vb_to_rb': 'automatic', 'vb_to_nn': 'automation', 'vb_to_jj': 'automatic', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'broaden': {'vb_to_rb': 'broad', 'vb_to_jj': 'broad', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'capacitate': {'vb_to_rb': 'capably', 'vb_to_nn': 'capacity', 'vb_to_jj': 'capable'},
 'deepen': {'vb_to_rb': 'deeply', 'vb_to_nn': 'deep', 'vb_to_jj': 'deep', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'diversify': {'vb_to_rb': 'diversely', 'vb_to_nn': 'diversity', 'vb_to_jj': 'diverse', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'dramatize': {'vb_to_rb': 'dramatically', 'vb_to_nn': 'drama', 'vb_to_jj': 'dramatic', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'excel': {'vb_to_rb': 'excellently', 'vb_to_nn': 'excellence', 'vb_to_jj': 'excellent', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'externalise': {'vb_to_rb': 'externally', 'vb_to_nn': 'externality', 'vb_to_jj': 'external'},
 'fatten': {'vb_to_rb': 'fatly', 'vb_to_nn': 'fat', 'vb_to_jj': 'fat', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'finalise': {'vb_to_rb': 'finally', 'vb_to_nn': 'final', 'vb_to_jj': 'final'},
 'harden': {'vb_to_rb': 'hard', 'vb_to_nn': 'hardness', 'vb_to_jj': 'hard', 'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'intensify': {'vb_to_rb': 'intensely', 'vb_to_nn': 'intensity', 'vb_to_jj': 'intense', 'vbd_eq_vbn': ''},
 'internalize': {'vb_to_rb': 'internally', 'vb_to_jj': 'internal', 'vbd_eq_vbn': ''},
 'lighten': {'vb_to_rb': 'light', 'vb_to_nn': 'light', 'vb_to_jj': 'light', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'minimise': {'vb_to_rb': 'minimally', 'vb_to_nn': 'minimum', 'vb_to_jj': 'minimum'},
 'normalize': {'vb_to_rb': 'normally', 'vb_to_nn': 'normality', 'vb_to_jj': 'normal', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'offend': {'vb_to_rb': 'offensively', 'vb_to_nn': 'offendence', 'vb_to_jj': 'offensive', 'v_prprtcl_non': '', 'vbg_non': ''},
 'originate': {'vb_to_rb': 'originally', 'vb_to_nn': 'origin', 'vb_to_jj': 'original', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'persist': {'vb_to_rb': 'persistently', 'vb_to_nn': 'persistence', 'vb_to_jj': 'persistent', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'precede': {'vb_to_rb': 'precedently', 'vb_to_nn': 'precedence', 'vb_to_jj': 'precedent', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'predominate': {'vb_to_rb': 'predominantly', 'vb_to_nn': 'predominance', 'vb_to_jj': 'predominant', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'rationalise': {'vb_to_rb': 'rationally', 'vb_to_nn': 'rationalisation', 'vb_to_jj': 'rational'},
 'reactivate': {'vb_to_rb': 'reactively', 'vb_to_nn': 'reaction', 'vb_to_jj': 'reactive', 'vbd_eq_vbn': ''},
 'sadden': {'vb_to_rb': 'sadly', 'vb_to_nn': 'sadness', 'vb_to_jj': 'sad', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'sharpen': {'vb_to_rb': 'sharply', 'vb_to_nn': 'sharpness', 'vb_to_jj': 'sharp', 'v_compcl_non': '', 'v_infcl_non': ''},
 'shorten': {'vb_to_rb': 'shortly', 'vb_to_nn': 'short', 'vb_to_jj': 'short', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'soften': {'vb_to_rb': 'softly', 'vb_to_nn': 'soft', 'vb_to_jj': 'softened', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'solidify': {'vb_to_rb': 'solidly', 'vb_to_nn': 'solid', 'vb_to_jj': 'solidified', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'specialize': {'vb_to_rb': 'specially', 'vb_to_nn': 'special', 'vb_to_jj': 'specialist', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'stiffen': {'vb_to_rb': 'stiff', 'vb_to_nn': 'stiff', 'vb_to_jj': 'stiff', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'straighten': {'vb_to_rb': 'straight', 'vb_to_nn': 'straight', 'vb_to_jj': 'straight', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'stylise': {'vb_to_rb': 'stylishly', 'vb_to_nn': 'style', 'vb_to_jj': 'stylized'},
 'stylize': {'vb_to_rb': 'stylishly', 'vb_to_nn': 'style', 'vb_to_jj': 'stylized'},
 'symbolise': {'vb_to_rb': 'symbolically', 'vb_to_nn': 'symbol', 'vb_to_jj': 'symbolic'},
 'symbolize': {'vb_to_rb': 'symbolically', 'vb_to_nn': 'symbol', 'vb_to_jj': 'symbolic', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vbg_non': ''},
 'theatricalize': {'vb_to_rb': 'theatrically', 'vb_to_nn': 'theatre', 'vb_to_jj': 'theatrical'},
 'tighten': {'vb_to_rb': 'tightly', 'vb_to_nn': 'tightness', 'vb_to_jj': 'tight', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'totalize': {'vb_to_rb': 'totally', 'vb_to_nn': 'total', 'vb_to_jj': 'total'},
 'toughen': {'vb_to_rb': 'toughly', 'vb_to_nn': 'tough', 'vb_to_jj': 'tough', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'transmit': {'vb_to_rb': 'transmissively', 'vb_to_nn': 'transmission', 'vb_to_jj': 'transmissive', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'uglify': {'vb_to_rb': 'uglily', 'vb_to_nn': 'uglifier', 'vb_to_jj': 'ugly'},
 'unite': {'vb_to_rb': 'unitively', 'vb_to_nn': 'unity', 'vb_to_jj': 'unitive', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'validate': {'vb_to_rb': 'validly', 'vb_to_nn': 'validation', 'vb_to_jj': 'valid', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vbg_non': ''},
 'violate': {'vb_to_rb': 'violably', 'vb_to_nn': 'violator', 'vb_to_jj': 'violable', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'virtualize': {'vb_to_rb': 'virtually', 'vb_to_nn': 'virtualization', 'vb_to_jj': 'virtual'},
 'visualise': {'vb_to_rb': 'visually', 'vb_to_nn': 'visualisation', 'vb_to_jj': 'visual'},
 'visualize': {'vb_to_rb': 'visually', 'vb_to_nn': 'visualisation', 'vb_to_jj': 'visual', 'v_compcl_non': '', 'v_infcl_non': ''},
 'wast': {'vb_to_rb': 'wastefully', 'vb_to_nn': 'waste', 'vb_to_jj': 'wasteful'},
 'weaken': {'vb_to_rb': 'weakly', 'vb_to_nn': 'weakness', 'vb_to_jj': 'weak', 'vbd_eq_vbn': ''},
 'wetten': {'vb_to_rb': 'wetly', 'vb_to_nn': 'wet', 'vb_to_jj': 'wet'},
 'widen': {'vb_to_rb': 'widely', 'vb_to_nn': 'wide', 'vb_to_jj': 'wide', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'wisen': {'vb_to_rb': 'wisely', 'vb_to_nn': 'wise', 'vb_to_jj': 'wise'},
 'youthen': {'vb_to_rb': 'youthfully', 'vb_to_nn': 'youth', 'vb_to_jj': 'youthful'},
 'accommodate': {'vb_to_nn': 'accommodation', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'accumulate': {'vb_to_nn': 'accumulation', 'vb_to_jj': 'accumulative', 'v_prprtcl_non': ''},
 'accustom': {'vb_to_nn': 'accustomization'},
 'administrate': {'vb_to_nn': 'administration', 'vb_to_jj': 'administrative', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'allocate': {'vb_to_nn': 'allocation', 'vb_to_jj': 'allocative', 'v_compcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'amend': {'vb_to_nn': 'amendment', 'vb_to_jj': 'amenable', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'amuse': {'vb_to_nn': 'amusement', 'vb_to_jj': 'amusing', 'vb_to_vbn': 'amused', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'analogize': {'vb_to_nn': 'analogy', 'vb_to_jj': 'analogous', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'applaud': {'vb_to_nn': 'applause', 'vb_to_jj': 'applaudable', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'artificialize': {'vb_to_nn': 'artificiality', 'vb_to_jj': 'artificial'},
 'assemble': {'vb_to_nn': 'assembly', 'vb_to_jj': 'assembling', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'assign': {'vb_to_nn': 'assignment', 'vb_to_jj': 'assigned', 'v_compcl_non': '', 'v_whcl_non': ''},
 'astonish': {'vb_to_nn': 'astonishment', 'vb_to_jj': 'astonishing', 'v_prprtcl_non': '', 'vbg_non': '', 'vt_typical': '', 'vb_to_vbz': 'astonishes'},
 'attain': {'vb_to_nn': 'attainment', 'vb_to_jj': 'attainable', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vt_typical': ''},
 'authorize': {'vb_to_nn': 'authority', 'vb_to_jj': 'authoritative', 'vbd_eq_vbn': '', 'vbg_non': ''},
 'awaken': {'vb_to_nn': 'awakeness', 'vb_to_jj': 'awake', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'beautify': {'vb_to_nn': 'beauty', 'vb_to_jj': 'beautiful', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'categorise': {'vb_to_nn': 'category', 'vb_to_jj': 'categorial'},
 'cite': {'vb_to_nn': 'citation', 'vbd_eq_vbn': ''},
 'civilize': {'vb_to_nn': 'civilisation', 'vb_to_jj': 'civilized', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'clarify': {'vb_to_nn': 'clarification', 'vb_to_jj': 'clarified', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'classify': {'vb_to_nn': 'class', 'vb_to_jj': 'class', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'vt_typical': '', 'v_n_as_n': ''},
 'colonize': {'vb_to_nn': 'colonization', 'vb_to_jj': 'colonial', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'compensate': {'vb_to_nn': 'compensation', 'vb_to_jj': 'compensatory', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'compile': {'vb_to_nn': 'compilation', 'vb_to_jj': 'compiled', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'complicate': {'vb_to_nn': 'complication', 'vb_to_jj': 'complicated', 'vbd_eq_vbn': ''},
 'compose': {'vb_to_nn': 'composition', 'vb_to_jj': 'composed', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'compute': {'vb_to_nn': 'computation', 'vb_to_jj': 'computational', 'vbd_eq_vbn': ''},
 'conceptualise': {'vb_to_nn': 'concept', 'vb_to_jj': 'conceptual'},
 'confer': {'vb_to_nn': 'conference', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'congratulate': {'vb_to_nn': 'congratulation', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'constrain': {'vb_to_nn': 'constraint', 'vb_to_jj': 'constrained', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'consume': {'vb_to_nn': 'consumption', 'vb_to_jj': 'consuming', 'vbd_eq_vbn': '', 'vt_typical': ''},
 'contextualise': {'vb_to_nn': 'context', 'vb_to_jj': 'contextual'},
 'contradict': {'vb_to_nn': 'contradiction', 'vb_to_jj': 'contradictory', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'controvert': {'vb_to_nn': 'controversy', 'vb_to_jj': 'controversial'},
 'convene': {'vb_to_nn': 'convention', 'vb_to_jj': 'conventional', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'cooperate': {'vb_to_nn': 'cooperation', 'vb_to_jj': 'cooperative', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'correspond': {'vb_to_nn': 'correspondence', 'vb_to_jj': 'corresponding', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'vi_typical': ''},
 'cultivate': {'vb_to_nn': 'cultivation', 'vb_to_jj': 'cultivated', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'deceive': {'vb_to_nn': 'deception', 'vb_to_jj': 'deceived', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'depress': {'vb_to_nn': 'depression', 'vb_to_jj': 'depressed', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'descend': {'vb_to_nn': 'descent', 'vb_to_jj': 'descending', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'differentiate': {'vb_to_nn': 'differentiation', 'vb_to_jj': 'differentiated', 'v_compcl_non': '', 'vbg_non': ''},
 'diminish': {'vb_to_nn': 'diminution', 'vb_to_jj': 'diminished', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'discriminate': {'vb_to_nn': 'discrimination', 'vb_to_jj': 'discriminating', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'displace': {'vb_to_nn': 'displacement', 'vb_to_jj': 'displaced', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'distort': {'vb_to_nn': 'distortion', 'vb_to_jj': 'distorted', 'vbd_eq_vbn': ''},
 'eliminate': {'vb_to_nn': 'elimination', 'vb_to_jj': 'eliminating', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'enclose': {'vb_to_nn': 'enclosure', 'vb_to_jj': 'enclosed', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'enforce': {'vb_to_nn': 'enforcement', 'vb_to_jj': 'enforced', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'entertain': {'vb_to_nn': 'entertainment', 'vb_to_jj': 'entertaining', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'equate': {'vb_to_nn': 'equation', 'vb_to_jj': 'equational', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'equip': {'vb_to_nn': 'equipment', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'erode': {'vb_to_nn': 'erosion', 'vb_to_jj': 'eroding', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'evolve': {'vb_to_nn': 'evolution', 'vb_to_jj': 'evolutionary', 'vbd_eq_vbn': ''},
 'facilitate': {'vb_to_nn': 'facilitation', 'vb_to_jj': 'facilitative', 'v_vbg': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'fasten': {'vb_to_nn': 'fastener', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'fluctuate': {'vb_to_nn': 'fluctuation', 'vb_to_jj': 'fluctuating', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'formulate': {'vb_to_nn': 'formula', 'vb_to_jj': 'formulaic', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'generalise': {'vb_to_nn': 'generality', 'vb_to_jj': 'general'},
 'imitate': {'vb_to_nn': 'imitation', 'vb_to_jj': 'imitation', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'immigrate': {'vb_to_nn': 'immigration', 'vb_to_jj': 'immigrant', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'implicate': {'vb_to_nn': 'implication', 'vb_to_jj': 'implicated', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'individualise': {'vb_to_nn': 'individuality', 'vb_to_jj': 'individual'},
 'induce': {'vb_to_nn': 'induction', 'vb_to_jj': 'inducing', 'v_compcl_non': '', 'vbd_eq_vbn': ''},
 'inhibit': {'vb_to_nn': 'inhibition', 'vb_to_jj': 'inhibited', 'v_compcl_non': '', 'v_infcl_non': ''},
 'initialize': {'vb_to_nn': 'initialization', 'vb_to_jj': 'initial'},
 'innovate': {'vb_to_nn': 'innovation', 'vb_to_jj': 'innovative', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'interfere': {'vb_to_nn': 'interference', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'intervene': {'vb_to_nn': 'intervention', 'vb_to_jj': 'intervening', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'itemise': {'vb_to_nn': 'item', 'vb_to_jj': 'item'},
 'kneel': {'vb_to_nn': 'kneeling', 'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'legislate': {'vb_to_nn': 'legislation', 'vb_to_jj': 'legislative', 'vbd_eq_vbn': ''},
 'lengthen': {'vb_to_nn': 'length', 'vb_to_jj': 'lengthy', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'liberalize': {'vb_to_nn': 'liberty', 'vb_to_jj': 'liberal', 'vbd_eq_vbn': ''},
 'manipulate': {'vb_to_nn': 'manipulation', 'vb_to_jj': 'manipulative', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'maximise': {'vb_to_nn': 'maximisation', 'vb_to_jj': 'maximum'},
 'memorise': {'vb_to_nn': 'memory', 'vb_to_jj': 'memorial'},
 'migrate': {'vb_to_nn': 'migration', 'vb_to_jj': 'migrant', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'modernize': {'vb_to_nn': 'modern', 'vb_to_jj': 'modern', 'v_compcl_non': '', 'v_whcl_non': ''},
 'modify': {'vb_to_nn': 'modification', 'vb_to_jj': 'modified', 'v_compcl_non': ''},
 'motivate': {'vb_to_nn': 'motivation', 'vb_to_jj': 'motive', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_n_to_vb': ''},
 'neutralize': {'vb_to_nn': 'neutrality', 'vb_to_jj': 'neutral', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'philosophise': {'vb_to_nn': 'philosopher'},
 'preach': {'vb_to_nn': 'preacher', 'vbd_eq_vbn': ''},
 'prioritise': {'vb_to_nn': 'prioritisation'},
 'publicize': {'vb_to_nn': 'publication', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'purplish': {'vb_to_nn': 'purple'},
 'refine': {'vb_to_nn': 'refinement', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'refresh': {'vb_to_nn': 'refreshment', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'regulate': {'vb_to_nn': 'regulation', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'reproduce': {'vb_to_nn': 'reproduction', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'reside': {'vb_to_nn': 'resident', 'vb_to_jj': 'residential', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'restrain': {'vb_to_nn': 'restraint', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'revolutionise': {'vb_to_nn': 'revolution', 'vb_to_jj': 'revolutionary'},
 'situate': {'vb_to_nn': 'situation', 'vb_to_jj': 'situated', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'stabilize': {'vb_to_nn': 'stable', 'vb_to_jj': 'stable', 'v_compcl_non': ''},
 'stabilise': {'vb_to_nn': 'stable', 'vb_to_jj': 'stable'},
 'subsidise': {'vb_to_nn': 'subsidy', 'vb_to_jj': 'subsidized'},
 'subsidize': {'vb_to_nn': 'subsidy', 'vb_to_jj': 'subsidized', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'suspend': {'vb_to_nn': 'suspension', 'vb_to_jj': 'suspended', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'tempt': {'vb_to_nn': 'tempter', 'vb_to_jj': 'tempting', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'utilize': {'vb_to_nn': 'utilization', 'vb_to_jj': 'utilisable', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'utilise': {'vb_to_nn': 'utilization', 'vb_to_jj': 'utilisable'},
 'whiten': {'vb_to_nn': 'white', 'vb_to_jj': 'white', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'wooden': {'vb_to_nn': 'wood', 'vb_to_jj': 'woody'},
 'woollen': {'vb_to_nn': 'wool', 'vb_to_jj': 'woolly'},
 'coincide': {'vb_to_jj': 'coincident', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'nagate': {'vb_to_jj': 'negative'},
 'untie': {'vb_to_jj': 'tieless', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'entrust': {'vb_to_jj': 'trustable', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'oblige': {'v_n_to_vb': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'rejected': {'vbd_to_vb': 'reject', 'vbn_to_vb': 'reject', 'vbn_to_vbg': 'rejecting', 'vbd_eq_vbn': ''},
 'related': {'vbd_to_vb': 'relate', 'vbn_to_vb': 'relate', 'vbn_to_vbg': 'relating', 'jj_ed': '', 'be_jj_to_vbg': '', 'vbd_eq_vbn': ''},
 'relaxed': {'vbd_to_vb': 'relax', 'vbn_to_vb': 'relax', 'vbn_to_vbg': 'relaxing', 'sb_be_jj': '', 'vbd_eq_vbn': ''},
 'released': {'vbd_to_vb': 'release', 'vbn_to_vb': 'release', 'vbn_to_vbg': 'releasing', 'vbd_eq_vbn': ''},
 'relieved': {'vbd_to_vb': 'relieve', 'vbn_to_vb': 'relieve', 'vbn_to_vbg': 'relieving', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'relied': {'vbd_to_vb': 'rely', 'vbn_to_vb': 'rely', 'vbn_to_vbg': 'relying', 'vbd_eq_vbn': ''},
 'remained': {'vbd_to_vb': 'remain', 'vbn_to_vb': 'remain', 'vbn_to_vbg': 'remaining', 'vbd_eq_vbn': ''},
 'remarked': {'vbd_to_vb': 'remark', 'vbn_to_vb': 'remark', 'vbn_to_vbg': 'remarking', 'vbd_eq_vbn': ''},
 'remembered': {'vbd_to_vb': 'remember', 'vbn_to_vb': 'remember', 'vbn_to_vbg': 'remembering', 'vbd_eq_vbn': ''},
 'reminded': {'vbd_to_vb': 'remind', 'vbn_to_vb': 'remind', 'vbn_to_vbg': 'reminding', 'vbd_eq_vbn': ''},
 'removed': {'vbd_to_vb': 'remove', 'vbn_to_vb': 'remove', 'vbn_to_vbg': 'removing', 'vbd_eq_vbn': ''},
 'rented': {'vbd_to_vb': 'rent', 'vbn_to_vb': 'rent', 'vbn_to_vbg': 'renting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'repaired': {'vbd_to_vb': 'repair', 'vbn_to_vb': 'repair', 'vbn_to_vbg': 'repairing', 'vbd_eq_vbn': ''},
 'replaced': {'vbd_to_vb': 'replace', 'vbn_to_vb': 'replace', 'vbn_to_vbg': 'replacing', 'vbd_eq_vbn': ''},
 'replied': {'vbd_to_vb': 'reply', 'vbn_to_vb': 'reply', 'vbn_to_vbg': 'replying', 'vbd_eq_vbn': ''},
 'reported': {'vbd_to_vb': 'report', 'vbn_to_vb': 'report', 'vbn_to_vbg': 'reporting', 'vbd_eq_vbn': ''},
 'represented': {'vbd_to_vb': 'represent', 'vbn_to_vb': 'represent', 'vbn_to_vbg': 'representing', 'vbd_eq_vbn': ''},
 'requested': {'vbd_to_vb': 'request', 'vbn_to_vb': 'request', 'vbn_to_vbg': 'requesting', 'vbd_eq_vbn': ''},
 'required': {'vbd_to_vb': 'require', 'vbn_to_vb': 'require', 'vbn_to_vbg': 'requiring', 'vbd_eq_vbn': ''},
 'rescued': {'vbd_to_vb': 'rescue', 'vbn_to_vb': 'rescue', 'vbn_to_vbg': 'rescuing', 'vbd_eq_vbn': ''},
 'researched': {'vbd_to_vb': 'research', 'vbn_to_vb': 'research', 'vbn_to_vbg': 'researching', 'vbd_eq_vbn': ''},
 'reserved': {'vbd_to_vb': 'reserve', 'vbn_to_vb': 'reserve', 'vbn_to_vbg': 'reserving', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'resigned': {'vbd_to_vb': 'resign', 'vbn_to_vb': 'resign', 'vbn_to_vbg': 'resigning', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'resisted': {'vbd_to_vb': 'resist', 'vbn_to_vb': 'resist', 'vbn_to_vbg': 'resisting', 'vbd_eq_vbn': ''},
 'resolved': {'vbd_to_vb': 'resolve', 'vbn_to_vb': 'resolve', 'vbn_to_vbg': 'resolving', 'vbd_eq_vbn': ''},
 'resorted': {'vbd_to_vb': 'resort', 'vbn_to_vb': 'resort', 'vbn_to_vbg': 'resorting', 'vbd_eq_vbn': ''},
 'respected': {'vbd_to_vb': 'respect', 'vbn_to_vb': 'respect', 'vbn_to_vbg': 'respecting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'responded': {'vbd_to_vb': 'respond', 'vbn_to_vb': 'respond', 'vbn_to_vbg': 'responding', 'vbd_eq_vbn': ''},
 'rested': {'vbd_to_vb': 'rest', 'vbn_to_vb': 'rest', 'vbn_to_vbg': 'resting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'restored': {'vbd_to_vb': 'restore', 'vbn_to_vb': 'restore', 'vbn_to_vbg': 'restoring', 'vbd_eq_vbn': ''},
 'resulted': {'vbd_to_vb': 'result', 'vbn_to_vb': 'result', 'vbn_to_vbg': 'resulting', 'vbd_eq_vbn': ''},
 'retained': {'vbd_to_vb': 'retain', 'vbn_to_vb': 'retain', 'vbn_to_vbg': 'retaining', 'vbd_eq_vbn': ''},
 'retired': {'vbd_to_vb': 'retire', 'vbn_to_vb': 'retire', 'vbn_to_vbg': 'retiring', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'returned': {'vbd_to_vb': 'return', 'vbn_to_vb': 'return', 'vbn_to_vbg': 'returning', 'vbd_eq_vbn': ''},
 'revealed': {'vbd_to_vb': 'reveal', 'vbn_to_vb': 'reveal', 'vbn_to_vbg': 'revealing', 'vbd_eq_vbn': ''},
 'reversed': {'vbd_to_vb': 'reverse', 'vbn_to_vb': 'reverse', 'vbn_to_vbg': 'reversing', 'vbd_eq_vbn': ''},
 'reviewed': {'vbd_to_vb': 'review', 'vbn_to_vb': 'review', 'vbn_to_vbg': 'reviewing', 'vbd_eq_vbn': ''},
 'rewarded': {'vbd_to_vb': 'reward', 'vbn_to_vb': 'reward', 'vbn_to_vbg': 'rewarding', 'vbd_eq_vbn': ''},
 'rode': {'vbd_to_vb': 'ride', 'vbd_to_vbn': 'ridden'},
 'ringed': {'vbd_to_vb': 'ring', 'vbn_to_vb': 'ring', 'vbn_to_vbg': 'ringing', 'vbd_eq_vbn': ''},
 'ripped': {'vbd_to_vb': 'rip', 'vbn_to_vb': 'rip', 'vbn_to_vbg': 'ripping', 'vbd_eq_vbn': ''},
 'rised': {'vbd_to_vb': 'rise', 'vbn_to_vb': 'rise', 'vbn_to_vbg': 'rising'},
 'risked': {'vbd_to_vb': 'risk', 'vbn_to_vb': 'risk', 'vbn_to_vbg': 'risking', 'vbd_eq_vbn': ''},
 'rivaled': {'vbd_to_vb': 'rival', 'vbn_to_vb': 'rival', 'vbn_to_vbg': 'rivaling', 'vbd_eq_vbn': ''},
 'robbed': {'vbd_to_vb': 'rob', 'vbn_to_vb': 'rob', 'vbn_to_vbg': 'robbing', 'vbd_eq_vbn': ''},
 'rocked': {'vbd_to_vb': 'rock', 'vbn_to_vb': 'rock', 'vbn_to_vbg': 'rocking', 'vbd_eq_vbn': ''},
 'rolled': {'vbd_to_vb': 'roll', 'vbn_to_vb': 'roll', 'vbn_to_vbg': 'rolling', 'vbd_eq_vbn': ''},
 'roofed': {'vbd_to_vb': 'roof', 'vbn_to_vb': 'roof', 'vbn_to_vbg': 'roofing', 'vbd_eq_vbn': ''},
 'rooted': {'vbd_to_vb': 'root', 'vbn_to_vb': 'root', 'vbn_to_vbg': 'rooting', 'vbd_eq_vbn': ''},
 'roped': {'vbd_to_vb': 'rope', 'vbn_to_vb': 'rope', 'vbn_to_vbg': 'roping', 'vbd_eq_vbn': ''},
 'routed': {'vbd_to_vb': 'route', 'vbn_to_vb': 'route', 'vbn_to_vbg': 'routing', 'vbd_eq_vbn': ''},
 'rowed': {'vbd_to_vb': 'row', 'vbn_to_vb': 'row', 'vbn_to_vbg': 'rowing', 'vbd_eq_vbn': ''},
 'rubbed': {'vbd_to_vb': 'rub', 'vbn_to_vb': 'rub', 'vbn_to_vbg': 'rubbing', 'vbd_eq_vbn': ''},
 'ruined': {'vbd_to_vb': 'ruin', 'vbn_to_vb': 'ruin', 'vbn_to_vbg': 'ruining', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'ruled': {'vbd_to_vb': 'rule', 'vbn_to_vb': 'rule', 'vbn_to_vbg': 'ruling', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'runned': {'vbd_to_vb': 'run', 'vbn_to_vb': 'run', 'vbn_to_vbg': 'runing'},
 'rushed': {'vbd_to_vb': 'rush', 'vbn_to_vb': 'rush', 'vbn_to_vbg': 'rushing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'sacked': {'vbd_to_vb': 'sack', 'vbn_to_vb': 'sack', 'vbn_to_vbg': 'sacking', 'vbd_eq_vbn': ''},
 'sailed': {'vbd_to_vb': 'sail', 'vbn_to_vb': 'sail', 'vbn_to_vbg': 'sailing', 'vbd_eq_vbn': ''},
 'salted': {'vbd_to_vb': 'salt', 'vbn_to_vb': 'salt', 'vbn_to_vbg': 'salting', 'vbd_eq_vbn': ''},
 'sampled': {'vbd_to_vb': 'sample', 'vbn_to_vb': 'sample', 'vbn_to_vbg': 'sampling', 'vbd_eq_vbn': ''},
 'sanded': {'vbd_to_vb': 'sand', 'vbn_to_vb': 'sand', 'vbn_to_vbg': 'sanding', 'vbd_eq_vbn': ''},
 'sandwiched': {'vbd_to_vb': 'sandwich', 'vbn_to_vb': 'sandwich', 'vbn_to_vbg': 'sandwiching', 'vbd_eq_vbn': ''},
 'satisfied': {'vbd_to_vb': 'satisfy', 'vbn_to_vb': 'satisfy', 'vbn_to_vbg': 'satisfying', 'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'sauced': {'vbd_to_vb': 'sauce', 'vbn_to_vb': 'sauce', 'vbn_to_vbg': 'saucing', 'vbd_eq_vbn': ''},
 'scaled': {'vbd_to_vb': 'scale', 'vbn_to_vb': 'scale', 'vbn_to_vbg': 'scaling', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'scheduled': {'vbd_to_vb': 'schedule', 'vbn_to_vb': 'schedule', 'vbn_to_vbg': 'scheduling', 'vbd_eq_vbn': ''},
 'schemed': {'vbd_to_vb': 'scheme', 'vbn_to_vb': 'scheme', 'vbn_to_vbg': 'scheming', 'vbd_eq_vbn': ''},
 'scored': {'vbd_to_vb': 'score', 'vbn_to_vb': 'score', 'vbn_to_vbg': 'scoring', 'vbd_eq_vbn': ''},
 'scratched': {'vbd_to_vb': 'scratch', 'vbn_to_vb': 'scratch', 'vbn_to_vbg': 'scratching', 'vbd_eq_vbn': ''},
 'screamed': {'vbd_to_vb': 'scream', 'vbn_to_vb': 'scream', 'vbn_to_vbg': 'screaming', 'vbd_eq_vbn': ''},
 'screened': {'vbd_to_vb': 'screen', 'vbn_to_vb': 'screen', 'vbn_to_vbg': 'screening', 'vbd_eq_vbn': ''},
 'scripted': {'vbd_to_vb': 'script', 'vbn_to_vb': 'script', 'vbn_to_vbg': 'scripting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'sealed': {'vbd_to_vb': 'seal', 'vbn_to_vb': 'seal', 'vbn_to_vbg': 'sealing', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'searched': {'vbd_to_vb': 'search', 'vbn_to_vb': 'search', 'vbn_to_vbg': 'searching', 'vbd_eq_vbn': ''},
 'seasoned': {'vbd_to_vb': 'season', 'vbn_to_vb': 'season', 'vbn_to_vbg': 'seasoning', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'seated': {'vbd_to_vb': 'seat', 'vbn_to_vb': 'seat', 'vbn_to_vbg': 'seating', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'seconded': {'vbd_to_vb': 'second', 'vbn_to_vb': 'second', 'vbn_to_vbg': 'seconding', 'vbd_eq_vbn': ''},
 'sectioned': {'vbd_to_vb': 'section', 'vbn_to_vb': 'section', 'vbn_to_vbg': 'sectioning', 'vbd_eq_vbn': ''},
 'secured': {'vbd_to_vb': 'secure', 'vbn_to_vb': 'secure', 'vbn_to_vbg': 'securing', 'vbd_eq_vbn': ''},
 'seeded': {'vbd_to_vb': 'seed', 'vbn_to_vb': 'seed', 'vbn_to_vbg': 'seeding', 'vbd_eq_vbn': ''},
 'sought': {'vbd_to_vb': 'seek', 'vbn_to_vb': 'seek', 'vbn_to_vbg': 'seeking', 'vbd_eq_vbn': ''},
 'seemed': {'vbd_to_vb': 'seem', 'vbn_to_vb': 'seem', 'vbn_to_vbg': 'seeming', 'vbd_eq_vbn': ''},
 'seized': {'vbd_to_vb': 'seize', 'vbn_to_vb': 'seize', 'vbn_to_vbg': 'seizing', 'vbd_eq_vbn': ''},
 'selected': {'vbd_to_vb': 'select', 'vbn_to_vb': 'select', 'vbn_to_vbg': 'selecting', 'vbd_eq_vbn': ''},
 'sold': {'vbd_to_vb': 'sell', 'vbn_to_vb': 'sell', 'vbn_to_vbg': 'selling', 'vbd_eq_vbn': ''},
 'sent': {'vbd_to_vb': 'send', 'vbn_to_vb': 'send', 'vbn_to_vbg': 'sending', 'vbd_eq_vbn': ''},
 'sensed': {'vbd_to_vb': 'sense', 'vbn_to_vb': 'sense', 'vbn_to_vbg': 'sensing', 'vbd_eq_vbn': ''},
 'sentenced': {'vbd_to_vb': 'sentence', 'vbn_to_vb': 'sentence', 'vbn_to_vbg': 'sentencing', 'be_jj_to_vbg': '', 'vbd_eq_vbn': ''},
 'sequenced': {'vbd_to_vb': 'sequence', 'vbn_to_vb': 'sequence', 'vbn_to_vbg': 'sequencing', 'vbd_eq_vbn': ''},
 'served': {'vbd_to_vb': 'serve', 'vbn_to_vb': 'serve', 'vbn_to_vbg': 'serving', 'vbd_eq_vbn': ''},
 'serviced': {'vbd_to_vb': 'service', 'vbn_to_vb': 'service', 'vbn_to_vbg': 'servicing', 'vbd_eq_vbn': ''},
 'settled': {'vbd_to_vb': 'settle', 'vbn_to_vb': 'settle', 'vbn_to_vbg': 'settling', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'sewed': {'vbd_to_vb': 'sew', 'vbd_to_vbn': 'sewn', 'vbd_eq_vbn': ''},
 'shadowed': {'vbd_to_vb': 'shadow', 'vbn_to_vb': 'shadow', 'vbn_to_vbg': 'shadowing', 'vbd_eq_vbn': ''},
 'shook': {'vbd_to_vb': 'shake', 'vbd_to_vbn': 'shaken'},
 'shamed': {'vbd_to_vb': 'shame', 'vbn_to_vb': 'shame', 'vbn_to_vbg': 'shaming', 'vbd_eq_vbn': ''},
 'shaped': {'vbd_to_vb': 'shape', 'vbn_to_vb': 'shape', 'vbn_to_vbg': 'shaping', 'vbd_eq_vbn': ''},
 'shared': {'vbd_to_vb': 'share', 'vbn_to_vb': 'share', 'vbn_to_vbg': 'sharing', 'vbd_eq_vbn': ''},
 'shaved': {'vbd_to_vb': 'shave', 'vbn_to_vb': 'shave', 'vbn_to_vbg': 'shaving', 'vbd_eq_vbn': ''},
 'shedded,shed': {'vbd_to_vb': 'shed', 'vbn_to_vb': 'shed', 'vbn_to_vbg': 'sheding'},
 'shelled': {'vbd_to_vb': 'shell', 'vbn_to_vb': 'shell', 'vbn_to_vbg': 'shelling', 'vbd_eq_vbn': ''},
 'sheltered': {'vbd_to_vb': 'shelter', 'vbn_to_vb': 'shelter', 'vbn_to_vbg': 'sheltering', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'shifted': {'vbd_to_vb': 'shift', 'vbn_to_vb': 'shift', 'vbn_to_vbg': 'shifting', 'vbd_eq_vbn': ''},
 'shone': {'vbd_to_vb': 'shine', 'vbn_to_vb': 'shine', 'vbn_to_vbg': 'shining', 'vbd_eq_vbn': ''},
 'shipped': {'vbd_to_vb': 'ship', 'vbn_to_vb': 'ship', 'vbn_to_vbg': 'shipping', 'vbd_eq_vbn': ''},
 'shocked': {'vbd_to_vb': 'shock', 'vbn_to_vb': 'shock', 'vbn_to_vbg': 'shocking', 'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'shopped': {'vbd_to_vb': 'shop', 'vbn_to_vb': 'shop', 'vbn_to_vbg': 'shopping', 'vbd_eq_vbn': ''},
 'shouldered': {'vbd_to_vb': 'shoulder', 'vbn_to_vb': 'shoulder', 'vbn_to_vbg': 'shouldering', 'vbd_eq_vbn': ''},
 'shouted': {'vbd_to_vb': 'shout', 'vbn_to_vb': 'shout', 'vbn_to_vbg': 'shouting', 'vbd_eq_vbn': ''},
 'shoved': {'vbd_to_vb': 'shove', 'vbn_to_vb': 'shove', 'vbn_to_vbg': 'shoving', 'vbd_eq_vbn': ''},
 'showed': {'vbd_to_vb': 'show', 'vbd_to_vbn': 'shown'},
 'showered': {'vbd_to_vb': 'shower', 'vbn_to_vb': 'shower', 'vbn_to_vbg': 'showering', 'vbd_eq_vbn': ''},
 'shrugged': {'vbd_to_vb': 'shrug', 'vbn_to_vb': 'shrug', 'vbn_to_vbg': 'shruging'},
 'shutted,shut': {'vbd_to_vb': 'shut', 'vbn_to_vb': 'shut', 'vbn_to_vbg': 'shutting'},
 'sighted': {'vbd_to_vb': 'sight', 'vbn_to_vb': 'sight', 'vbn_to_vbg': 'sighting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'signed': {'vbd_to_vb': 'sign', 'vbn_to_vb': 'sign', 'vbn_to_vbg': 'signing', 'vbd_eq_vbn': ''},
 'signaled': {'vbd_to_vb': 'signal', 'vbn_to_vb': 'signal', 'vbn_to_vbg': 'signaling', 'vbd_eq_vbn': ''},
 'silvered': {'vbd_to_vb': 'silver', 'vbn_to_vb': 'silver', 'vbn_to_vbg': 'silvering', 'vbd_eq_vbn': ''},
 'sinned': {'vbd_to_vb': 'sin', 'vbn_to_vb': 'sin', 'vbn_to_vbg': 'sining', 'vbd_eq_vbn': ''},
 'sat': {'vbd_to_vb': 'sit', 'vbn_to_vb': 'sit', 'vbn_to_vbg': 'sitting', 'vbd_eq_vbn': ''},
 'sited': {'vbd_to_vb': 'site', 'vbn_to_vb': 'site', 'vbn_to_vbg': 'siting', 'vbd_eq_vbn': ''},
 'skirted': {'vbd_to_vb': 'skirt', 'vbn_to_vb': 'skirt', 'vbn_to_vbg': 'skirting', 'vbd_eq_vbn': ''},
 'slept': {'vbd_to_vb': 'sleep', 'vbn_to_vb': 'sleep', 'vbn_to_vbg': 'sleeping', 'vbd_eq_vbn': ''},
 'slided': {'vbd_to_vb': 'slide', 'vbn_to_vb': 'slide', 'vbn_to_vbg': 'sliding'},
 'slowed': {'vbd_to_vb': 'slow', 'vbn_to_vb': 'slow', 'vbn_to_vbg': 'slowing', 'vbd_eq_vbn': ''},
 'smelled,smelt': {'vbd_to_vb': 'smell', 'vbn_to_vb': 'smell', 'vbn_to_vbg': 'smelling'},
 'smiled': {'vbd_to_vb': 'smile', 'vbn_to_vb': 'smile', 'vbn_to_vbg': 'smiling', 'vbd_eq_vbn': ''},
 'snaped': {'vbd_to_vb': 'snap', 'vbn_to_vb': 'snap', 'vbn_to_vbg': 'snapping'},
 'sounded': {'vbd_to_vb': 'sound', 'vbn_to_vb': 'sound', 'vbn_to_vbg': 'sounding', 'vbd_eq_vbn': ''},
 'spelled,spelt': {'vbd_to_vb': 'spell', 'vbn_to_vb': 'spell', 'vbn_to_vbg': 'spelling'},
 'spilled,spilt': {'vbd_to_vb': 'spill', 'vbn_to_vb': 'spill', 'vbn_to_vbg': 'spilling'},
 'sprayed': {'vbd_to_vb': 'spray', 'vbn_to_vb': 'spray', 'vbn_to_vbg': 'spraying', 'vbd_eq_vbn': ''},
 'squeezed': {'vbd_to_vb': 'squeeze', 'vbn_to_vb': 'squeeze', 'vbn_to_vbg': 'squeezing', 'vbd_eq_vbn': ''},
 'stampped': {'vbd_to_vb': 'stamp', 'vbn_to_vb': 'stamp', 'vbn_to_vbg': 'stamping'},
 'stood': {'vbd_to_vb': 'stand', 'vbn_to_vb': 'stand', 'vbn_to_vbg': 'standing', 'vbd_eq_vbn': ''},
 'stared': {'vbd_to_vb': 'stare', 'vbn_to_vb': 'stare', 'vbn_to_vbg': 'staring', 'vbd_eq_vbn': ''},
 'started': {'vbd_to_vb': 'start', 'vbn_to_vb': 'start', 'vbn_to_vbg': 'starting', 'vbd_eq_vbn': ''},
 'starved': {'vbd_to_vb': 'starve', 'vbn_to_vb': 'starve', 'vbn_to_vbg': 'starving', 'vbd_eq_vbn': ''},
 'stayed': {'vbd_to_vb': 'stay', 'vbn_to_vb': 'stay', 'vbn_to_vbg': 'staying', 'vbd_eq_vbn': ''},
 'stepped': {'vbd_to_vb': 'step', 'vbn_to_vb': 'step', 'vbn_to_vbg': 'steping', 'vbd_eq_vbn': ''},
 'stirred': {'vbd_to_vb': 'stir', 'vbn_to_vb': 'stir', 'vbn_to_vbg': 'stiring', 'vbd_eq_vbn': ''},
 'strengthened': {'vbd_to_vb': 'strengthen', 'vbn_to_vb': 'strengthen', 'vbn_to_vbg': 'strengthening', 'vbd_eq_vbn': ''},
 'struggled': {'vbd_to_vb': 'struggle', 'vbn_to_vb': 'struggle', 'vbn_to_vbg': 'struggling', 'vbd_eq_vbn': ''},
 'submitted': {'vbd_to_vb': 'submit', 'vbn_to_vb': 'submit', 'vbn_to_vbg': 'submiting', 'vbd_eq_vbn': ''},
 'succeeded': {'vbd_to_vb': 'succeed', 'vbn_to_vb': 'succeed', 'vbn_to_vbg': 'succeeding', 'vbd_eq_vbn': ''},
 'sucked': {'vbd_to_vb': 'suck', 'vbn_to_vb': 'suck', 'vbn_to_vbg': 'sucking', 'vbd_eq_vbn': ''},
 'suffered': {'vbd_to_vb': 'suffer', 'vbn_to_vb': 'suffer', 'vbn_to_vbg': 'suffering', 'vbd_eq_vbn': ''},
 'swapped': {'vbd_to_vb': 'swap', 'vbn_to_vb': 'swap', 'vbn_to_vbg': 'swapping', 'vbd_eq_vbn': ''},
 'swimmed,swam': {'vbd_to_vb': 'swim', 'vbd_to_vbn': 'swimmed,swum'},
 'swung': {'vbd_to_vb': 'swing', 'vbn_to_vb': 'swing', 'vbn_to_vbg': 'swinging', 'vbd_eq_vbn': ''},
 'switched': {'vbd_to_vb': 'switch', 'vbn_to_vb': 'switch', 'vbn_to_vbg': 'switching', 'vbd_eq_vbn': ''},
 'tackled': {'vbd_to_vb': 'tackle', 'vbn_to_vb': 'tackle', 'vbn_to_vbg': 'tackling', 'vbd_eq_vbn': ''},
 'took': {'vbd_to_vb': 'take', 'vbd_to_vbn': 'taken', 'vt_typical': ''},
 'talked': {'vbd_to_vb': 'talk', 'vbn_to_vb': 'talk', 'vbn_to_vbg': 'talking', 'vbd_eq_vbn': ''},
 'tasted': {'vbd_to_vb': 'taste', 'vbn_to_vb': 'taste', 'vbn_to_vbg': 'tasting', 'vbd_eq_vbn': ''},
 'teached': {'vbd_to_vb': 'teach', 'vbn_to_vb': 'teach', 'vbn_to_vbg': 'teaching'},
 'told': {'vbd_to_vb': 'tell', 'vbn_to_vb': 'tell', 'vbn_to_vbg': 'telling', 'vbd_eq_vbn': ''},
 'tended': {'vbd_to_vb': 'tend', 'vbn_to_vb': 'tend', 'vbn_to_vbg': 'tending', 'vbd_eq_vbn': ''},
 'texted': {'vbd_to_vb': 'text', 'vbn_to_vb': 'text', 'vbn_to_vbg': 'texting', 'vbd_eq_vbn': ''},
 'thanked': {'vbd_to_vb': 'thank', 'vbn_to_vb': 'thank', 'vbn_to_vbg': 'thanking', 'vbd_eq_vbn': ''},
 'threw': {'vbd_to_vb': 'throw', 'vbd_to_vbn': 'thrown'},
 'tied': {'vbd_to_vb': 'tie', 'vbn_to_vb': 'tie', 'vbn_to_vbg': 'tying', 'vbd_eq_vbn': ''},
 'tipped': {'vbd_to_vb': 'tip', 'vbn_to_vb': 'tip', 'vbn_to_vbg': 'tiping', 'vbd_eq_vbn': ''},
 'touched': {'vbd_to_vb': 'touch', 'vbn_to_vb': 'touch', 'vbn_to_vbg': 'touching', 'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'traded': {'vbd_to_vb': 'trade', 'vbn_to_vb': 'trade', 'vbn_to_vbg': 'trading', 'vbd_eq_vbn': ''},
 'transfered': {'vbd_to_vb': 'transfer', 'vbn_to_vb': 'transfer', 'vbn_to_vbg': 'transfering'},
 'transformed': {'vbd_to_vb': 'transform', 'vbn_to_vb': 'transform', 'vbn_to_vbg': 'transforming', 'vbd_eq_vbn': ''},
 'translated': {'vbd_to_vb': 'translate', 'vbn_to_vb': 'translate', 'vbn_to_vbg': 'translating', 'vbd_eq_vbn': ''},
 'trusted': {'vbd_to_vb': 'trust', 'vbn_to_vb': 'trust', 'vbn_to_vbg': 'trusting', 'vbd_eq_vbn': ''},
 'twisted': {'vbd_to_vb': 'twist', 'vbn_to_vb': 'twist', 'vbn_to_vbg': 'twisting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'understood': {'vbd_to_vb': 'understand', 'vbn_to_vb': 'understand', 'vbn_to_vbg': 'understanding', 'vbd_eq_vbn': ''},
 'undertook': {'vbd_to_vb': 'undertake', 'vbd_to_vbn': 'undertaken'},
 'urged': {'vbd_to_vb': 'urge', 'vbn_to_vb': 'urge', 'vbn_to_vbg': 'urging'},
 'vacationed': {'vbd_to_vb': 'vacation', 'vbn_to_vb': 'vacation', 'vbn_to_vbg': 'vacationing', 'vbd_eq_vbn': ''},
 'varied': {'vbd_to_vb': 'vary', 'vbn_to_vb': 'vary', 'vbn_to_vbg': 'varying', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'visited': {'vbd_to_vb': 'visit', 'vbn_to_vb': 'visit', 'vbn_to_vbg': 'visiting', 'vbd_eq_vbn': ''},
 'voted': {'vbd_to_vb': 'vote', 'vbn_to_vb': 'vote', 'vbn_to_vbg': 'voting', 'vbd_eq_vbn': ''},
 'waited': {'vbd_to_vb': 'wait', 'vbn_to_vb': 'wait', 'vbn_to_vbg': 'waiting', 'vbd_eq_vbn': ''},
 'woke': {'vbd_to_vb': 'wake', 'vbd_to_vbn': 'waken'},
 'walked': {'vbd_to_vb': 'walk', 'vbn_to_vb': 'walk', 'vbn_to_vbg': 'walking', 'vbd_eq_vbn': ''},
 'wandered': {'vbd_to_vb': 'wander', 'vbn_to_vb': 'wander', 'vbn_to_vbg': 'wandering', 'vbd_eq_vbn': ''},
 'wanted': {'vbd_to_vb': 'want', 'vbn_to_vb': 'want', 'vbn_to_vbg': 'wanting', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'warned': {'vbd_to_vb': 'warn', 'vbn_to_vb': 'warn', 'vbn_to_vbg': 'warning', 'vbd_eq_vbn': ''},
 'wasted': {'vbd_to_vb': 'waste', 'vbn_to_vb': 'waste', 'vbn_to_vbg': 'wasting', 'vbd_eq_vbn': ''},
 'watched': {'vbd_to_vb': 'watch', 'vbn_to_vb': 'watch', 'vbn_to_vbg': 'watching', 'vbd_eq_vbn': ''},
 'waved': {'vbd_to_vb': 'wave', 'vbn_to_vb': 'wave', 'vbn_to_vbg': 'waving', 'vbd_eq_vbn': ''},
 'wore': {'vbd_to_vb': 'wear', 'vbd_to_vbn': 'worn'},
 'weighed': {'vbd_to_vb': 'weigh', 'vbn_to_vb': 'weigh', 'vbn_to_vbg': 'weighing', 'vbd_eq_vbn': ''},
 'welcomed': {'vbd_to_vb': 'welcome', 'vbn_to_vb': 'welcome', 'vbn_to_vbg': 'welcoming', 'vbd_eq_vbn': ''},
 'whispered': {'vbd_to_vb': 'whisper', 'vbn_to_vb': 'whisper', 'vbn_to_vbg': 'whispering', 'vbd_eq_vbn': ''},
 'won': {'vbd_to_vb': 'win', 'vbn_to_vb': 'win', 'vbn_to_vbg': 'winning', 'vbd_eq_vbn': ''},
 'winded,wound': {'vbd_to_vb': 'wind', 'vbn_to_vb': 'wind', 'vbn_to_vbg': 'winding'},
 'wiped': {'vbd_to_vb': 'wipe', 'vbn_to_vb': 'wipe', 'vbn_to_vbg': 'wiping', 'vbd_eq_vbn': ''},
 'wished': {'vbd_to_vb': 'wish', 'vbn_to_vb': 'wish', 'vbn_to_vbg': 'wishing', 'vbd_eq_vbn': ''},
 'withdrew': {'vbd_to_vb': 'withdraw', 'vbd_to_vbn': 'withdrawn'},
 'wondered': {'vbd_to_vb': 'wonder', 'vbn_to_vb': 'wonder', 'vbn_to_vbg': 'wondering', 'vbd_eq_vbn': ''},
 'worked': {'vbd_to_vb': 'work', 'vbn_to_vb': 'work', 'vbn_to_vbg': 'working', 'vbd_eq_vbn': ''},
 'worried': {'vbd_to_vb': 'worry', 'vbn_to_vb': 'worry', 'vbn_to_vbg': 'worrying', 'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'wounded': {'vbd_to_vb': 'wound', 'vbn_to_vb': 'wound', 'vbn_to_vbg': 'wounding', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'wraped': {'vbd_to_vb': 'wrap', 'vbn_to_vb': 'wrap', 'vbn_to_vbg': 'wrapping'},
 'wrote': {'vbd_to_vb': 'write', 'vbd_to_vbn': 'written'},
 'bitten': {'vbn_to_vb': 'bite', 'vbn_to_vbd': 'bit', 'vbn_to_vbg': 'biting'},
 'broken': {'vbn_to_vb': 'break', 'vbn_to_vbd': 'broke', 'vbn_to_vbg': 'breaking'},
 'eaten': {'vbn_to_vb': 'eat', 'vbn_to_vbd': 'ate', 'vbn_to_vbg': 'eating'},
 'flown': {'vbn_to_vb': 'flow', 'vbn_to_vbd': 'flew', 'vbn_to_vbg': 'flowing'},
 'forgotten': {'vbn_to_vb': 'forget', 'vbn_to_vbd': 'forgot', 'vbn_to_vbg': 'forgeting'},
 'forgiven': {'vbn_to_vb': 'forgive', 'vbn_to_vbd': 'forgave', 'vbn_to_vbg': 'forgiving'},
 'gotten': {'vbn_to_vb': 'get', 'vbn_to_vbd': 'got', 'vbn_to_vbg': 'getting'},
 'proven': {'vbn_to_vb': 'prove', 'vbn_to_vbd': 'proved', 'vbn_to_vbg': 'proving', 'vbd_eq_vbn': ''},
 'ridden': {'vbn_to_vb': 'ride', 'vbn_to_vbd': 'rode', 'vbn_to_vbg': 'riding'},
 'seen': {'vbn_to_vb': 'see', 'vbn_to_vbd': 'saw', 'vbn_to_vbg': 'seeing'},
 'sewn': {'vbn_to_vb': 'sew', 'vbn_to_vbd': 'sewed', 'vbn_to_vbg': 'sewing'},
 'shaken': {'vbn_to_vb': 'shake', 'vbn_to_vbd': 'shook', 'vbn_to_vbg': 'shaking'},
 'shown': {'vbn_to_vb': 'show', 'vbn_to_vbd': 'showed', 'vbn_to_vbg': 'showing'},
 'sung': {'vbn_to_vb': 'sing', 'vbn_to_vbd': 'sang', 'vbn_to_vbg': 'singing'},
 'swimmed,swum': {'vbn_to_vb': 'swim', 'vbn_to_vbd': 'swimmed,swam', 'vbn_to_vbg': 'swiming'},
 'taken': {'vbn_to_vb': 'take', 'vbn_to_vbd': 'took', 'vbn_to_vbg': 'taking', 'vt_typical': ''},
 'thrown': {'vbn_to_vb': 'throw', 'vbn_to_vbd': 'threw', 'vbn_to_vbg': 'throwing'},
 'undertaken': {'vbn_to_vb': 'undertake', 'vbn_to_vbd': 'undertook', 'vbn_to_vbg': 'undertaking'},
 'waken': {'vbn_to_vb': 'wake', 'vbn_to_vbd': 'woke', 'vbn_to_vbg': 'waking', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'worn': {'vbn_to_vb': 'wear', 'vbn_to_vbd': 'wore', 'vbn_to_vbg': 'wearing'},
 'withdrawn': {'vbn_to_vb': 'withdraw', 'vbn_to_vbd': 'withdrew', 'vbn_to_vbg': 'withdrawing'},
 'written': {'vbn_to_vb': 'write', 'vbn_to_vbd': 'wrote', 'vbn_to_vbg': 'writing'},
 'excepted': {'jj_to_nn': 'exceptation', 'vbn_to_nn': 'exceptation', 'vbd_eq_vbn': ''},
 'abandonedly': {'rb_to_nn': 'abandonment', 'rb_to_jj': 'abandoned', 'rb_to_vb': 'abandon'},
 'ably': {'rb_to_nn': 'ability', 'rb_to_jj': 'able', 'rb_to_vb': 'able'},
 'absently': {'rb_to_nn': 'absence', 'rb_to_jj': 'absent', 'rb_to_vb': 'absent'},
 'absolutely': {'rb_to_nn': 'absolution', 'rb_to_jj': 'absolute', 'rb_to_vb': 'absolute'},
 'abstractly': {'rb_to_nn': 'abstraction', 'rb_to_jj': 'abstract', 'rb_to_vb': 'abstract'},
 'academically': {'rb_to_nn': 'academy', 'rb_to_jj': 'academic'},
 'acceptably': {'rb_to_nn': 'acceptance', 'rb_to_jj': 'acceptable', 'rb_to_vb': 'accept'},
 'accessibly': {'rb_to_nn': 'access', 'rb_to_jj': 'accessible', 'rb_to_vb': 'access'},
 'accidentally': {'rb_to_nn': 'accident', 'rb_to_jj': 'accidental'},
 'accordingly': {'rb_to_nn': 'accordance', 'rb_to_jj': 'according', 'rb_to_vb': 'accord'},
 'accurately': {'rb_to_nn': 'accuracy', 'rb_to_jj': 'accurate'},
 'actively': {'rb_to_nn': 'activity', 'rb_to_jj': 'active', 'rb_to_vb': 'activate'},
 'actually': {'rb_to_nn': 'actuality', 'rb_to_jj': 'actual', 'rb_to_vb': 'actualize'},
 'adequately': {'rb_to_nn': 'adequacy', 'rb_to_jj': 'adequate', 'rb_to_vb': 'adequate'},
 'adjacently': {'rb_to_nn': 'adjacence', 'rb_to_jj': 'adjacent', 'rb_to_vb': 'adjacent'},
 'adjustable': {'rb_to_nn': 'adjustment', 'rb_to_jj': 'adjusted', 'rb_to_vb': 'adjust'},
 'allowably': {'rb_to_nn': 'allowance', 'rb_to_jj': 'allowable', 'rb_to_vb': 'allow'},
 'alterably': {'rb_to_nn': 'alteration', 'rb_to_jj': 'alterable', 'rb_to_vb': 'alter'},
 'annually': {'rb_to_nn': 'annual', 'rb_to_jj': 'annual'},
 'anticipatively': {'rb_to_nn': 'anticipation', 'rb_to_jj': 'anticipative', 'rb_to_vb': 'anticipate'},
 'anxiously': {'rb_to_nn': 'anxiety', 'rb_to_jj': 'anxious'},
 'apologetically': {'rb_to_nn': 'apology', 'rb_to_jj': 'apologetical', 'rb_to_vb': 'apologize'},
 'applicably': {'rb_to_nn': 'application', 'rb_to_jj': 'applicable', 'rb_to_vb': 'apply'},
 'appreciably': {'rb_to_nn': 'appreciation', 'rb_to_jj': 'appreciable', 'rb_to_vb': 'appreciate'},
 'approachably': {'rb_to_nn': 'approach', 'rb_to_jj': 'approachable', 'rb_to_vb': 'approach'},
 'appropriately': {'rb_to_nn': 'appropriateness', 'rb_to_jj': 'appropriate', 'rb_to_vb': 'appropriate'},
 'approximately': {'rb_to_nn': 'approximation', 'rb_to_jj': 'approximate', 'rb_to_vb': 'approximate'},
 'arbitrarily': {'rb_to_nn': 'arbitrariness', 'rb_to_jj': 'arbitrary', 'rb_to_vb': 'arbitrate'},
 'archly': {'rb_to_nn': 'arch', 'rb_to_jj': 'arch', 'rb_to_vb': 'arch'},
 'attentively': {'rb_to_nn': 'attention', 'rb_to_jj': 'attentive'},
 'attractively': {'rb_to_nn': 'attraction', 'rb_to_jj': 'attractive', 'rb_to_vb': 'attract'},
 'awkwardly': {'rb_to_nn': 'awkwardness', 'rb_to_jj': 'awkward'},
 'badly': {'rb_to_nn': 'badness', 'rb_to_jj': 'bad'},
 'bitterly': {'rb_to_nn': 'bitterness', 'rb_to_jj': 'bitter', 'rb_to_vb': 'bitter'},
 'blackly': {'rb_to_nn': 'blackness', 'rb_to_jj': 'black', 'rb_to_vb': 'black'},
 'bloodily': {'rb_to_nn': 'blood', 'rb_to_jj': 'bloody', 'rb_to_vb': 'blood'},
 'boldly': {'rb_to_nn': 'boldness', 'rb_to_jj': 'bold'},
 'bravely': {'rb_to_nn': 'bravery', 'rb_to_jj': 'brave', 'rb_to_vb': 'brave'},
 'brightly': {'rb_to_nn': 'brightness', 'rb_to_jj': 'bright', 'rb_to_vb': 'brighten'},
 'bulkily': {'rb_to_nn': 'bulk', 'rb_to_jj': 'bulky', 'rb_to_vb': 'bulk'},
 'bushily': {'rb_to_nn': 'bush', 'rb_to_jj': 'bush', 'rb_to_vb': 'bush'},
 'capably': {'rb_to_nn': 'capacity', 'rb_to_jj': 'capable', 'rb_to_vb': 'capacitate'},
 'carefully': {'rb_to_nn': 'care', 'rb_to_jj': 'careful', 'rb_to_vb': 'care'},
 'cautiously': {'rb_to_nn': 'caution', 'rb_to_jj': 'cautious', 'rb_to_vb': 'caution'},
 'centrally': {'rb_to_nn': 'centre', 'rb_to_jj': 'center', 'rb_to_vb': 'centre'},
 'ceremonially': {'rb_to_nn': 'ceremony', 'rb_to_jj': 'ceremonial'},
 'changeably': {'rb_to_nn': 'change', 'rb_to_jj': 'changeable', 'rb_to_vb': 'change'},
 'cheaply': {'rb_to_nn': 'cheapness', 'rb_to_jj': 'cheap'},
 'chemically': {'rb_to_nn': 'chemical', 'rb_to_jj': 'chemical'},
 'chiefly': {'rb_to_nn': 'chief', 'rb_to_jj': 'chief'},
 'childishly': {'rb_to_nn': 'child', 'rb_to_jj': 'childish'},
 'choicely': {'rb_to_nn': 'choice', 'rb_to_jj': 'choice', 'rb_to_vb': 'choose'},
 'circularly': {'rb_to_nn': 'circle', 'rb_to_jj': 'circular', 'rb_to_vb': 'circle'},
 'civilly': {'rb_to_nn': 'civilian', 'rb_to_jj': 'civil'},
 'cleanly': {'rb_to_nn': 'cleaness', 'rb_to_jj': 'clean', 'rb_to_vb': 'clean'},
 'coarsely': {'rb_to_nn': 'coarseness', 'rb_to_jj': 'coarse'},
 'coherently': {'rb_to_nn': 'coherence', 'rb_to_jj': 'coherent'},
 'coldly': {'rb_to_nn': 'coldness', 'rb_to_jj': 'cold'},
 'comfortably': {'rb_to_nn': 'comfort', 'rb_to_jj': 'comfortable', 'rb_to_vb': 'comfort'},
 'commercially': {'rb_to_nn': 'commerce', 'rb_to_jj': 'commercial'},
 'commonly': {'rb_to_nn': 'commonness', 'rb_to_jj': 'common'},
 'completely': {'rb_to_nn': 'completion', 'rb_to_jj': 'complete', 'rb_to_vb': 'complete'},
 'complexly': {'rb_to_nn': 'complexity', 'rb_to_jj': 'complex'},
 'confidently': {'rb_to_nn': 'confidence', 'rb_to_jj': 'confident'},
 'conscientiously': {'rb_to_nn': 'conscience', 'rb_to_jj': 'conscientious'},
 'consciously': {'rb_to_nn': 'consciousness', 'rb_to_jj': 'conscious'},
 'consequently': {'rb_to_nn': 'consequence', 'rb_to_jj': 'consequent'},
 'constantly': {'rb_to_nn': 'constancy', 'rb_to_jj': 'constant'},
 'contrarily': {'rb_to_nn': 'contrary', 'rb_to_jj': 'contrary'},
 'conveniently': {'rb_to_nn': 'convenience', 'rb_to_jj': 'convenient'},
 'coolly': {'rb_to_nn': 'coolness', 'rb_to_jj': 'cool', 'rb_to_vb': 'cool'},
 'creatively': {'rb_to_nn': 'creation', 'rb_to_jj': 'creative', 'rb_to_vb': 'create'},
 'criminally': {'rb_to_nn': 'crime', 'rb_to_jj': 'criminal', 'rb_to_vb': 'crime'},
 'critically': {'rb_to_nn': 'critic', 'rb_to_jj': 'critical'},
 'crossly': {'rb_to_nn': 'cross', 'rb_to_jj': 'cross', 'rb_to_vb': 'cross'},
 'cruelly': {'rb_to_nn': 'cruelty', 'rb_to_jj': 'cruel'},
 'curiously': {'rb_to_nn': 'curiosity', 'rb_to_jj': 'curious'},
 'currently': {'rb_to_nn': 'currency', 'rb_to_jj': 'current'},
 'dangerously': {'rb_to_nn': 'danger', 'rb_to_jj': 'dangerous'},
 'darkly': {'rb_to_nn': 'darkness', 'rb_to_jj': 'dark'},
 'deadly': {'rb_to_nn': 'death', 'rb_to_jj': 'dead', 'rb_to_vb': 'die', 'jj_to_jjr': 'deadlier', 'jj_to_jjs': 'deadliest'},
 'deafly': {'rb_to_nn': 'deafness', 'rb_to_jj': 'deaf'},
 'deeply': {'rb_to_nn': 'deep', 'rb_to_jj': 'deep', 'rb_to_vb': 'deepen'},
 'definitely': {'rb_to_nn': 'definitiveness', 'rb_to_jj': 'definite'},
 'delicately': {'rb_to_nn': 'delicacy', 'rb_to_jj': 'delicate'},
 'difficultly': {'rb_to_nn': 'difficulty', 'rb_to_jj': 'difficult'},
 'dimensionally': {'rb_to_nn': 'dimension', 'rb_to_jj': 'dimensional'},
 'discretely': {'rb_to_nn': 'discretion', 'rb_to_jj': 'discrete'},
 'diversely': {'rb_to_nn': 'diversity', 'rb_to_jj': 'diverse', 'rb_to_vb': 'diversify'},
 'domestically': {'rb_to_nn': 'domestic', 'rb_to_jj': 'domestic'},
 'doubtfully': {'rb_to_nn': 'doubt', 'rb_to_jj': 'doubtful', 'rb_to_vb': 'doubt'},
 'dramatically': {'rb_to_nn': 'drama', 'rb_to_jj': 'dramatic', 'rb_to_vb': 'dramatize'},
 'dreamily': {'rb_to_nn': 'dream', 'rb_to_jj': 'dream', 'rb_to_vb': 'dream'},
 'drily': {'rb_to_nn': 'dryness', 'rb_to_jj': 'dry', 'rb_to_vb': 'dry'},
 'dully': {'rb_to_nn': 'dullness', 'rb_to_jj': 'dull', 'rb_to_vb': 'dull'},
 'dynamically': {'rb_to_nn': 'dynamic', 'rb_to_jj': 'dynamic'},
 'eagerly': {'rb_to_nn': 'eagerness', 'rb_to_jj': 'eager'},
 'earnestly': {'rb_to_nn': 'earnest', 'rb_to_jj': 'earnest'},
 'economically': {'rb_to_nn': 'economy', 'rb_to_jj': 'economic'},
 'efficiently': {'rb_to_nn': 'efficiency', 'rb_to_jj': 'efficient'},
 'elastically': {'rb_to_nn': 'elasticity', 'rb_to_jj': 'elastic'},
 'electrically': {'rb_to_nn': 'electricity', 'rb_to_jj': 'electric'},
 'empirically': {'rb_to_nn': 'empiricism', 'rb_to_jj': 'empirical'},
 'emptily': {'rb_to_nn': 'empty', 'rb_to_jj': 'empty', 'rb_to_vb': 'empty'},
 'energetically': {'rb_to_nn': 'energy', 'rb_to_jj': 'energetic'},
 'enormously': {'rb_to_nn': 'enormity', 'rb_to_jj': 'enormous'},
 'environmentally': {'rb_to_nn': 'environment', 'rb_to_jj': 'environmental'},
 'equivalently': {'rb_to_nn': 'equivalence', 'rb_to_jj': 'equivalent'},
 'erroneously': {'rb_to_nn': 'error', 'rb_to_jj': 'erroneous'},
 'essentially': {'rb_to_nn': 'essence', 'rb_to_jj': 'essential'},
 'ethically': {'rb_to_nn': 'ethic', 'rb_to_jj': 'ethical'},
 'ethnically': {'rb_to_nn': 'ethnicity', 'rb_to_jj': 'ethnic'},
 'eventually': {'rb_to_nn': 'eventuality', 'rb_to_jj': 'eventual'},
 'excellently': {'rb_to_nn': 'excellence', 'rb_to_jj': 'excellent', 'rb_to_vb': 'excel'},
 'excessively': {'rb_to_nn': 'excess', 'rb_to_jj': 'excessive'},
 'explosively': {'rb_to_nn': 'explosion', 'rb_to_jj': 'explosive', 'rb_to_vb': 'explode'},
 'expressively': {'rb_to_nn': 'expression', 'rb_to_jj': 'express', 'rb_to_vb': 'express'},
 'extensively': {'rb_to_nn': 'extension', 'rb_to_jj': 'extensive', 'rb_to_vb': 'extend'},
 'externally': {'rb_to_nn': 'externality', 'rb_to_jj': 'external', 'rb_to_vb': 'externalise'},
 'extremely': {'rb_to_nn': 'extreme', 'rb_to_jj': 'extreme'},
 'factually': {'rb_to_nn': 'fact', 'rb_to_jj': 'factual'},
 'faintly': {'rb_to_nn': 'faintness', 'rb_to_jj': 'faint', 'rb_to_vb': 'faint'},
 'fairly': {'rb_to_nn': 'fairness', 'rb_to_jj': 'fair', 'rb_to_vb': 'fair'},
 'faithfully': {'rb_to_nn': 'faith', 'rb_to_jj': 'faithful'},
 'falsely': {'rb_to_nn': 'falsehood', 'rb_to_jj': 'FALSE'},
 'familiarly': {'rb_to_nn': 'familiarity', 'rb_to_jj': 'familiar'},
 'fancily': {'rb_to_nn': 'fanciness', 'rb_to_jj': 'fancy', 'rb_to_vb': 'fancy'},
 'fatly': {'rb_to_nn': 'fat', 'rb_to_jj': 'fat', 'rb_to_vb': 'fat'},
 'faultily': {'rb_to_nn': 'fault', 'rb_to_jj': 'faulty', 'rb_to_vb': 'fault'},
 'favourably': {'rb_to_nn': 'favour', 'rb_to_jj': 'favourable', 'rb_to_vb': 'favour'},
 'federally': {'rb_to_nn': 'federation', 'rb_to_jj': 'federal'},
 'fiercely': {'rb_to_nn': 'fierceness', 'rb_to_jj': 'fierce'},
 'finally': {'rb_to_nn': 'final', 'rb_to_jj': 'final', 'rb_to_vb': 'finalise'},
 'finely': {'rb_to_nn': 'fineness', 'rb_to_jj': 'fine', 'rb_to_vb': 'fine'},
 'firstly': {'rb_to_nn': 'first', 'rb_to_jj': 'first'},
 'flexibly': {'rb_to_nn': 'flexibility', 'rb_to_jj': 'flexible'},
 'fondly': {'rb_to_nn': 'fondness', 'rb_to_jj': 'fond'},
 'formally': {'rb_to_nn': 'formality', 'rb_to_jj': 'formal'},
 'formerly': {'rb_to_nn': 'former', 'rb_to_jj': 'former'},
 'foundationally': {'rb_to_nn': 'foundation', 'rb_to_jj': 'foundational'},
 'freely': {'rb_to_nn': 'freedom', 'rb_to_jj': 'free', 'rb_to_vb': 'free'},
 'freshly': {'rb_to_nn': 'freshness', 'rb_to_jj': 'fresh'},
 'fundamentally': {'rb_to_nn': 'fundamental', 'rb_to_jj': 'fundamental'},
 'funerally': {'rb_to_nn': 'funeral', 'rb_to_jj': 'funeral'},
 'generously': {'rb_to_nn': 'generosity', 'rb_to_jj': 'generous'},
 'gently': {'rb_to_nn': 'gentle', 'rb_to_jj': 'gentle', 'rb_to_vb': 'gentle'},
 'globally': {'rb_to_nn': 'globe', 'rb_to_jj': 'global', 'rb_to_vb': 'globe'},
 'goldenly': {'rb_to_nn': 'gold', 'rb_to_jj': 'golden'},
 'gradually': {'rb_to_nn': 'gradual', 'rb_to_jj': 'gradual'},
 'grandly': {'rb_to_nn': 'grand', 'rb_to_jj': 'grand'},
 'gratefully': {'rb_to_nn': 'gratefulness', 'rb_to_jj': 'grateful'},
 'greatly': {'rb_to_nn': 'greatness', 'rb_to_jj': 'great'},
 'greedily': {'rb_to_nn': 'greed', 'rb_to_jj': 'greedy'},
 'guiltily': {'rb_to_nn': 'guilt', 'rb_to_jj': 'guilty'},
 'hairily': {'rb_to_nn': 'hair', 'rb_to_jj': 'hair', 'rb_to_vb': 'hair'},
 'happily': {'rb_to_nn': 'happiness', 'rb_to_jj': 'happy'},
 'hastily': {'rb_to_nn': 'haste', 'rb_to_jj': 'hasty', 'rb_to_vb': 'haste'},
 'highly': {'rb_to_nn': 'highness', 'rb_to_jj': 'high'},
 'historically': {'rb_to_nn': 'history', 'rb_to_jj': 'historic'},
 'honestly': {'rb_to_nn': 'honesty', 'rb_to_jj': 'honest'},
 'hopefully': {'rb_to_nn': 'hope', 'rb_to_jj': 'hopeful', 'rb_to_vb': 'hope'},
 'hungrily': {'rb_to_nn': 'hunger', 'rb_to_jj': 'hungry', 'rb_to_vb': 'hunger'},
 'hurriedly': {'rb_to_nn': 'hurry', 'rb_to_jj': 'hurried', 'rb_to_vb': 'hurry'},
 'icily': {'rb_to_nn': 'ice', 'rb_to_jj': 'ice', 'rb_to_vb': 'ice'},
 'ideally': {'rb_to_nn': 'ideal', 'rb_to_jj': 'ideal'},
 'identically': {'rb_to_nn': 'identical', 'rb_to_jj': 'identical'},
 'ideologically': {'rb_to_nn': 'ideology', 'rb_to_jj': 'ideological'},
 'immediately': {'rb_to_nn': 'immediacy', 'rb_to_jj': 'immediate'},
 'immensely': {'rb_to_nn': 'immenseness', 'rb_to_jj': 'immense'},
 'implicitly': {'rb_to_nn': 'implicity', 'rb_to_jj': 'implicit'},
 'importantly': {'rb_to_nn': 'importance', 'rb_to_jj': 'important'},
 'incidentally': {'rb_to_nn': 'incidence', 'rb_to_jj': 'incident'},
 'increasingly': {'rb_to_nn': 'increase', 'rb_to_jj': 'increasing', 'rb_to_vb': 'increase'},
 'independently': {'rb_to_nn': 'independence', 'rb_to_jj': 'independent'},
 'industrially': {'rb_to_nn': 'industry', 'rb_to_jj': 'industrial'},
 'inevitably': {'rb_to_nn': 'inevitability', 'rb_to_jj': 'inevitable'},
 'inherently': {'rb_to_nn': 'inherence', 'rb_to_jj': 'inherent'},
 'instantly': {'rb_to_nn': 'instance', 'rb_to_jj': 'instant'},
 'instrumentally': {'rb_to_nn': 'instrument', 'rb_to_jj': 'instrumental'},
 'integrally': {'rb_to_nn': 'integral', 'rb_to_jj': 'integral'},
 'intelligently': {'rb_to_nn': 'intelligence', 'rb_to_jj': 'intelligent'},
 'intensely': {'rb_to_nn': 'intensity', 'rb_to_jj': 'intense', 'rb_to_vb': 'intensify'},
 'introductory': {'rb_to_nn': 'introduction', 'rb_to_vb': 'introduce'},
 'inwardly': {'rb_to_nn': 'inward', 'rb_to_jj': 'inward'},
 'jealously': {'rb_to_nn': 'jealousy', 'rb_to_jj': 'jealous'},
 'jointly': {'rb_to_nn': 'joint', 'rb_to_jj': 'jointed', 'rb_to_vb': 'joint'},
 'juicily': {'rb_to_nn': 'juice', 'rb_to_jj': 'juicy'},
 'lastly': {'rb_to_nn': 'last', 'rb_to_jj': 'last', 'rb_to_vb': 'last'},
 'lately': {'rb_to_nn': 'lateness', 'rb_to_jj': 'late'},
 'lazily': {'rb_to_nn': 'laziness', 'rb_to_jj': 'lazy'},
 'legally': {'rb_to_nn': 'legality', 'rb_to_jj': 'legal'},
 'likewise': {'rb_to_nn': 'likelihood', 'rb_to_jj': 'likely'},
 'literarily': {'rb_to_nn': 'literature', 'rb_to_jj': 'literary'},
 'lively': {'rb_to_nn': 'living', 'rb_to_jj': 'living', 'rb_to_vb': 'live', 'jj_to_jjr': 'livelier', 'jj_to_jjs': 'liveliest'},
 'locally': {'rb_to_nn': 'local', 'rb_to_jj': 'local'},
 'logically': {'rb_to_nn': 'logic', 'rb_to_jj': 'logical'},
 'loudly': {'rb_to_nn': 'loudness', 'rb_to_jj': 'loud'},
 'loyally': {'rb_to_nn': 'loyalty', 'rb_to_jj': 'loyal'},
 'luckily': {'rb_to_nn': 'luck', 'rb_to_jj': 'lucky', 'rb_to_vb': 'luck'},
 'madly': {'rb_to_nn': 'madness', 'rb_to_jj': 'mad'},
 'mainly': {'rb_to_nn': 'main', 'rb_to_jj': 'main'},
 'manually': {'rb_to_nn': 'manual', 'rb_to_jj': 'manual'},
 'massively': {'rb_to_nn': 'mass', 'rb_to_jj': 'mass', 'rb_to_vb': 'mass'},
 'materially': {'rb_to_nn': 'material', 'rb_to_jj': 'material'},
 'maturely': {'rb_to_nn': 'maturity', 'rb_to_jj': 'mature', 'rb_to_vb': 'mature'},
 'meanly': {'rb_to_nn': 'meanness', 'rb_to_jj': 'mean', 'rb_to_vb': 'mean'},
 'mechanically': {'rb_to_nn': 'mechanic', 'rb_to_jj': 'mechanical'},
 'medically': {'rb_to_nn': 'medical', 'rb_to_jj': 'medical'},
 'mentally': {'rb_to_nn': 'mentality', 'rb_to_jj': 'mental'},
 'mercifully': {'rb_to_nn': 'mercy', 'rb_to_jj': 'merciful'},
 'merely': {'rb_to_nn': 'mere', 'rb_to_jj': 'mere'},
 'merrily': {'rb_to_nn': 'merriness', 'rb_to_jj': 'merry'},
 'methodically': {'rb_to_nn': 'method', 'rb_to_jj': 'methodical'},
 'mildly': {'rb_to_nn': 'mildness', 'rb_to_jj': 'mild'},
 'minimally': {'rb_to_nn': 'minimum', 'rb_to_jj': 'minimum', 'rb_to_vb': 'minimise'},
 'miserably': {'rb_to_nn': 'misery', 'rb_to_jj': 'miserable'},
 'modestly': {'rb_to_nn': 'modesty', 'rb_to_jj': 'modest'},
 'morally': {'rb_to_nn': 'morality', 'rb_to_jj': 'moral'},
 'muddily': {'rb_to_nn': 'mud', 'rb_to_jj': 'muddy', 'rb_to_vb': 'mud'},
 'musically': {'rb_to_nn': 'music', 'rb_to_jj': 'musical'},
 'mysteriously': {'rb_to_nn': 'mystery', 'rb_to_jj': 'mysterious'},
 'narrowly': {'rb_to_nn': 'narrowness', 'rb_to_jj': 'narrow', 'rb_to_vb': 'narrow'},
 'nationally': {'rb_to_nn': 'nation', 'rb_to_jj': 'national'},
 'natively': {'rb_to_nn': 'native', 'rb_to_jj': 'native'},
 'naturally': {'rb_to_nn': 'nature', 'rb_to_jj': 'natural'},
 'neatly': {'rb_to_nn': 'neatness', 'rb_to_jj': 'neat'},
 'necessarily': {'rb_to_nn': 'necessity', 'rb_to_jj': 'necessary'},
 'newly': {'rb_to_nn': 'newness', 'rb_to_jj': 'new'},
 'nicely': {'rb_to_nn': 'niceness', 'rb_to_jj': 'nice'},
 'nobly': {'rb_to_nn': 'nobility', 'rb_to_jj': 'noble', 'rb_to_vb': 'noble'},
 'noisily': {'rb_to_nn': 'noise', 'rb_to_jj': 'noisy', 'rb_to_vb': 'noise'},
 'nonsensically': {'rb_to_nn': 'nonsense', 'rb_to_jj': 'nonsensical'},
 'normally': {'rb_to_nn': 'normality', 'rb_to_jj': 'normal', 'rb_to_vb': 'normalize'},
 'notably': {'rb_to_nn': 'note', 'rb_to_jj': 'notable', 'rb_to_vb': 'note'},
 'noticeably': {'rb_to_nn': 'notice', 'rb_to_jj': 'noticeable', 'rb_to_vb': 'notice'},
 'obediently': {'rb_to_nn': 'obedience', 'rb_to_jj': 'obedient', 'rb_to_vb': 'obey'},
 'objectively': {'rb_to_nn': 'objection', 'rb_to_jj': 'objective', 'rb_to_vb': 'object'},
 'occasionally': {'rb_to_nn': 'occasion', 'rb_to_jj': 'occasional'},
 'offensively': {'rb_to_nn': 'offendence', 'rb_to_jj': 'offensive', 'rb_to_vb': 'offend'},
 'officially': {'rb_to_nn': 'officialdom', 'rb_to_jj': 'official'},
 'oily': {'rb_to_nn': 'oiliness', 'rb_to_jj': 'oiled', 'jj_to_jjr': 'oilier', 'jj_to_jjs': 'oiliest'},
 'openly': {'rb_to_nn': 'openness', 'rb_to_jj': 'open', 'rb_to_vb': 'open'},
 'ordinarily': {'rb_to_nn': 'ordinary', 'rb_to_jj': 'ordinary'},
 'originally': {'rb_to_nn': 'orientation', 'rb_to_jj': 'orientational', 'rb_to_vb': 'orient'},
 'painfully': {'rb_to_nn': 'pain', 'rb_to_jj': 'painful', 'rb_to_vb': 'pain'},
 'palely': {'rb_to_nn': 'paleness', 'rb_to_jj': 'pale', 'rb_to_vb': 'pale'},
 'partially': {'rb_to_nn': 'particle', 'rb_to_jj': 'partial', 'rb_to_vb': 'part'},
 'particularly': {'rb_to_nn': 'particularity', 'rb_to_jj': 'particular'},
 'passively': {'rb_to_nn': 'passivity', 'rb_to_jj': 'passive'},
 'patiently': {'rb_to_nn': 'patience', 'rb_to_jj': 'patient'},
 'peacefully': {'rb_to_nn': 'peace', 'rb_to_jj': 'peaceful'},
 'peculiarly': {'rb_to_nn': 'peculiarity', 'rb_to_jj': 'peculiar'},
 'perfectly': {'rb_to_nn': 'perfection', 'rb_to_jj': 'perfect'},
 'periodically': {'rb_to_nn': 'period', 'rb_to_jj': 'periodical'},
 'persistently': {'rb_to_nn': 'persistence', 'rb_to_jj': 'persistent', 'rb_to_vb': 'persist'},
 'persuasively': {'rb_to_nn': 'persuasion', 'rb_to_jj': 'persuasive', 'rb_to_vb': 'persuade'},
 'pinkly': {'rb_to_nn': 'pinkness', 'rb_to_jj': 'pink'},
 'poisonously': {'rb_to_nn': 'poisoner', 'rb_to_jj': 'poisonous', 'rb_to_vb': 'poison'},
 'politest': {'rb_to_nn': 'polisher', 'rb_to_vb': 'polish'},
 'politely': {'rb_to_nn': 'politeness', 'rb_to_jj': 'polite'},
 'politically': {'rb_to_nn': 'politician', 'rb_to_jj': 'political'},
 'popularly': {'rb_to_nn': 'popularity', 'rb_to_jj': 'popular'},
 'possibly': {'rb_to_nn': 'possibility', 'rb_to_jj': 'possible'},
 'precedently': {'rb_to_nn': 'precedence', 'rb_to_jj': 'precedent', 'rb_to_vb': 'precede'},
 'precisely': {'rb_to_nn': 'precision', 'rb_to_jj': 'precise'},
 'predictably': {'rb_to_nn': 'predictability', 'rb_to_jj': 'predictable', 'rb_to_vb': 'predict'},
 'predominantly': {'rb_to_nn': 'predominance', 'rb_to_jj': 'predominant', 'rb_to_vb': 'predominate'},
 'preferably': {'rb_to_nn': 'preference', 'rb_to_jj': 'preferable', 'rb_to_vb': 'prefer'},
 'presently': {'rb_to_nn': 'presence', 'rb_to_jj': 'present', 'rb_to_vb': 'present'},
 'presidentially': {'rb_to_nn': 'president', 'rb_to_jj': 'presidential'},
 'presumably': {'rb_to_nn': 'presumption', 'rb_to_jj': 'presumable', 'rb_to_vb': 'presume'},
 'prettily': {'rb_to_nn': 'prettiness', 'rb_to_jj': 'pretty'},
 'privately': {'rb_to_nn': 'privacy', 'rb_to_jj': 'private'},
 'probably': {'rb_to_nn': 'probability', 'rb_to_jj': 'probable'},
 'problematically': {'rb_to_nn': 'problem', 'rb_to_jj': 'problematic'},
 'procedurally': {'rb_to_nn': 'procedure', 'rb_to_jj': 'procedural', 'rb_to_vb': 'proceed'},
 'productively': {'rb_to_nn': 'production', 'rb_to_jj': 'productive'},
 'professionally': {'rb_to_nn': 'professionalism', 'rb_to_jj': 'professional'},
 'progressively': {'rb_to_nn': 'progress', 'rb_to_jj': 'progressive', 'rb_to_vb': 'progress'},
 'prohibitively': {'rb_to_nn': 'prohibition', 'rb_to_jj': 'prohibitive', 'rb_to_vb': 'prohibit'},
 'promptly': {'rb_to_nn': 'prompt', 'rb_to_jj': 'prompt', 'rb_to_vb': 'prompt'},
 'prospectively': {'rb_to_nn': 'prospection', 'rb_to_jj': 'prospective', 'rb_to_vb': 'prospect'},
 'protectively': {'rb_to_nn': 'protection', 'rb_to_jj': 'protective', 'rb_to_vb': 'protect'},
 'provisionally': {'rb_to_nn': 'provision', 'rb_to_jj': 'provisional'},
 'psychologically': {'rb_to_nn': 'psychology', 'rb_to_jj': 'psychological'},
 'publically': {'rb_to_nn': 'publicity', 'rb_to_jj': 'publical'},
 'punctually': {'rb_to_nn': 'punctuality', 'rb_to_jj': 'punctual'},
 'purely': {'rb_to_nn': 'pureness', 'rb_to_jj': 'pure'},
 'purposively': {'rb_to_nn': 'purposiveness', 'rb_to_jj': 'purposive'},
 'questionably': {'rb_to_nn': 'questionnaire', 'rb_to_vb': 'question'},
 'quickly': {'rb_to_nn': 'quickness', 'rb_to_jj': 'questionable'},
 'quietly': {'rb_to_nn': 'quietness', 'rb_to_jj': 'quick'},
 'randomly': {'rb_to_nn': 'randomness', 'rb_to_jj': 'random'},
 'rankly': {'rb_to_nn': 'rank', 'rb_to_jj': 'rank', 'rb_to_vb': 'rank'},
 'rapidly': {'rb_to_nn': 'rapidity', 'rb_to_jj': 'rapid'},
 'rarely': {'rb_to_nn': 'rareness', 'rb_to_jj': 'rare'},
 'rationally': {'rb_to_nn': 'rationalisation', 'rb_to_jj': 'rational', 'rb_to_vb': 'rationalise'},
 'rawly': {'rb_to_nn': 'rawness', 'rb_to_jj': 'raw'},
 'reactively': {'rb_to_nn': 'reaction', 'rb_to_jj': 'reactive', 'rb_to_vb': 'reactivate'},
 'really': {'rb_to_nn': 'reality', 'rb_to_jj': 'real'},
 'reasonably': {'rb_to_nn': 'reason', 'rb_to_jj': 'reasonable'},
 'reflectively': {'rb_to_nn': 'reflection', 'rb_to_jj': 'reflective', 'rb_to_vb': 'reflect'},
 'regionally': {'rb_to_nn': 'region', 'rb_to_jj': 'regional'},
 'regretfully': {'rb_to_nn': 'regret', 'rb_to_jj': 'regretful', 'rb_to_vb': 'regret'},
 'regularly': {'rb_to_nn': 'regularity', 'rb_to_jj': 'regular'},
 'relevantly': {'rb_to_nn': 'relevance', 'rb_to_jj': 'relevant'},
 'religiously': {'rb_to_nn': 'religion', 'rb_to_jj': 'religious'},
 'reluctantly': {'rb_to_nn': 'reluctance', 'rb_to_jj': 'reluctant'},
 'reliably': {'rb_to_nn': 'reliability', 'rb_to_jj': 'reliable', 'rb_to_vb': 'rely'},
 'remarkably': {'rb_to_nn': 'remark', 'rb_to_jj': 'remarkable'},
 'repeatedly': {'rb_to_nn': 'repetition', 'rb_to_jj': 'repeated', 'rb_to_vb': 'repeat'},
 'representively': {'rb_to_nn': 'representation', 'rb_to_jj': 'representative', 'rb_to_vb': 'represent'},
 'respectively': {'rb_to_nn': 'respect', 'rb_to_jj': 'respectful', 'rb_to_vb': 'respect'},
 'respectfully': {'rb_to_nn': 'respect', 'rb_to_jj': 'respectful', 'rb_to_vb': 'respect'},
 'restrictively': {'rb_to_nn': 'restriction', 'rb_to_jj': 'restrictive', 'rb_to_vb': 'restrict'},
 'richly': {'rb_to_nn': 'richness', 'rb_to_jj': 'rich'},
 'rightfully': {'rb_to_nn': 'rightness', 'rb_to_jj': 'rightful', 'rb_to_vb': 'right'},
 'rightly': {'rb_to_nn': 'rightness', 'rb_to_jj': 'rightful', 'rb_to_vb': 'right'},
 'rigidly': {'rb_to_nn': 'rigidity', 'rb_to_jj': 'rigid'},
 'riskily': {'rb_to_nn': 'risk', 'rb_to_jj': 'risky', 'rb_to_vb': 'risk'},
 'roughly': {'rb_to_nn': 'roughness', 'rb_to_jj': 'rough'},
 'royally': {'rb_to_nn': 'royalty', 'rb_to_jj': 'royal'},
 'rudely': {'rb_to_nn': 'rudeness', 'rb_to_jj': 'rude'},
 'sadly': {'rb_to_nn': 'sadness', 'rb_to_jj': 'sad', 'rb_to_vb': 'sadden'},
 'safely': {'rb_to_nn': 'safeness', 'rb_to_jj': 'safe'},
 'scarcely': {'rb_to_nn': 'scarcity', 'rb_to_jj': 'scarce'},
 'schematically': {'rb_to_nn': 'scheme', 'rb_to_jj': 'schematic', 'rb_to_vb': 'scheme'},
 'scientifically': {'rb_to_nn': 'science', 'rb_to_jj': 'scientific'},
 'scornfully': {'rb_to_nn': 'scorn', 'rb_to_jj': 'scornful', 'rb_to_vb': 'scorn'},
 'secondly': {'rb_to_nn': 'second', 'rb_to_jj': 'second', 'rb_to_vb': 'second'},
 'secretly': {'rb_to_nn': 'secret', 'rb_to_jj': 'secret'},
 'securely': {'rb_to_nn': 'security', 'rb_to_jj': 'secure', 'rb_to_vb': 'secure'},
 'selectively': {'rb_to_nn': 'select', 'rb_to_jj': 'selective', 'rb_to_vb': 'select'},
 'sensibly': {'rb_to_nn': 'sense', 'rb_to_jj': 'sensible', 'rb_to_vb': 'sense'},
 'sensitively': {'rb_to_nn': 'sensitivity', 'rb_to_jj': 'sensitive'},
 'separately': {'rb_to_nn': 'separate', 'rb_to_jj': 'separate', 'rb_to_vb': 'separate'},
 'sequentially': {'rb_to_nn': 'sequence', 'rb_to_jj': 'sequential', 'rb_to_vb': 'sequence'},
 'seriously': {'rb_to_nn': 'seriousness', 'rb_to_jj': 'serious'},
 'severely': {'rb_to_nn': 'severity', 'rb_to_jj': 'severe'},
 'sexually': {'rb_to_nn': 'sex', 'rb_to_jj': 'sexual', 'rb_to_vb': 'sex'},
 'shakily': {'rb_to_nn': 'shake', 'rb_to_jj': 'shaky', 'rb_to_vb': 'shake'},
 'shallowly': {'rb_to_nn': 'shallowness', 'rb_to_jj': 'shallow', 'rb_to_vb': 'shallow'},
 'shamefully': {'rb_to_nn': 'shame', 'rb_to_jj': 'shameful', 'rb_to_vb': 'shame'},
 'sharply': {'rb_to_nn': 'sharpness', 'rb_to_jj': 'sharp', 'rb_to_vb': 'sharp'},
 'shortly': {'rb_to_nn': 'short', 'rb_to_jj': 'short', 'rb_to_vb': 'shorten'},
 'sickly': {'rb_to_nn': 'sickness', 'rb_to_jj': 'sick', 'jj_to_jjr': 'sicklier', 'jj_to_jjs': 'sickliest'},
 'significantly': {'rb_to_nn': 'significance', 'rb_to_jj': 'significant', 'rb_to_vb': 'signify'},
 'silently': {'rb_to_nn': 'silence', 'rb_to_jj': 'silent', 'rb_to_vb': 'silence'},
 'similarly': {'rb_to_nn': 'similarity', 'rb_to_jj': 'similar'},
 'simply': {'rb_to_nn': 'simpleness', 'rb_to_jj': 'simple', 'rb_to_vb': 'simplify'},
 'simulatedly': {'rb_to_nn': 'simulation', 'rb_to_jj': 'simulate', 'rb_to_vb': 'simulate'},
 'sincerely': {'rb_to_nn': 'sincerity', 'rb_to_jj': 'sincere'},
 'singingly': {'rb_to_nn': 'sing', 'rb_to_jj': 'singing', 'rb_to_vb': 'sing'},
 'sixthly': {'rb_to_nn': 'six', 'rb_to_jj': 'sixteenth'},
 'skilfully': {'rb_to_nn': 'skill', 'rb_to_jj': 'skilled'},
 'slightly': {'rb_to_nn': 'slight', 'rb_to_jj': 'slight', 'rb_to_vb': 'slight'},
 'slowly': {'rb_to_nn': 'slow', 'rb_to_jj': 'slow', 'rb_to_vb': 'slow'},
 'smoothly': {'rb_to_nn': 'smooth', 'rb_to_jj': 'smoothed', 'rb_to_vb': 'smooth'},
 'softly': {'rb_to_nn': 'soft', 'rb_to_jj': 'softened', 'rb_to_vb': 'soften'},
 'solely': {'rb_to_nn': 'sole', 'rb_to_jj': 'sole', 'rb_to_vb': 'sole'},
 'solemnly': {'rb_to_nn': 'solemnity', 'rb_to_jj': 'solemn'},
 'solidly': {'rb_to_nn': 'solid', 'rb_to_jj': 'solidified', 'rb_to_vb': 'solidify'},
 'sourly': {'rb_to_nn': 'sour', 'rb_to_jj': 'sour', 'rb_to_vb': 'sour'},
 'specially': {'rb_to_nn': 'special', 'rb_to_jj': 'specialist', 'rb_to_vb': 'specialize'},
 'specifically': {'rb_to_nn': 'specific', 'rb_to_jj': 'specific'},
 'spherically': {'rb_to_nn': 'sphere', 'rb_to_jj': 'spherical', 'rb_to_vb': 'sphere'},
 'squarely': {'rb_to_nn': 'square', 'rb_to_jj': 'square', 'rb_to_vb': 'square'},
 'steadily': {'rb_to_nn': 'steady', 'rb_to_jj': 'steady', 'rb_to_vb': 'steady'},
 'steered': {'rb_to_nn': 'steer', 'rb_to_jj': 'steerable', 'rb_to_vb': 'steer', 'vbd_eq_vbn': ''},
 'stingingly': {'rb_to_nn': 'sting', 'rb_to_jj': 'stinging', 'rb_to_vb': 'sting'},
 'stonily': {'rb_to_nn': 'stone', 'rb_to_jj': 'stone', 'rb_to_vb': 'stone'},
 'strategically': {'rb_to_nn': 'strategy', 'rb_to_jj': 'strategic'},
 'strictly': {'rb_to_nn': 'strictness', 'rb_to_jj': 'strict'},
 'strongly': {'rb_to_nn': 'strong', 'rb_to_jj': 'strong'},
 'stupidly': {'rb_to_nn': 'stupid', 'rb_to_jj': 'stupid'},
 'stylishly': {'rb_to_nn': 'style', 'rb_to_jj': 'stylized', 'rb_to_vb': 'style'},
 'substantially': {'rb_to_nn': 'substance', 'rb_to_jj': 'substantial'},
 'successfully': {'rb_to_nn': 'success', 'rb_to_jj': 'succeeding', 'rb_to_vb': 'succeed'},
 'succeedingly': {'rb_to_nn': 'success', 'rb_to_jj': 'succeeding', 'rb_to_vb': 'succeed'},
 'successively': {'rb_to_nn': 'successor', 'rb_to_jj': 'successive'},
 'suddenly': {'rb_to_nn': 'sudden', 'rb_to_jj': 'sudden'},
 'sufficiently': {'rb_to_nn': 'sufficiency', 'rb_to_jj': 'sufficient'},
 'sunnily': {'rb_to_nn': 'sun', 'rb_to_jj': 'sunny'},
 'supposedly': {'rb_to_nn': 'supposition', 'rb_to_jj': 'supposed', 'rb_to_vb': 'suppose'},
 'surficially': {'rb_to_nn': 'surface', 'rb_to_jj': 'surface', 'rb_to_vb': 'surface'},
 'surprisingly': {'rb_to_nn': 'surprise', 'rb_to_jj': 'surprise', 'rb_to_vb': 'surprise'},
 'suspiciously': {'rb_to_nn': 'suspicion', 'rb_to_jj': 'suspicious', 'rb_to_vb': 'suspicion'},
 'sweetly': {'rb_to_nn': 'sweet', 'rb_to_jj': 'sweet'},
 'swimmingly': {'rb_to_nn': 'swim', 'rb_to_jj': 'swim', 'rb_to_vb': 'swim'},
 'symbolically': {'rb_to_nn': 'symbol', 'rb_to_jj': 'symbolic', 'rb_to_vb': 'symbolise'},
 'sympathetically': {'rb_to_nn': 'sympathy', 'rb_to_jj': 'sympathetic'},
 'systematically': {'rb_to_nn': 'system', 'rb_to_jj': 'systematic'},
 'taxably': {'rb_to_nn': 'tax', 'rb_to_jj': 'taxable', 'rb_to_vb': 'tax'},
 'technologically': {'rb_to_nn': 'technology', 'rb_to_jj': 'technological'},
 'telegraphically': {'rb_to_nn': 'telegraph', 'rb_to_jj': 'telegraphic', 'rb_to_vb': 'telegraph'},
 'temporarily': {'rb_to_nn': 'temporary', 'rb_to_jj': 'temporary'},
 'tenderly': {'rb_to_nn': 'tender', 'rb_to_jj': 'tender', 'rb_to_vb': 'tender'},
 'tensely': {'rb_to_nn': 'tense', 'rb_to_jj': 'tense', 'rb_to_vb': 'tense'},
 'terribly': {'rb_to_nn': 'terribleness', 'rb_to_jj': 'terrible'},
 'textually': {'rb_to_nn': 'text', 'rb_to_jj': 'textual', 'rb_to_vb': 'text'},
 'thankfully': {'rb_to_nn': 'thank', 'rb_to_jj': 'thankful', 'rb_to_vb': 'thank'},
 'theatrically': {'rb_to_nn': 'theatre', 'rb_to_jj': 'theatrical', 'rb_to_vb': 'theatricalize'},
 'thematically': {'rb_to_nn': 'theme', 'rb_to_jj': 'thematic'},
 'theoretically': {'rb_to_nn': 'theory', 'rb_to_jj': 'theoretical'},
 'thickly': {'rb_to_nn': 'thick', 'rb_to_jj': 'thick'},
 'thinly': {'rb_to_nn': 'thin', 'rb_to_jj': 'thin', 'rb_to_vb': 'thin'},
 'thoughtfully': {'rb_to_nn': 'think', 'rb_to_jj': 'think', 'rb_to_vb': 'think'},
 'thirstily': {'rb_to_nn': 'thirty', 'rb_to_jj': 'thirtieth'},
 'thoroughly': {'rb_to_nn': 'thoroughness', 'rb_to_jj': 'thorough'},
 'threadbare': {'rb_to_nn': 'thread', 'rb_to_jj': 'threaded', 'rb_to_vb': 'thread'},
 'thirdly': {'rb_to_nn': 'three', 'rb_to_jj': 'third'},
 'thunderously': {'rb_to_nn': 'thunder', 'rb_to_jj': 'thunderous'},
 'tidily': {'rb_to_nn': 'tidy', 'rb_to_jj': 'tidy', 'rb_to_vb': 'tidy'},
 'tightly': {'rb_to_nn': 'tightness', 'rb_to_jj': 'tight', 'rb_to_vb': 'tighten'},
 'timely': {'rb_to_nn': 'time', 'rb_to_jj': 'timeless', 'rb_to_vb': 'time', 'jj_to_jjr': 'timelier', 'jj_to_jjs': 'timeliest'},
 'tiredly': {'rb_to_nn': 'tire', 'rb_to_jj': 'tired', 'rb_to_vb': 'tire'},
 'topically': {'rb_to_nn': 'topic', 'rb_to_jj': 'topical'},
 'totally': {'rb_to_nn': 'total', 'rb_to_jj': 'total', 'rb_to_vb': 'totalize'},
 'toughly': {'rb_to_nn': 'tough', 'rb_to_jj': 'tough', 'rb_to_vb': 'toughen'},
 'traditionally': {'rb_to_nn': 'tradition', 'rb_to_jj': 'traditional'},
 'transformationally': {'rb_to_nn': 'transformat', 'rb_to_jj': 'transformational', 'rb_to_vb': 'transform'},
 'transitionally': {'rb_to_nn': 'transit', 'rb_to_jj': 'transitory', 'rb_to_vb': 'transit'},
 'transmissively': {'rb_to_nn': 'transmission', 'rb_to_jj': 'transmissive', 'rb_to_vb': 'transmit'},
 'troublesomely': {'rb_to_nn': 'trouble', 'rb_to_jj': 'troublesome', 'rb_to_vb': 'trouble'},
 'truly': {'rb_to_nn': 'truth', 'rb_to_jj': 'TRUE'},
 'tunelessly': {'rb_to_nn': 'tune', 'rb_to_jj': 'tuneless', 'rb_to_vb': 'tune'},
 'uglily': {'rb_to_nn': 'uglifier', 'rb_to_jj': 'ugly', 'rb_to_vb': 'uglify'},
 'uniformly': {'rb_to_nn': 'uniform', 'rb_to_jj': 'uniform', 'rb_to_vb': 'uniform'},
 'uniquely': {'rb_to_nn': 'unique', 'rb_to_jj': 'unique'},
 'unitively': {'rb_to_nn': 'unity', 'rb_to_jj': 'unitive', 'rb_to_vb': 'unite'},
 'universally': {'rb_to_nn': 'universe', 'rb_to_jj': 'universal'},
 'upsettingly': {'rb_to_nn': 'upset', 'rb_to_jj': 'upsetting', 'rb_to_vb': 'upset'},
 'urgently': {'rb_to_nn': 'urge', 'rb_to_jj': 'urgent', 'rb_to_vb': 'urge', 'be_rb_to.rb_to_jj': 'urgent'},
 'usefully': {'rb_to_nn': 'use', 'rb_to_jj': 'useful', 'rb_to_vb': 'use'},
 'validly': {'rb_to_nn': 'validation', 'rb_to_jj': 'valid', 'rb_to_vb': 'validate'},
 'valuably': {'rb_to_nn': 'value', 'rb_to_jj': 'valuable', 'rb_to_vb': 'value'},
 'variably': {'rb_to_nn': 'vary', 'rb_to_jj': 'variable', 'rb_to_vb': 'vary'},
 'victoriously': {'rb_to_nn': 'victory', 'rb_to_jj': 'victorious'},
 'violably': {'rb_to_nn': 'violator', 'rb_to_jj': 'violable', 'rb_to_vb': 'violate'},
 'violently': {'rb_to_nn': 'violence', 'rb_to_jj': 'violent'},
 'virtually': {'rb_to_nn': 'virtualization', 'rb_to_jj': 'virtual', 'rb_to_vb': 'virtualize'},
 'virtuously': {'rb_to_nn': 'virtue', 'rb_to_jj': 'virtuous', 'rb_to_vb': 'virtue'},
 'visibly': {'rb_to_nn': 'visibility', 'rb_to_jj': 'visible'},
 'visionally': {'rb_to_nn': 'vision', 'rb_to_jj': 'visional', 'rb_to_vb': 'vision'},
 'visually': {'rb_to_nn': 'visualisation', 'rb_to_jj': 'visual', 'rb_to_vb': 'visualise'},
 'voicelessly': {'rb_to_nn': 'voice', 'rb_to_jj': 'voiced', 'rb_to_vb': 'voice'},
 'voluntarily': {'rb_to_nn': 'voluntary', 'rb_to_jj': 'voluntary'},
 'warmly': {'rb_to_nn': 'warm', 'rb_to_jj': 'warm', 'rb_to_vb': 'warm'},
 'wastefully': {'rb_to_nn': 'waste', 'rb_to_jj': 'wasteful', 'rb_to_vb': 'wast'},
 'waxily': {'rb_to_nn': 'wax', 'rb_to_jj': 'waxy', 'rb_to_vb': 'wax'},
 'weakly': {'rb_to_nn': 'weakness', 'rb_to_jj': 'weak', 'rb_to_vb': 'weaken', 'jj_to_jjr': 'weaklier', 'jj_to_jjs': 'weakliest'},
 'wealthily': {'rb_to_nn': 'wealth', 'rb_to_jj': 'wealthy'},
 'wearily': {'rb_to_nn': 'wear', 'rb_to_jj': 'wearable', 'rb_to_vb': 'wear'},
 'welcomely': {'rb_to_nn': 'welcome', 'rb_to_jj': 'welcome', 'rb_to_vb': 'welcome'},
 'wetly': {'rb_to_nn': 'wet', 'rb_to_jj': 'wet', 'rb_to_vb': 'wetten'},
 'wholly': {'rb_to_nn': 'whole', 'rb_to_jj': 'whole'},
 'widely': {'rb_to_nn': 'wide', 'rb_to_jj': 'wide', 'rb_to_vb': 'widen'},
 'wildly': {'rb_to_nn': 'wild', 'rb_to_jj': 'wild'},
 'windily': {'rb_to_nn': 'wind', 'rb_to_jj': 'windy', 'rb_to_vb': 'wind'},
 'wintrily': {'rb_to_nn': 'winter', 'rb_to_jj': 'wintry'},
 'wirelessly': {'rb_to_nn': 'wire', 'rb_to_jj': 'wireless', 'rb_to_vb': 'wire'},
 'wisely': {'rb_to_nn': 'wise', 'rb_to_jj': 'wise', 'rb_to_vb': 'wisen'},
 'wishfully': {'rb_to_nn': 'wish', 'rb_to_jj': 'wishful', 'rb_to_vb': 'wish'},
 'wonderfully': {'rb_to_nn': 'wonder', 'rb_to_jj': 'wonderful', 'rb_to_vb': 'wonder'},
 'wordlessly': {'rb_to_nn': 'word', 'rb_to_jj': 'wordless', 'rb_to_vb': 'word'},
 'worshipfully': {'rb_to_nn': 'worship', 'rb_to_jj': 'worshipful', 'rb_to_vb': 'worship'},
 'worthily': {'rb_to_nn': 'worth', 'rb_to_jj': 'worthy', 'rb_to_vb': 'worth'},
 'youthfully': {'rb_to_nn': 'youth', 'rb_to_jj': 'youthful', 'rb_to_vb': 'youthen'},
 'positively': {'rb_to_nn': 'positiveness'},
 'internally': {'rb_to_jj': 'internal', 'rb_to_vb': 'internalize'},
 'philosophically': {'rb_to_jj': 'philosophical'},
 'pleasantly': {'rb_to_jj': 'pleasant'},
 'proportionally': {'rb_to_jj': 'proportional'},
 'qualitatively': {'rb_to_jj': 'qualitative'},
 'inherit': {'vb_to_nn': 'inheritance', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'recently': {'rb_to_jj': 'recent'},
 'recent': {'jj_to_rb': 'recently'},
 'harmonious': {'jj_to_nn': 'harmony'},
 'practising': {'vbg_to_nn': 'practice', 'vbg_to_vb': 'practise', 'vbg_to_vbn': 'practised'},
 'prosperous': {'jj_to_nn': 'prosperity'},
 'rapacious': {'jj_to_nn': 'rapaciousness'},
 'rapaciousness': {'nn_to_jj': 'rapacious'},
 'developing ': {'vbg_to_nn': 'development'},
 'inconvenient': {'jj_to_nn': 'inconvenience'},
 'talented': {'jj_to_nn': 'talent', 'jj_ed': ''},
 'sure': {'jj_to_vb': 'ensure', 'rb_to_vb': 'ensure', 'be_jj_to_vb': '', 'jj_to_jjr': 'surer', 'jj_to_jjs': 'surest'},
 'obviously': {'rb_to_jj': 'obvious'},
 'laze': {'vb_to_nn': 'laziness', 'nn_to_jj': 'lazy', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'athletic': {'jj_to_nn': 'athlete'},
 'analyze': {'vb_to_nn': 'analysis', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'zealous': {'jj_to_nn': 'zeal'},
 'flippant': {'jj_to_nn': 'flippancy'},
 'conquer': {'vb_to_nn': 'conquest', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'effected': {'confu_pair': 'affected', 'vbd_eq_vbn': ''},
 'affected': {'confu_pair': 'effected', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'idly': {'rb_to_jj': 'idle'},
 'corroded': {'jj_to_nn': 'corrosion', 'vbd_eq_vbn': ''},
 'unfortunately': {'rb_to_jj': 'unfortunate'},
 'clearly': {'rb_to_jj': 'clear'},
 'advantageous': {'jj_to_nn': 'advantage'},
 'discordant': {'jj_to_nn': 'discordance'},
 'confused': {'vbn_to_nn': 'confusion', 'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'holily': {'rb_to_jj': 'holy'},
 'dialectical': {'jj_to_rb': 'dialectically'},
 'dialectically': {'rb_to_jj': 'dialectical'},
 'intensive': {'jj_to_rb': 'intensively'},
 'intensively': {'rb_to_jj': 'intensive'},
 'powered': {'confu_pair': 'powerful', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'naughty': {'jj_to_nn': 'naught', 'jj_to_jjr': 'naughtier', 'jj_to_jjs': 'naughtiest'},
 'skillful': {'jj_to_rb': 'skillfully'},
 'skillfully': {'rb_to_jj': 'skillful'},
 'aloud': {'rb_to_jj': 'loud'},
 'humors': {'nns_to_jj': 'humorous'},
 'discussing': {'vbg_to_nn': 'discussion', 'vbg_to_vb': 'discuss', 'vbg_to_vbn': 'discussed'},
 'terrify': {'vb_to_nn': 'terror', 'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'tasty': {'confu_pair': 'tasteful', 'jj_to_jjr': 'tastier', 'jj_to_jjs': 'tastiest'},
 'addicting': {'vbg_to_vbn': 'addicted'},
 'addicted': {'vbn_to_vbg': 'addicting', 'jj_ed': '', 'be_jj_to_vbg': '', 'be_jj_to_n': '', 'vbd_eq_vbn': ''},
 'barracks': {'nn_eq_nns': ''},
 'Chinese': {'nn_eq_nns': ''},
 'Swiss': {'nn_eq_nns': ''},
 'trousers': {'nn_eq_nns': ''},
 'adore': {'v_vbg': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'vt_typical': ''},
 'begrudge': {'v_vbg': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'condone': {'v_vbg': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'disclaim': {'v_vbg': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'discontinue': {'v_vbg': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'evade': {'v_vbg': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'feellike': {'v_vbg': ''},
 'forswear': {'v_vbg': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'giveup': {'v_vbg': ''},
 'meditate': {'v_vbg': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'necessitate': {'v_vbg': '', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'repent': {'v_vbg': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'shirk': {'v_vbg': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'shun': {'v_vbg': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'abandoning': {'vbg_to_vb': 'abandon', 'vbg_to_vbn': 'abandoned'},
 'absorbing': {'vbg_to_vb': 'absorb', 'vbg_to_vbn': 'absorbed'},
 'abusing': {'vbg_to_vb': 'abuse', 'vbg_to_vbn': 'abused'},
 'accepting': {'vbg_to_vb': 'accept', 'vbg_to_vbn': 'accepted'},
 'accessing': {'vbg_to_vb': 'access', 'vbg_to_vbn': 'accessed'},
 'accompanying': {'vbg_to_vb': 'accompany', 'vbg_to_vbn': 'accompanied'},
 'accusing': {'vbg_to_vb': 'accuse', 'vbg_to_vbn': 'accused'},
 'achieving': {'vbg_to_vb': 'achieve', 'vbg_to_vbn': 'achieved'},
 'acknowledging': {'vbg_to_vb': 'acknowledge', 'vbg_to_vbn': 'acknowledged'},
 'acquiring': {'vbg_to_vb': 'acquire', 'vbg_to_vbn': 'acquired'},
 'adapting': {'vbg_to_vb': 'adapt', 'vbg_to_vbn': 'adapted'},
 'adding': {'vbg_to_vb': 'add', 'vbg_to_vbn': 'added'},
 'addressing': {'vbg_to_vb': 'address', 'vbg_to_vbn': 'addressed'},
 'adjusting': {'vbg_to_vb': 'adjust', 'vbg_to_vbn': 'adjusted'},
 'admiring': {'vbg_to_vb': 'admire', 'vbg_to_vbn': 'admired', 'sth_be_jj': ''},
 'admiting': {'vbg_to_vb': 'admit', 'vbg_to_vbn': 'admited'},
 'adopting': {'vbg_to_vb': 'adopt', 'vbg_to_vbn': 'adopted'},
 'advancing': {'vbg_to_vb': 'advance', 'vbg_to_vbn': 'advanced'},
 'advantaging': {'vbg_to_vb': 'advantage', 'vbg_to_vbn': 'advantaged'},
 'adverting': {'vbg_to_vb': 'advert', 'vbg_to_vbn': 'adverted'},
 'advising': {'vbg_to_vb': 'advise', 'vbg_to_vbn': 'advised'},
 'a\x1effecting': {'vbg_to_vb': 'a\x1effect', 'vbg_to_vbn': 'a\x1effected'},
 'a\x1effording': {'vbg_to_vb': 'a\x1efford', 'vbg_to_vbn': 'a\x1efforded'},
 'agreeing': {'vbg_to_vb': 'agree', 'vbg_to_vbn': 'agreed'},
 'aiming': {'vbg_to_vb': 'aim', 'vbg_to_vbn': 'aimed'},
 'alarming': {'vbg_to_vb': 'alarm', 'vbg_to_vbn': 'alarmed', 'sth_be_jj': ''},
 'allowing': {'vbg_to_vb': 'allow', 'vbg_to_vbn': 'allowed'},
 'altering': {'vbg_to_vb': 'alter', 'vbg_to_vbn': 'altered'},
 'amounting': {'vbg_to_vb': 'amount', 'vbg_to_vbn': 'amounted'},
 'analysing': {'vbg_to_vb': 'analyse', 'vbg_to_vbn': 'analysed'},
 'announcing': {'vbg_to_vb': 'announce', 'vbg_to_vbn': 'announced'},
 'anticipating': {'vbg_to_vb': 'anticipate', 'vbg_to_vbn': 'anticipated'},
 'apologizing': {'vbg_to_vb': 'apologize', 'vbg_to_vbn': 'apologized'},
 'appealing': {'vbg_to_vb': 'appeal', 'vbg_to_vbn': 'appealed'},
 'appearing': {'vbg_to_vb': 'appear', 'vbg_to_vbn': 'appeared'},
 'applying': {'vbg_to_vb': 'apply', 'vbg_to_vbn': 'applied'},
 'appointing': {'vbg_to_vb': 'appoint', 'vbg_to_vbn': 'appointed'},
 'appreciating': {'vbg_to_vb': 'appreciate', 'vbg_to_vbn': 'appreciated'},
 'approaching': {'vbg_to_vb': 'approach', 'vbg_to_vbn': 'approached'},
 'appropriating': {'vbg_to_vb': 'appropriate', 'vbg_to_vbn': 'appropriated'},
 'approximating': {'vbg_to_vb': 'approximate', 'vbg_to_vbn': 'approximated'},
 'arguing': {'vbg_to_vb': 'argue', 'vbg_to_vbn': 'argued'},
 'argumenting': {'vbg_to_vb': 'argument', 'vbg_to_vbn': 'argumented'},
 'arising': {'vbg_to_vb': 'arise', 'vbg_to_vbn': 'arised'},
 'arranging': {'vbg_to_vb': 'arrange', 'vbg_to_vbn': 'arranged'},
 'arriving': {'vbg_to_vb': 'arrive', 'vbg_to_vbn': 'arrived'},
 'articling': {'vbg_to_vb': 'article', 'vbg_to_vbn': 'articled'},
 'asking': {'vbg_to_vb': 'ask', 'vbg_to_vbn': 'asked'},
 'assessing': {'vbg_to_vb': 'assess', 'vbg_to_vbn': 'assessed'},
 'assisting': {'vbg_to_vb': 'assist', 'vbg_to_vbn': 'assisted'},
 'associating': {'vbg_to_vb': 'associate', 'vbg_to_vbn': 'associated'},
 'assuming': {'vbg_to_vb': 'assume', 'vbg_to_vbn': 'assumed'},
 'assuring': {'vbg_to_vb': 'assure', 'vbg_to_vbn': 'assured'},
 'attending': {'vbg_to_vb': 'attend', 'vbg_to_vbn': 'attended'},
 'attracting': {'vbg_to_vb': 'attract', 'vbg_to_vbn': 'attracted'},
 'avoiding': {'vbg_to_vb': 'avoid', 'vbg_to_vbn': 'avoided'},
 'awaking': {'vbg_to_vb': 'awake', 'vbg_to_vbn': 'awaked'},
 'awarding': {'vbg_to_vb': 'award', 'vbg_to_vbn': 'awarded'},
 'balancing': {'vbg_to_vb': 'balance', 'vbg_to_vbn': 'balanced'},
 'banning': {'vbg_to_vb': 'ban', 'vbg_to_vbn': 'banned'},
 'banding': {'vbg_to_vb': 'band', 'vbg_to_vbn': 'banded'},
 'banging': {'vbg_to_vb': 'bang', 'vbg_to_vbn': 'banged'},
 'basing': {'vbg_to_vb': 'base', 'vbg_to_vbn': 'based'},
 'bating': {'vbg_to_vb': 'bat', 'vbg_to_vbn': 'batted'},
 'battling': {'vbg_to_vb': 'battle', 'vbg_to_vbn': 'battled'},
 'beaching': {'vbg_to_vb': 'beach', 'vbg_to_vbn': 'beached'},
 'bearding': {'vbg_to_vb': 'beard', 'vbg_to_vbn': 'bearded'},
 'behaving': {'vbg_to_vb': 'behave', 'vbg_to_vbn': 'behaved'},
 'bending': {'vbg_to_vb': 'bend', 'vbg_to_vbn': 'bent'},
 'benefi\x1dting': {'vbg_to_vb': 'benefi\x1dt', 'vbg_to_vbn': 'benefi\x1dted'},
 'betting': {'vbg_to_vb': 'bet', 'vbg_to_vbn': 'bet'},
 'bettering': {'vbg_to_vb': 'better', 'vbg_to_vbn': 'bettered'},
 'bicycling': {'vbg_to_vb': 'bicycle', 'vbg_to_vbn': 'bicycled'},
 'biking': {'vbg_to_vb': 'bike', 'vbg_to_vbn': 'biked'},
 'blaming': {'vbg_to_vb': 'blame', 'vbg_to_vbn': 'blamed'},
 'blinding': {'vbg_to_vb': 'blind', 'vbg_to_vbn': 'blinded'},
 'blocking': {'vbg_to_vb': 'block', 'vbg_to_vbn': 'blocked'},
 'blooding': {'vbg_to_vb': 'blood', 'vbg_to_vbn': 'blooded'},
 'blowing': {'vbg_to_vb': 'blow', 'vbg_to_vbn': 'blown'},
 'bluing': {'vbg_to_vb': 'blue', 'vbg_to_vbn': 'blued'},
 'boating': {'vbg_to_vb': 'boat', 'vbg_to_vbn': 'boated', 'nu_typical': '', 'n_is_nu': ''},
 'bombing': {'vbg_to_vb': 'bomb', 'vbg_to_vbn': 'bombed'},
 'booting': {'vbg_to_vb': 'boot', 'vbg_to_vbn': 'booted'},
 'bossing': {'vbg_to_vb': 'boss', 'vbg_to_vbn': 'bossed'},
 'bothering': {'vbg_to_vb': 'bother', 'vbg_to_vbn': 'bothered'},
 'bouncing': {'vbg_to_vb': 'bounce', 'vbg_to_vbn': 'bounced'},
 'bounding': {'vbg_to_vb': 'bound', 'vbg_to_vbn': 'bounded'},
 'branching': {'vbg_to_vb': 'branch', 'vbg_to_vbn': 'branched'},
 'braving': {'vbg_to_vb': 'brave', 'vbg_to_vbn': 'braved'},
 'breasting': {'vbg_to_vb': 'breast', 'vbg_to_vbn': 'breasted'},
 'bricking': {'vbg_to_vb': 'brick', 'vbg_to_vbn': 'bricked'},
 'bridging': {'vbg_to_vb': 'bridge', 'vbg_to_vbn': 'bridged'},
 'bringing': {'vbg_to_vb': 'bring', 'vbg_to_vbn': 'brought'},
 'bucking': {'vbg_to_vb': 'buck', 'vbg_to_vbn': 'bucked'},
 'bucketing': {'vbg_to_vb': 'bucket', 'vbg_to_vbn': 'bucketed'},
 'budgeting': {'vbg_to_vb': 'budget', 'vbg_to_vbn': 'budgeted'},
 'bugging': {'vbg_to_vb': 'bug', 'vbg_to_vbn': 'bugged'},
 'bumping': {'vbg_to_vb': 'bump', 'vbg_to_vbn': 'bumped'},
 'bunching': {'vbg_to_vb': 'bunch', 'vbg_to_vbn': 'bunched'},
 'butchering': {'vbg_to_vb': 'butcher', 'vbg_to_vbn': 'butchered'},
 'buttering': {'vbg_to_vb': 'butter', 'vbg_to_vbn': 'buttered'},
 'buttoning': {'vbg_to_vb': 'button', 'vbg_to_vbn': 'buttoned'},
 'buying': {'vbg_to_vb': 'buy', 'vbg_to_vbn': 'bought'},
 'cabling': {'vbg_to_vb': 'cable', 'vbg_to_vbn': 'cabled'},
 'calendaring': {'vbg_to_vb': 'calendar', 'vbg_to_vbn': 'calendared'},
 'calming': {'vbg_to_vb': 'calm', 'vbg_to_vbn': 'calmed'},
 'camping': {'vbg_to_vb': 'camp', 'vbg_to_vbn': 'camped'},
 'campaigning': {'vbg_to_vb': 'campaign', 'vbg_to_vbn': 'campaigned'},
 'canceling': {'vbg_to_vb': 'cancel', 'vbg_to_vbn': 'canceled'},
 'candying': {'vbg_to_vb': 'candy', 'vbg_to_vbn': 'candied'},
 'capping': {'vbg_to_vb': 'cap', 'vbg_to_vbn': 'capped'},
 'captaining': {'vbg_to_vb': 'captain', 'vbg_to_vbn': 'captained'},
 'capturing': {'vbg_to_vb': 'capture', 'vbg_to_vbn': 'captured'},
 'caring': {'vbg_to_vb': 'care', 'vbg_to_vbn': 'cared'},
 'carpeting': {'vbg_to_vb': 'carpet', 'vbg_to_vbn': 'carpeted'},
 'cashing': {'vbg_to_vb': 'cash', 'vbg_to_vbn': 'cashed'},
 'causing': {'vbg_to_vb': 'cause', 'vbg_to_vbn': 'caused'},
 'ceasing': {'vbg_to_vb': 'cease', 'vbg_to_vbn': 'ceased'},
 'celebrating': {'vbg_to_vb': 'celebrate', 'vbg_to_vbn': 'celebrated'},
 'changing': {'vbg_to_vb': 'change', 'vbg_to_vbn': 'changed'},
 'characterizing': {'vbg_to_vb': 'characterize', 'vbg_to_vbn': 'characterized'},
 'charging': {'vbg_to_vb': 'charge', 'vbg_to_vbn': 'charged'},
 'chasing': {'vbg_to_vb': 'chase', 'vbg_to_vbn': 'chased'},
 'checking': {'vbg_to_vb': 'check', 'vbg_to_vbn': 'checked'},
 'choosing': {'vbg_to_vb': 'choose', 'vbg_to_vbn': 'chosen'},
 'chopping': {'vbg_to_vb': 'chop', 'vbg_to_vbn': 'choopped'},
 'chucking': {'vbg_to_vb': 'chuck', 'vbg_to_vbn': 'chucked'},
 'claiming': {'vbg_to_vb': 'claim', 'vbg_to_vbn': 'claimed'},
 'clerking': {'vbg_to_vb': 'clerk', 'vbg_to_vbn': 'clerked'},
 'clicking': {'vbg_to_vb': 'click', 'vbg_to_vbn': 'clicked'},
 'clocking': {'vbg_to_vb': 'clock', 'vbg_to_vbn': 'clocked'},
 'closeting': {'vbg_to_vb': 'closet', 'vbg_to_vbn': 'closeted'},
 'clouding': {'vbg_to_vb': 'cloud', 'vbg_to_vbn': 'clouded'},
 'cluing': {'vbg_to_vb': 'clue', 'vbg_to_vbn': 'clued'},
 'coaching': {'vbg_to_vb': 'coach', 'vbg_to_vbn': 'coached'},
 'coaling': {'vbg_to_vb': 'coal', 'vbg_to_vbn': 'coaled'},
 'coasting': {'vbg_to_vb': 'coast', 'vbg_to_vbn': 'coasted'},
 'coining': {'vbg_to_vb': 'coin', 'vbg_to_vbn': 'coined'},
 'collapsing': {'vbg_to_vb': 'collapse', 'vbg_to_vbn': 'collapsed'},
 'collaring': {'vbg_to_vb': 'collar', 'vbg_to_vbn': 'collared'},
 'collecting': {'vbg_to_vb': 'collect', 'vbg_to_vbn': 'collected'},
 'colouring': {'vbg_to_vb': 'colour', 'vbg_to_vbn': 'coloured'},
 'commenting': {'vbg_to_vb': 'comment', 'vbg_to_vbn': 'commented'},
 'commissioning': {'vbg_to_vb': 'commission', 'vbg_to_vbn': 'commissioned'},
 'commiting': {'vbg_to_vb': 'commit', 'vbg_to_vbn': 'commited'},
 'communicating': {'vbg_to_vb': 'communicate', 'vbg_to_vbn': 'communicated', 'nn_to_vb': 'communicate'},
 'comparing': {'vbg_to_vb': 'compare', 'vbg_to_vbn': 'compared'},
 'completing': {'vbg_to_vb': 'complete', 'vbg_to_vbn': 'completed'},
 'complicateding': {'vbg_to_vb': 'complicated', 'vbg_to_vbn': 'complicateded'},
 'comprising': {'vbg_to_vb': 'comprise', 'vbg_to_vbn': 'comprised'},
 'concentrating': {'vbg_to_vb': 'concentrate', 'vbg_to_vbn': 'concentrated'},
 'concerning': {'vbg_to_vb': 'concern', 'vbg_to_vbn': 'concerned'},
 'concerting': {'vbg_to_vb': 'concert', 'vbg_to_vbn': 'concerted'},
 'concluding': {'vbg_to_vb': 'conclude', 'vbg_to_vbn': 'concluded'},
 'conducting': {'vbg_to_vb': 'conduct', 'vbg_to_vbn': 'conducted'},
 'con\x1dfining': {'vbg_to_vb': 'con\x1dfine', 'vbg_to_vbn': 'con\x1dfined'},
 'con\x1dfirming': {'vbg_to_vb': 'con\x1dfirm', 'vbg_to_vbn': 'con\x1dfirmed'},
 'conflicting': {'vbg_to_vb': 'conflict', 'vbg_to_vbn': 'conflicted'},
 'connecting': {'vbg_to_vb': 'connect', 'vbg_to_vbn': 'connected'},
 'considering': {'vbg_to_vb': 'consider', 'vbg_to_vbn': 'considered'},
 'consisting': {'vbg_to_vb': 'consist', 'vbg_to_vbn': 'consisted'},
 'constituting': {'vbg_to_vb': 'constitute', 'vbg_to_vbn': 'constituted'},
 'constructing': {'vbg_to_vb': 'construct', 'vbg_to_vbn': 'constructed'},
 'consulting': {'vbg_to_vb': 'consult', 'vbg_to_vbn': 'consulted'},
 'contacting': {'vbg_to_vb': 'contact', 'vbg_to_vbn': 'contacted'},
 'contenting': {'vbg_to_vb': 'content', 'vbg_to_vbn': 'contented'},
 'contesting': {'vbg_to_vb': 'contest', 'vbg_to_vbn': 'contested'},
 'continuing': {'vbg_to_vb': 'continue', 'vbg_to_vbn': 'continued'},
 'contracting': {'vbg_to_vb': 'contract', 'vbg_to_vbn': 'contracted'},
 'contrasting': {'vbg_to_vb': 'contrast', 'vbg_to_vbn': 'contrasted'},
 'contributing': {'vbg_to_vb': 'contribute', 'vbg_to_vbn': 'contributed'},
 'controling': {'vbg_to_vb': 'control', 'vbg_to_vbn': 'controled'},
 'converting': {'vbg_to_vb': 'convert', 'vbg_to_vbn': 'converted'},
 'convincing': {'vbg_to_vb': 'convince', 'vbg_to_vbn': 'convinced', 'sth_be_jj': ''},
 'copying': {'vbg_to_vb': 'copy', 'vbg_to_vbn': 'copied'},
 'coring': {'vbg_to_vb': 'core', 'vbg_to_vbn': 'cored'},
 'cornering': {'vbg_to_vb': 'corner', 'vbg_to_vbn': 'cornered'},
 'costing': {'vbg_to_vb': 'cost', 'vbg_to_vbn': 'cost'},
 'cottoning': {'vbg_to_vb': 'cotton', 'vbg_to_vbn': 'cottoned'},
 'countering': {'vbg_to_vb': 'counter', 'vbg_to_vbn': 'countered'},
 'courting': {'vbg_to_vb': 'court', 'vbg_to_vbn': 'courted'},
 'cowing': {'vbg_to_vb': 'cow', 'vbg_to_vbn': 'cowed'},
 'crashing': {'vbg_to_vb': 'crash', 'vbg_to_vbn': 'crashed'},
 'creating': {'vbg_to_vb': 'create', 'vbg_to_vbn': 'created'},
 'crediting': {'vbg_to_vb': 'credit', 'vbg_to_vbn': 'credited'},
 'crewing': {'vbg_to_vb': 'crew', 'vbg_to_vbn': 'crewed'},
 'criticizing': {'vbg_to_vb': 'criticize', 'vbg_to_vbn': 'criticized'},
 'cropping': {'vbg_to_vb': 'crop', 'vbg_to_vbn': 'cropped'},
 'crowding': {'vbg_to_vb': 'crowd', 'vbg_to_vbn': 'crowded'},
 'crowning': {'vbg_to_vb': 'crown', 'vbg_to_vbn': 'crowned'},
 'curtaining': {'vbg_to_vb': 'curtain', 'vbg_to_vbn': 'curtained'},
 'curving': {'vbg_to_vb': 'curve', 'vbg_to_vbn': 'curved'},
 'cushioning': {'vbg_to_vb': 'cushion', 'vbg_to_vbn': 'cushioned'},
 'cycling': {'vbg_to_vb': 'cycle', 'vbg_to_vbn': 'cycled'},
 'dating': {'vbg_to_vb': 'date', 'vbg_to_vbn': 'dated'},
 'debating': {'vbg_to_vb': 'debate', 'vbg_to_vbn': 'debated'},
 'deciding': {'vbg_to_vb': 'decide', 'vbg_to_vbn': 'decided'},
 'declaring': {'vbg_to_vb': 'declare', 'vbg_to_vbn': 'declared'},
 'defeating': {'vbg_to_vb': 'defeat', 'vbg_to_vbn': 'defeated'},
 'defi\x1dning': {'vbg_to_vb': 'defi\x1dne', 'vbg_to_vbn': 'defi\x1dned'},
 'delaying': {'vbg_to_vb': 'delay', 'vbg_to_vbn': 'delayed'},
 'delivering': {'vbg_to_vb': 'deliver', 'vbg_to_vbn': 'delivered'},
 'demonstrating': {'vbg_to_vb': 'demonstrate', 'vbg_to_vbn': 'demonstrated'},
 'denying': {'vbg_to_vb': 'deny', 'vbg_to_vbn': 'denied'},
 'depending': {'vbg_to_vb': 'depend', 'vbg_to_vbn': 'depended'},
 'depositing': {'vbg_to_vb': 'deposit', 'vbg_to_vbn': 'deposited'},
 'deriving': {'vbg_to_vb': 'derive', 'vbg_to_vbn': 'derived'},
 'describing': {'vbg_to_vb': 'describe', 'vbg_to_vbn': 'described'},
 'deserting': {'vbg_to_vb': 'desert', 'vbg_to_vbn': 'deserted'},
 'deserving': {'vbg_to_vb': 'deserve', 'vbg_to_vbn': 'deserved'},
 'desiring': {'vbg_to_vb': 'desire', 'vbg_to_vbn': 'desired'},
 'destroying': {'vbg_to_vb': 'destroy', 'vbg_to_vbn': 'destroyed'},
 'detailing': {'vbg_to_vb': 'detail', 'vbg_to_vbn': 'detailed'},
 'detecting': {'vbg_to_vb': 'detect', 'vbg_to_vbn': 'detected'},
 'determining': {'vbg_to_vb': 'determine', 'vbg_to_vbn': 'determined'},
 'diagraming': {'vbg_to_vb': 'diagram', 'vbg_to_vbn': 'diagramed'},
 'di\x1effering': {'vbg_to_vb': 'di\x1effer', 'vbg_to_vbn': 'di\x1effered'},
 'directing': {'vbg_to_vb': 'direct', 'vbg_to_vbn': 'directed'},
 'dirtying': {'vbg_to_vb': 'dirty', 'vbg_to_vbn': 'dirtied'},
 'disagreing': {'vbg_to_vb': 'disagree', 'vbg_to_vbn': 'disagreed'},
 'disappearing': {'vbg_to_vb': 'disappear', 'vbg_to_vbn': 'disappeared'},
 'disciplining': {'vbg_to_vb': 'discipline', 'vbg_to_vbn': 'disciplined'},
 'discounting': {'vbg_to_vb': 'discount', 'vbg_to_vbn': 'discounted'},
 'discovering': {'vbg_to_vb': 'discover', 'vbg_to_vbn': 'discovered'},
 'dishing': {'vbg_to_vb': 'dish', 'vbg_to_vbn': 'dished'},
 'dismissing': {'vbg_to_vb': 'dismiss', 'vbg_to_vbn': 'dismissed'},
 'displaying': {'vbg_to_vb': 'display', 'vbg_to_vbn': 'displayed'},
 'disputing': {'vbg_to_vb': 'dispute', 'vbg_to_vbn': 'disputed'},
 'distancing': {'vbg_to_vb': 'distance', 'vbg_to_vbn': 'distanced'},
 'distinguishing': {'vbg_to_vb': 'distinguish', 'vbg_to_vbn': 'distinguished'},
 'distributing': {'vbg_to_vb': 'distribute', 'vbg_to_vbn': 'distributed'},
 'dividing': {'vbg_to_vb': 'divide', 'vbg_to_vbn': 'divided'},
 'divorcing': {'vbg_to_vb': 'divorce', 'vbg_to_vbn': 'divorced'},
 'doctoring': {'vbg_to_vb': 'doctor', 'vbg_to_vbn': 'doctored'},
 'documenting': {'vbg_to_vb': 'document', 'vbg_to_vbn': 'documented'},
 'dominating': {'vbg_to_vb': 'dominate', 'vbg_to_vbn': 'dominated'},
 'doting': {'vbg_to_vb': 'dot', 'vbg_to_vbn': 'dotted'},
 'doubling': {'vbg_to_vb': 'double', 'vbg_to_vbn': 'doubled'},
 'doubting': {'vbg_to_vb': 'doubt', 'vbg_to_vbn': 'doubted'},
 'draging': {'vbg_to_vb': 'drag', 'vbg_to_vbn': 'dragged'},
 'drawinging': {'vbg_to_vb': 'drawing', 'vbg_to_vbn': 'drawinged'},
 'dreaming': {'vbg_to_vb': 'dream', 'vbg_to_vbn': 'dreamed,dreamt'},
 'drinking': {'vbg_to_vb': 'drink', 'vbg_to_vbn': 'drunk'},
 'driving': {'vbg_to_vb': 'drive', 'vbg_to_vbn': 'drived'},
 'droping': {'vbg_to_vb': 'drop', 'vbg_to_vbn': 'dropped'},
 'druging': {'vbg_to_vb': 'drug', 'vbg_to_vbn': 'drugged'},
 'drying': {'vbg_to_vb': 'dry', 'vbg_to_vbn': 'dried'},
 'ducking': {'vbg_to_vb': 'duck', 'vbg_to_vbn': 'ducked'},
 'dulling': {'vbg_to_vb': 'dull', 'vbg_to_vbn': 'dulled'},
 'dusting': {'vbg_to_vb': 'dust', 'vbg_to_vbn': 'dusted'},
 'earning': {'vbg_to_vb': 'earn', 'vbg_to_vbn': 'earned'},
 'earthing': {'vbg_to_vb': 'earth', 'vbg_to_vbn': 'earthed'},
 'e\x1effecting': {'vbg_to_vb': 'e\x1effect', 'vbg_to_vbn': 'e\x1effected'},
 'egging': {'vbg_to_vb': 'egg', 'vbg_to_vbn': 'egged'},
 'electing': {'vbg_to_vb': 'elect', 'vbg_to_vbn': 'elected'},
 'emerging': {'vbg_to_vb': 'emerge', 'vbg_to_vbn': 'emerged'},
 'emphasizing': {'vbg_to_vb': 'emphasize', 'vbg_to_vbn': 'emphasized'},
 'employing': {'vbg_to_vb': 'employ', 'vbg_to_vbn': 'employed'},
 'emptying': {'vbg_to_vb': 'empty', 'vbg_to_vbn': 'emptied'},
 'enabling': {'vbg_to_vb': 'enable', 'vbg_to_vbn': 'enabled'},
 'encountering': {'vbg_to_vb': 'encounter', 'vbg_to_vbn': 'encountered'},
 'engaging': {'vbg_to_vb': 'engage', 'vbg_to_vbn': 'engaged'},
 'enhancing': {'vbg_to_vb': 'enhance', 'vbg_to_vbn': 'enhanced'},
 'enjoying': {'vbg_to_vb': 'enjoy', 'vbg_to_vbn': 'enjoyed'},
 'ensuring': {'vbg_to_vb': 'ensure', 'vbg_to_vbn': 'ensured'},
 'entering': {'vbg_to_vb': 'enter', 'vbg_to_vbn': 'entered'},
 'entitling': {'vbg_to_vb': 'entitle', 'vbg_to_vbn': 'entitled'},
 'entrancing': {'vbg_to_vb': 'entrance', 'vbg_to_vbn': 'entranced'},
 'equalling': {'vbg_to_vb': 'equal', 'vbg_to_vbn': 'equalled'},
 'escaping': {'vbg_to_vb': 'escape', 'vbg_to_vbn': 'escaped'},
 'establishing': {'vbg_to_vb': 'establish', 'vbg_to_vbn': 'established'},
 'estimating': {'vbg_to_vb': 'estimate', 'vbg_to_vbn': 'estimated'},
 'excluding': {'vbg_to_vb': 'exclude', 'vbg_to_vbn': 'excluded'},
 'existing': {'vbg_to_vb': 'exist', 'vbg_to_vbn': 'existed'},
 'exiting': {'vbg_to_vb': 'exit', 'vbg_to_vbn': 'exited'},
 'expanding': {'vbg_to_vb': 'expand', 'vbg_to_vbn': 'expanded'},
 'expecting': {'vbg_to_vb': 'expect', 'vbg_to_vbn': 'expected'},
 'experimenting': {'vbg_to_vb': 'experiment', 'vbg_to_vbn': 'experimented'},
 'explaining': {'vbg_to_vb': 'explain', 'vbg_to_vbn': 'explained'},
 'exploring': {'vbg_to_vb': 'explore', 'vbg_to_vbn': 'explored'},
 'exposing': {'vbg_to_vb': 'expose', 'vbg_to_vbn': 'exposed'},
 'expressing': {'vbg_to_vb': 'express', 'vbg_to_vbn': 'expressed'},
 'extending': {'vbg_to_vb': 'extend', 'vbg_to_vbn': 'extended'},
 'factoring': {'vbg_to_vb': 'factor', 'vbg_to_vbn': 'factored'},
 'falling': {'vbg_to_vb': 'fall', 'vbg_to_vbn': 'falled'},
 'faning': {'vbg_to_vb': 'fan', 'vbg_to_vbn': 'fanned'},
 'fancying': {'vbg_to_vb': 'fancy', 'vbg_to_vbn': 'fancied'},
 'fashioning': {'vbg_to_vb': 'fashion', 'vbg_to_vbn': 'fashioned'},
 'faulting': {'vbg_to_vb': 'fault', 'vbg_to_vbn': 'faulted'},
 'favouring': {'vbg_to_vb': 'favour', 'vbg_to_vbn': 'favoured'},
 'fearing': {'vbg_to_vb': 'fear', 'vbg_to_vbn': 'feared'},
 'featuring': {'vbg_to_vb': 'feature', 'vbg_to_vbn': 'featured'},
 'fetching': {'vbg_to_vb': 'fetch', 'vbg_to_vbn': 'fetched'},
 'fi\x1delding': {'vbg_to_vb': 'fi\x1deld', 'vbg_to_vbn': 'fi\x1delded'},
 'fi\x1dghting': {'vbg_to_vb': 'fi\x1dght', 'vbg_to_vbn': 'fought'},
 'fi\x1dguring': {'vbg_to_vb': 'fi\x1dgure', 'vbg_to_vbn': 'fi\x1dgured'},
 'fi\x1dling': {'vbg_to_vb': 'fi\x1dle', 'vbg_to_vbn': 'fi\x1dled'},
 'fi\x1dlling': {'vbg_to_vb': 'fi\x1dll', 'vbg_to_vbn': 'fi\x1dlled'},
 'fi\x1dlming': {'vbg_to_vb': 'fi\x1dlm', 'vbg_to_vbn': 'fi\x1dlmed'},
 'fi\x1dnding': {'vbg_to_vb': 'fi\x1dnd', 'vbg_to_vbn': 'fi\x1dnded'},
 '\x1dfinishing': {'vbg_to_vb': '\x1dfinish', 'vbg_to_vbn': '\x1dfinished'},
 'fi\x1dring': {'vbg_to_vb': 'fi\x1dre', 'vbg_to_vbn': 'fi\x1dred'},
 'fi\x1drming': {'vbg_to_vb': 'fi\x1drm', 'vbg_to_vbn': 'fi\x1drmed'},
 'fi\x1dshing': {'vbg_to_vb': 'fi\x1dsh', 'vbg_to_vbn': 'fi\x1dshed'},
 'fi\x1dtting': {'vbg_to_vb': 'fi\x1dt', 'vbg_to_vbn': 'fi\x1dtted,fit'},
 'fi\x1dxing': {'vbg_to_vb': 'fi\x1dx', 'vbg_to_vbn': 'fi\x1dxed'},
 'flavouring': {'vbg_to_vb': 'flavour', 'vbg_to_vbn': 'flavoured'},
 'fleshing': {'vbg_to_vb': 'flesh', 'vbg_to_vbn': 'fleshed'},
 'flooring': {'vbg_to_vb': 'floor', 'vbg_to_vbn': 'floored'},
 'focusing': {'vbg_to_vb': 'focus', 'vbg_to_vbn': 'focused'},
 'forcing': {'vbg_to_vb': 'force', 'vbg_to_vbn': 'forced'},
 'foresting': {'vbg_to_vb': 'forest', 'vbg_to_vbn': 'forested'},
 'forgeting': {'vbg_to_vb': 'forget', 'vbg_to_vbn': 'forgotten'},
 'forking': {'vbg_to_vb': 'fork', 'vbg_to_vbn': 'forked'},
 'forming': {'vbg_to_vb': 'form', 'vbg_to_vbn': 'formed'},
 'freing': {'vbg_to_vb': 'free', 'vbg_to_vbn': 'freed'},
 'fronting': {'vbg_to_vb': 'front', 'vbg_to_vbn': 'fronted'},
 'fruiting': {'vbg_to_vb': 'fruit', 'vbg_to_vbn': 'fruited'},
 'frying': {'vbg_to_vb': 'fry', 'vbg_to_vbn': 'fried'},
 'fueling': {'vbg_to_vb': 'fuel', 'vbg_to_vbn': 'fueled'},
 'fulling': {'vbg_to_vb': 'full', 'vbg_to_vbn': 'fulled'},
 'functioning': {'vbg_to_vb': 'function', 'vbg_to_vbn': 'functioned'},
 'funding': {'vbg_to_vb': 'fund', 'vbg_to_vbn': 'funded'},
 'fussing': {'vbg_to_vb': 'fuss', 'vbg_to_vbn': 'fussed'},
 'gaining': {'vbg_to_vb': 'gain', 'vbg_to_vbn': 'gained'},
 'ganging': {'vbg_to_vb': 'gang', 'vbg_to_vbn': 'ganged'},
 'garaging': {'vbg_to_vb': 'garage', 'vbg_to_vbn': 'garaged'},
 'gasing': {'vbg_to_vb': 'gas', 'vbg_to_vbn': 'gassed'},
 'generating': {'vbg_to_vb': 'generate', 'vbg_to_vbn': 'generated'},
 'giving': {'vbg_to_vb': 'give', 'vbg_to_vbn': 'given'},
 'glancing': {'vbg_to_vb': 'glance', 'vbg_to_vbn': 'glanced'},
 'glassing': {'vbg_to_vb': 'glass', 'vbg_to_vbn': 'glassed'},
 'gloving': {'vbg_to_vb': 'glove', 'vbg_to_vbn': 'gloved'},
 'grabbing': {'vbg_to_vb': 'grab', 'vbg_to_vbn': 'grabbed'},
 'grading': {'vbg_to_vb': 'grade', 'vbg_to_vbn': 'graded'},
 'granting': {'vbg_to_vb': 'grant', 'vbg_to_vbn': 'granted'},
 'graphing': {'vbg_to_vb': 'graph', 'vbg_to_vbn': 'graphed'},
 'growing': {'vbg_to_vb': 'grow', 'vbg_to_vbn': 'grown'},
 'guaranteeing': {'vbg_to_vb': 'guarantee', 'vbg_to_vbn': 'guaranteed'},
 'guessing': {'vbg_to_vb': 'guess', 'vbg_to_vbn': 'guessed'},
 'handing': {'vbg_to_vb': 'hand', 'vbg_to_vbn': 'handed'},
 'harming': {'vbg_to_vb': 'harm', 'vbg_to_vbn': 'harmed'},
 'hating': {'vbg_to_vb': 'hat', 'vbg_to_vbn': 'hatted'},
 'hiring': {'vbg_to_vb': 'hire', 'vbg_to_vbn': 'hired'},
 'hitting': {'vbg_to_vb': 'hit', 'vbg_to_vbn': 'hit'},
 'holing': {'vbg_to_vb': 'hole', 'vbg_to_vbn': 'holed'},
 'honouring': {'vbg_to_vb': 'honour', 'vbg_to_vbn': 'honoured'},
 'hooking': {'vbg_to_vb': 'hook', 'vbg_to_vbn': 'hooked'},
 'hoping': {'vbg_to_vb': 'hope', 'vbg_to_vbn': 'hoped'},
 'hosting': {'vbg_to_vb': 'host', 'vbg_to_vbn': 'hosted'},
 'hurrying': {'vbg_to_vb': 'hurry', 'vbg_to_vbn': 'hurried'},
 'hurting': {'vbg_to_vb': 'hurt', 'vbg_to_vbn': 'hurt'},
 'identifying': {'vbg_to_vb': 'identify', 'vbg_to_vbn': 'identified'},
 'ignoring': {'vbg_to_vb': 'ignore', 'vbg_to_vbn': 'ignored'},
 'illustrating': {'vbg_to_vb': 'illustrate', 'vbg_to_vbn': 'illustrated'},
 'imagining': {'vbg_to_vb': 'imagine', 'vbg_to_vbn': 'imagined'},
 'impacting': {'vbg_to_vb': 'impact', 'vbg_to_vbn': 'impacted'},
 'implementing': {'vbg_to_vb': 'implement', 'vbg_to_vbn': 'implemented'},
 'implying': {'vbg_to_vb': 'imply', 'vbg_to_vbn': 'implied'},
 'importing': {'vbg_to_vb': 'import', 'vbg_to_vbn': 'imported'},
 'imposing': {'vbg_to_vb': 'impose', 'vbg_to_vbn': 'imposed'},
 'impressing': {'vbg_to_vb': 'impress', 'vbg_to_vbn': 'impressed'},
 'inching': {'vbg_to_vb': 'inch', 'vbg_to_vbn': 'inched'},
 'including': {'vbg_to_vb': 'include', 'vbg_to_vbn': 'included'},
 'incorporating': {'vbg_to_vb': 'incorporate', 'vbg_to_vbn': 'incorporated'},
 'indexing': {'vbg_to_vb': 'index', 'vbg_to_vbn': 'indexed'},
 'indicating': {'vbg_to_vb': 'indicate', 'vbg_to_vbn': 'indicated'},
 'influencing': {'vbg_to_vb': 'influence', 'vbg_to_vbn': 'influenced'},
 'initialing': {'vbg_to_vb': 'initial', 'vbg_to_vbn': 'initialed'},
 'injuring': {'vbg_to_vb': 'injure', 'vbg_to_vbn': 'injured'},
 'inputting': {'vbg_to_vb': 'input', 'vbg_to_vbn': 'input'},
 'insisting': {'vbg_to_vb': 'insist', 'vbg_to_vbn': 'insisted'},
 'installing': {'vbg_to_vb': 'install', 'vbg_to_vbn': 'installed'},
 'instancing': {'vbg_to_vb': 'instance', 'vbg_to_vbn': 'instanced'},
 'instituting': {'vbg_to_vb': 'institute', 'vbg_to_vbn': 'instituted'},
 'intending': {'vbg_to_vb': 'intend', 'vbg_to_vbn': 'intended'},
 'interpreting': {'vbg_to_vb': 'interpret', 'vbg_to_vbn': 'interpreted'},
 'interviewing': {'vbg_to_vb': 'interview', 'vbg_to_vbn': 'interviewed'},
 'introducing': {'vbg_to_vb': 'introduce', 'vbg_to_vbn': 'introduced'},
 'investing': {'vbg_to_vb': 'invest', 'vbg_to_vbn': 'invested'},
 'investigating': {'vbg_to_vb': 'investigate', 'vbg_to_vbn': 'investigated'},
 'involving': {'vbg_to_vb': 'involve', 'vbg_to_vbn': 'involved'},
 'ironing': {'vbg_to_vb': 'iron', 'vbg_to_vbn': 'ironed'},
 'issuing': {'vbg_to_vb': 'issue', 'vbg_to_vbn': 'issued'},
 'jamming': {'vbg_to_vb': 'jam', 'vbg_to_vbn': 'jammed'},
 'jointing': {'vbg_to_vb': 'joint', 'vbg_to_vbn': 'jointed'},
 'judging': {'vbg_to_vb': 'judge', 'vbg_to_vbn': 'judged'},
 'justifying': {'vbg_to_vb': 'justify', 'vbg_to_vbn': 'justified'},
 'kitting': {'vbg_to_vb': 'kit', 'vbg_to_vbn': 'kitted'},
 'kneeing': {'vbg_to_vb': 'knee', 'vbg_to_vbn': 'kneed'},
 'knocking': {'vbg_to_vb': 'knock', 'vbg_to_vbn': 'knocked'},
 'labelling': {'vbg_to_vb': 'label', 'vbg_to_vbn': 'labeled'},
 'labouring': {'vbg_to_vb': 'labour', 'vbg_to_vbn': 'laboured'},
 'laddering': {'vbg_to_vb': 'ladder', 'vbg_to_vbn': 'laddered'},
 'lambing': {'vbg_to_vb': 'lamb', 'vbg_to_vbn': 'lambed'},
 'landscaping': {'vbg_to_vb': 'landscape', 'vbg_to_vbn': 'landscaped'},
 'laughing': {'vbg_to_vb': 'laugh', 'vbg_to_vbn': 'laughed'},
 'laying': {'vbg_to_vb': 'lay', 'vbg_to_vbn': 'laid'},
 'layering': {'vbg_to_vb': 'layer', 'vbg_to_vbn': 'layered'},
 'leafing': {'vbg_to_vb': 'leaf', 'vbg_to_vbn': 'leafed'},
 'leaving': {'vbg_to_vb': 'leave', 'vbg_to_vbn': 'left'},
 'leting': {'vbg_to_vb': 'let', 'vbg_to_vbn': 'let'},
 'licking': {'vbg_to_vb': 'lick', 'vbg_to_vbn': 'licked'},
 'limiting': {'vbg_to_vb': 'limit', 'vbg_to_vbn': 'limited'},
 'linking': {'vbg_to_vb': 'link', 'vbg_to_vbn': 'linked'},
 'locating': {'vbg_to_vb': 'locate', 'vbg_to_vbn': 'located'},
 'locking': {'vbg_to_vb': 'lock', 'vbg_to_vbn': 'locked'},
 'loving': {'vbg_to_vb': 'love', 'vbg_to_vbn': 'loved'},
 'lowering': {'vbg_to_vb': 'lower', 'vbg_to_vbn': 'lowered'},
 'maintaining': {'vbg_to_vb': 'maintain', 'vbg_to_vbn': 'maintained'},
 'marrying': {'vbg_to_vb': 'marry', 'vbg_to_vbn': 'married'},
 'matching': {'vbg_to_vb': 'match', 'vbg_to_vbn': 'matched'},
 'mattering': {'vbg_to_vb': 'matter', 'vbg_to_vbn': 'mattered'},
 'mentioning': {'vbg_to_vb': 'mention', 'vbg_to_vbn': 'mentioned'},
 'messing': {'vbg_to_vb': 'mess', 'vbg_to_vbn': 'messed'},
 'minding': {'vbg_to_vb': 'mind', 'vbg_to_vbn': 'minded'},
 'mixing': {'vbg_to_vb': 'mix', 'vbg_to_vbn': 'mixed'},
 'monitoring': {'vbg_to_vb': 'monitor', 'vbg_to_vbn': 'monitored'},
 'naming': {'vbg_to_vb': 'name', 'vbg_to_vbn': 'named'},
 'needing': {'vbg_to_vb': 'need', 'vbg_to_vbn': 'needed'},
 'negotiating': {'vbg_to_vb': 'negotiate', 'vbg_to_vbn': 'negotiated'},
 'nodding': {'vbg_to_vb': 'nod', 'vbg_to_vbn': 'nodded'},
 'noting': {'vbg_to_vb': 'note', 'vbg_to_vbn': 'noted'},
 'noticing': {'vbg_to_vb': 'notice', 'vbg_to_vbn': 'noticed'},
 'objecting': {'vbg_to_vb': 'object', 'vbg_to_vbn': 'objected'},
 'observing': {'vbg_to_vb': 'observe', 'vbg_to_vbn': 'observed'},
 'obtaining': {'vbg_to_vb': 'obtain', 'vbg_to_vbn': 'obtained'},
 'occupying': {'vbg_to_vb': 'occupy', 'vbg_to_vbn': 'occupied'},
 'occuring': {'vbg_to_vb': 'occur', 'vbg_to_vbn': 'occured'},
 'operating': {'vbg_to_vb': 'operate', 'vbg_to_vbn': 'operated'},
 'opposing': {'vbg_to_vb': 'oppose', 'vbg_to_vbn': 'opposed'},
 'ordering': {'vbg_to_vb': 'order', 'vbg_to_vbn': 'ordered'},
 'organizing': {'vbg_to_vb': 'organize', 'vbg_to_vbn': 'organized'},
 'overcoming': {'vbg_to_vb': 'overcome', 'vbg_to_vbn': 'overcome'},
 'owing': {'vbg_to_vb': 'owe', 'vbg_to_vbn': 'owed'},
 'owning': {'vbg_to_vb': 'own', 'vbg_to_vbn': 'owned'},
 'participating': {'vbg_to_vb': 'participate', 'vbg_to_vbn': 'participated'},
 'pausing': {'vbg_to_vb': 'pause', 'vbg_to_vbn': 'paused'},
 'paying': {'vbg_to_vb': 'pay', 'vbg_to_vbn': 'paid'},
 'perceiving': {'vbg_to_vb': 'perceive', 'vbg_to_vbn': 'perceived'},
 'performing': {'vbg_to_vb': 'perform', 'vbg_to_vbn': 'performed'},
 'permiting': {'vbg_to_vb': 'permit', 'vbg_to_vbn': 'permitted'},
 'persuading': {'vbg_to_vb': 'persuade', 'vbg_to_vbn': 'persuaded'},
 'phoning': {'vbg_to_vb': 'phone', 'vbg_to_vbn': 'phoned'},
 'photocopying': {'vbg_to_vb': 'photocopy', 'vbg_to_vbn': 'photocopied'},
 'placing': {'vbg_to_vb': 'place', 'vbg_to_vbn': 'placed'},
 'planing': {'vbg_to_vb': 'plan', 'vbg_to_vbn': 'planned'},
 'playing': {'vbg_to_vb': 'play', 'vbg_to_vbn': 'played'},
 'pleasing': {'vbg_to_vb': 'please', 'vbg_to_vbn': 'pleased', 'sth_be_jj': ''},
 'pointing': {'vbg_to_vb': 'point', 'vbg_to_vbn': 'pointed'},
 'popping': {'vbg_to_vb': 'pop', 'vbg_to_vbn': 'popped'},
 'posing': {'vbg_to_vb': 'pose', 'vbg_to_vbn': 'posed'},
 'possessing': {'vbg_to_vb': 'possess', 'vbg_to_vbn': 'possessed'},
 'posting': {'vbg_to_vb': 'post', 'vbg_to_vbn': 'posted'},
 'pouring': {'vbg_to_vb': 'pour', 'vbg_to_vbn': 'poured'},
 'praying': {'vbg_to_vb': 'pray', 'vbg_to_vbn': 'prayed'},
 'predicting': {'vbg_to_vb': 'predict', 'vbg_to_vbn': 'predicted'},
 'prefering': {'vbg_to_vb': 'prefer', 'vbg_to_vbn': 'prefered'},
 'preparing': {'vbg_to_vb': 'prepare', 'vbg_to_vbn': 'prepared'},
 'presenting': {'vbg_to_vb': 'present', 'vbg_to_vbn': 'presented'},
 'preserving': {'vbg_to_vb': 'preserve', 'vbg_to_vbn': 'preserved'},
 'presuming': {'vbg_to_vb': 'presume', 'vbg_to_vbn': 'presumed'},
 'pretending': {'vbg_to_vb': 'pretend', 'vbg_to_vbn': 'pretended'},
 'preventing': {'vbg_to_vb': 'prevent', 'vbg_to_vbn': 'prevented'},
 'producing': {'vbg_to_vb': 'produce', 'vbg_to_vbn': 'produced'},
 'promising': {'vbg_to_vb': 'promise', 'vbg_to_vbn': 'promised'},
 'promoting': {'vbg_to_vb': 'promote', 'vbg_to_vbn': 'promoted'},
 'proposing': {'vbg_to_vb': 'propose', 'vbg_to_vbn': 'proposed'},
 'protecting': {'vbg_to_vb': 'protect', 'vbg_to_vbn': 'protected'},
 'proving': {'vbg_to_vb': 'prove', 'vbg_to_vbn': 'proven'},
 'publishing': {'vbg_to_vb': 'publish', 'vbg_to_vbn': 'published'},
 'pulling': {'vbg_to_vb': 'pull', 'vbg_to_vbn': 'pulled'},
 'punching': {'vbg_to_vb': 'punch', 'vbg_to_vbn': 'punched'},
 'purchasing': {'vbg_to_vb': 'purchase', 'vbg_to_vbn': 'purchased'},
 'pursuing': {'vbg_to_vb': 'pursue', 'vbg_to_vbn': 'pursued'},
 'pushing': {'vbg_to_vb': 'push', 'vbg_to_vbn': 'pushed'},
 'putting': {'vbg_to_vb': 'put', 'vbg_to_vbn': 'put'},
 'qualifying': {'vbg_to_vb': 'qualify', 'vbg_to_vbn': 'qualified'},
 'questioning': {'vbg_to_vb': 'question', 'vbg_to_vbn': 'questioned'},
 'quiting': {'vbg_to_vb': 'quit', 'vbg_to_vbn': 'quit,quitted'},
 'quoting': {'vbg_to_vb': 'quote', 'vbg_to_vbn': 'quoted'},
 'raining': {'vbg_to_vb': 'rain', 'vbg_to_vbn': 'rained'},
 'raising': {'vbg_to_vb': 'raise', 'vbg_to_vbn': 'raised'},
 'ranging': {'vbg_to_vb': 'range', 'vbg_to_vbn': 'ranged'},
 'reaching': {'vbg_to_vb': 'reach', 'vbg_to_vbn': 'reached'},
 'reacting': {'vbg_to_vb': 'react', 'vbg_to_vbn': 'reacted'},
 'realizing': {'vbg_to_vb': 'realize', 'vbg_to_vbn': 'realized'},
 'recalling': {'vbg_to_vb': 'recall', 'vbg_to_vbn': 'recalled'},
 'receipting': {'vbg_to_vb': 'receipt', 'vbg_to_vbn': 'receipted'},
 'receiving': {'vbg_to_vb': 'receive', 'vbg_to_vbn': 'received'},
 'recognizing': {'vbg_to_vb': 'recognize', 'vbg_to_vbn': 'recognized'},
 'recommending': {'vbg_to_vb': 'recommend', 'vbg_to_vbn': 'recommended'},
 'recovering': {'vbg_to_vb': 'recover', 'vbg_to_vbn': 'recovered'},
 'refering': {'vbg_to_vb': 'refer', 'vbg_to_vbn': 'referred'},
 'reflecting': {'vbg_to_vb': 'reflect', 'vbg_to_vbn': 'reflected'},
 'reforming': {'vbg_to_vb': 'reform', 'vbg_to_vbn': 'reformed'},
 'refusing': {'vbg_to_vb': 'refuse', 'vbg_to_vbn': 'refused'},
 'regarding': {'vbg_to_vb': 'regard', 'vbg_to_vbn': 'regarded'},
 'registering': {'vbg_to_vb': 'register', 'vbg_to_vbn': 'registered'},
 'regreting': {'vbg_to_vb': 'regret', 'vbg_to_vbn': 'regretted'},
 'reinforcing': {'vbg_to_vb': 'reinforce', 'vbg_to_vbn': 'reinforced'},
 'rejecting': {'vbg_to_vb': 'reject', 'vbg_to_vbn': 'rejected'},
 'relating': {'vbg_to_vb': 'relate', 'vbg_to_vbn': 'related'},
 'relaxing': {'vbg_to_vb': 'relax', 'vbg_to_vbn': 'relaxed', 'sth_be_jj': ''},
 'releasing': {'vbg_to_vb': 'release', 'vbg_to_vbn': 'released'},
 'relieving': {'vbg_to_vb': 'relieve', 'vbg_to_vbn': 'relieved'},
 'relying': {'vbg_to_vb': 'rely', 'vbg_to_vbn': 'relied'},
 'remaining': {'vbg_to_vb': 'remain', 'vbg_to_vbn': 'remained'},
 'remarking': {'vbg_to_vb': 'remark', 'vbg_to_vbn': 'remarked'},
 'remembering': {'vbg_to_vb': 'remember', 'vbg_to_vbn': 'remembered'},
 'reminding': {'vbg_to_vb': 'remind', 'vbg_to_vbn': 'reminded'},
 'removing': {'vbg_to_vb': 'remove', 'vbg_to_vbn': 'removed'},
 'renting': {'vbg_to_vb': 'rent', 'vbg_to_vbn': 'rented'},
 'repairing': {'vbg_to_vb': 'repair', 'vbg_to_vbn': 'repaired'},
 'repeating': {'vbg_to_vb': 'repeat', 'vbg_to_vbn': 'repeated'},
 'replacing': {'vbg_to_vb': 'replace', 'vbg_to_vbn': 'replaced'},
 'replying': {'vbg_to_vb': 'reply', 'vbg_to_vbn': 'replied'},
 'reporting': {'vbg_to_vb': 'report', 'vbg_to_vbn': 'reported'},
 'representing': {'vbg_to_vb': 'represent', 'vbg_to_vbn': 'represented'},
 'requesting': {'vbg_to_vb': 'request', 'vbg_to_vbn': 'requested'},
 'requiring': {'vbg_to_vb': 'require', 'vbg_to_vbn': 'required'},
 'rescuing': {'vbg_to_vb': 'rescue', 'vbg_to_vbn': 'rescued'},
 'researching': {'vbg_to_vb': 'research', 'vbg_to_vbn': 'researched'},
 'reserving': {'vbg_to_vb': 'reserve', 'vbg_to_vbn': 'reserved'},
 'resigning': {'vbg_to_vb': 'resign', 'vbg_to_vbn': 'resigned'},
 'resisting': {'vbg_to_vb': 'resist', 'vbg_to_vbn': 'resisted'},
 'resolving': {'vbg_to_vb': 'resolve', 'vbg_to_vbn': 'resolved'},
 'resorting': {'vbg_to_vb': 'resort', 'vbg_to_vbn': 'resorted'},
 'respecting': {'vbg_to_vb': 'respect', 'vbg_to_vbn': 'respected'},
 'responding': {'vbg_to_vb': 'respond', 'vbg_to_vbn': 'responded'},
 'resting': {'vbg_to_vb': 'rest', 'vbg_to_vbn': 'rested'},
 'restoring': {'vbg_to_vb': 'restore', 'vbg_to_vbn': 'restored'},
 'restricting': {'vbg_to_vb': 'restrict', 'vbg_to_vbn': 'restricted'},
 'resulting': {'vbg_to_vb': 'result', 'vbg_to_vbn': 'resulted'},
 'retaining': {'vbg_to_vb': 'retain', 'vbg_to_vbn': 'retained'},
 'retiring': {'vbg_to_vb': 'retire', 'vbg_to_vbn': 'retired'},
 'returning': {'vbg_to_vb': 'return', 'vbg_to_vbn': 'returned'},
 'revealing': {'vbg_to_vb': 'reveal', 'vbg_to_vbn': 'revealed'},
 'reversing': {'vbg_to_vb': 'reverse', 'vbg_to_vbn': 'reversed'},
 'reviewing': {'vbg_to_vb': 'review', 'vbg_to_vbn': 'reviewed'},
 'rewarding': {'vbg_to_vb': 'reward', 'vbg_to_vbn': 'rewarded'},
 'ringing': {'vbg_to_vb': 'ring', 'vbg_to_vbn': 'ringed'},
 'ripping': {'vbg_to_vb': 'rip', 'vbg_to_vbn': 'ripped'},
 'risking': {'vbg_to_vb': 'risk', 'vbg_to_vbn': 'risked'},
 'rivaling': {'vbg_to_vb': 'rival', 'vbg_to_vbn': 'rivaled'},
 'robbing': {'vbg_to_vb': 'rob', 'vbg_to_vbn': 'robbed'},
 'rocking': {'vbg_to_vb': 'rock', 'vbg_to_vbn': 'rocked'},
 'rooting': {'vbg_to_vb': 'root', 'vbg_to_vbn': 'rooted'},
 'roping': {'vbg_to_vb': 'rope', 'vbg_to_vbn': 'roped'},
 'routing': {'vbg_to_vb': 'route', 'vbg_to_vbn': 'routed'},
 'ruining': {'vbg_to_vb': 'ruin', 'vbg_to_vbn': 'ruined'},
 'runing': {'vbg_to_vb': 'run', 'vbg_to_vbn': 'runned'},
 'rushing': {'vbg_to_vb': 'rush', 'vbg_to_vbn': 'rushed'},
 'salting': {'vbg_to_vb': 'salt', 'vbg_to_vbn': 'salted'},
 'sanding': {'vbg_to_vb': 'sand', 'vbg_to_vbn': 'sanded'},
 'sandwiching': {'vbg_to_vb': 'sandwich', 'vbg_to_vbn': 'sandwiched'},
 'satisfying': {'vbg_to_vb': 'satisfy', 'vbg_to_vbn': 'satisfied', 'sth_be_jj': ''},
 'saucing': {'vbg_to_vb': 'sauce', 'vbg_to_vbn': 'sauced'},
 'scaling': {'vbg_to_vb': 'scale', 'vbg_to_vbn': 'scaled'},
 'scheduling': {'vbg_to_vb': 'schedule', 'vbg_to_vbn': 'scheduled'},
 'scheming': {'vbg_to_vb': 'scheme', 'vbg_to_vbn': 'schemed'},
 'scratching': {'vbg_to_vb': 'scratch', 'vbg_to_vbn': 'scratched'},
 'screaming': {'vbg_to_vb': 'scream', 'vbg_to_vbn': 'screamed'},
 'scripting': {'vbg_to_vb': 'script', 'vbg_to_vbn': 'scripted'},
 'searching': {'vbg_to_vb': 'search', 'vbg_to_vbn': 'searched'},
 'seconding': {'vbg_to_vb': 'second', 'vbg_to_vbn': 'seconded'},
 'sectioning': {'vbg_to_vb': 'section', 'vbg_to_vbn': 'sectioned'},
 'securing': {'vbg_to_vb': 'secure', 'vbg_to_vbn': 'secured'},
 'seeding': {'vbg_to_vb': 'seed', 'vbg_to_vbn': 'seeded'},
 'seeking': {'vbg_to_vb': 'seek', 'vbg_to_vbn': 'sought'},
 'seeming': {'vbg_to_vb': 'seem', 'vbg_to_vbn': 'seemed'},
 'selecting': {'vbg_to_vb': 'select', 'vbg_to_vbn': 'selected'},
 'selling': {'vbg_to_vb': 'sell', 'vbg_to_vbn': 'sold'},
 'sentencing': {'vbg_to_vb': 'sentence', 'vbg_to_vbn': 'sentenced'},
 'sequencing': {'vbg_to_vb': 'sequence', 'vbg_to_vbn': 'sequenced'},
 'servicing': {'vbg_to_vb': 'service', 'vbg_to_vbn': 'serviced'},
 'settling': {'vbg_to_vb': 'settle', 'vbg_to_vbn': 'settled'},
 'shadowing': {'vbg_to_vb': 'shadow', 'vbg_to_vbn': 'shadowed'},
 'shaking': {'vbg_to_vb': 'shake', 'vbg_to_vbn': 'shaken'},
 'shaming': {'vbg_to_vb': 'shame', 'vbg_to_vbn': 'shamed'},
 'shaping': {'vbg_to_vb': 'shape', 'vbg_to_vbn': 'shaped'},
 'sheding': {'vbg_to_vb': 'shed', 'vbg_to_vbn': 'shedded,shed'},
 'sheltering': {'vbg_to_vb': 'shelter', 'vbg_to_vbn': 'sheltered'},
 'shining': {'vbg_to_vb': 'shine', 'vbg_to_vbn': 'shone'},
 'shocking': {'vbg_to_vb': 'shock', 'vbg_to_vbn': 'shocked', 'sth_be_jj': ''},
 'shouldering': {'vbg_to_vb': 'shoulder', 'vbg_to_vbn': 'shouldered'},
 'shoving': {'vbg_to_vb': 'shove', 'vbg_to_vbn': 'shoved'},
 'showering': {'vbg_to_vb': 'shower', 'vbg_to_vbn': 'showered'},
 'shruging': {'vbg_to_vb': 'shrug', 'vbg_to_vbn': 'shrugged'},
 'shutting': {'vbg_to_vb': 'shut', 'vbg_to_vbn': 'shutted,shut'},
 'signing': {'vbg_to_vb': 'sign', 'vbg_to_vbn': 'signed'},
 'signaling': {'vbg_to_vb': 'signal', 'vbg_to_vbn': 'signaled'},
 'silvering': {'vbg_to_vb': 'silver', 'vbg_to_vbn': 'silvered'},
 'sining': {'vbg_to_vb': 'sin', 'vbg_to_vbn': 'sinned'},
 'siting': {'vbg_to_vb': 'site', 'vbg_to_vbn': 'sited'},
 'skirting': {'vbg_to_vb': 'skirt', 'vbg_to_vbn': 'skirted'},
 'snapping': {'vbg_to_vb': 'snap', 'vbg_to_vbn': 'snaped'},
 'solving': {'vbg_to_vb': 'solve', 'vbg_to_vbn': 'solved'},
 'spilling': {'vbg_to_vb': 'spill', 'vbg_to_vbn': 'spilled,spilt'},
 'spliting': {'vbg_to_vb': 'split', 'vbg_to_vbn': 'split'},
 'spoiling': {'vbg_to_vb': 'spoil', 'vbg_to_vbn': 'spoiled'},
 'spraying': {'vbg_to_vb': 'spray', 'vbg_to_vbn': 'sprayed'},
 'spreading': {'vbg_to_vb': 'spread', 'vbg_to_vbn': 'spread'},
 'squeezing': {'vbg_to_vb': 'squeeze', 'vbg_to_vbn': 'squeezed'},
 'staring': {'vbg_to_vb': 'stare', 'vbg_to_vbn': 'stared'},
 'starving': {'vbg_to_vb': 'starve', 'vbg_to_vbn': 'starved'},
 'steping': {'vbg_to_vb': 'step', 'vbg_to_vbn': 'stepped'},
 'stiring': {'vbg_to_vb': 'stir', 'vbg_to_vbn': 'stirred'},
 'stressing': {'vbg_to_vb': 'stress', 'vbg_to_vbn': 'stressed'},
 'studying': {'vbg_to_vb': 'study', 'vbg_to_vbn': 'studied'},
 'submiting': {'vbg_to_vb': 'submit', 'vbg_to_vbn': 'submitted'},
 'suggesting': {'vbg_to_vb': 'suggest', 'vbg_to_vbn': 'suggested'},
 'suspecting': {'vbg_to_vb': 'suspect', 'vbg_to_vbn': 'suspected'},
 'swapping': {'vbg_to_vb': 'swap', 'vbg_to_vbn': 'swapped'},
 'swiming': {'vbg_to_vb': 'swim', 'vbg_to_vbn': 'swimmed,swum'},
 'switching': {'vbg_to_vb': 'switch', 'vbg_to_vbn': 'switched'},
 'tackling': {'vbg_to_vb': 'tackle', 'vbg_to_vbn': 'tackled'},
 'tending': {'vbg_to_vb': 'tend', 'vbg_to_vbn': 'tended'},
 'texting': {'vbg_to_vb': 'text', 'vbg_to_vbn': 'texted'},
 'threatening': {'vbg_to_vb': 'threaten', 'vbg_to_vbn': 'threatened', 'sth_be_jj': ''},
 'throwing': {'vbg_to_vb': 'throw', 'vbg_to_vbn': 'thrown'},
 'tying': {'vbg_to_vb': 'tie', 'vbg_to_vbn': 'tied'},
 'tiping': {'vbg_to_vb': 'tip', 'vbg_to_vbn': 'tipped'},
 'touching': {'vbg_to_vb': 'touch', 'vbg_to_vbn': 'touched', 'sth_be_jj': ''},
 'trading': {'vbg_to_vb': 'trade', 'vbg_to_vbn': 'traded'},
 'transfering': {'vbg_to_vb': 'transfer', 'vbg_to_vbn': 'transfered'},
 'transforming': {'vbg_to_vb': 'transform', 'vbg_to_vbn': 'transformed'},
 'translating': {'vbg_to_vb': 'translate', 'vbg_to_vbn': 'translated'},
 'treating': {'vbg_to_vb': 'treat', 'vbg_to_vbn': 'treated'},
 'trusting': {'vbg_to_vb': 'trust', 'vbg_to_vbn': 'trusted'},
 'trying': {'vbg_to_vb': 'try', 'vbg_to_vbn': 'tried'},
 'twisting': {'vbg_to_vb': 'twist', 'vbg_to_vbn': 'twisted'},
 'upseting': {'vbg_to_vb': 'upset', 'vbg_to_vbn': 'upset'},
 'urging': {'vbg_to_vb': 'urge', 'vbg_to_vbn': 'urged'},
 'using': {'vbg_to_vb': 'use', 'vbg_to_vbn': 'used'},
 'vacationing': {'vbg_to_vb': 'vacation', 'vbg_to_vbn': 'vacationed'},
 'varying': {'vbg_to_vb': 'vary', 'vbg_to_vbn': 'varied'},
 'visiting': {'vbg_to_vb': 'visit', 'vbg_to_vbn': 'visited'},
 'waking': {'vbg_to_vb': 'wake', 'vbg_to_vbn': 'waken'},
 'wandering': {'vbg_to_vb': 'wander', 'vbg_to_vbn': 'wandered'},
 'wanting': {'vbg_to_vb': 'want', 'vbg_to_vbn': 'wanted'},
 'wasting': {'vbg_to_vb': 'waste', 'vbg_to_vbn': 'wasted'},
 'watching': {'vbg_to_vb': 'watch', 'vbg_to_vbn': 'watched'},
 'waving': {'vbg_to_vb': 'wave', 'vbg_to_vbn': 'waved'},
 'wearing': {'vbg_to_vb': 'wear', 'vbg_to_vbn': 'worn'},
 'weighing': {'vbg_to_vb': 'weigh', 'vbg_to_vbn': 'weighed'},
 'welcoming': {'vbg_to_vb': 'welcome', 'vbg_to_vbn': 'welcomed'},
 'whispering': {'vbg_to_vb': 'whisper', 'vbg_to_vbn': 'whispered'},
 'wiping': {'vbg_to_vb': 'wipe', 'vbg_to_vbn': 'wiped'},
 'wishing': {'vbg_to_vb': 'wish', 'vbg_to_vbn': 'wished'},
 'withdrawing': {'vbg_to_vb': 'withdraw', 'vbg_to_vbn': 'withdrawn'},
 'wondering': {'vbg_to_vb': 'wonder', 'vbg_to_vbn': 'wondered'},
 'worrying': {'vbg_to_vb': 'worry', 'vbg_to_vbn': 'worried', 'sth_be_jj': ''},
 'wounding': {'vbg_to_vb': 'wound', 'vbg_to_vbn': 'wounded'},
 'tantamount': {'be_jj_to_vbg': ''},
 'akin': {'be_jj_to_vbg': ''},
 'prone': {'be_jj_to_vbg': ''},
 'crucial': {'be_jj_to_vbg': ''},
 'comparable': {'be_jj_to_vbg': ''},
 'vital': {'be_jj_to_vbg': ''},
 'conducive': {'be_jj_to_vbg': ''},
 'irrelevant': {'be_jj_to_vbg': ''},
 'vulnerable': {'be_jj_to_vbg': ''},
 'unused': {'be_jj_to_vbg': '', 'jj_ed': ''},
 'differently': {'rb_to_jj': 'different'},
 'l': {'confu_pair': 'I'},
 'properly': {'rb_to_jj': 'proper'},
 'proper': {'jj_to_rb': 'properly'},
 'instead': {'confu_pair': 'instead of'},
 'easily': {'rb_to_jj': 'easy'},
 'brilliant': {'jj_to_rb': 'brilliantly'},
 'brilliantly': {'rb_to_jj': 'brilliant'},
 'scholarly': {'jj_to_nn': 'scholar'},
 'genetically': {'rb_to_jj': 'genetical'},
 'genetical': {'jj_to_rb': 'genetically'},
 'olympic': {'cap_word': 'Olympic'},
 'unhealth': {'nn_to_jj': 'unhealthy'},
 'unhealthy': {'jj_to_nn': 'unhealth', 'jj_to_jjr': 'unhealthier', 'jj_to_jjs': 'unhealthiest'},
 'aggravating': {'sth_be_jj': ''},
 'amazing': {'sth_be_jj': ''},
 'astounding': {'sth_be_jj': ''},
 'bewildering': {'sth_be_jj': ''},
 'captivating': {'sth_be_jj': ''},
 'chilling': {'sth_be_jj': ''},
 'depressing': {'sth_be_jj': ''},
 'devastating': {'sth_be_jj': ''},
 'discouraging': {'sth_be_jj': ''},
 'disheartening': {'sth_be_jj': ''},
 'distressing': {'sth_be_jj': ''},
 'embarrassing': {'sth_be_jj': ''},
 'enchanting': {'sth_be_jj': ''},
 'enthralling': {'sth_be_jj': ''},
 'exasperating': {'sth_be_jj': ''},
 'exciting': {'sth_be_jj': ''},
 'exhausting': {'sth_be_jj': ''},
 'fascinating': {'sth_be_jj': ''},
 'flattering': {'sth_be_jj': ''},
 'frightening': {'sth_be_jj': ''},
 'frustrating': {'sth_be_jj': ''},
 'gratifying': {'sth_be_jj': ''},
 'horrifying': {'sth_be_jj': ''},
 'humiliating': {'sth_be_jj': ''},
 'infuriating': {'sth_be_jj': ''},
 'inspiring': {'sth_be_jj': ''},
 'intimidating': {'sth_be_jj': ''},
 'intriguing': {'sth_be_jj': ''},
 'irritating': {'sth_be_jj': ''},
 'mesmerizing': {'sth_be_jj': ''},
 'overwhelming': {'sth_be_jj': ''},
 'perplexing': {'sth_be_jj': ''},
 'provoking': {'sth_be_jj': ''},
 'puzzling': {'sth_be_jj': ''},
 'sickening': {'sth_be_jj': ''},
 'terrifying': {'sth_be_jj': ''},
 'thrilling': {'sth_be_jj': ''},
 'tiring': {'sth_be_jj': ''},
 'unnerving': {'sth_be_jj': ''},
 'vexing': {'sth_be_jj': ''},
 'aggravated': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'astonished': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'astounded': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'bewildered': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'bored': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'captivated': {'sb_be_jj': '', 'vbd_eq_vbn': ''},
 'charmed': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'delighted': {'sb_be_jj': '', 'jj_ed': '', 'be_jj_to_vb': '', 'vbd_eq_vbn': ''},
 'devastated': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'discouraged': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'disgusted': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'disheartened': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'distracted': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'distressed': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'embarrassed': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'enchanted': {'sb_be_jj': '', 'vbd_eq_vbn': ''},
 'entertained': {'sb_be_jj': '', 'vbd_eq_vbn': ''},
 'enthralled': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'exasperated': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'exhausted': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'fascinated': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'frightened': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'frustrated': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'fulfilled': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'horrified': {'sb_be_jj': '', 'vbd_eq_vbn': ''},
 'humiliated': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'infuriated': {'sb_be_jj': '', 'vbd_eq_vbn': ''},
 'inspired': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'intimidated': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'irritated': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'mesmerized': {'sb_be_jj': '', 'vbd_eq_vbn': ''},
 'overwhelmed': {'sb_be_jj': '', 'vbd_eq_vbn': ''},
 'perplexed': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'puzzled': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'scared': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'terrified': {'sb_be_jj': '', 'jj_ed': '', 'be_jj_to_vb': '', 'vbd_eq_vbn': ''},
 'thrilled': {'sb_be_jj': '', 'jj_ed': '', 'vbd_eq_vbn': ''},
 'unsettled': {'sb_be_jj': '', 'jj_ed': '', 'n_is_sth': '0', 'vbd_eq_vbn': ''},
 'beset': {'vb_eq_vbd': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'vbd_eq_vbn': ''},
 'outbid': {'vb_eq_vbd': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'vbd_eq_vbn': ''},
 'recast': {'vb_eq_vbd': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbd_eq_vbn': ''},
 'reset': {'vb_eq_vbd': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': '', 'vb_eq_vbn': '', 'vbd_eq_vbn': ''},
 'rid': {'vb_eq_vbd': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbd_eq_vbn': ''},
 'underbid': {'vb_eq_vbd': '', 'vbd_eq_vbn': ''},
 'ashamed': {'jj_to_nn': 'shame', 'jj_ed': '', 'be_jj_to_vb': ''},
 'depart': {'vi_typical': '', 'v_pass_non': ''},
 'sympathize': {'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'expire': {'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'vanish': {'vi_typical': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'deteriorate': {'vi_typical': '', 'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'economize': {'vi_typical': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'soar': {'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'subside': {'vi_typical': '', 'vbd_eq_vbn': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'vibrate': {'vi_typical': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'elapse': {'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'dine': {'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'erupt': {'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'weep': {'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'evaporate': {'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'prosper': {'vi_typical': '', 'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'come out': {'vi_typical': ''},
 'come true': {'vi_typical': ''},
 'take place': {'vi_typical': ''},
 'break out': {'vi_typical': ''},
 'grow up': {'vi_typical': ''},
 'eat out': {'vi_typical': ''},
 'drop by': {'vi_typical': ''},
 'run out': {'vi_typical': ''},
 'show up': {'vi_typical': ''},
 'wake up': {'vi_typical': ''},
 'go up': {'vi_typical': ''},
 'go down': {'vi_typical': ''},
 'come about': {'vi_typical': ''},
 'go out': {'vi_typical': ''},
 'die out': {'vi_typical': ''},
 'come back': {'vi_typical': ''},
 'enthusiastic': {'jj_to_rb': 'enthusiastically'},
 'enthusiastically': {'rb_to_jj': 'enthusiastic'},
 'hypocritical': {'jj_to_nn': 'hypocrisy'},
 'goods': {'nns_only': ''},
 'handpick': {'vbd_eq_vbn': ''},
 'carve': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'immerse': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'intrude': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'reintroduce': {'vbd_eq_vbn': ''},
 'greet': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'replenish': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'overcharge': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'undermine': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'disburse': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'rebut': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'overwhelm': {'vbd_eq_vbn': ''},
 'imprison': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'vbg_non': ''},
 'endorse': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'confront': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'renew': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'portray': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'overextend': {'vbd_eq_vbn': ''},
 'rename': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'nominate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'compel': {'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'delouse': {'vbd_eq_vbn': ''},
 'televise': {'vbd_eq_vbn': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'propel': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'kidnap': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'fascinate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'revive': {'vbd_eq_vbn': ''},
 'inspire': {'vbd_eq_vbn': '', 'vt_typical': ''},
 'impart': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'detain': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'execute': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'retrieve': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'penetrate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'instal': {'vbd_eq_vbn': ''},
 'donate': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'stun': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'prosecute': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'comply': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'dispel': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'emit': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'liquidate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'diagnose': {'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'cram': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'designate': {'vbd_eq_vbn': ''},
 'downgrade': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'repel': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'hijack': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'indict': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'exert': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_n_on_n': ''},
 'permeate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'impoverish': {'vbd_eq_vbn': ''},
 'animate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'repurchase': {'vbd_eq_vbn': ''},
 'preheat': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'molest': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'disband': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'digitize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'inhale': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'accost': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'adhere': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'counteract': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'dateline': {'vbd_eq_vbn': ''},
 'imbibe': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'launder': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'sicken': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'coalesce': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'recreate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'extort': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'redden': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'overpower': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'demarcate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'jell': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'assuage': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'dislodge': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'revamp': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'assassinate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'venerate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'eradicate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'federate': {'vbd_eq_vbn': ''},
 'supplant': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'cross-pollinate': {'vbd_eq_vbn': ''},
 'elude': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'rescind': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'emblazon': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'rearrange': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'reanimate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'appal': {'vbd_eq_vbn': ''},
 'irradiate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'desensitize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'substantiate': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'acculturate': {'vbd_eq_vbn': ''},
 'elucidate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'transcribe': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'enchant': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'bereave': {'vbd_eq_vbn': ''},
 'customize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'enliven': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'ogle': {'vbd_eq_vbn': ''},
 'derail': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'predigest': {'vbd_eq_vbn': ''},
 'confiscate': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'collate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'faze': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'immobilize': {'vbd_eq_vbn': ''},
 'precook': {'vbd_eq_vbn': ''},
 'limp': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': '', 'jj_to_jjr': 'limper', 'jj_to_jjs': 'limpest'},
 'airlift': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'ripen': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'deregulate': {'vbd_eq_vbn': ''},
 'amputate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'mollify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'sizzle': {'vbd_eq_vbn': ''},
 'realign': {'vbd_eq_vbn': ''},
 'extradite': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'allay': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'victimize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'entail': {'vbd_eq_vbn': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'exacerbate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'inter': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'cleanse': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'underestimate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'defecate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'patronize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'spay': {'vbd_eq_vbn': ''},
 'liken': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'waive': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'comport': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'skew': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'memorize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'recede': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'gesticulate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'underdress': {'vbd_eq_vbn': ''},
 'enthral': {'vbd_eq_vbn': ''},
 'overfeed': {'vbd_eq_vbn': ''},
 'oversupply': {'vbd_eq_vbn': ''},
 'uncoil': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'gird': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'dry-clean': {'vbd_eq_vbn': ''},
 'disenfranchise': {'vbd_eq_vbn': ''},
 'perspire': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'finalize': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'lionize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'clothe': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'lynch': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'exhale': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'outplay': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'exemplify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'indulge': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'dismember': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'unroll': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'ensue': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'emote': {'vbd_eq_vbn': ''},
 'numb': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'bestow': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'expurgate': {'vbd_eq_vbn': ''},
 'navigate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'romanticize': {'vbd_eq_vbn': ''},
 'cater': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'overreact': {'vbd_eq_vbn': ''},
 'preclude': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'mince': {'vbd_eq_vbn': ''},
 'procure': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'repackage': {'vbd_eq_vbn': ''},
 'recapitalize': {'vbd_eq_vbn': ''},
 'amalgamate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'foreshorten': {'vbd_eq_vbn': ''},
 'erect': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'summarize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'edify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'superimpose': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'attenuate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'stonewall': {'vbd_eq_vbn': ''},
 'overtax': {'vbd_eq_vbn': ''},
 'punt': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'revalue': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'pooh-pooh': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'suckle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'disseminate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'impound': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'plop': {'vbd_eq_vbn': ''},
 'inaugurate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'remonstrate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'occlude': {'vbd_eq_vbn': ''},
 'squat': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'jj_to_jjr': 'squatter', 'jj_to_jjs': 'squattest'},
 'demythologize': {'vbd_eq_vbn': ''},
 'cringe': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'devalue': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'wield': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'encircle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'denominate': {'vbd_eq_vbn': ''},
 'accouter': {'vbd_eq_vbn': ''},
 'fossilize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'vaccinate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'embark': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'irritate': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'interbreed': {'vbd_eq_vbn': ''},
 'engrave': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'festoon': {'vbd_eq_vbn': ''},
 'regroup': {'vbd_eq_vbn': ''},
 'plagiarize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'about-face': {'vbd_eq_vbn': ''},
 'glom': {'vbd_eq_vbn': ''},
 'hanker': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'accrete': {'vbd_eq_vbn': ''},
 'herniate': {'vbd_eq_vbn': ''},
 'exude': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'depreciate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'devour': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'divest': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'reinvest': {'vbd_eq_vbn': ''},
 'imperil': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'evince': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'nab': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'debug': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'narrate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'whet': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'abrogate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'titillate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'hunker': {'vbd_eq_vbn': ''},
 'flout': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'canonize': {'vbd_eq_vbn': ''},
 'outsmart': {'vbd_eq_vbn': ''},
 'falsify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'brutalize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'maim': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'whipsaw': {'vbd_eq_vbn': ''},
 'transfuse': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'rearm': {'vbd_eq_vbn': ''},
 'mesmerize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'imbed': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'prorate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'overemphasize': {'vbd_eq_vbn': ''},
 'resurface': {'vbd_eq_vbn': ''},
 'unveil': {'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'restate': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'nuzzle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'chide': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'revolutionize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'denationalize': {'vbd_eq_vbn': ''},
 'quench': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'consign': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'profane': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'philosophize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'overrate': {'vbd_eq_vbn': ''},
 'rekindle': {'vbd_eq_vbn': ''},
 'deploy': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'gree': {'vbd_eq_vbn': ''},
 'impede': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'recant': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'dabble': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'reincarnate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'worsen': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'mystify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'provoke': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'mourn': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'sober': {'vbd_eq_vbn': ''},
 'expound': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'localize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'redesign': {'vbd_eq_vbn': ''},
 'teem': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'castigate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'unburden': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'transfix': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'decant': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'apportion': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'commend': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'correlate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'readjust': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'astound': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'arraign': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'encumber': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'mislead': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'slacken': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'eschew': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'distract': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'rehabilitate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'roil': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'rectify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'misrepresent': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'disassociate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'outpace': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'rework': {'vbd_eq_vbn': ''},
 'foreclose': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'inflict': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'undergird': {'vbd_eq_vbn': ''},
 'revisit': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'unfold': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'fluster': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'dissatisfy': {'vbd_eq_vbn': ''},
 'denature': {'vbd_eq_vbn': ''},
 'blanch': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'sheer': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'jj_to_jjr': 'sheerer', 'jj_to_jjs': 'sheerest'},
 'betray': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'embroil': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'memorialize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'besiege': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'legalize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'disinherit': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'stash': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'nestle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'fraternize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'daunt': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'tenderize': {'vbd_eq_vbn': ''},
 'fortify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'illumine': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'pummel': {'vbd_eq_vbn': ''},
 'pave': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'congregate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'revolve': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'entwine': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'disavow': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'dislocate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'nationalize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'whittle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'underplay': {'vbd_eq_vbn': ''},
 'mutate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'afflict': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'laud': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'conspire': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'exculpate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'inflame': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'retrain': {'vbd_eq_vbn': ''},
 'abet': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'suppress': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'manhandle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'inactivate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'codify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'cleave': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'disparage': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'idolize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'succumb': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'italicize': {'vbd_eq_vbn': ''},
 'wean': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'stow': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'sip': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'suffuse': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'protrude': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'disintegrate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'bemuse': {'vbd_eq_vbn': ''},
 'undeceive': {'vbd_eq_vbn': ''},
 'dissuade': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'remunerate': {'vbd_eq_vbn': ''},
 'bewitch': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'emulate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'dunk': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bode': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'embitter': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'curdle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'baptize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'mangle': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'personify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'coddle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'litigate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'desegregate': {'vbd_eq_vbn': ''},
 'dicker': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'underpin': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'collude': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'rationalize': {'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'delve': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'uncurl': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'decease': {'vbd_eq_vbn': ''},
 'recur': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'expunge': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'dissociate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cremate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'particularize': {'vbd_eq_vbn': ''},
 'swathe': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'fixate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'defraud': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'restructure': {'vbd_eq_vbn': ''},
 'incubate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'prowl': {'vbd_eq_vbn': ''},
 'itemize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'stipple': {'vbd_eq_vbn': ''},
 'ensconce': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'resonate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'vilify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'utter': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'enmesh': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'choreograph': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'caparison': {'vbd_eq_vbn': ''},
 'ascend': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'outmaneuver': {'vbd_eq_vbn': ''},
 'squander': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'aggravate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'quicken': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'bushwhack': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'shamble': {'vbd_eq_vbn': ''},
 'prefabricate': {'vbd_eq_vbn': ''},
 'enrol': {'vbd_eq_vbn': ''},
 'prejudge': {'vbd_eq_vbn': ''},
 'harmonize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'germinate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'demobilize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'outlast': {'vbd_eq_vbn': ''},
 'unclog': {'vbd_eq_vbn': ''},
 'goad': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'dismantle': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'befriend': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'misappropriate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'uncover': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'reorganize': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'overdress': {'vbd_eq_vbn': ''},
 'await': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'metamorphose': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'pulsate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'encrust': {'vbd_eq_vbn': ''},
 'abstain': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'miscarry': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'unwrap': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'belittle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'defame': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'underline': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'depict': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'concoct': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'backfire': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'perpetuate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'eulogize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'entreat': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'deride': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'tousle': {'vbd_eq_vbn': ''},
 'invalidate': {'vbd_eq_vbn': ''},
 'alphabetize': {'vbd_eq_vbn': ''},
 'skim': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'gratify': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'empower': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'overstate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'fictionalize': {'vbd_eq_vbn': ''},
 'recharge': {'vbd_eq_vbn': ''},
 'slake': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'quadruple': {'vbd_eq_vbn': ''},
 'disfavor': {'vbd_eq_vbn': ''},
 'diffuse': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'perish': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'mistreat': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'spangle': {'vbd_eq_vbn': ''},
 'two-time': {'vbd_eq_vbn': ''},
 'ascribe': {'vbd_eq_vbn': ''},
 'authenticate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'reap': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'intercede': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'impeach': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'refrain': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'distil': {'vbd_eq_vbn': ''},
 'co-opt': {'vbd_eq_vbn': ''},
 'acquit': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'filch': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'summon': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'overawe': {'vbd_eq_vbn': ''},
 'mutilate': {'vbd_eq_vbn': ''},
 'shag': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'reassemble': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'systematize': {'vbd_eq_vbn': ''},
 'consecrate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'indoctrinate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'miff': {'vbd_eq_vbn': ''},
 'shatter': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'beatify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'overdevelop': {'vbd_eq_vbn': ''},
 'jeopardize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'enkindle': {'vbd_eq_vbn': ''},
 'forestall': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'overreach': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'preordain': {'vbd_eq_vbn': ''},
 'rankle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'resurrect': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'humiliate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'administer': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'transmogrify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'abound': {'vbd_eq_vbn': '', 'v_pass_non': ''},
 'decry': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'hasten': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'cherish': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'rove': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'furl': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'vie': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'disentangle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'chastise': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'prerecord': {'vbd_eq_vbn': ''},
 'side-step': {'vbd_eq_vbn': ''},
 'commemorate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'frizzle': {'vbd_eq_vbn': ''},
 'alienate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'popularize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'repress': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'vivify': {'vbd_eq_vbn': ''},
 'humble': {'vbd_eq_vbn': '', 'jj_to_jjr': 'humbler', 'jj_to_jjs': 'humblest'},
 'deter': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'hinder': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'transmute': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'monopolize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'evict': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'assail': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'unseat': {'vbd_eq_vbn': ''},
 'brainwash': {'vbd_eq_vbn': ''},
 'parody': {'vbd_eq_vbn': ''},
 'careen': {'vbd_eq_vbn': ''},
 'downsize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'procrastinate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'overcrowd': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'unscrew': {'vbd_eq_vbn': ''},
 'defuse': {'vbd_eq_vbn': ''},
 'encroach': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'intersperse': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'sleepwalk': {'vbd_eq_vbn': ''},
 'languish': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'gobble': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'uncap': {'vbd_eq_vbn': ''},
 'delete': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'vt_typical': ''},
 'balkanize': {'vbd_eq_vbn': ''},
 'cross-fertilize': {'vbd_eq_vbn': ''},
 'maximize': {'vbd_eq_vbn': ''},
 'slick': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'jj_to_jjr': 'slicker', 'jj_to_jjs': 'slickest'},
 'frustrate': {'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'counterpoise': {'vbd_eq_vbn': ''},
 'ablate': {'vbd_eq_vbn': ''},
 'notarize': {'vbd_eq_vbn': ''},
 'triple': {'vbd_eq_vbn': ''},
 'corrupt': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'covet': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'mingle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'untangle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'woo': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'bask': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'expel': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'placate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'motorize': {'vbd_eq_vbn': ''},
 'protract': {'vbd_eq_vbn': ''},
 'infringe': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'pasteurize': {'vbd_eq_vbn': ''},
 'oxidize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'reintegrate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'zoom': {'vbd_eq_vbn': '', 'vi_typical': ''},
 'extirpate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'poach': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'revile': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'finagle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'actuate': {'vbd_eq_vbn': ''},
 'maltreat': {'vbd_eq_vbn': ''},
 'infuse': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'apprise': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'overprice': {'vbd_eq_vbn': ''},
 'excoriate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'discern': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'inflate': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'regurgitate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'collaborate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'instigate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'remodel': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'double-cross': {'vbd_eq_vbn': ''},
 'misspell': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'aspire': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'disfranchise': {'vbd_eq_vbn': ''},
 'heighten': {'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'expropriate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'verbalize': {'vbd_eq_vbn': ''},
 're-form': {'vbd_eq_vbn': ''},
 'blurt': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bemoan': {'vbd_eq_vbn': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'betroth': {'vbd_eq_vbn': ''},
 'emanate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'demoralize': {'vbd_eq_vbn': ''},
 'expedite': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'refract': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'unlock': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'revivify': {'vbd_eq_vbn': ''},
 'elaborate': {'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'outlive': {'vbd_eq_vbn': ''},
 'outmode': {'vbd_eq_vbn': ''},
 'trudge': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'hoodwink': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'unlink': {'vbd_eq_vbn': ''},
 'deafen': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'reinterpret': {'vbd_eq_vbn': ''},
 'emigrate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'bamboozle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'subsume': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'ingest': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'rusticate': {'vbd_eq_vbn': ''},
 'enslave': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'dwell': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'commingle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'parlay': {'vbd_eq_vbn': ''},
 'abate': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vb_to_vbd': 'abated', 'vb_to_vbn': 'abated', 'vb_to_vbg': 'abating'},
 'accelerate': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'entrench': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'ignite': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'commandeer': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'elicit': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'commercialize': {'vbd_eq_vbn': ''},
 'temporize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'conceal': {'vbd_eq_vbn': ''},
 'burglarize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'denude': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'sexualize': {'vbd_eq_vbn': ''},
 'ready': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'be_jj_to_vb': '', 'jj_to_jjr': 'readier', 'jj_to_jjs': 'readiest'},
 'misfire': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'reload': {'vbd_eq_vbn': ''},
 'degrade': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'bewilder': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'hydrolyze': {'vbd_eq_vbn': ''},
 'collateralize': {'vbd_eq_vbn': ''},
 'shrivel': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'reshuffle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'disinter': {'vbd_eq_vbn': ''},
 'unify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'bruit': {'vbd_eq_vbn': ''},
 'overstuff': {'vbd_eq_vbn': ''},
 'deep-fry': {'vbd_eq_vbn': ''},
 'scrounge': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'seduce': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'grin': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'parboil': {'vbd_eq_vbn': ''},
 'embolden': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'sidle': {'vbd_eq_vbn': ''},
 'unleash': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'misstate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'vandalize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'enshrine': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'impugn': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'gussy': {'vbd_eq_vbn': ''},
 'mobilize': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'magnetize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'decamp': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'manicure': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'lop': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'rile': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'deflect': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'boycott': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'immortalize': {'vbd_eq_vbn': ''},
 'decontaminate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'depersonalize': {'vbd_eq_vbn': ''},
 'despoil': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'quash': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'bide': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'enlarge': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'unarm': {'vbd_eq_vbn': ''},
 'consummate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'cede': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'overdose': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'second-guess': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'embellish': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'nudge': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'amass': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'serialize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'repulse': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'acclimatize': {'vbd_eq_vbn': ''},
 'scrawl': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'tantalize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'disrupt': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'avert': {'vbd_eq_vbn': '', 'v_infcl_non': '', 'vbg_non': ''},
 'despise': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'terrorize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'skyrocket': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'exaggerate': {'vbd_eq_vbn': '', 'v_prprtcl_non': ''},
 'escalate': {'vbd_eq_vbn': ''},
 'stoke': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'disaffiliate': {'vbd_eq_vbn': ''},
 'wed': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'crumble': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'dampen': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'linger': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'reclassify': {'vbd_eq_vbn': ''},
 'befoul': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'outdistance': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'revitalize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'retaliate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'desist': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'overestimate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'crave': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'impute': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'delineate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'singe': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'decentralize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'overplay': {'vbd_eq_vbn': ''},
 'obsolete': {'vbd_eq_vbn': ''},
 'deport': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'unfurl': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'engender': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'err': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'lavish': {'vbd_eq_vbn': ''},
 'annihilate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'deprive': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'reappraise': {'vbd_eq_vbn': ''},
 'nonplus': {'vbd_eq_vbn': ''},
 'abduct': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'erase': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'penalize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'retool': {'vbd_eq_vbn': ''},
 'vitiate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'guzzle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'encamp': {'vbd_eq_vbn': ''},
 'arouse': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'beleaguer': {'vbd_eq_vbn': ''},
 'surpass': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'traduce': {'vbd_eq_vbn': ''},
 'contaminate': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'personalize': {'vbd_eq_vbn': ''},
 'sidestep': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'stagnate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'bawl': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'wilt': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'subtract': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'categorize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'peddle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'dwindle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'oscillate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'berate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'subscribe': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'dehumanize': {'vbd_eq_vbn': ''},
 'interpose': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'secede': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'metabolize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'treble': {'vbd_eq_vbn': ''},
 'agitate': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'consolidate': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'cavort': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'burgeon': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'promulgate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'entangle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'democratize': {'vbd_eq_vbn': ''},
 'shortchange': {'vbd_eq_vbn': ''},
 'fondle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bombard': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'drowse': {'vbd_eq_vbn': ''},
 'coagulate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'entomb': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'disassemble': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'transgress': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'blunt': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'jj_to_jjr': 'blunter', 'jj_to_jjs': 'bluntest'},
 'adjourn': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'vbg_non': ''},
 'unclothe': {'vbd_eq_vbn': ''},
 'sear': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'drawl': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'grapple': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'spurn': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'exult': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'sashay': {'vbd_eq_vbn': ''},
 'desiccate': {'vbd_eq_vbn': ''},
 'splay': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'adjoin': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'dangle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'pacify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'disgruntle': {'vbd_eq_vbn': ''},
 'redirect': {'vbd_eq_vbn': '', 'vt_typical': ''},
 'disable': {'vbd_eq_vbn': ''},
 'replicate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'catalyze': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'preside': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'avenge': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'dishearten': {'vbd_eq_vbn': ''},
 'mellow': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'jj_to_jjr': 'mellower', 'jj_to_jjs': 'mellowest'},
 'overindulge': {'vbd_eq_vbn': ''},
 'coax': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'narcotize': {'vbd_eq_vbn': ''},
 'debunk': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'hypnotize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'refurbish': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'slim': {'vbd_eq_vbn': '', 'jj_to_jjr': 'slimmer', 'jj_to_jjs': 'slimmest'},
 'punctuate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vt_typical': ''},
 'renounce': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'invert': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'horrify': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'incur': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'disorganize': {'vbd_eq_vbn': ''},
 'purloin': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'militarize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'rotate': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'implant': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'acquiesce': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'generalize': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'defoliate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'undervalue': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'hew': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'emend': {'vbd_eq_vbn': ''},
 'excavate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'unmask': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bedraggle': {'vbd_eq_vbn': ''},
 'dissipate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'shoo': {'vbd_eq_vbn': ''},
 'smolder': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'deduct': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'scrutinize': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'unhitch': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'predetermine': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'foment': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'embezzle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'sculpt': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'imbue': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'elevate': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'overshadow': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'slither': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'reignite': {'vbd_eq_vbn': ''},
 'illuminate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'kindle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'ostracize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'assimilate': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'mismanage': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'decapitate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'concur': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'boggle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'busy': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'jj_to_jjr': 'busier', 'jj_to_jjs': 'busiest'},
 'pester': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'obligate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'invoke': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'affiance': {'vbd_eq_vbn': ''},
 'detonate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'fractionate': {'vbd_eq_vbn': ''},
 'trounce': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'mishandle': {'vbd_eq_vbn': ''},
 'conventionalize': {'vbd_eq_vbn': ''},
 'redistribute': {'vbd_eq_vbn': ''},
 'abhor': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'inject': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'incite': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'excommunicate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'appraise': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'tog': {'vbd_eq_vbn': ''},
 'demolish': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'officiate': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'drub': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'lyophilize': {'vbd_eq_vbn': ''},
 'subvert': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'bequeath': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'devise': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'tape-record': {'vbd_eq_vbn': ''},
 'epitomize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'wreak': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'familiarize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'defray': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'banish': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'outweigh': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'beguile': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'bootleg': {'vbd_eq_vbn': ''},
 'plunk': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'vacate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'inculcate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'misinform': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'crucify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'intimidate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'disobey': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'propagate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'relocate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'topple': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'rehearse': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'outclass': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'disarrange': {'vbd_eq_vbn': ''},
 'allude': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'enrapture': {'vbd_eq_vbn': ''},
 'attune': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'outmatch': {'vbd_eq_vbn': ''},
 'tabulate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'depopulate': {'vbd_eq_vbn': ''},
 'discomfit': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'redouble': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'juxtapose': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'irk': {'vbd_eq_vbn': ''},
 'interrogate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'ejaculate': {'vbd_eq_vbn': ''},
 'immunize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'ill-treat': {'vbd_eq_vbn': ''},
 'admonish': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'deputize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'downplay': {'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'commute': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'jettison': {'vbd_eq_vbn': ''},
 'withstand': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'portend': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'compartmentalize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'suffice': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'agglomerate': {'vbd_eq_vbn': ''},
 'vaporize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'convulse': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'engulf': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'idealize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'coerce': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'corrode': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'pervade': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'americanize': {'vbd_eq_vbn': ''},
 'persecute': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'enlist': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'interconnect': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'exempt': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'transpire': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'abort': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'yearn': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'proliferate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'foist': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'militate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'oust': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'appease': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'tattoo': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'enunciate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'besmirch': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'strangle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'delude': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'secrete': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'impair': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'renovate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'envision': {'vbd_eq_vbn': ''},
 'capitulate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'perpetrate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'remit': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'minimize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'repudiate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'wrest': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'heft': {'vbd_eq_vbn': ''},
 'quantify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'syncopate': {'vbd_eq_vbn': ''},
 'politicize': {'vbd_eq_vbn': ''},
 'subjugate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'dethrone': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'thrive': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'persevere': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'federalize': {'vbd_eq_vbn': ''},
 'bate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'halve': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'enumerate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'reshape': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'wainscot': {'vbd_eq_vbn': ''},
 'ransack': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'tame': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'jj_to_jjr': 'tamer', 'jj_to_jjs': 'tamest'},
 'demean': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'heckle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'pertain': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'lambaste': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'infest': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'merge': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'declaim': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'vacillate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'nullify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'unsheathe': {'vbd_eq_vbn': ''},
 'dawdle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'further': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'formalize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'disbelieve': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'snuggle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'vomit': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'alleviate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'implore': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'replant': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'dispense': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'gladden': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'airmail': {'vbd_eq_vbn': ''},
 'impale': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'croon': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'retrace': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'roam': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'renegotiate': {'vbd_eq_vbn': ''},
 'hearten': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'transpose': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'unlace': {'vbd_eq_vbn': ''},
 'reconsider': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'darn': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'culminate': {'vbd_eq_vbn': ''},
 'hiss': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'decimate': {'vbd_eq_vbn': ''},
 'miniaturize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'inflect': {'vbd_eq_vbn': ''},
 'expend': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'weary': {'vbd_eq_vbn': '', 'jj_to_jjr': 'wearier', 'jj_to_jjs': 'weariest'},
 'intermix': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'demote': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'digitalize': {'vbd_eq_vbn': ''},
 'cerebrate': {'vbd_eq_vbn': ''},
 'reimburse': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'adorn': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'misplace': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'harry': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'globalize': {'vbd_eq_vbn': ''},
 'reinvent': {'vbd_eq_vbn': ''},
 'segregate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'desecrate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'propound': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'sanitize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'calcify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'usurp': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'bedazzle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'envenom': {'vbd_eq_vbn': ''},
 'curtail': {'vbd_eq_vbn': '', 'v_compcl_non': ''},
 'christen': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'foreshadow': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'dialyze': {'vbd_eq_vbn': ''},
 'theorize': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'enchain': {'vbd_eq_vbn': ''},
 'reopen': {'vbd_eq_vbn': ''},
 'malign': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'unravel': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'tinkle': {'vbd_eq_vbn': ''},
 'straggle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'hospitalize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'vbg_non': ''},
 'reverberate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'internationalize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'putt': {'vbd_eq_vbn': ''},
 'disapprove': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'incapacitate': {'vbd_eq_vbn': ''},
 'embody': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'asphyxiate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'evoke': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'individualize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'scandalize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'disabuse': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'blaspheme': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bastardize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bedevil': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'flabbergast': {'vbd_eq_vbn': ''},
 'writhe': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'detract': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'emulsify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'hurtle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'disembark': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'vindicate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'de-emphasize': {'vbd_eq_vbn': ''},
 'discombobulate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'rejoice': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'absolve': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'outstrip': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'ensnare': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'impersonate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'quell': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'reassign': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_whcl_non': ''},
 'scrimp': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'conjure': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'overrule': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'sift': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'yelp': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'uncork': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'annotate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'thwart': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'extrapolate': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'galvanize': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'reinvigorate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'dignify': {'vbd_eq_vbn': ''},
 'refinance': {'vbd_eq_vbn': ''},
 'articulate': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'rustle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'proscribe': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'hobble': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'supersede': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'corroborate': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'rouse': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'legitimize': {'vbd_eq_vbn': ''},
 'flounce': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'intone': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'lurk': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'decommission': {'vbd_eq_vbn': ''},
 'deign': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'declassify': {'vbd_eq_vbn': ''},
 'marinate': {'vbd_eq_vbn': ''},
 'enfranchise': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'douse': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'abolish': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'vt_typical': ''},
 'madden': {'vbd_eq_vbn': ''},
 'paginate': {'vbd_eq_vbn': ''},
 'exterminate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'populate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'espouse': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'reinstate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'vbg_non': ''},
 'bandy': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'jj_to_jjr': 'bandier', 'jj_to_jjs': 'bandiest'},
 'disallow': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'chelate': {'vbd_eq_vbn': ''},
 'bulldoze': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'twiddle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'intertwine': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'purify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'unfasten': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'disqualify': {'vbd_eq_vbn': ''},
 'dote': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bilk': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'infiltrate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'belie': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'revert': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'volatilize': {'vbd_eq_vbn': ''},
 'condense': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'decelerate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'refute': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'mitigate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'polarize': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'encompass': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'retry': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'pamper': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'encase': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'smirk': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'soothe': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'mismatch': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'invigorate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'supervise': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'excrete': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'mortify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'eject': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'remarry': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'devastate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'rephrase': {'vbd_eq_vbn': ''},
 'traumatize': {'vbd_eq_vbn': ''},
 'disown': {'vbd_eq_vbn': ''},
 'transact': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'captivate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'smuggle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'short-circuit': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'endanger': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'chasten': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'nauseate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'intoxicate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'accede': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bunk': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'wheedle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'coarsen': {'vbd_eq_vbn': ''},
 'resuscitate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'fizzle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'freshen': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'induct': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'pare': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'slurp': {'vbd_eq_vbn': ''},
 'entice': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'exonerate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'circulate': {'vbd_eq_vbn': '', 'v_whcl_non': ''},
 'transcend': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'typify': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'uproot': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'liberate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'accentuate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'relegate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'dilute': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'deplore': {'vbd_eq_vbn': '', 'v_infcl_non': '', 'vbg_non': ''},
 'elope': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'splatter': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'unfix': {'vbd_eq_vbn': ''},
 'bestir': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'orchestrate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'smart': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': '', 'jj_to_jjr': 'smarter', 'jj_to_jjs': 'smartest'},
 'rumple': {'vbd_eq_vbn': ''},
 'relinquish': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'relent': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'flee': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'plead': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'exceed': {'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'denounce': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'opt': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'prevail': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'uphold': {'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'underscore': {'vbd_eq_vbn': '', 'v_infcl_non': ''},
 'invade': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': ''},
 'regain': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': ''},
 'outnumber': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'defy': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'hover': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'haul': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'hurl': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'outperform': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'veer': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'materialize': {'vbd_eq_vbn': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'beckon': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'contravene': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'dismount': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'eke': {'vbd_eq_vbn': ''},
 'endear': {'vbd_eq_vbn': ''},
 'fend': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'gyrate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'purl': {'vbd_eq_vbn': ''},
 'radiate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'reappear': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_pass_non': ''},
 'regale': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'reminisce': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'ruminate': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'seep': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'spew': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'waffle': {'vbd_eq_vbn': '', 'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'daresay': {'v_compcl': ''},
 'deputise': {'vbd_eq_vbn': ''},
 'blackspot': {'n_is_nc': ''},
 'hillwalker': {'n_is_nc': '', 'n_is_sb': '0', 'nn_to_nns': 'hillwalkers'},
 'scottish': {'cap_word': 'Scottish'},
 'romanesque': {'cap_word': 'Romanesque'},
 'keynesian': {'cap_word': 'Keynesian'},
 'jewish': {'cap_word': 'Jewish'},
 'kurdish': {'cap_word': 'Kurdish'},
 'celtic': {'cap_word': 'Celtic'},
 'copernican': {'cap_word': 'Copernican'},
 'islamic': {'cap_word': 'Islamic'},
 'islamist ': {'cap_word': 'Islamist '},
 'germanic': {'cap_word': 'Germanic'},
 'sicily': {'cap_word': 'Sicily'},
 'viennese': {'cap_word': 'Viennese'},
 'freudian': {'cap_word': 'Freudian'},
 'euclidean': {'cap_word': 'Euclidean'},
 'x-rayed': {'cap_word': 'X-rayed'},
 'napoleonic': {'cap_word': 'Napoleonic'},
 'grecian': {'cap_word': 'Grecian'},
 'nordic': {'cap_word': 'Nordic'},
 'baltic': {'cap_word': 'Baltic'},
 'masonic': {'cap_word': 'Masonic'},
 'glasgow': {'cap_word': 'Glasgow'},
 'yiddish': {'cap_word': 'Yiddish'},
 'liverpool': {'cap_word': 'Liverpool'},
 'gregorian': {'cap_word': 'Gregorian'},
 'slavic': {'cap_word': 'Slavic'},
 'himalayan': {'cap_word': 'Himalayan'},
 'sussex': {'cap_word': 'Sussex'},
 'dickensian': {'cap_word': 'Dickensian'},
 'teutonic': {'cap_word': 'Teutonic'},
 'slavonic': {'cap_word': 'Slavonic'},
 'cartesian': {'cap_word': 'Cartesian'},
 'pleistocene': {'cap_word': 'Pleistocene'},
 'bavarian': {'cap_word': 'Bavarian'},
 'brooklyn': {'cap_word': 'Brooklyn'},
 'essex': {'cap_word': 'Essex'},
 'ordovician': {'cap_word': 'Ordovician'},
 'homeric': {'cap_word': 'Homeric'},
 'shakespearean': {'cap_word': 'Shakespearean'},
 'marian': {'cap_word': 'Marian'},
 'newcastle': {'cap_word': 'Newcastle'},
 'aberdeen': {'cap_word': 'Aberdeen'},
 'stygian': {'cap_word': 'Stygian'},
 'disneyland': {'cap_word': 'Disneyland'},
 'lenten': {'cap_word': 'Lenten'},
 'gaussian': {'cap_word': 'Gaussian'},
 'manx': {'cap_word': 'Manx'},
 'gallic': {'cap_word': 'Gallic'},
 'saskatchewan': {'cap_word': 'Saskatchewan'},
 'chicano': {'cap_word': 'Chicano'},
 'jurassic': {'cap_word': 'Jurassic'},
 'pompeii': {'cap_word': 'Pompeii'},
 'scots': {'cap_word': 'Scots'},
 'americans': {'cap_word': 'Americans'},
 'overhear': {'v_compcl': '', 'vbg_non': ''},
 'twinkly': {'jj_to_nn': 'twinke'},
 'baste': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'barf': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'badmouth': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'backtrack': {'v_compcl_non': '', 'v_pass_non': ''},
 'backpedal': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'backslide': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'backdate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'augment': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'atomize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'atone': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'arrogate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'antagonize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'anthropomorphize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'annul': {'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'anoint': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'anesthetize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'anatomize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'amortize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'amplify': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'ameliorate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'allot': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'alight': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'align': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'aline': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'air-condition': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'agonize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'ail': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'aggrandize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'affront': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'aerate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'adulterate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'adduce': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'acquaint': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'accrue': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'acidify': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'accredit': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'acclimate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'abut': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'abridge': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'abscond': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'abrade': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'abide': {'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'abbreviate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'abdicate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'hibernate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': '', 'vi_typical': ''},
 'hitchhike': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'hobnob': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'homogenize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'honk': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_pass_non': ''},
 'humanize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'hybridize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'immolate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'impel': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'impinge': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'impregnate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'improvise': {'v_compcl_non': '', 'v_prprtcl_non': ''},
 'incarnate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'incarcerate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'incinerate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'incriminate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'indemnify': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'indent': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'industrialize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'infuriate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'ingratiate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'inoculate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'inseminate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'inscribe': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'insulate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'interlace': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'interdict': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'intermingle': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'intermarry': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'interlink': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'interpolate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'intersect': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'interweave': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'inure': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'inundate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'inveigle': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'inveigh': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'irrigate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'vt_typical': ''},
 'josh': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'kibitz': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'knead': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'lacerate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'lactate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'lampoon': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'leach': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'leapfrog': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'limn': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'liquefy': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'liven': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'loll': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'loiter': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'lubricate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'luxuriate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'macerate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'mainline': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'magnify': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'marginalize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'mash': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'masturbate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'maul': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'meddle': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'mechanize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'medicate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'menstruate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'metastasize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'misapply': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'misbehave': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'misperceive': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'misspeak': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'misspend': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'moisten': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'modulate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'molder': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'moot': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'mooch': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'moralize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'moulder': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'mosey': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'mummify': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'mull': {'v_compcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'mulch': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'mythologize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'naturalize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'natter': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'nitpick': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'nourish': {'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'nosedive': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'objectify': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'obstruct': {'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'obscure': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'obliterate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'offload': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'obviate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'orate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'optimize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'oppress': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'outdo': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'outguess': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'outgrow': {'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'outflank': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'outshine': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'outrun': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'outwit': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'overdo': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'overeat': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'overdraw': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'overfly': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'overlay': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'overproduce': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'overpraise': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'oversee': {'v_compcl_non': '', 'v_infcl_non': ''},
 'override': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'overspend': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'oversimplify': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'overstep': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'overtake': {'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'overstress': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'overwinter': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'ovulate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'panhandle': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'paralyze': {'v_compcl_non': '', 'v_infcl_non': ''},
 'parch': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'partake': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'parse': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'perforate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'percolate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'perm': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'perplex': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'perturb': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'peruse': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'philander': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'piddle': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'pigeonhole': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'pilfer': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'pollinate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'preen': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'preoccupy': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'prepay': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'prevaricate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'prettify': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'pressurize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'prim': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'jj_to_jjr': 'primmer', 'jj_to_jjs': 'primmest'},
 'primp': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'probate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'procreate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'prolong': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'proofread': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'vbd_eq_vbn': ''},
 'propagandize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'proselytize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'prostrate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'pulverize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'pussyfoot': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'purvey': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'quaff': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'rampage': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'ravish': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 're-create': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'razz': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'raze': {'v_compcl_non': '', 'v_prprtcl_non': ''},
 're-examine': {'v_compcl_non': ''},
 're-enter': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'rear-end': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'rebuild': {'v_compcl_non': '', 'vt_typical': ''},
 'recapitulate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'reciprocate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'recline': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'reclaim': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'recombine': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'reconnoiter': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'recondition': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'reconcile': {'v_compcl_non': '', 'v_infcl_non': ''},
 'reconquer': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'recuperate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'redline': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'redeploy': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'redeem': {'v_compcl_non': '', 'v_prprtcl_non': ''},
 'redound': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'reelect': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'refashion': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'reexamine': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'refloat': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'reformulate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'refuel': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'refrigerate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'regenerate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'regularize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'regress': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'rehear': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'reheat': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'reinsure': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'rejuvenate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'relive': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'remold': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'rend': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'renege': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'repay': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'repot': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'repossess': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'reprocess': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'reprise': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'republish': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'reprove': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'rerun': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'reread': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'vbd_eq_vbn': ''},
 'resemble': {'v_compcl_non': '', 'v_infcl_non': '', 'v_pass_non': '', 'vt_typical': ''},
 'resell': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'reseed': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'resound': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'respire': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'resurge': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'retake': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'ret': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'retch': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'retouch': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'retransmit': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'retract': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'retrench': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'retread': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'retrograde': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'retrofit': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'reunite': {'v_compcl_non': '', 'v_prprtcl_non': ''},
 'rewrite': {'v_compcl_non': '', 'v_prprtcl_non': '', 'vt_typical': ''},
 'reword': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'rive': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'roughhouse': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'salivate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'sanctify': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'saturate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'satirize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'saute': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'scant': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'scavenge': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'schlep': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'scorch': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'scoot': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'scram': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'scribble': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'scrunch': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'sedate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'seel': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'segue': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'sequester': {'v_compcl_non': '', 'v_prprtcl_non': ''},
 'sentimentalize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'sensitize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'sever': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'sermonize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'sheathe': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'shear': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'shelve': {'v_compcl_non': ''},
 'sideswipe': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'sightsee': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'skedaddle': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'skimp': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'skulk': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'slay': {'v_compcl_non': ''},
 'slather': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'sleek': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'jj_to_jjr': 'sleeker', 'jj_to_jjs': 'sleekest'},
 'slink': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'slog': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'slosh': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'smite': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'socialize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'solicit': {'v_compcl_non': '', 'v_whcl_non': ''},
 'soundproof': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'spank': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'speckle': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'spot-check': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'stale': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'jj_to_jjr': 'staler', 'jj_to_jjs': 'stalest'},
 'stanch': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'standardize': {'v_compcl_non': '', 'v_infcl_non': ''},
 'stargaze': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'staunch': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'jj_to_jjr': 'stauncher', 'jj_to_jjs': 'staunchest'},
 'sterilize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'stigmatize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'stimulate': {'v_compcl_non': '', 'v_whcl_non': ''},
 'strafe': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'strew': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'strong-arm': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'strum': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'stultify': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'stucco': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'subdivide': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'sublease': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'subdue': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'sublime': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'sublimate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'submerge': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'suborn': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'subsist': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'suffocate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'supercharge': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'sup': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'sunder': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'supple': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'jj_to_jjr': 'suppler', 'jj_to_jjs': 'supplest'},
 'surmount': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'surf': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'swaddle': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'swelter': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'sweeten': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'sweet-talk': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'swoop': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'synthesize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'synchronize': {'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'tamp': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'tarry': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'jj_to_jjr': 'tarrier', 'jj_to_jjs': 'tarriest'},
 'thicken': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'thresh': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'toddle': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'totter': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'traipse': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'tranquilize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'trivialize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'truncate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'tyrannize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'typeset': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': '', 'vbd_eq_vbn': ''},
 'typecast': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'vbd_eq_vbn': ''},
 'unbolt': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'unbalance': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'unbuckle': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'uncouple': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'undershoot': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'undersell': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'underrate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'underwrite': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'undulate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'undo': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'unfit': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'unearth': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'unfreeze': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'unionize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'unhook': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'unlearn': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'unmake': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'unload': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'unpack': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'unseal': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'unscramble': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'unsnarl': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'unsettle': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'untwist': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'unzip': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'unwind': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'upchuck': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'upbraid': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'upholster': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'upend': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'urinate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'vanquish': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'vegetate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'vend': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'ventilate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'vex': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'vocalize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'waddle': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'waggle': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'waylay': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'wend': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'westernize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'winnow': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'wive': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'wither': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'worst': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'yammer': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'xerox': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'undergo': {'v_compcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'withhold': {'v_compcl_non': ''},
 'headquarter': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'hark': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'harass': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'hamper': {'v_compcl_non': '', 'v_infcl_non': ''},
 'hallow': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'habituate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'gurgle': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'grovel': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'gravitate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'gnaw': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'gnash': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'glorify': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'glamorize': {'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'gestate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'genuflect': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'garnishee': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'garble': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'gainsay': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'furnish': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'fumigate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'fulminate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'fulfil': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'forsake': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'forgo': {'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'forfend': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'forego': {'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'flummox': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'flog': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'flit': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'flay': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'fireproof': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'fib': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'fertilize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'feminize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'fabricate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'extricate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'extol': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'extinguish': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'explicate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'expiate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'exorcise': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'exhume': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'exhort': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'exfoliate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'exasperate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'exalt': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'evangelize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'evacuate': {'v_compcl_non': ''},
 'etch': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'estrange': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'espy': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'equivocate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'equalize': {'v_compcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'environ': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'envelop': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'entrap': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'enthuse': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'enthrall': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'enshroud': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'enroll': {'v_compcl_non': '', 'v_prprtcl_non': ''},
 'enrich': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'ennoble': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'enlighten': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'engraft': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'enfold': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'energize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'endow': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'encrypt': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'encode': {'v_compcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'encapsulate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'empathize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'embroider': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'embed': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'embalm': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'emasculate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'emancipate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'elongate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'electrify': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'effectuate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'efface': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'eavesdrop': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'drench': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'dowse': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'download': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vt_typical': ''},
 'domesticate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'doff': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'dizzy': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'divert': {'v_compcl_non': '', 'v_whcl_non': ''},
 'diverge': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'distill': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'dissolve': {'v_compcl_non': '', 'v_prprtcl_non': ''},
 'dissemble': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'dissect': {'v_compcl_non': '', 'v_prprtcl_non': ''},
 'dispossess': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'disperse': {'v_compcl_non': ''},
 'disinfect': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'disgorge': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'disengage': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'disembowel': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'disconnect': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'disconcert': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'discolor': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'disarm': {'v_compcl_non': '', 'vbg_non': ''},
 'dilly-dally': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'dilate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'digress': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'diddle': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'devolve': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'devaluate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'detoxify': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'detach': {'v_compcl_non': '', 'v_prprtcl_non': '', 'vbg_non': ''},
 'destabilize': {'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'desolate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'derogate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'deodorize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'denigrate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'demystify': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'dematerialize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'deify': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'degrease': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'defrost': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'deform': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'deflate': {'v_compcl_non': '', 'v_prprtcl_non': ''},
 'deface': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'dedicate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'decrypt': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'decouple': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'decompress': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'decode': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'debrief': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'debase': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'deaden': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'deactivate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'darken': {'v_compcl_non': '', 'v_prprtcl_non': ''},
 'dally': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'cumulate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'crystallize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'crumple': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'criticise': {'v_compcl_non': '', 'v_infcl_non': ''},
 'creak': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'cower': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'countersink': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'countersign': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'countermand': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cosign': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'copulate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'converge': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'convalesce': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'contrive': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'contort': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'constrict': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'connive': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'conjugate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'congest': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'congeal': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'confound': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': ''},
 'conflate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'configure': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'conduce': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'condescend': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'condemn': {'v_compcl_non': '', 'vt_typical': ''},
 'conciliate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'compassionate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'commiserate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'commentate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'collide': {'v_compcl_non': '', 'v_pass_non': ''},
 'cohere': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cohabit': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cogitate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cog': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'coexist': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cloy': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'cling': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'clench': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'clamber': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'circumvent': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'circumscribe': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'chuckle': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'cheapen': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'checkmate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'centralize': {'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'caulk': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'cauterize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'carouse': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'capsulize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'caper': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'capitalize': {'v_compcl_non': '', 'v_prprtcl_non': ''},
 'capsize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'canoodle': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cannibalize': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'calve': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'cajole': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': ''},
 'calibrate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'cadge': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'burble': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bulletproof': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'browbeat': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'brainstorm': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'braise': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'boomerang': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bootstrap': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bonk': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bobble': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'bloat': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'blab': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bisect': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'bifurcate': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bewail': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'betide': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bestride': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'besmear': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'bespeak': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'beseech': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'behold': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'behoove': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'belabor': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'beget': {'v_compcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'behead': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'befuddle': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'befall': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'befit': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'bedeck': {'v_compcl_non': '', 'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'appall': {'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': ''},
 'attest': {'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'avow': {'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'beware': {'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'decompose': {'v_prprtcl_non': '', 'v_infcl_non': ''},
 'dehydrate': {'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'dim': {'v_prprtcl_non': '', 'jj_to_jjr': 'dimmer', 'jj_to_jjs': 'dimmest'},
 'disfigure': {'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'displease': {'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'disprove': {'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'elate': {'v_prprtcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'enrage': {'v_prprtcl_non': '', 'v_infcl_non': '', 'vbg_non': ''},
 'fade': {'v_prprtcl_non': '', 'v_pass_non': ''},
 'grieve': {'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'infect': {'v_prprtcl_non': '', 'v_infcl_non': ''},
 'opine': {'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'petrify': {'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'posit': {'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'ratify': {'v_prprtcl_non': '', 'vbg_non': ''},
 'reassert': {'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'v_pass_non': ''},
 'reestablish': {'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': ''},
 'seethe': {'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'snicker': {'v_prprtcl_non': '', 'v_infcl_non': '', 'v_pass_non': ''},
 'vouch': {'v_prprtcl_non': '', 'v_infcl_non': '', 'v_whcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'accomplish': {'v_infcl_non': '', 'vt_typical': ''},
 'deplete': {'v_infcl_non': ''},
 'fathom': {'v_infcl_non': '', 'vbg_non': '', 'v_pass_non': ''},
 'feign': {'v_whcl_non': ''},
 'abut proposal': {'e_trp.dobj': ''},
 'abuse mercy_killing': {'e_trp.dobj': ''},
 'abandon torture': {'e_trp.dobj': ''},
 'abandon intension': {'e_trp.dobj': ''},
 'access class': {'e_trp.dobj': ''},
 'accept yeh': {'e_trp.dobj': ''},
 'accept practise': {'e_trp.dobj': ''},
 'accord world': {'e_trp.dobj': ''},
 'accord talent': {'e_trp.dobj': ''},
 'accord favour': {'e_trp.dobj': ''},
 'ace sun': {'e_trp.dobj': ''},
 'ace lot': {'e_trp.dobj': ''},
 'accumulate experiment': {'e_trp.dobj': ''},
 'acquire experiment': {'e_trp.dobj': ''},
 'achieve find': {'e_trp.dobj': ''},
 'achieve consequent': {'e_trp.dobj': ''},
 'achieve blessing': {'e_trp.dobj': ''},
 'act general': {'e_trp.dobj': ''},
 'act euthanasia': {'e_trp.dobj': ''},
 'acquire triumph': {'e_trp.dobj': ''},
 'adapt society': {'e_trp.dobj': ''},
 'adapt mind': {'e_trp.dobj': ''},
 'act use': {'e_trp.dobj': ''},
 'act ice': {'e_trp.dobj': ''},
 'admire mood': {'e_trp.dobj': ''},
 'add_up beauty': {'e_trp.dobj': ''},
 'admit knife': {'e_trp.dobj': ''},
 'admit equality': {'e_trp.dobj': ''},
 'admire sign': {'e_trp.dobj': ''},
 'admire round': {'e_trp.dobj': ''},
 'adopt society': {'e_trp.dobj': ''},
 'adopt job': {'e_trp.dobj': ''},
 'adopt feminist': {'e_trp.dobj': ''},
 'advance sex': {'e_trp.dobj': ''},
 'adore moon': {'e_trp.dobj': ''},
 'adore degree': {'e_trp.dobj': ''},
 'afford grief': {'e_trp.dobj': ''},
 'afford at': {'e_trp.dobj': ''},
 'affect flourish': {'e_trp.dobj': ''},
 'advocate human': {'e_trp.dobj': ''},
 'aggravate sickness': {'e_trp.dobj': ''},
 'aggravate initiative': {'e_trp.dobj': ''},
 'afford skill': {'e_trp.dobj': ''},
 'aim degree': {'e_trp.dobj': ''},
 'aid mind': {'e_trp.dobj': ''},
 'agonize condition': {'e_trp.dobj': ''},
 'allocate leaver': {'e_trp.dobj': ''},
 'allocate graduate': {'e_trp.dobj': ''},
 'alleviate tone': {'e_trp.dobj': ''},
 'alled relationship': {'e_trp.dobj': ''},
 'alloted chemistry': {'e_trp.dobj': ''},
 'allocate vocational_school': {'e_trp.dobj': ''},
 'allocate school': {'e_trp.dobj': ''},
 'amuse show': {'e_trp.dobj': ''},
 'alter uneasiness': {'e_trp.dobj': ''},
 'alloted job': {'e_trp.dobj': ''},
 'answer electricity': {'e_trp.dobj': ''},
 'answer behaviour': {'e_trp.dobj': ''},
 'analyse root': {'e_trp.dobj': ''},
 'appeal public': {'e_trp.dobj': ''},
 'apologize smile': {'e_trp.dobj': ''},
 'ante tree': {'e_trp.dobj': ''},
 'answer friendship': {'e_trp.dobj': ''},
 'appreciate cd': {'e_trp.dobj': ''},
 'apply disadvantage': {'e_trp.dobj': ''},
 'appeal society': {'e_trp.dobj': ''},
 'appreciate invention': {'e_trp.dobj': ''},
 'appreciate festival': {'e_trp.dobj': ''},
 'appreciate ferver': {'e_trp.dobj': ''},
 'approach see': {'e_trp.dobj': ''},
 'appreciate motherland': {'e_trp.dobj': ''},
 'appreciate moon': {'e_trp.dobj': ''},
 'arise debate': {'e_trp.dobj': ''},
 'arise change': {'e_trp.dobj': ''},
 'argue less': {'e_trp.dobj': ''},
 'arouse arguement': {'e_trp.dobj': ''},
 'arised negative': {'e_trp.dobj': ''},
 'arise discussion': {'e_trp.dobj': ''},
 'arouse money': {'e_trp.dobj': ''},
 'arouse liberation': {'e_trp.dobj': ''},
 'arouse knowledge': {'e_trp.dobj': ''},
 'arouse initiative': {'e_trp.dobj': ''},
 'arrange leaver': {'e_trp.dobj': ''},
 'arouse problem': {'e_trp.dobj': ''},
 'arouse nature': {'e_trp.dobj': ''},
 'arrive destination': {'e_trp.dobj': ''},
 'arrest beloved': {'e_trp.dobj': ''},
 'arrange sketch': {'e_trp.dobj': ''},
 'arrange quilt': {'e_trp.dobj': ''},
 'attach economy': {'e_trp.dobj': ''},
 'attach attention': {'e_trp.dobj': ''},
 'ask weather': {'e_trp.dobj': ''},
 'arrive hen': {'e_trp.dobj': ''},
 'attain treatment': {'e_trp.dobj': ''},
 'attain 40': {'e_trp.dobj': ''},
 'attach water': {'e_trp.dobj': ''},
 'attach middle_school': {'e_trp.dobj': ''},
 'attend experiment': {'e_trp.dobj': ''},
 'attend activites': {'e_trp.dobj': ''},
 'attend acting': {'e_trp.dobj': ''},
 'attain water': {'e_trp.dobj': ''},
 'avoid dullness': {'e_trp.dobj': ''},
 'authorize mercy_killing': {'e_trp.dobj': ''},
 'attract technique': {'e_trp.dobj': ''},
 'attract sight': {'e_trp.dobj': ''},
 'award good_will': {'e_trp.dobj': ''},
 'await whole': {'e_trp.dobj': ''},
 'await fish': {'e_trp.dobj': ''},
 'avoid waster': {'e_trp.dobj': ''},
 'back dormitory': {'e_trp.dobj': ''},
 'back bike': {'e_trp.dobj': ''},
 'bare college': {'e_trp.dobj': ''},
 'ban commodity': {'e_trp.dobj': ''},
 'balance psychology': {'e_trp.dobj': ''},
 'base haste': {'e_trp.dobj': ''},
 'base euthanasia': {'e_trp.dobj': ''},
 'base eloquence': {'e_trp.dobj': ''},
 'bare rule': {'e_trp.dobj': ''},
 'bear mistake': {'e_trp.dobj': ''},
 'bear method': {'e_trp.dobj': ''},
 'bear deed': {'e_trp.dobj': ''},
 'base legalization': {'e_trp.dobj': ''},
 'beat commodity': {'e_trp.dobj': ''},
 'bear sport': {'e_trp.dobj': ''},
 'bear shine': {'e_trp.dobj': ''},
 'bear motherland': {'e_trp.dobj': ''},
 'befall homeland': {'e_trp.dobj': ''},
 'become superiority': {'e_trp.dobj': '', 'e_trp.xcomp_vbe_nn': ''},
 'beat watchs': {'e_trp.dobj': ''},
 'beat split': {'e_trp.dobj': ''},
 'begin puppet': {'e_trp.dobj': ''},
 'beg ear': {'e_trp.dobj': ''},
 'beg rage': {'e_trp.dobj': ''},
 'beget habit': {'e_trp.dobj': ''},
 'believe festival': {'e_trp.dobj': ''},
 'believe entertainment': {'e_trp.dobj': ''},
 'believe commodity': {'e_trp.dobj': ''},
 'behave thought': {'e_trp.dobj': ''},
 'benefit learner': {'e_trp.dobj': ''},
 'bend pair': {'e_trp.dobj': ''},
 'believe life_expectancy': {'e_trp.dobj': ''},
 'believe give': {'e_trp.dobj': ''},
 'better examination': {'e_trp.dobj': ''},
 'better cycle': {'e_trp.dobj': ''},
 'bestow light': {'e_trp.dobj': ''},
 'bestow colour': {'e_trp.dobj': ''},
 'bitt peasant': {'e_trp.dobj': ''},
 'biting left': {'e_trp.dobj': ''},
 'bind exile': {'e_trp.dobj': ''},
 'better status': {'e_trp.dobj': ''},
 'bless luckiness': {'e_trp.dobj': ''},
 'bless fairy': {'e_trp.dobj': ''},
 'blame conscience': {'e_trp.dobj': ''},
 'black rich': {'e_trp.dobj': ''},
 'bow wish': {'e_trp.dobj': ''},
 'board cast': {'e_trp.dobj': ''},
 'blush tooth': {'e_trp.dobj': ''},
 'breathe knowledge': {'e_trp.dobj': ''},
 'break_down industry': {'e_trp.dobj': ''},
 'break regularity': {'e_trp.dobj': ''},
 'brandish baton': {'e_trp.dobj': ''},
 'bring avoidance': {'e_trp.dobj': ''},
 'brighten water': {'e_trp.dobj': ''},
 'brick car': {'e_trp.dobj': ''},
 'bring morever': {'e_trp.dobj': ''},
 'bring euthanasia': {'e_trp.dobj': ''},
 'bring brain_drain': {'e_trp.dobj': ''},
 'bring_to damage': {'e_trp.dobj': ''},
 'bring potentiality': {'e_trp.dobj': ''},
 'bring plaque': {'e_trp.dobj': ''},
 'bring permission': {'e_trp.dobj': ''},
 'build ambition': {'e_trp.dobj': ''},
 'bring_to mankind': {'e_trp.dobj': ''},
 'bring_to health': {'e_trp.dobj': ''},
 'build_up lake': {'e_trp.dobj': ''},
 'build_up hardware': {'e_trp.dobj': ''},
 'build flore': {'e_trp.dobj': ''},
 'burden responsibility': {'e_trp.dobj': ''},
 'bump knowledge': {'e_trp.dobj': ''},
 'build_up prison': {'e_trp.dobj': ''},
 'burn_out leaf': {'e_trp.dobj': ''},
 'burn use': {'e_trp.dobj': ''},
 'burn manderley': {'e_trp.dobj': ''},
 'burgeon pollution': {'e_trp.dobj': ''},
 'buy marrage': {'e_trp.dobj': ''},
 'buy grandpa': {'e_trp.dobj': ''},
 'busy class': {'e_trp.dobj': ''},
 'burst laugh': {'e_trp.dobj': ''},
 'buy_in commodity': {'e_trp.dobj': ''},
 'buy swindler': {'e_trp.dobj': ''},
 'buy somethings': {'e_trp.dobj': ''},
 'call boredom': {'e_trp.dobj': ''},
 'calculate task': {'e_trp.dobj': ''},
 'cake friendship': {'e_trp.dobj': ''},
 'call_out victor_hugo': {'e_trp.dobj': ''},
 'calling refuse': {'e_trp.dobj': ''},
 'call euthanasia': {'e_trp.dobj': ''},
 'capture tap': {'e_trp.dobj': ''},
 'capitalize lie': {'e_trp.dobj': ''},
 'cane teenager': {'e_trp.dobj': ''},
 'cane american': {'e_trp.dobj': ''},
 'care speed': {'e_trp.dobj': ''},
 'care ore': {'e_trp.dobj': ''},
 'care living': {'e_trp.dobj': ''},
 'care interest': {'e_trp.dobj': ''},
 'catch crop': {'e_trp.dobj': ''},
 'cast mercy': {'e_trp.dobj': ''},
 'carry principal': {'e_trp.dobj': ''},
 'care water': {'e_trp.dobj': ''},
 'catch perfect': {'e_trp.dobj': ''},
 'catch fascist': {'e_trp.dobj': ''},
 'catch english': {'e_trp.dobj': ''},
 'categorize car': {'e_trp.dobj': ''},
 'catch sea': {'e_trp.dobj': ''},
 'cause inbalance': {'e_trp.dobj': ''},
 'cause bread': {'e_trp.dobj': ''},
 'cause beating': {'e_trp.dobj': ''},
 'cause angerer': {'e_trp.dobj': ''},
 'cease people': {'e_trp.dobj': ''},
 'cease patient': {'e_trp.dobj': ''},
 'causing crime': {'e_trp.dobj': ''},
 'cement building': {'e_trp.dobj': ''},
 'celebrate moon': {'e_trp.dobj': ''},
 'celebrate influent': {'e_trp.dobj': ''},
 'celebrate cake': {'e_trp.dobj': ''},
 'chance job': {'e_trp.dobj': ''},
 'challenge mystery': {'e_trp.dobj': ''},
 'censor goods': {'e_trp.dobj': ''},
 'change mortality': {'e_trp.dobj': ''},
 'change fob': {'e_trp.dobj': ''},
 'change farmland': {'e_trp.dobj': ''},
 'change criminal': {'e_trp.dobj': ''},
 'change ram': {'e_trp.dobj': ''},
 'change pleasure': {'e_trp.dobj': ''},
 'change pajama': {'e_trp.dobj': ''},
 'charge best': {'e_trp.dobj': ''},
 'character difficulty': {'e_trp.dobj': ''},
 'change tokenism': {'e_trp.dobj': ''},
 'change spon': {'e_trp.dobj': ''},
 'chat ect': {'e_trp.dobj': ''},
 'chase quickness': {'e_trp.dobj': ''},
 'charging water': {'e_trp.dobj': ''},
 'cheat money': {'e_trp.dobj': ''},
 'cheat invention': {'e_trp.dobj': ''},
 'cheat harm': {'e_trp.dobj': ''},
 'check_out factory': {'e_trp.dobj': ''},
 'check_in dictionary': {'e_trp.dobj': ''},
 'check commodity': {'e_trp.dobj': '', 'e_trp.nsv': ''},
 'cheat ugly': {'e_trp.dobj': ''},
 'cherish longevity': {'e_trp.dobj': ''},
 'class drove': {'e_trp.dobj': ''},
 'circulate resource': {'e_trp.dobj': ''},
 'choke boredom': {'e_trp.dobj': ''},
 'cherish row': {'e_trp.dobj': ''},
 'classify sport': {'e_trp.dobj': ''},
 'classify aim': {'e_trp.dobj': ''},
 'classify ability': {'e_trp.dobj': ''},
 'clean_up commodity': {'e_trp.dobj': ''},
 'cleaning squad': {'e_trp.dobj': ''},
 'clean commodity': {'e_trp.dobj': ''},
 'clear_out phenomenon': {'e_trp.dobj': ''},
 'clear no': {'e_trp.dobj': ''},
 'clear commodity': {'e_trp.dobj': ''},
 'clothe house': {'e_trp.dobj': ''},
 'clothe belt': {'e_trp.dobj': ''},
 'clock moon': {'e_trp.dobj': ''},
 'climb seed': {'e_trp.dobj': ''},
 'come eleven': {'e_trp.dobj': ''},
 'cold-shoulder child': {'e_trp.dobj': ''},
 'cloud pillar': {'e_trp.dobj': ''},
 'color air': {'e_trp.dobj': ''},
 'come balk': {'e_trp.dobj': ''},
 'come earth': {'e_trp.dobj': ''},
 'come foreigner': {'e_trp.dobj': ''},
 'come formality': {'e_trp.dobj': ''},
 'come full_moon': {'e_trp.dobj': ''},
 'collide tiger': {'e_trp.dobj': ''},
 'come materialist': {'e_trp.dobj': ''},
 'come island': {'e_trp.dobj': ''},
 'come huan': {'e_trp.dobj': ''},
 'come trice': {'e_trp.dobj': ''},
 'come past_tense': {'e_trp.dobj': ''},
 'come passenger': {'e_trp.dobj': ''},
 'command come': {'e_trp.dobj': ''},
 'come woth': {'e_trp.dobj': ''},
 'come william_tell': {'e_trp.dobj': ''},
 'come waste': {'e_trp.dobj': ''},
 'commence man': {'e_trp.dobj': ''},
 'commence gain': {'e_trp.dobj': ''},
 'commemorate fairy': {'e_trp.dobj': ''},
 'commiting kind': {'e_trp.dobj': ''},
 'commited disorder': {'e_trp.dobj': ''},
 'commit verdict': {'e_trp.dobj': ''},
 'company askes': {'e_trp.dobj': ''},
 'communicate teacher': {'e_trp.dobj': ''},
 'communicate reward': {'e_trp.dobj': ''},
 'complain condition': {'e_trp.dobj': ''},
 'compensate agony': {'e_trp.dobj': ''},
 'compare dictatorship': {'e_trp.dobj': ''},
 'complain step': {'e_trp.dobj': ''},
 'complain luck': {'e_trp.dobj': ''},
 'complain enterprise': {'e_trp.dobj': ''},
 'complement sentence': {'e_trp.dobj': ''},
 'complement expense': {'e_trp.dobj': ''},
 'complain word': {'e_trp.dobj': ''},
 'complain telephone': {'e_trp.dobj': ''},
 'complete high_dam': {'e_trp.dobj': ''},
 'complete existence': {'e_trp.dobj': ''},
 'complete equality': {'e_trp.dobj': ''},
 'concentrate strenth': {'e_trp.dobj': ''},
 'compose extended_family': {'e_trp.dobj': ''},
 'compose casualty': {'e_trp.dobj': ''},
 'concern femininity': {'e_trp.dobj': ''},
 'concern euthanasia': {'e_trp.dobj': ''},
 'confer citizen': {'e_trp.dobj': ''},
 'conduct cooperation': {'e_trp.dobj': ''},
 'conclude arm': {'e_trp.dobj': ''},
 'confront winner': {'e_trp.dobj': ''},
 'confine school': {'e_trp.dobj': ''},
 'confine criminal': {'e_trp.dobj': ''},
 'confess prison': {'e_trp.dobj': ''},
 'connect fate': {'e_trp.dobj': ''},
 'connect cadre': {'e_trp.dobj': ''},
 'connect boredom': {'e_trp.dobj': ''},
 'connect praise': {'e_trp.dobj': ''},
 'connect language': {'e_trp.dobj': ''},
 'connect feature': {'e_trp.dobj': ''},
 'conquer kuwait': {'e_trp.dobj': ''},
 'connect war': {'e_trp.dobj': ''},
 'connect sentence': {'e_trp.dobj': ''},
 'consider masculinity': {'e_trp.dobj': ''},
 'consider hell': {'e_trp.dobj': ''},
 'consider devotion': {'e_trp.dobj': ''},
 'conquer neighbour': {'e_trp.dobj': ''},
 'consist job': {'e_trp.dobj': ''},
 'consist army': {'e_trp.dobj': ''},
 'consider wether': {'e_trp.dobj': ''},
 'contact throught': {'e_trp.dobj': ''},
 'construct army': {'e_trp.dobj': ''},
 'consist soldier': {'e_trp.dobj': ''},
 'contend mark': {'e_trp.dobj': ''},
 'contain sedative': {'e_trp.dobj': ''},
 'contain mortality': {'e_trp.dobj': ''},
 'continue fei': {'e_trp.dobj': ''},
 'content subject': {'e_trp.dobj': ''},
 'content kind': {'e_trp.dobj': ''},
 'contend tear': {'e_trp.dobj': ''},
 'contrast pavement': {'e_trp.dobj': ''},
 'continue supper': {'e_trp.dobj': ''},
 'continue procession': {'e_trp.dobj': ''},
 'control industrial': {'e_trp.dobj': ''},
 'control euthanasia': {'e_trp.dobj': ''},
 'contrast time': {'e_trp.dobj': ''},
 'convert prairie': {'e_trp.dobj': ''},
 'controled fire': {'e_trp.dobj': ''},
 'cool_down furiousness': {'e_trp.dobj': ''},
 'cook computer': {'e_trp.dobj': ''},
 'cost quantity': {'e_trp.dobj': ''},
 'cost balance': {'e_trp.dobj': ''},
 'corrupt at': {'e_trp.dobj': ''},
 'cope measure': {'e_trp.dobj': ''},
 'course wisdom': {'e_trp.dobj': ''},
 'count figues': {'e_trp.dobj': ''},
 'cost yan': {'e_trp.dobj': ''},
 'crave come': {'e_trp.dobj': ''},
 'crash hare': {'e_trp.dobj': ''},
 'cover_up shoe': {'e_trp.dobj': ''},
 'cover_up evil': {'e_trp.dobj': ''},
 'criticise stop': {'e_trp.dobj': ''},
 'create find': {'e_trp.dobj': ''},
 'creasing water': {'e_trp.dobj': ''},
 'criticize water': {'e_trp.dobj': ''},
 'create pleat': {'e_trp.dobj': ''},
 'crisp potato_chip': {'e_trp.dobj': ''},
 'cry black': {'e_trp.dobj': ''},
 'crowd earth': {'e_trp.dobj': ''},
 'crop government': {'e_trp.dobj': ''},
 'cultivate forster': {'e_trp.dobj': ''},
 'cry_out match': {'e_trp.dobj': ''},
 'cry breeze': {'e_trp.dobj': ''},
 'cure cam': {'e_trp.dobj': ''},
 'curb ill-treatment': {'e_trp.dobj': ''},
 'cultivate temperament': {'e_trp.dobj': ''},
 'cultivate imaginativeness': {'e_trp.dobj': ''},
 'cut_down demand': {'e_trp.dobj': ''},
 'curse gob': {'e_trp.dobj': ''},
 'cure husband': {'e_trp.dobj': ''},
 'dazzle sunlight': {'e_trp.dobj': ''},
 'dance lantern': {'e_trp.dobj': ''},
 'cut_off grass': {'e_trp.dobj': ''},
 'cut_down rose': {'e_trp.dobj': ''},
 'decide hat': {'e_trp.dobj': ''},
 'deal imagination': {'e_trp.dobj': ''},
 'deaden cafe': {'e_trp.dobj': ''},
 'decide taste': {'e_trp.dobj': ''},
 'decide mountain': {'e_trp.dobj': ''},
 'decide lesson': {'e_trp.dobj': ''},
 'decide inferiority': {'e_trp.dobj': ''},
 'decrease good': {'e_trp.dobj': ''},
 'decrease example': {'e_trp.dobj': ''},
 'decline 100': {'e_trp.dobj': ''},
 'dedicate gain': {'e_trp.dobj': ''},
 'defeat gain': {'e_trp.dobj': ''},
 'defeat black_eye': {'e_trp.dobj': ''},
 'deem phanton': {'e_trp.dobj': ''},
 'deduce influence': {'e_trp.dobj': ''},
 'define opium': {'e_trp.dobj': ''},
 'define instrument': {'e_trp.dobj': ''},
 'defense country': {'e_trp.dobj': ''},
 'denounce commodity': {'e_trp.dobj': ''},
 'demonstrate education': {'e_trp.dobj': ''},
 'degrade money': {'e_trp.dobj': ''},
 'deny proverb': {'e_trp.dobj': ''},
 'deny commodity': {'e_trp.dobj': ''},
 'deprive freedom': {'e_trp.dobj': ''},
 'depress factory': {'e_trp.dobj': ''},
 'depend study': {'e_trp.dobj': ''},
 'depend education': {'e_trp.dobj': ''},
 'derive river': {'e_trp.dobj': ''},
 'deprive neighbour': {'e_trp.dobj': ''},
 'deprive hope': {'e_trp.dobj': ''},
 'desolate million': {'e_trp.dobj': ''},
 'desire evil': {'e_trp.dobj': ''},
 'deserve villain': {'e_trp.dobj': ''},
 'desert prisoner': {'e_trp.dobj': ''},
 'destroy viewer': {'e_trp.dobj': ''},
 'destroy gentleman': {'e_trp.dobj': ''},
 'destory example': {'e_trp.dobj': ''},
 'detect shrewdness': {'e_trp.dobj': ''},
 'detail second': {'e_trp.dobj': ''},
 'destruct nature': {'e_trp.dobj': ''},
 'develop dead': {'e_trp.dobj': ''},
 'develop construction': {'e_trp.dobj': ''},
 'determine birth': {'e_trp.dobj': ''},
 'devote thing': {'e_trp.dobj': ''},
 'develop patriotism': {'e_trp.dobj': ''},
 'develop morever': {'e_trp.dobj': ''},
 'develop defeat': {'e_trp.dobj': ''},
 'die crop': {'e_trp.dobj': ''},
 'die bobby': {'e_trp.dobj': ''},
 'devour area': {'e_trp.dobj': ''},
 'digest knowledge': {'e_trp.dobj': ''},
 'die_off friendship': {'e_trp.dobj': ''},
 'die tortoise': {'e_trp.dobj': ''},
 'diminish purchase': {'e_trp.dobj': ''},
 'diminish kuwait': {'e_trp.dobj': ''},
 'digest textbook': {'e_trp.dobj': ''},
 'disappoint felt': {'e_trp.dobj': ''},
 'disappear planet': {'e_trp.dobj': ''},
 'direct doing': {'e_trp.dobj': ''},
 'discover donkey': {'e_trp.dobj': ''},
 'disclose tiredness': {'e_trp.dobj': ''},
 'disclose commodity': {'e_trp.dobj': ''},
 'dismiss criminal': {'e_trp.dobj': ''},
 'dislike worst': {'e_trp.dobj': ''},
 'discover ingenuity': {'e_trp.dobj': ''},
 'disregard achievement': {'e_trp.dobj': ''},
 'display job': {'e_trp.dobj': ''},
 'disorder routine': {'e_trp.dobj': ''},
 'disturb step': {'e_trp.dobj': ''},
 'distinguish mercy_killing': {'e_trp.dobj': ''},
 'distinguish commodity': {'e_trp.dobj': ''},
 'divide crime': {'e_trp.dobj': ''},
 'divide aftermath': {'e_trp.dobj': ''},
 'disturb viewing': {'e_trp.dobj': ''},
 'do haid': {'e_trp.dobj': ''},
 'do euthanasia': {'e_trp.dobj': '', 'e_trp.nsv': ''},
 'do convenience': {'e_trp.dobj': ''},
 'do consistantly': {'e_trp.dobj': ''},
 'do lending_library': {'e_trp.dobj': ''},
 'do jot': {'e_trp.dobj': ''},
 'do huan': {'e_trp.dobj': ''},
 'do stuffing': {'e_trp.dobj': ''},
 'do sellings': {'e_trp.dobj': ''},
 'do population_control': {'e_trp.dobj': ''},
 'do metter': {'e_trp.dobj': ''},
 'do ut': {'e_trp.dobj': ''},
 'do ti': {'e_trp.dobj': ''},
 'do test_paper': {'e_trp.dobj': ''},
 'do_in housework': {'e_trp.dobj': ''},
 'do_in choice': {'e_trp.dobj': ''},
 'dot branch': {'e_trp.dobj': ''},
 'dominate organ': {'e_trp.dobj': ''},
 'dream process': {'e_trp.dobj': ''},
 'drag third_world': {'e_trp.dobj': ''},
 'do_up grup': {'e_trp.dobj': ''},
 'dress float': {'e_trp.dobj': ''},
 'dredge tunnel': {'e_trp.dobj': ''},
 'dream success': {'e_trp.dobj': ''},
 'drink anjou': {'e_trp.dobj': ''},
 'drill ability': {'e_trp.dobj': ''},
 'dress sell': {'e_trp.dobj': ''},
 'drive sleep': {'e_trp.dobj': ''},
 'drive private': {'e_trp.dobj': ''},
 'drink_in campus': {'e_trp.dobj': ''},
 'dub mercy_killing': {'e_trp.dobj': ''},
 'dub euthanasia': {'e_trp.dobj': ''},
 'droped success': {'e_trp.dobj': ''},
 'eat commodity': {'e_trp.dobj': ''},
 'earth nature': {'e_trp.dobj': ''},
 'ear sir': {'e_trp.dobj': ''},
 'eat heating': {'e_trp.dobj': ''},
 'eat gam': {'e_trp.dobj': ''},
 'eat elixir': {'e_trp.dobj': ''},
 'eat developing_country': {'e_trp.dobj': ''},
 'eat losts': {'e_trp.dobj': ''},
 'eat jiao': {'e_trp.dobj': ''},
 'eat hower': {'e_trp.dobj': ''},
 'eat xiao': {'e_trp.dobj': ''},
 'eat tang': {'e_trp.dobj': ''},
 'eat structure': {'e_trp.dobj': ''},
 'eat_up moon': {'e_trp.dobj': ''},
 'eat zozi': {'e_trp.dobj': ''},
 'eat zhong': {'e_trp.dobj': ''},
 'eat yuan': {'e_trp.dobj': ''},
 'educate law': {'e_trp.dobj': ''},
 'educate criticism': {'e_trp.dobj': ''},
 'economize water': {'e_trp.dobj': ''},
 'elimated commodity': {'e_trp.dobj': ''},
 'effect study': {'e_trp.dobj': ''},
 'effect person': {'e_trp.dobj': ''},
 'effect medicine': {'e_trp.dobj': ''},
 'emit harm': {'e_trp.dobj': ''},
 'eliminating word': {'e_trp.dobj': ''},
 'elimated procession': {'e_trp.dobj': ''},
 'encapsulate detail': {'e_trp.dobj': ''},
 'enable stay': {'e_trp.dobj': ''},
 'employ greeting_card': {'e_trp.dobj': ''},
 'employ anti': {'e_trp.dobj': ''},
 'english englishman': {'e_trp.dobj': ''},
 'english 30': {'e_trp.dobj': ''},
 'engage job': {'e_trp.dobj': ''},
 'enhance law': {'e_trp.dobj': ''},
 'english study': {'e_trp.dobj': ''},
 'enlarge property': {'e_trp.dobj': ''},
 'enlarge mediator': {'e_trp.dobj': ''},
 'enlarge establishment': {'e_trp.dobj': ''},
 'enjoy sweetness': {'e_trp.dobj': ''},
 'enrich experiment': {'e_trp.dobj': ''},
 'enlarge skill': {'e_trp.dobj': ''},
 'enter singer': {'e_trp.dobj': ''},
 'enter layer': {'e_trp.dobj': ''},
 'enter girl': {'e_trp.dobj': ''},
 'equiped university': {'e_trp.dobj': ''},
 'equate contribution': {'e_trp.dobj': ''},
 'equal bicycle': {'e_trp.dobj': ''},
 'escape mesh': {'e_trp.dobj': ''},
 'erect sense': {'e_trp.dobj': ''},
 'erase class': {'e_trp.dobj': ''},
 'estimating relation': {'e_trp.dobj': ''},
 'esteem parent': {'e_trp.dobj': ''},
 'establish legalization': {'e_trp.dobj': ''},
 'evoke lie': {'e_trp.dobj': ''},
 'even incense': {'e_trp.dobj': ''},
 'evade rain': {'e_trp.dobj': ''},
 'etc euthanasia': {'e_trp.dobj': ''},
 'examine mother': {'e_trp.dobj': ''},
 'examine greenhouse_effect': {'e_trp.dobj': ''},
 'excite government': {'e_trp.dobj': ''},
 'excise day': {'e_trp.dobj': ''},
 'excel woman': {'e_trp.dobj': ''},
 'exceed quality': {'e_trp.dobj': ''},
 'exert ability': {'e_trp.dobj': ''},
 'exercise citizen': {'e_trp.dobj': ''},
 'exciting space': {'e_trp.dobj': ''},
 'exert rest': {'e_trp.dobj': ''},
 'exert resource': {'e_trp.dobj': ''},
 'exert pleasure': {'e_trp.dobj': ''},
 'exist equality': {'e_trp.dobj': ''},
 'exist action': {'e_trp.dobj': ''},
 'exhaust water': {'e_trp.dobj': ''},
 'expect oh': {'e_trp.dobj': ''},
 'expect life_expectancy': {'e_trp.dobj': ''},
 'expand anguish': {'e_trp.dobj': ''},
 'experience low_tide': {'e_trp.dobj': ''},
 'experience hough': {'e_trp.dobj': ''},
 'expel criminal': {'e_trp.dobj': ''},
 'experiment life': {'e_trp.dobj': ''},
 'experiment expert': {'e_trp.dobj': ''},
 "experience new_year's_eve": {'e_trp.dobj': ''},
 'extend counter': {'e_trp.dobj': ''},
 'expose commodity': {'e_trp.dobj': ''},
 'experiment sentence': {'e_trp.dobj': ''},
 'face chicken': {'e_trp.dobj': ''},
 'extricate self': {'e_trp.dobj': ''},
 'extinguish commodity': {'e_trp.dobj': ''},
 'extend wild': {'e_trp.dobj': ''},
 'face win': {'e_trp.dobj': ''},
 'face officals': {'e_trp.dobj': ''},
 'face fresh': {'e_trp.dobj': ''},
 'fail end': {'e_trp.dobj': ''},
 'fade boy': {'e_trp.dobj': ''},
 'factor water': {'e_trp.dobj': ''},
 'face_up problem': {'e_trp.dobj': ''},
 'fake family': {'e_trp.dobj': ''},
 'fair principal': {'e_trp.dobj': ''},
 'fail peter': {'e_trp.dobj': ''},
 'fasten owner': {'e_trp.dobj': ''},
 'fan_out spark': {'e_trp.dobj': ''},
 'fan factory': {'e_trp.dobj': ''},
 'familiarise ad': {'e_trp.dobj': ''},
 'favour life': {'e_trp.dobj': ''},
 'favour job': {'e_trp.dobj': ''},
 'favor county': {'e_trp.dobj': ''},
 'feel lesson': {'e_trp.dobj': ''},
 'feel composition': {'e_trp.dobj': ''},
 'feel aroud': {'e_trp.dobj': ''},
 'fear ache': {'e_trp.dobj': ''},
 'feel pond': {'e_trp.dobj': ''},
 'feel neighbor': {'e_trp.dobj': ''},
 'feel moon': {'e_trp.dobj': ''},
 'felt pocket': {'e_trp.dobj': ''},
 'fell ecause': {'e_trp.dobj': ''},
 'feel_out thought': {'e_trp.dobj': ''},
 'feel servel': {'e_trp.dobj': ''},
 'fill hoe': {'e_trp.dobj': ''},
 'fill filter': {'e_trp.dobj': ''},
 'field it': {'e_trp.dobj': ''},
 'find dest': {'e_trp.dobj': ''},
 'fill_in world': {'e_trp.dobj': ''},
 'fill violence': {'e_trp.dobj': ''},
 'fill onion': {'e_trp.dobj': ''},
 'find plight': {'e_trp.dobj': ''},
 'find othewise': {'e_trp.dobj': ''},
 'find leave': {'e_trp.dobj': ''},
 'find keep': {'e_trp.dobj': ''},
 'find_out ability': {'e_trp.dobj': ''},
 'find varity': {'e_trp.dobj': ''},
 'find spirt': {'e_trp.dobj': ''},
 'find_out water': {'e_trp.dobj': ''},
 'find_out cure': {'e_trp.dobj': ''},
 'find_out commodity': {'e_trp.dobj': ''},
 'find_out are': {'e_trp.dobj': ''},
 'fine robber': {'e_trp.dobj': ''},
 'fine light': {'e_trp.dobj': ''},
 'fine eye': {'e_trp.dobj': ''},
 'finish living': {'e_trp.dobj': ''},
 'finish labour': {'e_trp.dobj': ''},
 'finish granddaughter': {'e_trp.dobj': ''},
 'finish english': {'e_trp.dobj': ''},
 'fire pact': {'e_trp.dobj': ''},
 'finish procession': {'e_trp.dobj': ''},
 'fit post': {'e_trp.dobj': ''},
 'fit major': {'e_trp.dobj': ''},
 'fish disease': {'e_trp.dobj': ''},
 'flatter supervisor': {'e_trp.dobj': ''},
 'fix sind': {'e_trp.dobj': ''},
 'fit_in work': {'e_trp.dobj': ''},
 'fit_in job': {'e_trp.dobj': ''},
 'flesh air': {'e_trp.dobj': ''},
 'fleece milk': {'e_trp.dobj': ''},
 'flee form_class': {'e_trp.dobj': ''},
 'flog buttock': {'e_trp.dobj': ''},
 'flip trigger': {'e_trp.dobj': ''},
 'flesh mean': {'e_trp.dobj': ''},
 'flesh england': {'e_trp.dobj': ''},
 'follow heel': {'e_trp.dobj': ''},
 'fly moon': {'e_trp.dobj': ''},
 'fly fee': {'e_trp.dobj': ''},
 'fly cicada': {'e_trp.dobj': ''},
 'forbid commodity': {'e_trp.dobj': ''},
 'fondle head': {'e_trp.dobj': ''},
 'form psychology': {'e_trp.dobj': ''},
 'form death': {'e_trp.dobj': ''},
 'force still': {'e_trp.dobj': ''},
 'forbid flow': {'e_trp.dobj': ''},
 'forward lib': {'e_trp.dobj': ''},
 'formulate regretably': {'e_trp.dobj': ''},
 'formalize euthanasia': {'e_trp.dobj': ''},
 'free form': {'e_trp.dobj': ''},
 'fox example': {'e_trp.dobj': ''},
 'found athat': {'e_trp.dobj': ''},
 'frighten table': {'e_trp.dobj': ''},
 'frighten came': {'e_trp.dobj': ''},
 'fright water': {'e_trp.dobj': ''},
 'frequent female': {'e_trp.dobj': ''},
 'fulfil work': {'e_trp.dobj': ''},
 'fruit just': {'e_trp.dobj': ''},
 'frown eyebrow': {'e_trp.dobj': ''},
 'full heart': {'e_trp.dobj': ''},
 'full family': {'e_trp.dobj': ''},
 'full bangkok': {'e_trp.dobj': ''},
 'further friendship': {'e_trp.dobj': ''},
 'function result': {'e_trp.dobj': ''},
 'gain care': {'e_trp.dobj': ''},
 'gain ame': {'e_trp.dobj': ''},
 'gain aim': {'e_trp.dobj': ''},
 'further week': {'e_trp.dobj': ''},
 'gain mind': {'e_trp.dobj': ''},
 'gain invention': {'e_trp.dobj': ''},
 'gain fun': {'e_trp.dobj': ''},
 'gain conscious': {'e_trp.dobj': ''},
 'gain society': {'e_trp.dobj': ''},
 'gain nowdays': {'e_trp.dobj': ''},
 'gain mortality': {'e_trp.dobj': ''},
 'genting skyway': {'e_trp.dobj': ''},
 'gather_in river': {'e_trp.dobj': ''},
 'gape david': {'e_trp.dobj': ''},
 'gain surroundings': {'e_trp.dobj': ''},
 'get for_example': {'e_trp.dobj': ''},
 'get fond': {'e_trp.dobj': ''},
 'get dease': {'e_trp.dobj': ''},
 'get_along country': {'e_trp.dobj': ''},
 'get recreation': {'e_trp.dobj': ''},
 'get majesty': {'e_trp.dobj': ''},
 'get haemorrhage': {'e_trp.dobj': ''},
 'get_out campus': {'e_trp.dobj': ''},
 'get_in social': {'e_trp.dobj': ''},
 'get_back coming': {'e_trp.dobj': ''},
 'give fen': {'e_trp.dobj': ''},
 'get_through lash': {'e_trp.dobj': ''},
 'get_out tool': {'e_trp.dobj': ''},
 'give recommedation': {'e_trp.dobj': ''},
 'give physics': {'e_trp.dobj': ''},
 'give harvest': {'e_trp.dobj': ''},
 'give_in subject': {'e_trp.dobj': ''},
 'give_in chinese': {'e_trp.dobj': ''},
 'give smartness': {'e_trp.dobj': ''},
 'give se': {'e_trp.dobj': ''},
 'give_off thing': {'e_trp.dobj': ''},
 'giving cigarette': {'e_trp.dobj': ''},
 'give_up running': {'e_trp.dobj': ''},
 'give_out noise': {'e_trp.dobj': ''},
 'give_out lantern': {'e_trp.dobj': ''},
 'go inversion': {'e_trp.dobj': ''},
 'go great_wall': {'e_trp.dobj': ''},
 'glance material': {'e_trp.dobj': ''},
 'go thief': {'e_trp.dobj': ''},
 'go righ': {'e_trp.dobj': ''},
 'go quater': {'e_trp.dobj': ''},
 'go pity': {'e_trp.dobj': ''},
 'graduate society': {'e_trp.dobj': ''},
 'graduate factory': {'e_trp.dobj': ''},
 'go ver': {'e_trp.dobj': ''},
 'grasp sprit': {'e_trp.dobj': ''},
 'grasp scient': {'e_trp.dobj': ''},
 'grasp opportunies': {'e_trp.dobj': ''},
 'graduate team': {'e_trp.dobj': ''},
 'greet pleasure': {'e_trp.dobj': ''},
 'gray dead': {'e_trp.dobj': ''},
 'gratify attention': {'e_trp.dobj': ''},
 'grow standard': {'e_trp.dobj': ''},
 'grow intention': {'e_trp.dobj': ''},
 'grip chance': {'e_trp.dobj': ''},
 'grind world': {'e_trp.dobj': ''},
 'gulp part': {'e_trp.dobj': ''},
 'guess test': {'e_trp.dobj': ''},
 'grow standard_of_living': {'e_trp.dobj': ''},
 'halve sorrow': {'e_trp.dobj': ''},
 'habit bad': {'e_trp.dobj': ''},
 'gun outward': {'e_trp.dobj': ''},
 'handle lantern': {'e_trp.dobj': ''},
 'hand english': {'e_trp.dobj': ''},
 'happen train': {'e_trp.dobj': ''},
 'happen ii': {'e_trp.dobj': ''},
 'hang_up kind': {'e_trp.dobj': ''},
 'handle opium': {'e_trp.dobj': ''},
 'harm commodity': {'e_trp.dobj': ''},
 'harm are': {'e_trp.dobj': ''},
 'harden mind': {'e_trp.dobj': ''},
 'harm living': {'e_trp.dobj': ''},
 'harm honour': {'e_trp.dobj': ''},
 'harm feminism': {'e_trp.dobj': ''},
 'harm ear': {'e_trp.dobj': ''},
 'haste fell': {'e_trp.dobj': ''},
 'harm waste': {'e_trp.dobj': ''},
 'harm study': {'e_trp.dobj': ''},
 'harm physique': {'e_trp.dobj': ''},
 'haste lead': {'e_trp.dobj': ''},
 'haste haste': {'e_trp.dobj': ''},
 'haste guide': {'e_trp.dobj': ''},
 'haste waste': {'e_trp.dobj': ''},
 'haste time': {'e_trp.dobj': ''},
 'haste speed': {'e_trp.dobj': ''},
 'haste pace': {'e_trp.dobj': ''},
 'haul eyesight': {'e_trp.dobj': ''},
 'hate much': {'e_trp.dobj': ''},
 'haste work': {'e_trp.dobj': ''},
 'haste way': {'e_trp.dobj': ''},
 'have counteraction': {'e_trp.dobj': ''},
 'have bodys': {'e_trp.dobj': ''},
 'have ance': {'e_trp.dobj': ''},
 'have haste': {'e_trp.dobj': ''},
 'have gine': {'e_trp.dobj': ''},
 'have futher': {'e_trp.dobj': ''},
 'have eats': {'e_trp.dobj': ''},
 'have mang': {'e_trp.dobj': ''},
 'have luchy': {'e_trp.dobj': ''},
 'have lready': {'e_trp.dobj': ''},
 'have strick': {'e_trp.dobj': ''},
 'have servies': {'e_trp.dobj': ''},
 'have savage': {'e_trp.dobj': ''},
 'have oin': {'e_trp.dobj': ''},
 'have wwii': {'e_trp.dobj': ''},
 'have uselessness': {'e_trp.dobj': ''},
 'have tense': {'e_trp.dobj': ''},
 'hear blessing': {'e_trp.dobj': ''},
 'hear appetite': {'e_trp.dobj': ''},
 'head lesson': {'e_trp.dobj': ''},
 'have_on disagreement': {'e_trp.dobj': ''},
 'hear gigi': {'e_trp.dobj': ''},
 'hear friendship': {'e_trp.dobj': ''},
 'hear deed': {'e_trp.dobj': ''},
 'heart voice': {'e_trp.dobj': ''},
 'heart plate': {'e_trp.dobj': ''},
 'heart deal': {'e_trp.dobj': ''},
 'hear noice': {'e_trp.dobj': ''},
 'help self-improvement': {'e_trp.dobj': ''},
 'help bad': {'e_trp.dobj': ''},
 'heed are': {'e_trp.dobj': ''},
 'hide darkness': {'e_trp.dobj': ''},
 'hem paper': {'e_trp.dobj': ''},
 'hem letter': {'e_trp.dobj': ''},
 'help snake': {'e_trp.dobj': ''},
 'hit strick': {'e_trp.dobj': ''},
 'hit rmb': {'e_trp.dobj': ''},
 'hinder existence': {'e_trp.dobj': ''},
 'hill climb': {'e_trp.dobj': ''},
 'hold pat': {'e_trp.dobj': ''},
 'hold grandma': {'e_trp.dobj': ''},
 'hold electioneering': {'e_trp.dobj': ''},
 'hold_back legality': {'e_trp.dobj': ''},
 'hold ridiculous': {'e_trp.dobj': ''},
 'hold patriarch': {'e_trp.dobj': ''},
 'honour moon': {'e_trp.dobj': ''},
 'hold_up commodity': {'e_trp.dobj': '', 'e_trp.nsv': ''},
 'hold_on match': {'e_trp.dobj': ''},
 'hold_back wind': {'e_trp.dobj': ''},
 'hope friendship': {'e_trp.dobj': ''},
 'hope brother': {'e_trp.dobj': ''},
 'honour poet': {'e_trp.dobj': ''},
 'house payload': {'e_trp.dobj': ''},
 'house classmate': {'e_trp.dobj': ''},
 'hoping work': {'e_trp.dobj': ''},
 'hurry cave': {'e_trp.dobj': ''},
 'hurry bus': {'e_trp.dobj': ''},
 'hurry bag': {'e_trp.dobj': ''},
 'hug layer': {'e_trp.dobj': ''},
 'hurry ready': {'e_trp.dobj': ''},
 'hurry impostor': {'e_trp.dobj': ''},
 'hurry downstair': {'e_trp.dobj': ''},
 'identify commodity': {'e_trp.dobj': ''},
 'hurt passion': {'e_trp.dobj': ''},
 'hurry train': {'e_trp.dobj': ''},
 'hurry speed': {'e_trp.dobj': ''},
 'imagine maxim': {'e_trp.dobj': ''},
 'imagine detergent': {'e_trp.dobj': ''},
 'igg city': {'e_trp.dobj': ''},
 'identify euthanasia': {'e_trp.dobj': ''},
 'imprison life': {'e_trp.dobj': ''},
 'impress condition': {'e_trp.dobj': ''},
 'impact harvest': {'e_trp.dobj': ''},
 'improve infant': {'e_trp.dobj': ''},
 'improve horizon': {'e_trp.dobj': ''},
 'improve comprehensive': {'e_trp.dobj': ''},
 'improve assignment': {'e_trp.dobj': ''},
 'improve professional': {'e_trp.dobj': ''},
 'improve monochrome': {'e_trp.dobj': ''},
 'improve lever': {'e_trp.dobj': ''},
 'improve lesson': {'e_trp.dobj': ''},
 'increase etc': {'e_trp.dobj': ''},
 'increase basketball': {'e_trp.dobj': ''},
 'incarcerate three': {'e_trp.dobj': ''},
 'increase wordpower': {'e_trp.dobj': ''},
 'increase theme': {'e_trp.dobj': ''},
 'increase stander': {'e_trp.dobj': ''},
 'increase existence': {'e_trp.dobj': ''},
 'indicate nation': {'e_trp.dobj': ''},
 'indicate make': {'e_trp.dobj': ''},
 'increasing reason': {'e_trp.dobj': ''},
 'influnced earth': {'e_trp.dobj': ''},
 'influence mercy': {'e_trp.dobj': ''},
 'induce mercy_killing': {'e_trp.dobj': ''},
 'indict gain': {'e_trp.dobj': ''},
 'input procedure': {'e_trp.dobj': ''},
 'inherit cause': {'e_trp.dobj': ''},
 'ingratiate taste': {'e_trp.dobj': ''},
 'inspire self': {'e_trp.dobj': ''},
 'inspire colleages': {'e_trp.dobj': ''},
 'insist inhumanity': {'e_trp.dobj': ''},
 'inquire price': {'e_trp.dobj': ''},
 'instruct china': {'e_trp.dobj': ''},
 'instill girl': {'e_trp.dobj': ''},
 'install information': {'e_trp.dobj': ''},
 'invade benefit': {'e_trp.dobj': ''},
 'introduce rich': {'e_trp.dobj': ''},
 'introduce et': {'e_trp.dobj': ''},
 'interest eager': {'e_trp.dobj': ''},
 'invent commodity': {'e_trp.dobj': ''},
 'invent aircraft': {'e_trp.dobj': ''},
 'invade sky': {'e_trp.dobj': ''},
 'invade clock': {'e_trp.dobj': ''},
 'invent rmb': {'e_trp.dobj': ''},
 'invent invention': {'e_trp.dobj': ''},
 'invent daytime': {'e_trp.dobj': ''},
 'invigorate atmosphere': {'e_trp.dobj': ''},
 'invent ver': {'e_trp.dobj': ''},
 'jam bus': {'e_trp.dobj': ''},
 'jack telephone': {'e_trp.dobj': ''},
 'jack mike': {'e_trp.dobj': ''},
 'inviting controversy': {'e_trp.dobj': ''},
 'job lifes': {'e_trp.dobj': ''},
 'job feeling': {'e_trp.dobj': ''},
 'job favore': {'e_trp.dobj': ''},
 'jam ordinary': {'e_trp.dobj': ''},
 'join active': {'e_trp.dobj': ''},
 'job throught': {'e_trp.dobj': ''},
 'job pursuer': {'e_trp.dobj': ''},
 'join server': {'e_trp.dobj': ''},
 'join serve': {'e_trp.dobj': ''},
 'join middle_school': {'e_trp.dobj': ''},
 'join match': {'e_trp.dobj': ''},
 'jump rest': {'e_trp.dobj': ''},
 'jump peter': {'e_trp.dobj': ''},
 'jump lesson': {'e_trp.dobj': ''},
 'jump hill': {'e_trp.dobj': ''},
 'keep confortable': {'e_trp.dobj': ''},
 'keep commodity': {'e_trp.dobj': ''},
 'keen rest': {'e_trp.dobj': ''},
 'keep sovereign': {'e_trp.dobj': ''},
 'keep pauling': {'e_trp.dobj': ''},
 'keep mooncakes': {'e_trp.dobj': ''},
 'keep good_nature': {'e_trp.dobj': ''},
 'keep_back blood': {'e_trp.dobj': ''},
 'keep_back advertisement': {'e_trp.dobj': ''},
 'keep wrongdoer': {'e_trp.dobj': ''},
 'keep_on recorder': {'e_trp.dobj': ''},
 'keep_on habit': {'e_trp.dobj': ''},
 'keep_in health': {'e_trp.dobj': ''},
 'keep_back smile': {'e_trp.dobj': ''},
 'kill aquitted': {'e_trp.dobj': ''},
 'keep_up mind': {'e_trp.dobj': ''},
 'keep_up bound': {'e_trp.dobj': ''},
 'knock policeman': {'e_trp.dobj': ''},
 'knife father': {'e_trp.dobj': ''},
 'kill olds': {'e_trp.dobj': ''},
 'kill cheat': {'e_trp.dobj': ''},
 'know existance': {'e_trp.dobj': ''},
 'know curative': {'e_trp.dobj': ''},
 'knock_down mony': {'e_trp.dobj': ''},
 'know regularity': {'e_trp.dobj': ''},
 'know perfect': {'e_trp.dobj': ''},
 'know ouside': {'e_trp.dobj': ''},
 'last physical': {'e_trp.dobj': ''},
 'land moon': {'e_trp.dobj': ''},
 'lack rich': {'e_trp.dobj': ''},
 'know social': {'e_trp.dobj': ''},
 'lay role': {'e_trp.dobj': ''},
 'lawyer honour': {'e_trp.dobj': ''},
 'launch campain': {'e_trp.dobj': ''},
 'last sweat': {'e_trp.dobj': ''},
 'lean heart': {'e_trp.dobj': ''},
 'lean english': {'e_trp.dobj': ''},
 'leak secrecy': {'e_trp.dobj': ''},
 'lead st': {'e_trp.dobj': ''},
 'lean technology': {'e_trp.dobj': ''},
 'lean powder': {'e_trp.dobj': ''},
 'lean knowledge': {'e_trp.dobj': ''},
 'lean kitchen': {'e_trp.dobj': ''},
 'learn knowlege': {'e_trp.dobj': ''},
 'learn haircut': {'e_trp.dobj': ''},
 'learn commodity': {'e_trp.dobj': ''},
 'learn bee': {'e_trp.dobj': ''},
 'learn swimming': {'e_trp.dobj': ''},
 'learn object': {'e_trp.dobj': ''},
 'legalize comparison': {'e_trp.dobj': ''},
 'leave_behind crowd': {'e_trp.dobj': ''},
 'learn throught': {'e_trp.dobj': ''},
 'learn techology': {'e_trp.dobj': ''},
 'legalize pratice': {'e_trp.dobj': ''},
 'legalize oyo': {'e_trp.dobj': ''},
 'legalize law': {'e_trp.dobj': ''},
 'legalize effect': {'e_trp.dobj': ''},
 'lesson boy': {'e_trp.dobj': ''},
 'lessen gas': {'e_trp.dobj': ''},
 'legalize rise': {'e_trp.dobj': ''},
 'let cheat': {'e_trp.dobj': ''},
 'lesson study': {'e_trp.dobj': ''},
 'lesson japan': {'e_trp.dobj': ''},
 'lesson initiative': {'e_trp.dobj': ''},
 'lie_down hunter': {'e_trp.dobj': ''},
 'lie hometown': {'e_trp.dobj': ''},
 'let mark': {'e_trp.dobj': ''},
 'let importance': {'e_trp.dobj': ''},
 'line streetside': {'e_trp.dobj': ''},
 'limit vitality': {'e_trp.dobj': ''},
 'like haste': {'e_trp.dobj': ''},
 'light brilliant': {'e_trp.dobj': ''},
 'listen howl': {'e_trp.dobj': ''},
 'listen food': {'e_trp.dobj': ''},
 'listen folk_music': {'e_trp.dobj': ''},
 'listen text': {'e_trp.dobj': ''},
 'listen situation': {'e_trp.dobj': ''},
 'listen passage': {'e_trp.dobj': ''},
 'listen lesson': {'e_trp.dobj': ''},
 'live force': {'e_trp.dobj': ''},
 'live ecause': {'e_trp.dobj': ''},
 'live complant': {'e_trp.dobj': ''},
 'live cause': {'e_trp.dobj': '', 'e_trp.nsv': ''},
 'live hurry': {'e_trp.dobj': ''},
 'live how': {'e_trp.dobj': ''},
 'live happiness': {'e_trp.dobj': ''},
 'long cloth': {'e_trp.dobj': ''},
 'lock animal': {'e_trp.dobj': ''},
 'live university': {'e_trp.dobj': ''},
 'live stander': {'e_trp.dobj': ''},
 'look_up criminal': {'e_trp.dobj': ''},
 'look_on waterfall': {'e_trp.dobj': ''},
 'look second': {'e_trp.dobj': ''},
 'look mary': {'e_trp.dobj': ''},
 'lose earing': {'e_trp.dobj': ''},
 'loot china': {'e_trp.dobj': ''},
 'look_up reference_book': {'e_trp.dobj': ''},
 'look_up lamp': {'e_trp.dobj': ''},
 'lot life': {'e_trp.dobj': ''},
 'lot china': {'e_trp.dobj': ''},
 'maintain lifes': {'e_trp.dobj': ''},
 'maim nature': {'e_trp.dobj': ''},
 'lustrate strictness': {'e_trp.dobj': ''},
 'love collective': {'e_trp.dobj': ''},
 'make calme': {'e_trp.dobj': ''},
 'make beacuse': {'e_trp.dobj': ''},
 'major purpose': {'e_trp.dobj': ''},
 'make eyesight': {'e_trp.dobj': ''},
 'make excise': {'e_trp.dobj': ''},
 'make esp': {'e_trp.dobj': ''},
 'make contry': {'e_trp.dobj': ''},
 'make lifes': {'e_trp.dobj': ''},
 'make len': {'e_trp.dobj': ''},
 'make jiao': {'e_trp.dobj': ''},
 'make goodness': {'e_trp.dobj': ''},
 'make quitely': {'e_trp.dobj': ''},
 'make postman': {'e_trp.dobj': ''},
 'make mortality': {'e_trp.dobj': ''},
 'make sucessfully': {'e_trp.dobj': ''},
 'make secondly': {'e_trp.dobj': ''},
 'make respond': {'e_trp.dobj': ''},
 'make unequal': {'e_trp.dobj': ''},
 'make theirselves': {'e_trp.dobj': ''},
 'make synonym': {'e_trp.dobj': ''},
 'make_up cigarette': {'e_trp.dobj': ''},
 'make_up charm': {'e_trp.dobj': ''},
 'make_out water': {'e_trp.dobj': ''},
 'make_out endeavor': {'e_trp.dobj': ''},
 'maltreat salt': {'e_trp.dobj': ''},
 'make_up palace': {'e_trp.dobj': ''},
 'make_up laura': {'e_trp.dobj': ''},
 'make_up iceberg': {'e_trp.dobj': ''},
 'man invention': {'e_trp.dobj': ''},
 'man impression': {'e_trp.dobj': ''},
 'man example': {'e_trp.dobj': ''},
 'manage euthanasia': {'e_trp.dobj': ''},
 'man opportunity': {'e_trp.dobj': ''},
 'man mind': {'e_trp.dobj': ''},
 'man meaning': {'e_trp.dobj': ''},
 'mar class': {'e_trp.dobj': ''},
 'map_out law': {'e_trp.dobj': ''},
 'manufacture commodity': {'e_trp.dobj': ''},
 'manipulate rope': {'e_trp.dobj': ''},
 'mark felton': {'e_trp.dobj': ''},
 'mark cotton': {'e_trp.dobj': ''},
 'mar tue': {'e_trp.dobj': ''},
 'mar satuday': {'e_trp.dobj': ''},
 'match developement': {'e_trp.dobj': ''},
 'master development': {'e_trp.dobj': ''},
 'mass way': {'e_trp.dobj': ''},
 'marry nothing': {'e_trp.dobj': ''},
 'may best': {'e_trp.dobj': ''},
 'may basketball': {'e_trp.dobj': ''},
 'materialize human_being': {'e_trp.dobj': ''},
 'meet engels': {'e_trp.dobj': ''},
 'mean hotbed': {'e_trp.dobj': ''},
 'mean defence': {'e_trp.dobj': ''},
 'may knowledge': {'e_trp.dobj': ''},
 'meet surroundings': {'e_trp.dobj': ''},
 'meet human_nature': {'e_trp.dobj': ''},
 'meet exam': {'e_trp.dobj': ''},
 'meld iron': {'e_trp.dobj': ''},
 'meet touch': {'e_trp.dobj': ''},
 'meet ther': {'e_trp.dobj': ''},
 'memorize people': {'e_trp.dobj': ''},
 'memorize forebear': {'e_trp.dobj': ''},
 'memorize death': {'e_trp.dobj': ''},
 'merge kuwait': {'e_trp.dobj': ''},
 'mend boat': {'e_trp.dobj': ''},
 'memorize writer': {'e_trp.dobj': ''},
 'mistake right': {'e_trp.dobj': ''},
 'mislead behaviour': {'e_trp.dobj': ''},
 'mind theft': {'e_trp.dobj': ''},
 'moralize people': {'e_trp.dobj': ''},
 'moralize folly': {'e_trp.dobj': ''},
 'monopolize price': {'e_trp.dobj': ''},
 'mumbling number': {'e_trp.dobj': ''},
 'mud water': {'e_trp.dobj': ''},
 'mount ship': {'e_trp.dobj': ''},
 'mould temperament': {'e_trp.dobj': ''},
 'must advice': {'e_trp.dobj': ''},
 'mush water': {'e_trp.dobj': ''},
 'murder chance': {'e_trp.dobj': ''},
 'must health': {'e_trp.dobj': ''},
 'must direction': {'e_trp.dobj': ''},
 'must develope': {'e_trp.dobj': ''},
 'must works': {'e_trp.dobj': ''},
 'must water': {'e_trp.dobj': ''},
 'must reading': {'e_trp.dobj': ''},
 'need comprehension': {'e_trp.dobj': ''},
 'narrow_down reward': {'e_trp.dobj': ''},
 'name gessler': {'e_trp.dobj': ''},
 'muster boll': {'e_trp.dobj': ''},
 'neglect capacity': {'e_trp.dobj': ''},
 'need procession': {'e_trp.dobj': ''},
 'need occupation': {'e_trp.dobj': ''},
 'nickname class': {'e_trp.dobj': ''},
 'neighbour water': {'e_trp.dobj': ''},
 'neglect shout': {'e_trp.dobj': ''},
 'nourish night': {'e_trp.dobj': ''},
 'notice productivity': {'e_trp.dobj': ''},
 'northen china': {'e_trp.dobj': ''},
 'obey method': {'e_trp.dobj': ''},
 'obey fact': {'e_trp.dobj': ''},
 'nudge pathway': {'e_trp.dobj': ''},
 'observe yuan': {'e_trp.dobj': ''},
 'object independence': {'e_trp.dobj': ''},
 'obey morality': {'e_trp.dobj': ''},
 'occupy love': {'e_trp.dobj': ''},
 'occupy judge': {'e_trp.dobj': ''},
 'obtain gaol': {'e_trp.dobj': ''},
 'open clinique': {'e_trp.dobj': ''},
 'open chaper': {'e_trp.dobj': ''},
 'off right': {'e_trp.dobj': ''},
 'occured kind': {'e_trp.dobj': ''},
 'open washer': {'e_trp.dobj': ''},
 'open knowledge': {'e_trp.dobj': ''},
 'organize boat_race': {'e_trp.dobj': ''},
 'organise soldier': {'e_trp.dobj': ''},
 'open_up sight': {'e_trp.dobj': ''},
 'out armchair': {'e_trp.dobj': ''},
 'ought shirt': {'e_trp.dobj': ''},
 'ought boy': {'e_trp.dobj': ''},
 'overhear novel': {'e_trp.dobj': ''},
 'out recorder': {'e_trp.dobj': ''},
 'out commodity': {'e_trp.dobj': ''},
 'out campus': {'e_trp.dobj': ''},
 'overthrow rich': {'e_trp.dobj': ''},
 'overrule letter': {'e_trp.dobj': ''},
 'overlook elderly': {'e_trp.dobj': ''},
 'own characteristic': {'e_trp.dobj': ''},
 'owe skill': {'e_trp.dobj': ''},
 'own tyson': {'e_trp.dobj': ''},
 'own sum': {'e_trp.dobj': ''},
 'own richness': {'e_trp.dobj': ''},
 'part homeland': {'e_trp.dobj': ''},
 'paralyse mind': {'e_trp.dobj': ''},
 'pamper wrongdoer': {'e_trp.dobj': ''},
 'owning eye': {'e_trp.dobj': ''},
 'pass william_tell': {'e_trp.dobj': ''},
 'pass jim': {'e_trp.dobj': ''},
 'pass ear': {'e_trp.dobj': ''},
 'pass commodity': {'e_trp.dobj': ''},
 'patronize staircase': {'e_trp.dobj': ''},
 'patch pair': {'e_trp.dobj': ''},
 'paste back': {'e_trp.dobj': ''},
 'pen ruler': {'e_trp.dobj': ''},
 'peep moon': {'e_trp.dobj': ''},
 'pay_out die': {'e_trp.dobj': ''},
 'pay praise': {'e_trp.dobj': ''},
 'people chang': {'e_trp.dobj': ''},
 'people behavor': {'e_trp.dobj': ''},
 'people ability': {'e_trp.dobj': ''},
 'people knowledge': {'e_trp.dobj': ''},
 'people happiness': {'e_trp.dobj': ''},
 'people cigarette': {'e_trp.dobj': ''},
 'people chrismas': {'e_trp.dobj': ''},
 'people mercy_killing': {'e_trp.dobj': ''},
 'people lion': {'e_trp.dobj': ''},
 'people lantern': {'e_trp.dobj': ''},
 'people throat': {'e_trp.dobj': ''},
 'people protection': {'e_trp.dobj': ''},
 'perfect worry': {'e_trp.dobj': ''},
 'perceive theory': {'e_trp.dobj': ''},
 'people wili': {'e_trp.dobj': ''},
 'permit probability': {'e_trp.dobj': ''},
 'perform finger': {'e_trp.dobj': ''},
 'perform associate_professor': {'e_trp.dobj': ''},
 'phone locksmith': {'e_trp.dobj': ''},
 'persued thing': {'e_trp.dobj': ''},
 'persuade criminal': {'e_trp.dobj': ''},
 'permit set': {'e_trp.dobj': ''},
 'pick_up mote': {'e_trp.dobj': ''},
 'pick_out soon': {'e_trp.dobj': ''},
 'picknicking park': {'e_trp.dobj': ''},
 'plan living': {'e_trp.dobj': ''},
 'plan commodity': {'e_trp.dobj': ''},
 'place gourd': {'e_trp.dobj': ''},
 'pique dignity': {'e_trp.dobj': ''},
 'plant planting': {'e_trp.dobj': ''},
 'plant moral': {'e_trp.dobj': ''},
 'plan ping': {'e_trp.dobj': ''},
 'play self-improvement': {'e_trp.dobj': ''},
 'play matchs': {'e_trp.dobj': ''},
 'play lantern': {'e_trp.dobj': ''},
 'plat crop': {'e_trp.dobj': ''},
 'pocket meal_ticket': {'e_trp.dobj': ''},
 'plead rain': {'e_trp.dobj': ''},
 'play smoking': {'e_trp.dobj': ''},
 'poison groan': {'e_trp.dobj': ''},
 'point influent': {'e_trp.dobj': ''},
 'point corner': {'e_trp.dobj': ''},
 'pollute kind': {'e_trp.dobj': ''},
 'pollute factor': {'e_trp.dobj': ''},
 'pollute amount': {'e_trp.dobj': ''},
 'police training_school': {'e_trp.dobj': ''},
 'pollute million': {'e_trp.dobj': ''},
 'pollute rain': {'e_trp.dobj': ''},
 'pollute quantity': {'e_trp.dobj': ''},
 'pollute number': {'e_trp.dobj': ''},
 'popularize masterpiece': {'e_trp.dobj': ''},
 'pop platter': {'e_trp.dobj': ''},
 'pollute worst': {'e_trp.dobj': ''},
 'practice bike': {'e_trp.dobj': ''},
 'power enable': {'e_trp.dobj': ''},
 'pour basin': {'e_trp.dobj': ''},
 'possess certification': {'e_trp.dobj': ''},
 'practice ist': {'e_trp.dobj': ''},
 'practice closing': {'e_trp.dobj': ''},
 'practice boxer': {'e_trp.dobj': ''},
 'practise body': {'e_trp.dobj': ''},
 'practice service': {'e_trp.dobj': ''},
 'practice perfect': {'e_trp.dobj': ''},
 'practise humanitarianism': {'e_trp.dobj': ''},
 'practise fake': {'e_trp.dobj': ''},
 'practise experience': {'e_trp.dobj': ''},
 'practise practice': {'e_trp.dobj': ''},
 'practise need': {'e_trp.dobj': ''},
 'practise teacher': {'e_trp.dobj': ''},
 'practise service': {'e_trp.dobj': ''},
 'practise reading': {'e_trp.dobj': ''},
 'preach pluralism': {'e_trp.dobj': ''},
 'practise violence': {'e_trp.dobj': ''},
 'practise time': {'e_trp.dobj': '', 'e_trp.nsv': ''},
 'prepare adquately': {'e_trp.dobj': ''},
 'preach society': {'e_trp.dobj': ''},
 'preach point_of_view': {'e_trp.dobj': ''},
 'present negroes': {'e_trp.dobj': ''},
 'prepare new_year': {'e_trp.dobj': ''},
 'prepare boot': {'e_trp.dobj': ''},
 'pretend cloth': {'e_trp.dobj': ''},
 'pretend cheat': {'e_trp.dobj': ''},
 'preserve woman': {'e_trp.dobj': ''},
 'preserve punishment': {'e_trp.dobj': ''},
 'prevent dub': {'e_trp.dobj': ''},
 'prevent die': {'e_trp.dobj': ''},
 'prevent clock': {'e_trp.dobj': ''},
 'produce motorcar': {'e_trp.dobj': ''},
 'print writing': {'e_trp.dobj': ''},
 'prevent resource': {'e_trp.dobj': ''},
 'prevent outlaw': {'e_trp.dobj': ''},
 'prohibit water': {'e_trp.dobj': ''},
 'profit purpose': {'e_trp.dobj': ''},
 'produce unfitness': {'e_trp.dobj': ''},
 'prolonging person': {'e_trp.dobj': ''},
 'prolong mean': {'e_trp.dobj': ''},
 'prolong injection': {'e_trp.dobj': ''},
 'project assay': {'e_trp.dobj': ''},
 'proof courage': {'e_trp.dobj': ''},
 'promise wish': {'e_trp.dobj': ''},
 'promise palace': {'e_trp.dobj': ''},
 'protect punishment': {'e_trp.dobj': ''},
 'prostituting thing': {'e_trp.dobj': ''},
 'propel death': {'e_trp.dobj': ''},
 'propagate football': {'e_trp.dobj': ''},
 'prove suspect': {'e_trp.dobj': ''},
 'prove perfect': {'e_trp.dobj': ''},
 'protest homeland': {'e_trp.dobj': ''},
 'punish commodity': {'e_trp.dobj': '', 'e_trp.nsv': ''},
 'publicize marxism': {'e_trp.dobj': ''},
 'provide vacancy': {'e_trp.dobj': ''},
 'punish frake': {'e_trp.dobj': ''},
 'punish fake': {'e_trp.dobj': ''},
 'punish tell': {'e_trp.dobj': ''},
 'punish minute': {'e_trp.dobj': ''},
 'punish indignation': {'e_trp.dobj': ''},
 'punish ill': {'e_trp.dobj': ''},
 'pursue cultivation': {'e_trp.dobj': ''},
 'punish william_tell': {'e_trp.dobj': ''},
 'pursue turn': {'e_trp.dobj': ''},
 'pursue sun': {'e_trp.dobj': ''},
 'pursue haste': {'e_trp.dobj': ''},
 'put coon': {'e_trp.dobj': ''},
 'push commodity': {'e_trp.dobj': ''},
 'pursuing valuable': {'e_trp.dobj': ''},
 'put offsprings': {'e_trp.dobj': ''},
 'put examination': {'e_trp.dobj': ''},
 'put euthanasia': {'e_trp.dobj': ''},
 'put termite': {'e_trp.dobj': ''},
 'put suffering': {'e_trp.dobj': ''},
 'put paula': {'e_trp.dobj': ''},
 'put_away sort': {'e_trp.dobj': ''},
 'put_aside quality': {'e_trp.dobj': ''},
 'putting item': {'e_trp.dobj': ''},
 'put_in rew': {'e_trp.dobj': ''},
 'put_forward euthanasia': {'e_trp.dobj': ''},
 'put_down crime': {'e_trp.dobj': ''},
 'put_out grass': {'e_trp.dobj': ''},
 'put_on jack': {'e_trp.dobj': ''},
 'put_on hope': {'e_trp.dobj': ''},
 'qualifed are': {'e_trp.dobj': ''},
 'puzzle honor': {'e_trp.dobj': ''},
 'put_up air': {'e_trp.dobj': ''},
 'rain en': {'e_trp.dobj': ''},
 'rain amount': {'e_trp.dobj': ''},
 'quilt study': {'e_trp.dobj': ''},
 'quicken death': {'e_trp.dobj': ''},
 'rain school': {'e_trp.dobj': ''},
 'rain river': {'e_trp.dobj': ''},
 'rain pointing': {'e_trp.dobj': ''},
 'raise arguement': {'e_trp.dobj': ''},
 'raining water': {'e_trp.dobj': ''},
 'ravage ground': {'e_trp.dobj': ''},
 'raising holiday': {'e_trp.dobj': ''},
 'raise argumentation': {'e_trp.dobj': ''},
 'reach spade': {'e_trp.dobj': ''},
 'reach downstairs': {'e_trp.dobj': ''},
 'react ball': {'e_trp.dobj': ''},
 'reach_out grove': {'e_trp.dobj': ''},
 'reach_out coin': {'e_trp.dobj': ''},
 'reach twenty': {'e_trp.dobj': ''},
 'read sth': {'e_trp.dobj': ''},
 'read massage': {'e_trp.dobj': ''},
 'read jack': {'e_trp.dobj': ''},
 'realise tradition': {'e_trp.dobj': ''},
 'realise relationship': {'e_trp.dobj': ''},
 'ready courage': {'e_trp.dobj': ''},
 'readjust behavior': {'e_trp.dobj': ''},
 'realize heart': {'e_trp.dobj': ''},
 'realize unhappiness': {'e_trp.dobj': ''},
 'realize society': {'e_trp.dobj': ''},
 'realize school': {'e_trp.dobj': ''},
 'realize maternity': {'e_trp.dobj': ''},
 'receive contentment': {'e_trp.dobj': ''},
 'receipt life': {'e_trp.dobj': ''},
 'recall former': {'e_trp.dobj': ''},
 'recieved opinion': {'e_trp.dobj': ''},
 'recieved education': {'e_trp.dobj': ''},
 'recieved answer': {'e_trp.dobj': ''},
 'receive visual': {'e_trp.dobj': ''},
 'recite cet': {'e_trp.dobj': ''},
 'recite advertisement': {'e_trp.dobj': ''},
 'recieving news': {'e_trp.dobj': ''},
 'recognize commodity': {'e_trp.dobj': ''},
 'reckon uncle': {'e_trp.dobj': ''},
 'recived card': {'e_trp.dobj': ''},
 'recollect segment': {'e_trp.dobj': ''},
 'recollect hurt': {'e_trp.dobj': ''},
 'recognize euthanasia': {'e_trp.dobj': ''},
 'reduce casulties': {'e_trp.dobj': ''},
 'redouble exertion': {'e_trp.dobj': ''},
 'recycle think': {'e_trp.dobj': ''},
 'record everyday': {'e_trp.dobj': ''},
 'reel silk': {'e_trp.dobj': ''},
 'reduce happening': {'e_trp.dobj': ''},
 'reduce clause': {'e_trp.dobj': '', 'e_trp.nsv': ''},
 'reform take': {'e_trp.dobj': ''},
 'reform opportunity': {'e_trp.dobj': ''},
 'reflect de': {'e_trp.dobj': ''},
 'refuse attraction': {'e_trp.dobj': ''},
 'refresh idea': {'e_trp.dobj': ''},
 'refrain jollity': {'e_trp.dobj': ''},
 'refuse tear': {'e_trp.dobj': ''},
 'refuse success': {'e_trp.dobj': ''},
 'refuse graduate': {'e_trp.dobj': ''},
 'refuse commodity': {'e_trp.dobj': '', 'e_trp.nsv': ''},
 'regard homeland': {'e_trp.dobj': ''},
 'regard euthanasia': {'e_trp.dobj': ''},
 'refuse warning': {'e_trp.dobj': ''},
 'regard total': {'e_trp.dobj': ''},
 'regard peasant': {'e_trp.dobj': ''},
 'regard lesson': {'e_trp.dobj': ''},
 'reject leaver': {'e_trp.dobj': ''},
 'reject commodity': {'e_trp.dobj': ''},
 'rehabilitate society': {'e_trp.dobj': '', 'e_trp.nsv': ''},
 'regard willow': {'e_trp.dobj': ''},
 'relieve result': {'e_trp.dobj': ''},
 'relax spirit': {'e_trp.dobj': ''},
 'relax pain': {'e_trp.dobj': ''},
 'remember perfect': {'e_trp.dobj': ''},
 'remember haste': {'e_trp.dobj': ''},
 'remake thank_you': {'e_trp.dobj': ''},
 'render knowledge': {'e_trp.dobj': ''},
 'remold ideology': {'e_trp.dobj': ''},
 'remember practise': {'e_trp.dobj': ''},
 'replace farmhouse': {'e_trp.dobj': ''},
 'repel commodity': {'e_trp.dobj': ''},
 'repay kiss': {'e_trp.dobj': ''},
 'reproduce father': {'e_trp.dobj': ''},
 'represent greeting': {'e_trp.dobj': ''},
 'reply chicken': {'e_trp.dobj': ''},
 'require fax': {'e_trp.dobj': ''},
 'request skill': {'e_trp.dobj': ''},
 'reproduce sheep': {'e_trp.dobj': ''},
 'reproduce person': {'e_trp.dobj': ''},
 'resettle habitant': {'e_trp.dobj': ''},
 'rescue whe': {'e_trp.dobj': ''},
 'rescue temple': {'e_trp.dobj': ''},
 'respect male': {'e_trp.dobj': ''},
 'respect fruit': {'e_trp.dobj': ''},
 'resist harm': {'e_trp.dobj': ''},
 'resist commodity': {'e_trp.dobj': ''},
 'rest do': {'e_trp.dobj': ''},
 'respect respond': {'e_trp.dobj': ''},
 'respect night': {'e_trp.dobj': ''},
 'retain sweat': {'e_trp.dobj': ''},
 'retain scenery': {'e_trp.dobj': ''},
 'restore criminal': {'e_trp.dobj': ''},
 'restore cleaner': {'e_trp.dobj': ''},
 'reveal manor': {'e_trp.dobj': ''},
 'revalue mean': {'e_trp.dobj': ''},
 'reunite festival': {'e_trp.dobj': ''},
 'reward riddle': {'e_trp.dobj': ''},
 'reward good_will': {'e_trp.dobj': ''},
 'revenge criminal': {'e_trp.dobj': ''},
 'ride guangzhou': {'e_trp.dobj': ''},
 'ride everyday': {'e_trp.dobj': ''},
 'rid lantern': {'e_trp.dobj': ''},
 'rid businessman': {'e_trp.dobj': ''},
 'ring fire_fighter': {'e_trp.dobj': ''},
 'ring firefighter': {'e_trp.dobj': ''},
 'right behind': {'e_trp.dobj': ''},
 'rise pong': {'e_trp.dobj': ''},
 'rinse distress': {'e_trp.dobj': ''},
 'ring year': {'e_trp.dobj': ''},
 'ring walk': {'e_trp.dobj': ''},
 'root_out malady': {'e_trp.dobj': ''},
 'rob riches': {'e_trp.dobj': ''},
 'risk adventure': {'e_trp.dobj': ''},
 'rustle atmosphere': {'e_trp.dobj': ''},
 'rule age': {'e_trp.dobj': ''},
 'ruin aunt': {'e_trp.dobj': ''},
 'round fat': {'e_trp.dobj': ''},
 'satisfy job': {'e_trp.dobj': ''},
 'save electicity': {'e_trp.dobj': ''},
 'satisfy walk': {'e_trp.dobj': ''},
 'satisfy personality': {'e_trp.dobj': ''},
 'say thay': {'e_trp.dobj': ''},
 'say imagination': {'e_trp.dobj': ''},
 'saw kind': {'e_trp.dobj': ''},
 'save shortage': {'e_trp.dobj': ''},
 'second cloudy': {'e_trp.dobj': ''},
 'school code': {'e_trp.dobj': ''},
 'say victor_hugo': {'e_trp.dobj': ''},
 'see cheat': {'e_trp.dobj': ''},
 'see bron': {'e_trp.dobj': ''},
 'see belove': {'e_trp.dobj': ''},
 'second law': {'e_trp.dobj': ''},
 'see feasibility': {'e_trp.dobj': ''},
 'see eclips': {'e_trp.dobj': ''},
 'see creepshow': {'e_trp.dobj': ''},
 'see confinement': {'e_trp.dobj': ''},
 'see life_expectancy': {'e_trp.dobj': ''},
 'see flim': {'e_trp.dobj': ''},
 'see stange': {'e_trp.dobj': ''},
 'see proverb': {'e_trp.dobj': ''},
 'see pour': {'e_trp.dobj': ''},
 'see notice_board': {'e_trp.dobj': ''},
 'sell wether': {'e_trp.dobj': ''},
 'select ability': {'e_trp.dobj': ''},
 'seize sight': {'e_trp.dobj': ''},
 'seize bell': {'e_trp.dobj': ''},
 'see_through distribution': {'e_trp.dobj': ''},
 'sentence loss': {'e_trp.dobj': ''},
 'send earth': {'e_trp.dobj': ''},
 'serve header': {'e_trp.dobj': ''},
 'serve happiness': {'e_trp.dobj': ''},
 'sentence rest': {'e_trp.dobj': ''},
 'sentence negro': {'e_trp.dobj': ''},
 'service society': {'e_trp.dobj': ''},
 'serve schemer': {'e_trp.dobj': ''},
 'serve patriotism': {'e_trp.dobj': ''},
 'serve knowledge': {'e_trp.dobj': ''},
 'set_aside 15th': {'e_trp.dobj': ''},
 'settle shoud': {'e_trp.dobj': ''},
 'settle mercy_killing': {'e_trp.dobj': ''},
 'settle fortune': {'e_trp.dobj': ''},
 'set_up personality': {'e_trp.dobj': ''},
 'set_up frag': {'e_trp.dobj': ''},
 'set_up aim': {'e_trp.dobj': ''},
 'set_on criminal': {'e_trp.dobj': ''},
 'shake_off concept': {'e_trp.dobj': ''},
 'shake development': {'e_trp.dobj': ''},
 'set_up russia': {'e_trp.dobj': ''},
 'shall environment': {'e_trp.dobj': ''},
 'shall considerable': {'e_trp.dobj': ''},
 'shall alway': {'e_trp.dobj': ''},
 'shall job': {'e_trp.dobj': ''},
 'shall haste': {'e_trp.dobj': ''},
 'shall goods': {'e_trp.dobj': ''},
 'shall familiar': {'e_trp.dobj': ''},
 'shall remains': {'e_trp.dobj': ''},
 'shall purity': {'e_trp.dobj': ''},
 'shall understanding': {'e_trp.dobj': ''},
 'shall teacher': {'e_trp.dobj': ''},
 'shall rich': {'e_trp.dobj': ''},
 'shave power': {'e_trp.dobj': ''},
 'shave fist': {'e_trp.dobj': ''},
 'shaping grave': {'e_trp.dobj': ''},
 'shall water': {'e_trp.dobj': ''},
 'shine swimming_pool': {'e_trp.dobj': ''},
 'shin turn': {'e_trp.dobj': ''},
 'shift sum': {'e_trp.dobj': ''},
 'shoot shot_put': {'e_trp.dobj': ''},
 'shoot shop': {'e_trp.dobj': ''},
 'shoot shill': {'e_trp.dobj': ''},
 'shout breaking': {'e_trp.dobj': ''},
 'shorten torture': {'e_trp.dobj': ''},
 'short ear': {'e_trp.dobj': ''},
 'shopping apple': {'e_trp.dobj': ''},
 'shout savage': {'e_trp.dobj': ''},
 'shout fine': {'e_trp.dobj': ''},
 'shout emperor': {'e_trp.dobj': ''},
 'side courage': {'e_trp.dobj': ''},
 'sick peace': {'e_trp.dobj': ''},
 'show lament': {'e_trp.dobj': ''},
 'shout_out sentence': {'e_trp.dobj': ''},
 'sing blessing': {'e_trp.dobj': ''},
 'sign_in crowd': {'e_trp.dobj': ''},
 'sight gleam': {'e_trp.dobj': ''},
 'sit armchair': {'e_trp.dobj': ''},
 'single dear': {'e_trp.dobj': ''},
 'sing someome': {'e_trp.dobj': ''},
 'sit smoker': {'e_trp.dobj': ''},
 'sit moon': {'e_trp.dobj': ''},
 'sit dow': {'e_trp.dobj': ''},
 'sit classroom': {'e_trp.dobj': ''},
 'slave machine': {'e_trp.dobj': ''},
 'sit_in dog': {'e_trp.dobj': ''},
 'smell tinge': {'e_trp.dobj': ''},
 'smash first': {'e_trp.dobj': ''},
 'sleep daytime': {'e_trp.dobj': ''},
 'sleep consciousness': {'e_trp.dobj': ''},
 'smoke place': {'e_trp.dobj': ''},
 'smoke chance': {'e_trp.dobj': ''},
 'smile tome': {'e_trp.dobj': ''},
 'soak life': {'e_trp.dobj': ''},
 'soak battlefield': {'e_trp.dobj': ''},
 'smoke_out country': {'e_trp.dobj': ''},
 'solve practise': {'e_trp.dobj': ''},
 'solve haste': {'e_trp.dobj': ''},
 'solve food': {'e_trp.dobj': ''},
 'soar tourist': {'e_trp.dobj': ''},
 'spare english': {'e_trp.dobj': ''},
 'sow bend': {'e_trp.dobj': ''},
 'sound at': {'e_trp.dobj': ''},
 'speak situation': {'e_trp.dobj': ''},
 'speak quick': {'e_trp.dobj': ''},
 'speak practice': {'e_trp.dobj': ''},
 'speak dictation': {'e_trp.dobj': ''},
 'specialize soldier': {'e_trp.dobj': ''},
 'specialize ect': {'e_trp.dobj': ''},
 'speak use': {'e_trp.dobj': ''},
 'spoil producer': {'e_trp.dobj': ''},
 'spite job': {'e_trp.dobj': ''},
 'spend litle': {'e_trp.dobj': ''},
 'spend beijing': {'e_trp.dobj': ''},
 'square assign': {'e_trp.dobj': ''},
 'spread dig': {'e_trp.dobj': ''},
 'sprain hen': {'e_trp.dobj': ''},
 'stand fate': {'e_trp.dobj': ''},
 'stand english': {'e_trp.dobj': ''},
 'stand denouncement': {'e_trp.dobj': ''},
 'squeeze earth': {'e_trp.dobj': ''},
 'stand nan': {'e_trp.dobj': ''},
 'stand laugh': {'e_trp.dobj': ''},
 'stand homeland': {'e_trp.dobj': ''},
 'stare full_moon': {'e_trp.dobj': ''},
 'stare footprint': {'e_trp.dobj': ''},
 'stand_up grandma': {'e_trp.dobj': ''},
 'stand writing_desk': {'e_trp.dobj': ''},
 'start communism': {'e_trp.dobj': ''},
 'start alled': {'e_trp.dobj': ''},
 'stare lip': {'e_trp.dobj': ''},
 'station at': {'e_trp.dobj': ''},
 'state euthanasia': {'e_trp.dobj': ''},
 'start enviroment': {'e_trp.dobj': ''},
 'stick raincoat': {'e_trp.dobj': ''},
 'stem climate': {'e_trp.dobj': ''},
 'stay school': {'e_trp.dobj': '', 'e_trp.xcomp_vbe_nn': ''},
 'still cream': {'e_trp.dobj': ''},
 'stick_up position': {'e_trp.dobj': ''},
 'stick valley': {'e_trp.dobj': ''},
 'stick track': {'e_trp.dobj': ''},
 'stop commodity': {'e_trp.dobj': ''},
 'stiring sea': {'e_trp.dobj': ''},
 'still yeild': {'e_trp.dobj': ''},
 'strengthen enviroment': {'e_trp.dobj': ''},
 'stop lib': {'e_trp.dobj': ''},
 'strike ballance': {'e_trp.dobj': ''},
 'strengthen love': {'e_trp.dobj': ''},
 'strengthen grammar': {'e_trp.dobj': ''},
 'strengthen equipment': {'e_trp.dobj': ''},
 'strike neighbour': {'e_trp.dobj': ''},
 'strike fig_tree': {'e_trp.dobj': ''},
 'strike crime': {'e_trp.dobj': ''},
 'study doe': {'e_trp.dobj': ''},
 'study commodity': {'e_trp.dobj': ''},
 'studing english': {'e_trp.dobj': '', 'e_trp.amod_n_a': ''},
 'struggle sixty-nine': {'e_trp.dobj': ''},
 'studying can': {'e_trp.dobj': ''},
 'study widly': {'e_trp.dobj': ''},
 'study ings': {'e_trp.dobj': ''},
 'substitute veteran': {'e_trp.dobj': ''},
 'subjugate kuwait': {'e_trp.dobj': ''},
 'subject exam': {'e_trp.dobj': ''},
 'studying will': {'e_trp.dobj': ''},
 'succeed fail': {'e_trp.dobj': ''},
 'succeed commodity': {'e_trp.dobj': ''},
 'suffer humanitarianism': {'e_trp.dobj': ''},
 'suffer euthanasia': {'e_trp.dobj': ''},
 'succeed wish': {'e_trp.dobj': ''},
 'succeed take': {'e_trp.dobj': ''},
 'suffer self-criticism': {'e_trp.dobj': ''},
 'suffer reprimand': {'e_trp.dobj': ''},
 'suffer relation': {'e_trp.dobj': ''},
 'suit hind': {'e_trp.dobj': ''},
 'suit camera': {'e_trp.dobj': ''},
 'suffocate water': {'e_trp.dobj': ''},
 'suffer warrent': {'e_trp.dobj': ''},
 'summarise university': {'e_trp.dobj': ''},
 'suit war': {'e_trp.dobj': ''},
 'suit medicine': {'e_trp.dobj': ''},
 'surprise paper': {'e_trp.dobj': ''},
 'suppress reform': {'e_trp.dobj': ''},
 'suppose situation': {'e_trp.dobj': ''},
 'support scold': {'e_trp.dobj': ''},
 'swell criminal': {'e_trp.dobj': ''},
 'sweep black_market': {'e_trp.dobj': ''},
 'sustain procedure': {'e_trp.dobj': ''},
 'symbolize reunite': {'e_trp.dobj': ''},
 'swim holiday': {'e_trp.dobj': ''},
 'take bribery': {'e_trp.dobj': ''},
 'take begain': {'e_trp.dobj': ''},
 'take advatage': {'e_trp.dobj': ''},
 'take actvity': {'e_trp.dobj': ''},
 'take farther': {'e_trp.dobj': ''},
 'take etter': {'e_trp.dobj': ''},
 'take chare': {'e_trp.dobj': ''},
 'take humanitarianism': {'e_trp.dobj': ''},
 'take guangzhou': {'e_trp.dobj': ''},
 'take guangdong_province': {'e_trp.dobj': ''},
 'take guangdong': {'e_trp.dobj': ''},
 'talk farewell': {'e_trp.dobj': ''},
 'take whick': {'e_trp.dobj': ''},
 'take swimming_pool': {'e_trp.dobj': ''},
 'tame criminal': {'e_trp.dobj': ''},
 'talk_over price': {'e_trp.dobj': ''},
 'talking tale': {'e_trp.dobj': ''},
 'teach cinema': {'e_trp.dobj': ''},
 'teach action': {'e_trp.dobj': ''},
 'tap initiative': {'e_trp.dobj': ''},
 'tang luck': {'e_trp.dobj': ''},
 'telephone car': {'e_trp.dobj': ''},
 'tear dumpling': {'e_trp.dobj': ''},
 'teach morever': {'e_trp.dobj': ''},
 'teach ear': {'e_trp.dobj': ''},
 'tell fales': {'e_trp.dobj': ''},
 'telephone neighbour': {'e_trp.dobj': ''},
 'telephone firefighter': {'e_trp.dobj': ''},
 'tell phenomenom': {'e_trp.dobj': ''},
 'tell isvery': {'e_trp.dobj': ''},
 'tell hether': {'e_trp.dobj': ''},
 'tell happiness': {'e_trp.dobj': ''},
 'tell_apart commodity': {'e_trp.dobj': ''},
 'telling young': {'e_trp.dobj': ''},
 'tell supermaket': {'e_trp.dobj': ''},
 'tempt foot': {'e_trp.dobj': ''},
 'temper willpower': {'e_trp.dobj': ''},
 'temper body': {'e_trp.dobj': ''},
 'tend play': {'e_trp.dobj': ''},
 'tend job': {'e_trp.dobj': ''},
 'tend food': {'e_trp.dobj': ''},
 'thank generosity': {'e_trp.dobj': ''},
 'test skip': {'e_trp.dobj': ''},
 'test college': {'e_trp.dobj': ''},
 'test address': {'e_trp.dobj': ''},
 'think 70': {'e_trp.dobj': ''},
 'thank miss': {'e_trp.dobj': ''},
 'thank kindness': {'e_trp.dobj': ''},
 'think hat': {'e_trp.dobj': ''},
 'think haste': {'e_trp.dobj': ''},
 'think footmark': {'e_trp.dobj': ''},
 'think duty': {'e_trp.dobj': ''},
 'think quick': {'e_trp.dobj': ''},
 'think physics': {'e_trp.dobj': ''},
 'think hurry': {'e_trp.dobj': ''},
 'think_out place': {'e_trp.dobj': ''},
 'think_out method': {'e_trp.dobj': ''},
 'think_out al': {'e_trp.dobj': ''},
 'think tutor': {'e_trp.dobj': ''},
 'thrust strain': {'e_trp.dobj': ''},
 'throw wish': {'e_trp.dobj': ''},
 'throw mood': {'e_trp.dobj': ''},
 'thirst job': {'e_trp.dobj': ''},
 'time glass': {'e_trp.dobj': ''},
 'tilt candle': {'e_trp.dobj': ''},
 'till riddle': {'e_trp.dobj': ''},
 'title girl': {'e_trp.dobj': ''},
 'tire relationship': {'e_trp.dobj': ''},
 'time telephone': {'e_trp.dobj': ''},
 'time novel': {'e_trp.dobj': ''},
 'torment tense': {'e_trp.dobj': ''},
 'tong law': {'e_trp.dobj': ''},
 'title problem': {'e_trp.dobj': ''},
 'train determination': {'e_trp.dobj': ''},
 'toughing toe': {'e_trp.dobj': ''},
 'touch environment': {'e_trp.dobj': ''},
 'touch crevice': {'e_trp.dobj': ''},
 'trample trust': {'e_trp.dobj': ''},
 'train interest': {'e_trp.dobj': ''},
 'train ideal': {'e_trp.dobj': ''},
 'transmit regard': {'e_trp.dobj': ''},
 'transmit brother': {'e_trp.dobj': ''},
 'translate yunnan': {'e_trp.dobj': ''},
 'travel tomb': {'e_trp.dobj': ''},
 'travel pot': {'e_trp.dobj': ''},
 'travel lake': {'e_trp.dobj': ''},
 'treat euthanasia': {'e_trp.dobj': ''},
 'treat dream': {'e_trp.dobj': ''},
 'treasure water': {'e_trp.dobj': ''},
 'trust base': {'e_trp.dobj': ''},
 'true science': {'e_trp.dobj': ''},
 'troop japan': {'e_trp.dobj': ''},
 'try popo': {'e_trp.dobj': ''},
 'try pick': {'e_trp.dobj': ''},
 'try est': {'e_trp.dobj': ''},
 'turn modernization': {'e_trp.dobj': ''},
 'turn mercy_killing': {'e_trp.dobj': ''},
 'try_out riddle': {'e_trp.dobj': ''},
 'try_on research': {'e_trp.dobj': ''},
 'typewrite wps': {'e_trp.dobj': ''},
 'typewrite word': {'e_trp.dobj': ''},
 'turn utopia': {'e_trp.dobj': ''},
 'underlie lack': {'e_trp.dobj': ''},
 'undercut reliance': {'e_trp.dobj': ''},
 'understand ascent': {'e_trp.dobj': ''},
 'understand all': {'e_trp.dobj': ''},
 'unfit job': {'e_trp.dobj': ''},
 'understand treat': {'e_trp.dobj': ''},
 'understand euthanasia': {'e_trp.dobj': ''},
 'uniform time': {'e_trp.dobj': ''},
 'uniform mind': {'e_trp.dobj': ''},
 'unfit office': {'e_trp.dobj': ''},
 'unravel parcel': {'e_trp.dobj': ''},
 'unknow keyboard': {'e_trp.dobj': ''},
 'unite clothing': {'e_trp.dobj': ''},
 'use fen': {'e_trp.dobj': ''},
 'use economicaly': {'e_trp.dobj': ''},
 'up intention': {'e_trp.dobj': ''},
 'use lectricity': {'e_trp.dobj': ''},
 'use galileo': {'e_trp.dobj': ''},
 'utilize initiative': {'e_trp.dobj': ''},
 'use_up rain': {'e_trp.dobj': ''},
 'use_up pollution': {'e_trp.dobj': ''},
 'vanish merchandise': {'e_trp.dobj': ''},
 'vanish evil': {'e_trp.dobj': ''},
 'van bear': {'e_trp.dobj': ''},
 'view associate_professor': {'e_trp.dobj': ''},
 'veil point': {'e_trp.dobj': ''},
 'vary playground': {'e_trp.dobj': ''},
 'visit poor_boy': {'e_trp.dobj': ''},
 'violate aim': {'e_trp.dobj': ''},
 'view euthanasia': {'e_trp.dobj': ''},
 'void waste': {'e_trp.dobj': ''},
 'visit vocation': {'e_trp.dobj': ''},
 'visit shan': {'e_trp.dobj': ''},
 'wait monster': {'e_trp.dobj': ''},
 'wait festival': {'e_trp.dobj': ''},
 'wait arrest': {'e_trp.dobj': ''},
 'vote client': {'e_trp.dobj': ''},
 'waken people': {'e_trp.dobj': ''},
 'wait train': {'e_trp.dobj': ''},
 'wait policeman': {'e_trp.dobj': ''},
 'walk cloth': {'e_trp.dobj': ''},
 'wake_up race': {'e_trp.dobj': ''},
 'walk mcdonald': {'e_trp.dobj': ''},
 'walk happiness': {'e_trp.dobj': ''},
 'walk grandma': {'e_trp.dobj': ''},
 'wan river': {'e_trp.dobj': ''},
 'wan match': {'e_trp.dobj': ''},
 'wall_up danger': {'e_trp.dobj': ''},
 'walk society': {'e_trp.dobj': ''},
 'ware sign_language': {'e_trp.dobj': ''},
 'want succeed': {'e_trp.dobj': ''},
 'want afternoon': {'e_trp.dobj': ''},
 'waste haste': {'e_trp.dobj': ''},
 'waste finish': {'e_trp.dobj': ''},
 'warp lip': {'e_trp.dobj': ''},
 'warn servel': {'e_trp.dobj': ''},
 'watch expecially': {'e_trp.dobj': ''},
 'watch eclips': {'e_trp.dobj': ''},
 'waste smoke': {'e_trp.dobj': ''},
 'waste lifes': {'e_trp.dobj': ''},
 'water follow': {'e_trp.dobj': ''},
 'water danger': {'e_trp.dobj': ''},
 'water china': {'e_trp.dobj': ''},
 'watching moon': {'e_trp.dobj': ''},
 'water scallop': {'e_trp.dobj': ''},
 'water river': {'e_trp.dobj': ''},
 'water lower': {'e_trp.dobj': ''},
 'water ice_water': {'e_trp.dobj': ''},
 'weight illness': {'e_trp.dobj': ''},
 'wear_out water': {'e_trp.dobj': ''},
 'wear_away patience': {'e_trp.dobj': ''},
 'wave trouser': {'e_trp.dobj': ''},
 'welcome thunder': {'e_trp.dobj': ''},
 'welcome passer': {'e_trp.dobj': ''},
 'welcome exam': {'e_trp.dobj': ''},
 'while mortality': {'e_trp.dobj': ''},
 'while infant': {'e_trp.dobj': ''},
 'while advance': {'e_trp.dobj': ''},
 'well college': {'e_trp.dobj': ''},
 'wield procedure': {'e_trp.dobj': ''},
 'win earth': {'e_trp.dobj': ''},
 'win acclamation': {'e_trp.dobj': ''},
 'wire bag': {'e_trp.dobj': ''},
 'wipe_out fake': {'e_trp.dobj': ''},
 'wipe_off commodity': {'e_trp.dobj': ''},
 'wipe study': {'e_trp.dobj': ''},
 'wish grace': {'e_trp.dobj': ''},
 'wish examination': {'e_trp.dobj': ''},
 'wire fense': {'e_trp.dobj': ''},
 'withhold life': {'e_trp.dobj': ''},
 'wish properity': {'e_trp.dobj': ''},
 'wish practical': {'e_trp.dobj': ''},
 'witness patient': {'e_trp.dobj': ''},
 'witness descendents': {'e_trp.dobj': ''},
 'word true': {'e_trp.dobj': ''},
 'wonder sea': {'e_trp.dobj': ''},
 'witness spaceship': {'e_trp.dobj': ''},
 'work_in thing': {'e_trp.dobj': ''},
 'work_in import': {'e_trp.dobj': ''},
 'work beause': {'e_trp.dobj': ''},
 'wrap fire': {'e_trp.dobj': ''},
 'worship two': {'e_trp.dobj': ''},
 'worsen nature': {'e_trp.dobj': ''},
 'worry english': {'e_trp.dobj': ''},
 'write lantern': {'e_trp.dobj': ''},
 'write civil_war': {'e_trp.dobj': ''},
 'wring sir': {'e_trp.dobj': ''},
 'writting people': {'e_trp.dobj': ''},
 'write trouser': {'e_trp.dobj': ''},
 'write setter': {'e_trp.dobj': ''},
 'wrap shape': {'e_trp.dobj': ''},
 'write businessman': {'e_trp.dobj': ''},
 'wrong student': {'e_trp.dobj': ''},
 'ying fund': {'e_trp.dobj': ''},
 'work mistake': {'e_trp.dobj': ''},
 'work oh': {'e_trp.dobj': ''},
 'worry tim': {'e_trp.dobj': ''},
 'word reaction': {'e_trp.dobj': ''},
 'word sentence': {'e_trp.dobj': ''},
 'work dark': {'e_trp.dobj': ''},
 'win marriage': {'e_trp.dobj': ''},
 'win progress': {'e_trp.dobj': ''},
 'wipe wind': {'e_trp.dobj': ''},
 'wish progress': {'e_trp.dobj': ''},
 'while lead': {'e_trp.dobj': ''},
 'watch passer-by': {'e_trp.dobj': ''},
 'water vegetable': {'e_trp.dobj': ''},
 'well can': {'e_trp.dobj': ''},
 'want swim': {'e_trp.dobj': ''},
 'want waiting': {'e_trp.dobj': ''},
 'war trend': {'e_trp.dobj': ''},
 'waste quantity': {'e_trp.dobj': ''},
 'want fishing': {'e_trp.dobj': ''},
 'want haste': {'e_trp.dobj': ''},
 'want still_life': {'e_trp.dobj': ''},
 'wait death': {'e_trp.dobj': ''},
 'walk while': {'e_trp.dobj': ''},
 'walk will': {'e_trp.dobj': ''},
 'use underground': {'e_trp.dobj': ''},
 'visit interest': {'e_trp.dobj': ''},
 'visit seaside': {'e_trp.dobj': ''},
 'twist dance': {'e_trp.dobj': ''},
 'up law': {'e_trp.dobj': ''},
 'up luggage': {'e_trp.dobj': ''},
 'use harvester': {'e_trp.dobj': ''},
 'train heart': {'e_trp.dobj': ''},
 'train sense': {'e_trp.dobj': ''},
 'try care': {'e_trp.dobj': ''},
 'turn commodity': {'e_trp.dobj': ''},
 'time energy': {'e_trp.dobj': ''},
 'tire job': {'e_trp.dobj': ''},
 'torture nature': {'e_trp.dobj': ''},
 'think_out problem': {'e_trp.dobj': ''},
 'think_out topic': {'e_trp.dobj': ''},
 'throw domination': {'e_trp.dobj': ''},
 'think advertisement': {'e_trp.dobj': ''},
 'think campus': {'e_trp.dobj': ''},
 'think importance': {'e_trp.dobj': ''},
 'tell text': {'e_trp.dobj': ''},
 'tell tribe': {'e_trp.dobj': ''},
 'tell water': {'e_trp.dobj': ''},
 'test scent': {'e_trp.dobj': ''},
 'teach get': {'e_trp.dobj': ''},
 'teach good': {'e_trp.dobj': ''},
 'tell commodity': {'e_trp.dobj': ''},
 'tell habit': {'e_trp.dobj': ''},
 'take olympic_games': {'e_trp.dobj': ''},
 'take prostitution': {'e_trp.dobj': ''},
 'take singapore': {'e_trp.dobj': ''},
 'take flood': {'e_trp.dobj': ''},
 'take housework': {'e_trp.dobj': ''},
 'take mastery': {'e_trp.dobj': ''},
 'take chink': {'e_trp.dobj': ''},
 'take developing_country': {'e_trp.dobj': ''},
 'supply chance': {'e_trp.dobj': ''},
 'sustain floor': {'e_trp.dobj': ''},
 'take active': {'e_trp.dobj': ''},
 'suffer existence': {'e_trp.dobj': ''},
 'suffer function': {'e_trp.dobj': ''},
 'suffer view': {'e_trp.dobj': ''},
 'suggest weather': {'e_trp.dobj': ''},
 'study last': {'e_trp.dobj': ''},
 'study machine': {'e_trp.dobj': ''},
 'study spirit': {'e_trp.dobj': ''},
 'study farmer': {'e_trp.dobj': ''},
 'study grammar': {'e_trp.dobj': ''},
 'steal cheat': {'e_trp.dobj': ''},
 'steal population': {'e_trp.dobj': ''},
 'stimulate act': {'e_trp.dobj': ''},
 'strike clock': {'e_trp.dobj': ''},
 'stand are': {'e_trp.dobj': ''},
 'start crime': {'e_trp.dobj': ''},
 'stash billion': {'e_trp.dobj': ''},
 'spend france': {'e_trp.dobj': ''},
 'spread_out fun': {'e_trp.dobj': ''},
 'spare water': {'e_trp.dobj': ''},
 'speak death': {'e_trp.dobj': ''},
 'speed step': {'e_trp.dobj': ''},
 'solve information': {'e_trp.dobj': ''},
 'spare skill': {'e_trp.dobj': ''},
 'spare tv': {'e_trp.dobj': ''},
 'skim passage': {'e_trp.dobj': ''},
 'slide side': {'e_trp.dobj': ''},
 'smile peter': {'e_trp.dobj': ''},
 'smoke will': {'e_trp.dobj': ''},
 'show correctness': {'e_trp.dobj': ''},
 'shroud sky': {'e_trp.dobj': ''},
 'sing guest': {'e_trp.dobj': ''},
 'share moon': {'e_trp.dobj': ''},
 'shelter space': {'e_trp.dobj': ''},
 'shout boy': {'e_trp.dobj': ''},
 'shall lot': {'e_trp.dobj': ''},
 'shall step': {'e_trp.dobj': ''},
 'shall thought': {'e_trp.dobj': ''},
 'shape table': {'e_trp.dobj': ''},
 'shake friendship': {'e_trp.dobj': ''},
 'shall ability': {'e_trp.dobj': ''},
 'shall example': {'e_trp.dobj': ''},
 'set impulse': {'e_trp.dobj': ''},
 'settle veteran': {'e_trp.dobj': ''},
 'set_on paper': {'e_trp.dobj': ''},
 'set_up constitution': {'e_trp.dobj': ''},
 'send harm': {'e_trp.dobj': ''},
 'set festival': {'e_trp.dobj': ''},
 'say pause': {'e_trp.dobj': ''},
 'say right_hand': {'e_trp.dobj': ''},
 'say spy': {'e_trp.dobj': ''},
 'seize oil_well': {'e_trp.dobj': ''},
 'say haste': {'e_trp.dobj': ''},
 'say homework': {'e_trp.dobj': ''},
 'say modern': {'e_trp.dobj': ''},
 'savage land': {'e_trp.dobj': ''},
 'save improvement': {'e_trp.dobj': ''},
 'saw sky': {'e_trp.dobj': ''},
 'say attire': {'e_trp.dobj': ''},
 'run how': {'e_trp.dobj': ''},
 'run reputation': {'e_trp.dobj': ''},
 'run shout': {'e_trp.dobj': ''},
 'rush room': {'e_trp.dobj': ''},
 'rise change': {'e_trp.dobj': ''},
 'rise impact': {'e_trp.dobj': ''},
 'roll bottom': {'e_trp.dobj': ''},
 'roll lump': {'e_trp.dobj': ''},
 'reward matter': {'e_trp.dobj': ''},
 'rid doctor': {'e_trp.dobj': ''},
 'rid shop': {'e_trp.dobj': ''},
 'return classroom': {'e_trp.dobj': '', 'e_trp.nsv': ''},
 'revere tree': {'e_trp.dobj': ''},
 'reward insistence': {'e_trp.dobj': ''},
 'repay bit': {'e_trp.dobj': ''},
 'result course': {'e_trp.dobj': ''},
 'resume nature': {'e_trp.dobj': ''},
 'retrain most': {'e_trp.dobj': ''},
 'relive people': {'e_trp.dobj': ''},
 'remedy pain': {'e_trp.dobj': ''},
 'remember push': {'e_trp.dobj': ''},
 'remove hill': {'e_trp.dobj': ''},
 'reflect equality': {'e_trp.dobj': ''},
 'regard spring': {'e_trp.dobj': ''},
 'rehabilitate hundred': {'e_trp.dobj': ''},
 'recompense evil': {'e_trp.dobj': ''},
 'recover boy': {'e_trp.dobj': ''},
 'reduce evil': {'e_trp.dobj': ''},
 'reduce morality': {'e_trp.dobj': ''},
 'read etc': {'e_trp.dobj': ''},
 'realize death': {'e_trp.dobj': ''},
 'realize quality': {'e_trp.dobj': ''},
 'quote confession': {'e_trp.dobj': ''},
 'raise 20': {'e_trp.dobj': ''},
 'reach desire': {'e_trp.dobj': ''},
 'read black': {'e_trp.dobj': ''},
 'put_up weight': {'e_trp.dobj': ''},
 'quicken rhythm': {'e_trp.dobj': ''},
 'quit kind': {'e_trp.dobj': ''},
 'put equal_sign': {'e_trp.dobj': ''},
 'put fault': {'e_trp.dobj': ''},
 'put stride': {'e_trp.dobj': ''},
 'punish factory': {'e_trp.dobj': ''},
 'punish goods': {'e_trp.dobj': ''},
 'punish right': {'e_trp.dobj': ''},
 'purse snatcher': {'e_trp.dobj': ''},
 'promote speed': {'e_trp.dobj': ''},
 'protect offering': {'e_trp.dobj': ''},
 'punch screen': {'e_trp.dobj': ''},
 'professionalize army': {'e_trp.dobj': ''},
 'project column': {'e_trp.dobj': ''},
 'print skill': {'e_trp.dobj': ''},
 'proceed effort': {'e_trp.dobj': ''},
 'produce evil': {'e_trp.dobj': ''},
 'prepare degree': {'e_trp.dobj': '', 'e_trp.nsv': ''},
 'prepare park': {'e_trp.dobj': ''},
 'present reunion': {'e_trp.dobj': ''},
 'prevent commodity': {'e_trp.dobj': ''},
 'practice capacity': {'e_trp.dobj': ''},
 'practice make': {'e_trp.dobj': ''},
 'plead doctor': {'e_trp.dobj': ''},
 'point mistake': {'e_trp.dobj': ''},
 'pour thing': {'e_trp.dobj': ''},
 'play karaoke': {'e_trp.dobj': ''},
 'play plane': {'e_trp.dobj': ''},
 'play playground': {'e_trp.dobj': ''},
 'play snow': {'e_trp.dobj': ''},
 'plant tea': {'e_trp.dobj': ''},
 'play fooball': {'e_trp.dobj': ''},
 'place dinner': {'e_trp.dobj': ''},
 'plant beauty': {'e_trp.dobj': ''},
 'permit tree': {'e_trp.dobj': ''},
 'pick goods': {'e_trp.dobj': ''},
 'pick_up necessary': {'e_trp.dobj': ''},
 'pick_up trouser': {'e_trp.dobj': ''},
 'people fun': {'e_trp.dobj': ''},
 'people good': {'e_trp.dobj': ''},
 'permeate people': {'e_trp.dobj': ''},
 'people desire': {'e_trp.dobj': ''},
 'people fight': {'e_trp.dobj': ''},
 'pay crime': {'e_trp.dobj': ''},
 'pay expenditure': {'e_trp.dobj': ''},
 'pay peace': {'e_trp.dobj': ''},
 'penetrate right': {'e_trp.dobj': ''},
 'pass text': {'e_trp.dobj': ''},
 'pass_on screen': {'e_trp.dobj': ''},
 'pay celebration': {'e_trp.dobj': ''},
 'part teacher': {'e_trp.dobj': ''},
 'participate position': {'e_trp.dobj': ''},
 'pass brand': {'e_trp.dobj': ''},
 'overthrow warlord': {'e_trp.dobj': ''},
 'overwhelm situation': {'e_trp.dobj': ''},
 'own journey': {'e_trp.dobj': ''},
 'out job': {'e_trp.dobj': ''},
 'outline festival': {'e_trp.dobj': ''},
 'outrage law': {'e_trp.dobj': ''},
 'organize success': {'e_trp.dobj': ''},
 'out classroom': {'e_trp.dobj': ''},
 'out hotel': {'e_trp.dobj': ''},
 'obtain aim': {'e_trp.dobj': ''},
 'occur situation': {'e_trp.dobj': ''},
 'order apple': {'e_trp.dobj': ''},
 'order shoot': {'e_trp.dobj': ''},
 'notice significance': {'e_trp.dobj': ''},
 'obey word': {'e_trp.dobj': ''},
 'object move': {'e_trp.dobj': ''},
 'neglect situation': {'e_trp.dobj': ''},
 'nestle face': {'e_trp.dobj': ''},
 'notice opening': {'e_trp.dobj': ''},
 'need make': {'e_trp.dobj': ''},
 'neglect mistake': {'e_trp.dobj': ''},
 'neglect relation': {'e_trp.dobj': ''},
 'need affair': {'e_trp.dobj': ''},
 'need enjoyment': {'e_trp.dobj': ''},
 'need evil': {'e_trp.dobj': ''},
 'must food': {'e_trp.dobj': ''},
 'must reality': {'e_trp.dobj': ''},
 'name pole': {'e_trp.dobj': ''},
 'miss homework': {'e_trp.dobj': ''},
 'modify aim': {'e_trp.dobj': ''},
 'move example': {'e_trp.dobj': ''},
 'must customer': {'e_trp.dobj': ''},
 'meet method': {'e_trp.dobj': ''},
 'meet shop': {'e_trp.dobj': ''},
 'mind roof': {'e_trp.dobj': ''},
 'mean poison': {'e_trp.dobj': ''},
 'measure job': {'e_trp.dobj': ''},
 'meet luck': {'e_trp.dobj': ''},
 'mean disposal': {'e_trp.dobj': ''},
 'mean greed': {'e_trp.dobj': ''},
 'mean haste': {'e_trp.dobj': ''},
 'manage prisoner': {'e_trp.dobj': ''},
 'matter opinion': {'e_trp.dobj': ''},
 'may crime': {'e_trp.dobj': ''},
 'may scene': {'e_trp.dobj': ''},
 'make wrongdoing': {'e_trp.dobj': ''},
 'make_up atmosphere': {'e_trp.dobj': ''},
 'make_up disadvantage': {'e_trp.dobj': ''},
 'manage cadre': {'e_trp.dobj': ''},
 'make homeland': {'e_trp.dobj': ''},
 'make lion': {'e_trp.dobj': ''},
 'make second_thought': {'e_trp.dobj': ''},
 'make surroundings': {'e_trp.dobj': ''},
 'lose description': {'e_trp.dobj': ''},
 'lose wish': {'e_trp.dobj': ''},
 'make fault': {'e_trp.dobj': ''},
 'make forever': {'e_trp.dobj': ''},
 'look miss': {'e_trp.dobj': ''},
 'look situation': {'e_trp.dobj': '', 'e_trp.xcomp_vbe_nn': ''},
 'look_on death': {'e_trp.dobj': ''},
 'look_up tom': {'e_trp.dobj': ''},
 'live france': {'e_trp.dobj': ''},
 'live low': {'e_trp.dobj': ''},
 'live minter': {'e_trp.dobj': ''},
 'live normal': {'e_trp.dobj': ''},
 'let_off firecracker': {'e_trp.dobj': ''},
 'lie bed': {'e_trp.dobj': ''},
 'like good-bye': {'e_trp.dobj': ''},
 'listen tape': {'e_trp.dobj': ''},
 'lessen place': {'e_trp.dobj': ''},
 'let example': {'e_trp.dobj': ''},
 'let population': {'e_trp.dobj': ''},
 'let tree': {'e_trp.dobj': ''},
 'leave heaven': {'e_trp.dobj': ''},
 'leave less': {'e_trp.dobj': ''},
 'leave pencil': {'e_trp.dobj': ''},
 'legalize problem': {'e_trp.dobj': ''},
 'learn spirit': {'e_trp.dobj': ''},
 'learn swim': {'e_trp.dobj': ''},
 'learn unit': {'e_trp.dobj': ''},
 'learn writer': {'e_trp.dobj': ''},
 'learn construction': {'e_trp.dobj': ''},
 'learn everyday': {'e_trp.dobj': ''},
 'learn radio': {'e_trp.dobj': ''},
 'learn society': {'e_trp.dobj': ''},
 'lay football': {'e_trp.dobj': ''},
 'learn bad': {'e_trp.dobj': ''},
 'learn campus': {'e_trp.dobj': ''},
 'learn clothes': {'e_trp.dobj': ''},
 'know ice_cream': {'e_trp.dobj': ''},
 'know tuition': {'e_trp.dobj': ''},
 'laugh brother': {'e_trp.dobj': ''},
 'lay cat': {'e_trp.dobj': '', 'e_trp.nsv': ''},
 'judge friendship': {'e_trp.dobj': ''},
 'keep_on speed': {'e_trp.dobj': ''},
 'kill can': {'e_trp.dobj': ''},
 'knock shoulder': {'e_trp.dobj': ''},
 'interest literature': {'e_trp.dobj': ''},
 'invent plane': {'e_trp.dobj': ''},
 'invite attitude': {'e_trp.dobj': ''},
 'join running': {'e_trp.dobj': ''},
 'influence death': {'e_trp.dobj': ''},
 'infuse power': {'e_trp.dobj': ''},
 'insist belief': {'e_trp.dobj': ''},
 'insist word': {'e_trp.dobj': ''},
 'increase alert': {'e_trp.dobj': ''},
 'increase condition': {'e_trp.dobj': ''},
 'increase hand': {'e_trp.dobj': ''},
 'indicate saying': {'e_trp.dobj': ''},
 'improve shortage': {'e_trp.dobj': ''},
 'include birth_control': {'e_trp.dobj': ''},
 'include perfect': {'e_trp.dobj': ''},
 'improve aptitude': {'e_trp.dobj': ''},
 'improve circle': {'e_trp.dobj': ''},
 'improve question': {'e_trp.dobj': ''},
 'improve reason': {'e_trp.dobj': ''},
 'hurt nature': {'e_trp.dobj': ''},
 'image word': {'e_trp.dobj': ''},
 'implement purpose': {'e_trp.dobj': ''},
 'impose course': {'e_trp.dobj': ''},
 'hope coming': {'e_trp.dobj': ''},
 'hope give': {'e_trp.dobj': ''},
 'hope see': {'e_trp.dobj': ''},
 'house businessman': {'e_trp.dobj': ''},
 'hold flea_market': {'e_trp.dobj': ''},
 'home situation': {'e_trp.dobj': ''},
 'honor moon': {'e_trp.dobj': ''},
 'hope absence': {'e_trp.dobj': ''},
 'hear thief': {'e_trp.dobj': ''},
 'heed nature': {'e_trp.dobj': ''},
 'help respect': {'e_trp.dobj': ''},
 'hit commodity': {'e_trp.dobj': ''},
 'have waitress': {'e_trp.dobj': ''},
 'have wrongdoer': {'e_trp.dobj': ''},
 'hear crisis': {'e_trp.dobj': ''},
 'have small_talk': {'e_trp.dobj': ''},
 'have sovereign': {'e_trp.dobj': ''},
 'have subway': {'e_trp.dobj': ''},
 'have throught': {'e_trp.dobj': ''},
 'have procession': {'e_trp.dobj': ''},
 'have rebirth': {'e_trp.dobj': ''},
 'have rebuke': {'e_trp.dobj': ''},
 'have sick': {'e_trp.dobj': ''},
 'have lu': {'e_trp.dobj': ''},
 'have middle': {'e_trp.dobj': ''},
 'have misconduct': {'e_trp.dobj': ''},
 'have p.e.': {'e_trp.dobj': ''},
 'have insistence': {'e_trp.dobj': ''},
 'have japan': {'e_trp.dobj': ''},
 'have lifes': {'e_trp.dobj': ''},
 'have lower': {'e_trp.dobj': ''},
 'have everyday': {'e_trp.dobj': ''},
 'have grab': {'e_trp.dobj': ''},
 'have heath': {'e_trp.dobj': ''},
 'have ill': {'e_trp.dobj': ''},
 'have cal': {'e_trp.dobj': ''},
 'have don': {'e_trp.dobj': ''},
 'have eft': {'e_trp.dobj': ''},
 'have en': {'e_trp.dobj': ''},
 'hate more': {'e_trp.dobj': ''},
 'have aggressiveness': {'e_trp.dobj': ''},
 'have ass': {'e_trp.dobj': ''},
 'have boxing': {'e_trp.dobj': ''},
 'halve burden': {'e_trp.dobj': ''},
 'harm being': {'e_trp.dobj': ''},
 'harm medicine': {'e_trp.dobj': ''},
 'harm smoker': {'e_trp.dobj': ''},
 'grow_up generation': {'e_trp.dobj': ''},
 'guarantee doctor': {'e_trp.dobj': ''},
 'guide enterprise': {'e_trp.dobj': ''},
 'guide information': {'e_trp.dobj': ''},
 'group friend': {'e_trp.dobj': ''},
 'grow factory': {'e_trp.dobj': ''},
 'grasp word': {'e_trp.dobj': ''},
 'greet summer': {'e_trp.dobj': ''},
 'give_up idea': {'e_trp.dobj': ''},
 'give_up mummy': {'e_trp.dobj': ''},
 'gnaw heart': {'e_trp.dobj': ''},
 'go vacation': {'e_trp.dobj': ''},
 'give mercy_killing': {'e_trp.dobj': ''},
 'give realization': {'e_trp.dobj': ''},
 'give waste': {'e_trp.dobj': ''},
 'get invention': {'e_trp.dobj': ''},
 'get laziness': {'e_trp.dobj': ''},
 'get_in pursuit': {'e_trp.dobj': ''},
 'get excellent': {'e_trp.dobj': ''},
 'get fate': {'e_trp.dobj': ''},
 'get grad': {'e_trp.dobj': ''},
 'get importance': {'e_trp.dobj': ''},
 'get consequence': {'e_trp.dobj': ''},
 'get diplomat': {'e_trp.dobj': ''},
 'get english': {'e_trp.dobj': ''},
 'fulfil project': {'e_trp.dobj': ''},
 'fulfill future': {'e_trp.dobj': ''},
 'full house': {'e_trp.dobj': ''},
 'gain health': {'e_trp.dobj': ''},
 'forgo punishment': {'e_trp.dobj': ''},
 'form respect': {'e_trp.dobj': ''},
 'form thousand': {'e_trp.dobj': ''},
 'frighten heart': {'e_trp.dobj': ''},
 'flourish extent': {'e_trp.dobj': ''},
 'follow allocation': {'e_trp.dobj': ''},
 'forbid drug': {'e_trp.dobj': ''},
 'find_out tree': {'e_trp.dobj': ''},
 'fire hero': {'e_trp.dobj': ''},
 'fit benefit': {'e_trp.dobj': ''},
 'fit first': {'e_trp.dobj': ''},
 'fill_up mind': {'e_trp.dobj': ''},
 'find_out drawback': {'e_trp.dobj': ''},
 'find_out murderer': {'e_trp.dobj': ''},
 'feel smell': {'e_trp.dobj': ''},
 'fell wood': {'e_trp.dobj': ''},
 'fighting capacity': {'e_trp.dobj': ''},
 'fill_up frame': {'e_trp.dobj': ''},
 'fear sex': {'e_trp.dobj': ''},
 'feel bout': {'e_trp.dobj': ''},
 'feel goal': {'e_trp.dobj': ''},
 'face blame': {'e_trp.dobj': ''},
 'face emperor': {'e_trp.dobj': ''},
 'face preacher': {'e_trp.dobj': ''},
 'fear more': {'e_trp.dobj': ''},
 'explain behind': {'e_trp.dobj': ''},
 'expose deed': {'e_trp.dobj': ''},
 'extend human': {'e_trp.dobj': ''},
 'extend mean': {'e_trp.dobj': ''},
 'exist obstacle': {'e_trp.dobj': ''},
 'exist society': {'e_trp.dobj': ''},
 'exit child': {'e_trp.dobj': ''},
 'escape kid': {'e_trp.dobj': ''},
 'evaluate war': {'e_trp.dobj': ''},
 'exist concept': {'e_trp.dobj': ''},
 'exist discrimination': {'e_trp.dobj': ''},
 'engage reason': {'e_trp.dobj': ''},
 'enjoy 50': {'e_trp.dobj': ''},
 'enjoy wish': {'e_trp.dobj': ''},
 'end water': {'e_trp.dobj': ''},
 'endow life': {'e_trp.dobj': ''},
 'enforce ability': {'e_trp.dobj': ''},
 'engage newspaper': {'e_trp.dobj': ''},
 'encourage uniformity': {'e_trp.dobj': ''},
 'end commodity': {'e_trp.dobj': ''},
 'end sorrow': {'e_trp.dobj': ''},
 'embody saying': {'e_trp.dobj': ''},
 'enable ability': {'e_trp.dobj': ''},
 'enchant mind': {'e_trp.dobj': ''},
 'encounter decision': {'e_trp.dobj': ''},
 'eat smoke': {'e_trp.dobj': ''},
 'effect thing': {'e_trp.dobj': ''},
 'eliminate fossil_fuel': {'e_trp.dobj': ''},
 'dub form': {'e_trp.dobj': ''},
 'dub murder': {'e_trp.dobj': ''},
 'earn anchor': {'e_trp.dobj': ''},
 'eat poet': {'e_trp.dobj': ''},
 'drive master': {'e_trp.dobj': ''},
 'drop hold': {'e_trp.dobj': ''},
 'drop soup': {'e_trp.dobj': ''},
 'do_in bit': {'e_trp.dobj': ''},
 'do_in works': {'e_trp.dobj': ''},
 'dream future': {'e_trp.dobj': ''},
 'drink wind': {'e_trp.dobj': ''},
 'do small_talk': {'e_trp.dobj': ''},
 'do usefulness': {'e_trp.dobj': ''},
 'do vocabulary': {'e_trp.dobj': ''},
 'double joy': {'e_trp.dobj': ''},
 'do seller': {'e_trp.dobj': ''},
 'do sexual_harassment': {'e_trp.dobj': ''},
 'do shortage': {'e_trp.dobj': ''},
 'do homeland': {'e_trp.dobj': ''},
 'do no-good': {'e_trp.dobj': ''},
 'do perfect': {'e_trp.dobj': ''},
 'do practical': {'e_trp.dobj': ''},
 'do birth': {'e_trp.dobj': ''},
 'do case_in_point': {'e_trp.dobj': ''},
 'do etc.': {'e_trp.dobj': ''},
 'do etter': {'e_trp.dobj': ''},
 'devour rest': {'e_trp.dobj': ''},
 'display harmony': {'e_trp.dobj': ''},
 'display society': {'e_trp.dobj': ''},
 'divide match': {'e_trp.dobj': ''},
 'develop merit': {'e_trp.dobj': ''},
 'develop reward': {'e_trp.dobj': ''},
 'devour kuwait': {'e_trp.dobj': ''},
 'demoralize will': {'e_trp.dobj': ''},
 'depend pattern': {'e_trp.dobj': ''},
 'deprive time': {'e_trp.dobj': ''},
 'design invention': {'e_trp.dobj': ''},
 'defeat city': {'e_trp.dobj': '', 'e_trp.nsv': ''},
 'defeat home': {'e_trp.dobj': ''},
 'define boredom': {'e_trp.dobj': ''},
 'decide conduct': {'e_trp.dobj': ''},
 'decrease difference': {'e_trp.dobj': ''},
 'decrease morale': {'e_trp.dobj': ''},
 'decrease unemployment': {'e_trp.dobj': ''},
 'cut_off subject': {'e_trp.dobj': ''},
 'cycle system': {'e_trp.dobj': ''},
 'deal quality': {'e_trp.dobj': ''},
 'create tomorrow': {'e_trp.dobj': ''},
 'cry self': {'e_trp.dobj': ''},
 'cultivate thousand': {'e_trp.dobj': ''},
 'cover_up cruelty': {'e_trp.dobj': ''},
 'create globe': {'e_trp.dobj': ''},
 'create hallucination': {'e_trp.dobj': ''},
 'create sin': {'e_trp.dobj': ''},
 'convert dream': {'e_trp.dobj': ''},
 'count ideal': {'e_trp.dobj': ''},
 'couple knowledge': {'e_trp.dobj': ''},
 'course water': {'e_trp.dobj': ''},
 'continue topic': {'e_trp.dobj': ''},
 'contract bus': {'e_trp.dobj': ''},
 'contribute life': {'e_trp.dobj': ''},
 'consider donkey': {'e_trp.dobj': ''},
 'consult material': {'e_trp.dobj': ''},
 'continue deed': {'e_trp.dobj': ''},
 'continue request': {'e_trp.dobj': ''},
 'connect reward': {'e_trp.dobj': ''},
 'connect vocabulary': {'e_trp.dobj': ''},
 'conquer one': {'e_trp.dobj': ''},
 'conduct crime': {'e_trp.dobj': ''},
 'conduct murder': {'e_trp.dobj': ''},
 'connect ability': {'e_trp.dobj': ''},
 'come festival': {'e_trp.dobj': ''},
 'commit law': {'e_trp.dobj': ''},
 'commit request': {'e_trp.dobj': ''},
 'compare jane_austen': {'e_trp.dobj': ''},
 'cloud sea': {'e_trp.dobj': ''},
 'collect achievement': {'e_trp.dobj': ''},
 'combine prevention': {'e_trp.dobj': ''},
 'chase violence': {'e_trp.dobj': ''},
 'cherish hound': {'e_trp.dobj': ''},
 'cherish young': {'e_trp.dobj': ''},
 'chew gun': {'e_trp.dobj': ''},
 'carry reformation': {'e_trp.dobj': ''},
 'carry tail': {'e_trp.dobj': ''},
 'change graduate': {'e_trp.dobj': ''},
 'care problem': {'e_trp.dobj': ''},
 'carry birth': {'e_trp.dobj': ''},
 'carry euthanasia': {'e_trp.dobj': ''},
 'buy try': {'e_trp.dobj': ''},
 'call calendar': {'e_trp.dobj': ''},
 'call fairy': {'e_trp.dobj': ''},
 'call summons': {'e_trp.dobj': ''},
 'burden girl': {'e_trp.dobj': ''},
 'buy cripple': {'e_trp.dobj': ''},
 'buy think': {'e_trp.dobj': ''},
 'build_in school': {'e_trp.dobj': ''},
 'build_up consciousness': {'e_trp.dobj': ''},
 'build_up family': {'e_trp.dobj': ''},
 'build_up need': {'e_trp.dobj': ''},
 'bring depletion': {'e_trp.dobj': ''},
 'bring disadvantage': {'e_trp.dobj': ''},
 'build aswan_high_dam': {'e_trp.dobj': ''},
 'box house': {'e_trp.dobj': ''},
 'break role': {'e_trp.dobj': ''},
 'break ruler': {'e_trp.dobj': ''},
 'break_down habit': {'e_trp.dobj': ''},
 'believe euthanasia': {'e_trp.dobj': ''},
 'believe moon': {'e_trp.dobj': ''},
 'bind run': {'e_trp.dobj': ''},
 'bear desire': {'e_trp.dobj': ''},
 'beg die': {'e_trp.dobj': ''},
 'begin success': {'e_trp.dobj': ''},
 'begin worry': {'e_trp.dobj': ''},
 'back wife': {'e_trp.dobj': ''},
 'ban producer': {'e_trp.dobj': ''},
 'attribute husband': {'e_trp.dobj': ''},
 'back homeland': {'e_trp.dobj': ''},
 'back mother': {'e_trp.dobj': ''},
 'back town': {'e_trp.dobj': ''},
 'arrive content': {'e_trp.dobj': ''},
 'arrive object': {'e_trp.dobj': ''},
 'attain information': {'e_trp.dobj': ''},
 'attend hand': {'e_trp.dobj': ''},
 'apply food': {'e_trp.dobj': ''},
 'appreciate section': {'e_trp.dobj': ''},
 'arouse dispute': {'e_trp.dobj': ''},
 'affect fame': {'e_trp.dobj': ''},
 'agree survey': {'e_trp.dobj': ''},
 'agree word': {'e_trp.dobj': '', 'e_trp.nsv': ''},
 'announce secret': {'e_trp.dobj': ''},
 'adjust motion': {'e_trp.dobj': ''},
 'adjust theory': {'e_trp.dobj': ''},
 'admit a': {'e_trp.dobj': ''},
 'adopt content': {'e_trp.dobj': ''},
 'act_out text': {'e_trp.dobj': ''},
 'add life_expectancy': {'e_trp.dobj': ''},
 'accept execution': {'e_trp.dobj': ''},
 'accumulate work': {'e_trp.dobj': ''},
 'acknowledge mercy_killing': {'e_trp.dobj': ''},
 'act_out lesson': {'e_trp.dobj': ''},
 'leave not': {'e_trp.dobj': ''},
 'watch lantern': {'e_trp.dobj': ''},
 'abuse possibility': {'e_trp.dobj': ''},
 'divide ground': {'e_trp.dobj': ''},
 'hand composition': {'e_trp.dobj': ''},
 'hold diamond': {'e_trp.dobj': ''},
 'improve comprehension': {'e_trp.dobj': ''},
 'weaken importance': {'e_trp.dobj': ''},
 'win singer': {'e_trp.dobj': ''},
 'worry mum': {'e_trp.dobj': ''},
 'want master': {'e_trp.dobj': ''},
 'waste area': {'e_trp.dobj': ''},
 'watch waiting': {'e_trp.dobj': ''},
 'wave umbrella': {'e_trp.dobj': ''},
 'unite reason': {'e_trp.dobj': ''},
 'use ward': {'e_trp.dobj': ''},
 'utilise capacity': {'e_trp.dobj': ''},
 'wait bus': {'e_trp.dobj': ''},
 'take harm': {'e_trp.dobj': ''},
 'take sunlight': {'e_trp.dobj': ''},
 'take unemployed': {'e_trp.dobj': ''},
 'try earphone': {'e_trp.dobj': ''},
 'study homework': {'e_trp.dobj': ''},
 'succeed health': {'e_trp.dobj': ''},
 'suffer deal': {'e_trp.dobj': ''},
 'take everyday': {'e_trp.dobj': ''},
 'say si': {'e_trp.dobj': ''},
 'say trouser': {'e_trp.dobj': ''},
 'search method': {'e_trp.dobj': ''},
 'stop sense': {'e_trp.dobj': ''},
 'study do': {'e_trp.dobj': ''},
 'save workshop': {'e_trp.dobj': ''},
 'say commodity': {'e_trp.dobj': ''},
 'say lily': {'e_trp.dobj': ''},
 'say meaning': {'e_trp.dobj': ''},
 'relate programme': {'e_trp.dobj': ''},
 'report behaviour': {'e_trp.dobj': ''},
 'review knowledge': {'e_trp.dobj': ''},
 'run cave': {'e_trp.dobj': ''},
 'raise mortality': {'e_trp.dobj': ''},
 'realise society': {'e_trp.dobj': ''},
 'receive adult': {'e_trp.dobj': ''},
 'regard graduate': {'e_trp.dobj': ''},
 'promise penalty': {'e_trp.dobj': ''},
 'protect will': {'e_trp.dobj': ''},
 'prove saying': {'e_trp.dobj': ''},
 'put trouser': {'e_trp.dobj': ''},
 'perform programme': {'e_trp.dobj': ''},
 'postpone achievement': {'e_trp.dobj': ''},
 'prepare term': {'e_trp.dobj': ''},
 'preserve life-style': {'e_trp.dobj': ''},
 'obtain factor': {'e_trp.dobj': ''},
 'order experience': {'e_trp.dobj': ''},
 'own accord': {'e_trp.dobj': ''},
 'pass_on card': {'e_trp.dobj': ''},
 'meet anxiety': {'e_trp.dobj': ''},
 'meet example': {'e_trp.dobj': ''},
 'need a': {'e_trp.dobj': ''},
 'obey theory': {'e_trp.dobj': ''},
 'lose afternoon': {'e_trp.dobj': ''},
 'lose grade': {'e_trp.dobj': ''},
 'lose programme': {'e_trp.dobj': ''},
 'make pull': {'e_trp.dobj': ''},
 'like health': {'e_trp.dobj': ''},
 'listen question': {'e_trp.dobj': ''},
 'live circumstance': {'e_trp.dobj': ''},
 'look mum': {'e_trp.dobj': ''},
 'lead diamond': {'e_trp.dobj': ''},
 'legalize thing': {'e_trp.dobj': ''},
 'lend classroom': {'e_trp.dobj': ''},
 'impact benefit': {'e_trp.dobj': ''},
 'improve estate': {'e_trp.dobj': ''},
 'know dear': {'e_trp.dobj': ''},
 'know pa': {'e_trp.dobj': ''},
 'have social_service': {'e_trp.dobj': ''},
 'have waste': {'e_trp.dobj': ''},
 'having power': {'e_trp.dobj': ''},
 'illustrate inequality': {'e_trp.dobj': ''},
 'have adaptation': {'e_trp.dobj': ''},
 'have delight': {'e_trp.dobj': ''},
 'have harm': {'e_trp.dobj': ''},
 'give practise': {'e_trp.dobj': ''},
 'give_out sob': {'e_trp.dobj': ''},
 'grasp life': {'e_trp.dobj': ''},
 'grasp use': {'e_trp.dobj': ''},
 'gain condition': {'e_trp.dobj': ''},
 'get behaviour': {'e_trp.dobj': '', 'e_trp.nsv': ''},
 'give dictation': {'e_trp.dobj': ''},
 'follow directory': {'e_trp.dobj': ''},
 'form stratum': {'e_trp.dobj': ''},
 'found relationship': {'e_trp.dobj': ''},
 'fulfil test': {'e_trp.dobj': ''},
 'exist shortage': {'e_trp.dobj': ''},
 'expose ability': {'e_trp.dobj': ''},
 'finish distance': {'e_trp.dobj': ''},
 'follow behaviour': {'e_trp.dobj': ''},
 'do haste': {'e_trp.dobj': ''},
 'do li': {'e_trp.dobj': ''},
 'do supper': {'e_trp.dobj': ''},
 'earn trouble': {'e_trp.dobj': ''},
 'enclose sheet': {'e_trp.dobj': ''},
 'consider moon': {'e_trp.dobj': ''},
 'cover stream': {'e_trp.dobj': ''},
 'do goods': {'e_trp.dobj': ''},
 'change go': {'e_trp.dobj': ''},
 'change myth': {'e_trp.dobj': ''},
 'confuse part': {'e_trp.dobj': ''},
 'conquer race': {'e_trp.dobj': ''},
 'break_up relation': {'e_trp.dobj': ''},
 'cause space': {'e_trp.dobj': ''},
 'centre debate': {'e_trp.dobj': ''},
 'answer day': {'e_trp.dobj': ''},
 'arrange building': {'e_trp.dobj': ''},
 'back knowledge': {'e_trp.dobj': ''},
 'admit theory': {'e_trp.dobj': ''},
 'accept knowledge': {'e_trp.dobj': ''},
 'answer better': {'e_trp.dobj': ''},
 'get aim': {'e_trp.dobj': ''},
 'teacher-student good': {'e_trp.amod_n_a': ''},
 'chopstick one-off': {'e_trp.amod_n_a': ''},
 'elder collapsed': {'e_trp.amod_n_a': ''},
 'mortaility infant': {'e_trp.amod_n_a': ''},
 'elder collasped': {'e_trp.amod_n_a': ''},
 'passerby 19th': {'e_trp.amod_n_a': ''},
 'food home-prepared': {'e_trp.amod_n_a': ''},
 'phenomenon dishonest': {'e_trp.amod_n_a': ''},
 'creativity plentiful': {'e_trp.amod_n_a': ''},
 'robot exquisite': {'e_trp.amod_n_a': ''},
 'area job-related': {'e_trp.amod_n_a': ''},
 'craze postgraduate': {'e_trp.amod_n_a': ''},
 'elderly fallen': {'e_trp.amod_n_a': ''},
 'price-list current': {'e_trp.amod_n_a': ''},
 'norm interactive': {'e_trp.amod_n_a': ''},
 'teacher psychological': {'e_trp.amod_n_a': ''},
 'cleaner hiring': {'e_trp.amod_n_a': ''},
 'development all-around': {'e_trp.amod_n_a': ''},
 'course utilitarian': {'e_trp.amod_n_a': ''},
 'civilization excellent': {'e_trp.amod_n_a': ''},
 'examination memorable': {'e_trp.amod_n_a': ''},
 'university first-rate': {'e_trp.amod_n_a': ''},
 'size unfit': {'e_trp.amod_n_a': ''},
 'group sex-separate': {'e_trp.amod_n_a': ''},
 'custom deep-rooted': {'e_trp.amod_n_a': ''},
 'service overdrawing': {'e_trp.amod_n_a': ''},
 'student well-qualified': {'e_trp.amod_n_a': ''},
 'craze traveling': {'e_trp.amod_n_a': ''},
 'job high-paid': {'e_trp.amod_n_a': ''},
 'employee would-be': {'e_trp.amod_n_a': ''},
 'businessman illegal': {'e_trp.amod_n_a': ''},
 'scientist venusian': {'e_trp.amod_n_a': ''},
 'fact above-mentioned': {'e_trp.amod_n_a': ''},
 'envrionment good': {'e_trp.amod_n_a': ''},
 'professor first-class': {'e_trp.amod_n_a': ''},
 'shoping online': {'e_trp.amod_n_a': ''},
 'occupation male-dominated': {'e_trp.amod_n_a': ''},
 'child spoiling': {'e_trp.amod_n_a': ''},
 'food iron-rich': {'e_trp.amod_n_a': ''},
 'teacher-student positive': {'e_trp.amod_n_a': ''},
 'student so-so': {'e_trp.amod_n_a': ''},
 'phenomenon not-uncommon': {'e_trp.amod_n_a': ''},
 'force fast-growing': {'e_trp.amod_n_a': ''},
 'diet fat-reducing': {'e_trp.amod_n_a': ''},
 '1996 late': {'e_trp.amod_n_a': ''},
 'knowledge extracurricular': {'e_trp.amod_n_a': ''},
 'healthcare enviable': {'e_trp.amod_n_a': ''},
 'device tablet-like': {'e_trp.amod_n_a': ''},
 'trillion uncountable': {'e_trp.amod_n_a': ''},
 'signal wordless': {'e_trp.amod_n_a': ''},
 'necessary spoken': {'e_trp.amod_n_a': ''},
 'labor down-to-earth': {'e_trp.amod_n_a': ''},
 'pattern exam-oriented': {'e_trp.amod_n_a': ''},
 'society fast-growing': {'e_trp.amod_n_a': ''},
 'million starving': {'e_trp.amod_n_a': ''},
 'hotline psychological': {'e_trp.amod_n_a': ''},
 'population ever-dropping': {'e_trp.amod_n_a': ''},
 'society fierce': {'e_trp.amod_n_a': ''},
 'right hard-earned': {'e_trp.amod_n_a': ''},
 'lecturer selecting': {'e_trp.amod_n_a': ''},
 'rate popularizing': {'e_trp.amod_n_a': ''},
 'photographer well-meaning': {'e_trp.amod_n_a': ''},
 'gose saying': {'e_trp.amod_n_a': ''},
 'lecture selecting': {'e_trp.amod_n_a': ''},
 'tide undesirable': {'e_trp.amod_n_a': ''},
 'car ever-increasing': {'e_trp.amod_n_a': ''},
 'home-planet only': {'e_trp.amod_n_a': ''},
 'teacher-student bad': {'e_trp.amod_n_a': ''},
 'convient very': {'e_trp.amod_n_a': ''},
 'oil swill-cooked': {'e_trp.amod_n_a': ''},
 'prommote responsible': {'e_trp.amod_n_a': ''},
 'pressure overdue': {'e_trp.amod_n_a': ''},
 'institution government-established': {'e_trp.amod_n_a': ''},
 'conception examination-oriented': {'e_trp.amod_n_a': ''},
 'examination post-graduate': {'e_trp.amod_n_a': ''},
 'culture especial': {'e_trp.amod_n_a': ''},
 'factor above-mentioned': {'e_trp.amod_n_a': ''},
 'leisure-time favorite': {'e_trp.amod_n_a': ''},
 'professor world-famous': {'e_trp.amod_n_a': ''},
 'necessity long-term': {'e_trp.amod_n_a': ''},
 'case gun-shot': {'e_trp.amod_n_a': ''},
 'limitation property-purchasing': {'e_trp.amod_n_a': ''},
 'education test-oriented': {'e_trp.amod_n_a': ''},
 'program unhealthy': {'e_trp.amod_n_a': ''},
 'list memorizing': {'e_trp.amod_n_a': ''},
 'smoking second-hand': {'e_trp.amod_n_a': ''},
 'woman light-skinned': {'e_trp.amod_n_a': ''},
 'food unqualified': {'e_trp.amod_n_a': ''},
 'aftermath visible': {'e_trp.amod_n_a': ''},
 'blogs micro': {'e_trp.amod_n_a': ''},
 'organization darkest': {'e_trp.amod_n_a': ''},
 'phrase frequently-used': {'e_trp.amod_n_a': ''},
 'college fresh-faced': {'e_trp.amod_n_a': ''},
 'rigidness relative': {'e_trp.amod_n_a': ''},
 'advertisement unhealthy': {'e_trp.amod_n_a': ''},
 'phenomenon waste': {'e_trp.amod_n_a': ''},
 'vapour poisonous': {'e_trp.amod_n_a': ''},
 'talent well-educated': {'e_trp.amod_n_a': ''},
 'textbook second-hand': {'e_trp.amod_n_a': ''},
 'side-effects unhealthy': {'e_trp.amod_n_a': ''},
 'car petrol-engined': {'e_trp.amod_n_a': ''},
 'dad police-chief': {'e_trp.amod_n_a': ''},
 'commoditiess fake': {'e_trp.amod_n_a': ''},
 'columnist dear': {'e_trp.amod_n_a': ''},
 'mechanism decision-making': {'e_trp.amod_n_a': ''},
 'member dormitory': {'e_trp.amod_n_a': ''},
 'calorie stored': {'e_trp.amod_n_a': ''},
 'teen trick-playing': {'e_trp.amod_n_a': ''},
 '20 new': {'e_trp.amod_n_a': ''},
 'improtant very': {'e_trp.amod_n_a': ''},
 'approach prevention-only': {'e_trp.amod_n_a': ''},
 'phenomenon unequal': {'e_trp.amod_n_a': ''},
 'store reputed': {'e_trp.amod_n_a': ''},
 'coldness fearful': {'e_trp.amod_n_a': ''},
 'suchas chinese': {'e_trp.amod_n_a': ''},
 'card hand-drawn': {'e_trp.amod_n_a': ''},
 'history time-honored': {'e_trp.amod_n_a': ''},
 'man lighter-skinned': {'e_trp.amod_n_a': ''},
 'revelation reciprocal': {'e_trp.amod_n_a': ''},
 'complaint scribbled': {'e_trp.amod_n_a': ''},
 'activity non-academic': {'e_trp.amod_n_a': ''},
 'e-book reading': {'e_trp.amod_n_a': ''},
 'scholarship second-class': {'e_trp.amod_n_a': ''},
 'merchant gluttonous': {'e_trp.amod_n_a': ''},
 'self-employment graduate': {'e_trp.amod_n_a': ''},
 'certificate graduated': {'e_trp.amod_n_a': ''},
 'dorm harmonious': {'e_trp.amod_n_a': ''},
 'dad imposing': {'e_trp.amod_n_a': ''},
 'incentive finer': {'e_trp.amod_n_a': ''},
 'people criticising': {'e_trp.amod_n_a': ''},
 '1924 dated': {'e_trp.amod_n_a': ''},
 'mean dishonest': {'e_trp.amod_n_a': ''},
 'relationship dormitory': {'e_trp.amod_n_a': ''},
 'thing importent': {'e_trp.amod_n_a': ''},
 'facility superficial': {'e_trp.amod_n_a': ''},
 'learing online': {'e_trp.amod_n_a': ''},
 'study oversea': {'e_trp.amod_n_a': ''},
 'pround very': {'e_trp.amod_n_a': ''},
 'camera photo-video': {'e_trp.amod_n_a': ''},
 'gassesand poisonous': {'e_trp.amod_n_a': ''},
 'work saitisfied': {'e_trp.amod_n_a': ''},
 'graduate would-be': {'e_trp.amod_n_a': ''},
 'attitude unlearning': {'e_trp.amod_n_a': ''},
 'tunnel warmer': {'e_trp.amod_n_a': ''},
 'thing newly-emerged': {'e_trp.amod_n_a': ''},
 'beverage taiwan-manufactured': {'e_trp.amod_n_a': ''},
 'people mid-aged': {'e_trp.amod_n_a': ''},
 'pressure job-hunting': {'e_trp.amod_n_a': ''},
 'opportunity life-transforming': {'e_trp.amod_n_a': ''},
 'lecture listening': {'e_trp.amod_n_a': ''},
 'exam post-graduate': {'e_trp.amod_n_a': ''},
 'reason above-mentioned': {'e_trp.amod_n_a': ''},
 'history conditioned': {'e_trp.amod_n_a': ''},
 'society high-speed': {'e_trp.amod_n_a': ''},
 'self-study evening': {'e_trp.amod_n_a': ''},
 'are examination-oriented': {'e_trp.amod_n_a': ''},
 'scholarship first-class': {'e_trp.amod_n_a': ''},
 'administrator dormitory': {'e_trp.amod_n_a': ''},
 'brand unaffected': {'e_trp.amod_n_a': ''},
 'enjoyment open-hearted': {'e_trp.amod_n_a': ''},
 'pear watery': {'e_trp.amod_n_a': ''},
 'devotion whole-hearted': {'e_trp.amod_n_a': ''},
 'lecture psychological': {'e_trp.amod_n_a': ''},
 'occurrence quick': {'e_trp.amod_n_a': ''},
 'phenomenon long-lasting': {'e_trp.amod_n_a': ''},
 'matter in_question': {'e_trp.amod_n_a': ''},
 'producer lawful': {'e_trp.amod_n_a': ''},
 'determination joyless': {'e_trp.amod_n_a': ''},
 'trip time-consuming': {'e_trp.amod_n_a': ''},
 'imago lovely': {'e_trp.amod_n_a': ''},
 'mean superb': {'e_trp.amod_n_a': ''},
 'death_rate boosting': {'e_trp.amod_n_a': ''},
 'cultu chinese': {'e_trp.amod_n_a': ''},
 'effect above-mentioned': {'e_trp.amod_n_a': ''},
 'reality amenable': {'e_trp.amod_n_a': ''},
 'book extracurricular': {'e_trp.amod_n_a': ''},
 'loan impoverished': {'e_trp.amod_n_a': ''},
 'bird broken-winged': {'e_trp.amod_n_a': ''},
 'book abundant': {'e_trp.amod_n_a': ''},
 'habbit good': {'e_trp.amod_n_a': ''},
 'ritual confucius-commemorating': {'e_trp.amod_n_a': ''},
 'life delighting': {'e_trp.amod_n_a': ''},
 'substance non-edible': {'e_trp.amod_n_a': ''},
 'retailer incredible': {'e_trp.amod_n_a': ''},
 'impotant very': {'e_trp.amod_n_a': ''},
 'choi-ce wise': {'e_trp.amod_n_a': ''},
 'carbon so-called': {'e_trp.amod_n_a': ''},
 'increse steady': {'e_trp.amod_n_a': ''},
 'street well-patroled': {'e_trp.amod_n_a': ''},
 'commoditis online': {'e_trp.amod_n_a': ''},
 'conception quality-oriented': {'e_trp.amod_n_a': ''},
 'ad unhealthy': {'e_trp.amod_n_a': ''},
 'essence lean': {'e_trp.amod_n_a': ''},
 'log-cabin snug': {'e_trp.amod_n_a': ''},
 'marrige happy': {'e_trp.amod_n_a': ''},
 'habbits bad': {'e_trp.amod_n_a': ''},
 'after-sale good': {'e_trp.amod_n_a': ''},
 'institution government-supported': {'e_trp.amod_n_a': ''},
 'condition dining': {'e_trp.amod_n_a': ''},
 'worry due': {'e_trp.amod_n_a': ''},
 'change earth-shaking': {'e_trp.amod_n_a': ''},
 'wind blowed': {'e_trp.amod_n_a': ''},
 'college business-launching': {'e_trp.amod_n_a': ''},
 'goods combat': {'e_trp.amod_n_a': ''},
 'treatment a.': {'e_trp.amod_n_a': ''},
 'affection bad': {'e_trp.amod_n_a': ''},
 'society fast-developing': {'e_trp.amod_n_a': ''},
 'university so-called': {'e_trp.amod_n_a': ''},
 'desire strong_enough': {'e_trp.amod_n_a': ''},
 'in. live': {'e_trp.amod_n_a': ''},
 'task long-term': {'e_trp.amod_n_a': ''},
 'lira modern': {'e_trp.amod_n_a': ''},
 'foodstuff unsafe': {'e_trp.amod_n_a': ''},
 'concern wide-spread': {'e_trp.amod_n_a': ''},
 'differents physiological': {'e_trp.amod_n_a': ''},
 'brevity probable': {'e_trp.amod_n_a': ''},
 'malaria injected': {'e_trp.amod_n_a': ''},
 'lie lies-little': {'e_trp.amod_n_a': ''},
 'factor unsustainable': {'e_trp.amod_n_a': ''},
 'manager white-collar': {'e_trp.amod_n_a': ''},
 'book paper-based': {'e_trp.amod_n_a': ''},
 'sexism so-called': {'e_trp.amod_n_a': ''},
 'point-of-view societal': {'e_trp.amod_n_a': ''},
 'picture thought-provoking': {'e_trp.amod_n_a': ''},
 'chopstick throwaway': {'e_trp.amod_n_a': ''},
 'marriage trust-based': {'e_trp.amod_n_a': ''},
 'education long-distance': {'e_trp.amod_n_a': ''},
 'broadcaster most-heard': {'e_trp.amod_n_a': ''},
 'camaraderie pleasurable': {'e_trp.amod_n_a': ''},
 'work poineering': {'e_trp.amod_n_a': ''},
 'benefit ever-lasting': {'e_trp.amod_n_a': ''},
 'protetion copyright': {'e_trp.amod_n_a': ''},
 'kid due': {'e_trp.amod_n_a': ''},
 'spirit hard-working': {'e_trp.amod_n_a': ''},
 'youngster characteristic': {'e_trp.amod_n_a': ''},
 'note ardent': {'e_trp.amod_n_a': ''},
 'reputaion good': {'e_trp.amod_n_a': ''},
 'corpulence excessive': {'e_trp.amod_n_a': ''},
 'knowledge extra-curricular': {'e_trp.amod_n_a': ''},
 'daughter cross-country': {'e_trp.amod_n_a': ''},
 'area developped': {'e_trp.amod_n_a': ''},
 'basketbets better': {'e_trp.amod_n_a': ''},
 'score high-test': {'e_trp.amod_n_a': ''},
 'supervision shopping': {'e_trp.amod_n_a': ''},
 'student oversea': {'e_trp.amod_n_a': ''},
 'material paper-based': {'e_trp.amod_n_a': ''},
 'situation inharmonious': {'e_trp.amod_n_a': ''},
 'importment very': {'e_trp.amod_n_a': ''},
 'standing qualified': {'e_trp.amod_n_a': ''},
 'klm london-bound': {'e_trp.amod_n_a': ''},
 'friendship misinterpreted': {'e_trp.amod_n_a': ''},
 'certificate useless': {'e_trp.amod_n_a': ''},
 'device newborn': {'e_trp.amod_n_a': ''},
 'stuff old-fashioned': {'e_trp.amod_n_a': ''},
 'life self-reliant': {'e_trp.amod_n_a': ''},
 'roommate several': {'e_trp.amod_n_a': ''},
 'basketbets shopping': {'e_trp.amod_n_a': ''},
 'difficulty short-term': {'e_trp.amod_n_a': ''},
 'stranger unforgettable': {'e_trp.amod_n_a': ''},
 'thing unharmonious': {'e_trp.amod_n_a': ''},
 'advantage manny': {'e_trp.amod_n_a': ''},
 'office psychological': {'e_trp.amod_n_a': ''},
 'advertisement harmful': {'e_trp.amod_n_a': ''},
 'friend heart-to-heart': {'e_trp.amod_n_a': ''},
 'action hideous-looking': {'e_trp.amod_n_a': ''},
 'management immoral': {'e_trp.amod_n_a': ''},
 'leader evil-minded': {'e_trp.amod_n_a': ''},
 'program fanciful': {'e_trp.amod_n_a': ''},
 'spurt fantastic': {'e_trp.amod_n_a': ''},
 'education all-around': {'e_trp.amod_n_a': ''},
 'talent application-oriented': {'e_trp.amod_n_a': ''},
 'spelling-check automatic': {'e_trp.amod_n_a': ''},
 'comedy g-rated': {'e_trp.amod_n_a': ''},
 'eloquence good': {'e_trp.amod_n_a': ''},
 'graduate dishonest': {'e_trp.amod_n_a': ''},
 'brushstroke distinctive': {'e_trp.amod_n_a': ''},
 'teacher dormitory': {'e_trp.amod_n_a': ''},
 'card e-greeting': {'e_trp.amod_n_a': ''},
 'exam endless': {'e_trp.amod_n_a': ''},
 'triumph enjoyable': {'e_trp.amod_n_a': ''},
 'priorities-one conflicting': {'e_trp.amod_n_a': ''},
 'festival crucial': {'e_trp.amod_n_a': ''},
 'brushstroke dashed': {'e_trp.amod_n_a': ''},
 'self-help called': {'e_trp.amod_n_a': ''},
 'organ cloning': {'e_trp.amod_n_a': ''},
 'passer-by 19th': {'e_trp.amod_n_a': ''},
 'psychology fluky': {'e_trp.amod_n_a': ''},
 'everyday fucked': {'e_trp.amod_n_a': ''},
 'campaign government-led': {'e_trp.amod_n_a': ''},
 'cause elective': {'e_trp.amod_n_a': ''},
 'country english-spoken': {'e_trp.amod_n_a': ''},
 'businessman profit-minded': {'e_trp.amod_n_a': ''},
 'snack quick-frozen': {'e_trp.amod_n_a': ''},
 'education teacher-centered': {'e_trp.amod_n_a': ''},
 'relationship totalistic': {'e_trp.amod_n_a': ''},
 'couple unable': {'e_trp.amod_n_a': ''},
 'tool uncovered': {'e_trp.amod_n_a': ''},
 'thing undue': {'e_trp.amod_n_a': ''},
 'eath other': {'e_trp.amod_n_a': ''},
 'convinient very': {'e_trp.amod_n_a': ''},
 'diffcult very': {'e_trp.amod_n_a': ''},
 'security well-organized': {'e_trp.amod_n_a': ''},
 'vareity wide': {'e_trp.amod_n_a': ''},
 'confidence rebuilt-up': {'e_trp.amod_n_a': ''},
 'tone reigning': {'e_trp.amod_n_a': ''},
 'jinfenshijia small': {'e_trp.amod_n_a': ''},
 'perfection spelling': {'e_trp.amod_n_a': ''},
 'phenomenon inharmonious': {'e_trp.amod_n_a': ''},
 'precondition interior': {'e_trp.amod_n_a': ''},
 'yueyue little': {'e_trp.amod_n_a': ''},
 'pace live': {'e_trp.amod_n_a': ''},
 'critic middle-aged': {'e_trp.amod_n_a': ''},
 'accident moped-pedestrian': {'e_trp.amod_n_a': ''},
 'masterpiece long-promised': {'e_trp.amod_n_a': ''},
 'mean multi-medium': {'e_trp.amod_n_a': ''},
 'karaoke nonstop': {'e_trp.amod_n_a': ''},
 'thing on-line': {'e_trp.amod_n_a': ''},
 'bag one-off': {'e_trp.amod_n_a': ''},
 'shpping online': {'e_trp.amod_n_a': ''},
 'life un-regretful': {'e_trp.amod_n_a': ''},
 'daughter unbearable': {'e_trp.amod_n_a': ''},
 'teacher-student unfavorable': {'e_trp.amod_n_a': ''},
 'thing inharmonious': {'e_trp.amod_n_a': ''},
 'feeling intrapersonal': {'e_trp.amod_n_a': ''},
 'market job-hunting': {'e_trp.amod_n_a': ''},
 'law severer': {'e_trp.amod_n_a': ''},
 'car environmentally-aware': {'e_trp.amod_n_a': ''},
 'fact heart-breaking': {'e_trp.amod_n_a': ''},
 'problem heated': {'e_trp.amod_n_a': ''},
 'news illusive': {'e_trp.amod_n_a': ''},
 'entertainment beneficiary': {'e_trp.amod_n_a': ''},
 'people cold-blooded': {'e_trp.amod_n_a': ''},
 'sport 11th': {'e_trp.amod_n_a': ''},
 'disease food-born': {'e_trp.amod_n_a': ''},
 'goods faking': {'e_trp.amod_n_a': ''},
 'oue best': {'e_trp.amod_n_a': ''},
 'bedroll big': {'e_trp.amod_n_a': ''},
 'life disharmonious': {'e_trp.amod_n_a': ''},
 '303 dormitory': {'e_trp.amod_n_a': ''},
 'reputation due': {'e_trp.amod_n_a': ''},
 'pre-hugh early': {'e_trp.amod_n_a': ''},
 'experience hard-earned': {'e_trp.amod_n_a': ''},
 'teacher-student harmonious': {'e_trp.amod_n_a': ''},
 'role importent': {'e_trp.amod_n_a': ''},
 'student incalculable': {'e_trp.amod_n_a': ''},
 'enrollment ever-expanding': {'e_trp.amod_n_a': ''},
 'significance far-reaching': {'e_trp.amod_n_a': ''},
 'underclass 100_million-strong': {'e_trp.amod_n_a': ''},
 'foal academic': {'e_trp.amod_n_a': ''},
 'scheme acquired': {'e_trp.amod_n_a': ''},
 'self-control adequate': {'e_trp.amod_n_a': ''},
 'effection bad': {'e_trp.amod_n_a': ''},
 'habbit bad': {'e_trp.amod_n_a': ''},
 'college g-rated': {'e_trp.amod_n_a': ''},
 'authority so-called': {'e_trp.amod_n_a': ''},
 'tip so-called': {'e_trp.amod_n_a': ''},
 'tear synthetic': {'e_trp.amod_n_a': ''},
 'test time-consuming': {'e_trp.amod_n_a': ''},
 'craze travelling': {'e_trp.amod_n_a': ''},
 'statement true-false': {'e_trp.amod_n_a': ''},
 'railway underdeveloped': {'e_trp.amod_n_a': ''},
 'trail unforeseen': {'e_trp.amod_n_a': ''},
 'goods on-line': {'e_trp.amod_n_a': ''},
 'televiewers passive': {'e_trp.amod_n_a': ''},
 'coast pathless': {'e_trp.amod_n_a': ''},
 'commen very': {'e_trp.amod_n_a': ''},
 'commom very': {'e_trp.amod_n_a': ''},
 'killing wayward': {'e_trp.amod_n_a': ''},
 'essay well-organied': {'e_trp.amod_n_a': ''},
 'futune wonderful': {'e_trp.amod_n_a': ''},
 'counterpart pirated': {'e_trp.amod_n_a': ''},
 'teacher-student pleasurable': {'e_trp.amod_n_a': ''},
 'agreement pre-marital': {'e_trp.amod_n_a': ''},
 'moped private': {'e_trp.amod_n_a': ''},
 'class public-speaking': {'e_trp.amod_n_a': ''},
 'activity publical': {'e_trp.amod_n_a': ''},
 'fashion pursing': {'e_trp.amod_n_a': ''},
 'altar rocky': {'e_trp.amod_n_a': ''},
 'prefertial self-employed': {'e_trp.amod_n_a': ''},
 'stunt shameful': {'e_trp.amod_n_a': ''},
 'certificate job-related': {'e_trp.amod_n_a': ''},
 'amout large': {'e_trp.amod_n_a': ''},
 '1960 late': {'e_trp.amod_n_a': ''},
 'reason life-and-death': {'e_trp.amod_n_a': ''},
 'teacherteacher life-long': {'e_trp.amod_n_a': ''},
 'dialect learning': {'e_trp.amod_n_a': ''},
 'code lifeless': {'e_trp.amod_n_a': ''},
 'ward lit': {'e_trp.amod_n_a': ''},
 'person weak-willed': {'e_trp.amod_n_a': ''},
 'circumstance whatsoever': {'e_trp.amod_n_a': ''},
 'gose old': {'e_trp.amod_n_a': ''},
 'goods over-packing': {'e_trp.amod_n_a': ''},
 'pratice social': {'e_trp.amod_n_a': ''},
 'sorrow social': {'e_trp.amod_n_a': ''},
 'consumption spendthrift': {'e_trp.amod_n_a': ''},
 'inequity tangible': {'e_trp.amod_n_a': ''},
 'indication unfair': {'e_trp.amod_n_a': ''},
 'story unforgetable': {'e_trp.amod_n_a': ''},
 'life unharmonious': {'e_trp.amod_n_a': ''},
 'paradise love-filled': {'e_trp.amod_n_a': ''},
 'friend pleasurable': {'e_trp.amod_n_a': ''},
 'accident police-reported': {'e_trp.amod_n_a': ''},
 'factor premier': {'e_trp.amod_n_a': ''},
 'work-life proper': {'e_trp.amod_n_a': ''},
 'society rapid': {'e_trp.amod_n_a': ''},
 'rising sea-levering': {'e_trp.amod_n_a': ''},
 'jod good': {'e_trp.amod_n_a': ''},
 'benevolence good-hearted': {'e_trp.amod_n_a': ''},
 'condition dormitory': {'e_trp.amod_n_a': ''},
 'university dreaming': {'e_trp.amod_n_a': ''},
 'collasped elder': {'e_trp.amod_n_a': ''},
 'temperament elegant': {'e_trp.amod_n_a': ''},
 'ability english-speaking': {'e_trp.amod_n_a': ''},
 'commodity enormous': {'e_trp.amod_n_a': ''},
 'farce confused': {'e_trp.amod_n_a': ''},
 'idears different': {'e_trp.amod_n_a': ''},
 'see benevolent': {'e_trp.amod_n_a': ''},
 'schoolyard better': {'e_trp.amod_n_a': ''},
 'spell built-in': {'e_trp.amod_n_a': ''},
 'student-teacher closer': {'e_trp.amod_n_a': ''},
 'feeling admiring': {'e_trp.amod_n_a': ''},
 'bride ill-fated': {'e_trp.amod_n_a': ''},
 'wedding ill-fated': {'e_trp.amod_n_a': ''},
 'merchant illegal': {'e_trp.amod_n_a': ''},
 'pedlar illegal': {'e_trp.amod_n_a': ''},
 'air illimitable': {'e_trp.amod_n_a': ''},
 'phenomenon immoral': {'e_trp.amod_n_a': ''},
 'skydiving impromptu': {'e_trp.amod_n_a': ''},
 'secretareis executive': {'e_trp.amod_n_a': ''},
 'commodies fake': {'e_trp.amod_n_a': ''},
 'book extra-curricular': {'e_trp.amod_n_a': ''},
 'commodites fake': {'e_trp.amod_n_a': ''},
 'loyalty comradely': {'e_trp.amod_n_a': ''},
 'life dialy': {'e_trp.amod_n_a': ''},
 'hurt frequent': {'e_trp.amod_n_a': ''},
 'sciencific good': {'e_trp.amod_n_a': ''},
 'destrucktion great': {'e_trp.amod_n_a': ''},
 'harmony dormitory': {'e_trp.amod_n_a': ''},
 'sword doubled-edged': {'e_trp.amod_n_a': ''},
 'phenomenon due': {'e_trp.amod_n_a': ''},
 'employee elder': {'e_trp.amod_n_a': ''},
 'fruently english': {'e_trp.amod_n_a': ''},
 'opportunity hard-won': {'e_trp.amod_n_a': ''},
 'shcool high': {'e_trp.amod_n_a': ''},
 'tutor hiring': {'e_trp.amod_n_a': ''},
 'representative imaginary': {'e_trp.amod_n_a': ''},
 'citys big': {'e_trp.amod_n_a': ''},
 'alcoholic boastful': {'e_trp.amod_n_a': ''},
 'nutrition body-building': {'e_trp.amod_n_a': ''},
 'spirit break-new-ground': {'e_trp.amod_n_a': ''},
 'self-introduction brief': {'e_trp.amod_n_a': ''},
 'curriculum broad-based': {'e_trp.amod_n_a': ''},
 'historian c.': {'e_trp.amod_n_a': ''},
 'consanguinity chinese': {'e_trp.amod_n_a': ''},
 'research aberrant': {'e_trp.amod_n_a': ''},
 'bill above-mentioned': {'e_trp.amod_n_a': ''},
 'characteristic above-mentioned': {'e_trp.amod_n_a': ''},
 'trailblazer aggressive': {'e_trp.amod_n_a': ''},
 'retailer alike': {'e_trp.amod_n_a': ''},
 'development repaid': {'e_trp.amod_n_a': ''},
 'teacher-student rosy': {'e_trp.amod_n_a': ''},
 'shool senior': {'e_trp.amod_n_a': ''},
 'people shabby-dressed': {'e_trp.amod_n_a': ''},
 'onling shopping': {'e_trp.amod_n_a': ''},
 'businessman triumphant': {'e_trp.amod_n_a': ''},
 'heritage non-material': {'e_trp.amod_n_a': ''},
 'verse non-traditional': {'e_trp.amod_n_a': ''},
 'chat_room online': {'e_trp.amod_n_a': ''},
 'game indulged': {'e_trp.amod_n_a': ''},
 'talent inter-disciplinary': {'e_trp.amod_n_a': ''},
 'poem leading': {'e_trp.amod_n_a': ''},
 'dog-ends lighting': {'e_trp.amod_n_a': ''},
 'commission unproportional': {'e_trp.amod_n_a': ''},
 'self-improvement unremitting': {'e_trp.amod_n_a': ''},
 'thing unuseful': {'e_trp.amod_n_a': ''},
 'student upright': {'e_trp.amod_n_a': ''},
 'e-book using': {'e_trp.amod_n_a': ''},
 'inportant very': {'e_trp.amod_n_a': ''},
 'boy warm-hearted': {'e_trp.amod_n_a': ''},
 'graduate well-educated': {'e_trp.amod_n_a': ''},
 'philosopher well-known': {'e_trp.amod_n_a': ''},
 'attitude well-meaning': {'e_trp.amod_n_a': ''},
 'essay well-organized': {'e_trp.amod_n_a': ''},
 'increase steedy': {'e_trp.amod_n_a': ''},
 'technique supervising': {'e_trp.amod_n_a': ''},
 'semi-colon pivotal': {'e_trp.amod_n_a': ''},
 'carbon-life low': {'e_trp.amod_n_a': ''},
 'misadventure mobile': {'e_trp.amod_n_a': ''},
 'zmnvfdkfnalksnefr n.': {'e_trp.amod_n_a': ''},
 'hug wormy': {'e_trp.amod_n_a': ''},
 'word wrongly-spelled': {'e_trp.amod_n_a': ''},
 'mask vivid': {'e_trp.amod_n_a': ''},
 'educator well-known': {'e_trp.amod_n_a': ''},
 'worker white-collared': {'e_trp.amod_n_a': ''},
 'availibility wide': {'e_trp.amod_n_a': ''},
 'image never-before-seen': {'e_trp.amod_n_a': ''},
 'phenominon new': {'e_trp.amod_n_a': ''},
 'merrymaking noisy': {'e_trp.amod_n_a': ''},
 'arrangement non-traditional': {'e_trp.amod_n_a': ''},
 '1 number': {'e_trp.amod_n_a': ''},
 'pursuit one-sided': {'e_trp.amod_n_a': ''},
 'bag outer-packed': {'e_trp.amod_n_a': ''},
 'spot over-crowded': {'e_trp.amod_n_a': ''},
 'active-ties recreational': {'e_trp.amod_n_a': ''},
 'life safe_and_sound': {'e_trp.amod_n_a': ''},
 'lecturer select': {'e_trp.amod_n_a': ''},
 'text self-made': {'e_trp.amod_n_a': ''},
 'doe shopping': {'e_trp.amod_n_a': ''},
 'onlion shopping': {'e_trp.amod_n_a': ''},
 'finacial significant': {'e_trp.amod_n_a': ''},
 'stranger tame': {'e_trp.amod_n_a': ''},
 'festival thrilling': {'e_trp.amod_n_a': ''},
 'interview triumphant': {'e_trp.amod_n_a': ''},
 'preacher unfrocked': {'e_trp.amod_n_a': ''},
 'department indispensable': {'e_trp.amod_n_a': ''},
 'speech infective': {'e_trp.amod_n_a': ''},
 'life inharmonious': {'e_trp.amod_n_a': ''},
 'air-conditioner installing': {'e_trp.amod_n_a': ''},
 'hobby lazy': {'e_trp.amod_n_a': ''},
 'fine lean': {'e_trp.amod_n_a': ''},
 'lifestyle low-carbon': {'e_trp.amod_n_a': ''},
 'scandal made-up': {'e_trp.amod_n_a': ''},
 'worry meaningless': {'e_trp.amod_n_a': ''},
 'business meat-packing': {'e_trp.amod_n_a': ''},
 'folk-songs melodious': {'e_trp.amod_n_a': ''},
 'shoe merchant': {'e_trp.amod_n_a': ''},
 'fieldworker mexican': {'e_trp.amod_n_a': ''},
 'refrigerator modest': {'e_trp.amod_n_a': ''},
 'marrige naked': {'e_trp.amod_n_a': ''},
 'exercise skill-based': {'e_trp.amod_n_a': ''},
 'doe smoking': {'e_trp.amod_n_a': ''},
 'device so-called': {'e_trp.amod_n_a': ''},
 'protector so-called': {'e_trp.amod_n_a': ''},
 'student so-called': {'e_trp.amod_n_a': ''},
 'word plosive': {'e_trp.amod_n_a': ''},
 'cellphones possible': {'e_trp.amod_n_a': ''},
 'life post-marriage': {'e_trp.amod_n_a': ''},
 'cartel profitable': {'e_trp.amod_n_a': ''},
 'teacher-student promising': {'e_trp.amod_n_a': ''},
 'speech pubic': {'e_trp.amod_n_a': ''},
 '1959 published': {'e_trp.amod_n_a': ''},
 'system aa': {'e_trp.amod_n_a': ''},
 'entity akin': {'e_trp.amod_n_a': ''},
 'individual alike': {'e_trp.amod_n_a': ''},
 'sence common': {'e_trp.amod_n_a': ''},
 'phenomenon comparing': {'e_trp.amod_n_a': ''},
 'character complex-formed': {'e_trp.amod_n_a': ''},
 'obsession concentrated': {'e_trp.amod_n_a': ''},
 'snack contaminated': {'e_trp.amod_n_a': ''},
 'people crowed': {'e_trp.amod_n_a': ''},
 'canteen dear': {'e_trp.amod_n_a': ''},
 'scords better': {'e_trp.amod_n_a': ''},
 'word borrowing': {'e_trp.amod_n_a': ''},
 'dialect busy': {'e_trp.amod_n_a': ''},
 'water-garden celebrated': {'e_trp.amod_n_a': ''},
 'course certificate-oriented': {'e_trp.amod_n_a': ''},
 'mistake chinese': {'e_trp.amod_n_a': ''},
 'are citied': {'e_trp.amod_n_a': ''},
 'answer diverse': {'e_trp.amod_n_a': ''},
 'rule dormitory': {'e_trp.amod_n_a': ''},
 'bread dyed': {'e_trp.amod_n_a': ''},
 'gramme english': {'e_trp.amod_n_a': ''},
 'learing english': {'e_trp.amod_n_a': ''},
 'secrecy enjoyable': {'e_trp.amod_n_a': ''},
 'mistake growing': {'e_trp.amod_n_a': ''},
 'patentability high': {'e_trp.amod_n_a': ''},
 'fiance ideal': {'e_trp.amod_n_a': ''},
 'one ill-advised': {'e_trp.amod_n_a': ''},
 'fieldworker illegal': {'e_trp.amod_n_a': ''},
 'ad harmful': {'e_trp.amod_n_a': ''},
 'phenomenon harmonious': {'e_trp.amod_n_a': ''},
 'university high-ranking': {'e_trp.amod_n_a': ''},
 'method hit-or-miss': {'e_trp.amod_n_a': ''},
 'mammal hunting': {'e_trp.amod_n_a': ''},
 'seller immoral': {'e_trp.amod_n_a': ''},
 'reason importent': {'e_trp.amod_n_a': ''},
 'menbers family': {'e_trp.amod_n_a': ''},
 'excuse feeblest': {'e_trp.amod_n_a': ''},
 'one 40-year-old': {'e_trp.amod_n_a': ''},
 'analysis above-mentioned': {'e_trp.amod_n_a': ''},
 'case above-mentioned': {'e_trp.amod_n_a': ''},
 'issue above-mentioned': {'e_trp.amod_n_a': ''},
 'ethos bad': {'e_trp.amod_n_a': ''},
 'coutries foreign': {'e_trp.amod_n_a': ''},
 'snake foreign': {'e_trp.amod_n_a': ''},
 'dormitory good': {'e_trp.amod_n_a': ''},
 'menthods good': {'e_trp.amod_n_a': ''},
 'opions different': {'e_trp.amod_n_a': ''},
 'oppions different': {'e_trp.amod_n_a': ''},
 'market disabling': {'e_trp.amod_n_a': ''},
 'situation disharmonious': {'e_trp.amod_n_a': ''},
 'event dishonest': {'e_trp.amod_n_a': ''},
 'friend dormitory': {'e_trp.amod_n_a': ''},
 'freshman dramatic': {'e_trp.amod_n_a': ''},
 'problem drunken': {'e_trp.amod_n_a': ''},
 'bread dyeing': {'e_trp.amod_n_a': ''},
 'language easy-learning': {'e_trp.amod_n_a': ''},
 'tolerance courtly': {'e_trp.amod_n_a': ''},
 'people deferent': {'e_trp.amod_n_a': ''},
 'news-not best': {'e_trp.amod_n_a': ''},
 'chain biologic': {'e_trp.amod_n_a': ''},
 'sincerity black_and_white': {'e_trp.amod_n_a': ''},
 'life-style chaste': {'e_trp.amod_n_a': ''},
 'conflict child-care': {'e_trp.amod_n_a': ''},
 'city-dwellers chinese': {'e_trp.amod_n_a': ''},
 'campus colourful': {'e_trp.amod_n_a': ''},
 'bag platic': {'e_trp.amod_n_a': ''},
 'test post-graduate': {'e_trp.amod_n_a': ''},
 'property pre-marital': {'e_trp.amod_n_a': ''},
 'yakker premier': {'e_trp.amod_n_a': ''},
 'marriage prenup-based': {'e_trp.amod_n_a': ''},
 'konwledge professional': {'e_trp.amod_n_a': ''},
 'concers public': {'e_trp.amod_n_a': ''},
 'weapon unclear': {'e_trp.amod_n_a': ''},
 'advertisement undesirable': {'e_trp.amod_n_a': ''},
 'mood unfavorable': {'e_trp.amod_n_a': ''},
 'thing unforgetable': {'e_trp.amod_n_a': ''},
 'website unhealthy': {'e_trp.amod_n_a': ''},
 'tuition newly-adopted': {'e_trp.amod_n_a': ''},
 'phenomenon newly-born': {'e_trp.amod_n_a': ''},
 'figure offical': {'e_trp.amod_n_a': ''},
 'chopstick one-time': {'e_trp.amod_n_a': ''},
 'educaton online': {'e_trp.amod_n_a': ''},
 'attention paied': {'e_trp.amod_n_a': ''},
 'hod part-time': {'e_trp.amod_n_a': ''},
 'jods part-time': {'e_trp.amod_n_a': ''},
 'controversy peculiar': {'e_trp.amod_n_a': ''},
 'life unregretful': {'e_trp.amod_n_a': ''},
 'student warm-hearted': {'e_trp.amod_n_a': ''},
 'people weak-willed': {'e_trp.amod_n_a': ''},
 '120-acre weed-choked': {'e_trp.amod_n_a': ''},
 'carry well-deserved': {'e_trp.amod_n_a': ''},
 'elite well-educated': {'e_trp.amod_n_a': ''},
 'knowledge well-established': {'e_trp.amod_n_a': ''},
 'word world-changing': {'e_trp.amod_n_a': ''},
 'low-carbon real': {'e_trp.amod_n_a': ''},
 'sum record-breaking': {'e_trp.amod_n_a': ''},
 'spotsduring scenic': {'e_trp.amod_n_a': ''},
 'way self-centered': {'e_trp.amod_n_a': ''},
 'student self-motivated': {'e_trp.amod_n_a': ''},
 'success so-called': {'e_trp.amod_n_a': ''},
 'century soul-stirring': {'e_trp.amod_n_a': ''},
 'competition spoken': {'e_trp.amod_n_a': ''},
 'disadvantage static': {'e_trp.amod_n_a': ''},
 'software subject-related': {'e_trp.amod_n_a': ''},
 'aftertaste infinite': {'e_trp.amod_n_a': ''},
 'habit innovative': {'e_trp.amod_n_a': ''},
 'witht involved': {'e_trp.amod_n_a': ''},
 'student kindhearted': {'e_trp.amod_n_a': ''},
 'homework layered': {'e_trp.amod_n_a': ''},
 'male lighter-skinned': {'e_trp.amod_n_a': ''},
 'stander living': {'e_trp.amod_n_a': ''},
 'drive long-term': {'e_trp.amod_n_a': ''},
 'control macroscopical': {'e_trp.amod_n_a': ''},
 'stranger memorable': {'e_trp.amod_n_a': ''},
 'student misbehaved': {'e_trp.amod_n_a': ''},
 'road multi-lane': {'e_trp.amod_n_a': ''},
 'low-carbon living': {'e_trp.amod_n_a': ''},
 'psychology lucky': {'e_trp.amod_n_a': ''},
 'job major-related': {'e_trp.amod_n_a': ''},
 'factor man-made': {'e_trp.amod_n_a': ''},
 'building many-storied': {'e_trp.amod_n_a': ''},
 'socity modern': {'e_trp.amod_n_a': ''},
 'date multi-medium': {'e_trp.amod_n_a': ''},
 'one unmoral': {'e_trp.amod_n_a': ''},
 'phenomenon unreasonable': {'e_trp.amod_n_a': ''},
 'spirit unremitting': {'e_trp.amod_n_a': ''},
 'appliance up-to-date': {'e_trp.amod_n_a': ''},
 'society upwardly_mobile': {'e_trp.amod_n_a': ''},
 'gald very': {'e_trp.amod_n_a': ''},
 'usefull very': {'e_trp.amod_n_a': ''},
 'college well-educated': {'e_trp.amod_n_a': ''},
 'phenomenon wide-spread': {'e_trp.amod_n_a': ''},
 'concern world-wide': {'e_trp.amod_n_a': ''},
 'phenomenon new-born': {'e_trp.amod_n_a': ''},
 'correspondent new_york-based': {'e_trp.amod_n_a': ''},
 'screen non-glossy': {'e_trp.amod_n_a': ''},
 'signal non-verbal': {'e_trp.amod_n_a': ''},
 'product one-off': {'e_trp.amod_n_a': ''},
 'connection one-to-one': {'e_trp.amod_n_a': ''},
 'shoppping online': {'e_trp.amod_n_a': ''},
 'disadvantage overweight': {'e_trp.amod_n_a': ''},
 'reader packable': {'e_trp.amod_n_a': ''},
 'computer paly': {'e_trp.amod_n_a': ''},
 'phenomenon plagiarizing': {'e_trp.amod_n_a': ''},
 'after-sale poor': {'e_trp.amod_n_a': ''},
 'graduate post-': {'e_trp.amod_n_a': ''},
 'crazy postgraduate': {'e_trp.amod_n_a': ''},
 'ofen powerful': {'e_trp.amod_n_a': ''},
 'angle prettiest': {'e_trp.amod_n_a': ''},
 'mane primeval': {'e_trp.amod_n_a': ''},
 'message texting': {'e_trp.amod_n_a': ''},
 'wedding tobacco-free': {'e_trp.amod_n_a': ''},
 'socieries traditional': {'e_trp.amod_n_a': ''},
 'job triumphant': {'e_trp.amod_n_a': ''},
 'self-development unceasing': {'e_trp.amod_n_a': ''},
 'metaphor unconventional': {'e_trp.amod_n_a': ''},
 'height wuthering': {'e_trp.amod_n_a': ''},
 'war knowledge-based': {'e_trp.amod_n_a': ''},
 'race-car licensed': {'e_trp.amod_n_a': ''},
 'belief life-long': {'e_trp.amod_n_a': ''},
 'friendship life-long': {'e_trp.amod_n_a': ''},
 'girl light-skinned': {'e_trp.amod_n_a': ''},
 'couplet red': {'e_trp.amod_n_a': ''},
 'iphone revolutionary': {'e_trp.amod_n_a': ''},
 'income rural-urban': {'e_trp.amod_n_a': ''},
 'ability self-reliant': {'e_trp.amod_n_a': ''},
 'guy semi-believable': {'e_trp.amod_n_a': ''},
 'fisherman senior': {'e_trp.amod_n_a': ''},
 'period senior': {'e_trp.amod_n_a': ''},
 'diease serious': {'e_trp.amod_n_a': ''},
 'affact significant': {'e_trp.amod_n_a': ''},
 'plow sophisticated': {'e_trp.amod_n_a': ''},
 'self-discipline strong': {'e_trp.amod_n_a': ''},
 'custom studing': {'e_trp.amod_n_a': ''},
 'privatetutoringis beneficial': {'e_trp.amod_n_a': ''},
 'institution best-known': {'e_trp.amod_n_a': ''},
 'diploma better': {'e_trp.amod_n_a': ''},
 'lawrence_harvey_zeiger born': {'e_trp.amod_n_a': ''},
 'merit born': {'e_trp.amod_n_a': ''},
 'person cloning': {'e_trp.amod_n_a': ''},
 'adult 18_year_old': {'e_trp.amod_n_a': ''},
 'birthday 57th': {'e_trp.amod_n_a': ''},
 'member 5th': {'e_trp.amod_n_a': ''},
 'measure according': {'e_trp.amod_n_a': ''},
 'teleplay american': {'e_trp.amod_n_a': ''},
 'idiom animal': {'e_trp.amod_n_a': ''},
 'day beatful': {'e_trp.amod_n_a': ''},
 'cyberspace healthy': {'e_trp.amod_n_a': ''},
 'pyramid healthy-eating': {'e_trp.amod_n_a': ''},
 'schooldays high': {'e_trp.amod_n_a': ''},
 'strenth high': {'e_trp.amod_n_a': ''},
 'people high-educated': {'e_trp.amod_n_a': ''},
 'job higher-paid': {'e_trp.amod_n_a': ''},
 'swerve horrible': {'e_trp.amod_n_a': ''},
 'age hyper-competitive': {'e_trp.amod_n_a': ''},
 'part importent': {'e_trp.amod_n_a': ''},
 'representative impressionist': {'e_trp.amod_n_a': ''},
 'future ever-brighter': {'e_trp.amod_n_a': ''},
 'gas existed': {'e_trp.amod_n_a': ''},
 'litterateur famous': {'e_trp.amod_n_a': ''},
 'developes fast': {'e_trp.amod_n_a': ''},
 'pasture fast': {'e_trp.amod_n_a': ''},
 'way fast-paced': {'e_trp.amod_n_a': ''},
 'assignment finishing': {'e_trp.amod_n_a': ''},
 'talent compound': {'e_trp.amod_n_a': ''},
 'assumption crushing': {'e_trp.amod_n_a': ''},
 'schoolmaster dear': {'e_trp.amod_n_a': ''},
 'sign delicious': {'e_trp.amod_n_a': ''},
 'dorm flat': {'e_trp.amod_n_a': ''},
 '1985 formed': {'e_trp.amod_n_a': ''},
 'deficiency grammatical': {'e_trp.amod_n_a': ''},
 'compus green': {'e_trp.amod_n_a': ''},
 'oppinions different': {'e_trp.amod_n_a': ''},
 'degree doctorial': {'e_trp.amod_n_a': ''},
 'society dog-eat-dog': {'e_trp.amod_n_a': ''},
 'car drived': {'e_trp.amod_n_a': ''},
 'behavior drunken-driving': {'e_trp.amod_n_a': ''},
 'disadvantage due': {'e_trp.amod_n_a': ''},
 'balance ecologic': {'e_trp.amod_n_a': ''},
 'ship elder': {'e_trp.amod_n_a': ''},
 'tutor employing': {'e_trp.amod_n_a': ''},
 'term energy-saving': {'e_trp.amod_n_a': ''},
 'crowd-pleaser enormous': {'e_trp.amod_n_a': ''},
 'projects entrepreneurial': {'e_trp.amod_n_a': ''},
 'role essencial': {'e_trp.amod_n_a': ''},
 'poultries domestic': {'e_trp.amod_n_a': ''},
 'culture dormitory': {'e_trp.amod_n_a': ''},
 'effect double-edged': {'e_trp.amod_n_a': ''},
 'job dreaming': {'e_trp.amod_n_a': ''},
 'externality due': {'e_trp.amod_n_a': ''},
 'feature due': {'e_trp.amod_n_a': ''},
 'society due': {'e_trp.amod_n_a': ''},
 'teacher due': {'e_trp.amod_n_a': ''},
 'economist earliest': {'e_trp.amod_n_a': ''},
 'ticket easing': {'e_trp.amod_n_a': ''},
 'crissis economic': {'e_trp.amod_n_a': ''},
 'dormitary harmonious': {'e_trp.amod_n_a': ''},
 'study harmonious': {'e_trp.amod_n_a': ''},
 'promble healthy': {'e_trp.amod_n_a': ''},
 'communication heart-to-heart': {'e_trp.amod_n_a': ''},
 'clone helpful': {'e_trp.amod_n_a': ''},
 'person high-level': {'e_trp.amod_n_a': ''},
 'transportation high-speed': {'e_trp.amod_n_a': ''},
 'seller higher-rated': {'e_trp.amod_n_a': ''},
 'festival home-grown': {'e_trp.amod_n_a': ''},
 'professor humorous': {'e_trp.amod_n_a': ''},
 'shop hypostatic': {'e_trp.amod_n_a': ''},
 'self-defense important': {'e_trp.amod_n_a': ''},
 'choise best': {'e_trp.amod_n_a': ''},
 'effect bestly': {'e_trp.amod_n_a': ''},
 'attention brave': {'e_trp.amod_n_a': ''},
 '1902 built-in': {'e_trp.amod_n_a': ''},
 'festival caribbean-inspired': {'e_trp.amod_n_a': ''},
 'microbloggers chinese': {'e_trp.amod_n_a': ''},
 'poultries choice': {'e_trp.amod_n_a': ''},
 'pursuit cognitive': {'e_trp.amod_n_a': ''},
 'chopstick common': {'e_trp.amod_n_a': ''},
 'trade 16th': {'e_trp.amod_n_a': ''},
 'phenomenon above-mentioned': {'e_trp.amod_n_a': ''},
 'work above-mentioned': {'e_trp.amod_n_a': ''},
 'culture achievement-obsessed': {'e_trp.amod_n_a': ''},
 'advertisement adverse': {'e_trp.amod_n_a': ''},
 'trailblazers aggressive': {'e_trp.amod_n_a': ''},
 'citizen aiding': {'e_trp.amod_n_a': ''},
 'situation all-black': {'e_trp.amod_n_a': ''},
 'development all-sided': {'e_trp.amod_n_a': ''},
 'management amoral': {'e_trp.amod_n_a': ''},
 'value artic': {'e_trp.amod_n_a': ''},
 'spot artificial': {'e_trp.amod_n_a': ''},
 'marriage bare': {'e_trp.amod_n_a': ''},
 'trainer battered': {'e_trp.amod_n_a': ''},
 'professor first_class': {'e_trp.amod_n_a': ''},
 'college fresher': {'e_trp.amod_n_a': ''},
 'vehicle gas-burning': {'e_trp.amod_n_a': ''},
 'language gender-neutral': {'e_trp.amod_n_a': ''},
 'aunt gleaning': {'e_trp.amod_n_a': ''},
 'intension good': {'e_trp.amod_n_a': ''},
 'jop good': {'e_trp.amod_n_a': ''},
 'deed good-hearted': {'e_trp.amod_n_a': ''},
 'photograph graduating': {'e_trp.amod_n_a': ''},
 'entrepreneurs great': {'e_trp.amod_n_a': ''},
 'quantity ever-increasing': {'e_trp.amod_n_a': ''},
 'specialty extracurricular': {'e_trp.amod_n_a': ''},
 'chat face-to-face': {'e_trp.amod_n_a': ''},
 'mumbers family': {'e_trp.amod_n_a': ''},
 'economy fast-developing': {'e_trp.amod_n_a': ''},
 'heart comparative': {'e_trp.amod_n_a': ''},
 'highway computer-monitored': {'e_trp.amod_n_a': ''},
 'authority correlated': {'e_trp.amod_n_a': ''},
 'phenomenon corrupt': {'e_trp.amod_n_a': ''},
 'parent dearest': {'e_trp.amod_n_a': ''},
 'craftwork decorating': {'e_trp.amod_n_a': ''},
 'food delious': {'e_trp.amod_n_a': ''},
 'winter snow-free': {'e_trp.amod_n_a': ''},
 'perfection so-called': {'e_trp.amod_n_a': ''},
 'reason so-called': {'e_trp.amod_n_a': ''},
 'habit spelling': {'e_trp.amod_n_a': ''},
 'learning spoken': {'e_trp.amod_n_a': ''},
 'high-tech stone': {'e_trp.amod_n_a': ''},
 'class student-centered': {'e_trp.amod_n_a': ''},
 'mode student-centered': {'e_trp.amod_n_a': ''},
 'method teacher-centered': {'e_trp.amod_n_a': ''},
 'block thawed': {'e_trp.amod_n_a': ''},
 'word unacquainted': {'e_trp.amod_n_a': ''},
 'businessman undesirable': {'e_trp.amod_n_a': ''},
 'mistake undue': {'e_trp.amod_n_a': ''},
 'absence unexcuted': {'e_trp.amod_n_a': ''},
 'customer unimportant': {'e_trp.amod_n_a': ''},
 'hot-spot new': {'e_trp.amod_n_a': ''},
 'discussion night-long': {'e_trp.amod_n_a': ''},
 'geometry non-euclidean': {'e_trp.amod_n_a': ''},
 'tooling non-standard': {'e_trp.amod_n_a': ''},
 'polymath noted': {'e_trp.amod_n_a': ''},
 'tool one-off': {'e_trp.amod_n_a': ''},
 'dealing one-on-one': {'e_trp.amod_n_a': ''},
 'people ordinate': {'e_trp.amod_n_a': ''},
 'education oversea': {'e_trp.amod_n_a': ''},
 'slave long-suffering': {'e_trp.amod_n_a': ''},
 'ability lousy': {'e_trp.amod_n_a': ''},
 'anniversary luxurious': {'e_trp.amod_n_a': ''},
 'fairy-tales many': {'e_trp.amod_n_a': ''},
 'system marked-oriented': {'e_trp.amod_n_a': ''},
 'critic masterful': {'e_trp.amod_n_a': ''},
 'exam memorable': {'e_trp.amod_n_a': ''},
 'product micro-electric': {'e_trp.amod_n_a': ''},
 'consumer middle-aged': {'e_trp.amod_n_a': ''},
 'notebook minute': {'e_trp.amod_n_a': ''},
 'niews misleading': {'e_trp.amod_n_a': ''},
 'philosophy most-enduring': {'e_trp.amod_n_a': ''},
 'behicles motor': {'e_trp.amod_n_a': ''},
 'e-paper multi-lingual': {'e_trp.amod_n_a': ''},
 'chairman multibillionaire': {'e_trp.amod_n_a': ''},
 'teacher-student negative': {'e_trp.amod_n_a': ''},
 'fators unsustainable': {'e_trp.amod_n_a': ''},
 'afforestation urban': {'e_trp.amod_n_a': ''},
 'gap urban-rural': {'e_trp.amod_n_a': ''},
 'girl well-behaved': {'e_trp.amod_n_a': ''},
 'campus well-known': {'e_trp.amod_n_a': ''},
 'investigator well-known': {'e_trp.amod_n_a': ''},
 'city world-renowned': {'e_trp.amod_n_a': ''},
 'language world-wide': {'e_trp.amod_n_a': ''},
 'grade pleasurable': {'e_trp.amod_n_a': ''},
 'sdtudies postgraduate': {'e_trp.amod_n_a': ''},
 'low-carbon present': {'e_trp.amod_n_a': ''},
 'tutorings private': {'e_trp.amod_n_a': ''},
 'method problem-solving': {'e_trp.amod_n_a': ''},
 'high-quality pursuing': {'e_trp.amod_n_a': ''},
 'seletively reading': {'e_trp.amod_n_a': ''},
 'money redundant': {'e_trp.amod_n_a': ''},
 'depth rosy': {'e_trp.amod_n_a': ''},
 'consciousness safe': {'e_trp.amod_n_a': ''},
 'car scraped': {'e_trp.amod_n_a': ''},
 'bicycle second-hand': {'e_trp.amod_n_a': ''},
 'message second-hand': {'e_trp.amod_n_a': ''},
 'ugliness seeing': {'e_trp.amod_n_a': ''},
 'room self-teaching': {'e_trp.amod_n_a': ''},
 'shcool senior': {'e_trp.amod_n_a': ''},
 'decision-making shady': {'e_trp.amod_n_a': ''},
 'after-sale shopping': {'e_trp.amod_n_a': ''},
 'oline shopping': {'e_trp.amod_n_a': ''},
 'onlie shopping': {'e_trp.amod_n_a': ''},
 'onlin shopping': {'e_trp.amod_n_a': ''},
 'people short_for': {'e_trp.amod_n_a': ''},
 'sulfur shoveling': {'e_trp.amod_n_a': ''},
 'peopel young': {'e_trp.amod_n_a': ''},
 'clue writing': {'e_trp.amod_n_a': ''},
 'factor insecure': {'e_trp.amod_n_a': ''},
 'metropilis international': {'e_trp.amod_n_a': ''},
 'forum irresistible': {'e_trp.amod_n_a': ''},
 'konw just': {'e_trp.amod_n_a': ''},
 '20/12/98 latest': {'e_trp.amod_n_a': ''},
 'station life-relaying': {'e_trp.amod_n_a': ''},
 'redcape little': {'e_trp.amod_n_a': ''},
 'temperture increasing': {'e_trp.amod_n_a': ''},
 'passerby indifferent': {'e_trp.amod_n_a': ''},
 'atmosphere inharmonious': {'e_trp.amod_n_a': ''},
 'factor inharmonious': {'e_trp.amod_n_a': ''},
 'temperament inner': {'e_trp.amod_n_a': ''},
 'attitude instinct': {'e_trp.amod_n_a': ''},
 'payable irrevocable': {'e_trp.amod_n_a': ''},
 'zhang jade': {'e_trp.amod_n_a': ''},
 'curriculum joyful': {'e_trp.amod_n_a': ''},
 'woman kind-hearted': {'e_trp.amod_n_a': ''},
 'works laid-off': {'e_trp.amod_n_a': ''},
 'spelling lax': {'e_trp.amod_n_a': ''},
 'education life-long': {'e_trp.amod_n_a': ''},
 'student light-skinned': {'e_trp.amod_n_a': ''},
 'impression lighted': {'e_trp.amod_n_a': ''},
 'talent literal': {'e_trp.amod_n_a': ''},
 'hrad little': {'e_trp.amod_n_a': ''},
 'diet unreasonable': {'e_trp.amod_n_a': ''},
 'imformation useful': {'e_trp.amod_n_a': ''},
 'conveninent very': {'e_trp.amod_n_a': ''},
 'pressure vocational': {'e_trp.amod_n_a': ''},
 'slab walking': {'e_trp.amod_n_a': ''},
 'foundation well-knit': {'e_trp.amod_n_a': ''},
 'animation well-known': {'e_trp.amod_n_a': ''},
 'go well-known': {'e_trp.amod_n_a': ''},
 'masterpiece well-known': {'e_trp.amod_n_a': ''},
 'judgment whatsoever': {'e_trp.amod_n_a': ''},
 'employment nervous': {'e_trp.amod_n_a': ''},
 '51test. net': {'e_trp.amod_n_a': ''},
 'konwledge new': {'e_trp.amod_n_a': ''},
 'talk_show nightly': {'e_trp.amod_n_a': ''},
 'passer-by nineteenth': {'e_trp.amod_n_a': ''},
 'people non-local': {'e_trp.amod_n_a': ''},
 'activism non-violent': {'e_trp.amod_n_a': ''},
 'perfection number': {'e_trp.amod_n_a': ''},
 'boy one-time': {'e_trp.amod_n_a': ''},
 'shoppings online': {'e_trp.amod_n_a': ''},
 'boy out-going': {'e_trp.amod_n_a': ''},
 'lecture outdated': {'e_trp.amod_n_a': ''},
 'overnight out_of_date': {'e_trp.amod_n_a': ''},
 'advantage overweight': {'e_trp.amod_n_a': ''},
 'game paly': {'e_trp.amod_n_a': ''},
 'ob part-time': {'e_trp.amod_n_a': ''},
 'lady silver-haired': {'e_trp.amod_n_a': ''},
 'jolt slamming': {'e_trp.amod_n_a': ''},
 'yue small': {'e_trp.amod_n_a': ''},
 'difference so-called': {'e_trp.amod_n_a': ''},
 'double-personality so-called': {'e_trp.amod_n_a': ''},
 'feminism so-called': {'e_trp.amod_n_a': ''},
 'field so-called': {'e_trp.amod_n_a': ''},
 'construction socialistic': {'e_trp.amod_n_a': ''},
 'he sticked': {'e_trp.amod_n_a': ''},
 'self-respect strong': {'e_trp.amod_n_a': ''},
 'state sub-healthy': {'e_trp.amod_n_a': ''},
 'stranger surrounding': {'e_trp.amod_n_a': ''},
 'buiding tall': {'e_trp.amod_n_a': ''},
 'letter thanks-giving': {'e_trp.amod_n_a': ''},
 'passer-by that': {'e_trp.amod_n_a': ''},
 'holiday tourism-based': {'e_trp.amod_n_a': ''},
 'thing un-useful': {'e_trp.amod_n_a': ''},
 'mosquito uncountable': {'e_trp.amod_n_a': ''},
 'memory unforgetable': {'e_trp.amod_n_a': ''},
 'situation unharmonious': {'e_trp.amod_n_a': ''},
 'habbits unhealthy': {'e_trp.amod_n_a': ''},
 'choice unheard_of': {'e_trp.amod_n_a': ''},
 "cann't live": {'e_trp.amod_n_a': ''},
 'flight london-bound': {'e_trp.amod_n_a': ''},
 'theirselves lost': {'e_trp.amod_n_a': ''},
 'friend love-making': {'e_trp.amod_n_a': ''},
 'annircrsaries luxurious': {'e_trp.amod_n_a': ''},
 'flavor meet': {'e_trp.amod_n_a': ''},
 'economy microcosmic': {'e_trp.amod_n_a': ''},
 'man mid-aged': {'e_trp.amod_n_a': ''},
 'marsh mosquito-breeding': {'e_trp.amod_n_a': ''},
 'classroom multi-medium': {'e_trp.amod_n_a': ''},
 'building mushrooming': {'e_trp.amod_n_a': ''},
 'resouces natural': {'e_trp.amod_n_a': ''},
 'infulence negative': {'e_trp.amod_n_a': ''},
 'skill writting': {'e_trp.amod_n_a': ''},
 'resource per_capita': {'e_trp.amod_n_a': ''},
 'combustion petrol-driven': {'e_trp.amod_n_a': ''},
 'principle play-hard': {'e_trp.amod_n_a': ''},
 'water poluted': {'e_trp.amod_n_a': ''},
 "people'quickly poor": {'e_trp.amod_n_a': ''},
 'broadcastor popular': {'e_trp.amod_n_a': ''},
 'low-carbon popular': {'e_trp.amod_n_a': ''},
 'notion post-modern': {'e_trp.amod_n_a': ''},
 'test postgraduate': {'e_trp.amod_n_a': ''},
 'trip pre-arranged': {'e_trp.amod_n_a': ''},
 'agreement pre-marriage': {'e_trp.amod_n_a': ''},
 'assignment prefab': {'e_trp.amod_n_a': ''},
 'c. presentational': {'e_trp.amod_n_a': ''},
 'value puritan': {'e_trp.amod_n_a': ''},
 'step quick-passing': {'e_trp.amod_n_a': ''},
 'school quiting': {'e_trp.amod_n_a': ''},
 'professor randy': {'e_trp.amod_n_a': ''},
 'underestimate real': {'e_trp.amod_n_a': ''},
 'collocation reasonable': {'e_trp.amod_n_a': ''},
 'sophomore respectful': {'e_trp.amod_n_a': ''},
 'elective right': {'e_trp.amod_n_a': ''},
 'development roaring': {'e_trp.amod_n_a': ''},
 'education rosy': {'e_trp.amod_n_a': ''},
 'grade satisfied': {'e_trp.amod_n_a': ''},
 'thing satisfied': {'e_trp.amod_n_a': ''},
 'condition schooling': {'e_trp.amod_n_a': ''},
 'smoker second-hand': {'e_trp.amod_n_a': ''},
 'transaction secondhand': {'e_trp.amod_n_a': ''},
 'role egmental': {'e_trp.amod_n_a': ''},
 'message self-made': {'e_trp.amod_n_a': ''},
 'exercise self-serving': {'e_trp.amod_n_a': ''},
 'shelter shabby': {'e_trp.amod_n_a': ''},
 'datum shocking': {'e_trp.amod_n_a': ''},
 'skill communicational': {'e_trp.amod_n_a': ''},
 'fascination conceptual': {'e_trp.amod_n_a': ''},
 'campus conversation-oriented': {'e_trp.amod_n_a': ''},
 'society cordial': {'e_trp.amod_n_a': ''},
 'cressroads cultural': {'e_trp.amod_n_a': ''},
 'class custom-made': {'e_trp.amod_n_a': ''},
 'trifle daily': {'e_trp.amod_n_a': ''},
 'manger dear': {'e_trp.amod_n_a': ''},
 'misconception deep-entrenched': {'e_trp.amod_n_a': ''},
 'reason deep-seated': {'e_trp.amod_n_a': ''},
 'failure defective': {'e_trp.amod_n_a': ''},
 '8 destructive': {'e_trp.amod_n_a': ''},
 'aspect below': {'e_trp.amod_n_a': ''},
 'institution better-known': {'e_trp.amod_n_a': ''},
 'society blundering': {'e_trp.amod_n_a': ''},
 'lawrance_harvey_zeiger born': {'e_trp.amod_n_a': ''},
 'engel bright': {'e_trp.amod_n_a': ''},
 'metre broken': {'e_trp.amod_n_a': ''},
 'gate cabinet': {'e_trp.amod_n_a': ''},
 'life career-centered': {'e_trp.amod_n_a': ''},
 'youngster＇s characteristic': {'e_trp.amod_n_a': ''},
 'ole cleaner': {'e_trp.amod_n_a': ''},
 'dorm coffin-styled': {'e_trp.amod_n_a': ''},
 'opnions different': {'e_trp.amod_n_a': ''},
 'peopie different': {'e_trp.amod_n_a': ''},
 'phenomenonena different': {'e_trp.amod_n_a': ''},
 'view diffident': {'e_trp.amod_n_a': ''},
 'thing disharmonious': {'e_trp.amod_n_a': ''},
 'emission disorderly': {'e_trp.amod_n_a': ''},
 'opinion dissimilar': {'e_trp.amod_n_a': ''},
 'certificate diverse': {'e_trp.amod_n_a': ''},
 'match diving': {'e_trp.amod_n_a': ''},
 'college dreaming': {'e_trp.amod_n_a': ''},
 'drivings drunk': {'e_trp.amod_n_a': ''},
 'drivings drunken': {'e_trp.amod_n_a': ''},
 'elective due': {'e_trp.amod_n_a': ''},
 'bun dyed': {'e_trp.amod_n_a': ''},
 'teacher easy-going': {'e_trp.amod_n_a': ''},
 'society economized': {'e_trp.amod_n_a': ''},
 'imperfection editorial': {'e_trp.amod_n_a': ''},
 'test english-speaking': {'e_trp.amod_n_a': ''},
 'study happier': {'e_trp.amod_n_a': ''},
 'chance hard-won': {'e_trp.amod_n_a': ''},
 'circumstance harmonious': {'e_trp.amod_n_a': ''},
 'domitory harmonious': {'e_trp.amod_n_a': ''},
 'hormitory harmonious': {'e_trp.amod_n_a': ''},
 'molecule heat-absorbing': {'e_trp.amod_n_a': ''},
 'phenomenon heated': {'e_trp.amod_n_a': ''},
 'body heathy': {'e_trp.amod_n_a': ''},
 'magazine home-decorating': {'e_trp.amod_n_a': ''},
 'purchase hot-headed': {'e_trp.amod_n_a': ''},
 'teacher-student ideal': {'e_trp.amod_n_a': ''},
 'attempt ill-considered': {'e_trp.amod_n_a': ''},
 'website ill-oriented': {'e_trp.amod_n_a': ''},
 'net-bars illegal': {'e_trp.amod_n_a': ''},
 'tree-felling illicit': {'e_trp.amod_n_a': ''},
 'habit improper': {'e_trp.amod_n_a': ''},
 'astronomer even': {'e_trp.amod_n_a': ''},
 'trend ever-lasting': {'e_trp.amod_n_a': ''},
 'price ever-rising': {'e_trp.amod_n_a': ''},
 'time extra-curricular': {'e_trp.amod_n_a': ''},
 'transaction face-to-face': {'e_trp.amod_n_a': ''},
 'host-king famous': {'e_trp.amod_n_a': ''},
 'talk-show famous': {'e_trp.amod_n_a': ''},
 'hospital fast': {'e_trp.amod_n_a': ''},
 'elective favourite': {'e_trp.amod_n_a': ''},
 'leisure-time favourite': {'e_trp.amod_n_a': ''},
 'competence fierce': {'e_trp.amod_n_a': ''},
 'friendship firmer': {'e_trp.amod_n_a': ''},
 'self-confidence abundant': {'e_trp.amod_n_a': ''},
 'master academic-based': {'e_trp.amod_n_a': ''},
 'professor admirable': {'e_trp.amod_n_a': ''},
 'journey all-alone': {'e_trp.amod_n_a': ''},
 'style anesthetic': {'e_trp.amod_n_a': ''},
 'moped annual': {'e_trp.amod_n_a': ''},
 'ware anti-spy': {'e_trp.amod_n_a': ''},
 'question asked-to': {'e_trp.amod_n_a': ''},
 'edition authorised': {'e_trp.amod_n_a': ''},
 'enrolment autonomous': {'e_trp.amod_n_a': ''},
 'situation aweful': {'e_trp.amod_n_a': ''},
 'transitoriness basic': {'e_trp.amod_n_a': ''},
 'carrer future': {'e_trp.amod_n_a': ''},
 'theory geocentric': {'e_trp.amod_n_a': ''},
 'temperture global': {'e_trp.amod_n_a': ''},
 'atomosphere good': {'e_trp.amod_n_a': ''},
 'choise good': {'e_trp.amod_n_a': ''},
 'leader gpabecoming': {'e_trp.amod_n_a': ''},
 'craze graduate': {'e_trp.amod_n_a': ''},
 'conveniece great': {'e_trp.amod_n_a': ''},
 'advertiser greedy': {'e_trp.amod_n_a': ''},
 'feast foreign': {'e_trp.amod_n_a': ''},
 'say foreign': {'e_trp.amod_n_a': ''},
 'inner-city former': {'e_trp.amod_n_a': ''},
 'beer free-flowing': {'e_trp.amod_n_a': ''},
 'ues full': {'e_trp.amod_n_a': ''},
 'atmosphere full-bodied': {'e_trp.amod_n_a': ''},
 'life futural': {'e_trp.amod_n_a': ''},
 'chioce good': {'e_trp.amod_n_a': ''},
 'idear good': {'e_trp.amod_n_a': ''},
 'reputatiom good': {'e_trp.amod_n_a': ''},
 'repution good': {'e_trp.amod_n_a': ''},
 'sence good': {'e_trp.amod_n_a': ''},
 'coherence graceful': {'e_trp.amod_n_a': ''},
 'achivement great': {'e_trp.amod_n_a': ''},
 'benifit great': {'e_trp.amod_n_a': ''},
 'convience great': {'e_trp.amod_n_a': ''},
 'prodigality greatest': {'e_trp.amod_n_a': ''},
 'opinons different': {'e_trp.amod_n_a': ''},
 'opinion diffident': {'e_trp.amod_n_a': ''},
 'produtors digital': {'e_trp.amod_n_a': ''},
 'carton disposable': {'e_trp.amod_n_a': ''},
 'everyday dormitory': {'e_trp.amod_n_a': ''},
 'health dormitory': {'e_trp.amod_n_a': ''},
 'essay downloaded': {'e_trp.amod_n_a': ''},
 'debate drastic': {'e_trp.amod_n_a': ''},
 'driver drived': {'e_trp.amod_n_a': ''},
 'stain drug-resistant': {'e_trp.amod_n_a': ''},
 'hazard drunk': {'e_trp.amod_n_a': ''},
 'drving drunken': {'e_trp.amod_n_a': ''},
 'drawback due': {'e_trp.amod_n_a': ''},
 'graduation due': {'e_trp.amod_n_a': ''},
 'opinion due': {'e_trp.amod_n_a': ''},
 '1880 early': {'e_trp.amod_n_a': ''},
 'low-carbon economic': {'e_trp.amod_n_a': ''},
 'intership editorial': {'e_trp.amod_n_a': ''},
 'demeanour elegant': {'e_trp.amod_n_a': ''},
 'commute eliminating': {'e_trp.amod_n_a': ''},
 'occasion embarrassed': {'e_trp.amod_n_a': ''},
 'worker employing': {'e_trp.amod_n_a': ''},
 'advertisement endless': {'e_trp.amod_n_a': ''},
 'behavior energy-saving': {'e_trp.amod_n_a': ''},
 'vehicle energy-saving': {'e_trp.amod_n_a': ''},
 'leaning english': {'e_trp.amod_n_a': ''},
 'equipment communicated': {'e_trp.amod_n_a': ''},
 'atomosphere competitive': {'e_trp.amod_n_a': ''},
 'hatred complex': {'e_trp.amod_n_a': ''},
 'expression conceited': {'e_trp.amod_n_a': ''},
 'meaning connotative': {'e_trp.amod_n_a': ''},
 'campus conservation-minded': {'e_trp.amod_n_a': ''},
 'friend contacting': {'e_trp.amod_n_a': ''},
 'study contrastive': {'e_trp.amod_n_a': ''},
 'merit convenient': {'e_trp.amod_n_a': ''},
 'opportunity cost-free': {'e_trp.amod_n_a': ''},
 'clothes cotton-padded': {'e_trp.amod_n_a': ''},
 'commodity counterfeit': {'e_trp.amod_n_a': ''},
 '2 covering': {'e_trp.amod_n_a': ''},
 'mean criminal': {'e_trp.amod_n_a': ''},
 'one cross-cultural': {'e_trp.amod_n_a': ''},
 'knowledge cutting-edge': {'e_trp.amod_n_a': ''},
 'person dead-alive': {'e_trp.amod_n_a': ''},
 'family deep-freeze-owning': {'e_trp.amod_n_a': ''},
 'socialist determined': {'e_trp.amod_n_a': ''},
 'ca123alist developed': {'e_trp.amod_n_a': ''},
 'citys different': {'e_trp.amod_n_a': ''},
 'imagist best': {'e_trp.amod_n_a': ''},
 'self-image best': {'e_trp.amod_n_a': ''},
 'low-carbon better': {'e_trp.amod_n_a': ''},
 'cuture big': {'e_trp.amod_n_a': ''},
 'scrape blue': {'e_trp.amod_n_a': ''},
 'thing brand_new': {'e_trp.amod_n_a': ''},
 'grandpa calm': {'e_trp.amod_n_a': ''},
 'student card-holding': {'e_trp.amod_n_a': ''},
 'transaction cash-free': {'e_trp.amod_n_a': ''},
 'capacity changeable': {'e_trp.amod_n_a': ''},
 'comic charcoal': {'e_trp.amod_n_a': ''},
 'machine chatting': {'e_trp.amod_n_a': ''},
 'medicine chemic': {'e_trp.amod_n_a': ''},
 'reformation chinese': {'e_trp.amod_n_a': ''},
 'condition chromatographic': {'e_trp.amod_n_a': ''},
 'passer-by cold-blooded': {'e_trp.amod_n_a': ''},
 'passerby cold-blooded': {'e_trp.amod_n_a': ''},
 'university colourful': {'e_trp.amod_n_a': ''},
 'grader 12th': {'e_trp.amod_n_a': ''},
 'advantage above-mentioned': {'e_trp.amod_n_a': ''},
 'aspect above-mentioned': {'e_trp.amod_n_a': ''},
 'opinion above-mentioned': {'e_trp.amod_n_a': ''},
 'suggestion above-mentioned': {'e_trp.amod_n_a': ''},
 'way above-mentioned': {'e_trp.amod_n_a': ''},
 'factor accountable': {'e_trp.amod_n_a': ''},
 'chore age-appropriate': {'e_trp.amod_n_a': ''},
 'speller all': {'e_trp.amod_n_a': ''},
 'view all-round': {'e_trp.amod_n_a': ''},
 'brooch almond-shaped': {'e_trp.amod_n_a': ''},
 'woman amicable': {'e_trp.amod_n_a': ''},
 'commodity annoying': {'e_trp.amod_n_a': ''},
 'people anti-globalization': {'e_trp.amod_n_a': ''},
 'artwork artificial': {'e_trp.amod_n_a': ''},
 'thermohaline atlantic': {'e_trp.amod_n_a': ''},
 'afainst available': {'e_trp.amod_n_a': ''},
 'influnce bad': {'e_trp.amod_n_a': ''},
 'family beatific': {'e_trp.amod_n_a': ''},
 'contest beaty': {'e_trp.amod_n_a': ''},
 'schoolyard beautiful': {'e_trp.amod_n_a': ''},
 'card hand-drawing': {'e_trp.amod_n_a': ''},
 'dormitory happy': {'e_trp.amod_n_a': ''},
 'hand hard-working': {'e_trp.amod_n_a': ''},
 'composition harmful': {'e_trp.amod_n_a': ''},
 'doctor-patient harmonious': {'e_trp.amod_n_a': ''},
 'void healthy': {'e_trp.amod_n_a': ''},
 'problem heart-beating': {'e_trp.amod_n_a': ''},
 'communication heart_to_heart': {'e_trp.amod_n_a': ''},
 'device hi-tech': {'e_trp.amod_n_a': ''},
 'student high-grade': {'e_trp.amod_n_a': ''},
 'development high-speeding': {'e_trp.amod_n_a': ''},
 'issue hotly-debated': {'e_trp.amod_n_a': ''},
 'greenhouse human-related': {'e_trp.amod_n_a': ''},
 'car illicit': {'e_trp.amod_n_a': ''},
 'door impersonal': {'e_trp.amod_n_a': ''},
 'society impetuous': {'e_trp.amod_n_a': ''},
 'extremly important': {'e_trp.amod_n_a': ''},
 'imformation important': {'e_trp.amod_n_a': ''},
 'communication in-depth': {'e_trp.amod_n_a': ''},
 'gap ever-widening': {'e_trp.amod_n_a': ''},
 'skulduggery everyday': {'e_trp.amod_n_a': ''},
 'coin evey': {'e_trp.amod_n_a': ''},
 'lesson excessive': {'e_trp.amod_n_a': ''},
 'mean existed': {'e_trp.amod_n_a': ''},
 'dad exuberant': {'e_trp.amod_n_a': ''},
 'attitude fact-finding': {'e_trp.amod_n_a': ''},
 'song fair-sounding': {'e_trp.amod_n_a': ''},
 'bargain fake': {'e_trp.amod_n_a': ''},
 'comodities fake': {'e_trp.amod_n_a': ''},
 'diplomat fake': {'e_trp.amod_n_a': ''},
 'medicine faked': {'e_trp.amod_n_a': ''},
 'commodity false': {'e_trp.amod_n_a': ''},
 'discrimination familiar': {'e_trp.amod_n_a': ''},
 'picture far-reaching': {'e_trp.amod_n_a': ''},
 'technology fast-developing': {'e_trp.amod_n_a': ''},
 'elective favorable': {'e_trp.amod_n_a': ''},
 'collegegraduates female': {'e_trp.amod_n_a': ''},
 'couplet festival': {'e_trp.amod_n_a': ''},
 'he fighted': {'e_trp.amod_n_a': ''},
 'person filial': {'e_trp.amod_n_a': ''},
 'palce first': {'e_trp.amod_n_a': ''},
 'lens recessive': {'e_trp.amod_n_a': ''},
 'list reciting': {'e_trp.amod_n_a': ''},
 'mall remote': {'e_trp.amod_n_a': ''},
 'string restraining': {'e_trp.amod_n_a': ''},
 'teacher richest': {'e_trp.amod_n_a': ''},
 'lecturer right': {'e_trp.amod_n_a': ''},
 'desire rigid': {'e_trp.amod_n_a': ''},
 'character rosy': {'e_trp.amod_n_a': ''},
 'end-parting same': {'e_trp.amod_n_a': ''},
 'teenages same': {'e_trp.amod_n_a': ''},
 'flavour satiric': {'e_trp.amod_n_a': ''},
 'mark satisfying': {'e_trp.amod_n_a': ''},
 "goes'no saying": {'e_trp.amod_n_a': ''},
 'skill self-learning': {'e_trp.amod_n_a': ''},
 'scholl senior': {'e_trp.amod_n_a': ''},
 'e-mail sent': {'e_trp.amod_n_a': ''},
 'promble serious': {'e_trp.amod_n_a': ''},
 'onine shopping': {'e_trp.amod_n_a': ''},
 'buidings tall': {'e_trp.amod_n_a': ''},
 'mall tedious': {'e_trp.amod_n_a': ''},
 'university testate': {'e_trp.amod_n_a': ''},
 'improtant the': {'e_trp.amod_n_a': ''},
 'basis thick': {'e_trp.amod_n_a': ''},
 'nerve tight': {'e_trp.amod_n_a': ''},
 'phenomenon time-honored': {'e_trp.amod_n_a': ''},
 'preparation toeic': {'e_trp.amod_n_a': ''},
 'master topmost': {'e_trp.amod_n_a': ''},
 'crazy travelling': {'e_trp.amod_n_a': ''},
 'communication triumphant': {'e_trp.amod_n_a': ''},
 'ad tutoring': {'e_trp.amod_n_a': ''},
 'sword two-sided': {'e_trp.amod_n_a': ''},
 'fascination unbalanced': {'e_trp.amod_n_a': ''},
 'deforestation unbridled': {'e_trp.amod_n_a': ''},
 'couple undergraduate': {'e_trp.amod_n_a': ''},
 'collective undeveloped': {'e_trp.amod_n_a': ''},
 'word undistinguishable': {'e_trp.amod_n_a': ''},
 'activity unfaithful': {'e_trp.amod_n_a': ''},
 'grade unfavorable': {'e_trp.amod_n_a': ''},
 'aspect unfavourable': {'e_trp.amod_n_a': ''},
 'effect unfavourable': {'e_trp.amod_n_a': ''},
 'people unforgivable': {'e_trp.amod_n_a': ''},
 'magnification unimaginable': {'e_trp.amod_n_a': ''},
 'activity net-based': {'e_trp.amod_n_a': ''},
 'thing new-born': {'e_trp.amod_n_a': ''},
 'student newly-graduated': {'e_trp.amod_n_a': ''},
 'passerby nineteenth': {'e_trp.amod_n_a': ''},
 'product non-essential': {'e_trp.amod_n_a': ''},
 'behavior non-verbal': {'e_trp.amod_n_a': ''},
 'height novel': {'e_trp.amod_n_a': ''},
 'people on-line': {'e_trp.amod_n_a': ''},
 'co-star one-time': {'e_trp.amod_n_a': ''},
 'illegal online-trading': {'e_trp.amod_n_a': ''},
 'waste on_line': {'e_trp.amod_n_a': ''},
 'platform open-air': {'e_trp.amod_n_a': ''},
 'way opinion-expressing': {'e_trp.amod_n_a': ''},
 'character out-going': {'e_trp.amod_n_a': ''},
 'truism outdated': {'e_trp.amod_n_a': ''},
 'barber outdoor': {'e_trp.amod_n_a': ''},
 'college oversea': {'e_trp.amod_n_a': ''},
 'pressure overweight': {'e_trp.amod_n_a': ''},
 'basketball paly': {'e_trp.amod_n_a': ''},
 'basketball palying': {'e_trp.amod_n_a': ''},
 'book paper-made': {'e_trp.amod_n_a': ''},
 'dictionary paper-made': {'e_trp.amod_n_a': ''},
 'assistant parental': {'e_trp.amod_n_a': ''},
 'jod part-time': {'e_trp.amod_n_a': ''},
 'decads past': {'e_trp.amod_n_a': ''},
 'eduction patriotic': {'e_trp.amod_n_a': ''},
 'cyberspace perfect': {'e_trp.amod_n_a': ''},
 'study-many independent': {'e_trp.amod_n_a': ''},
 'deal indirect': {'e_trp.amod_n_a': ''},
 'counterpart inexperienced': {'e_trp.amod_n_a': ''},
 'kindness insignificant': {'e_trp.amod_n_a': ''},
 'give-and-take intellectual': {'e_trp.amod_n_a': ''},
 'family inter-generational': {'e_trp.amod_n_a': ''},
 'lecture interested': {'e_trp.amod_n_a': ''},
 'campaign job-hunting': {'e_trp.amod_n_a': ''},
 'outing joyful': {'e_trp.amod_n_a': ''},
 'cellist juliard-trained': {'e_trp.amod_n_a': ''},
 'living keen': {'e_trp.amod_n_a': ''},
 'boy kind-hearted': {'e_trp.amod_n_a': ''},
 'student kind-hearted': {'e_trp.amod_n_a': ''},
 'drawback latent': {'e_trp.amod_n_a': ''},
 'argument laughing': {'e_trp.amod_n_a': ''},
 'language leaner': {'e_trp.amod_n_a': ''},
 'student left-over': {'e_trp.amod_n_a': ''},
 'confection legalistic': {'e_trp.amod_n_a': ''},
 'people less-educated': {'e_trp.amod_n_a': ''},
 'love unmature': {'e_trp.amod_n_a': ''},
 'athlete unpaid': {'e_trp.amod_n_a': ''},
 'milk unqualified': {'e_trp.amod_n_a': ''},
 'advertisement unreal': {'e_trp.amod_n_a': ''},
 'responsibility unshirkable': {'e_trp.amod_n_a': ''},
 'breeze unsympathetic': {'e_trp.amod_n_a': ''},
 'cheep very': {'e_trp.amod_n_a': ''},
 'convenint very': {'e_trp.amod_n_a': ''},
 'pessary very': {'e_trp.amod_n_a': ''},
 'populer very': {'e_trp.amod_n_a': ''},
 'prefect very': {'e_trp.amod_n_a': ''},
 'signification very': {'e_trp.amod_n_a': ''},
 'help warm-hearted': {'e_trp.amod_n_a': ''},
 'volunteer warm-heart': {'e_trp.amod_n_a': ''},
 'technology water-saving': {'e_trp.amod_n_a': ''},
 'festival water-sprinkling': {'e_trp.amod_n_a': ''},
 'konwn well': {'e_trp.amod_n_a': ''},
 'one well-known': {'e_trp.amod_n_a': ''},
 'overnight well-known': {'e_trp.amod_n_a': ''},
 'truth well-known': {'e_trp.amod_n_a': ''},
 'paragraph well-written': {'e_trp.amod_n_a': ''},
 'preacher wide': {'e_trp.amod_n_a': ''},
 'choise wise': {'e_trp.amod_n_a': ''},
 'tool-aspects wonderful': {'e_trp.amod_n_a': ''},
 'lead wordless': {'e_trp.amod_n_a': ''},
 'thing significative': {'e_trp.amod_n_a': ''},
 'cause-and-effect simple': {'e_trp.amod_n_a': ''},
 'beforce sitting': {'e_trp.amod_n_a': ''},
 'dormitory sixth': {'e_trp.amod_n_a': ''},
 'help skimming': {'e_trp.amod_n_a': ''},
 'problem sloving': {'e_trp.amod_n_a': ''},
 'bomb sneaking': {'e_trp.amod_n_a': ''},
 'antique so-called': {'e_trp.amod_n_a': ''},
 'campus so-called': {'e_trp.amod_n_a': ''},
 'difficulty so-called': {'e_trp.amod_n_a': ''},
 'experience so-called': {'e_trp.amod_n_a': ''},
 'happiness so-called': {'e_trp.amod_n_a': ''},
 'lover so-called': {'e_trp.amod_n_a': ''},
 'mainframe so-called': {'e_trp.amod_n_a': ''},
 'perfect so-called': {'e_trp.amod_n_a': ''},
 'pride so-called': {'e_trp.amod_n_a': ''},
 'scientist so-called': {'e_trp.amod_n_a': ''},
 'sexismon so-called': {'e_trp.amod_n_a': ''},
 'skill so-called': {'e_trp.amod_n_a': ''},
 'stereotype so-called': {'e_trp.amod_n_a': ''},
 'superstar so-called': {'e_trp.amod_n_a': ''},
 'are so_on': {'e_trp.amod_n_a': ''},
 'software specially-written': {'e_trp.amod_n_a': ''},
 'satisfaction spirtual': {'e_trp.amod_n_a': ''},
 'study spoken': {'e_trp.amod_n_a': ''},
 'program star-making': {'e_trp.amod_n_a': ''},
 'capital state-owned': {'e_trp.amod_n_a': ''},
 'person strong-minded': {'e_trp.amod_n_a': ''},
 'he successed': {'e_trp.amod_n_a': ''},
 'volution such': {'e_trp.amod_n_a': ''},
 'area per_capita': {'e_trp.amod_n_a': ''},
 'hook pirated': {'e_trp.amod_n_a': ''},
 'skill plan-making': {'e_trp.amod_n_a': ''},
 'health pleasurable': {'e_trp.amod_n_a': ''},
 'bread poisonous': {'e_trp.amod_n_a': ''},
 'canteen poor': {'e_trp.amod_n_a': ''},
 'attitute positive': {'e_trp.amod_n_a': ''},
 'curriculum post-graduate': {'e_trp.amod_n_a': ''},
 'town poverty-stricken': {'e_trp.amod_n_a': ''},
 'dramatist pre-eminent': {'e_trp.amod_n_a': ''},
 'idea predigested': {'e_trp.amod_n_a': ''},
 'assignment prelab': {'e_trp.amod_n_a': ''},
 'college present-day': {'e_trp.amod_n_a': ''},
 'mastery proficient': {'e_trp.amod_n_a': ''},
 'curriculum psychological': {'e_trp.amod_n_a': ''},
 'hint psychological': {'e_trp.amod_n_a': ''},
 'as-areness public': {'e_trp.amod_n_a': ''},
 'effort pygmy': {'e_trp.amod_n_a': ''},
 'wish long-cherished': {'e_trp.amod_n_a': ''},
 'value long-held': {'e_trp.amod_n_a': ''},
 'virtue long-lasting': {'e_trp.amod_n_a': ''},
 'vacation long-overdue': {'e_trp.amod_n_a': ''},
 'ambition long-range': {'e_trp.amod_n_a': ''},
 'accumulation long-term': {'e_trp.amod_n_a': ''},
 'brain long-term': {'e_trp.amod_n_a': ''},
 'riding long-term': {'e_trp.amod_n_a': ''},
 'tension long-term': {'e_trp.amod_n_a': ''},
 'scholarship longer': {'e_trp.amod_n_a': ''},
 'inferior lovely': {'e_trp.amod_n_a': ''},
 'car-bon low': {'e_trp.amod_n_a': ''},
 'summit luminous': {'e_trp.amod_n_a': ''},
 'view macrocosmic': {'e_trp.amod_n_a': ''},
 'system maketing': {'e_trp.amod_n_a': ''},
 'shoe medium-heeled': {'e_trp.amod_n_a': ''},
 '$_150_million mere': {'e_trp.amod_n_a': ''},
 'restriction metrical': {'e_trp.amod_n_a': ''},
 'family mid-class': {'e_trp.amod_n_a': ''},
 'word midget': {'e_trp.amod_n_a': ''},
 'student misleading': {'e_trp.amod_n_a': ''},
 'sociaty modern': {'e_trp.amod_n_a': ''},
 'self-cultivation moral': {'e_trp.amod_n_a': ''},
 'story much-told': {'e_trp.amod_n_a': ''},
 'person multi-cultural': {'e_trp.amod_n_a': ''},
 'creation multicolored': {'e_trp.amod_n_a': ''},
 'advertisement nagative': {'e_trp.amod_n_a': ''},
 'fou necessary': {'e_trp.amod_n_a': ''},
 'problem-water worrying': {'e_trp.amod_n_a': ''},
 'campaign year-round': {'e_trp.amod_n_a': ''},
 'peopie young': {'e_trp.amod_n_a': ''},
 'problem worried': {'e_trp.amod_n_a': ''},
 'coat worn-out': {'e_trp.amod_n_a': ''},
 'achievement wrong': {'e_trp.amod_n_a': ''},
 'letter writed': {'e_trp.amod_n_a': ''},
 'classmate wounded': {'e_trp.amod_n_a': ''},
 'exploitation surging': {'e_trp.amod_n_a': ''},
 'person swiftest': {'e_trp.amod_n_a': ''},
 'presticides synthetic': {'e_trp.amod_n_a': ''},
 'device table-like': {'e_trp.amod_n_a': ''},
 'need tactile': {'e_trp.amod_n_a': ''},
 'predominance tempera-mental': {'e_trp.amod_n_a': ''},
 'cookout tex-mex': {'e_trp.amod_n_a': ''},
 'dollor the': {'e_trp.amod_n_a': ''},
 'inportant the': {'e_trp.amod_n_a': ''},
 'painkiller them': {'e_trp.amod_n_a': ''},
 'knowledge theoretic': {'e_trp.amod_n_a': ''},
 'broken-heart thorough': {'e_trp.amod_n_a': ''},
 'word thought-provoking': {'e_trp.amod_n_a': ''},
 'society throw-away': {'e_trp.amod_n_a': ''},
 'method time-saving': {'e_trp.amod_n_a': ''},
 'regret torturing': {'e_trp.amod_n_a': ''},
 'festional traditional': {'e_trp.amod_n_a': ''},
 'color tragic': {'e_trp.amod_n_a': ''},
 'temperament transcendent': {'e_trp.amod_n_a': ''},
 'mean traveling': {'e_trp.amod_n_a': ''},
 'aspect traveling-related': {'e_trp.amod_n_a': ''},
 'college triumphant': {'e_trp.amod_n_a': ''},
 'sport triumphant': {'e_trp.amod_n_a': ''},
 'disease tv-related': {'e_trp.amod_n_a': ''},
 'exercise ultra': {'e_trp.amod_n_a': ''},
 'food un-delicious': {'e_trp.amod_n_a': ''},
 'seller un-honest': {'e_trp.amod_n_a': ''},
 'producer un-normal': {'e_trp.amod_n_a': ''},
 'criticism unconditional': {'e_trp.amod_n_a': ''},
 'number unconditional': {'e_trp.amod_n_a': ''},
 'reflection unconditional': {'e_trp.amod_n_a': ''},
 'dream unconsummated': {'e_trp.amod_n_a': ''},
 'authority underestimated': {'e_trp.amod_n_a': ''},
 'marriage undergraduate': {'e_trp.amod_n_a': ''},
 'phenomenon undesirable': {'e_trp.amod_n_a': ''},
 'money undue': {'e_trp.amod_n_a': ''},
 'affair unfair': {'e_trp.amod_n_a': ''},
 'one unfavourable': {'e_trp.amod_n_a': ''},
 'situation unfavourable': {'e_trp.amod_n_a': ''},
 'series unforeseen': {'e_trp.amod_n_a': ''},
 'exam unforgettable': {'e_trp.amod_n_a': ''},
 'forever unforgettable': {'e_trp.amod_n_a': ''},
 'phenomenon unharmonious': {'e_trp.amod_n_a': ''},
 'campus unhealthy': {'e_trp.amod_n_a': ''},
 'habites unhealthy': {'e_trp.amod_n_a': ''},
 'clothes uni-sexual': {'e_trp.amod_n_a': ''},
 'skils reading': {'e_trp.amod_n_a': ''},
 'guidance real-time': {'e_trp.amod_n_a': ''},
 'friend realistic': {'e_trp.amod_n_a': ''},
 'store realistic': {'e_trp.amod_n_a': ''},
 'phenomenon reasonable': {'e_trp.amod_n_a': ''},
 'habit reciting': {'e_trp.amod_n_a': ''},
 'paper-cuts red': {'e_trp.amod_n_a': ''},
 'correction red-penciled': {'e_trp.amod_n_a': ''},
 'relationship relations-modular': {'e_trp.amod_n_a': ''},
 'communication relaxing': {'e_trp.amod_n_a': ''},
 'moped renting': {'e_trp.amod_n_a': ''},
 'setback repeated': {'e_trp.amod_n_a': ''},
 'gap resident': {'e_trp.amod_n_a': ''},
 'emotion resistant': {'e_trp.amod_n_a': ''},
 'characteristic respectable': {'e_trp.amod_n_a': ''},
 'jade return': {'e_trp.amod_n_a': ''},
 'anklebone right-hand': {'e_trp.amod_n_a': ''},
 'spectacle rose-colored': {'e_trp.amod_n_a': ''},
 'goods saled': {'e_trp.amod_n_a': ''},
 'conformation sales': {'e_trp.amod_n_a': ''},
 'oppotunity same': {'e_trp.amod_n_a': ''},
 'freedom sandy': {'e_trp.amod_n_a': ''},
 'profession satisfied': {'e_trp.amod_n_a': ''},
 'sight satisfied': {'e_trp.amod_n_a': ''},
 'decision-making scientific': {'e_trp.amod_n_a': ''},
 'court selective': {'e_trp.amod_n_a': ''},
 'love self-giving': {'e_trp.amod_n_a': ''},
 'awareness self-protective': {'e_trp.amod_n_a': ''},
 'code self-replicating': {'e_trp.amod_n_a': ''},
 'future self-school': {'e_trp.amod_n_a': ''},
 'man self-taught': {'e_trp.amod_n_a': ''},
 'scientist self-taught': {'e_trp.amod_n_a': ''},
 'blessing sending': {'e_trp.amod_n_a': ''},
 'problom serious': {'e_trp.amod_n_a': ''},
 'stammer serious': {'e_trp.amod_n_a': ''},
 'stituation serious': {'e_trp.amod_n_a': ''},
 'poster shinier': {'e_trp.amod_n_a': ''},
 'aiso shopping': {'e_trp.amod_n_a': ''},
 "dosen't shopping": {'e_trp.amod_n_a': ''},
 'brushstroke short': {'e_trp.amod_n_a': ''},
 'self-introduction short': {'e_trp.amod_n_a': ''},
 'explorer short-term': {'e_trp.amod_n_a': ''},
 'emission per_capita': {'e_trp.amod_n_a': ''},
 'effect pessimistic': {'e_trp.amod_n_a': ''},
 'basketball piaying': {'e_trp.amod_n_a': ''},
 'ping-pong playing': {'e_trp.amod_n_a': ''},
 'job pleased': {'e_trp.amod_n_a': ''},
 'thing pleased': {'e_trp.amod_n_a': ''},
 'homework plentiful': {'e_trp.amod_n_a': ''},
 'chemistry poisonous': {'e_trp.amod_n_a': ''},
 'transport pollution-free': {'e_trp.amod_n_a': ''},
 'self-care poor': {'e_trp.amod_n_a': ''},
 'dissension popular': {'e_trp.amod_n_a': ''},
 'gose popular': {'e_trp.amod_n_a': ''},
 'nowdays popular': {'e_trp.amod_n_a': ''},
 'atitude positive': {'e_trp.amod_n_a': ''},
 'self-esteem positive': {'e_trp.amod_n_a': ''},
 'are post-graduate': {'e_trp.amod_n_a': ''},
 'crazy post-graduate': {'e_trp.amod_n_a': ''},
 'heat post-graduate': {'e_trp.amod_n_a': ''},
 'ad postgraduate': {'e_trp.amod_n_a': ''},
 'recommendation postgraduate': {'e_trp.amod_n_a': ''},
 'cape precious': {'e_trp.amod_n_a': ''},
 'aggrements premarital': {'e_trp.amod_n_a': ''},
 '3 presentational': {'e_trp.amod_n_a': ''},
 'live-action previous': {'e_trp.amod_n_a': ''},
 'sadness previous': {'e_trp.amod_n_a': ''},
 'school privately-run': {'e_trp.amod_n_a': ''},
 'agreement pro-marriage': {'e_trp.amod_n_a': ''},
 'care probable': {'e_trp.amod_n_a': ''},
 'solute problem': {'e_trp.amod_n_a': ''},
 'activity profit-making': {'e_trp.amod_n_a': ''},
 'behavior profit-maximizing': {'e_trp.amod_n_a': ''},
 'friend promising': {'e_trp.amod_n_a': ''},
 'marrow proper': {'e_trp.amod_n_a': ''},
 'ting proper': {'e_trp.amod_n_a': ''},
 'diaeresis psychological': {'e_trp.amod_n_a': ''},
 'general pubic': {'e_trp.amod_n_a': ''},
 'product pubic': {'e_trp.amod_n_a': ''},
 'campus pure': {'e_trp.amod_n_a': ''},
 'schoolyard pure': {'e_trp.amod_n_a': ''},
 'problem puzzled': {'e_trp.amod_n_a': ''},
 'housewife qualified': {'e_trp.amod_n_a': ''},
 'river raining': {'e_trp.amod_n_a': ''},
 'day rainny': {'e_trp.amod_n_a': ''},
 'soar rapid': {'e_trp.amod_n_a': ''},
 'perposals significant': {'e_trp.amod_n_a': ''},
 'pay sincere': {'e_trp.amod_n_a': ''},
 'e-book small': {'e_trp.amod_n_a': ''},
 'becauses smaller': {'e_trp.amod_n_a': ''},
 'bomb sneak': {'e_trp.amod_n_a': ''},
 'package sneak': {'e_trp.amod_n_a': ''},
 'brain so-called': {'e_trp.amod_n_a': ''},
 'certificate so-called': {'e_trp.amod_n_a': ''},
 'equality so-called': {'e_trp.amod_n_a': ''},
 'gentleman so-called': {'e_trp.amod_n_a': ''},
 'high-tech so-called': {'e_trp.amod_n_a': ''},
 'job so-called': {'e_trp.amod_n_a': ''},
 'language so-called': {'e_trp.amod_n_a': ''},
 'privacy so-called': {'e_trp.amod_n_a': ''},
 'teacher so-called': {'e_trp.amod_n_a': ''},
 'time so-called': {'e_trp.amod_n_a': ''},
 'waterfowl soaring': {'e_trp.amod_n_a': ''},
 'system socio-ecological': {'e_trp.amod_n_a': ''},
 'problem solute': {'e_trp.amod_n_a': ''},
 'lawn southeastern': {'e_trp.amod_n_a': ''},
 'hand so_on': {'e_trp.amod_n_a': ''},
 'high-rise spectacular': {'e_trp.amod_n_a': ''},
 'course speed-reading': {'e_trp.amod_n_a': ''},
 'heaven splendid': {'e_trp.amod_n_a': ''},
 'patch sporting': {'e_trp.amod_n_a': ''},
 'danger spreaded': {'e_trp.amod_n_a': ''},
 'disease spreaded': {'e_trp.amod_n_a': ''},
 'malaria spreaded': {'e_trp.amod_n_a': ''},
 'he standed': {'e_trp.amod_n_a': ''},
 'out standed': {'e_trp.amod_n_a': ''},
 'undertaking starting': {'e_trp.amod_n_a': ''},
 'society steady': {'e_trp.amod_n_a': ''},
 'rubbing steamed': {'e_trp.amod_n_a': ''},
 'study strained': {'e_trp.amod_n_a': ''},
 'centre stray': {'e_trp.amod_n_a': ''},
 'disease stress-related': {'e_trp.amod_n_a': ''},
 'lecturer strict': {'e_trp.amod_n_a': ''},
 'commodity stricter': {'e_trp.amod_n_a': ''},
 'career-ambition strong': {'e_trp.amod_n_a': ''},
 'society-influence strong': {'e_trp.amod_n_a': ''},
 'person strong-willed': {'e_trp.amod_n_a': ''},
 'link strong_enough': {'e_trp.amod_n_a': ''},
 'people sub-healthy': {'e_trp.amod_n_a': ''},
 'well-being subjective': {'e_trp.amod_n_a': ''},
 'helplessness subsequent': {'e_trp.amod_n_a': ''},
 'man success-full': {'e_trp.amod_n_a': ''},
 'lnes successful': {'e_trp.amod_n_a': ''},
 'pedal successful': {'e_trp.amod_n_a': ''},
 'people＇s successful': {'e_trp.amod_n_a': ''},
 'prude such': {'e_trp.amod_n_a': ''},
 'haw sugarcoated': {'e_trp.amod_n_a': ''},
 'appliance suning': {'e_trp.amod_n_a': ''},
 'manufacturer supervising': {'e_trp.amod_n_a': ''},
 'feature indeterminate': {'e_trp.amod_n_a': ''},
 'mean indispensable': {'e_trp.amod_n_a': ''},
 'antics inflated': {'e_trp.amod_n_a': ''},
 'element inharmonious': {'e_trp.amod_n_a': ''},
 'care innate': {'e_trp.amod_n_a': ''},
 'opinion inner': {'e_trp.amod_n_a': ''},
 'event insecure': {'e_trp.amod_n_a': ''},
 'cat insignificant': {'e_trp.amod_n_a': ''},
 'novelty insignificant': {'e_trp.amod_n_a': ''},
 'shackle intangible': {'e_trp.amod_n_a': ''},
 'subject inter-discipline': {'e_trp.amod_n_a': ''},
 'language interent': {'e_trp.amod_n_a': ''},
 'focalization internal': {'e_trp.amod_n_a': ''},
 'school internet-learning': {'e_trp.amod_n_a': ''},
 'thing intersting': {'e_trp.amod_n_a': ''},
 'rescue invalid': {'e_trp.amod_n_a': ''},
 'model invariable': {'e_trp.amod_n_a': ''},
 'roommate in_question': {'e_trp.amod_n_a': ''},
 'career irrelevant': {'e_trp.amod_n_a': ''},
 'graduate job-hunting': {'e_trp.amod_n_a': ''},
 'tension job-hunting': {'e_trp.amod_n_a': ''},
 'matter joyful': {'e_trp.amod_n_a': ''},
 'person-full joyous': {'e_trp.amod_n_a': ''},
 'mood keeping': {'e_trp.amod_n_a': ''},
 'accident killing': {'e_trp.amod_n_a': ''},
 'style kin-aesthetic': {'e_trp.amod_n_a': ''},
 'style kinaesthetic': {'e_trp.amod_n_a': ''},
 'room-mates kind': {'e_trp.amod_n_a': ''},
 'woman laid-off': {'e_trp.amod_n_a': ''},
 'amont large': {'e_trp.amod_n_a': ''},
 'amunt large': {'e_trp.amod_n_a': ''},
 'munber large': {'e_trp.amod_n_a': ''},
 'numble large': {'e_trp.amod_n_a': ''},
 'corpus large-scale': {'e_trp.amod_n_a': ''},
 'sentence large-scale': {'e_trp.amod_n_a': ''},
 'segment-about larger': {'e_trp.amod_n_a': ''},
 '1820 late': {'e_trp.amod_n_a': ''},
 '1970 later': {'e_trp.amod_n_a': ''},
 'course law-related': {'e_trp.amod_n_a': ''},
 'low-carbon lead': {'e_trp.amod_n_a': ''},
 'low-carbon leading': {'e_trp.amod_n_a': ''},
 'sleeve leg-of-mutton': {'e_trp.amod_n_a': ''},
 'festival legal': {'e_trp.amod_n_a': ''},
 'jag let': {'e_trp.amod_n_a': ''},
 'warmth life-giving': {'e_trp.amod_n_a': ''},
 'employment life-long': {'e_trp.amod_n_a': ''},
 'study life-long': {'e_trp.amod_n_a': ''},
 'real-name net': {'e_trp.amod_n_a': ''},
 'french_tv network-tried': {'e_trp.amod_n_a': ''},
 'convergence-type new': {'e_trp.amod_n_a': ''},
 'inmotions new': {'e_trp.amod_n_a': ''},
 'low-carbon new': {'e_trp.amod_n_a': ''},
 'marrige new': {'e_trp.amod_n_a': ''},
 'confidence newly-founded': {'e_trp.amod_n_a': ''},
 'photograph newsworthy': {'e_trp.amod_n_a': ''},
 'day＇s next': {'e_trp.amod_n_a': ''},
 'topic-how next': {'e_trp.amod_n_a': ''},
 'concern non-economic': {'e_trp.amod_n_a': ''},
 'value non-economic': {'e_trp.amod_n_a': ''},
 'chemical non-edible': {'e_trp.amod_n_a': ''},
 'disaster non-military': {'e_trp.amod_n_a': ''},
 'product non-public': {'e_trp.amod_n_a': ''},
 'charge non-regulatory': {'e_trp.amod_n_a': ''},
 'expression non-verbal': {'e_trp.amod_n_a': ''},
 'mean non-verbal': {'e_trp.amod_n_a': ''},
 'message non-verbal': {'e_trp.amod_n_a': ''},
 'status now-lifeless': {'e_trp.amod_n_a': ''},
 'measure number-limited': {'e_trp.amod_n_a': ''},
 'advantage number_one': {'e_trp.amod_n_a': ''},
 "students'abilities nurturing": {'e_trp.amod_n_a': ''},
 'no-no nutritional': {'e_trp.amod_n_a': ''},
 'class-structure obvious': {'e_trp.amod_n_a': ''},
 'traffic odd-even': {'e_trp.amod_n_a': ''},
 'detour off-road': {'e_trp.amod_n_a': ''},
 'are on-line': {'e_trp.amod_n_a': ''},
 'bank on-line': {'e_trp.amod_n_a': ''},
 'crime on-line': {'e_trp.amod_n_a': ''},
 "kids'being on-line": {'e_trp.amod_n_a': ''},
 'waste on-line': {'e_trp.amod_n_a': ''},
 'cup one-off': {'e_trp.amod_n_a': ''},
 'tableware one-off': {'e_trp.amod_n_a': ''},
 'development one-sided': {'e_trp.amod_n_a': ''},
 'diet one-sided': {'e_trp.amod_n_a': ''},
 'aiso online': {'e_trp.amod_n_a': ''},
 "dosen't online": {'e_trp.amod_n_a': ''},
 'shoppling online': {'e_trp.amod_n_a': ''},
 'have online-shopping': {'e_trp.amod_n_a': ''},
 'shoping onling': {'e_trp.amod_n_a': ''},
 'affliction oppressive': {'e_trp.amod_n_a': ''},
 'yuan original': {'e_trp.amod_n_a': ''},
 'building out-of-date': {'e_trp.amod_n_a': ''},
 'graduate over-loaded': {'e_trp.amod_n_a': ''},
 'college overall-developed': {'e_trp.amod_n_a': ''},
 'student overall-excellent': {'e_trp.amod_n_a': ''},
 'child overbearing': {'e_trp.amod_n_a': ''},
 'worker oversea': {'e_trp.amod_n_a': ''},
 'rind panic': {'e_trp.amod_n_a': ''},
 'book papery': {'e_trp.amod_n_a': ''},
 'time part-time': {'e_trp.amod_n_a': ''},
 '50 past': {'e_trp.amod_n_a': ''},
 'feedback peer-referenced': {'e_trp.amod_n_a': ''},
 'match-it perfect': {'e_trp.amod_n_a': ''},
 'woman person-oriented': {'e_trp.amod_n_a': ''},
 'habit live': {'e_trp.amod_n_a': ''},
 'mind liveliest': {'e_trp.amod_n_a': ''},
 'tempo living': {'e_trp.amod_n_a': ''},
 'thing loathly': {'e_trp.amod_n_a': ''},
 'histroy long': {'e_trp.amod_n_a': ''},
 'run long-distant': {'e_trp.amod_n_a': ''},
 'one long-expected': {'e_trp.amod_n_a': ''},
 'feeling long-lasting': {'e_trp.amod_n_a': ''},
 'fight long-lasting': {'e_trp.amod_n_a': ''},
 'love long-lasting': {'e_trp.amod_n_a': ''},
 'coexistence long-term': {'e_trp.amod_n_a': ''},
 'iron long-term': {'e_trp.amod_n_a': ''},
 'professional long-term': {'e_trp.amod_n_a': ''},
 'sight long-term': {'e_trp.amod_n_a': ''},
 'cardon-life low': {'e_trp.amod_n_a': ''},
 'datum low': {'e_trp.amod_n_a': ''},
 'efficency low': {'e_trp.amod_n_a': ''},
 'person low-income': {'e_trp.amod_n_a': ''},
 'period luckiest': {'e_trp.amod_n_a': ''},
 'gift lunar': {'e_trp.amod_n_a': ''},
 'instability macroscopical': {'e_trp.amod_n_a': ''},
 'honey maiden': {'e_trp.amod_n_a': ''},
 'french_tv major': {'e_trp.amod_n_a': ''},
 'it maked': {'e_trp.amod_n_a': ''},
 'accident man-made': {'e_trp.amod_n_a': ''},
 'cause man-made': {'e_trp.amod_n_a': ''},
 'organ man-made': {'e_trp.amod_n_a': ''},
 'mean marrying': {'e_trp.amod_n_a': ''},
 'cause-and-effect master': {'e_trp.amod_n_a': ''},
 'today masterful': {'e_trp.amod_n_a': ''},
 'solubility maximum': {'e_trp.amod_n_a': ''},
 'competitiveness mental': {'e_trp.amod_n_a': ''},
 'blogger micro': {'e_trp.amod_n_a': ''},
 'schoole middle': {'e_trp.amod_n_a': ''},
 'shcool middle': {'e_trp.amod_n_a': ''},
 'experience mind-exparding': {'e_trp.amod_n_a': ''},
 'tomboy mischievous': {'e_trp.amod_n_a': ''},
 'garbage miss-classified': {'e_trp.amod_n_a': ''},
 'exercise moring': {'e_trp.amod_n_a': ''},
 'topic much-talked-about': {'e_trp.amod_n_a': ''},
 'capability multi-function': {'e_trp.amod_n_a': ''},
 'building multi-storied': {'e_trp.amod_n_a': ''},
 'face multitudinous': {'e_trp.amod_n_a': ''},
 'measure mutual': {'e_trp.amod_n_a': ''},
 'effect nagative': {'e_trp.amod_n_a': ''},
 'macro-control national': {'e_trp.amod_n_a': ''},
 'issue needy': {'e_trp.amod_n_a': ''},
 'effection negative': {'e_trp.amod_n_a': ''},
 'peer unmarried': {'e_trp.amod_n_a': ''},
 'statement unpaid': {'e_trp.amod_n_a': ''},
 's unrealistic': {'e_trp.amod_n_a': ''},
 'lunch unrecyclable': {'e_trp.amod_n_a': ''},
 'product unrecyclable': {'e_trp.amod_n_a': ''},
 'childhood unrestrained': {'e_trp.amod_n_a': ''},
 'adventure unselfish': {'e_trp.amod_n_a': ''},
 'college up-to-date': {'e_trp.amod_n_a': ''},
 'life up-to-date': {'e_trp.amod_n_a': ''},
 'society up-to-date': {'e_trp.amod_n_a': ''},
 'telecommunication up-to-date': {'e_trp.amod_n_a': ''},
 'reason uppermost': {'e_trp.amod_n_a': ''},
 'art upsetting': {'e_trp.amod_n_a': ''},
 'disposal urban': {'e_trp.amod_n_a': ''},
 'fair-and-square used': {'e_trp.amod_n_a': ''},
 'fault-finding useless': {'e_trp.amod_n_a': ''},
 'belonging using': {'e_trp.amod_n_a': ''},
 'heart utilitarian': {'e_trp.amod_n_a': ''},
 'time valueable': {'e_trp.amod_n_a': ''},
 'factor varied': {'e_trp.amod_n_a': ''},
 'conveniet very': {'e_trp.amod_n_a': ''},
 'convinience very': {'e_trp.amod_n_a': ''},
 'nessary very': {'e_trp.amod_n_a': ''},
 'talktive very': {'e_trp.amod_n_a': ''},
 'worderful very': {'e_trp.amod_n_a': ''},
 'class vivid': {'e_trp.amod_n_a': ''},
 'dormitory warm': {'e_trp.amod_n_a': ''},
 'friend warm-hearted': {'e_trp.amod_n_a': ''},
 'behaviour wealth-flaunting': {'e_trp.amod_n_a': ''},
 'child well-educated': {'e_trp.amod_n_a': ''},
 'life well-fed': {'e_trp.amod_n_a': ''},
 'quotation well-honed': {'e_trp.amod_n_a': ''},
 'corporation well-known': {'e_trp.amod_n_a': ''},
 'entrepreneur well-known': {'e_trp.amod_n_a': ''},
 'lie well-meaning': {'e_trp.amod_n_a': ''},
 'lecture well-prepared': {'e_trp.amod_n_a': ''},
 'environment well-preserved': {'e_trp.amod_n_a': ''},
 'heat welling': {'e_trp.amod_n_a': ''},
 'educator western': {'e_trp.amod_n_a': ''},
 'woman white-collar': {'e_trp.amod_n_a': ''},
 'mishap wild': {'e_trp.amod_n_a': ''},
 'strategy word-guessing': {'e_trp.amod_n_a': ''},
 'programme work-study': {'e_trp.amod_n_a': ''},
 'enviornment working': {'e_trp.amod_n_a': ''},
 'romance ethical': {'e_trp.amod_n_a': ''},
 'thousand everyday': {'e_trp.amod_n_a': ''},
 'gas-carbon evil': {'e_trp.amod_n_a': ''},
 'advertisement exaggerating': {'e_trp.amod_n_a': ''},
 'study examinations-related': {'e_trp.amod_n_a': ''},
 'hunt excessive': {'e_trp.amod_n_a': ''},
 'change exercise-induced': {'e_trp.amod_n_a': ''},
 'endeavor explicit': {'e_trp.amod_n_a': ''},
 'diseconomy external': {'e_trp.amod_n_a': ''},
 'life extra-curricular': {'e_trp.amod_n_a': ''},
 'fervency extraordinary': {'e_trp.amod_n_a': ''},
 'charm eye-catching': {'e_trp.amod_n_a': ''},
 'one face-to-face': {'e_trp.amod_n_a': ''},
 'eye fairy-tale': {'e_trp.amod_n_a': ''},
 'mercenary faithless': {'e_trp.amod_n_a': ''},
 'commoditie fake': {'e_trp.amod_n_a': ''},
 'ware fake': {'e_trp.amod_n_a': ''},
 'diploma faking': {'e_trp.amod_n_a': ''},
 'well-being family': {'e_trp.amod_n_a': ''},
 'ideologist famous': {'e_trp.amod_n_a': ''},
 'university-nanjing famous': {'e_trp.amod_n_a': ''},
 'beyondany far': {'e_trp.amod_n_a': ''},
 'friend far-away': {'e_trp.amod_n_a': ''},
 'thing fashional': {'e_trp.amod_n_a': ''},
 'develope fast': {'e_trp.amod_n_a': ''},
 'develpment fast': {'e_trp.amod_n_a': ''},
 'information fast-developing': {'e_trp.amod_n_a': ''},
 'stateswoman female': {'e_trp.amod_n_a': ''},
 'dilemma fertile': {'e_trp.amod_n_a': ''},
 'completion fierce': {'e_trp.amod_n_a': ''},
 'workforce fierce': {'e_trp.amod_n_a': ''},
 'disadvantage fifth': {'e_trp.amod_n_a': ''},
 'lnes first': {'e_trp.amod_n_a': ''},
 'discipline first-class': {'e_trp.amod_n_a': ''},
 'education ability-oriented': {'e_trp.amod_n_a': ''},
 'issue above-discussed': {'e_trp.amod_n_a': ''},
 'example above-mentioned': {'e_trp.amod_n_a': ''},
 'view above-mentioned': {'e_trp.amod_n_a': ''},
 'college abundant': {'e_trp.amod_n_a': ''},
 'impressionist accepted': {'e_trp.amod_n_a': ''},
 'sourece adequate': {'e_trp.amod_n_a': ''},
 'low-carbon advocating': {'e_trp.amod_n_a': ''},
 'constant afraid': {'e_trp.amod_n_a': ''},
 'student afraid': {'e_trp.amod_n_a': ''},
 'community afro-canadian': {'e_trp.amod_n_a': ''},
 'tendency aged': {'e_trp.amod_n_a': ''},
 'garbage air-borne': {'e_trp.amod_n_a': ''},
 'person all-around': {'e_trp.amod_n_a': ''},
 'capability all-round': {'e_trp.amod_n_a': ''},
 'plan all-round': {'e_trp.amod_n_a': ''},
 'skill all-round': {'e_trp.amod_n_a': ''},
 'way all-sided': {'e_trp.amod_n_a': ''},
 'moped alone': {'e_trp.amod_n_a': ''},
 'datum amazing': {'e_trp.amod_n_a': ''},
 'learner anesthetic': {'e_trp.amod_n_a': ''},
 'drug anit-malarial': {'e_trp.amod_n_a': ''},
 'freedom apart': {'e_trp.amod_n_a': ''},
 'self-education arduous': {'e_trp.amod_n_a': ''},
 'cause assignable': {'e_trp.amod_n_a': ''},
 'college atteding': {'e_trp.amod_n_a': ''},
 'facility backward': {'e_trp.amod_n_a': ''},
 'skill basical': {'e_trp.amod_n_a': ''},
 'gril beautiful': {'e_trp.amod_n_a': ''},
 'pursuit beautiful': {'e_trp.amod_n_a': ''},
 'scenary beautiful': {'e_trp.amod_n_a': ''},
 'scence beautiful': {'e_trp.amod_n_a': ''},
 'senery beautiful': {'e_trp.amod_n_a': ''},
 'great beneficial': {'e_trp.amod_n_a': ''},
 'whishes best': {'e_trp.amod_n_a': ''},
 'wishs best': {'e_trp.amod_n_a': ''},
 'choise better': {'e_trp.amod_n_a': ''},
 'promble big': {'e_trp.amod_n_a': ''},
 'underpant big': {'e_trp.amod_n_a': ''},
 'grace biggest': {'e_trp.amod_n_a': ''},
 'businessman black-hearted': {'e_trp.amod_n_a': ''},
 'people blatant': {'e_trp.amod_n_a': ''},
 'fashion body-fit': {'e_trp.amod_n_a': ''},
 'card bolder': {'e_trp.amod_n_a': ''},
 'way bran-new': {'e_trp.amod_n_a': ''},
 'consumption brand_new': {'e_trp.amod_n_a': ''},
 'student bridge-like': {'e_trp.amod_n_a': ''},
 'furture bright': {'e_trp.amod_n_a': ''},
 'professor broken': {'e_trp.amod_n_a': ''},
 'complexion bronze-colored': {'e_trp.amod_n_a': ''},
 'buiding buiding': {'e_trp.amod_n_a': ''},
 'buidings buiding': {'e_trp.amod_n_a': ''},
 'city built-in': {'e_trp.amod_n_a': ''},
 'way burgeoning': {'e_trp.amod_n_a': ''},
 'coal burring': {'e_trp.amod_n_a': ''},
 'eversince busy': {'e_trp.amod_n_a': ''},
 'toglance busy': {'e_trp.amod_n_a': ''},
 'advice carbon-saving': {'e_trp.amod_n_a': ''},
 'friend causal': {'e_trp.amod_n_a': ''},
 'product celebrity-endorsed': {'e_trp.amod_n_a': ''},
 '21st centry': {'e_trp.amod_n_a': ''},
 'truth chill': {'e_trp.amod_n_a': ''},
 'shower chilling': {'e_trp.amod_n_a': ''},
 'freshman chinese': {'e_trp.amod_n_a': ''},
 'microbiology chinese': {'e_trp.amod_n_a': ''},
 'microblog chinese': {'e_trp.amod_n_a': ''},
 'sorrow chinese': {'e_trp.amod_n_a': ''},
 'stupid chinese': {'e_trp.amod_n_a': ''},
 'country chinese-speaking': {'e_trp.amod_n_a': ''},
 'friend choosing': {'e_trp.amod_n_a': ''},
 'dormitory civilized': {'e_trp.amod_n_a': ''},
 'cyberspace clean': {'e_trp.amod_n_a': ''},
 'conclusion clear-cut': {'e_trp.amod_n_a': ''},
 'man cold-blooded': {'e_trp.amod_n_a': ''},
 'student college-graduated': {'e_trp.amod_n_a': ''},
 'goods combating': {'e_trp.amod_n_a': ''},
 'cet4 coming': {'e_trp.amod_n_a': ''},
 'in. coming': {'e_trp.amod_n_a': ''},
 'syste direct': {'e_trp.amod_n_a': ''},
 'sea dirtier': {'e_trp.amod_n_a': ''},
 'campus dirty': {'e_trp.amod_n_a': ''},
 'instance dishonest': {'e_trp.amod_n_a': ''},
 'shopkeeper dishonest': {'e_trp.amod_n_a': ''},
 'reason disparate': {'e_trp.amod_n_a': ''},
 'product disqualified': {'e_trp.amod_n_a': ''},
 'factor diverse': {'e_trp.amod_n_a': ''},
 'hygiene dormitory': {'e_trp.amod_n_a': ''},
 'people dormitory': {'e_trp.amod_n_a': ''},
 'time dormitory': {'e_trp.amod_n_a': ''},
 'effort down-to-earth': {'e_trp.amod_n_a': ''},
 'university dreamed': {'e_trp.amod_n_a': ''},
 'campus dreaming': {'e_trp.amod_n_a': ''},
 'case drink-driving': {'e_trp.amod_n_a': ''},
 'tragedy drink-driving': {'e_trp.amod_n_a': ''},
 'he drived': {'e_trp.amod_n_a': ''},
 'harm driving': {'e_trp.amod_n_a': ''},
 'penalty drunk': {'e_trp.amod_n_a': ''},
 'have drunken': {'e_trp.amod_n_a': ''},
 'goods due': {'e_trp.amod_n_a': ''},
 'word due': {'e_trp.amod_n_a': ''},
 '1800 early': {'e_trp.amod_n_a': ''},
 'university easier': {'e_trp.amod_n_a': ''},
 'character easy-going': {'e_trp.amod_n_a': ''},
 'dumpling eating': {'e_trp.amod_n_a': ''},
 'nmch economical': {'e_trp.amod_n_a': ''},
 'low-carbon effective': {'e_trp.amod_n_a': ''},
 'messures effective': {'e_trp.amod_n_a': ''},
 'reading-room electronic': {'e_trp.amod_n_a': ''},
 'atmosphere embarrassing': {'e_trp.amod_n_a': ''},
 'application embryonic': {'e_trp.amod_n_a': ''},
 'everyday energetic': {'e_trp.amod_n_a': ''},
 'electricity energy-saving': {'e_trp.amod_n_a': ''},
 'lifestyle energy-saving': {'e_trp.amod_n_a': ''},
 'knowlege english': {'e_trp.amod_n_a': ''},
 'lerning english': {'e_trp.amod_n_a': ''},
 'ofen english': {'e_trp.amod_n_a': ''},
 'text-book english': {'e_trp.amod_n_a': ''},
 'vedios english': {'e_trp.amod_n_a': ''},
 'atmosphere english-speaking': {'e_trp.amod_n_a': ''},
 'foreigner english-speaking': {'e_trp.amod_n_a': ''},
 'friend english-speaking': {'e_trp.amod_n_a': ''},
 '50-minute entire': {'e_trp.amod_n_a': ''},
 'invention epoch-making': {'e_trp.amod_n_a': ''},
 'circumstance equal': {'e_trp.amod_n_a': ''},
 'water especial': {'e_trp.amod_n_a': ''},
 'woman especial': {'e_trp.amod_n_a': ''},
 'room folded': {'e_trp.amod_n_a': ''},
 'washing-up following': {'e_trp.amod_n_a': ''},
 'parent forbidden': {'e_trp.amod_n_a': ''},
 'lauguage foreign': {'e_trp.amod_n_a': ''},
 'masterpiece foreign': {'e_trp.amod_n_a': ''},
 'websides foreign': {'e_trp.amod_n_a': ''},
 'experience forgetful': {'e_trp.amod_n_a': ''},
 'aspect fractionalized': {'e_trp.amod_n_a': ''},
 'repudiation fraudulent': {'e_trp.amod_n_a': ''},
 'museum free_opened': {'e_trp.amod_n_a': ''},
 'tree full-grown': {'e_trp.amod_n_a': ''},
 'equipment full-scale': {'e_trp.amod_n_a': ''},
 'firefighting funded': {'e_trp.amod_n_a': ''},
 'revolutionist german': {'e_trp.amod_n_a': ''},
 'strength gethering': {'e_trp.amod_n_a': ''},
 'villege global': {'e_trp.amod_n_a': ''},
 'chance god-given': {'e_trp.amod_n_a': ''},
 'saga gondal': {'e_trp.amod_n_a': ''},
 'educaton good': {'e_trp.amod_n_a': ''},
 'lookings good': {'e_trp.amod_n_a': ''},
 'parent-children good': {'e_trp.amod_n_a': ''},
 'phenonmenon good': {'e_trp.amod_n_a': ''},
 'self-cultivation good': {'e_trp.amod_n_a': ''},
 'boy good-looking': {'e_trp.amod_n_a': ''},
 'facility good_enough': {'e_trp.amod_n_a': ''},
 'flow graduate': {'e_trp.amod_n_a': ''},
 'pressurefrom great': {'e_trp.amod_n_a': ''},
 'desert greedy': {'e_trp.amod_n_a': ''},
 'campu green': {'e_trp.amod_n_a': ''},
 'circumstance green': {'e_trp.amod_n_a': ''},
 'notion green': {'e_trp.amod_n_a': ''},
 'city guiping': {'e_trp.amod_n_a': ''},
 'division hanged': {'e_trp.amod_n_a': ''},
 'make hard-working': {'e_trp.amod_n_a': ''},
 'study hardworking': {'e_trp.amod_n_a': ''},
 'college harmonious': {'e_trp.amod_n_a': ''},
 'get harmonious': {'e_trp.amod_n_a': ''},
 'need harmonious': {'e_trp.amod_n_a': ''},
 'woman health-conscious': {'e_trp.amod_n_a': ''},
 'diet heathy': {'e_trp.amod_n_a': ''},
 '80globalization held': {'e_trp.amod_n_a': ''},
 'expection high': {'e_trp.amod_n_a': ''},
 'nose high-bridged': {'e_trp.amod_n_a': ''},
 'technology high-developed': {'e_trp.amod_n_a': ''},
 'position high-paid': {'e_trp.amod_n_a': ''},
 'department high-rise': {'e_trp.amod_n_a': ''},
 'capability high-speed': {'e_trp.amod_n_a': ''},
 'evolution high-speed': {'e_trp.amod_n_a': ''},
 'information high-speed': {'e_trp.amod_n_a': ''},
 'pace high-speed': {'e_trp.amod_n_a': ''},
 'remark higher': {'e_trp.amod_n_a': ''},
 'position highly-paid': {'e_trp.amod_n_a': ''},
 'discussion hit': {'e_trp.amod_n_a': ''},
 'blindness hit-and-miss': {'e_trp.amod_n_a': ''},
 'result homosexual': {'e_trp.amod_n_a': ''},
 'pant huge': {'e_trp.amod_n_a': ''},
 'activies human': {'e_trp.amod_n_a': ''},
 'garrulousness human': {'e_trp.amod_n_a': ''},
 'friend humourous': {'e_trp.amod_n_a': ''},
 'man humourous': {'e_trp.amod_n_a': ''},
 'trimester iambic': {'e_trp.amod_n_a': ''},
 'jop ideal': {'e_trp.amod_n_a': ''},
 'advertisement ill': {'e_trp.amod_n_a': ''},
 'phenomenon ill': {'e_trp.amod_n_a': ''},
 'comment ill-disposed': {'e_trp.amod_n_a': ''},
 'molecule illegal': {'e_trp.amod_n_a': ''},
 'consumption immature': {'e_trp.amod_n_a': ''},
 'food immoral': {'e_trp.amod_n_a': ''},
 'atmosphere impetuous': {'e_trp.amod_n_a': ''},
 'deed improper': {'e_trp.amod_n_a': ''},
 'terest in': {'e_trp.amod_n_a': ''},
 'thinking in-depth': {'e_trp.amod_n_a': ''},
 'classmate inactive': {'e_trp.amod_n_a': ''},
 'phenomemon common': {'e_trp.amod_n_a': ''},
 'tool communicational': {'e_trp.amod_n_a': ''},
 'society competed': {'e_trp.amod_n_a': ''},
 'statistic concrete': {'e_trp.amod_n_a': ''},
 'disclosure confident': {'e_trp.amod_n_a': ''},
 'interviewer confident': {'e_trp.amod_n_a': ''},
 'campus consenvation-oriented': {'e_trp.amod_n_a': ''},
 'compus conservation-oriented': {'e_trp.amod_n_a': ''},
 'atrocity continued': {'e_trp.amod_n_a': ''},
 'implicature conversational': {'e_trp.amod_n_a': ''},
 'graduate cornered': {'e_trp.amod_n_a': ''},
 'idolater crazy': {'e_trp.amod_n_a': ''},
 'thingking critical': {'e_trp.amod_n_a': ''},
 'backgroud cultural': {'e_trp.amod_n_a': ''},
 'cress cultural': {'e_trp.amod_n_a': ''},
 'role curial': {'e_trp.amod_n_a': ''},
 'limelight dazzling': {'e_trp.amod_n_a': ''},
 'accommodation dear': {'e_trp.amod_n_a': ''},
 'vibe dear': {'e_trp.amod_n_a': ''},
 'platform deduced_enough': {'e_trp.amod_n_a': ''},
 'habit deep-rooted': {'e_trp.amod_n_a': ''},
 'syste deliverying': {'e_trp.amod_n_a': ''},
 'interest dense': {'e_trp.amod_n_a': ''},
 'lie designed': {'e_trp.amod_n_a': ''},
 'gas detrimental': {'e_trp.amod_n_a': ''},
 'respect dietary': {'e_trp.amod_n_a': ''},
 'dustbin different': {'e_trp.amod_n_a': ''},
 'hobbit different': {'e_trp.amod_n_a': ''},
 'idear different': {'e_trp.amod_n_a': ''},
 'proudly': {'rb_to_jj': 'proud'},
 'appear ability': {'e_trp.xcomp_vbe_nn': ''},
 'appear accident': {'e_trp.xcomp_vbe_nn': ''},
 'appear action': {'e_trp.xcomp_vbe_nn': ''},
 'appear ad': {'e_trp.xcomp_vbe_nn': ''},
 'appear addict': {'e_trp.xcomp_vbe_nn': ''},
 'appear advantage': {'e_trp.xcomp_vbe_nn': ''},
 'appear advertisement': {'e_trp.xcomp_vbe_nn': ''},
 'appear anemia': {'e_trp.xcomp_vbe_nn': ''},
 'appear ang': {'e_trp.xcomp_vbe_nn': ''},
 'appear appearance': {'e_trp.xcomp_vbe_nn': ''},
 'appear area': {'e_trp.xcomp_vbe_nn': ''},
 'appear argument': {'e_trp.xcomp_vbe_nn': ''},
 'appear art': {'e_trp.xcomp_vbe_nn': ''},
 'appear aspect': {'e_trp.xcomp_vbe_nn': ''},
 'appear attitude': {'e_trp.xcomp_vbe_nn': ''},
 'appear behavior': {'e_trp.xcomp_vbe_nn': ''},
 'appear book': {'e_trp.xcomp_vbe_nn': ''},
 'appear business': {'e_trp.xcomp_vbe_nn': ''},
 'appear campus': {'e_trp.xcomp_vbe_nn': ''},
 'appear capability': {'e_trp.xcomp_vbe_nn': ''},
 'appear case': {'e_trp.xcomp_vbe_nn': ''},
 'appear commodity': {'e_trp.xcomp_vbe_nn': ''},
 'appear complexion': {'e_trp.xcomp_vbe_nn': ''},
 'appear contradiction': {'e_trp.xcomp_vbe_nn': ''},
 'appear conversation': {'e_trp.xcomp_vbe_nn': ''},
 'appear cow': {'e_trp.xcomp_vbe_nn': ''},
 'appear crisis': {'e_trp.xcomp_vbe_nn': ''},
 'appear custom': {'e_trp.xcomp_vbe_nn': ''},
 'appear cyberspace': {'e_trp.xcomp_vbe_nn': ''},
 'appear danger': {'e_trp.xcomp_vbe_nn': ''},
 'appear deficiency': {'e_trp.xcomp_vbe_nn': ''},
 'appear degree': {'e_trp.xcomp_vbe_nn': '', 'e_trp.nsv': ''},
 'appear desertification': {'e_trp.xcomp_vbe_nn': ''},
 'appear diarrhea': {'e_trp.xcomp_vbe_nn': ''},
 'appear difference': {'e_trp.xcomp_vbe_nn': ''},
 'appear differentiation': {'e_trp.xcomp_vbe_nn': ''},
 'appear difficulty': {'e_trp.xcomp_vbe_nn': ''},
 'appear discomfort': {'e_trp.xcomp_vbe_nn': ''},
 'appear discussion': {'e_trp.xcomp_vbe_nn': ''},
 'appear disease': {'e_trp.xcomp_vbe_nn': ''},
 'appear disharmony': {'e_trp.xcomp_vbe_nn': ''},
 'appear disorder': {'e_trp.xcomp_vbe_nn': ''},
 'appear dissension': {'e_trp.xcomp_vbe_nn': ''},
 'appear distinction': {'e_trp.xcomp_vbe_nn': ''},
 'appear drought': {'e_trp.xcomp_vbe_nn': ''},
 'appear e': {'e_trp.xcomp_vbe_nn': ''},
 'appear eagle': {'e_trp.xcomp_vbe_nn': ''},
 'appear element': {'e_trp.xcomp_vbe_nn': ''},
 'appear emotion': {'e_trp.xcomp_vbe_nn': ''},
 'appear environment': {'e_trp.xcomp_vbe_nn': ''},
 'appear error': {'e_trp.xcomp_vbe_nn': ''},
 'appear etc.': {'e_trp.xcomp_vbe_nn': ''},
 'appear expression': {'e_trp.xcomp_vbe_nn': ''},
 'appear eye': {'e_trp.xcomp_vbe_nn': ''},
 'appear eyesight': {'e_trp.xcomp_vbe_nn': ''},
 'appear failure': {'e_trp.xcomp_vbe_nn': ''},
 'appear father': {'e_trp.xcomp_vbe_nn': ''},
 'appear flower': {'e_trp.xcomp_vbe_nn': ''},
 'appear food': {'e_trp.xcomp_vbe_nn': ''},
 'appear format': {'e_trp.xcomp_vbe_nn': ''},
 'appear friction': {'e_trp.xcomp_vbe_nn': ''},
 'appear friend': {'e_trp.xcomp_vbe_nn': ''},
 'appear gap': {'e_trp.xcomp_vbe_nn': ''},
 'appear gash': {'e_trp.xcomp_vbe_nn': ''},
 'appear group': {'e_trp.xcomp_vbe_nn': ''},
 'appear growth': {'e_trp.xcomp_vbe_nn': ''},
 'appear habit': {'e_trp.xcomp_vbe_nn': ''},
 'appear harmony': {'e_trp.xcomp_vbe_nn': ''},
 'appear headache': {'e_trp.xcomp_vbe_nn': ''},
 'appear heat': {'e_trp.xcomp_vbe_nn': ''},
 'appear heresy': {'e_trp.xcomp_vbe_nn': ''},
 'appear hole': {'e_trp.xcomp_vbe_nn': ''},
 'appear horror': {'e_trp.xcomp_vbe_nn': ''},
 'appear image': {'e_trp.xcomp_vbe_nn': ''},
 'appear importance': {'e_trp.xcomp_vbe_nn': ''},
 'appear inflation': {'e_trp.xcomp_vbe_nn': ''},
 'appear information': {'e_trp.xcomp_vbe_nn': ''},
 'appear interest': {'e_trp.xcomp_vbe_nn': ''},
 'appear item': {'e_trp.xcomp_vbe_nn': ''},
 'appear job': {'e_trp.xcomp_vbe_nn': ''},
 'appear landslide': {'e_trp.xcomp_vbe_nn': ''},
 'appear life': {'e_trp.xcomp_vbe_nn': ''},
 'appear loophole': {'e_trp.xcomp_vbe_nn': ''},
 'appear lot': {'e_trp.xcomp_vbe_nn': ''},
 'appear lover': {'e_trp.xcomp_vbe_nn': ''},
 'appear machine': {'e_trp.xcomp_vbe_nn': ''},
 'appear melody': {'e_trp.xcomp_vbe_nn': ''},
 'appear mind': {'e_trp.xcomp_vbe_nn': ''},
 'appear mistake': {'e_trp.xcomp_vbe_nn': ''},
 'appear mixture': {'e_trp.xcomp_vbe_nn': ''},
 'appear mode': {'e_trp.xcomp_vbe_nn': ''},
 'appear momentum': {'e_trp.xcomp_vbe_nn': ''},
 'appear mouth': {'e_trp.xcomp_vbe_nn': ''},
 'appear must': {'e_trp.xcomp_vbe_nn': ''},
 'appear news': {'e_trp.xcomp_vbe_nn': ''},
 'appear newspaper': {'e_trp.xcomp_vbe_nn': ''},
 'appear noun': {'e_trp.xcomp_vbe_nn': ''},
 'appear number': {'e_trp.xcomp_vbe_nn': ''},
 'appear obstacle': {'e_trp.xcomp_vbe_nn': ''},
 'appear ocean': {'e_trp.xcomp_vbe_nn': ''},
 'appear oil': {'e_trp.xcomp_vbe_nn': ''},
 'appear oligarch': {'e_trp.xcomp_vbe_nn': ''},
 'appear operation': {'e_trp.xcomp_vbe_nn': ''},
 'appear opinion': {'e_trp.xcomp_vbe_nn': ''},
 'appear paganism': {'e_trp.xcomp_vbe_nn': ''},
 'appear page': {'e_trp.xcomp_vbe_nn': ''},
 'appear people': {'e_trp.xcomp_vbe_nn': ''},
 'appear person': {'e_trp.xcomp_vbe_nn': ''},
 'appear phenomenon': {'e_trp.xcomp_vbe_nn': ''},
 'appear photo': {'e_trp.xcomp_vbe_nn': ''},
 'appear place': {'e_trp.xcomp_vbe_nn': ''},
 'appear player': {'e_trp.xcomp_vbe_nn': ''},
 'appear polarization': {'e_trp.xcomp_vbe_nn': ''},
 'appear preoccupation': {'e_trp.xcomp_vbe_nn': ''},
 'appear product': {'e_trp.xcomp_vbe_nn': ''},
 'appear reaction': {'e_trp.xcomp_vbe_nn': ''},
 'appear reflection': {'e_trp.xcomp_vbe_nn': ''},
 'appear rift': {'e_trp.xcomp_vbe_nn': ''},
 'appear road': {'e_trp.xcomp_vbe_nn': ''},
 'appear rotation': {'e_trp.xcomp_vbe_nn': ''},
 'appear saying': {'e_trp.xcomp_vbe_nn': ''},
 'appear scene': {'e_trp.xcomp_vbe_nn': ''},
 'appear series': {'e_trp.xcomp_vbe_nn': ''},
 'appear shadow': {'e_trp.xcomp_vbe_nn': ''},
 'appear shortage': {'e_trp.xcomp_vbe_nn': ''},
 'appear significance': {'e_trp.xcomp_vbe_nn': ''},
 'appear situation': {'e_trp.xcomp_vbe_nn': ''},
 'appear slum': {'e_trp.xcomp_vbe_nn': ''},
 'appear stain': {'e_trp.xcomp_vbe_nn': ''},
 'appear store': {'e_trp.xcomp_vbe_nn': ''},
 'appear student': {'e_trp.xcomp_vbe_nn': ''},
 'appear symbol': {'e_trp.xcomp_vbe_nn': ''},
 'appear television': {'e_trp.xcomp_vbe_nn': ''},
 'appear tendency': {'e_trp.xcomp_vbe_nn': ''},
 'appear tension': {'e_trp.xcomp_vbe_nn': ''},
 'appear thing': {'e_trp.xcomp_vbe_nn': ''},
 'appear thought': {'e_trp.xcomp_vbe_nn': ''},
 'appear trend': {'e_trp.xcomp_vbe_nn': ''},
 'appear tribe': {'e_trp.xcomp_vbe_nn': ''},
 'appear tumor': {'e_trp.xcomp_vbe_nn': ''},
 'appear type': {'e_trp.xcomp_vbe_nn': ''},
 'appear university': {'e_trp.xcomp_vbe_nn': ''},
 'appear upheaval': {'e_trp.xcomp_vbe_nn': ''},
 'appear uprising': {'e_trp.xcomp_vbe_nn': ''},
 'appear valence': {'e_trp.xcomp_vbe_nn': ''},
 'appear variety': {'e_trp.xcomp_vbe_nn': ''},
 'appear vehicle': {'e_trp.xcomp_vbe_nn': ''},
 'appear war': {'e_trp.xcomp_vbe_nn': ''},
 'appear warning': {'e_trp.xcomp_vbe_nn': ''},
 'appear water': {'e_trp.xcomp_vbe_nn': ''},
 'appear woman': {'e_trp.xcomp_vbe_nn': ''},
 'appear worker': {'e_trp.xcomp_vbe_nn': ''},
 'appear world': {'e_trp.xcomp_vbe_nn': ''},
 'become ability': {'e_trp.xcomp_vbe_nn': '', 'e_trp.nsv': ''},
 'become abundance': {'e_trp.xcomp_vbe_nn': ''},
 'become abyss': {'e_trp.xcomp_vbe_nn': ''},
 'become academician': {'e_trp.xcomp_vbe_nn': ''},
 'become access': {'e_trp.xcomp_vbe_nn': ''},
 'become accountability': {'e_trp.xcomp_vbe_nn': ''},
 'become accounting': {'e_trp.xcomp_vbe_nn': ''},
 'become accusation': {'e_trp.xcomp_vbe_nn': ''},
 'become achievement': {'e_trp.xcomp_vbe_nn': ''},
 'become achiever': {'e_trp.xcomp_vbe_nn': ''},
 'become acquaintance': {'e_trp.xcomp_vbe_nn': ''},
 'become ad': {'e_trp.xcomp_vbe_nn': ''},
 'become administration': {'e_trp.xcomp_vbe_nn': ''},
 'become admiration': {'e_trp.xcomp_vbe_nn': ''},
 'become admission': {'e_trp.xcomp_vbe_nn': ''},
 'become admonition': {'e_trp.xcomp_vbe_nn': ''},
 'become adoption': {'e_trp.xcomp_vbe_nn': ''},
 'become adversity': {'e_trp.xcomp_vbe_nn': ''},
 'become advocacy': {'e_trp.xcomp_vbe_nn': ''},
 'become affection': {'e_trp.xcomp_vbe_nn': ''},
 'become age': {'e_trp.xcomp_vbe_nn': ''},
 'become air': {'e_trp.xcomp_vbe_nn': ''},
 'become alcoholism': {'e_trp.xcomp_vbe_nn': ''},
 'become alienation': {'e_trp.xcomp_vbe_nn': ''},
 'become ambit': {'e_trp.xcomp_vbe_nn': ''},
 'become amusement': {'e_trp.xcomp_vbe_nn': ''},
 'become ang': {'e_trp.xcomp_vbe_nn': ''},
 'become angle': {'e_trp.xcomp_vbe_nn': ''},
 'become ant': {'e_trp.xcomp_vbe_nn': ''},
 'become anxiety': {'e_trp.xcomp_vbe_nn': ''},
 'become apartment': {'e_trp.xcomp_vbe_nn': ''},
 'become apathy': {'e_trp.xcomp_vbe_nn': ''},
 'become apparition': {'e_trp.xcomp_vbe_nn': ''},
 'become appearance': {'e_trp.xcomp_vbe_nn': ''},
 'become apple': {'e_trp.xcomp_vbe_nn': ''},
 'become appliance': {'e_trp.xcomp_vbe_nn': ''},
 'become application': {'e_trp.xcomp_vbe_nn': ''},
 'become archer': {'e_trp.xcomp_vbe_nn': ''},
 'become army': {'e_trp.xcomp_vbe_nn': ''},
 'become as': {'e_trp.xcomp_vbe_nn': ''},
 'become aspiration': {'e_trp.xcomp_vbe_nn': ''},
 'become assessment': {'e_trp.xcomp_vbe_nn': ''},
 'become assistance': {'e_trp.xcomp_vbe_nn': ''},
 'become attention': {'e_trp.xcomp_vbe_nn': ''},
 'become attitude': {'e_trp.xcomp_vbe_nn': ''},
 'become autonomy': {'e_trp.xcomp_vbe_nn': ''},
 'become awareness': {'e_trp.xcomp_vbe_nn': ''},
 'become axiom': {'e_trp.xcomp_vbe_nn': ''},
 'become baby-sitter': {'e_trp.xcomp_vbe_nn': ''},
 'become bachelor': {'e_trp.xcomp_vbe_nn': ''},
 'become background': {'e_trp.xcomp_vbe_nn': ''},
 'become backing': {'e_trp.xcomp_vbe_nn': ''},
 'become baker': {'e_trp.xcomp_vbe_nn': ''},
 'become balm': {'e_trp.xcomp_vbe_nn': ''},
 'become bamboo': {'e_trp.xcomp_vbe_nn': ''},
 'become barber': {'e_trp.xcomp_vbe_nn': ''},
 'become barrel': {'e_trp.xcomp_vbe_nn': ''},
 'become basement': {'e_trp.xcomp_vbe_nn': ''},
 'become bassist': {'e_trp.xcomp_vbe_nn': ''},
 'become batter': {'e_trp.xcomp_vbe_nn': ''},
 'become bean': {'e_trp.xcomp_vbe_nn': ''},
 'become beauty': {'e_trp.xcomp_vbe_nn': ''},
 'become bedroom': {'e_trp.xcomp_vbe_nn': ''},
 'become beer': {'e_trp.xcomp_vbe_nn': ''},
 'become behavior': {'e_trp.xcomp_vbe_nn': ''},
 'become beholder': {'e_trp.xcomp_vbe_nn': ''},
 'become betrayal': {'e_trp.xcomp_vbe_nn': ''},
 'become biologist': {'e_trp.xcomp_vbe_nn': ''},
 'become birthday': {'e_trp.xcomp_vbe_nn': ''},
 'become blade': {'e_trp.xcomp_vbe_nn': ''},
 'become blindness': {'e_trp.xcomp_vbe_nn': ''},
 'become blocker': {'e_trp.xcomp_vbe_nn': ''},
 'become blood': {'e_trp.xcomp_vbe_nn': ''},
 'become blues': {'e_trp.xcomp_vbe_nn': ''},
 'become bond': {'e_trp.xcomp_vbe_nn': ''},
 'become bondage': {'e_trp.xcomp_vbe_nn': ''},
 'become bookworm': {'e_trp.xcomp_vbe_nn': ''},
 'become boomer': {'e_trp.xcomp_vbe_nn': ''},
 'become booster': {'e_trp.xcomp_vbe_nn': ''},
 'become boot': {'e_trp.xcomp_vbe_nn': ''},
 'become bottleneck': {'e_trp.xcomp_vbe_nn': ''},
 'become boundary': {'e_trp.xcomp_vbe_nn': ''},
 'become boyfriend': {'e_trp.xcomp_vbe_nn': ''},
 'become brain': {'e_trp.xcomp_vbe_nn': ''},
 'become bravery': {'e_trp.xcomp_vbe_nn': ''},
 'become bread': {'e_trp.xcomp_vbe_nn': ''},
 'become brick': {'e_trp.xcomp_vbe_nn': ''},
 'become brightness': {'e_trp.xcomp_vbe_nn': ''},
 'become brother-in-law': {'e_trp.xcomp_vbe_nn': ''},
 'become bug': {'e_trp.xcomp_vbe_nn': ''},
 'become bulldog': {'e_trp.xcomp_vbe_nn': ''},
 'become button': {'e_trp.xcomp_vbe_nn': ''},
 'become cadre': {'e_trp.xcomp_vbe_nn': ''},
 'become cage': {'e_trp.xcomp_vbe_nn': ''},
 'become caller': {'e_trp.xcomp_vbe_nn': ''},
 'become cameraman': {'e_trp.xcomp_vbe_nn': ''},
 'become campus': {'e_trp.xcomp_vbe_nn': ''},
 'become canvas': {'e_trp.xcomp_vbe_nn': ''},
 'become capability': {'e_trp.xcomp_vbe_nn': ''},
 'become carbon': {'e_trp.xcomp_vbe_nn': ''},
 'become cartel': {'e_trp.xcomp_vbe_nn': ''},
 'become castle': {'e_trp.xcomp_vbe_nn': ''},
 'become cat': {'e_trp.xcomp_vbe_nn': ''},
 'become catholicity': {'e_trp.xcomp_vbe_nn': ''},
 'become ceo': {'e_trp.xcomp_vbe_nn': ''},
 'become certificate': {'e_trp.xcomp_vbe_nn': ''},
 'become cf': {'e_trp.xcomp_vbe_nn': ''},
 'become chairperson': {'e_trp.xcomp_vbe_nn': ''},
 'become championship': {'e_trp.xcomp_vbe_nn': ''},
 'become changeling': {'e_trp.xcomp_vbe_nn': ''},
 'become chaos': {'e_trp.xcomp_vbe_nn': ''},
 'become cheater': {'e_trp.xcomp_vbe_nn': ''},
 'become china': {'e_trp.xcomp_vbe_nn': ''},
 'become choir': {'e_trp.xcomp_vbe_nn': ''},
 'become chrysalis': {'e_trp.xcomp_vbe_nn': ''},
 'become cigarette': {'e_trp.xcomp_vbe_nn': ''},
 'become circle': {'e_trp.xcomp_vbe_nn': ''},
 'become civilization': {'e_trp.xcomp_vbe_nn': ''},
 'become clam': {'e_trp.xcomp_vbe_nn': ''},
 'become clan': {'e_trp.xcomp_vbe_nn': ''},
 'become classmate': {'e_trp.xcomp_vbe_nn': ''},
 'become cleaner': {'e_trp.xcomp_vbe_nn': ''},
 'become clothes': {'e_trp.xcomp_vbe_nn': ''},
 'become clothing': {'e_trp.xcomp_vbe_nn': ''},
 'become clue': {'e_trp.xcomp_vbe_nn': ''},
 'become co': {'e_trp.xcomp_vbe_nn': ''},
 'become coachman': {'e_trp.xcomp_vbe_nn': ''},
 'become coder': {'e_trp.xcomp_vbe_nn': ''},
 'become cohesion': {'e_trp.xcomp_vbe_nn': ''},
 'become collage': {'e_trp.xcomp_vbe_nn': ''},
 'become collegian': {'e_trp.xcomp_vbe_nn': ''},
 'become column': {'e_trp.xcomp_vbe_nn': ''},
 'become combination': {'e_trp.xcomp_vbe_nn': ''},
 'become commercialism': {'e_trp.xcomp_vbe_nn': ''},
 'become committee': {'e_trp.xcomp_vbe_nn': ''},
 'become communication': {'e_trp.xcomp_vbe_nn': ''},
 'become comparison': {'e_trp.xcomp_vbe_nn': ''},
 'become competency': {'e_trp.xcomp_vbe_nn': ''},
 'become competitiveness': {'e_trp.xcomp_vbe_nn': ''},
 'become complaint': {'e_trp.xcomp_vbe_nn': ''},
 'become complexity': {'e_trp.xcomp_vbe_nn': ''},
 'become conditioning': {'e_trp.xcomp_vbe_nn': ''},
 'become confidence': {'e_trp.xcomp_vbe_nn': ''},
 'become confusion': {'e_trp.xcomp_vbe_nn': ''},
 'become connotation': {'e_trp.xcomp_vbe_nn': ''},
 'become consensus': {'e_trp.xcomp_vbe_nn': ''},
 'become consequence': {'e_trp.xcomp_vbe_nn': ''},
 'become conspiracy': {'e_trp.xcomp_vbe_nn': ''},
 'become constraint': {'e_trp.xcomp_vbe_nn': ''},
 'become construction': {'e_trp.xcomp_vbe_nn': ''},
 'become consumption': {'e_trp.xcomp_vbe_nn': ''},
 'become contact': {'e_trp.xcomp_vbe_nn': ''},
 'become contagion': {'e_trp.xcomp_vbe_nn': ''},
 'become container': {'e_trp.xcomp_vbe_nn': ''},
 'become contradiction': {'e_trp.xcomp_vbe_nn': ''},
 'become convenience': {'e_trp.xcomp_vbe_nn': ''},
 'become convent': {'e_trp.xcomp_vbe_nn': ''},
 'become conversation': {'e_trp.xcomp_vbe_nn': ''},
 'become cooker': {'e_trp.xcomp_vbe_nn': ''},
 'become coolness': {'e_trp.xcomp_vbe_nn': ''},
 'become copycat': {'e_trp.xcomp_vbe_nn': ''},
 'become corn': {'e_trp.xcomp_vbe_nn': ''},
 'become corpse': {'e_trp.xcomp_vbe_nn': ''},
 'become counterpart': {'e_trp.xcomp_vbe_nn': ''},
 'become countryside': {'e_trp.xcomp_vbe_nn': ''},
 'become courage': {'e_trp.xcomp_vbe_nn': ''},
 'become courtship': {'e_trp.xcomp_vbe_nn': ''},
 'become cow': {'e_trp.xcomp_vbe_nn': ''},
 'become crammer': {'e_trp.xcomp_vbe_nn': ''},
 'become cream': {'e_trp.xcomp_vbe_nn': ''},
 'become creativity': {'e_trp.xcomp_vbe_nn': ''},
 'become credo': {'e_trp.xcomp_vbe_nn': ''},
 'become crescent': {'e_trp.xcomp_vbe_nn': ''},
 'become crony': {'e_trp.xcomp_vbe_nn': ''},
 'become crowd': {'e_trp.xcomp_vbe_nn': ''},
 'become crystal': {'e_trp.xcomp_vbe_nn': ''},
 'become culprit': {'e_trp.xcomp_vbe_nn': ''},
 'become cupboard': {'e_trp.xcomp_vbe_nn': ''},
 'become curriculum': {'e_trp.xcomp_vbe_nn': ''},
 'become cutter': {'e_trp.xcomp_vbe_nn': ''},
 'become cyberspace': {'e_trp.xcomp_vbe_nn': ''},
 'become dairy': {'e_trp.xcomp_vbe_nn': ''},
 'become darkness': {'e_trp.xcomp_vbe_nn': ''},
 'become deafness': {'e_trp.xcomp_vbe_nn': ''},
 'become dealing': {'e_trp.xcomp_vbe_nn': ''},
 'become debris': {'e_trp.xcomp_vbe_nn': ''},
 'become debtor': {'e_trp.xcomp_vbe_nn': ''},
 'become decoration': {'e_trp.xcomp_vbe_nn': ''},
 'become defense': {'e_trp.xcomp_vbe_nn': ''},
 'become deficiency': {'e_trp.xcomp_vbe_nn': ''},
 'become degree': {'e_trp.xcomp_vbe_nn': ''},
 'become delusion': {'e_trp.xcomp_vbe_nn': ''},
 'become demon': {'e_trp.xcomp_vbe_nn': ''},
 'become dependence': {'e_trp.xcomp_vbe_nn': ''},
 'become depravity': {'e_trp.xcomp_vbe_nn': ''},
 'become depth': {'e_trp.xcomp_vbe_nn': ''},
 'become desalination': {'e_trp.xcomp_vbe_nn': ''},
 'become deserter': {'e_trp.xcomp_vbe_nn': ''},
 'become desertification': {'e_trp.xcomp_vbe_nn': ''},
 'become despot': {'e_trp.xcomp_vbe_nn': ''},
 'become dessert': {'e_trp.xcomp_vbe_nn': ''},
 'become deterioration': {'e_trp.xcomp_vbe_nn': ''},
 'become development': {'e_trp.xcomp_vbe_nn': ''},
 'become dialogue': {'e_trp.xcomp_vbe_nn': ''},
 'become dictionary': {'e_trp.xcomp_vbe_nn': ''},
 'become difficulty': {'e_trp.xcomp_vbe_nn': ''},
 'become digger': {'e_trp.xcomp_vbe_nn': ''},
 'become dilemma': {'e_trp.xcomp_vbe_nn': ''},
 'become diligence': {'e_trp.xcomp_vbe_nn': ''},
 'become direction': {'e_trp.xcomp_vbe_nn': ''},
 'become dirk': {'e_trp.xcomp_vbe_nn': ''},
 'become disability': {'e_trp.xcomp_vbe_nn': ''},
 'become discourse': {'e_trp.xcomp_vbe_nn': ''},
 'become dishonesty': {'e_trp.xcomp_vbe_nn': ''},
 'become disparity': {'e_trp.xcomp_vbe_nn': ''},
 'become dissemination': {'e_trp.xcomp_vbe_nn': ''},
 'become distortion': {'e_trp.xcomp_vbe_nn': ''},
 'become disturbance': {'e_trp.xcomp_vbe_nn': ''},
 'become diver': {'e_trp.xcomp_vbe_nn': ''},
 'become diversification': {'e_trp.xcomp_vbe_nn': ''},
 'become diversity': {'e_trp.xcomp_vbe_nn': ''},
 'become dogmatist': {'e_trp.xcomp_vbe_nn': ''},
 'become doll': {'e_trp.xcomp_vbe_nn': ''},
 'become donkey': {'e_trp.xcomp_vbe_nn': ''},
 'become dozen': {'e_trp.xcomp_vbe_nn': ''},
 'become dragon': {'e_trp.xcomp_vbe_nn': ''},
 'become dragonfly': {'e_trp.xcomp_vbe_nn': ''},
 'become drawback': {'e_trp.xcomp_vbe_nn': ''},
 'become drifter': {'e_trp.xcomp_vbe_nn': ''},
 'become drunkard': {'e_trp.xcomp_vbe_nn': ''},
 'become duplication': {'e_trp.xcomp_vbe_nn': ''},
 'become dwarf': {'e_trp.xcomp_vbe_nn': ''},
 'become eagle': {'e_trp.xcomp_vbe_nn': ''},
 'become earth': {'e_trp.xcomp_vbe_nn': ''},
 'become earthquake': {'e_trp.xcomp_vbe_nn': ''},
 'become eater': {'e_trp.xcomp_vbe_nn': ''},
 'become eden': {'e_trp.xcomp_vbe_nn': ''},
 'become education': {'e_trp.xcomp_vbe_nn': ''},
 'become efficiency': {'e_trp.xcomp_vbe_nn': ''},
 'become egghead': {'e_trp.xcomp_vbe_nn': ''},
 'become ego': {'e_trp.xcomp_vbe_nn': ''},
 'become elderly': {'e_trp.xcomp_vbe_nn': ''},
 'become elegance': {'e_trp.xcomp_vbe_nn': ''},
 'become elegy': {'e_trp.xcomp_vbe_nn': ''},
 'become embryo': {'e_trp.xcomp_vbe_nn': ''},
 'become en': {'e_trp.xcomp_vbe_nn': ''},
 'become encumbrance': {'e_trp.xcomp_vbe_nn': ''},
 'become endeavor': {'e_trp.xcomp_vbe_nn': ''},
 'become enthusiasm': {'e_trp.xcomp_vbe_nn': ''},
 'become enticement': {'e_trp.xcomp_vbe_nn': ''},
 'become entirety': {'e_trp.xcomp_vbe_nn': ''},
 'become environment': {'e_trp.xcomp_vbe_nn': ''},
 'become environmentalist': {'e_trp.xcomp_vbe_nn': ''},
 'become era': {'e_trp.xcomp_vbe_nn': ''},
 'become error': {'e_trp.xcomp_vbe_nn': ''},
 'become essay': {'e_trp.xcomp_vbe_nn': ''},
 'become etc': {'e_trp.xcomp_vbe_nn': ''},
 'become eternity': {'e_trp.xcomp_vbe_nn': ''},
 'become everyman': {'e_trp.xcomp_vbe_nn': ''},
 'become ex-boyfriend': {'e_trp.xcomp_vbe_nn': ''},
 'become exam': {'e_trp.xcomp_vbe_nn': ''},
 'become examination': {'e_trp.xcomp_vbe_nn': ''},
 'become excellence': {'e_trp.xcomp_vbe_nn': ''},
 'become existence': {'e_trp.xcomp_vbe_nn': ''},
 'become expectation': {'e_trp.xcomp_vbe_nn': ''},
 'become explanation': {'e_trp.xcomp_vbe_nn': ''},
 'become exploitation': {'e_trp.xcomp_vbe_nn': ''},
 'become exploration': {'e_trp.xcomp_vbe_nn': ''},
 'become explosion': {'e_trp.xcomp_vbe_nn': ''},
 'become extinction': {'e_trp.xcomp_vbe_nn': ''},
 'become extrovert': {'e_trp.xcomp_vbe_nn': ''},
 'become eyewitness': {'e_trp.xcomp_vbe_nn': ''},
 'become facility': {'e_trp.xcomp_vbe_nn': ''},
 'become faction': {'e_trp.xcomp_vbe_nn': ''},
 'become fading': {'e_trp.xcomp_vbe_nn': ''},
 'become fame': {'e_trp.xcomp_vbe_nn': ''},
 'become farewell': {'e_trp.xcomp_vbe_nn': ''},
 'become farmland': {'e_trp.xcomp_vbe_nn': ''},
 'become fascination': {'e_trp.xcomp_vbe_nn': ''},
 'become fashioner': {'e_trp.xcomp_vbe_nn': ''},
 'become fever': {'e_trp.xcomp_vbe_nn': ''},
 'become fiber': {'e_trp.xcomp_vbe_nn': ''},
 'become fiend': {'e_trp.xcomp_vbe_nn': ''},
 'become flogger': {'e_trp.xcomp_vbe_nn': ''},
 'become fluency': {'e_trp.xcomp_vbe_nn': ''},
 'become forefront': {'e_trp.xcomp_vbe_nn': ''},
 'become formalism': {'e_trp.xcomp_vbe_nn': ''},
 'become formation': {'e_trp.xcomp_vbe_nn': ''},
 'become fortitude': {'e_trp.xcomp_vbe_nn': ''},
 'become fortune': {'e_trp.xcomp_vbe_nn': ''},
 'become fraction': {'e_trp.xcomp_vbe_nn': ''},
 'become fragility': {'e_trp.xcomp_vbe_nn': ''},
 'become frailty': {'e_trp.xcomp_vbe_nn': ''},
 'become freedom': {'e_trp.xcomp_vbe_nn': ''},
 'become freeway': {'e_trp.xcomp_vbe_nn': ''},
 'become frequency': {'e_trp.xcomp_vbe_nn': ''},
 'become friendship': {'e_trp.xcomp_vbe_nn': ''},
 'become frustration': {'e_trp.xcomp_vbe_nn': ''},
 'become fullback': {'e_trp.xcomp_vbe_nn': ''},
 'become functionary': {'e_trp.xcomp_vbe_nn': ''},
 'become fury': {'e_trp.xcomp_vbe_nn': ''},
 'become garbage': {'e_trp.xcomp_vbe_nn': ''},
 'become gate': {'e_trp.xcomp_vbe_nn': ''},
 'become gem': {'e_trp.xcomp_vbe_nn': ''},
 'become generalization': {'e_trp.xcomp_vbe_nn': ''},
 'become generosity': {'e_trp.xcomp_vbe_nn': ''},
 'become genre': {'e_trp.xcomp_vbe_nn': ''},
 'become gent': {'e_trp.xcomp_vbe_nn': ''},
 'become geographer': {'e_trp.xcomp_vbe_nn': ''},
 'become geologist': {'e_trp.xcomp_vbe_nn': ''},
 'become giver': {'e_trp.xcomp_vbe_nn': ''},
 'become globalization': {'e_trp.xcomp_vbe_nn': ''},
 'become globe': {'e_trp.xcomp_vbe_nn': ''},
 'become goods': {'e_trp.xcomp_vbe_nn': ''},
 'become grater': {'e_trp.xcomp_vbe_nn': ''},
 'become gravedigger': {'e_trp.xcomp_vbe_nn': ''},
 'become greenhouse': {'e_trp.xcomp_vbe_nn': ''},
 'become grid': {'e_trp.xcomp_vbe_nn': ''},
 'become grief': {'e_trp.xcomp_vbe_nn': ''},
 'become grinder': {'e_trp.xcomp_vbe_nn': ''},
 'become groove': {'e_trp.xcomp_vbe_nn': ''},
 'become grownup': {'e_trp.xcomp_vbe_nn': ''},
 'become growth': {'e_trp.xcomp_vbe_nn': ''},
 'become guidance': {'e_trp.xcomp_vbe_nn': ''},
 'become hacker': {'e_trp.xcomp_vbe_nn': ''},
 'become hair': {'e_trp.xcomp_vbe_nn': ''},
 'become handrail': {'e_trp.xcomp_vbe_nn': ''},
 'become handwriting': {'e_trp.xcomp_vbe_nn': ''},
 'become happiness': {'e_trp.xcomp_vbe_nn': ''},
 'become harassment': {'e_trp.xcomp_vbe_nn': ''},
 'become harbor': {'e_trp.xcomp_vbe_nn': ''},
 'become havoc': {'e_trp.xcomp_vbe_nn': ''},
 'become healthier': {'e_trp.xcomp_vbe_nn': ''},
 'become heartbreak': {'e_trp.xcomp_vbe_nn': ''},
 'become heat': {'e_trp.xcomp_vbe_nn': ''},
 'become heater': {'e_trp.xcomp_vbe_nn': ''},
 'become heath': {'e_trp.xcomp_vbe_nn': ''},
 'become heaven': {'e_trp.xcomp_vbe_nn': ''},
 'become hedonist': {'e_trp.xcomp_vbe_nn': ''},
 'become helot': {'e_trp.xcomp_vbe_nn': ''},
 'become herb': {'e_trp.xcomp_vbe_nn': ''},
 'become heritage': {'e_trp.xcomp_vbe_nn': ''},
 'become highpoint': {'e_trp.xcomp_vbe_nn': ''},
 'become highroad': {'e_trp.xcomp_vbe_nn': ''},
 'become highway': {'e_trp.xcomp_vbe_nn': ''},
 'become homelessness': {'e_trp.xcomp_vbe_nn': ''},
 'become homemaker': {'e_trp.xcomp_vbe_nn': ''},
 'become hometown': {'e_trp.xcomp_vbe_nn': ''},
 'become horizon': {'e_trp.xcomp_vbe_nn': ''},
 'become horticulturist': {'e_trp.xcomp_vbe_nn': ''},
 'become hour': {'e_trp.xcomp_vbe_nn': ''},
 'become humor': {'e_trp.xcomp_vbe_nn': ''},
 'become hundred': {'e_trp.xcomp_vbe_nn': ''},
 'become hurdle': {'e_trp.xcomp_vbe_nn': ''},
 'become iceman': {'e_trp.xcomp_vbe_nn': ''},
 'become identification': {'e_trp.xcomp_vbe_nn': ''},
 'become idiom': {'e_trp.xcomp_vbe_nn': ''},
 'become idiot': {'e_trp.xcomp_vbe_nn': ''},
 'become idolater': {'e_trp.xcomp_vbe_nn': ''},
 'become ignorance': {'e_trp.xcomp_vbe_nn': ''},
 'become illness': {'e_trp.xcomp_vbe_nn': ''},
 'become illustrator': {'e_trp.xcomp_vbe_nn': ''},
 'become impairment': {'e_trp.xcomp_vbe_nn': ''},
 'become impetus': {'e_trp.xcomp_vbe_nn': ''},
 'become importance': {'e_trp.xcomp_vbe_nn': ''},
 'become impression': {'e_trp.xcomp_vbe_nn': ''},
 'become incarnation': {'e_trp.xcomp_vbe_nn': ''},
 'become independence': {'e_trp.xcomp_vbe_nn': ''},
 'become indifference': {'e_trp.xcomp_vbe_nn': ''},
 'become indulgence': {'e_trp.xcomp_vbe_nn': ''},
 'become industrialist': {'e_trp.xcomp_vbe_nn': ''},
 'become inefficiency': {'e_trp.xcomp_vbe_nn': ''},
 'become inferiority': {'e_trp.xcomp_vbe_nn': ''},
 'become inflammation': {'e_trp.xcomp_vbe_nn': ''},
 'become inheritor': {'e_trp.xcomp_vbe_nn': ''},
 'become injury': {'e_trp.xcomp_vbe_nn': ''},
 'become injustice': {'e_trp.xcomp_vbe_nn': ''},
 'become insecurity': {'e_trp.xcomp_vbe_nn': ''},
 'become integration': {'e_trp.xcomp_vbe_nn': ''},
 'become integrity': {'e_trp.xcomp_vbe_nn': ''},
 'become intelligence': {'e_trp.xcomp_vbe_nn': ''},
 'become interaction': {'e_trp.xcomp_vbe_nn': ''},
 'become interlude': {'e_trp.xcomp_vbe_nn': ''},
 'become internationalization': {'e_trp.xcomp_vbe_nn': ''},
 'become internet': {'e_trp.xcomp_vbe_nn': ''},
 'become internship': {'e_trp.xcomp_vbe_nn': ''},
 'become interviewee': {'e_trp.xcomp_vbe_nn': ''},
 'become introvert': {'e_trp.xcomp_vbe_nn': ''},
 'become invention': {'e_trp.xcomp_vbe_nn': ''},
 'become inventor': {'e_trp.xcomp_vbe_nn': ''},
 'become irony': {'e_trp.xcomp_vbe_nn': ''},
 'become jack': {'e_trp.xcomp_vbe_nn': ''},
 'become jail': {'e_trp.xcomp_vbe_nn': ''},
 'become jam': {'e_trp.xcomp_vbe_nn': ''},
 'become jock': {'e_trp.xcomp_vbe_nn': ''},
 'become joy': {'e_trp.xcomp_vbe_nn': ''},
 'become judgement': {'e_trp.xcomp_vbe_nn': ''},
 'become judgment': {'e_trp.xcomp_vbe_nn': ''},
 'become juice': {'e_trp.xcomp_vbe_nn': ''},
 'become kidnapper': {'e_trp.xcomp_vbe_nn': ''},
 'become la': {'e_trp.xcomp_vbe_nn': ''},
 'become labor': {'e_trp.xcomp_vbe_nn': ''},
 'become ladder': {'e_trp.xcomp_vbe_nn': ''},
 'become lager': {'e_trp.xcomp_vbe_nn': ''},
 'become lamb': {'e_trp.xcomp_vbe_nn': ''},
 'become landfill': {'e_trp.xcomp_vbe_nn': ''},
 'become lantern': {'e_trp.xcomp_vbe_nn': ''},
 'become laxity': {'e_trp.xcomp_vbe_nn': ''},
 'become layman': {'e_trp.xcomp_vbe_nn': ''},
 'become lazybones': {'e_trp.xcomp_vbe_nn': ''},
 'become leadership': {'e_trp.xcomp_vbe_nn': ''},
 'become leaf': {'e_trp.xcomp_vbe_nn': ''},
 'become learning': {'e_trp.xcomp_vbe_nn': ''},
 'become leaver': {'e_trp.xcomp_vbe_nn': ''},
 'become leisure': {'e_trp.xcomp_vbe_nn': ''},
 'become liberalization': {'e_trp.xcomp_vbe_nn': ''},
 'become lifestyle': {'e_trp.xcomp_vbe_nn': ''},
 'become lifetime': {'e_trp.xcomp_vbe_nn': ''},
 'become lineage': {'e_trp.xcomp_vbe_nn': ''},
 'become lineup': {'e_trp.xcomp_vbe_nn': ''},
 'become literacy': {'e_trp.xcomp_vbe_nn': ''},
 'become literature': {'e_trp.xcomp_vbe_nn': ''},
 'become loafer': {'e_trp.xcomp_vbe_nn': ''},
 'become loan': {'e_trp.xcomp_vbe_nn': ''},
 'become logger': {'e_trp.xcomp_vbe_nn': ''},
 'become logo': {'e_trp.xcomp_vbe_nn': ''},
 'become loneliness': {'e_trp.xcomp_vbe_nn': ''},
 'become lottery': {'e_trp.xcomp_vbe_nn': ''},
 'become louse': {'e_trp.xcomp_vbe_nn': ''},
 'become lube': {'e_trp.xcomp_vbe_nn': ''},
 'become lullaby': {'e_trp.xcomp_vbe_nn': ''},
 'become machinery': {'e_trp.xcomp_vbe_nn': ''},
 'become madman': {'e_trp.xcomp_vbe_nn': ''},
 'become maidservant': {'e_trp.xcomp_vbe_nn': ''},
 'become mailman': {'e_trp.xcomp_vbe_nn': ''},
 'become mainland': {'e_trp.xcomp_vbe_nn': ''},
 'become maintainer': {'e_trp.xcomp_vbe_nn': ''},
 'become make-up': {'e_trp.xcomp_vbe_nn': ''},
 'become malaria': {'e_trp.xcomp_vbe_nn': ''},
 'become malnutrition': {'e_trp.xcomp_vbe_nn': ''},
 'become maniac': {'e_trp.xcomp_vbe_nn': ''},
 'become mankind': {'e_trp.xcomp_vbe_nn': ''},
 'become manner': {'e_trp.xcomp_vbe_nn': ''},
 'become manuscript': {'e_trp.xcomp_vbe_nn': ''},
 'become map': {'e_trp.xcomp_vbe_nn': ''},
 'become marketing': {'e_trp.xcomp_vbe_nn': ''},
 'become marriage': {'e_trp.xcomp_vbe_nn': ''},
 'become masterpiece': {'e_trp.xcomp_vbe_nn': ''},
 'become mater': {'e_trp.xcomp_vbe_nn': ''},
 'become materialist': {'e_trp.xcomp_vbe_nn': ''},
 'become maturation': {'e_trp.xcomp_vbe_nn': ''},
 'become maturity': {'e_trp.xcomp_vbe_nn': ''},
 'become meaning': {'e_trp.xcomp_vbe_nn': ''},
 'become measurement': {'e_trp.xcomp_vbe_nn': ''},
 'become media': {'e_trp.xcomp_vbe_nn': ''},
 'become mediocrity': {'e_trp.xcomp_vbe_nn': ''},
 'become melody': {'e_trp.xcomp_vbe_nn': ''},
 'become meme': {'e_trp.xcomp_vbe_nn': ''},
 'become mendicant': {'e_trp.xcomp_vbe_nn': ''},
 'become merchant': {'e_trp.xcomp_vbe_nn': ''},
 'become mere': {'e_trp.xcomp_vbe_nn': ''},
 'become metropolis': {'e_trp.xcomp_vbe_nn': ''},
 'become microbiology': {'e_trp.xcomp_vbe_nn': ''},
 'become milepost': {'e_trp.xcomp_vbe_nn': ''},
 'become milliner': {'e_trp.xcomp_vbe_nn': ''},
 'become mind': {'e_trp.xcomp_vbe_nn': ''},
 'become minster': {'e_trp.xcomp_vbe_nn': ''},
 'become miracle': {'e_trp.xcomp_vbe_nn': ''},
 'become miser': {'e_trp.xcomp_vbe_nn': ''},
 'become misery': {'e_trp.xcomp_vbe_nn': ''},
 'become mixture': {'e_trp.xcomp_vbe_nn': ''},
 'become modernization': {'e_trp.xcomp_vbe_nn': ''},
 'become monitor': {'e_trp.xcomp_vbe_nn': ''},
 'become monstrosity': {'e_trp.xcomp_vbe_nn': ''},
 'become month': {'e_trp.xcomp_vbe_nn': ''},
 'become mood': {'e_trp.xcomp_vbe_nn': ''},
 'become morality': {'e_trp.xcomp_vbe_nn': ''},
 'become mosquito': {'e_trp.xcomp_vbe_nn': ''},
 'become moth': {'e_trp.xcomp_vbe_nn': ''},
 'become motherland': {'e_trp.xcomp_vbe_nn': ''},
 'become mouse': {'e_trp.xcomp_vbe_nn': ''},
 'become musketeer': {'e_trp.xcomp_vbe_nn': ''},
 'become myopia': {'e_trp.xcomp_vbe_nn': ''},
 'become mythology': {'e_trp.xcomp_vbe_nn': ''},
 'become nanny': {'e_trp.xcomp_vbe_nn': ''},
 'become navigator': {'e_trp.xcomp_vbe_nn': ''},
 'become nearsightedness': {'e_trp.xcomp_vbe_nn': ''},
 'become needle': {'e_trp.xcomp_vbe_nn': ''},
 'become neighborhood': {'e_trp.xcomp_vbe_nn': ''},
 'become nerd': {'e_trp.xcomp_vbe_nn': ''},
 'become nerve': {'e_trp.xcomp_vbe_nn': ''},
 'become net': {'e_trp.xcomp_vbe_nn': ''},
 'become neurosurgery': {'e_trp.xcomp_vbe_nn': ''},
 'become neutrality': {'e_trp.xcomp_vbe_nn': ''},
 'become newsboy': {'e_trp.xcomp_vbe_nn': ''},
 'become newspaper': {'e_trp.xcomp_vbe_nn': ''},
 'become newswoman': {'e_trp.xcomp_vbe_nn': ''},
 'become nicety': {'e_trp.xcomp_vbe_nn': ''},
 'become ninja': {'e_trp.xcomp_vbe_nn': ''},
 'become novel': {'e_trp.xcomp_vbe_nn': ''},
 'become numbness': {'e_trp.xcomp_vbe_nn': ''},
 'become nut': {'e_trp.xcomp_vbe_nn': ''},
 'become nutrition': {'e_trp.xcomp_vbe_nn': ''},
 'become nutritionist': {'e_trp.xcomp_vbe_nn': ''},
 'become nutter': {'e_trp.xcomp_vbe_nn': ''},
 'become obesity': {'e_trp.xcomp_vbe_nn': ''},
 'become ocean': {'e_trp.xcomp_vbe_nn': ''},
 'become officeholder': {'e_trp.xcomp_vbe_nn': ''},
 'become oncologist': {'e_trp.xcomp_vbe_nn': ''},
 'become opener': {'e_trp.xcomp_vbe_nn': ''},
 'become opinion': {'e_trp.xcomp_vbe_nn': ''},
 'become oppressor': {'e_trp.xcomp_vbe_nn': ''},
 'become optimism': {'e_trp.xcomp_vbe_nn': ''},
 'become orator': {'e_trp.xcomp_vbe_nn': ''},
 'become overconfidence': {'e_trp.xcomp_vbe_nn': ''},
 'become overpopulation': {'e_trp.xcomp_vbe_nn': ''},
 'become page': {'e_trp.xcomp_vbe_nn': ''},
 'become panda': {'e_trp.xcomp_vbe_nn': ''},
 'become pap': {'e_trp.xcomp_vbe_nn': ''},
 'become paparazzo': {'e_trp.xcomp_vbe_nn': ''},
 'become parking': {'e_trp.xcomp_vbe_nn': ''},
 'become particle': {'e_trp.xcomp_vbe_nn': ''},
 'become passer': {'e_trp.xcomp_vbe_nn': ''},
 'become patience': {'e_trp.xcomp_vbe_nn': ''},
 'become paucity': {'e_trp.xcomp_vbe_nn': ''},
 'become paycheck': {'e_trp.xcomp_vbe_nn': ''},
 'become peace': {'e_trp.xcomp_vbe_nn': ''},
 'become pedant': {'e_trp.xcomp_vbe_nn': ''},
 'become peer': {'e_trp.xcomp_vbe_nn': ''},
 'become perfection': {'e_trp.xcomp_vbe_nn': ''},
 'become perfectionist': {'e_trp.xcomp_vbe_nn': ''},
 'become perpetrator': {'e_trp.xcomp_vbe_nn': ''},
 'become personage': {'e_trp.xcomp_vbe_nn': ''},
 'become pessimist': {'e_trp.xcomp_vbe_nn': ''},
 'become philosophy': {'e_trp.xcomp_vbe_nn': ''},
 'become pie': {'e_trp.xcomp_vbe_nn': ''},
 'become pig': {'e_trp.xcomp_vbe_nn': ''},
 'become pinnacle': {'e_trp.xcomp_vbe_nn': ''},
 'become pint': {'e_trp.xcomp_vbe_nn': ''},
 'become pitfall': {'e_trp.xcomp_vbe_nn': ''},
 'become pity': {'e_trp.xcomp_vbe_nn': ''},
 'become planting': {'e_trp.xcomp_vbe_nn': ''},
 'become pole': {'e_trp.xcomp_vbe_nn': ''},
 'become policewoman': {'e_trp.xcomp_vbe_nn': ''},
 'become politico': {'e_trp.xcomp_vbe_nn': ''},
 'become pollutant': {'e_trp.xcomp_vbe_nn': ''},
 'become pollution': {'e_trp.xcomp_vbe_nn': ''},
 'become poplar': {'e_trp.xcomp_vbe_nn': ''},
 'become popularity': {'e_trp.xcomp_vbe_nn': ''},
 'become population': {'e_trp.xcomp_vbe_nn': ''},
 'become postgraduate': {'e_trp.xcomp_vbe_nn': ''},
 'become pot': {'e_trp.xcomp_vbe_nn': ''},
 'become potato': {'e_trp.xcomp_vbe_nn': ''},
 'become potluck': {'e_trp.xcomp_vbe_nn': ''},
 'become poverty': {'e_trp.xcomp_vbe_nn': ''},
 'become preamble': {'e_trp.xcomp_vbe_nn': ''},
 'become precept': {'e_trp.xcomp_vbe_nn': ''},
 'become prediction': {'e_trp.xcomp_vbe_nn': ''},
 'become prefect': {'e_trp.xcomp_vbe_nn': ''},
 'become preference': {'e_trp.xcomp_vbe_nn': ''},
 'become prejudice': {'e_trp.xcomp_vbe_nn': ''},
 'become premise': {'e_trp.xcomp_vbe_nn': ''},
 'become prestige': {'e_trp.xcomp_vbe_nn': ''},
 'become pretension': {'e_trp.xcomp_vbe_nn': ''},
 'become prevalence': {'e_trp.xcomp_vbe_nn': ''},
 'become pride': {'e_trp.xcomp_vbe_nn': ''},
 'become promotion': {'e_trp.xcomp_vbe_nn': ''},
 'become pronoun': {'e_trp.xcomp_vbe_nn': ''},
 'become proposer': {'e_trp.xcomp_vbe_nn': ''},
 'become prosperity': {'e_trp.xcomp_vbe_nn': ''},
 'become protagonist': {'e_trp.xcomp_vbe_nn': ''},
 'become protection': {'e_trp.xcomp_vbe_nn': ''},
 'become psychopath': {'e_trp.xcomp_vbe_nn': ''},
 'become pundit': {'e_trp.xcomp_vbe_nn': ''},
 'become purpose': {'e_trp.xcomp_vbe_nn': ''},
 'become quintessence': {'e_trp.xcomp_vbe_nn': ''},
 'become quitter': {'e_trp.xcomp_vbe_nn': ''},
 'become racing': {'e_trp.xcomp_vbe_nn': ''},
 'become raiser': {'e_trp.xcomp_vbe_nn': ''},
 'become ratio': {'e_trp.xcomp_vbe_nn': ''},
 'become reaction': {'e_trp.xcomp_vbe_nn': ''},
 'become realism': {'e_trp.xcomp_vbe_nn': ''},
 'become realization': {'e_trp.xcomp_vbe_nn': ''},
 'become recollection': {'e_trp.xcomp_vbe_nn': ''},
 'become reduction': {'e_trp.xcomp_vbe_nn': ''},
 'become regulation': {'e_trp.xcomp_vbe_nn': ''},
 'become relaxation': {'e_trp.xcomp_vbe_nn': ''},
 'become reliance': {'e_trp.xcomp_vbe_nn': ''},
 'become renown': {'e_trp.xcomp_vbe_nn': ''},
 'become reproduction': {'e_trp.xcomp_vbe_nn': ''},
 'become reputation': {'e_trp.xcomp_vbe_nn': ''},
 'become research': {'e_trp.xcomp_vbe_nn': ''},
 'become resistance': {'e_trp.xcomp_vbe_nn': ''},
 'become restriction': {'e_trp.xcomp_vbe_nn': ''},
 'become returnee': {'e_trp.xcomp_vbe_nn': ''},
 'become revenge': {'e_trp.xcomp_vbe_nn': ''},
 'become revenue': {'e_trp.xcomp_vbe_nn': ''},
 'become rhyme': {'e_trp.xcomp_vbe_nn': ''},
 'become rhythm': {'e_trp.xcomp_vbe_nn': ''},
 'become riches': {'e_trp.xcomp_vbe_nn': ''},
 'become richness': {'e_trp.xcomp_vbe_nn': ''},
 'become rift': {'e_trp.xcomp_vbe_nn': ''},
 'become rigidity': {'e_trp.xcomp_vbe_nn': ''},
 'become rink': {'e_trp.xcomp_vbe_nn': ''},
 'become ripper': {'e_trp.xcomp_vbe_nn': ''},
 'become riser': {'e_trp.xcomp_vbe_nn': ''},
 'become robber': {'e_trp.xcomp_vbe_nn': ''},
 'become robbery': {'e_trp.xcomp_vbe_nn': ''},
 'become robot': {'e_trp.xcomp_vbe_nn': ''},
 'become roughness': {'e_trp.xcomp_vbe_nn': ''},
 'become ruin': {'e_trp.xcomp_vbe_nn': ''},
 'become sadness': {'e_trp.xcomp_vbe_nn': ''},
 'become safety': {'e_trp.xcomp_vbe_nn': ''},
 'become sagacity': {'e_trp.xcomp_vbe_nn': ''},
 'become sake': {'e_trp.xcomp_vbe_nn': ''},
 'become salesperson': {'e_trp.xcomp_vbe_nn': ''},
 'become sand': {'e_trp.xcomp_vbe_nn': ''},
 'become saying': {'e_trp.xcomp_vbe_nn': ''},
 'become scarecrow': {'e_trp.xcomp_vbe_nn': ''},
 'become scenery': {'e_trp.xcomp_vbe_nn': ''},
 'become schoolgirl': {'e_trp.xcomp_vbe_nn': ''},
 'become sealer': {'e_trp.xcomp_vbe_nn': ''},
 'become seedbed': {'e_trp.xcomp_vbe_nn': ''},
 'become selection': {'e_trp.xcomp_vbe_nn': ''},
 'become self-confidence': {'e_trp.xcomp_vbe_nn': ''},
 'become self-control': {'e_trp.xcomp_vbe_nn': ''},
 'become self-esteem': {'e_trp.xcomp_vbe_nn': ''},
 'become self-reliance': {'e_trp.xcomp_vbe_nn': ''},
 'become selfishness': {'e_trp.xcomp_vbe_nn': ''},
 'become senescence': {'e_trp.xcomp_vbe_nn': ''},
 'become seriousness': {'e_trp.xcomp_vbe_nn': ''},
 'become settler': {'e_trp.xcomp_vbe_nn': ''},
 'become severity': {'e_trp.xcomp_vbe_nn': ''},
 'become sewage': {'e_trp.xcomp_vbe_nn': ''},
 'become sheepherder': {'e_trp.xcomp_vbe_nn': ''},
 'become shooting': {'e_trp.xcomp_vbe_nn': ''},
 'become shopper': {'e_trp.xcomp_vbe_nn': ''},
 'become shortage': {'e_trp.xcomp_vbe_nn': ''},
 'become shortcoming': {'e_trp.xcomp_vbe_nn': ''},
 'become shortness': {'e_trp.xcomp_vbe_nn': ''},
 'become shyness': {'e_trp.xcomp_vbe_nn': ''},
 'become sickness': {'e_trp.xcomp_vbe_nn': ''},
 'become significance': {'e_trp.xcomp_vbe_nn': ''},
 'become sill': {'e_trp.xcomp_vbe_nn': ''},
 'become simplicity': {'e_trp.xcomp_vbe_nn': ''},
 'become sitter': {'e_trp.xcomp_vbe_nn': ''},
 'become sky': {'e_trp.xcomp_vbe_nn': ''},
 'become slavery': {'e_trp.xcomp_vbe_nn': ''},
 'become slayer': {'e_trp.xcomp_vbe_nn': ''},
 'become sleeplessness': {'e_trp.xcomp_vbe_nn': ''},
 'become snack': {'e_trp.xcomp_vbe_nn': ''},
 'become snake': {'e_trp.xcomp_vbe_nn': ''},
 'become snow': {'e_trp.xcomp_vbe_nn': ''},
 'become snowman': {'e_trp.xcomp_vbe_nn': ''},
 'become socialism': {'e_trp.xcomp_vbe_nn': ''},
 'become socialite': {'e_trp.xcomp_vbe_nn': ''},
 'become software': {'e_trp.xcomp_vbe_nn': ''},
 'become solitude': {'e_trp.xcomp_vbe_nn': ''},
 'become sooner': {'e_trp.xcomp_vbe_nn': ''},
 'become sophomore': {'e_trp.xcomp_vbe_nn': ''},
 'become sorrow': {'e_trp.xcomp_vbe_nn': ''},
 'become soup': {'e_trp.xcomp_vbe_nn': ''},
 'become souvenir': {'e_trp.xcomp_vbe_nn': ''},
 'become spaceman': {'e_trp.xcomp_vbe_nn': ''},
 'become specialization': {'e_trp.xcomp_vbe_nn': ''},
 'become speech': {'e_trp.xcomp_vbe_nn': ''},
 'become spelling': {'e_trp.xcomp_vbe_nn': ''},
 'become spire': {'e_trp.xcomp_vbe_nn': ''},
 'become spotlight': {'e_trp.xcomp_vbe_nn': ''},
 'become spouse': {'e_trp.xcomp_vbe_nn': ''},
 'become spree': {'e_trp.xcomp_vbe_nn': ''},
 'become spur': {'e_trp.xcomp_vbe_nn': ''},
 'become stakeholder': {'e_trp.xcomp_vbe_nn': ''},
 'become status': {'e_trp.xcomp_vbe_nn': ''},
 'become stepfather': {'e_trp.xcomp_vbe_nn': ''},
 'become stepmother': {'e_trp.xcomp_vbe_nn': ''},
 'become stewardess': {'e_trp.xcomp_vbe_nn': ''},
 'become stone': {'e_trp.xcomp_vbe_nn': ''},
 'become storage': {'e_trp.xcomp_vbe_nn': ''},
 'become storyteller': {'e_trp.xcomp_vbe_nn': ''},
 'become stove': {'e_trp.xcomp_vbe_nn': ''},
 'become strangeness': {'e_trp.xcomp_vbe_nn': ''},
 'become strategist': {'e_trp.xcomp_vbe_nn': ''},
 'become stylist': {'e_trp.xcomp_vbe_nn': ''},
 'become subculture': {'e_trp.xcomp_vbe_nn': ''},
 'become substitution': {'e_trp.xcomp_vbe_nn': ''},
 'become suffering': {'e_trp.xcomp_vbe_nn': ''},
 'become sunlight': {'e_trp.xcomp_vbe_nn': ''},
 'become sunshine': {'e_trp.xcomp_vbe_nn': ''},
 'become superhighway': {'e_trp.xcomp_vbe_nn': ''},
 'become superman': {'e_trp.xcomp_vbe_nn': ''},
 'become superwoman': {'e_trp.xcomp_vbe_nn': ''},
 'become surfer': {'e_trp.xcomp_vbe_nn': ''},
 'become survival': {'e_trp.xcomp_vbe_nn': ''},
 'become survivor': {'e_trp.xcomp_vbe_nn': ''},
 'become sustenance': {'e_trp.xcomp_vbe_nn': ''},
 'become swan': {'e_trp.xcomp_vbe_nn': ''},
 'become swindler': {'e_trp.xcomp_vbe_nn': ''},
 'become syndrome': {'e_trp.xcomp_vbe_nn': ''},
 'become teaching': {'e_trp.xcomp_vbe_nn': ''},
 'become teenybopper': {'e_trp.xcomp_vbe_nn': ''},
 'become telecommuter': {'e_trp.xcomp_vbe_nn': ''},
 'become temperament': {'e_trp.xcomp_vbe_nn': ''},
 'become tempest': {'e_trp.xcomp_vbe_nn': ''},
 'become temptation': {'e_trp.xcomp_vbe_nn': ''},
 'become tendency': {'e_trp.xcomp_vbe_nn': ''},
 'become tension': {'e_trp.xcomp_vbe_nn': ''},
 'become thanks': {'e_trp.xcomp_vbe_nn': ''},
 'become theft': {'e_trp.xcomp_vbe_nn': ''},
 'become thinker': {'e_trp.xcomp_vbe_nn': ''},
 'become thirst': {'e_trp.xcomp_vbe_nn': ''},
 'become thought': {'e_trp.xcomp_vbe_nn': ''},
 'become throat': {'e_trp.xcomp_vbe_nn': ''},
 'become ti': {'e_trp.xcomp_vbe_nn': ''},
 'become timer': {'e_trp.xcomp_vbe_nn': ''},
 'become toilet': {'e_trp.xcomp_vbe_nn': ''},
 'become tolerance': {'e_trp.xcomp_vbe_nn': ''},
 'become tomato': {'e_trp.xcomp_vbe_nn': ''},
 'become tooth': {'e_trp.xcomp_vbe_nn': ''},
 'become totem': {'e_trp.xcomp_vbe_nn': ''},
 'become tourism': {'e_trp.xcomp_vbe_nn': ''},
 'become tragedy': {'e_trp.xcomp_vbe_nn': ''},
 'become training': {'e_trp.xcomp_vbe_nn': ''},
 'become tramper': {'e_trp.xcomp_vbe_nn': ''},
 'become trance': {'e_trp.xcomp_vbe_nn': ''},
 'become transformation': {'e_trp.xcomp_vbe_nn': ''},
 'become transmission': {'e_trp.xcomp_vbe_nn': ''},
 'become transparency': {'e_trp.xcomp_vbe_nn': ''},
 'become transportation': {'e_trp.xcomp_vbe_nn': ''},
 'become traveler': {'e_trp.xcomp_vbe_nn': ''},
 'become treason': {'e_trp.xcomp_vbe_nn': ''},
 'become tribe': {'e_trp.xcomp_vbe_nn': ''},
 'become troublemaker': {'e_trp.xcomp_vbe_nn': ''},
 'become tsunami': {'e_trp.xcomp_vbe_nn': ''},
 'become turtle': {'e_trp.xcomp_vbe_nn': ''},
 'become twister': {'e_trp.xcomp_vbe_nn': ''},
 'become unbeliever': {'e_trp.xcomp_vbe_nn': ''},
 'become uncle': {'e_trp.xcomp_vbe_nn': ''},
 'become underachiever': {'e_trp.xcomp_vbe_nn': ''},
 'become unemployment': {'e_trp.xcomp_vbe_nn': ''},
 'become unity': {'e_trp.xcomp_vbe_nn': ''},
 'become unrest': {'e_trp.xcomp_vbe_nn': ''},
 'become upsurge': {'e_trp.xcomp_vbe_nn': ''},
 'become urgency': {'e_trp.xcomp_vbe_nn': ''},
 'become usefulness': {'e_trp.xcomp_vbe_nn': ''},
 'become utilitarianism': {'e_trp.xcomp_vbe_nn': ''},
 'become utilization': {'e_trp.xcomp_vbe_nn': ''},
 'become vacation': {'e_trp.xcomp_vbe_nn': ''},
 'become valentine': {'e_trp.xcomp_vbe_nn': ''},
 'become van': {'e_trp.xcomp_vbe_nn': ''},
 'become variety': {'e_trp.xcomp_vbe_nn': ''},
 'become vase': {'e_trp.xcomp_vbe_nn': ''},
 'become vegetable': {'e_trp.xcomp_vbe_nn': ''},
 'become versatility': {'e_trp.xcomp_vbe_nn': ''},
 'become victory': {'e_trp.xcomp_vbe_nn': ''},
 'become vigilance': {'e_trp.xcomp_vbe_nn': ''},
 'become violence': {'e_trp.xcomp_vbe_nn': ''},
 'become vip': {'e_trp.xcomp_vbe_nn': ''},
 'become virus': {'e_trp.xcomp_vbe_nn': ''},
 'become vocabulary': {'e_trp.xcomp_vbe_nn': ''},
 'become vulcanologist': {'e_trp.xcomp_vbe_nn': ''},
 'become waif': {'e_trp.xcomp_vbe_nn': ''},
 'become waiter': {'e_trp.xcomp_vbe_nn': ''},
 'become wanderer': {'e_trp.xcomp_vbe_nn': ''},
 'become warmth': {'e_trp.xcomp_vbe_nn': ''},
 'become waster': {'e_trp.xcomp_vbe_nn': ''},
 'become wealth': {'e_trp.xcomp_vbe_nn': ''},
 'become website': {'e_trp.xcomp_vbe_nn': ''},
 'become whore': {'e_trp.xcomp_vbe_nn': ''},
 'become willpower': {'e_trp.xcomp_vbe_nn': ''},
 'become windbag': {'e_trp.xcomp_vbe_nn': ''},
 'become wonderland': {'e_trp.xcomp_vbe_nn': ''},
 'become workforce': {'e_trp.xcomp_vbe_nn': ''},
 'become workman': {'e_trp.xcomp_vbe_nn': ''},
 'become worshipper': {'e_trp.xcomp_vbe_nn': ''},
 'become wretch': {'e_trp.xcomp_vbe_nn': ''},
 'become youngster': {'e_trp.xcomp_vbe_nn': ''},
 'become youth': {'e_trp.xcomp_vbe_nn': ''},
 'become zeal': {'e_trp.xcomp_vbe_nn': ''},
 'become zoo': {'e_trp.xcomp_vbe_nn': ''},
 'fall achievement': {'e_trp.xcomp_vbe_nn': ''},
 'fall advertisement': {'e_trp.xcomp_vbe_nn': ''},
 'fall anxiety': {'e_trp.xcomp_vbe_nn': ''},
 'fall army': {'e_trp.xcomp_vbe_nn': ''},
 'fall atmosphere': {'e_trp.xcomp_vbe_nn': ''},
 'fall aversion': {'e_trp.xcomp_vbe_nn': ''},
 'fall background': {'e_trp.xcomp_vbe_nn': ''},
 'fall beggar': {'e_trp.xcomp_vbe_nn': ''},
 'fall body': {'e_trp.xcomp_vbe_nn': ''},
 'fall breath': {'e_trp.xcomp_vbe_nn': ''},
 'fall building': {'e_trp.xcomp_vbe_nn': ''},
 'fall coldness': {'e_trp.xcomp_vbe_nn': ''},
 'fall coma': {'e_trp.xcomp_vbe_nn': ''},
 'fall consumer': {'e_trp.xcomp_vbe_nn': ''},
 'fall contentment': {'e_trp.xcomp_vbe_nn': ''},
 'fall convenience': {'e_trp.xcomp_vbe_nn': ''},
 'fall country': {'e_trp.xcomp_vbe_nn': ''},
 'fall county': {'e_trp.xcomp_vbe_nn': ''},
 'fall deficiency': {'e_trp.xcomp_vbe_nn': ''},
 'fall depression': {'e_trp.xcomp_vbe_nn': ''},
 'fall dew': {'e_trp.xcomp_vbe_nn': ''},
 'fall difficulty': {'e_trp.xcomp_vbe_nn': ''},
 'fall disappointment': {'e_trp.xcomp_vbe_nn': ''},
 'fall disease': {'e_trp.xcomp_vbe_nn': ''},
 'fall earth': {'e_trp.xcomp_vbe_nn': ''},
 'fall empire': {'e_trp.xcomp_vbe_nn': ''},
 'fall energy': {'e_trp.xcomp_vbe_nn': ''},
 'fall exam': {'e_trp.xcomp_vbe_nn': ''},
 'fall failure': {'e_trp.xcomp_vbe_nn': ''},
 'fall flavour': {'e_trp.xcomp_vbe_nn': ''},
 'fall flood': {'e_trp.xcomp_vbe_nn': ''},
 'fall food': {'e_trp.xcomp_vbe_nn': ''},
 'fall forest': {'e_trp.xcomp_vbe_nn': ''},
 'fall friendship': {'e_trp.xcomp_vbe_nn': ''},
 'fall goo': {'e_trp.xcomp_vbe_nn': ''},
 'fall goods': {'e_trp.xcomp_vbe_nn': ''},
 'fall grammar': {'e_trp.xcomp_vbe_nn': ''},
 'fall habit': {'e_trp.xcomp_vbe_nn': ''},
 'fall happiness': {'e_trp.xcomp_vbe_nn': ''},
 'fall headache': {'e_trp.xcomp_vbe_nn': ''},
 'fall heart': {'e_trp.xcomp_vbe_nn': ''},
 'fall heir': {'e_trp.xcomp_vbe_nn': ''},
 'fall idea': {'e_trp.xcomp_vbe_nn': ''},
 'fall illness': {'e_trp.xcomp_vbe_nn': ''},
 'fall inferiority': {'e_trp.xcomp_vbe_nn': ''},
 'fall joy': {'e_trp.xcomp_vbe_nn': ''},
 'fall knife': {'e_trp.xcomp_vbe_nn': ''},
 'fall lesson': {'e_trp.xcomp_vbe_nn': ''},
 'fall life': {'e_trp.xcomp_vbe_nn': ''},
 'fall loneliness': {'e_trp.xcomp_vbe_nn': ''},
 'fall lot': {'e_trp.xcomp_vbe_nn': ''},
 'fall nerve': {'e_trp.xcomp_vbe_nn': ''},
 'fall phenomenon': {'e_trp.xcomp_vbe_nn': ''},
 'fall pie': {'e_trp.xcomp_vbe_nn': ''},
 'fall pity': {'e_trp.xcomp_vbe_nn': ''},
 'fall quality': {'e_trp.xcomp_vbe_nn': ''},
 'fall resource': {'e_trp.xcomp_vbe_nn': ''},
 'fall rice': {'e_trp.xcomp_vbe_nn': ''},
 'fall safety': {'e_trp.xcomp_vbe_nn': ''},
 'fall scum': {'e_trp.xcomp_vbe_nn': ''},
 'fall sea': {'e_trp.xcomp_vbe_nn': ''},
 'fall sickness': {'e_trp.xcomp_vbe_nn': ''},
 'fall sight': {'e_trp.xcomp_vbe_nn': ''},
 'fall sleeplessness': {'e_trp.xcomp_vbe_nn': ''},
 'fall song': {'e_trp.xcomp_vbe_nn': ''},
 'fall sorrow': {'e_trp.xcomp_vbe_nn': ''},
 'fall spirit': {'e_trp.xcomp_vbe_nn': ''},
 'fall student': {'e_trp.xcomp_vbe_nn': ''},
 'fall success': {'e_trp.xcomp_vbe_nn': ''},
 'fall sun': {'e_trp.xcomp_vbe_nn': ''},
 'fall suspense': {'e_trp.xcomp_vbe_nn': ''},
 'fall text': {'e_trp.xcomp_vbe_nn': ''},
 'fall thing': {'e_trp.xcomp_vbe_nn': ''},
 'fall thought': {'e_trp.xcomp_vbe_nn': ''},
 'fall trike': {'e_trp.xcomp_vbe_nn': ''},
 'fall warmth': {'e_trp.xcomp_vbe_nn': ''},
 'fall worm': {'e_trp.xcomp_vbe_nn': ''},
 'feel admiration': {'e_trp.xcomp_vbe_nn': ''},
 'feel affair': {'e_trp.xcomp_vbe_nn': ''},
 'feel air': {'e_trp.xcomp_vbe_nn': ''},
 'feel anxiety': {'e_trp.xcomp_vbe_nn': ''},
 'feel atmosphere': {'e_trp.xcomp_vbe_nn': ''},
 'feel attitude': {'e_trp.xcomp_vbe_nn': ''},
 'feel aversion': {'e_trp.xcomp_vbe_nn': ''},
 'feel beauty': {'e_trp.xcomp_vbe_nn': ''},
 'feel bond': {'e_trp.xcomp_vbe_nn': ''},
 'feel boredom': {'e_trp.xcomp_vbe_nn': ''},
 'feel chaos': {'e_trp.xcomp_vbe_nn': ''},
 'feel cheerfulness': {'e_trp.xcomp_vbe_nn': ''},
 'feel class': {'e_trp.xcomp_vbe_nn': ''},
 'feel college': {'e_trp.xcomp_vbe_nn': ''},
 'feel confidence': {'e_trp.xcomp_vbe_nn': ''},
 'feel consciousness': {'e_trp.xcomp_vbe_nn': ''},
 'feel consolation': {'e_trp.xcomp_vbe_nn': ''},
 'feel consumption': {'e_trp.xcomp_vbe_nn': ''},
 'feel contentment': {'e_trp.xcomp_vbe_nn': ''},
 'feel crowd': {'e_trp.xcomp_vbe_nn': ''},
 'feel cruelty': {'e_trp.xcomp_vbe_nn': ''},
 'feel culture': {'e_trp.xcomp_vbe_nn': ''},
 'feel death': {'e_trp.xcomp_vbe_nn': ''},
 'feel degree': {'e_trp.xcomp_vbe_nn': ''},
 'feel depression': {'e_trp.xcomp_vbe_nn': ''},
 'feel difference': {'e_trp.xcomp_vbe_nn': ''},
 'feel disappointment': {'e_trp.xcomp_vbe_nn': ''},
 'feel distance': {'e_trp.xcomp_vbe_nn': ''},
 'feel emotion': {'e_trp.xcomp_vbe_nn': ''},
 'feel empathy': {'e_trp.xcomp_vbe_nn': ''},
 'feel energy': {'e_trp.xcomp_vbe_nn': ''},
 'feel enthusiasm': {'e_trp.xcomp_vbe_nn': ''},
 'feel environment': {'e_trp.xcomp_vbe_nn': ''},
 'feel existence': {'e_trp.xcomp_vbe_nn': ''},
 'feel gift': {'e_trp.xcomp_vbe_nn': ''},
 'feel globalization': {'e_trp.xcomp_vbe_nn': ''},
 'feel gloom': {'e_trp.xcomp_vbe_nn': ''},
 'feel goodness': {'e_trp.xcomp_vbe_nn': ''},
 'feel goods': {'e_trp.xcomp_vbe_nn': ''},
 'feel happiness': {'e_trp.xcomp_vbe_nn': ''},
 'feel hardship': {'e_trp.xcomp_vbe_nn': ''},
 'feel headache': {'e_trp.xcomp_vbe_nn': ''},
 'feel hesitation': {'e_trp.xcomp_vbe_nn': ''},
 'feel hunger': {'e_trp.xcomp_vbe_nn': ''},
 'feel importance': {'e_trp.xcomp_vbe_nn': ''},
 'feel improvement': {'e_trp.xcomp_vbe_nn': ''},
 'feel infatuation': {'e_trp.xcomp_vbe_nn': ''},
 'feel injustice': {'e_trp.xcomp_vbe_nn': ''},
 'feel insignificance': {'e_trp.xcomp_vbe_nn': ''},
 'feel intelligence': {'e_trp.xcomp_vbe_nn': ''},
 'feel joy': {'e_trp.xcomp_vbe_nn': ''},
 'feel liability': {'e_trp.xcomp_vbe_nn': ''},
 'feel loneliness': {'e_trp.xcomp_vbe_nn': ''},
 'feel luck': {'e_trp.xcomp_vbe_nn': ''},
 'feel makeup': {'e_trp.xcomp_vbe_nn': ''},
 'feel mind': {'e_trp.xcomp_vbe_nn': ''},
 'feel music': {'e_trp.xcomp_vbe_nn': ''},
 'feel mystery': {'e_trp.xcomp_vbe_nn': ''},
 'feel nature': {'e_trp.xcomp_vbe_nn': ''},
 'feel nerve': {'e_trp.xcomp_vbe_nn': ''},
 'feel ordeal': {'e_trp.xcomp_vbe_nn': ''},
 'feel paradise': {'e_trp.xcomp_vbe_nn': ''},
 'feel parent': {'e_trp.xcomp_vbe_nn': ''},
 'feel people': {'e_trp.xcomp_vbe_nn': ''},
 'feel photo': {'e_trp.xcomp_vbe_nn': ''},
 'feel place': {'e_trp.xcomp_vbe_nn': '', 'dobj.prep_miss': ''},
 'feel pleasure': {'e_trp.xcomp_vbe_nn': ''},
 'feel prey': {'e_trp.xcomp_vbe_nn': ''},
 'feel price': {'e_trp.xcomp_vbe_nn': ''},
 'feel pride': {'e_trp.xcomp_vbe_nn': ''},
 'feel relationship': {'e_trp.xcomp_vbe_nn': ''},
 'feel remorse': {'e_trp.xcomp_vbe_nn': ''},
 'feel sadness': {'e_trp.xcomp_vbe_nn': ''},
 'feel safety': {'e_trp.xcomp_vbe_nn': ''},
 'feel science': {'e_trp.xcomp_vbe_nn': ''},
 'feel self-confidence': {'e_trp.xcomp_vbe_nn': ''},
 'feel sorrow': {'e_trp.xcomp_vbe_nn': ''},
 'feel sport': {'e_trp.xcomp_vbe_nn': ''},
 'feel stigma': {'e_trp.xcomp_vbe_nn': ''},
 'feel toe': {'e_trp.xcomp_vbe_nn': ''},
 'feel tradition': {'e_trp.xcomp_vbe_nn': ''},
 'feel vigor': {'e_trp.xcomp_vbe_nn': ''},
 'feel vision': {'e_trp.xcomp_vbe_nn': ''},
 'feel word': {'e_trp.xcomp_vbe_nn': ''},
 'feel world': {'e_trp.xcomp_vbe_nn': ''},
 'feel youth': {'e_trp.xcomp_vbe_nn': ''},
 'look ability': {'e_trp.xcomp_vbe_nn': ''},
 'look abortion': {'e_trp.xcomp_vbe_nn': ''},
 'look accident': {'e_trp.xcomp_vbe_nn': ''},
 'look advantage': {'e_trp.xcomp_vbe_nn': ''},
 'look advertisement': {'e_trp.xcomp_vbe_nn': ''},
 'look advertising': {'e_trp.xcomp_vbe_nn': ''},
 'look aftertaste': {'e_trp.xcomp_vbe_nn': ''},
 'look album': {'e_trp.xcomp_vbe_nn': ''},
 'look appearance': {'e_trp.xcomp_vbe_nn': ''},
 'look appetite': {'e_trp.xcomp_vbe_nn': ''},
 'look appreciation': {'e_trp.xcomp_vbe_nn': ''},
 'look armpit': {'e_trp.xcomp_vbe_nn': ''},
 'look article': {'e_trp.xcomp_vbe_nn': ''},
 'look assignment': {'e_trp.xcomp_vbe_nn': ''},
 'look athletics': {'e_trp.xcomp_vbe_nn': ''},
 'look audience': {'e_trp.xcomp_vbe_nn': ''},
 'look baby': {'e_trp.xcomp_vbe_nn': ''},
 'look background': {'e_trp.xcomp_vbe_nn': ''},
 'look basketball': {'e_trp.xcomp_vbe_nn': ''},
 'look battery': {'e_trp.xcomp_vbe_nn': ''},
 'look beach': {'e_trp.xcomp_vbe_nn': ''},
 'look beauty': {'e_trp.xcomp_vbe_nn': ''},
 'look behavior': {'e_trp.xcomp_vbe_nn': ''},
 'look behaviour': {'e_trp.xcomp_vbe_nn': ''},
 'look bike': {'e_trp.xcomp_vbe_nn': ''},
 'look body': {'e_trp.xcomp_vbe_nn': ''},
 'look book': {'e_trp.xcomp_vbe_nn': ''},
 'look bowl': {'e_trp.xcomp_vbe_nn': ''},
 'look boyfriend': {'e_trp.xcomp_vbe_nn': ''},
 'look campus': {'e_trp.xcomp_vbe_nn': ''},
 'look centre': {'e_trp.xcomp_vbe_nn': ''},
 'look certificate': {'e_trp.xcomp_vbe_nn': ''},
 'look choice': {'e_trp.xcomp_vbe_nn': ''},
 'look clam': {'e_trp.xcomp_vbe_nn': ''},
 'look comedy': {'e_trp.xcomp_vbe_nn': ''},
 'look company': {'e_trp.xcomp_vbe_nn': ''},
 'look compartment': {'e_trp.xcomp_vbe_nn': ''},
 'look competitiveness': {'e_trp.xcomp_vbe_nn': ''},
 'look composition': {'e_trp.xcomp_vbe_nn': ''},
 'look computer': {'e_trp.xcomp_vbe_nn': ''},
 'look confidence': {'e_trp.xcomp_vbe_nn': ''},
 'look connotation': {'e_trp.xcomp_vbe_nn': ''},
 'look customer': {'e_trp.xcomp_vbe_nn': ''},
 'look date': {'e_trp.xcomp_vbe_nn': ''},
 'look decision': {'e_trp.xcomp_vbe_nn': ''},
 'look desolation': {'e_trp.xcomp_vbe_nn': ''},
 'look development': {'e_trp.xcomp_vbe_nn': ''},
 'look dictionary': {'e_trp.xcomp_vbe_nn': ''},
 'look difference': {'e_trp.xcomp_vbe_nn': ''},
 'look distortion': {'e_trp.xcomp_vbe_nn': ''},
 'look doctor': {'e_trp.xcomp_vbe_nn': ''},
 'look door': {'e_trp.xcomp_vbe_nn': ''},
 'look dorm': {'e_trp.xcomp_vbe_nn': ''},
 'look elder': {'e_trp.xcomp_vbe_nn': ''},
 'look elephant': {'e_trp.xcomp_vbe_nn': ''},
 'look emotion': {'e_trp.xcomp_vbe_nn': ''},
 'look essay': {'e_trp.xcomp_vbe_nn': ''},
 'look exam': {'e_trp.xcomp_vbe_nn': ''},
 'look examination': {'e_trp.xcomp_vbe_nn': ''},
 'look expression': {'e_trp.xcomp_vbe_nn': ''},
 'look eye': {'e_trp.xcomp_vbe_nn': ''},
 'look failure': {'e_trp.xcomp_vbe_nn': ''},
 'look field': {'e_trp.xcomp_vbe_nn': ''},
 'look fir': {'e_trp.xcomp_vbe_nn': ''},
 'look flower': {'e_trp.xcomp_vbe_nn': ''},
 'look foe': {'e_trp.xcomp_vbe_nn': ''},
 'look footprint': {'e_trp.xcomp_vbe_nn': ''},
 'look fort': {'e_trp.xcomp_vbe_nn': ''},
 'look freshman': {'e_trp.xcomp_vbe_nn': ''},
 'look friend': {'e_trp.xcomp_vbe_nn': ''},
 'look game': {'e_trp.xcomp_vbe_nn': ''},
 'look garbage': {'e_trp.xcomp_vbe_nn': ''},
 'look goods': {'e_trp.xcomp_vbe_nn': ''},
 'look grace': {'e_trp.xcomp_vbe_nn': ''},
 'look grandfather': {'e_trp.xcomp_vbe_nn': ''},
 'look grief': {'e_trp.xcomp_vbe_nn': ''},
 'look harmony': {'e_trp.xcomp_vbe_nn': ''},
 'look health': {'e_trp.xcomp_vbe_nn': ''},
 'look herb': {'e_trp.xcomp_vbe_nn': ''},
 'look history': {'e_trp.xcomp_vbe_nn': ''},
 'look identity': {'e_trp.xcomp_vbe_nn': ''},
 'look illustration': {'e_trp.xcomp_vbe_nn': ''},
 'look information': {'e_trp.xcomp_vbe_nn': ''},
 'look insight': {'e_trp.xcomp_vbe_nn': ''},
 'look integrity': {'e_trp.xcomp_vbe_nn': ''},
 'look internet': {'e_trp.xcomp_vbe_nn': ''},
 'look interviewer': {'e_trp.xcomp_vbe_nn': ''},
 'look job': {'e_trp.xcomp_vbe_nn': '', 'dobj.prep_miss': ''},
 'look kid': {'e_trp.xcomp_vbe_nn': ''},
 'look kindness': {'e_trp.xcomp_vbe_nn': ''},
 'look language': {'e_trp.xcomp_vbe_nn': ''},
 'look learning': {'e_trp.xcomp_vbe_nn': ''},
 'look leaver': {'e_trp.xcomp_vbe_nn': ''},
 'look letter': {'e_trp.xcomp_vbe_nn': ''},
 'look library': {'e_trp.xcomp_vbe_nn': ''},
 'look life': {'e_trp.xcomp_vbe_nn': ''},
 'look lover': {'e_trp.xcomp_vbe_nn': ''},
 'look magazine': {'e_trp.xcomp_vbe_nn': ''},
 'look map': {'e_trp.xcomp_vbe_nn': ''},
 'look marriage': {'e_trp.xcomp_vbe_nn': ''},
 'look match': {'e_trp.xcomp_vbe_nn': ''},
 'look message': {'e_trp.xcomp_vbe_nn': ''},
 'look millionaire': {'e_trp.xcomp_vbe_nn': ''},
 'look money': {'e_trp.xcomp_vbe_nn': ''},
 'look moon': {'e_trp.xcomp_vbe_nn': ''},
 'look mother': {'e_trp.xcomp_vbe_nn': ''},
 'look mountain': {'e_trp.xcomp_vbe_nn': ''},
 'look movie': {'e_trp.xcomp_vbe_nn': ''},
 'look music': {'e_trp.xcomp_vbe_nn': ''},
 'look neighbor': {'e_trp.xcomp_vbe_nn': ''},
 'look net': {'e_trp.xcomp_vbe_nn': ''},
 'look news': {'e_trp.xcomp_vbe_nn': ''},
 'look newspaper': {'e_trp.xcomp_vbe_nn': ''},
 'look notebook': {'e_trp.xcomp_vbe_nn': ''},
 'look novel': {'e_trp.xcomp_vbe_nn': ''},
 'look number': {'e_trp.xcomp_vbe_nn': ''},
 'look panda': {'e_trp.xcomp_vbe_nn': ''},
 'look paper': {'e_trp.xcomp_vbe_nn': ''},
 'look parent': {'e_trp.xcomp_vbe_nn': ''},
 'look passage': {'e_trp.xcomp_vbe_nn': ''},
 'look peace': {'e_trp.xcomp_vbe_nn': ''},
 'look perspective': {'e_trp.xcomp_vbe_nn': ''},
 'look pet': {'e_trp.xcomp_vbe_nn': ''},
 'look phenomenon': {'e_trp.xcomp_vbe_nn': ''},
 'look photo': {'e_trp.xcomp_vbe_nn': ''},
 'look planet': {'e_trp.xcomp_vbe_nn': ''},
 'look poetry': {'e_trp.xcomp_vbe_nn': ''},
 'look poster': {'e_trp.xcomp_vbe_nn': ''},
 'look power': {'e_trp.xcomp_vbe_nn': ''},
 'look princess': {'e_trp.xcomp_vbe_nn': ''},
 'look privacy': {'e_trp.xcomp_vbe_nn': ''},
 'look problem': {'e_trp.xcomp_vbe_nn': ''},
 'look product': {'e_trp.xcomp_vbe_nn': ''},
 'look professor': {'e_trp.xcomp_vbe_nn': ''},
 'look reality': {'e_trp.xcomp_vbe_nn': ''},
 'look relation': {'e_trp.xcomp_vbe_nn': ''},
 'look research': {'e_trp.xcomp_vbe_nn': ''},
 'look researcher': {'e_trp.xcomp_vbe_nn': ''},
 'look restaurant': {'e_trp.xcomp_vbe_nn': ''},
 'look rice': {'e_trp.xcomp_vbe_nn': ''},
 'look road': {'e_trp.xcomp_vbe_nn': ''},
 'look robot': {'e_trp.xcomp_vbe_nn': ''},
 'look sadness': {'e_trp.xcomp_vbe_nn': ''},
 'look safety': {'e_trp.xcomp_vbe_nn': ''},
 'look scene': {'e_trp.xcomp_vbe_nn': ''},
 'look scenery': {'e_trp.xcomp_vbe_nn': ''},
 'look school': {'e_trp.xcomp_vbe_nn': ''},
 'look scientist': {'e_trp.xcomp_vbe_nn': ''},
 'look seat': {'e_trp.xcomp_vbe_nn': ''},
 'look shoe': {'e_trp.xcomp_vbe_nn': ''},
 'look shop': {'e_trp.xcomp_vbe_nn': ''},
 'look shrimp': {'e_trp.xcomp_vbe_nn': ''},
 'look site': {'e_trp.xcomp_vbe_nn': ''},
 'look sky': {'e_trp.xcomp_vbe_nn': ''},
 'look snowflake': {'e_trp.xcomp_vbe_nn': ''},
 'look snowman': {'e_trp.xcomp_vbe_nn': ''},
 'look society': {'e_trp.xcomp_vbe_nn': ''},
 'look soup': {'e_trp.xcomp_vbe_nn': ''},
 'look speaker': {'e_trp.xcomp_vbe_nn': ''},
 'look spirit': {'e_trp.xcomp_vbe_nn': ''},
 'look sportsman': {'e_trp.xcomp_vbe_nn': ''},
 'look star': {'e_trp.xcomp_vbe_nn': ''},
 'look store': {'e_trp.xcomp_vbe_nn': ''},
 'look story': {'e_trp.xcomp_vbe_nn': ''},
 'look stranger': {'e_trp.xcomp_vbe_nn': ''},
 'look student': {'e_trp.xcomp_vbe_nn': ''},
 'look suggestion': {'e_trp.xcomp_vbe_nn': ''},
 'look sun': {'e_trp.xcomp_vbe_nn': ''},
 'look sunshine': {'e_trp.xcomp_vbe_nn': ''},
 'look surroundings': {'e_trp.xcomp_vbe_nn': ''},
 'look symptom': {'e_trp.xcomp_vbe_nn': ''},
 'look talent': {'e_trp.xcomp_vbe_nn': ''},
 'look teacher': {'e_trp.xcomp_vbe_nn': ''},
 'look teenager': {'e_trp.xcomp_vbe_nn': ''},
 'look temperament': {'e_trp.xcomp_vbe_nn': ''},
 'look text': {'e_trp.xcomp_vbe_nn': ''},
 'look textbook': {'e_trp.xcomp_vbe_nn': ''},
 'look thought': {'e_trp.xcomp_vbe_nn': ''},
 'look thousand': {'e_trp.xcomp_vbe_nn': ''},
 'look topic': {'e_trp.xcomp_vbe_nn': ''},
 'look tree': {'e_trp.xcomp_vbe_nn': ''},
 'look tribe': {'e_trp.xcomp_vbe_nn': ''},
 'look trough': {'e_trp.xcomp_vbe_nn': ''},
 'look verity': {'e_trp.xcomp_vbe_nn': ''},
 'look video': {'e_trp.xcomp_vbe_nn': ''},
 'look website': {'e_trp.xcomp_vbe_nn': ''},
 'look window': {'e_trp.xcomp_vbe_nn': ''},
 'look wisdom': {'e_trp.xcomp_vbe_nn': ''},
 'look word': {'e_trp.xcomp_vbe_nn': ''},
 'look worker': {'e_trp.xcomp_vbe_nn': ''},
 'look world': {'e_trp.xcomp_vbe_nn': '', 'dobj.prep_miss': ''},
 'prove ability': {'e_trp.xcomp_vbe_nn': ''},
 'prove awareness': {'e_trp.xcomp_vbe_nn': ''},
 'prove capability': {'e_trp.xcomp_vbe_nn': ''},
 'prove capacity': {'e_trp.xcomp_vbe_nn': ''},
 'prove competitiveness': {'e_trp.xcomp_vbe_nn': ''},
 'prove creativity': {'e_trp.xcomp_vbe_nn': ''},
 'prove efficiency': {'e_trp.xcomp_vbe_nn': ''},
 'prove environment': {'e_trp.xcomp_vbe_nn': ''},
 'prove fact': {'e_trp.xcomp_vbe_nn': ''},
 'prove failure': {'e_trp.xcomp_vbe_nn': ''},
 'prove feasibility': {'e_trp.xcomp_vbe_nn': ''},
 'prove grandchild': {'e_trp.xcomp_vbe_nn': ''},
 'prove hardship': {'e_trp.xcomp_vbe_nn': ''},
 'prove heart': {'e_trp.xcomp_vbe_nn': ''},
 'prove idea': {'e_trp.xcomp_vbe_nn': ''},
 'prove intelligence': {'e_trp.xcomp_vbe_nn': ''},
 'prove language': {'e_trp.xcomp_vbe_nn': ''},
 'prove law': {'e_trp.xcomp_vbe_nn': ''},
 'prove man': {'e_trp.xcomp_vbe_nn': ''},
 'prove moon': {'e_trp.xcomp_vbe_nn': ''},
 'prove opinion': {'e_trp.xcomp_vbe_nn': ''},
 'prove relation': {'e_trp.xcomp_vbe_nn': ''},
 'prove relationship': {'e_trp.xcomp_vbe_nn': ''},
 'prove self': {'e_trp.xcomp_vbe_nn': ''},
 'prove skill': {'e_trp.xcomp_vbe_nn': ''},
 'prove status': {'e_trp.xcomp_vbe_nn': ''},
 'prove talent': {'e_trp.xcomp_vbe_nn': ''},
 'prove word': {'e_trp.xcomp_vbe_nn': ''},
 'remain advantage': {'e_trp.xcomp_vbe_nn': ''},
 'remain adventure': {'e_trp.xcomp_vbe_nn': ''},
 'remain antithesis': {'e_trp.xcomp_vbe_nn': ''},
 'remain appearance': {'e_trp.xcomp_vbe_nn': ''},
 'remain architect': {'e_trp.xcomp_vbe_nn': ''},
 'remain army': {'e_trp.xcomp_vbe_nn': ''},
 'remain aspect': {'e_trp.xcomp_vbe_nn': ''},
 'remain attitude': {'e_trp.xcomp_vbe_nn': ''},
 'remain bomb': {'e_trp.xcomp_vbe_nn': ''},
 'remain bone': {'e_trp.xcomp_vbe_nn': ''},
 'remain building': {'e_trp.xcomp_vbe_nn': ''},
 'remain car': {'e_trp.xcomp_vbe_nn': ''},
 'remain chance': {'e_trp.xcomp_vbe_nn': ''},
 'remain character': {'e_trp.xcomp_vbe_nn': ''},
 'remain cognition': {'e_trp.xcomp_vbe_nn': ''},
 'remain conception': {'e_trp.xcomp_vbe_nn': ''},
 'remain confusion': {'e_trp.xcomp_vbe_nn': ''},
 'remain contact': {'e_trp.xcomp_vbe_nn': ''},
 'remain controversy': {'e_trp.xcomp_vbe_nn': ''},
 'remain credibility': {'e_trp.xcomp_vbe_nn': ''},
 'remain culture': {'e_trp.xcomp_vbe_nn': ''},
 'remain deficiency': {'e_trp.xcomp_vbe_nn': ''},
 'remain determination': {'e_trp.xcomp_vbe_nn': ''},
 'remain development': {'e_trp.xcomp_vbe_nn': ''},
 'remain discussion': {'e_trp.xcomp_vbe_nn': ''},
 'remain dish': {'e_trp.xcomp_vbe_nn': ''},
 'remain disloyalty': {'e_trp.xcomp_vbe_nn': ''},
 'remain disorder': {'e_trp.xcomp_vbe_nn': ''},
 'remain diversification': {'e_trp.xcomp_vbe_nn': ''},
 'remain diversity': {'e_trp.xcomp_vbe_nn': ''},
 'remain door': {'e_trp.xcomp_vbe_nn': ''},
 'remain dormitory': {'e_trp.xcomp_vbe_nn': ''},
 'remain drawback': {'e_trp.xcomp_vbe_nn': ''},
 'remain dynasty': {'e_trp.xcomp_vbe_nn': ''},
 'remain earth': {'e_trp.xcomp_vbe_nn': ''},
 'remain education': {'e_trp.xcomp_vbe_nn': ''},
 'remain embodiment': {'e_trp.xcomp_vbe_nn': ''},
 'remain emotion': {'e_trp.xcomp_vbe_nn': ''},
 'remain encouragement': {'e_trp.xcomp_vbe_nn': ''},
 'remain essence': {'e_trp.xcomp_vbe_nn': ''},
 'remain failure': {'e_trp.xcomp_vbe_nn': ''},
 'remain fame': {'e_trp.xcomp_vbe_nn': ''},
 'remain fee': {'e_trp.xcomp_vbe_nn': ''},
 'remain food': {'e_trp.xcomp_vbe_nn': ''},
 'remain fortune': {'e_trp.xcomp_vbe_nn': ''},
 'remain fount': {'e_trp.xcomp_vbe_nn': ''},
 'remain friendship': {'e_trp.xcomp_vbe_nn': ''},
 'remain garbage': {'e_trp.xcomp_vbe_nn': ''},
 'remain gift': {'e_trp.xcomp_vbe_nn': ''},
 'remain habit': {'e_trp.xcomp_vbe_nn': ''},
 'remain handwriting': {'e_trp.xcomp_vbe_nn': ''},
 'remain happiness': {'e_trp.xcomp_vbe_nn': ''},
 'remain headache': {'e_trp.xcomp_vbe_nn': ''},
 'remain health': {'e_trp.xcomp_vbe_nn': ''},
 'remain hindrance': {'e_trp.xcomp_vbe_nn': ''},
 'remain housewife': {'e_trp.xcomp_vbe_nn': ''},
 'remain hunt': {'e_trp.xcomp_vbe_nn': ''},
 'remain impediment': {'e_trp.xcomp_vbe_nn': ''},
 'remain impression': {'e_trp.xcomp_vbe_nn': ''},
 'remain income': {'e_trp.xcomp_vbe_nn': ''},
 'remain independence': {'e_trp.xcomp_vbe_nn': ''},
 'remain innocence': {'e_trp.xcomp_vbe_nn': ''},
 'remain judgment': {'e_trp.xcomp_vbe_nn': ''},
 'remain justice': {'e_trp.xcomp_vbe_nn': ''},
 'remain kindness': {'e_trp.xcomp_vbe_nn': ''},
 'remain knowledge': {'e_trp.xcomp_vbe_nn': ''},
 'remain ladder': {'e_trp.xcomp_vbe_nn': ''},
 'remain learning': {'e_trp.xcomp_vbe_nn': ''},
 'remain lifestyle': {'e_trp.xcomp_vbe_nn': ''},
 'remain meal': {'e_trp.xcomp_vbe_nn': ''},
 'remain mind': {'e_trp.xcomp_vbe_nn': ''},
 'remain mission': {'e_trp.xcomp_vbe_nn': ''},
 'remain mist': {'e_trp.xcomp_vbe_nn': ''},
 'remain modesty': {'e_trp.xcomp_vbe_nn': ''},
 'remain monarch': {'e_trp.xcomp_vbe_nn': ''},
 'remain money': {'e_trp.xcomp_vbe_nn': ''},
 'remain monk': {'e_trp.xcomp_vbe_nn': ''},
 'remain motif': {'e_trp.xcomp_vbe_nn': ''},
 'remain nobility': {'e_trp.xcomp_vbe_nn': ''},
 'remain optimism': {'e_trp.xcomp_vbe_nn': ''},
 'remain participant': {'e_trp.xcomp_vbe_nn': ''},
 'remain people': {'e_trp.xcomp_vbe_nn': ''},
 'remain percentage': {'e_trp.xcomp_vbe_nn': ''},
 'remain personality': {'e_trp.xcomp_vbe_nn': ''},
 'remain pesticide': {'e_trp.xcomp_vbe_nn': ''},
 'remain pollution': {'e_trp.xcomp_vbe_nn': ''},
 'remain predictor': {'e_trp.xcomp_vbe_nn': ''},
 'remain purity': {'e_trp.xcomp_vbe_nn': ''},
 'remain quality': {'e_trp.xcomp_vbe_nn': ''},
 'remain rationality': {'e_trp.xcomp_vbe_nn': ''},
 'remain reader': {'e_trp.xcomp_vbe_nn': ''},
 'remain relationship': {'e_trp.xcomp_vbe_nn': ''},
 'remain relic': {'e_trp.xcomp_vbe_nn': ''},
 'remain resource': {'e_trp.xcomp_vbe_nn': ''},
 'remain role': {'e_trp.xcomp_vbe_nn': ''},
 'remain sea': {'e_trp.xcomp_vbe_nn': ''},
 'remain sex': {'e_trp.xcomp_vbe_nn': ''},
 'remain sight': {'e_trp.xcomp_vbe_nn': ''},
 'remain skeleton': {'e_trp.xcomp_vbe_nn': ''},
 'remain socialist': {'e_trp.xcomp_vbe_nn': ''},
 'remain space': {'e_trp.xcomp_vbe_nn': ''},
 'remain species': {'e_trp.xcomp_vbe_nn': ''},
 'remain spine': {'e_trp.xcomp_vbe_nn': ''},
 'remain status': {'e_trp.xcomp_vbe_nn': ''},
 'remain subsistence': {'e_trp.xcomp_vbe_nn': ''},
 'remain success': {'e_trp.xcomp_vbe_nn': ''},
 'remain supervision': {'e_trp.xcomp_vbe_nn': ''},
 'remain surroundings': {'e_trp.xcomp_vbe_nn': ''},
 'remain technology': {'e_trp.xcomp_vbe_nn': ''},
 'remain tendency': {'e_trp.xcomp_vbe_nn': ''},
 'remain terror': {'e_trp.xcomp_vbe_nn': ''},
 'remain thought': {'e_trp.xcomp_vbe_nn': ''},
 'remain tongue': {'e_trp.xcomp_vbe_nn': ''},
 'remain tradition': {'e_trp.xcomp_vbe_nn': ''},
 'remain unity': {'e_trp.xcomp_vbe_nn': ''},
 'remain vigilance': {'e_trp.xcomp_vbe_nn': ''},
 'remain virtue': {'e_trp.xcomp_vbe_nn': ''},
 'remain vogue': {'e_trp.xcomp_vbe_nn': ''},
 'remain water': {'e_trp.xcomp_vbe_nn': ''},
 'remain word': {'e_trp.xcomp_vbe_nn': ''},
 'remain writer': {'e_trp.xcomp_vbe_nn': ''},
 'run circle': {'e_trp.xcomp_vbe_nn': ''},
 'run direction': {'e_trp.xcomp_vbe_nn': '', 'dobj.prep_miss': ''},
 'run efficiency': {'e_trp.xcomp_vbe_nn': ''},
 'run effort': {'e_trp.xcomp_vbe_nn': ''},
 'run engine': {'e_trp.xcomp_vbe_nn': ''},
 'run enterprise': {'e_trp.xcomp_vbe_nn': ''},
 'run evolution': {'e_trp.xcomp_vbe_nn': ''},
 'run family': {'e_trp.xcomp_vbe_nn': ''},
 'run ground': {'e_trp.xcomp_vbe_nn': ''},
 'run horse': {'e_trp.xcomp_vbe_nn': ''},
 'run kilometer': {'e_trp.xcomp_vbe_nn': ''},
 'run life': {'e_trp.xcomp_vbe_nn': ''},
 'run management': {'e_trp.xcomp_vbe_nn': ''},
 'run market': {'e_trp.xcomp_vbe_nn': ''},
 'run marriage': {'e_trp.xcomp_vbe_nn': ''},
 'run moment': {'e_trp.xcomp_vbe_nn': ''},
 'run morning': {'e_trp.xcomp_vbe_nn': ''},
 'run museum': {'e_trp.xcomp_vbe_nn': ''},
 'run people': {'e_trp.xcomp_vbe_nn': ''},
 'run porterhouse': {'e_trp.xcomp_vbe_nn': ''},
 'run relationship': {'e_trp.xcomp_vbe_nn': ''},
 'run revenue': {'e_trp.xcomp_vbe_nn': ''},
 'run saga': {'e_trp.xcomp_vbe_nn': ''},
 'run sunshine': {'e_trp.xcomp_vbe_nn': ''},
 'run university': {'e_trp.xcomp_vbe_nn': ''},
 'seem access': {'e_trp.xcomp_vbe_nn': ''},
 'seem action': {'e_trp.xcomp_vbe_nn': ''},
 'seem activity': {'e_trp.xcomp_vbe_nn': ''},
 'seem advertisement': {'e_trp.xcomp_vbe_nn': ''},
 'seem air': {'e_trp.xcomp_vbe_nn': ''},
 'seem angel': {'e_trp.xcomp_vbe_nn': ''},
 'seem animal': {'e_trp.xcomp_vbe_nn': ''},
 'seem apathy': {'e_trp.xcomp_vbe_nn': ''},
 'seem artifact': {'e_trp.xcomp_vbe_nn': ''},
 'seem association': {'e_trp.xcomp_vbe_nn': ''},
 'seem beauty': {'e_trp.xcomp_vbe_nn': ''},
 'seem blessing': {'e_trp.xcomp_vbe_nn': ''},
 'seem box': {'e_trp.xcomp_vbe_nn': ''},
 'seem century': {'e_trp.xcomp_vbe_nn': ''},
 'seem certificate': {'e_trp.xcomp_vbe_nn': ''},
 'seem chest': {'e_trp.xcomp_vbe_nn': ''},
 'seem class': {'e_trp.xcomp_vbe_nn': ''},
 'seem clothes': {'e_trp.xcomp_vbe_nn': ''},
 'seem coach': {'e_trp.xcomp_vbe_nn': ''},
 'seem comedown': {'e_trp.xcomp_vbe_nn': ''},
 'seem condensation': {'e_trp.xcomp_vbe_nn': ''},
 'seem confession': {'e_trp.xcomp_vbe_nn': ''},
 'seem confidence': {'e_trp.xcomp_vbe_nn': ''},
 'seem confusion': {'e_trp.xcomp_vbe_nn': ''},
 'seem connection': {'e_trp.xcomp_vbe_nn': ''},
 'seem consumer': {'e_trp.xcomp_vbe_nn': ''},
 'seem convenience': {'e_trp.xcomp_vbe_nn': ''},
 'seem crowd': {'e_trp.xcomp_vbe_nn': ''},
 'seem culture': {'e_trp.xcomp_vbe_nn': ''},
 'seem cup': {'e_trp.xcomp_vbe_nn': ''},
 'seem dad': {'e_trp.xcomp_vbe_nn': ''},
 'seem danger': {'e_trp.xcomp_vbe_nn': ''},
 'seem daydream': {'e_trp.xcomp_vbe_nn': ''},
 'seem development': {'e_trp.xcomp_vbe_nn': ''},
 'seem device': {'e_trp.xcomp_vbe_nn': ''},
 'seem difference': {'e_trp.xcomp_vbe_nn': ''},
 'seem diploma': {'e_trp.xcomp_vbe_nn': ''},
 'seem disappointment': {'e_trp.xcomp_vbe_nn': ''},
 'seem disciplinarian': {'e_trp.xcomp_vbe_nn': ''},
 'seem doctor': {'e_trp.xcomp_vbe_nn': ''},
 'seem doll': {'e_trp.xcomp_vbe_nn': ''},
 'seem drug': {'e_trp.xcomp_vbe_nn': ''},
 'seem duty': {'e_trp.xcomp_vbe_nn': ''},
 'seem efficiency': {'e_trp.xcomp_vbe_nn': ''},
 'seem elegance': {'e_trp.xcomp_vbe_nn': ''},
 'seem entertainment': {'e_trp.xcomp_vbe_nn': ''},
 'seem fact': {'e_trp.xcomp_vbe_nn': ''},
 'seem failure': {'e_trp.xcomp_vbe_nn': ''},
 'seem fiction': {'e_trp.xcomp_vbe_nn': ''},
 'seem field': {'e_trp.xcomp_vbe_nn': ''},
 'seem freedom': {'e_trp.xcomp_vbe_nn': ''},
 'seem friendship': {'e_trp.xcomp_vbe_nn': ''},
 'seem gift': {'e_trp.xcomp_vbe_nn': ''},
 'seem gossip': {'e_trp.xcomp_vbe_nn': ''},
 'seem graybeard': {'e_trp.xcomp_vbe_nn': ''},
 'seem habit': {'e_trp.xcomp_vbe_nn': ''},
 'seem happiness': {'e_trp.xcomp_vbe_nn': ''},
 'seem hat': {'e_trp.xcomp_vbe_nn': ''},
 'seem human': {'e_trp.xcomp_vbe_nn': ''},
 'seem illusion': {'e_trp.xcomp_vbe_nn': ''},
 'seem importance': {'e_trp.xcomp_vbe_nn': ''},
 'seem information': {'e_trp.xcomp_vbe_nn': ''},
 'seem joy': {'e_trp.xcomp_vbe_nn': ''},
 'seem judge': {'e_trp.xcomp_vbe_nn': ''},
 'seem knowledge': {'e_trp.xcomp_vbe_nn': ''},
 'seem lesson': {'e_trp.xcomp_vbe_nn': ''},
 'seem listener': {'e_trp.xcomp_vbe_nn': ''},
 'seem method': {'e_trp.xcomp_vbe_nn': ''},
 'seem mission': {'e_trp.xcomp_vbe_nn': ''},
 'seem movie': {'e_trp.xcomp_vbe_nn': ''},
 'seem necessity': {'e_trp.xcomp_vbe_nn': ''},
 'seem negativism': {'e_trp.xcomp_vbe_nn': ''},
 'seem novel': {'e_trp.xcomp_vbe_nn': ''},
 'seem occurrence': {'e_trp.xcomp_vbe_nn': ''},
 'seem ocean': {'e_trp.xcomp_vbe_nn': ''},
 'seem overconfidence': {'e_trp.xcomp_vbe_nn': ''},
 'seem parent': {'e_trp.xcomp_vbe_nn': ''},
 'seem pet': {'e_trp.xcomp_vbe_nn': ''},
 'seem phenomenon': {'e_trp.xcomp_vbe_nn': ''},
 'seem photo': {'e_trp.xcomp_vbe_nn': ''},
 'seem pleasure': {'e_trp.xcomp_vbe_nn': ''},
 'seem presentation': {'e_trp.xcomp_vbe_nn': ''},
 'seem reaper': {'e_trp.xcomp_vbe_nn': ''},
 'seem relation': {'e_trp.xcomp_vbe_nn': ''},
 'seem relationship': {'e_trp.xcomp_vbe_nn': ''},
 'seem relief': {'e_trp.xcomp_vbe_nn': ''},
 'seem research': {'e_trp.xcomp_vbe_nn': ''},
 'seem responsibility': {'e_trp.xcomp_vbe_nn': ''},
 'seem self-sufficiency': {'e_trp.xcomp_vbe_nn': ''},
 'seem sermon': {'e_trp.xcomp_vbe_nn': ''},
 'seem shortage': {'e_trp.xcomp_vbe_nn': ''},
 'seem shortcut': {'e_trp.xcomp_vbe_nn': ''},
 'seem shot': {'e_trp.xcomp_vbe_nn': ''},
 'seem socialization': {'e_trp.xcomp_vbe_nn': ''},
 'seem society': {'e_trp.xcomp_vbe_nn': ''},
 'seem song': {'e_trp.xcomp_vbe_nn': ''},
 'seem specialty': {'e_trp.xcomp_vbe_nn': ''},
 'seem stone': {'e_trp.xcomp_vbe_nn': ''},
 'seem sunshine': {'e_trp.xcomp_vbe_nn': ''},
 'seem tendency': {'e_trp.xcomp_vbe_nn': ''},
 'seem tiger': {'e_trp.xcomp_vbe_nn': ''},
 'seem topic': {'e_trp.xcomp_vbe_nn': ''},
 'seem tragedy': {'e_trp.xcomp_vbe_nn': ''},
 'seem trend': {'e_trp.xcomp_vbe_nn': ''},
 'seem trial': {'e_trp.xcomp_vbe_nn': ''},
 'seem village': {'e_trp.xcomp_vbe_nn': ''},
 'seem war': {'e_trp.xcomp_vbe_nn': ''},
 'seem warning': {'e_trp.xcomp_vbe_nn': ''},
 'seem week': {'e_trp.xcomp_vbe_nn': ''},
 'seem wisdom': {'e_trp.xcomp_vbe_nn': ''},
 'sound beauty': {'e_trp.xcomp_vbe_nn': ''},
 'sound character': {'e_trp.xcomp_vbe_nn': ''},
 'sound concept': {'e_trp.xcomp_vbe_nn': ''},
 'sound contradiction': {'e_trp.xcomp_vbe_nn': ''},
 'sound dialect': {'e_trp.xcomp_vbe_nn': ''},
 'sound facility': {'e_trp.xcomp_vbe_nn': ''},
 'sound footstep': {'e_trp.xcomp_vbe_nn': ''},
 'sound foundation': {'e_trp.xcomp_vbe_nn': ''},
 'sound growth': {'e_trp.xcomp_vbe_nn': ''},
 'sound health': {'e_trp.xcomp_vbe_nn': ''},
 'sound information': {'e_trp.xcomp_vbe_nn': ''},
 'sound irresponsibility': {'e_trp.xcomp_vbe_nn': ''},
 'sound job': {'e_trp.xcomp_vbe_nn': ''},
 'sound judgment': {'e_trp.xcomp_vbe_nn': ''},
 'sound law': {'e_trp.xcomp_vbe_nn': ''},
 'sound marriage': {'e_trp.xcomp_vbe_nn': ''},
 'sound meaning': {'e_trp.xcomp_vbe_nn': ''},
 'sound music': {'e_trp.xcomp_vbe_nn': ''},
 'sound player': {'e_trp.xcomp_vbe_nn': ''},
 'sound reality': {'e_trp.xcomp_vbe_nn': ''},
 'sound song': {'e_trp.xcomp_vbe_nn': ''},
 'stand behavior': {'e_trp.xcomp_vbe_nn': ''},
 'stand boredom': {'e_trp.xcomp_vbe_nn': ''},
 'stand building': {'e_trp.xcomp_vbe_nn': ''},
 'stand culture': {'e_trp.xcomp_vbe_nn': ''},
 'stand customer': {'e_trp.xcomp_vbe_nn': ''},
 'stand difficulty': {'e_trp.xcomp_vbe_nn': ''},
 'stand forbearance': {'e_trp.xcomp_vbe_nn': ''},
 'stand frustration': {'e_trp.xcomp_vbe_nn': ''},
 'stand gate': {'e_trp.xcomp_vbe_nn': ''},
 'stand habit': {'e_trp.xcomp_vbe_nn': ''},
 'stand leaf': {'e_trp.xcomp_vbe_nn': ''},
 'stand life': {'e_trp.xcomp_vbe_nn': ''},
 'stand man': {'e_trp.xcomp_vbe_nn': ''},
 'stand meaning': {'e_trp.xcomp_vbe_nn': ''},
 'stand music': {'e_trp.xcomp_vbe_nn': ''},
 'stand noise': {'e_trp.xcomp_vbe_nn': ''},
 'stand opportunity': {'e_trp.xcomp_vbe_nn': ''},
 'stand pavilion': {'e_trp.xcomp_vbe_nn': ''},
 'stand place': {'e_trp.xcomp_vbe_nn': ''},
 'stand position': {'e_trp.xcomp_vbe_nn': ''},
 'stand roommate': {'e_trp.xcomp_vbe_nn': ''},
 'stand society': {'e_trp.xcomp_vbe_nn': ''},
 'stand suggestion': {'e_trp.xcomp_vbe_nn': ''},
 'stand text': {'e_trp.xcomp_vbe_nn': ''},
 'stand time': {'e_trp.xcomp_vbe_nn': ''},
 'stand tribe': {'e_trp.xcomp_vbe_nn': ''},
 'stand viewpoint': {'e_trp.xcomp_vbe_nn': ''},
 'stand winter': {'e_trp.xcomp_vbe_nn': ''},
 'stay airport': {'e_trp.xcomp_vbe_nn': ''},
 'stay attitude': {'e_trp.xcomp_vbe_nn': ''},
 'stay beauty': {'e_trp.xcomp_vbe_nn': ''},
 'stay bed': {'e_trp.xcomp_vbe_nn': ''},
 'stay behavior': {'e_trp.xcomp_vbe_nn': ''},
 'stay body': {'e_trp.xcomp_vbe_nn': ''},
 'stay bookstore': {'e_trp.xcomp_vbe_nn': ''},
 'stay building': {'e_trp.xcomp_vbe_nn': ''},
 'stay campus': {'e_trp.xcomp_vbe_nn': ''},
 'stay car': {'e_trp.xcomp_vbe_nn': '', 'dobj.prep_miss': ''},
 'stay cent': {'e_trp.xcomp_vbe_nn': ''},
 'stay child': {'e_trp.xcomp_vbe_nn': '', 'dobj.prep_miss': ''},
 'stay city': {'e_trp.xcomp_vbe_nn': ''},
 'stay clam': {'e_trp.xcomp_vbe_nn': ''},
 'stay class': {'e_trp.xcomp_vbe_nn': ''},
 'stay classroom': {'e_trp.xcomp_vbe_nn': ''},
 'stay coffee': {'e_trp.xcomp_vbe_nn': ''},
 'stay college': {'e_trp.xcomp_vbe_nn': ''},
 'stay company': {'e_trp.xcomp_vbe_nn': ''},
 'stay computer': {'e_trp.xcomp_vbe_nn': ''},
 'stay connection': {'e_trp.xcomp_vbe_nn': ''},
 'stay country': {'e_trp.xcomp_vbe_nn': ''},
 'stay cucumber': {'e_trp.xcomp_vbe_nn': ''},
 'stay dimity': {'e_trp.xcomp_vbe_nn': ''},
 'stay diversity': {'e_trp.xcomp_vbe_nn': ''},
 'stay doe': {'e_trp.xcomp_vbe_nn': ''},
 'stay dorm': {'e_trp.xcomp_vbe_nn': ''},
 'stay dormitory': {'e_trp.xcomp_vbe_nn': ''},
 'stay drug': {'e_trp.xcomp_vbe_nn': ''},
 'stay earth': {'e_trp.xcomp_vbe_nn': ''},
 'stay environment': {'e_trp.xcomp_vbe_nn': ''},
 'stay eye': {'e_trp.xcomp_vbe_nn': ''},
 'stay fairness': {'e_trp.xcomp_vbe_nn': ''},
 'stay family': {'e_trp.xcomp_vbe_nn': ''},
 'stay flower': {'e_trp.xcomp_vbe_nn': ''},
 'stay friendship': {'e_trp.xcomp_vbe_nn': ''},
 'stay goods': {'e_trp.xcomp_vbe_nn': ''},
 'stay grandfather': {'e_trp.xcomp_vbe_nn': ''},
 'stay habit': {'e_trp.xcomp_vbe_nn': ''},
 'stay happiness': {'e_trp.xcomp_vbe_nn': ''},
 'stay harmony': {'e_trp.xcomp_vbe_nn': ''},
 'stay health': {'e_trp.xcomp_vbe_nn': ''},
 'stay healthy': {'e_trp.xcomp_vbe_nn': ''},
 'stay heart': {'e_trp.xcomp_vbe_nn': ''},
 'stay hometown': {'e_trp.xcomp_vbe_nn': ''},
 'stay honesty': {'e_trp.xcomp_vbe_nn': ''},
 'stay hospital': {'e_trp.xcomp_vbe_nn': ''},
 'stay house': {'e_trp.xcomp_vbe_nn': '', 'dobj.prep_miss': ''},
 'stay hunger': {'e_trp.xcomp_vbe_nn': ''},
 'stay illness': {'e_trp.xcomp_vbe_nn': ''},
 'stay image': {'e_trp.xcomp_vbe_nn': ''},
 'stay insulation': {'e_trp.xcomp_vbe_nn': ''},
 'stay interior': {'e_trp.xcomp_vbe_nn': ''},
 'stay job': {'e_trp.xcomp_vbe_nn': ''},
 'stay kid': {'e_trp.xcomp_vbe_nn': ''},
 'stay knowledge': {'e_trp.xcomp_vbe_nn': ''},
 'stay leeway': {'e_trp.xcomp_vbe_nn': ''},
 'stay library': {'e_trp.xcomp_vbe_nn': ''},
 'stay life': {'e_trp.xcomp_vbe_nn': ''},
 'stay lifestyle': {'e_trp.xcomp_vbe_nn': ''},
 'stay mentality': {'e_trp.xcomp_vbe_nn': ''},
 'stay midnight': {'e_trp.xcomp_vbe_nn': ''},
 'stay mind': {'e_trp.xcomp_vbe_nn': '', 'dobj.prep_miss': ''},
 'stay mood': {'e_trp.xcomp_vbe_nn': ''},
 'stay mouth': {'e_trp.xcomp_vbe_nn': ''},
 'stay neutrality': {'e_trp.xcomp_vbe_nn': ''},
 'stay optimism': {'e_trp.xcomp_vbe_nn': ''},
 'stay palace': {'e_trp.xcomp_vbe_nn': ''},
 'stay peace': {'e_trp.xcomp_vbe_nn': ''},
 'stay people': {'e_trp.xcomp_vbe_nn': ''},
 'stay person': {'e_trp.xcomp_vbe_nn': ''},
 'stay place': {'e_trp.xcomp_vbe_nn': ''},
 'stay position': {'e_trp.xcomp_vbe_nn': ''},
 'stay potato': {'e_trp.xcomp_vbe_nn': ''},
 'stay ratio': {'e_trp.xcomp_vbe_nn': ''},
 'stay room': {'e_trp.xcomp_vbe_nn': ''},
 'stay safety': {'e_trp.xcomp_vbe_nn': ''},
 'stay situation': {'e_trp.xcomp_vbe_nn': ''},
 'stay smoker': {'e_trp.xcomp_vbe_nn': ''},
 'stay solitude': {'e_trp.xcomp_vbe_nn': ''},
 'stay soul': {'e_trp.xcomp_vbe_nn': ''},
 'stay standby': {'e_trp.xcomp_vbe_nn': ''},
 'stay state': {'e_trp.xcomp_vbe_nn': ''},
 'stay statement': {'e_trp.xcomp_vbe_nn': ''},
 'stay status': {'e_trp.xcomp_vbe_nn': ''},
 'stay surfing': {'e_trp.xcomp_vbe_nn': ''},
 'stay tension': {'e_trp.xcomp_vbe_nn': ''},
 'stay thing': {'e_trp.xcomp_vbe_nn': ''},
 'stay threshold': {'e_trp.xcomp_vbe_nn': ''},
 'stay town': {'e_trp.xcomp_vbe_nn': ''},
 'stay unit': {'e_trp.xcomp_vbe_nn': ''},
 'stay university': {'e_trp.xcomp_vbe_nn': ''},
 'stay village': {'e_trp.xcomp_vbe_nn': ''},
 'stay weakness': {'e_trp.xcomp_vbe_nn': ''},
 'stay woman': {'e_trp.xcomp_vbe_nn': ''},
 'stay world': {'e_trp.xcomp_vbe_nn': ''},
 'stay zeal': {'e_trp.xcomp_vbe_nn': ''},
 'turn cellphone': {'e_trp.xcomp_vbe_nn': ''},
 'turn character': {'e_trp.xcomp_vbe_nn': ''},
 'turn eye': {'e_trp.xcomp_vbe_nn': ''},
 'turn home': {'e_trp.xcomp_vbe_nn': ''},
 'turn hostility': {'e_trp.xcomp_vbe_nn': ''},
 'turn racket': {'e_trp.xcomp_vbe_nn': ''},
 'turn session': {'e_trp.xcomp_vbe_nn': ''},
 'turn talent': {'e_trp.xcomp_vbe_nn': ''},
 'turn uncle': {'e_trp.xcomp_vbe_nn': ''},
 'abide law': {'dobj.prep_miss': ''},
 'abide result': {'dobj.prep_miss': ''},
 'abide rule': {'dobj.prep_miss': ''},
 'accept school': {'dobj.prep_miss': ''},
 'adapt change': {'dobj.prep_miss': ''},
 'add collection': {'dobj.prep_miss': ''},
 'add menu': {'dobj.prep_miss': ''},
 'add soup': {'dobj.prep_miss': ''},
 'adjust change': {'dobj.prep_miss': ''},
 'adjust inflation': {'dobj.prep_miss': ''},
 'adjust life': {'dobj.prep_miss': ''},
 'adjust taste': {'dobj.prep_miss': ''},
 'agree strategy': {'dobj.prep_miss': ''},
 'agree way': {'dobj.prep_miss': ''},
 'appeal assistance': {'dobj.prep_miss': ''},
 'appeal authority': {'dobj.prep_miss': ''},
 'appeal government': {'dobj.prep_miss': ''},
 'appeal information': {'dobj.prep_miss': ''},
 'apply accreditation': {'dobj.prep_miss': ''},
 'apply admission': {'dobj.prep_miss': ''},
 'apply approval': {'dobj.prep_miss': ''},
 'apply assistance': {'dobj.prep_miss': ''},
 'apply citizenship': {'dobj.prep_miss': ''},
 'apply college': {'dobj.prep_miss': ''},
 'apply compensation': {'dobj.prep_miss': ''},
 'apply employee': {'dobj.prep_miss': ''},
 'apply exemption': {'dobj.prep_miss': ''},
 'apply human': {'dobj.prep_miss': ''},
 'apply insurance': {'dobj.prep_miss': ''},
 'apply job': {'dobj.prep_miss': ''},
 'apply licence': {'dobj.prep_miss': ''},
 'apply license': {'dobj.prep_miss': ''},
 'apply life': {'dobj.prep_miss': ''},
 'apply membership': {'dobj.prep_miss': ''},
 'apply patent': {'dobj.prep_miss': ''},
 'apply permission': {'dobj.prep_miss': ''},
 'apply position': {'dobj.prep_miss': ''},
 'apply registration': {'dobj.prep_miss': ''},
 'apply visa': {'dobj.prep_miss': ''},
 'argue detail': {'dobj.prep_miss': ''},
 'arrest incident': {'dobj.prep_miss': ''},
 'arrive car': {'dobj.prep_miss': ''},
 'arrive end': {'dobj.prep_miss': ''},
 'arrive hotel': {'dobj.prep_miss': ''},
 'arrive port': {'dobj.prep_miss': ''},
 'arrive ship': {'dobj.prep_miss': ''},
 'ask action': {'dobj.prep_miss': ''},
 'ask assistance': {'dobj.prep_miss': ''},
 'ask clarification': {'dobj.prep_miss': ''},
 'ask comment': {'dobj.prep_miss': ''},
 'ask cooperation': {'dobj.prep_miss': ''},
 'ask delay': {'dobj.prep_miss': ''},
 'ask detail': {'dobj.prep_miss': ''},
 'ask donation': {'dobj.prep_miss': ''},
 'ask evidence': {'dobj.prep_miss': ''},
 'ask guidance': {'dobj.prep_miss': ''},
 'ask information': {'dobj.prep_miss': ''},
 'ask mercy': {'dobj.prep_miss': ''},
 'ask patience': {'dobj.prep_miss': ''},
 'ask payment': {'dobj.prep_miss': ''},
 'ask proof': {'dobj.prep_miss': ''},
 'ask protection': {'dobj.prep_miss': ''},
 'ask release': {'dobj.prep_miss': ''},
 'ask suggestion': {'dobj.prep_miss': ''},
 'ask trial': {'dobj.prep_miss': ''},
 'attach back': {'dobj.prep_miss': ''},
 'attach belt': {'dobj.prep_miss': ''},
 'attach body': {'dobj.prep_miss': ''},
 'attach bottom': {'dobj.prep_miss': ''},
 'attach side': {'dobj.prep_miss': ''},
 'attach wall': {'dobj.prep_miss': ''},
 'attack night': {'dobj.prep_miss': ''},
 'avoid plague': {'dobj.prep_miss': ''},
 'awake night': {'dobj.prep_miss': ''},
 'balance head': {'dobj.prep_miss': ''},
 'bang wall': {'dobj.prep_miss': ''},
 'base age': {'dobj.prep_miss': ''},
 'base color': {'dobj.prep_miss': ''},
 'base combination': {'dobj.prep_miss': ''},
 'base condition': {'dobj.prep_miss': ''},
 'base consensus': {'dobj.prep_miss': ''},
 'base conversation': {'dobj.prep_miss': ''},
 'base cost': {'dobj.prep_miss': ''},
 'base criterion': {'dobj.prep_miss': ''},
 'base date': {'dobj.prep_miss': ''},
 'base difference': {'dobj.prep_miss': ''},
 'base event': {'dobj.prep_miss': ''},
 'base experience': {'dobj.prep_miss': ''},
 'base fact': {'dobj.prep_miss': ''},
 'base factor': {'dobj.prep_miss': ''},
 'base gender': {'dobj.prep_miss': ''},
 'base ground': {'dobj.prep_miss': ''},
 'base history': {'dobj.prep_miss': ''},
 'base incident': {'dobj.prep_miss': ''},
 'base intelligence': {'dobj.prep_miss': ''},
 'base interest': {'dobj.prep_miss': ''},
 'base interview': {'dobj.prep_miss': ''},
 'base issue': {'dobj.prep_miss': ''},
 'base length': {'dobj.prep_miss': ''},
 'base level': {'dobj.prep_miss': ''},
 'base location': {'dobj.prep_miss': ''},
 'base material': {'dobj.prep_miss': ''},
 'base merit': {'dobj.prep_miss': ''},
 'base need': {'dobj.prep_miss': ''},
 'base notion': {'dobj.prep_miss': ''},
 'base pattern': {'dobj.prep_miss': ''},
 'base people': {'dobj.prep_miss': ''},
 'base perception': {'dobj.prep_miss': ''},
 'base point': {'dobj.prep_miss': ''},
 'base population': {'dobj.prep_miss': ''},
 'base premise': {'dobj.prep_miss': ''},
 'base profit': {'dobj.prep_miss': ''},
 'base quality': {'dobj.prep_miss': ''},
 'base questionnaire': {'dobj.prep_miss': ''},
 'base race': {'dobj.prep_miss': ''},
 'base reality': {'dobj.prep_miss': ''},
 'base record': {'dobj.prep_miss': ''},
 'base respect': {'dobj.prep_miss': ''},
 'base revenue': {'dobj.prep_miss': ''},
 'base sample': {'dobj.prep_miss': ''},
 'base science': {'dobj.prep_miss': ''},
 'base software': {'dobj.prep_miss': ''},
 'base source': {'dobj.prep_miss': ''},
 'base testimony': {'dobj.prep_miss': ''},
 'base theme': {'dobj.prep_miss': ''},
 'base tradition': {'dobj.prep_miss': ''},
 'base trend': {'dobj.prep_miss': ''},
 'base type': {'dobj.prep_miss': ''},
 'base use': {'dobj.prep_miss': ''},
 'base volume': {'dobj.prep_miss': ''},
 'base year': {'dobj.prep_miss': ''},
 'beat ground': {'dobj.prep_miss': ''},
 'beat stick': {'dobj.prep_miss': ''},
 'beg life': {'dobj.prep_miss': ''},
 'beg mercy': {'dobj.prep_miss': ''},
 'begin afternoon': {'dobj.prep_miss': ''},
 'begin area': {'dobj.prep_miss': ''},
 'begin beginning': {'dobj.prep_miss': ''},
 'begin earnest': {'dobj.prep_miss': ''},
 'begin election': {'dobj.prep_miss': ''},
 'begin flow': {'dobj.prep_miss': ''},
 'begin government': {'dobj.prep_miss': ''},
 'begin hour': {'dobj.prep_miss': ''},
 'begin moment': {'dobj.prep_miss': ''},
 'begin site': {'dobj.prep_miss': ''},
 'begin time': {'dobj.prep_miss': ''},
 'begin top': {'dobj.prep_miss': ''},
 'believe ability': {'dobj.prep_miss': ''},
 'believe cause': {'dobj.prep_miss': ''},
 'believe ghost': {'dobj.prep_miss': ''},
 'believe heart': {'dobj.prep_miss': ''},
 'believe importance': {'dobj.prep_miss': ''},
 'believe miracle': {'dobj.prep_miss': ''},
 'believe power': {'dobj.prep_miss': ''},
 'believe right': {'dobj.prep_miss': ''},
 'believe team': {'dobj.prep_miss': ''},
 'believe time': {'dobj.prep_miss': ''},
 'believe value': {'dobj.prep_miss': ''},
 'belong group': {'dobj.prep_miss': ''},
 'bend shape': {'dobj.prep_miss': ''},
 'benefit amnesty': {'dobj.prep_miss': ''},
 'benefit change': {'dobj.prep_miss': ''},
 'benefit competition': {'dobj.prep_miss': ''},
 'benefit effort': {'dobj.prep_miss': ''},
 'benefit expectation': {'dobj.prep_miss': ''},
 'benefit improvement': {'dobj.prep_miss': ''},
 'benefit investment': {'dobj.prep_miss': ''},
 'benefit law': {'dobj.prep_miss': ''},
 'benefit news': {'dobj.prep_miss': ''},
 'benefit price': {'dobj.prep_miss': ''},
 'benefit rate': {'dobj.prep_miss': ''},
 'benefit recovery': {'dobj.prep_miss': ''},
 'benefit sale': {'dobj.prep_miss': ''},
 'benefit service': {'dobj.prep_miss': ''},
 'benefit sign': {'dobj.prep_miss': ''},
 'benefit trade': {'dobj.prep_miss': ''},
 'benefit treatment': {'dobj.prep_miss': ''},
 'benefit trend': {'dobj.prep_miss': ''},
 'benefit use': {'dobj.prep_miss': ''},
 'bet baseball': {'dobj.prep_miss': ''},
 'bet game': {'dobj.prep_miss': ''},
 'bet race': {'dobj.prep_miss': ''},
 'bet sport': {'dobj.prep_miss': ''},
 'bet stock': {'dobj.prep_miss': ''},
 'bid work': {'dobj.prep_miss': ''},
 'bind receptor': {'dobj.prep_miss': ''},
 'bleed death': {'dobj.prep_miss': ''},
 'blow steam': {'dobj.prep_miss': ''},
 'blow wind': {'dobj.prep_miss': ''},
 'border side': {'dobj.prep_miss': ''},
 'borrow friend': {'dobj.prep_miss': ''},
 'break area': {'dobj.prep_miss': ''},
 'break building': {'dobj.prep_miss': ''},
 'break business': {'dobj.prep_miss': ''},
 'break computer': {'dobj.prep_miss': ''},
 'break end': {'dobj.prep_miss': ''},
 'break group': {'dobj.prep_miss': ''},
 'break home': {'dobj.prep_miss': ''},
 'break house': {'dobj.prep_miss': ''},
 'break market': {'dobj.prep_miss': ''},
 'break office': {'dobj.prep_miss': ''},
 'break place': {'dobj.prep_miss': ''},
 'break room': {'dobj.prep_miss': ''},
 'break shop': {'dobj.prep_miss': ''},
 'break song': {'dobj.prep_miss': ''},
 'break tear': {'dobj.prep_miss': ''},
 'bring airport': {'dobj.prep_miss': ''},
 'bring brink': {'dobj.prep_miss': ''},
 'bring camp': {'dobj.prep_miss': ''},
 'bring floor': {'dobj.prep_miss': ''},
 'bring fold': {'dobj.prep_miss': ''},
 'bring mind': {'dobj.prep_miss': ''},
 'bring office': {'dobj.prep_miss': ''},
 'bring open': {'dobj.prep_miss': ''},
 'bring retirement': {'dobj.prep_miss': ''},
 'bring role': {'dobj.prep_miss': ''},
 'bring room': {'dobj.prep_miss': ''},
 'bring screen': {'dobj.prep_miss': ''},
 'bring shore': {'dobj.prep_miss': ''},
 'bring stage': {'dobj.prep_miss': ''},
 'bring surface': {'dobj.prep_miss': ''},
 'bring table': {'dobj.prep_miss': ''},
 'bring task': {'dobj.prep_miss': ''},
 'bring village': {'dobj.prep_miss': ''},
 'build brick': {'dobj.prep_miss': ''},
 'build crescendo': {'dobj.prep_miss': ''},
 'build downtown': {'dobj.prep_miss': ''},
 'build ground': {'dobj.prep_miss': ''},
 'build help': {'dobj.prep_miss': ''},
 'build hill': {'dobj.prep_miss': ''},
 'build land': {'dobj.prep_miss': ''},
 'build price': {'dobj.prep_miss': ''},
 'build purpose': {'dobj.prep_miss': ''},
 'build scratch': {'dobj.prep_miss': ''},
 'build side': {'dobj.prep_miss': ''},
 'burn day': {'dobj.prep_miss': ''},
 'burn ground': {'dobj.prep_miss': ''},
 'burn hour': {'dobj.prep_miss': ''},
 'burn night': {'dobj.prep_miss': ''},
 'bury hand': {'dobj.prep_miss': ''},
 'buy dealer': {'dobj.prep_miss': ''},
 'buy discount': {'dobj.prep_miss': ''},
 'buy end': {'dobj.prep_miss': ''},
 'buy manufacturer': {'dobj.prep_miss': ''},
 'buy supplier': {'dobj.prep_miss': ''},
 'buy vendor': {'dobj.prep_miss': ''},
 'buy year': {'dobj.prep_miss': ''},
 'call account': {'dobj.prep_miss': ''},
 'call adoption': {'dobj.prep_miss': ''},
 'call advice': {'dobj.prep_miss': ''},
 'call aid': {'dobj.prep_miss': ''},
 'call appointment': {'dobj.prep_miss': ''},
 'call arrest': {'dobj.prep_miss': ''},
 'call backup': {'dobj.prep_miss': ''},
 'call ban': {'dobj.prep_miss': ''},
 'call cancellation': {'dobj.prep_miss': ''},
 'call caution': {'dobj.prep_miss': ''},
 'call check': {'dobj.prep_miss': ''},
 'call closure': {'dobj.prep_miss': ''},
 'call comment': {'dobj.prep_miss': ''},
 'call compromise': {'dobj.prep_miss': ''},
 'call construction': {'dobj.prep_miss': ''},
 'call consultation': {'dobj.prep_miss': ''},
 'call continuation': {'dobj.prep_miss': ''},
 'call death': {'dobj.prep_miss': ''},
 'call debate': {'dobj.prep_miss': ''},
 'call delay': {'dobj.prep_miss': ''},
 'call democracy': {'dobj.prep_miss': ''},
 'call destruction': {'dobj.prep_miss': ''},
 'call development': {'dobj.prep_miss': '', 'e_trp.nsv': ''},
 'call dinner': {'dobj.prep_miss': ''},
 'call disclosure': {'dobj.prep_miss': ''},
 'call discussion': {'dobj.prep_miss': ''},
 'call dismissal': {'dobj.prep_miss': ''},
 'call donation': {'dobj.prep_miss': ''},
 'call elimination': {'dobj.prep_miss': ''},
 'call enforcement': {'dobj.prep_miss': ''},
 'call establishment': {'dobj.prep_miss': ''},
 'call exchange': {'dobj.prep_miss': ''},
 'call expansion': {'dobj.prep_miss': ''},
 'call extension': {'dobj.prep_miss': ''},
 'call freedom': {'dobj.prep_miss': ''},
 'call guarantee': {'dobj.prep_miss': ''},
 'call hour': {'dobj.prep_miss': ''},
 'call increase': {'dobj.prep_miss': ''},
 'call independence': {'dobj.prep_miss': ''},
 'call inspection': {'dobj.prep_miss': ''},
 'call intervention': {'dobj.prep_miss': ''},
 'call interview': {'dobj.prep_miss': ''},
 'call introduction': {'dobj.prep_miss': ''},
 'call investment': {'dobj.prep_miss': ''},
 'call job': {'dobj.prep_miss': ''},
 'call justice': {'dobj.prep_miss': ''},
 'call killing': {'dobj.prep_miss': ''},
 'call legislation': {'dobj.prep_miss': ''},
 'call limit': {'dobj.prep_miss': ''},
 'call negotiation': {'dobj.prep_miss': ''},
 'call observer': {'dobj.prep_miss': ''},
 'call passage': {'dobj.prep_miss': ''},
 'call peace': {'dobj.prep_miss': ''},
 'call port': {'dobj.prep_miss': ''},
 'call power': {'dobj.prep_miss': ''},
 'call prayer': {'dobj.prep_miss': ''},
 'call pressure': {'dobj.prep_miss': ''},
 'call progress': {'dobj.prep_miss': ''},
 'call protection': {'dobj.prep_miss': ''},
 'call public': {'dobj.prep_miss': ''},
 'call punishment': {'dobj.prep_miss': ''},
 'call reduction': {'dobj.prep_miss': ''},
 'call regulation': {'dobj.prep_miss': ''},
 'call release': {'dobj.prep_miss': ''},
 'call removal': {'dobj.prep_miss': ''},
 'call replacement': {'dobj.prep_miss': ''},
 'call respect': {'dobj.prep_miss': ''},
 'call restoration': {'dobj.prep_miss': ''},
 'call sanction': {'dobj.prep_miss': ''},
 'call sick': {'dobj.prep_miss': ''},
 'call stability': {'dobj.prep_miss': ''},
 'call study': {'dobj.prep_miss': ''},
 'call suspension': {'dobj.prep_miss': ''},
 'call tax': {'dobj.prep_miss': ''},
 'call trade': {'dobj.prep_miss': ''},
 'call unity': {'dobj.prep_miss': ''},
 'call violence': {'dobj.prep_miss': ''},
 'call volunteer': {'dobj.prep_miss': ''},
 'call weekend': {'dobj.prep_miss': ''},
 'call withdrawal': {'dobj.prep_miss': ''},
 'campaign right': {'dobj.prep_miss': ''},
 'capture film': {'dobj.prep_miss': ''},
 'capture tape': {'dobj.prep_miss': ''},
 'care character': {'dobj.prep_miss': ''},
 'care dog': {'dobj.prep_miss': ''},
 'care environment': {'dobj.prep_miss': ''},
 'care family': {'dobj.prep_miss': ''},
 'care game': {'dobj.prep_miss': ''},
 'care issue': {'dobj.prep_miss': ''},
 'care kid': {'dobj.prep_miss': ''},
 'care mother': {'dobj.prep_miss': ''},
 'care parent': {'dobj.prep_miss': ''},
 'care patient': {'dobj.prep_miss': ''},
 'care pet': {'dobj.prep_miss': ''},
 'carry building': {'dobj.prep_miss': ''},
 'carry court': {'dobj.prep_miss': ''},
 'carry end': {'dobj.prep_miss': ''},
 'carry field': {'dobj.prep_miss': ''},
 'carry hospital': {'dobj.prep_miss': ''},
 'carry house': {'dobj.prep_miss': ''},
 'carry night': {'dobj.prep_miss': ''},
 'carry shoulder': {'dobj.prep_miss': ''},
 'carry street': {'dobj.prep_miss': ''},
 'cast type': {'dobj.prep_miss': ''},
 'catch camera': {'dobj.prep_miss': ''},
 'catch middle': {'dobj.prep_miss': ''},
 'catch traffic': {'dobj.prep_miss': ''},
 'catch trap': {'dobj.prep_miss': ''},
 'cater need': {'dobj.prep_miss': ''},
 'cater people': {'dobj.prep_miss': ''},
 'cater student': {'dobj.prep_miss': ''},
 'cater taste': {'dobj.prep_miss': ''},
 'challenge title': {'dobj.prep_miss': ''},
 'change century': {'dobj.prep_miss': ''},
 'change concern': {'dobj.prep_miss': ''},
 'change good': {'dobj.prep_miss': ''},
 'change month': {'dobj.prep_miss': ''},
 'change recognition': {'dobj.prep_miss': ''},
 'change release': {'dobj.prep_miss': ''},
 'charge abuse': {'dobj.prep_miss': ''},
 'charge act': {'dobj.prep_miss': ''},
 'charge conspiracy': {'dobj.prep_miss': ''},
 'charge count': {'dobj.prep_miss': ''},
 'charge damage': {'dobj.prep_miss': ''},
 'charge death': {'dobj.prep_miss': ''},
 'charge drug': {'dobj.prep_miss': ''},
 'charge failure': {'dobj.prep_miss': ''},
 'charge felony': {'dobj.prep_miss': ''},
 'charge incident': {'dobj.prep_miss': ''},
 'charge investigation': {'dobj.prep_miss': ''},
 'charge law': {'dobj.prep_miss': ''},
 'charge membership': {'dobj.prep_miss': ''},
 'charge misdemeanor': {'dobj.prep_miss': ''},
 'charge murder': {'dobj.prep_miss': ''},
 'charge offence': {'dobj.prep_miss': ''},
 'charge offense': {'dobj.prep_miss': ''},
 'charge service': {'dobj.prep_miss': ''},
 'charge terrorism': {'dobj.prep_miss': ''},
 'charge use': {'dobj.prep_miss': ''},
 'chase street': {'dobj.prep_miss': ''},
 'chat friend': {'dobj.prep_miss': ''},
 'chat people': {'dobj.prep_miss': ''},
 'cheat test': {'dobj.prep_miss': ''},
 'cheat wife': {'dobj.prep_miss': ''},
 'check doctor': {'dobj.prep_miss': ''},
 'check game': {'dobj.prep_miss': ''},
 'chip green': {'dobj.prep_miss': ''},
 'choose list': {'dobj.prep_miss': ''},
 'choose two': {'dobj.prep_miss': ''},
 'chop piece': {'dobj.prep_miss': ''},
 'circulate body': {'dobj.prep_miss': ''},
 'circulate member': {'dobj.prep_miss': ''},
 'circulate week': {'dobj.prep_miss': ''},
 'claim waiver': {'dobj.prep_miss': ''},
 'click picture': {'dobj.prep_miss': ''},
 'climb top': {'dobj.prep_miss': ''},
 'close attack': {'dobj.prep_miss': ''},
 'close end': {'dobj.prep_miss': ''},
 'close good': {'dobj.prep_miss': ''},
 'close notice': {'dobj.prep_miss': ''},
 'close period': {'dobj.prep_miss': ''},
 'close point': {'dobj.prep_miss': ''},
 'close summer': {'dobj.prep_miss': ''},
 'close year': {'dobj.prep_miss': ''},
 'codify law': {'dobj.prep_miss': ''},
 'coincide release': {'dobj.prep_miss': ''},
 'collect year': {'dobj.prep_miss': ''},
 'combine goal': {'dobj.prep_miss': ''},
 'come action': {'dobj.prep_miss': ''},
 'come art': {'dobj.prep_miss': ''},
 'come attack': {'dobj.prep_miss': ''},
 'come book': {'dobj.prep_miss': ''},
 'come category': {'dobj.prep_miss': ''},
 'come challenge': {'dobj.prep_miss': ''},
 'come contact': {'dobj.prep_miss': ''},
 'come cost': {'dobj.prep_miss': ''},
 'come crisis': {'dobj.prep_miss': ''},
 'come dawn': {'dobj.prep_miss': ''},
 'come death': {'dobj.prep_miss': ''},
 'come decade': {'dobj.prep_miss': ''},
 'come end': {'dobj.prep_miss': ''},
 'come experience': {'dobj.prep_miss': ''},
 'come fire': {'dobj.prep_miss': ''},
 'come force': {'dobj.prep_miss': ''},
 'come form': {'dobj.prep_miss': ''},
 'come government': {'dobj.prep_miss': ''},
 'come gun': {'dobj.prep_miss': ''},
 'come hope': {'dobj.prep_miss': ''},
 'come hour': {'dobj.prep_miss': ''},
 'come idea': {'dobj.prep_miss': ''},
 'come knowledge': {'dobj.prep_miss': ''},
 'come life': {'dobj.prep_miss': ''},
 'come light': {'dobj.prep_miss': ''},
 'come mile': {'dobj.prep_miss': ''},
 'come model': {'dobj.prep_miss': ''},
 'come morning': {'dobj.prep_miss': ''},
 'come number': {'dobj.prep_miss': ''},
 'come pair': {'dobj.prep_miss': ''},
 'come part': {'dobj.prep_miss': ''},
 'come picture': {'dobj.prep_miss': ''},
 'come post': {'dobj.prep_miss': ''},
 'come power': {'dobj.prep_miss': ''},
 'come price': {'dobj.prep_miss': ''},
 'come product': {'dobj.prep_miss': ''},
 'come realization': {'dobj.prep_miss': ''},
 'come rescue': {'dobj.prep_miss': ''},
 'come risk': {'dobj.prep_miss': ''},
 'come rule': {'dobj.prep_miss': ''},
 'come scene': {'dobj.prep_miss': ''},
 'come season': {'dobj.prep_miss': ''},
 'come sense': {'dobj.prep_miss': ''},
 'come side': {'dobj.prep_miss': ''},
 'come sign': {'dobj.prep_miss': ''},
 'come size': {'dobj.prep_miss': ''},
 'come software': {'dobj.prep_miss': ''},
 'come son': {'dobj.prep_miss': ''},
 'come stage': {'dobj.prep_miss': ''},
 'come stair': {'dobj.prep_miss': ''},
 'come summer': {'dobj.prep_miss': ''},
 'come term': {'dobj.prep_miss': ''},
 'come title': {'dobj.prep_miss': ''},
 'come understanding': {'dobj.prep_miss': ''},
 'come variety': {'dobj.prep_miss': ''},
 'come weekend': {'dobj.prep_miss': ''},
 'come winter': {'dobj.prep_miss': ''},
 'come world': {'dobj.prep_miss': ''},
 'comment action': {'dobj.prep_miss': ''},
 'comment announcement': {'dobj.prep_miss': ''},
 'comment book': {'dobj.prep_miss': ''},
 'comment content': {'dobj.prep_miss': ''},
 'comment development': {'dobj.prep_miss': ''},
 'comment document': {'dobj.prep_miss': ''},
 'comment event': {'dobj.prep_miss': ''},
 'comment game': {'dobj.prep_miss': ''},
 'comment information': {'dobj.prep_miss': ''},
 'comment letter': {'dobj.prep_miss': ''},
 'comment proposal': {'dobj.prep_miss': ''},
 'comment question': {'dobj.prep_miss': ''},
 'comment suggestion': {'dobj.prep_miss': ''},
 'commit cause': {'dobj.prep_miss': ''},
 'commit change': {'dobj.prep_miss': ''},
 'commit program': {'dobj.prep_miss': ''},
 'commit project': {'dobj.prep_miss': ''},
 'communicate child': {'dobj.prep_miss': ''},
 'communicate computer': {'dobj.prep_miss': ''},
 'communicate customer': {'dobj.prep_miss': ''},
 'communicate employee': {'dobj.prep_miss': ''},
 'communicate member': {'dobj.prep_miss': ''},
 'communicate public': {'dobj.prep_miss': ''},
 'commute work': {'dobj.prep_miss': ''},
 'compare control': {'dobj.prep_miss': ''},
 'compare one': {'dobj.prep_miss': ''},
 'compensate lack': {'dobj.prep_miss': ''},
 'compensate risk': {'dobj.prep_miss': ''},
 'compete price': {'dobj.prep_miss': ''},
 'compete race': {'dobj.prep_miss': ''},
 'compete team': {'dobj.prep_miss': ''},
 'complain lack': {'dobj.prep_miss': ''},
 'comply requirement': {'dobj.prep_miss': ''},
 'concentrate market': {'dobj.prep_miss': ''},
 'concentrate study': {'dobj.prep_miss': ''},
 'concentrate work': {'dobj.prep_miss': ''},
 'condense water': {'dobj.prep_miss': ''},
 'conduct door': {'dobj.prep_miss': ''},
 'conflict law': {'dobj.prep_miss': ''},
 'conform regulation': {'dobj.prep_miss': ''},
 'conform rule': {'dobj.prep_miss': ''},
 'conform standard': {'dobj.prep_miss': ''},
 'confront evidence': {'dobj.prep_miss': ''},
 'connect audience': {'dobj.prep_miss': ''},
 'consult telephone': {'dobj.prep_miss': ''},
 'contact phone': {'dobj.prep_miss': ''},
 'contact telephone': {'dobj.prep_miss': ''},
 'contain bill': {'dobj.prep_miss': ''},
 'contaminate bacterium': {'dobj.prep_miss': ''},
 'continue area': {'dobj.prep_miss': ''},
 'continue country': {'dobj.prep_miss': ''},
 'continue day': {'dobj.prep_miss': ''},
 'continue director': {'dobj.prep_miss': ''},
 'continue end': {'dobj.prep_miss': ''},
 'continue evening': {'dobj.prep_miss': ''},
 'continue flow': {'dobj.prep_miss': ''},
 'continue morning': {'dobj.prep_miss': ''},
 'continue night': {'dobj.prep_miss': ''},
 'continue office': {'dobj.prep_miss': ''},
 'continue spring': {'dobj.prep_miss': ''},
 'continue stream': {'dobj.prep_miss': ''},
 'continue summer': {'dobj.prep_miss': ''},
 'continue winter': {'dobj.prep_miss': ''},
 'contribute development': {'dobj.prep_miss': ''},
 'contribute growth': {'dobj.prep_miss': ''},
 'contribute improvement': {'dobj.prep_miss': ''},
 'contribute increase': {'dobj.prep_miss': ''},
 'contribute pollution': {'dobj.prep_miss': ''},
 'contribute problem': {'dobj.prep_miss': ''},
 'contribute program': {'dobj.prep_miss': ''},
 'contribute project': {'dobj.prep_miss': ''},
 'contribute security': {'dobj.prep_miss': ''},
 'contribute sense': {'dobj.prep_miss': ''},
 'contribute success': {'dobj.prep_miss': ''},
 'contribute team': {'dobj.prep_miss': ''},
 'contribute understanding': {'dobj.prep_miss': ''},
 'convert cash': {'dobj.prep_miss': ''},
 'convert franc': {'dobj.prep_miss': ''},
 'cook family': {'dobj.prep_miss': ''},
 'cook grill': {'dobj.prep_miss': ''},
 'count hand': {'dobj.prep_miss': ''},
 'count part': {'dobj.prep_miss': ''},
 'cover blood': {'dobj.prep_miss': ''},
 'cover dust': {'dobj.prep_miss': ''},
 'cover fabric': {'dobj.prep_miss': ''},
 'cover mud': {'dobj.prep_miss': ''},
 'crack pressure': {'dobj.prep_miss': ''},
 'crash window': {'dobj.prep_miss': ''},
 'cross foot': {'dobj.prep_miss': ''},
 'cry night': {'dobj.prep_miss': ''},
 'cut bone': {'dobj.prep_miss': ''},
 'cut cube': {'dobj.prep_miss': ''},
 'cut grain': {'dobj.prep_miss': ''},
 'cut knife': {'dobj.prep_miss': ''},
 'cut middle': {'dobj.prep_miss': ''},
 'cut quarter': {'dobj.prep_miss': ''},
 'damage collision': {'dobj.prep_miss': ''},
 'damage repair': {'dobj.prep_miss': ''},
 'dance tune': {'dobj.prep_miss': ''},
 'deal abuse': {'dobj.prep_miss': ''},
 'deal affair': {'dobj.prep_miss': ''},
 'deal allegation': {'dobj.prep_miss': ''},
 'deal attack': {'dobj.prep_miss': ''},
 'deal business': {'dobj.prep_miss': ''},
 'deal challenge': {'dobj.prep_miss': ''},
 'deal change': {'dobj.prep_miss': ''},
 'deal child': {'dobj.prep_miss': ''},
 'deal client': {'dobj.prep_miss': ''},
 'deal complaint': {'dobj.prep_miss': ''},
 'deal conflict': {'dobj.prep_miss': ''},
 'deal crime': {'dobj.prep_miss': ''},
 'deal crisis': {'dobj.prep_miss': ''},
 'deal customer': {'dobj.prep_miss': ''},
 'deal death': {'dobj.prep_miss': ''},
 'deal difficulty': {'dobj.prep_miss': ''},
 'deal employee': {'dobj.prep_miss': ''},
 'deal enquiry': {'dobj.prep_miss': ''},
 'deal incident': {'dobj.prep_miss': ''},
 'deal information': {'dobj.prep_miss': ''},
 'deal injury': {'dobj.prep_miss': ''},
 'deal loss': {'dobj.prep_miss': ''},
 'deal man': {'dobj.prep_miss': ''},
 'deal offender': {'dobj.prep_miss': ''},
 'deal pain': {'dobj.prep_miss': ''},
 'deal patient': {'dobj.prep_miss': ''},
 'deal people': {'dobj.prep_miss': ''},
 'deal product': {'dobj.prep_miss': ''},
 'deal situation': {'dobj.prep_miss': ''},
 'deal student': {'dobj.prep_miss': ''},
 'deal terrorism': {'dobj.prep_miss': ''},
 'deal threat': {'dobj.prep_miss': ''},
 'deal violence': {'dobj.prep_miss': ''},
 'deal waste': {'dobj.prep_miss': ''},
 'decide month': {'dobj.prep_miss': ''},
 'decide proposal': {'dobj.prep_miss': ''},
 'decide surgery': {'dobj.prep_miss': ''},
 'decorate flag': {'dobj.prep_miss': ''},
 'decorate flower': {'dobj.prep_miss': ''},
 'decorate picture': {'dobj.prep_miss': ''},
 'dedicate memory': {'dobj.prep_miss': ''},
 'default loan': {'dobj.prep_miss': ''},
 'default payment': {'dobj.prep_miss': ''},
 'defeat election': {'dobj.prep_miss': ''},
 'defend accusation': {'dobj.prep_miss': ''},
 'defend allegation': {'dobj.prep_miss': ''},
 'defend criticism': {'dobj.prep_miss': ''},
 'deliver house': {'dobj.prep_miss': ''},
 'deliver office': {'dobj.prep_miss': ''},
 'deliver pledge': {'dobj.prep_miss': ''},
 'demonstrate city': {'dobj.prep_miss': ''},
 'demonstrate government': {'dobj.prep_miss': ''},
 'deny court': {'dobj.prep_miss': ''},
 'depart airport': {'dobj.prep_miss': ''},
 'depend country': {'dobj.prep_miss': ''},
 'depend direction': {'dobj.prep_miss': ''},
 'depend level': {'dobj.prep_miss': ''},
 'depend mood': {'dobj.prep_miss': ''},
 'depend nature': {'dobj.prep_miss': ''},
 'depend number': {'dobj.prep_miss': ''},
 'depend quality': {'dobj.prep_miss': ''},
 'depend success': {'dobj.prep_miss': ''},
 'depend type': {'dobj.prep_miss': ''},
 'deploy capital': {'dobj.prep_miss': ''},
 'deploy part': {'dobj.prep_miss': ''},
 'deploy site': {'dobj.prep_miss': ''},
 'deprive right': {'dobj.prep_miss': ''},
 'deprive sleep': {'dobj.prep_miss': ''},
 'describe chapter': {'dobj.prep_miss': ''},
 'design people': {'dobj.prep_miss': ''},
 'design woman': {'dobj.prep_miss': ''},
 'designate assignment': {'dobj.prep_miss': ''},
 'destine export': {'dobj.prep_miss': ''},
 'destroy fire': {'dobj.prep_miss': ''},
 'destroy war': {'dobj.prep_miss': ''},
 'develop time': {'dobj.prep_miss': ''},
 'develop year': {'dobj.prep_miss': ''},
 'devote discussion': {'dobj.prep_miss': ''},
 'devote study': {'dobj.prep_miss': ''},
 'diagnose lymphoma': {'dobj.prep_miss': ''},
 'diagnose schizophrenia': {'dobj.prep_miss': ''},
 'die car': {'dobj.prep_miss': ''},
 'die house': {'dobj.prep_miss': ''},
 'differ country': {'dobj.prep_miss': ''},
 'differ number': {'dobj.prep_miss': ''},
 'dig ground': {'dobj.prep_miss': ''},
 'dip chocolate': {'dobj.prep_miss': ''},
 'discriminate people': {'dobj.prep_miss': ''},
 'discuss chapter': {'dobj.prep_miss': ''},
 'discuss depth': {'dobj.prep_miss': ''},
 'discuss official': {'dobj.prep_miss': ''},
 'dismiss army': {'dobj.prep_miss': ''},
 'dispose body': {'dobj.prep_miss': ''},
 'dissolve water': {'dobj.prep_miss': ''},
 'distribute country': {'dobj.prep_miss': ''},
 'distribute member': {'dobj.prep_miss': ''},
 'dive water': {'dobj.prep_miss': ''},
 'divide part': {'dobj.prep_miss': ''},
 'divide phase': {'dobj.prep_miss': ''},
 'divide plate': {'dobj.prep_miss': ''},
 'divide sector': {'dobj.prep_miss': ''},
 'divide segment': {'dobj.prep_miss': ''},
 'divide unit': {'dobj.prep_miss': ''},
 'divide zone': {'dobj.prep_miss': ''},
 'do ability': {'dobj.prep_miss': ''},
 'do animal': {'dobj.prep_miss': ''},
 'do attack': {'dobj.prep_miss': ''},
 'do confidence': {'dobj.prep_miss': ''},
 'do economics': {'dobj.prep_miss': ''},
 'do effort': {'dobj.prep_miss': ''},
 'do fear': {'dobj.prep_miss': ''},
 'do information': {'dobj.prep_miss': ''},
 'do property': {'dobj.prep_miss': ''},
 'do talent': {'dobj.prep_miss': ''},
 'do terrorism': {'dobj.prep_miss': ''},
 'do victory': {'dobj.prep_miss': ''},
 'do voter': {'dobj.prep_miss': ''},
 'do water': {'dobj.prep_miss': ''},
 'do weapon': {'dobj.prep_miss': ''},
 'donate campaign': {'dobj.prep_miss': ''},
 'donate charity': {'dobj.prep_miss': ''},
 'donate museum': {'dobj.prep_miss': ''},
 'donate organization': {'dobj.prep_miss': ''},
 'donate school': {'dobj.prep_miss': ''},
 'draw conflict': {'dobj.prep_miss': ''},
 'draw discussion': {'dobj.prep_miss': ''},
 'draw well': {'dobj.prep_miss': ''},
 'drink death': {'dobj.prep_miss': ''},
 'drive edge': {'dobj.prep_miss': ''},
 'drive freeway': {'dobj.prep_miss': ''},
 'drive garage': {'dobj.prep_miss': ''},
 'drive gate': {'dobj.prep_miss': ''},
 'drop hole': {'dobj.prep_miss': ''},
 'drop news': {'dobj.prep_miss': ''},
 'drop race': {'dobj.prep_miss': ''},
 'drop zero': {'dobj.prep_miss': ''},
 'eat hand': {'dobj.prep_miss': ''},
 'eat profit': {'dobj.prep_miss': ''},
 'elaborate point': {'dobj.prep_miss': ''},
 'elaborate reason': {'dobj.prep_miss': ''},
 'elaborate statement': {'dobj.prep_miss': ''},
 'end disaster': {'dobj.prep_miss': ''},
 'end draw': {'dobj.prep_miss': ''},
 'end failure': {'dobj.prep_miss': ''},
 'end result': {'dobj.prep_miss': ''},
 'end tragedy': {'dobj.prep_miss': ''},
 'engage action': {'dobj.prep_miss': ''},
 'engage activity': {'dobj.prep_miss': ''},
 'engage battle': {'dobj.prep_miss': ''},
 'engage business': {'dobj.prep_miss': ''},
 'engage combat': {'dobj.prep_miss': ''},
 'engage conduct': {'dobj.prep_miss': ''},
 'engage conversation': {'dobj.prep_miss': ''},
 'engage debate': {'dobj.prep_miss': ''},
 'engage dialogue': {'dobj.prep_miss': ''},
 'engage discussion': {'dobj.prep_miss': ''},
 'engage practice': {'dobj.prep_miss': ''},
 'engage work': {'dobj.prep_miss': ''},
 'enroll class': {'dobj.prep_miss': ''},
 'enroll college': {'dobj.prep_miss': ''},
 'enroll course': {'dobj.prep_miss': ''},
 'enroll program': {'dobj.prep_miss': ''},
 'enroll school': {'dobj.prep_miss': ''},
 'enshrine law': {'dobj.prep_miss': ''},
 'enter arrangement': {'dobj.prep_miss': ''},
 'enter database': {'dobj.prep_miss': ''},
 'enter force': {'dobj.prep_miss': ''},
 'escape darkness': {'dobj.prep_miss': ''},
 'evolve time': {'dobj.prep_miss': ''},
 'excel school': {'dobj.prep_miss': ''},
 'excel sport': {'dobj.prep_miss': ''},
 'excrete urine': {'dobj.prep_miss': ''},
 'exempt rule': {'dobj.prep_miss': ''},
 'exist area': {'dobj.prep_miss': ''},
 'exist form': {'dobj.prep_miss': ''},
 'exist level': {'dobj.prep_miss': ''},
 'exist world': {'dobj.prep_miss': ''},
 'expand region': {'dobj.prep_miss': ''},
 'expel school': {'dobj.prep_miss': ''},
 'explain child': {'dobj.prep_miss': ''},
 'explain people': {'dobj.prep_miss': ''},
 'explain public': {'dobj.prep_miss': ''},
 'explode market': {'dobj.prep_miss': ''},
 'expose danger': {'dobj.prep_miss': ''},
 'expose risk': {'dobj.prep_miss': ''},
 'expose sun': {'dobj.prep_miss': ''},
 'express percentage': {'dobj.prep_miss': ''},
 'extend country': {'dobj.prep_miss': ''},
 'extend weekend': {'dobj.prep_miss': ''},
 'fade black': {'dobj.prep_miss': ''},
 'fail score': {'dobj.prep_miss': ''},
 'fall city': {'dobj.prep_miss': ''},
 'fall demand': {'dobj.prep_miss': ''},
 'fall edge': {'dobj.prep_miss': ''},
 'fall face': {'dobj.prep_miss': ''},
 'fall goal': {'dobj.prep_miss': ''},
 'fall power': {'dobj.prep_miss': ''},
 'fall rain': {'dobj.prep_miss': ''},
 'fall rate': {'dobj.prep_miss': ''},
 'fall river': {'dobj.prep_miss': ''},
 'fall snow': {'dobj.prep_miss': ''},
 'fall standard': {'dobj.prep_miss': ''},
 'fall step': {'dobj.prep_miss': ''},
 'fall sword': {'dobj.prep_miss': ''},
 'fall tree': {'dobj.prep_miss': ''},
 'feature cover': {'dobj.prep_miss': ''},
 'feel family': {'dobj.prep_miss': ''},
 'feel home': {'dobj.prep_miss': ''},
 'feel outsider': {'dobj.prep_miss': ''},
 'feel stranger': {'dobj.prep_miss': ''},
 'fight control': {'dobj.prep_miss': ''},
 'fight country': {'dobj.prep_miss': ''},
 'fight democracy': {'dobj.prep_miss': ''},
 'fight freedom': {'dobj.prep_miss': ''},
 'fight front': {'dobj.prep_miss': ''},
 'fight ground': {'dobj.prep_miss': ''},
 'fight independence': {'dobj.prep_miss': ''},
 'fight job': {'dobj.prep_miss': ''},
 'fight life': {'dobj.prep_miss': ''},
 'fight place': {'dobj.prep_miss': ''},
 'fight power': {'dobj.prep_miss': ''},
 'fight right': {'dobj.prep_miss': ''},
 'fight share': {'dobj.prep_miss': ''},
 'fight spot': {'dobj.prep_miss': ''},
 'fight title': {'dobj.prep_miss': ''},
 'file divorce': {'dobj.prep_miss': ''},
 'file seal': {'dobj.prep_miss': ''},
 'fill cash': {'dobj.prep_miss': ''},
 'fill family': {'dobj.prep_miss': ''},
 'fill fluid': {'dobj.prep_miss': ''},
 'fill food': {'dobj.prep_miss': ''},
 'fill gas': {'dobj.prep_miss': ''},
 'fill ice': {'dobj.prep_miss': ''},
 'fill information': {'dobj.prep_miss': ''},
 'fill mixture': {'dobj.prep_miss': ''},
 'fill photo': {'dobj.prep_miss': ''},
 'fill picture': {'dobj.prep_miss': ''},
 'fill player': {'dobj.prep_miss': ''},
 'fill sand': {'dobj.prep_miss': ''},
 'fill sound': {'dobj.prep_miss': ''},
 'fill water': {'dobj.prep_miss': ''},
 'fit pocket': {'dobj.prep_miss': ''},
 'float river': {'dobj.prep_miss': ''},
 'focus change': {'dobj.prep_miss': ''},
 'focus child': {'dobj.prep_miss': ''},
 'focus city': {'dobj.prep_miss': ''},
 'focus cooperation': {'dobj.prep_miss': ''},
 'focus country': {'dobj.prep_miss': ''},
 'focus customer': {'dobj.prep_miss': ''},
 'focus difference': {'dobj.prep_miss': ''},
 'focus drug': {'dobj.prep_miss': ''},
 'focus economy': {'dobj.prep_miss': ''},
 'focus effect': {'dobj.prep_miss': ''},
 'focus event': {'dobj.prep_miss': ''},
 'focus fact': {'dobj.prep_miss': ''},
 'focus family': {'dobj.prep_miss': ''},
 'focus fight': {'dobj.prep_miss': ''},
 'focus film': {'dobj.prep_miss': ''},
 'focus future': {'dobj.prep_miss': ''},
 'focus game': {'dobj.prep_miss': ''},
 'focus goal': {'dobj.prep_miss': ''},
 'focus growth': {'dobj.prep_miss': ''},
 'focus history': {'dobj.prep_miss': ''},
 'focus impact': {'dobj.prep_miss': ''},
 'focus importance': {'dobj.prep_miss': ''},
 'focus individual': {'dobj.prep_miss': ''},
 'focus industry': {'dobj.prep_miss': ''},
 'focus issue': {'dobj.prep_miss': ''},
 'focus job': {'dobj.prep_miss': ''},
 'focus man': {'dobj.prep_miss': ''},
 'focus matter': {'dobj.prep_miss': ''},
 'focus measure': {'dobj.prep_miss': ''},
 'focus member': {'dobj.prep_miss': ''},
 'focus music': {'dobj.prep_miss': ''},
 'focus negotiation': {'dobj.prep_miss': ''},
 'focus number': {'dobj.prep_miss': ''},
 'focus opportunity': {'dobj.prep_miss': ''},
 'focus part': {'dobj.prep_miss': ''},
 'focus performance': {'dobj.prep_miss': ''},
 'focus plan': {'dobj.prep_miss': ''},
 'focus point': {'dobj.prep_miss': ''},
 'focus policy': {'dobj.prep_miss': ''},
 'focus prevention': {'dobj.prep_miss': ''},
 'focus problem': {'dobj.prep_miss': ''},
 'focus process': {'dobj.prep_miss': ''},
 'focus product': {'dobj.prep_miss': ''},
 'focus project': {'dobj.prep_miss': ''},
 'focus quality': {'dobj.prep_miss': ''},
 'focus reform': {'dobj.prep_miss': ''},
 'focus region': {'dobj.prep_miss': ''},
 'focus relationship': {'dobj.prep_miss': ''},
 'focus report': {'dobj.prep_miss': ''},
 'focus result': {'dobj.prep_miss': ''},
 'focus return': {'dobj.prep_miss': ''},
 'focus role': {'dobj.prep_miss': ''},
 'focus sale': {'dobj.prep_miss': ''},
 'focus school': {'dobj.prep_miss': ''},
 'focus security': {'dobj.prep_miss': ''},
 'focus service': {'dobj.prep_miss': ''},
 'focus software': {'dobj.prep_miss': ''},
 'focus state': {'dobj.prep_miss': ''},
 'focus stock': {'dobj.prep_miss': ''},
 'focus strength': {'dobj.prep_miss': ''},
 'focus subject': {'dobj.prep_miss': ''},
 'focus task': {'dobj.prep_miss': ''},
 'focus technology': {'dobj.prep_miss': ''},
 'focus theme': {'dobj.prep_miss': ''},
 'focus thing': {'dobj.prep_miss': ''},
 'focus topic': {'dobj.prep_miss': ''},
 'focus trade': {'dobj.prep_miss': ''},
 'focus use': {'dobj.prep_miss': ''},
 'focus value': {'dobj.prep_miss': ''},
 'focus war': {'dobj.prep_miss': ''},
 'focus way': {'dobj.prep_miss': ''},
 'focus woman': {'dobj.prep_miss': ''},
 'force exile': {'dobj.prep_miss': ''},
 'force land': {'dobj.prep_miss': ''},
 'force slavery': {'dobj.prep_miss': ''},
 'free charge': {'dobj.prep_miss': ''},
 'free control': {'dobj.prep_miss': ''},
 'free prison': {'dobj.prep_miss': ''},
 'gain dollar': {'dobj.prep_miss': ''},
 'gather church': {'dobj.prep_miss': ''},
 'gather site': {'dobj.prep_miss': ''},
 'go account': {'dobj.prep_miss': ''},
 'go action': {'dobj.prep_miss': ''},
 'go bat': {'dobj.prep_miss': ''},
 'go battle': {'dobj.prep_miss': ''},
 'go bed': {'dobj.prep_miss': ''},
 'go block': {'dobj.prep_miss': ''},
 'go board': {'dobj.prep_miss': ''},
 'go camp': {'dobj.prep_miss': ''},
 'go college': {'dobj.prep_miss': ''},
 'go concert': {'dobj.prep_miss': ''},
 'go debt': {'dobj.prep_miss': ''},
 'go decision': {'dobj.prep_miss': ''},
 'go detail': {'dobj.prep_miss': ''},
 'go display': {'dobj.prep_miss': ''},
 'go doctor': {'dobj.prep_miss': ''},
 'go edge': {'dobj.prep_miss': ''},
 'go school': {'dobj.prep_miss': ''},
 'go sea': {'dobj.prep_miss': ''},
 'go title': {'dobj.prep_miss': ''},
 'go toilet': {'dobj.prep_miss': ''},
 'go tour': {'dobj.prep_miss': ''},
 'go town': {'dobj.prep_miss': ''},
 'go track': {'dobj.prep_miss': ''},
 'go tradition': {'dobj.prep_miss': ''},
 'go trip': {'dobj.prep_miss': ''},
 'go trouble': {'dobj.prep_miss': ''},
 'go university': {'dobj.prep_miss': ''},
 'go walk': {'dobj.prep_miss': ''},
 'graduate honor': {'dobj.prep_miss': ''},
 'graduate top': {'dobj.prep_miss': ''},
 'grin ear': {'dobj.prep_miss': ''},
 'grind halt': {'dobj.prep_miss': ''},
 'grow adult': {'dobj.prep_miss': ''},
 'grow popularity': {'dobj.prep_miss': ''},
 'guard attack': {'dobj.prep_miss': ''},
 'hang closet': {'dobj.prep_miss': ''},
 'hang effigy': {'dobj.prep_miss': ''},
 'hang locker': {'dobj.prep_miss': ''},
 'hang rack': {'dobj.prep_miss': ''},
 'hang side': {'dobj.prep_miss': ''},
 'hang thread': {'dobj.prep_miss': ''},
 'help crisis': {'dobj.prep_miss': ''},
 'hide sight': {'dobj.prep_miss': ''},
 'hit hammer': {'dobj.prep_miss': ''},
 'hit idea': {'dobj.prep_miss': ''},
 'hold bay': {'dobj.prep_miss': ''},
 'hold contempt': {'dobj.prep_miss': ''},
 'hold custody': {'dobj.prep_miss': ''},
 'hold detention': {'dobj.prep_miss': ''},
 'hold esteem': {'dobj.prep_miss': ''},
 'hold headquarters': {'dobj.prep_miss': ''},
 'hold location': {'dobj.prep_miss': ''},
 'hold trust': {'dobj.prep_miss': ''},
 'hope approval': {'dobj.prep_miss': ''},
 'improve age': {'dobj.prep_miss': '', 'e_trp.nsv': ''},
 'increase age': {'dobj.prep_miss': ''},
 'inherit parent': {'dobj.prep_miss': ''},
 'insure loss': {'dobj.prep_miss': ''},
 'intend sale': {'dobj.prep_miss': ''},
 'introduce crowd': {'dobj.prep_miss': ''},
 'introduce trial': {'dobj.prep_miss': ''},
 'invest bond': {'dobj.prep_miss': ''},
 'invest business': {'dobj.prep_miss': ''},
 'invest country': {'dobj.prep_miss': ''},
 'invest education': {'dobj.prep_miss': ''},
 'invest market': {'dobj.prep_miss': ''},
 'invest property': {'dobj.prep_miss': ''},
 'invest research': {'dobj.prep_miss': ''},
 'invest security': {'dobj.prep_miss': ''},
 'invest stock': {'dobj.prep_miss': ''},
 'invest technology': {'dobj.prep_miss': ''},
 'invest venture': {'dobj.prep_miss': ''},
 'invite meeting': {'dobj.prep_miss': ''},
 'involve abortion': {'dobj.prep_miss': ''},
 'involve affair': {'dobj.prep_miss': ''},
 'involve assassination': {'dobj.prep_miss': ''},
 'involve controversy': {'dobj.prep_miss': ''},
 'involve crash': {'dobj.prep_miss': ''},
 'involve inquiry': {'dobj.prep_miss': ''},
 'involve kidnapping': {'dobj.prep_miss': ''},
 'join hip': {'dobj.prep_miss': ''},
 'jump hoop': {'dobj.prep_miss': ''},
 'jump page': {'dobj.prep_miss': ''},
 'keep bay': {'dobj.prep_miss': ''},
 'keep loop': {'dobj.prep_miss': ''},
 'keep minimum': {'dobj.prep_miss': ''},
 'keep observation': {'dobj.prep_miss': ''},
 'kick gear': {'dobj.prep_miss': ''},
 'kill bombing': {'dobj.prep_miss': ''},
 'kill crash': {'dobj.prep_miss': ''},
 'land base': {'dobj.prep_miss': ''},
 'land runway': {'dobj.prep_miss': ''},
 'launch space': {'dobj.prep_miss': ''},
 'lay arm': {'dobj.prep_miss': ''},
 'lay floor': {'dobj.prep_miss': ''},
 'lay side': {'dobj.prep_miss': ''},
 'lay staff': {'dobj.prep_miss': ''},
 'lead complaint': {'dobj.prep_miss': ''},
 'lead conclusion': {'dobj.prep_miss': ''},
 'lead consolidation': {'dobj.prep_miss': ''},
 'lead death': {'dobj.prep_miss': ''},
 'lead example': {'dobj.prep_miss': ''},
 'lead impeachment': {'dobj.prep_miss': ''},
 'lead independence': {'dobj.prep_miss': ''},
 'lead injury': {'dobj.prep_miss': ''},
 'lead suicide': {'dobj.prep_miss': ''},
 'learn mistake': {'dobj.prep_miss': ''},
 'leave discretion': {'dobj.prep_miss': ''},
 'leave dust': {'dobj.prep_miss': ''},
 'leave peace': {'dobj.prep_miss': ''},
 'let steam': {'dobj.prep_miss': ''},
 'lie beach': {'dobj.prep_miss': ''},
 'lie edge': {'dobj.prep_miss': ''},
 'lie floor': {'dobj.prep_miss': ''},
 'lie heart': {'dobj.prep_miss': ''},
 'lie pile': {'dobj.prep_miss': ''},
 'lie range': {'dobj.prep_miss': ''},
 'lie root': {'dobj.prep_miss': ''},
 'lie ruin': {'dobj.prep_miss': ''},
 'lie shadow': {'dobj.prep_miss': ''},
 'lie side': {'dobj.prep_miss': ''},
 'lie top': {'dobj.prep_miss': ''},
 'lie way': {'dobj.prep_miss': ''},
 'lift ground': {'dobj.prep_miss': ''},
 'listen news': {'dobj.prep_miss': ''},
 'listen people': {'dobj.prep_miss': ''},
 'listen radio': {'dobj.prep_miss': ''},
 'live apartment': {'dobj.prep_miss': ''},
 'live city': {'dobj.prep_miss': ''},
 'live coast': {'dobj.prep_miss': ''},
 'live country': {'dobj.prep_miss': ''},
 'live county': {'dobj.prep_miss': ''},
 'live fear': {'dobj.prep_miss': ''},
 'live mean': {'dobj.prep_miss': ''},
 'live poverty': {'dobj.prep_miss': ''},
 'live rule': {'dobj.prep_miss': ''},
 'live wild': {'dobj.prep_miss': ''},
 'major business': {'dobj.prep_miss': ''},
 'mate life': {'dobj.prep_miss': ''},
 'meet airport': {'dobj.prep_miss': ''},
 'meet private': {'dobj.prep_miss': ''},
 'mount side': {'dobj.prep_miss': ''},
 'move front': {'dobj.prep_miss': ''},
 'move tear': {'dobj.prep_miss': ''},
 'operate law': {'dobj.prep_miss': ''},
 'operate name': {'dobj.prep_miss': ''},
 'operate night': {'dobj.prep_miss': ''},
 'operate patient': {'dobj.prep_miss': ''},
 'operate permit': {'dobj.prep_miss': ''},
 'operate protection': {'dobj.prep_miss': ''},
 'operate rule': {'dobj.prep_miss': ''},
 'operate speed': {'dobj.prep_miss': ''},
 'operate staff': {'dobj.prep_miss': ''},
 'operate vacuum': {'dobj.prep_miss': ''},
 'operate world': {'dobj.prep_miss': ''},
 'order country': {'dobj.prep_miss': ''},
 'order home': {'dobj.prep_miss': ''},
 'order restaurant': {'dobj.prep_miss': ''},
 'pack container': {'dobj.prep_miss': ''},
 'pack trip': {'dobj.prep_miss': ''},
 'park building': {'dobj.prep_miss': ''},
 'park corner': {'dobj.prep_miss': ''},
 'park entrance': {'dobj.prep_miss': ''},
 'park hotel': {'dobj.prep_miss': ''},
 'park house': {'dobj.prep_miss': ''},
 'park road': {'dobj.prep_miss': ''},
 'park street': {'dobj.prep_miss': ''},
 'part money': {'dobj.prep_miss': ''},
 'participate activity': {'dobj.prep_miss': ''},
 'participate conference': {'dobj.prep_miss': ''},
 'participate discussion': {'dobj.prep_miss': ''},
 'participate event': {'dobj.prep_miss': ''},
 'participate meeting': {'dobj.prep_miss': ''},
 'participate program': {'dobj.prep_miss': ''},
 'participate project': {'dobj.prep_miss': ''},
 'participate research': {'dobj.prep_miss': ''},
 'participate sport': {'dobj.prep_miss': ''},
 'participate survey': {'dobj.prep_miss': ''},
 'pass consumer': {'dobj.prep_miss': ''},
 'pass customer': {'dobj.prep_miss': ''},
 'pass father': {'dobj.prep_miss': ''},
 'pass generation': {'dobj.prep_miss': ''},
 'pass human': {'dobj.prep_miss': ''},
 'pass mother': {'dobj.prep_miss': ''},
 'pass person': {'dobj.prep_miss': ''},
 'pass south': {'dobj.prep_miss': ''},
 'pause second': {'dobj.prep_miss': ''},
 'pay acquisition': {'dobj.prep_miss': ''},
 'pay ad': {'dobj.prep_miss': ''},
 'pay advertisement': {'dobj.prep_miss': ''},
 'pay advertising': {'dobj.prep_miss': ''},
 'pay book': {'dobj.prep_miss': ''},
 'pay building': {'dobj.prep_miss': ''},
 'pay car': {'dobj.prep_miss': ''},
 'pay care': {'dobj.prep_miss': ''},
 'pay college': {'dobj.prep_miss': ''},
 'pay construction': {'dobj.prep_miss': ''},
 'pay coverage': {'dobj.prep_miss': ''},
 'pay day': {'dobj.prep_miss': ''},
 'pay delivery': {'dobj.prep_miss': ''},
 'pay education': {'dobj.prep_miss': ''},
 'pay electricity': {'dobj.prep_miss': ''},
 'pay equipment': {'dobj.prep_miss': ''},
 'pay flight': {'dobj.prep_miss': ''},
 'pay funeral': {'dobj.prep_miss': ''},
 'pay gas': {'dobj.prep_miss': ''},
 'pay goods': {'dobj.prep_miss': ''},
 'pay hour': {'dobj.prep_miss': ''},
 'pay house': {'dobj.prep_miss': ''},
 'pay import': {'dobj.prep_miss': ''},
 'pay improvement': {'dobj.prep_miss': ''},
 'pay information': {'dobj.prep_miss': ''},
 'pay item': {'dobj.prep_miss': ''},
 'pay land': {'dobj.prep_miss': ''},
 'pay license': {'dobj.prep_miss': ''},
 'pay material': {'dobj.prep_miss': ''},
 'pay meal': {'dobj.prep_miss': ''},
 'pay oil': {'dobj.prep_miss': ''},
 'pay operation': {'dobj.prep_miss': ''},
 'pay power': {'dobj.prep_miss': ''},
 'pay prescription': {'dobj.prep_miss': ''},
 'pay product': {'dobj.prep_miss': ''},
 'pay program': {'dobj.prep_miss': ''},
 'pay project': {'dobj.prep_miss': ''},
 'pay property': {'dobj.prep_miss': ''},
 'pay repair': {'dobj.prep_miss': ''},
 'pay research': {'dobj.prep_miss': ''},
 'pay room': {'dobj.prep_miss': ''},
 'pay sex': {'dobj.prep_miss': ''},
 'pay supply': {'dobj.prep_miss': ''},
 'pay system': {'dobj.prep_miss': ''},
 'pay test': {'dobj.prep_miss': ''},
 'pay thing': {'dobj.prep_miss': ''},
 'pay training': {'dobj.prep_miss': ''},
 'pay transaction': {'dobj.prep_miss': ''},
 'pay transportation': {'dobj.prep_miss': ''},
 'pay treatment': {'dobj.prep_miss': ''},
 'pay upkeep': {'dobj.prep_miss': ''},
 'pay use': {'dobj.prep_miss': ''},
 'pay war': {'dobj.prep_miss': ''},
 'pay water': {'dobj.prep_miss': ''},
 'perform band': {'dobj.prep_miss': ''},
 'perform club': {'dobj.prep_miss': ''},
 'perform country': {'dobj.prep_miss': ''},
 'perform expectation': {'dobj.prep_miss': ''},
 'perform group': {'dobj.prep_miss': ''},
 'perform level': {'dobj.prep_miss': ''},
 'perform pressure': {'dobj.prep_miss': ''},
 'perform public': {'dobj.prep_miss': ''},
 'perform stage': {'dobj.prep_miss': ''},
 'perform time': {'dobj.prep_miss': ''},
 'permit rule': {'dobj.prep_miss': ''},
 'place protection': {'dobj.prep_miss': ''},
 'place quarantine': {'dobj.prep_miss': ''},
 'place wall': {'dobj.prep_miss': ''},
 'plague problem': {'dobj.prep_miss': ''},
 'plan spring': {'dobj.prep_miss': ''},
 'plan today': {'dobj.prep_miss': ''},
 'play arena': {'dobj.prep_miss': ''},
 'play background': {'dobj.prep_miss': ''},
 'play beach': {'dobj.prep_miss': ''},
 'play car': {'dobj.prep_miss': ''},
 'play clay': {'dobj.prep_miss': ''},
 'play dog': {'dobj.prep_miss': ''},
 'play doll': {'dobj.prep_miss': ''},
 'play emotion': {'dobj.prep_miss': ''},
 'play fire': {'dobj.prep_miss': ''},
 'play fun': {'dobj.prep_miss': ''},
 'play grass': {'dobj.prep_miss': ''},
 'play home': {'dobj.prep_miss': ''},
 'play ice': {'dobj.prep_miss': ''},
 'play importance': {'dobj.prep_miss': ''},
 'play incident': {'dobj.prep_miss': ''},
 'play light': {'dobj.prep_miss': ''},
 'play morning': {'dobj.prep_miss': ''},
 'play park': {'dobj.prep_miss': ''},
 'play possibility': {'dobj.prep_miss': ''},
 'play pressure': {'dobj.prep_miss': ''},
 'play public': {'dobj.prep_miss': ''},
 'play rain': {'dobj.prep_miss': ''},
 'play road': {'dobj.prep_miss': ''},
 'play room': {'dobj.prep_miss': ''},
 'play stage': {'dobj.prep_miss': ''},
 'play start': {'dobj.prep_miss': ''},
 'play street': {'dobj.prep_miss': ''},
 'play summer': {'dobj.prep_miss': ''},
 'play television': {'dobj.prep_miss': ''},
 'play threat': {'dobj.prep_miss': ''},
 'play town': {'dobj.prep_miss': ''},
 'play toy': {'dobj.prep_miss': ''},
 'play water': {'dobj.prep_miss': ''},
 'play while': {'dobj.prep_miss': ''},
 'play world': {'dobj.prep_miss': ''},
 'play yard': {'dobj.prep_miss': ''},
 'pledge collateral': {'dobj.prep_miss': ''},
 'point area': {'dobj.prep_miss': ''},
 'point fact': {'dobj.prep_miss': ''},
 'point growth': {'dobj.prep_miss': ''},
 'point head': {'dobj.prep_miss': ''},
 'point history': {'dobj.prep_miss': ''},
 'point need': {'dobj.prep_miss': ''},
 'point picture': {'dobj.prep_miss': ''},
 'point possibility': {'dobj.prep_miss': ''},
 'point problem': {'dobj.prep_miss': ''},
 'point project': {'dobj.prep_miss': ''},
 'point reason': {'dobj.prep_miss': ''},
 'point report': {'dobj.prep_miss': ''},
 'point series': {'dobj.prep_miss': ''},
 'point sign': {'dobj.prep_miss': ''},
 'point spot': {'dobj.prep_miss': ''},
 'point strength': {'dobj.prep_miss': ''},
 'point study': {'dobj.prep_miss': ''},
 'point success': {'dobj.prep_miss': ''},
 'pose photo': {'dobj.prep_miss': ''},
 'pose photograph': {'dobj.prep_miss': ''},
 'pose picture': {'dobj.prep_miss': ''},
 'postpone week': {'dobj.prep_miss': ''},
 'postpone year': {'dobj.prep_miss': ''},
 'pour bowl': {'dobj.prep_miss': ''},
 'pour house': {'dobj.prep_miss': ''},
 'pour window': {'dobj.prep_miss': ''},
 'practice team': {'dobj.prep_miss': ''},
 'pray family': {'dobj.prep_miss': ''},
 'pray peace': {'dobj.prep_miss': ''},
 'prepare battle': {'dobj.prep_miss': ''},
 'prepare career': {'dobj.prep_miss': ''},
 'prepare college': {'dobj.prep_miss': ''},
 'prepare conference': {'dobj.prep_miss': ''},
 'prepare day': {'dobj.prep_miss': ''},
 'prepare delivery': {'dobj.prep_miss': ''},
 'prepare deployment': {'dobj.prep_miss': ''},
 'prepare disaster': {'dobj.prep_miss': ''},
 'prepare event': {'dobj.prep_miss': ''},
 'prepare exam': {'dobj.prep_miss': ''},
 'prepare funeral': {'dobj.prep_miss': ''},
 'prepare future': {'dobj.prep_miss': ''},
 'prepare game': {'dobj.prep_miss': ''},
 'prepare job': {'dobj.prep_miss': ''},
 'prepare life': {'dobj.prep_miss': ''},
 'prepare membership': {'dobj.prep_miss': ''},
 'prepare negotiation': {'dobj.prep_miss': ''},
 'prepare publication': {'dobj.prep_miss': ''},
 'prepare race': {'dobj.prep_miss': ''},
 'prepare start': {'dobj.prep_miss': ''},
 'prepare strike': {'dobj.prep_miss': ''},
 'prepare talk': {'dobj.prep_miss': ''},
 'prepare trial': {'dobj.prep_miss': ''},
 'prepare war': {'dobj.prep_miss': ''},
 'present ceremony': {'dobj.prep_miss': ''},
 'present form': {'dobj.prep_miss': ''},
 'present meeting': {'dobj.prep_miss': ''},
 'press access': {'dobj.prep_miss': ''},
 'press change': {'dobj.prep_miss': ''},
 'press talk': {'dobj.prep_miss': ''},
 'prevent doing': {'dobj.prep_miss': ''},
 'produce factory': {'dobj.prep_miss': ''},
 'promote chief': {'dobj.prep_miss': ''},
 'promote minister': {'dobj.prep_miss': ''},
 'promote post': {'dobj.prep_miss': ''},
 'promote president': {'dobj.prep_miss': ''},
 'promote rank': {'dobj.prep_miss': ''},
 'protect abuse': {'dobj.prep_miss': ''},
 'protect cancer': {'dobj.prep_miss': ''},
 'protect damage': {'dobj.prep_miss': ''},
 'protect development': {'dobj.prep_miss': ''},
 'protect effect': {'dobj.prep_miss': ''},
 'protect element': {'dobj.prep_miss': ''},
 'protect law': {'dobj.prep_miss': ''},
 'protect loss': {'dobj.prep_miss': ''},
 'protect rain': {'dobj.prep_miss': ''},
 'protect risk': {'dobj.prep_miss': ''},
 'protect sun': {'dobj.prep_miss': ''},
 'protect threat': {'dobj.prep_miss': ''},
 'prove world': {'dobj.prep_miss': ''},
 'provide creation': {'dobj.prep_miss': ''},
 'provide election': {'dobj.prep_miss': ''},
 'provide establishment': {'dobj.prep_miss': ''},
 'publish country': {'dobj.prep_miss': ''},
 'publish form': {'dobj.prep_miss': ''},
 'publish time': {'dobj.prep_miss': ''},
 'publish week': {'dobj.prep_miss': ''},
 'publish world': {'dobj.prep_miss': ''},
 'publish year': {'dobj.prep_miss': ''},
 'pull area': {'dobj.prep_miss': ''},
 'pull building': {'dobj.prep_miss': ''},
 'pull floor': {'dobj.prep_miss': ''},
 'pull ground': {'dobj.prep_miss': ''},
 'pull point': {'dobj.prep_miss': ''},
 'pull road': {'dobj.prep_miss': ''},
 'pull shelf': {'dobj.prep_miss': ''},
 'pull station': {'dobj.prep_miss': ''},
 'pull talk': {'dobj.prep_miss': ''},
 'punch face': {'dobj.prep_miss': ''},
 'purchase store': {'dobj.prep_miss': ''},
 'push access': {'dobj.prep_miss': ''},
 'push approval': {'dobj.prep_miss': ''},
 'push background': {'dobj.prep_miss': ''},
 'push integration': {'dobj.prep_miss': ''},
 'push job': {'dobj.prep_miss': ''},
 'push right': {'dobj.prep_miss': ''},
 'put alert': {'dobj.prep_miss': ''},
 'put ambulance': {'dobj.prep_miss': ''},
 'put cage': {'dobj.prep_miss': ''},
 'put category': {'dobj.prep_miss': ''},
 'put context': {'dobj.prep_miss': ''},
 'put corner': {'dobj.prep_miss': ''},
 'put ease': {'dobj.prep_miss': ''},
 'put effect': {'dobj.prep_miss': ''},
 'put field': {'dobj.prep_miss': ''},
 'put ground': {'dobj.prep_miss': ''},
 'put jail': {'dobj.prep_miss': ''},
 'put microscope': {'dobj.prep_miss': ''},
 'put oven': {'dobj.prep_miss': ''},
 'put pocket': {'dobj.prep_miss': ''},
 'put protection': {'dobj.prep_miss': ''},
 'put rebellion': {'dobj.prep_miss': ''},
 'put refrigerator': {'dobj.prep_miss': ''},
 'put retirement': {'dobj.prep_miss': ''},
 'put shelf': {'dobj.prep_miss': ''},
 'put stage': {'dobj.prep_miss': ''},
 'put street': {'dobj.prep_miss': ''},
 'put surveillance': {'dobj.prep_miss': ''},
 'put uniform': {'dobj.prep_miss': ''},
 'qualify aid': {'dobj.prep_miss': ''},
 'qualify assistance': {'dobj.prep_miss': ''},
 'qualify credit': {'dobj.prep_miss': ''},
 'qualify job': {'dobj.prep_miss': ''},
 'qualify mortgage': {'dobj.prep_miss': ''},
 'qualify payment': {'dobj.prep_miss': ''},
 'qualify program': {'dobj.prep_miss': ''},
 'qualify status': {'dobj.prep_miss': ''},
 'question death': {'dobj.prep_miss': ''},
 'quit end': {'dobj.prep_miss': ''},
 'quote context': {'dobj.prep_miss': ''},
 'rally government': {'dobj.prep_miss': ''},
 'reach detail': {'dobj.prep_miss': ''},
 'reach gun': {'dobj.prep_miss': ''},
 'reach phone': {'dobj.prep_miss': ''},
 'reach sky': {'dobj.prep_miss': ''},
 'reach star': {'dobj.prep_miss': ''},
 'reach time': {'dobj.prep_miss': ''},
 'read bed': {'dobj.prep_miss': ''},
 'read pleasure': {'dobj.prep_miss': ''},
 'recover shock': {'dobj.prep_miss': ''},
 'refer article': {'dobj.prep_miss': ''},
 'refer company': {'dobj.prep_miss': ''},
 'refer court': {'dobj.prep_miss': ''},
 'refer fact': {'dobj.prep_miss': ''},
 'refer letter': {'dobj.prep_miss': ''},
 'refer meeting': {'dobj.prep_miss': ''},
 'refer number': {'dobj.prep_miss': ''},
 'refer plan': {'dobj.prep_miss': ''},
 'refer statement': {'dobj.prep_miss': ''},
 'refer study': {'dobj.prep_miss': ''},
 'refer treatment': {'dobj.prep_miss': ''},
 'regard leader': {'dobj.prep_miss': ''},
 'register city': {'dobj.prep_miss': ''},
 'relate audit': {'dobj.prep_miss': ''},
 'relate conflict': {'dobj.prep_miss': ''},
 'relate dispute': {'dobj.prep_miss': ''},
 'relate drug': {'dobj.prep_miss': ''},
 'relate effort': {'dobj.prep_miss': ''},
 'relate job': {'dobj.prep_miss': ''},
 'relate operation': {'dobj.prep_miss': ''},
 'relate sale': {'dobj.prep_miss': ''},
 'relate sport': {'dobj.prep_miss': ''},
 'relate tension': {'dobj.prep_miss': ''},
 'relate terrorism': {'dobj.prep_miss': ''},
 'relate transaction': {'dobj.prep_miss': ''},
 'relate use': {'dobj.prep_miss': ''},
 'relate war': {'dobj.prep_miss': ''},
 'release custody': {'dobj.prep_miss': ''},
 'release duty': {'dobj.prep_miss': ''},
 'release prison': {'dobj.prep_miss': ''},
 'release wild': {'dobj.prep_miss': ''},
 'remain consideration': {'dobj.prep_miss': ''},
 'remain doubt': {'dobj.prep_miss': ''},
 'remain force': {'dobj.prep_miss': ''},
 'remain memory': {'dobj.prep_miss': ''},
 'remain operation': {'dobj.prep_miss': ''},
 'remain possession': {'dobj.prep_miss': ''},
 'remain range': {'dobj.prep_miss': ''},
 'remain risk': {'dobj.prep_miss': ''},
 'represent summit': {'dobj.prep_miss': ''},
 'resign government': {'dobj.prep_miss': ''},
 'resign head': {'dobj.prep_miss': ''},
 'resign president': {'dobj.prep_miss': ''},
 'respond comment': {'dobj.prep_miss': ''},
 'respond complaint': {'dobj.prep_miss': ''},
 'respond demand': {'dobj.prep_miss': ''},
 'respond inquiry': {'dobj.prep_miss': ''},
 'respond issue': {'dobj.prep_miss': ''},
 'respond letter': {'dobj.prep_miss': ''},
 'respond message': {'dobj.prep_miss': ''},
 'respond need': {'dobj.prep_miss': ''},
 'respond offer': {'dobj.prep_miss': ''},
 'respond query': {'dobj.prep_miss': ''},
 'respond question': {'dobj.prep_miss': ''},
 'respond request': {'dobj.prep_miss': ''},
 'result agreement': {'dobj.prep_miss': ''},
 'result change': {'dobj.prep_miss': ''},
 'result damage': {'dobj.prep_miss': ''},
 'result death': {'dobj.prep_miss': ''},
 'result decline': {'dobj.prep_miss': ''},
 'result development': {'dobj.prep_miss': '', 'e_trp.nsv': ''},
 'result growth': {'dobj.prep_miss': ''},
 'result improvement': {'dobj.prep_miss': ''},
 'result increase': {'dobj.prep_miss': ''},
 'result injury': {'dobj.prep_miss': ''},
 'result loss': {'dobj.prep_miss': ''},
 'result reduction': {'dobj.prep_miss': ''},
 'retire service': {'dobj.prep_miss': ''},
 'return airport': {'dobj.prep_miss': ''},
 'return apartment': {'dobj.prep_miss': ''},
 'return bank': {'dobj.prep_miss': ''},
 'return beach': {'dobj.prep_miss': ''},
 'return cell': {'dobj.prep_miss': ''},
 'return church': {'dobj.prep_miss': ''},
 'return circuit': {'dobj.prep_miss': ''},
 'return class': {'dobj.prep_miss': ''},
 'return college': {'dobj.prep_miss': ''},
 'return community': {'dobj.prep_miss': ''},
 'return court': {'dobj.prep_miss': ''},
 'return custody': {'dobj.prep_miss': ''},
 'return earth': {'dobj.prep_miss': ''},
 'return normal': {'dobj.prep_miss': ''},
 'return normalcy': {'dobj.prep_miss': ''},
 'return office': {'dobj.prep_miss': ''},
 'return operation': {'dobj.prep_miss': ''},
 'return owner': {'dobj.prep_miss': ''},
 'return parent': {'dobj.prep_miss': ''},
 'return root': {'dobj.prep_miss': ''},
 'return school': {'dobj.prep_miss': ''},
 'return society': {'dobj.prep_miss': ''},
 'return top': {'dobj.prep_miss': ''},
 'ring hook': {'dobj.prep_miss': ''},
 'rise air': {'dobj.prep_miss': ''},
 'rise ash': {'dobj.prep_miss': ''},
 'rise power': {'dobj.prep_miss': ''},
 'rise top': {'dobj.prep_miss': ''},
 'roll tongue': {'dobj.prep_miss': ''},
 'run background': {'dobj.prep_miss': ''},
 'run capacity': {'dobj.prep_miss': ''},
 'run control': {'dobj.prep_miss': ''},
 'run fuel': {'dobj.prep_miss': ''},
 'run gas': {'dobj.prep_miss': ''},
 'run petrol': {'dobj.prep_miss': ''},
 'run power': {'dobj.prep_miss': ''},
 'run senator': {'dobj.prep_miss': ''},
 'run space': {'dobj.prep_miss': ''},
 'scar life': {'dobj.prep_miss': ''},
 'score breakaway': {'dobj.prep_miss': ''},
 'screech halt': {'dobj.prep_miss': ''},
 'search answer': {'dobj.prep_miss': ''},
 'search evidence': {'dobj.prep_miss': ''},
 'sell discount': {'dobj.prep_miss': ''},
 'send exile': {'dobj.prep_miss': ''},
 'send printer': {'dobj.prep_miss': ''},
 'send school': {'dobj.prep_miss': ''},
 'separate husband': {'dobj.prep_miss': ''},
 'separate wife': {'dobj.prep_miss': ''},
 'serve base': {'dobj.prep_miss': ''},
 'serve basis': {'dobj.prep_miss': ''},
 'serve bridge': {'dobj.prep_miss': ''},
 'serve chairman': {'dobj.prep_miss': ''},
 'serve consultant': {'dobj.prep_miss': ''},
 'serve director': {'dobj.prep_miss': ''},
 'serve example': {'dobj.prep_miss': ''},
 'serve force': {'dobj.prep_miss': ''},
 'serve host': {'dobj.prep_miss': ''},
 'serve judge': {'dobj.prep_miss': ''},
 'serve liaison': {'dobj.prep_miss': ''},
 'serve minister': {'dobj.prep_miss': ''},
 'serve pleasure': {'dobj.prep_miss': ''},
 'serve producer': {'dobj.prep_miss': ''},
 'serve reminder': {'dobj.prep_miss': ''},
 'serve secretary': {'dobj.prep_miss': ''},
 'serve site': {'dobj.prep_miss': ''},
 'set motion': {'dobj.prep_miss': ''},
 'settle city': {'dobj.prep_miss': ''},
 'settle court': {'dobj.prep_miss': ''},
 'shoot foot': {'dobj.prep_miss': ''},
 'shoot sight': {'dobj.prep_miss': ''},
 'shop clothes': {'dobj.prep_miss': ''},
 'shop market': {'dobj.prep_miss': ''},
 'shut computer': {'dobj.prep_miss': ''},
 'shut production': {'dobj.prep_miss': ''},
 'sink bottom': {'dobj.prep_miss': ''},
 'sit board': {'dobj.prep_miss': ''},
 'sit car': {'dobj.prep_miss': ''},
 'sit class': {'dobj.prep_miss': ''},
 'slide track': {'dobj.prep_miss': ''},
 'speak behalf': {'dobj.prep_miss': ''},
 'speak seminar': {'dobj.prep_miss': ''},
 'specialize area': {'dobj.prep_miss': ''},
 'specialize research': {'dobj.prep_miss': ''},
 'specialize service': {'dobj.prep_miss': ''},
 'specialize software': {'dobj.prep_miss': ''},
 'specialize technology': {'dobj.prep_miss': ''},
 'specialize treatment': {'dobj.prep_miss': ''},
 'spend advertising': {'dobj.prep_miss': ''},
 'spend benefit': {'dobj.prep_miss': ''},
 'spend computer': {'dobj.prep_miss': ''},
 'spend education': {'dobj.prep_miss': ''},
 'spend family': {'dobj.prep_miss': ''},
 'spend food': {'dobj.prep_miss': ''},
 'spend item': {'dobj.prep_miss': ''},
 'spend research': {'dobj.prep_miss': ''},
 'spend security': {'dobj.prep_miss': ''},
 'spend technology': {'dobj.prep_miss': ''},
 'spin control': {'dobj.prep_miss': ''},
 'split middle': {'dobj.prep_miss': ''},
 'spread body': {'dobj.prep_miss': ''},
 'spread capital': {'dobj.prep_miss': ''},
 'stab knife': {'dobj.prep_miss': ''},
 'stand hand': {'dobj.prep_miss': ''},
 'stand hill': {'dobj.prep_miss': ''},
 'stand leg': {'dobj.prep_miss': ''},
 'stand line': {'dobj.prep_miss': ''},
 'stand podium': {'dobj.prep_miss': ''},
 'stand principle': {'dobj.prep_miss': ''},
 'stand way': {'dobj.prep_miss': ''},
 'start middle': {'dobj.prep_miss': ''},
 'start top': {'dobj.prep_miss': ''},
 'stay check': {'dobj.prep_miss': ''},
 'stay leader': {'dobj.prep_miss': ''},
 'stay point': {'dobj.prep_miss': ''},
 'step bound': {'dobj.prep_miss': ''},
 'step line': {'dobj.prep_miss': ''},
 'step ring': {'dobj.prep_miss': ''},
 'step step': {'dobj.prep_miss': ''},
 'stick mind': {'dobj.prep_miss': ''},
 'stick plan': {'dobj.prep_miss': ''},
 'stir life': {'dobj.prep_miss': ''},
 'stop airport': {'dobj.prep_miss': ''},
 'stop border': {'dobj.prep_miss': ''},
 'stop intersection': {'dobj.prep_miss': ''},
 'stop minute': {'dobj.prep_miss': ''},
 'store site': {'dobj.prep_miss': ''},
 'strap cash': {'dobj.prep_miss': ''},
 'study college': {'dobj.prep_miss': ''},
 'study university': {'dobj.prep_miss': ''},
 'subject approval': {'dobj.prep_miss': ''},
 'subject condition': {'dobj.prep_miss': ''},
 'subject law': {'dobj.prep_miss': ''},
 'submit approval': {'dobj.prep_miss': ''},
 'submit authority': {'dobj.prep_miss': ''},
 'subscribe magazine': {'dobj.prep_miss': ''},
 'suffer asthma': {'dobj.prep_miss': ''},
 'suffer hunger': {'dobj.prep_miss': ''},
 'suffer schizophrenia': {'dobj.prep_miss': ''},
 'suffer syndrome': {'dobj.prep_miss': ''},
 'suffer virus': {'dobj.prep_miss': ''},
 'surrender force': {'dobj.prep_miss': ''},
 'surrender government': {'dobj.prep_miss': ''},
 'swim beach': {'dobj.prep_miss': ''},
 'swim ocean': {'dobj.prep_miss': ''},
 'swim sea': {'dobj.prep_miss': ''},
 'take_care child': {'dobj.prep_miss': ''},
 'talk audience': {'dobj.prep_miss': ''},
 'talk book': {'dobj.prep_miss': ''},
 'talk boss': {'dobj.prep_miss': ''},
 'talk father': {'dobj.prep_miss': ''},
 'talk film': {'dobj.prep_miss': ''},
 'talk history': {'dobj.prep_miss': ''},
 'talk manager': {'dobj.prep_miss': ''},
 'talk marriage': {'dobj.prep_miss': ''},
 'talk movie': {'dobj.prep_miss': ''},
 'talk night': {'dobj.prep_miss': ''},
 'talk weather': {'dobj.prep_miss': ''},
 'teach university': {'dobj.prep_miss': ''},
 'test doneness': {'dobj.prep_miss': ''},
 'thank effort': {'dobj.prep_miss': ''},
 'thank help': {'dobj.prep_miss': ''},
 'thank support': {'dobj.prep_miss': ''},
 'throw confusion': {'dobj.prep_miss': ''},
 'throw jail': {'dobj.prep_miss': ''},
 'throw loop': {'dobj.prep_miss': ''},
 'throw track': {'dobj.prep_miss': ''},
 'toss coat': {'dobj.prep_miss': ''},
 'toy idea': {'dobj.prep_miss': ''},
 'translate action': {'dobj.prep_miss': ''},
 'travel air': {'dobj.prep_miss': ''},
 'travel boat': {'dobj.prep_miss': ''},
 'travel bus': {'dobj.prep_miss': ''},
 'travel train': {'dobj.prep_miss': ''},
 'treat care': {'dobj.prep_miss': ''},
 'treat clinic': {'dobj.prep_miss': ''},
 'treat equal': {'dobj.prep_miss': ''},
 'treat respect': {'dobj.prep_miss': ''},
 'tuck corner': {'dobj.prep_miss': ''},
 'tug heart': {'dobj.prep_miss': ''},
 'turn advantage': {'dobj.prep_miss': ''},
 'turn positive': {'dobj.prep_miss': ''},
 'vary case': {'dobj.prep_miss': ''},
 'vary company': {'dobj.prep_miss': ''},
 'vary country': {'dobj.prep_miss': ''},
 'vary market': {'dobj.prep_miss': ''},
 'vary person': {'dobj.prep_miss': ''},
 'vary place': {'dobj.prep_miss': ''},
 'vary quality': {'dobj.prep_miss': ''},
 'vary region': {'dobj.prep_miss': ''},
 'view angle': {'dobj.prep_miss': ''},
 'wait answer': {'dobj.prep_miss': ''},
 'wait approval': {'dobj.prep_miss': ''},
 'wait arrival': {'dobj.prep_miss': ''},
 'wait call': {'dobj.prep_miss': ''},
 'wait delivery': {'dobj.prep_miss': ''},
 'wait friend': {'dobj.prep_miss': ''},
 'wait information': {'dobj.prep_miss': ''},
 'wait instruction': {'dobj.prep_miss': ''},
 'wait man': {'dobj.prep_miss': ''},
 'wait night': {'dobj.prep_miss': ''},
 'wait opportunity': {'dobj.prep_miss': ''},
 'wait order': {'dobj.prep_miss': ''},
 'wait outcome': {'dobj.prep_miss': ''},
 'wait police': {'dobj.prep_miss': ''},
 'wait release': {'dobj.prep_miss': ''},
 'wait reply': {'dobj.prep_miss': ''},
 'wait response': {'dobj.prep_miss': ''},
 'wait result': {'dobj.prep_miss': ''},
 'wait return': {'dobj.prep_miss': ''},
 'wait sign': {'dobj.prep_miss': ''},
 'wait signal': {'dobj.prep_miss': ''},
 'wait work': {'dobj.prep_miss': ''},
 'walk circle': {'dobj.prep_miss': ''},
 'walk direction': {'dobj.prep_miss': ''},
 'walk night': {'dobj.prep_miss': ''},
 'walk school': {'dobj.prep_miss': ''},
 'walk shoe': {'dobj.prep_miss': ''},
 'warn attack': {'dobj.prep_miss': ''},
 'warn risk': {'dobj.prep_miss': ''},
 'warn sanction': {'dobj.prep_miss': ''},
 'wave camera': {'dobj.prep_miss': ''},
 'win default': {'dobj.prep_miss': ''},
 'win ease': {'dobj.prep_miss': ''},
 'win style': {'dobj.prep_miss': ''},
 'work assignment': {'dobj.prep_miss': ''},
 'work casino': {'dobj.prep_miss': ''},
 'work device': {'dobj.prep_miss': ''},
 'work document': {'dobj.prep_miss': ''},
 'work facility': {'dobj.prep_miss': ''},
 'work fund': {'dobj.prep_miss': ''},
 'work legislation': {'dobj.prep_miss': ''},
 'work model': {'dobj.prep_miss': ''},
 'work supervision': {'dobj.prep_miss': ''},
 'work track': {'dobj.prep_miss': ''},
 'work type': {'dobj.prep_miss': ''},
 'work version': {'dobj.prep_miss': ''},
 'worry child': {'dobj.prep_miss': ''},
 'worry security': {'dobj.prep_miss': ''},
 'wrap waist': {'dobj.prep_miss': ''},
 'wrestle problem': {'dobj.prep_miss': ''},
 'reuse': {'vt_typical': ''},
 'rewind': {'vt_typical': ''},
 'Buddhism': {'nu_typical': ''},
 'spaghetti': {'nu_typical': ''},
 'veal': {'nu_typical': ''},
 'bakery': {'nc_typical': ''},
 'Buddhist': {'nc_typical': ''},
 'businesswomen': {'nc_typical': ''},
 'centimetre': {'nc_typical': ''},
 'chairwomen': {'nc_typical': ''},
 'chopsticks': {'nc_typical': ''},
 'coursebook': {'nc_typical': ''},
 'coworker': {'nc_typical': ''},
 'criteria': {'nc_typical': ''},
 'meeting   ': {'nc_typical': ''},
 'metre': {'nc_typical': '', 'n_is_unit': 'length'},
 'modem': {'nc_typical': ''},
 'penfriend': {'nc_typical': ''},
 'palnet': {'nc_typical': ''},
 'playroom': {'nc_typical': ''},
 'postcode': {'nc_typical': ''},
 'schoolbag': {'nc_typical': ''},
 'school-leaver': {'nc_typical': ''},
 'sideway': {'nc_typical': ''},
 'snackbar': {'nc_typical': ''},
 'thriller': {'nc_typical': ''},
 'trolleybus': {'nc_typical': ''},
 'T-shirt': {'nc_typical': ''},
 'videophone': {'nc_typical': ''},
 'X-ray': {'nc_typical': ''},
 'zipper': {'nc_typical': ''},
 'zoo': {'nc_typical': ''},
 'arose': {'vi_typical': ''},
 'risen': {'vi_typical': ''},
 'system train': {'e_trp.nsv': ''},
 'sun like': {'e_trp.nsv': ''},
 'sun have_up': {'e_trp.nsv': ''},
 'substance add_in': {'e_trp.nsv': ''},
 'stuffing contain': {'e_trp.nsv': ''},
 'study well': {'e_trp.nsv': ''},
 'study time': {'e_trp.nsv': ''},
 'study study': {'e_trp.nsv': ''},
 'study read': {'e_trp.nsv': ''},
 'study feel': {'e_trp.nsv': ''},
 'study demand': {'e_trp.nsv': ''},
 'students find': {'e_trp.nsv': ''},
 'studing be': {'e_trp.nsv': ''},
 'student realise': {'e_trp.nsv': ''},
 'student pracitising': {'e_trp.nsv': ''},
 'student interest': {'e_trp.nsv': ''},
 'student chance': {'e_trp.nsv': ''},
 'struction fail': {'e_trp.nsv': ''},
 'struction be': {'e_trp.nsv': ''},
 'strick be': {'e_trp.nsv': ''},
 'stream fly': {'e_trp.nsv': ''},
 'story endding': {'e_trp.nsv': ''},
 'stiput be': {'e_trp.nsv': ''},
 'still think': {'e_trp.nsv': ''},
 'still farm': {'e_trp.nsv': ''},
 'step better': {'e_trp.nsv': ''},
 'standar be': {'e_trp.nsv': ''},
 'stand trail': {'e_trp.nsv': ''},
 'stand stand': {'e_trp.nsv': ''},
 'stand get': {'e_trp.nsv': ''},
 'stand cloud': {'e_trp.nsv': ''},
 'stadium bustle': {'e_trp.nsv': ''},
 'stable live': {'e_trp.nsv': ''},
 'sprit live': {'e_trp.nsv': ''},
 'spring comming': {'e_trp.nsv': ''},
 'sport swim': {'e_trp.nsv': ''},
 'sport listen': {'e_trp.nsv': ''},
 'sport exercise': {'e_trp.nsv': ''},
 'sound sleep': {'e_trp.nsv': ''},
 'song even': {'e_trp.nsv': ''},
 'society graduate': {'e_trp.nsv': ''},
 'society deed': {'e_trp.nsv': ''},
 'society advance': {'e_trp.nsv': ''},
 'social order': {'e_trp.nsv': ''},
 'soarce be': {'e_trp.nsv': ''},
 'smile welcome': {'e_trp.nsv': ''},
 'smile nestle': {'e_trp.nsv': ''},
 'sky rain': {'e_trp.nsv': ''},
 'skill rise': {'e_trp.nsv': ''},
 'skill pratise': {'e_trp.nsv': ''},
 'skill practice': {'e_trp.nsv': ''},
 'singing draw': {'e_trp.nsv': ''},
 'side sound': {'e_trp.nsv': ''},
 'side agreeted': {'e_trp.nsv': ''},
 'shoud try': {'e_trp.nsv': ''},
 'shoud do': {'e_trp.nsv': ''},
 'shop side': {'e_trp.nsv': ''},
 'shavor work': {'e_trp.nsv': ''},
 'severses be': {'e_trp.nsv': ''},
 'set refuse': {'e_trp.nsv': ''},
 'service compare': {'e_trp.nsv': ''},
 'serve give': {'e_trp.nsv': ''},
 'sergean be': {'e_trp.nsv': ''},
 'send be': {'e_trp.nsv': ''},
 'sence get_in': {'e_trp.nsv': ''},
 'self-esteem satisfy': {'e_trp.nsv': ''},
 'select job': {'e_trp.nsv': ''},
 'seam intestified': {'e_trp.nsv': ''},
 'screen send': {'e_trp.nsv': ''},
 'scientist endeavour': {'e_trp.nsv': ''},
 'school read': {'e_trp.nsv': ''},
 'school gate': {'e_trp.nsv': ''},
 'saying refering': {'e_trp.nsv': ''},
 'savage hill': {'e_trp.nsv': ''},
 'sale man': {'e_trp.nsv': ''},
 'rubbish poluted': {'e_trp.nsv': ''},
 'round shape': {'e_trp.nsv': ''},
 'round face': {'e_trp.nsv': ''},
 'roast suckle': {'e_trp.nsv': ''},
 'road full': {'e_trp.nsv': ''},
 'river full': {'e_trp.nsv': ''},
 'rise people': {'e_trp.nsv': ''},
 'right know': {'e_trp.nsv': ''},
 'rice grow': {'e_trp.nsv': ''},
 'result wonder': {'e_trp.nsv': ''},
 'result read': {'e_trp.nsv': ''},
 'resource tap': {'e_trp.nsv': ''},
 'research unknow': {'e_trp.nsv': ''},
 'rember clear': {'e_trp.nsv': ''},
 'remark even': {'e_trp.nsv': ''},
 'reluctantant be': {'e_trp.nsv': ''},
 'relationship base': {'e_trp.nsv': ''},
 'rehabilitation connive': {'e_trp.nsv': ''},
 'regretable be': {'e_trp.nsv': ''},
 'regetables be': {'e_trp.nsv': ''},
 'regard slim': {'e_trp.nsv': ''},
 'reform plan': {'e_trp.nsv': ''},
 'reform offer': {'e_trp.nsv': ''},
 'reen talk': {'e_trp.nsv': ''},
 'recieves repay': {'e_trp.nsv': ''},
 'recerch work': {'e_trp.nsv': ''},
 'reason result': {'e_trp.nsv': ''},
 'reason inflect': {'e_trp.nsv': ''},
 'reading word': {'e_trp.nsv': ''},
 'rapidlly speak': {'e_trp.nsv': ''},
 'rain even': {'e_trp.nsv': ''},
 'race immigrate': {'e_trp.nsv': ''},
 'quitely confirm': {'e_trp.nsv': ''},
 'quick operate': {'e_trp.nsv': ''},
 'quick break': {'e_trp.nsv': ''},
 'question write': {'e_trp.nsv': ''},
 'question wait': {'e_trp.nsv': ''},
 'put shall': {'e_trp.nsv': ''},
 'puring be': {'e_trp.nsv': ''},
 'punishment fall': {'e_trp.nsv': ''},
 'provids fund': {'e_trp.nsv': ''},
 'proposal enjoy': {'e_trp.nsv': ''},
 'propoganda resist': {'e_trp.nsv': ''},
 'prophecy prove': {'e_trp.nsv': ''},
 'pronographic lead': {'e_trp.nsv': ''},
 'progress study': {'e_trp.nsv': ''},
 'programme teach': {'e_trp.nsv': ''},
 'programme make': {'e_trp.nsv': ''},
 'program relate': {'e_trp.nsv': ''},
 'profit pursue': {'e_trp.nsv': ''},
 'production reduce': {'e_trp.nsv': ''},
 'product buy': {'e_trp.nsv': ''},
 'product arised': {'e_trp.nsv': ''},
 'produce fake': {'e_trp.nsv': ''},
 'procession finish': {'e_trp.nsv': ''},
 'problem smoke': {'e_trp.nsv': ''},
 'proberbly harm': {'e_trp.nsv': ''},
 'probaly run': {'e_trp.nsv': ''},
 'probabally have': {'e_trp.nsv': ''},
 'privilidged class': {'e_trp.nsv': ''},
 'prison confer': {'e_trp.nsv': ''},
 'principle guilding': {'e_trp.nsv': ''},
 'price concern': {'e_trp.nsv': ''},
 'prepair build': {'e_trp.nsv': ''},
 'preliminary contest': {'e_trp.nsv': ''},
 'precausion choose': {'e_trp.nsv': ''},
 'pratices help': {'e_trp.nsv': ''},
 'pratice succeed': {'e_trp.nsv': ''},
 'practise use': {'e_trp.nsv': ''},
 'practice turn': {'e_trp.nsv': ''},
 'practice recieved': {'e_trp.nsv': ''},
 'practice finish': {'e_trp.nsv': ''},
 'practice face': {'e_trp.nsv': ''},
 'practice cease': {'e_trp.nsv': ''},
 'practice ask': {'e_trp.nsv': ''},
 'practicaly be': {'e_trp.nsv': ''},
 'power aggress': {'e_trp.nsv': ''},
 'poverty puzzed': {'e_trp.nsv': ''},
 'poverty dominate': {'e_trp.nsv': ''},
 'pound injure': {'e_trp.nsv': ''},
 'position wait': {'e_trp.nsv': ''},
 'popullation larging': {'e_trp.nsv': ''},
 'population raise': {'e_trp.nsv': ''},
 'pollution raise': {'e_trp.nsv': ''},
 'pollution expand': {'e_trp.nsv': ''},
 'pollution destroy': {'e_trp.nsv': ''},
 'pollution pollute': {'e_trp.nsv': ''},
 'pollution lie': {'e_trp.nsv': ''},
 'pole place': {'e_trp.nsv': ''},
 'point click': {'e_trp.nsv': ''},
 'pocket see': {'e_trp.nsv': ''},
 'plenty be': {'e_trp.nsv': ''},
 'plant tart': {'e_trp.nsv': ''},
 'planet like': {'e_trp.nsv': ''},
 'plan realize': {'e_trp.nsv': ''},
 'physical train': {'e_trp.nsv': ''},
 'petrel shout': {'e_trp.nsv': ''},
 'peter smash': {'e_trp.nsv': ''},
 'peter see': {'e_trp.nsv': ''},
 'peter hit': {'e_trp.nsv': ''},
 'peter ask': {'e_trp.nsv': ''},
 'persuit need': {'e_trp.nsv': ''},
 'personnel fair': {'e_trp.nsv': ''},
 'person water': {'e_trp.nsv': ''},
 'perphaps think': {'e_trp.nsv': ''},
 'people water': {'e_trp.nsv': ''},
 'people up': {'e_trp.nsv': ''},
 'people true': {'e_trp.nsv': ''},
 'people jostle': {'e_trp.nsv': ''},
 'people gape': {'e_trp.nsv': ''},
 'people full': {'e_trp.nsv': ''},
 'people forward': {'e_trp.nsv': ''},
 'people excel': {'e_trp.nsv': ''},
 'people even': {'e_trp.nsv': ''},
 'people equal': {'e_trp.nsv': ''},
 'people endeavour': {'e_trp.nsv': ''},
 'people echo': {'e_trp.nsv': ''},
 'people decrease': {'e_trp.nsv': ''},
 'penalty wait': {'e_trp.nsv': ''},
 'pen leave': {'e_trp.nsv': ''},
 'pay sum': {'e_trp.nsv': ''},
 'pattern bore': {'e_trp.nsv': ''},
 'patient pass_away': {'e_trp.nsv': ''},
 'patience get': {'e_trp.nsv': ''},
 'patience drain_away': {'e_trp.nsv': ''},
 'part test': {'e_trp.nsv': ''},
 'part serve': {'e_trp.nsv': ''},
 'part grow': {'e_trp.nsv': ''},
 'part finish': {'e_trp.nsv': ''},
 'park bench': {'e_trp.nsv': ''},
 'paper last': {'e_trp.nsv': ''},
 'paorter have': {'e_trp.nsv': ''},
 'pan catch_fire': {'e_trp.nsv': ''},
 'pair receive': {'e_trp.nsv': ''},
 'pair flare': {'e_trp.nsv': ''},
 'pain prohibit': {'e_trp.nsv': ''},
 'pain hurt': {'e_trp.nsv': ''},
 'pain cook': {'e_trp.nsv': ''},
 'pain body': {'e_trp.nsv': ''},
 'pain beg': {'e_trp.nsv': ''},
 'page teach': {'e_trp.nsv': ''},
 'packet-box be': {'e_trp.nsv': ''},
 'outside dress': {'e_trp.nsv': ''},
 'out do': {'e_trp.nsv': ''},
 'opposite side': {'e_trp.nsv': ''},
 'opportunity practise': {'e_trp.nsv': ''},
 'one up': {'e_trp.nsv': ''},
 'one realise': {'e_trp.nsv': ''},
 'one practise': {'e_trp.nsv': ''},
 'ome be': {'e_trp.nsv': ''},
 'offsprings deal': {'e_trp.nsv': ''},
 'official found': {'e_trp.nsv': ''},
 'offence know': {'e_trp.nsv': ''},
 'ocean full': {'e_trp.nsv': ''},
 'occupation do': {'e_trp.nsv': ''},
 'nursing increase': {'e_trp.nsv': ''},
 'number keep_on': {'e_trp.nsv': ''},
 'number intend': {'e_trp.nsv': ''},
 'number close_down': {'e_trp.nsv': ''},
 'note clench': {'e_trp.nsv': ''},
 'noise wake': {'e_trp.nsv': ''},
 'noise smite': {'e_trp.nsv': ''},
 'no taste': {'e_trp.nsv': ''},
 'no pollute': {'e_trp.nsv': ''},
 'no own': {'e_trp.nsv': ''},
 'no dream': {'e_trp.nsv': ''},
 'no choose': {'e_trp.nsv': ''},
 'night put': {'e_trp.nsv': ''},
 'night help': {'e_trp.nsv': ''},
 'night draw': {'e_trp.nsv': ''},
 'niang be': {'e_trp.nsv': ''},
 'news word': {'e_trp.nsv': ''},
 'nevre walk': {'e_trp.nsv': ''},
 'net paint': {'e_trp.nsv': ''},
 'nerve collapse': {'e_trp.nsv': ''},
 'nephew lam': {'e_trp.nsv': ''},
 'need plan': {'e_trp.nsv': ''},
 'need find': {'e_trp.nsv': ''},
 'need enlarge': {'e_trp.nsv': ''},
 'need advanted': {'e_trp.nsv': ''},
 'necessary part': {'e_trp.nsv': ''},
 'nature feed': {'e_trp.nsv': ''},
 'natural proceed': {'e_trp.nsv': ''},
 'natural flow': {'e_trp.nsv': ''},
 'national develop': {'e_trp.nsv': ''},
 'must give': {'e_trp.nsv': ''},
 'must do': {'e_trp.nsv': ''},
 'mush take': {'e_trp.nsv': ''},
 'murder increase': {'e_trp.nsv': ''},
 'mumbers hold': {'e_trp.nsv': ''},
 'much know': {'e_trp.nsv': ''},
 'mow come': {'e_trp.nsv': ''},
 'movement try': {'e_trp.nsv': ''},
 'movement sweep': {'e_trp.nsv': ''},
 'mouth make': {'e_trp.nsv': ''},
 'motive account': {'e_trp.nsv': ''},
 'motivation release': {'e_trp.nsv': ''},
 'most object': {'e_trp.nsv': ''},
 'most lead': {'e_trp.nsv': ''},
 'most authorize': {'e_trp.nsv': ''},
 'mortality reduced': {'e_trp.nsv': ''},
 'mortality lie': {'e_trp.nsv': ''},
 'mortality droping': {'e_trp.nsv': ''},
 'mortality relive': {'e_trp.nsv': ''},
 'mortality lower': {'e_trp.nsv': ''},
 'mortality go': {'e_trp.nsv': ''},
 'mortality get': {'e_trp.nsv': ''},
 'mortality droped': {'e_trp.nsv': ''},
 'mortality begin': {'e_trp.nsv': ''},
 'more surprise': {'e_trp.nsv': ''},
 'more develop': {'e_trp.nsv': ''},
 'morality have': {'e_trp.nsv': ''},
 'morality admit': {'e_trp.nsv': ''},
 'money treat': {'e_trp.nsv': ''},
 'money serve': {'e_trp.nsv': ''},
 'money kill': {'e_trp.nsv': ''},
 'money complement': {'e_trp.nsv': ''},
 'money calculate': {'e_trp.nsv': ''},
 'money afford': {'e_trp.nsv': ''},
 'misery result': {'e_trp.nsv': ''},
 'mischivors bur': {'e_trp.nsv': ''},
 'mini-lecture give': {'e_trp.nsv': ''},
 'miner want': {'e_trp.nsv': ''},
 'mind receive': {'e_trp.nsv': ''},
 'mind fly': {'e_trp.nsv': ''},
 'mind finish': {'e_trp.nsv': ''},
 'mind concentrate': {'e_trp.nsv': ''},
 'millionare be': {'e_trp.nsv': ''},
 'millionaire appear': {'e_trp.nsv': ''},
 'mill grind': {'e_trp.nsv': ''},
 'metre run': {'e_trp.nsv': ''},
 'method stop': {'e_trp.nsv': ''},
 'method deal': {'e_trp.nsv': ''},
 'mercy release': {'e_trp.nsv': ''},
 'mention do': {'e_trp.nsv': ''},
 'memorys go': {'e_trp.nsv': ''},
 'memory hurt': {'e_trp.nsv': ''},
 'medium display': {'e_trp.nsv': ''},
 'medicine support': {'e_trp.nsv': ''},
 'medicine end': {'e_trp.nsv': ''},
 'medicine deteriorate': {'e_trp.nsv': ''},
 'medicine delay': {'e_trp.nsv': ''},
 'medical care': {'e_trp.nsv': ''},
 'measurement fight': {'e_trp.nsv': ''},
 'measurement promote': {'e_trp.nsv': ''},
 'measure contribute': {'e_trp.nsv': ''},
 'meaning make': {'e_trp.nsv': ''},
 'maxim remarry': {'e_trp.nsv': ''},
 'maxim kill': {'e_trp.nsv': ''},
 'matter breathe': {'e_trp.nsv': ''},
 'match memorize': {'e_trp.nsv': ''},
 'exercise match': {'e_trp.nsv': ''},
 'english maste': {'e_trp.nsv': ''},
 'provide love': {'e_trp.nsv': ''},
 'eat love': {'e_trp.nsv': ''},
 'buy love': {'e_trp.nsv': ''},
 'realize job': {'e_trp.nsv': ''},
 'know job': {'e_trp.nsv': ''},
 'interest job': {'e_trp.nsv': ''},
 'vary intersting': {'e_trp.nsv': ''},
 'happen interruption': {'e_trp.nsv': ''},
 'go intent': {'e_trp.nsv': ''},
 'spread instruction': {'e_trp.nsv': ''},
 'indicate instruction': {'e_trp.nsv': ''},
 'make inside': {'e_trp.nsv': ''},
 'be inner': {'e_trp.nsv': ''},
 'induce injection': {'e_trp.nsv': ''},
 'know information': {'e_trp.nsv': ''},
 'threaten illness': {'e_trp.nsv': ''},
 'pass illness': {'e_trp.nsv': ''},
 'full illness': {'e_trp.nsv': ''},
 'cure illness': {'e_trp.nsv': ''},
 'be idiom-haste': {'e_trp.nsv': ''},
 'make ideal': {'e_trp.nsv': ''},
 'become ideal': {'e_trp.nsv': ''},
 'undergo idea': {'e_trp.nsv': ''},
 'realize idea': {'e_trp.nsv': ''},
 'lag idea': {'e_trp.nsv': ''},
 'keep_up idea': {'e_trp.nsv': ''},
 'need hurt': {'e_trp.nsv': ''},
 'make hurt': {'e_trp.nsv': ''},
 'do hurry': {'e_trp.nsv': ''},
 'come hurry': {'e_trp.nsv': ''},
 'break hurry': {'e_trp.nsv': ''},
 'destroy hundred': {'e_trp.nsv': ''},
 'run hunderd': {'e_trp.nsv': ''},
 'mean humanity': {'e_trp.nsv': ''},
 'make humanity': {'e_trp.nsv': ''},
 'follow humanity': {'e_trp.nsv': ''},
 'enter humanity': {'e_trp.nsv': ''},
 'watch house': {'e_trp.nsv': ''},
 'surprise house': {'e_trp.nsv': ''},
 'dance hour': {'e_trp.nsv': ''},
 'lie hospital': {'e_trp.nsv': ''},
 'pass height': {'e_trp.nsv': ''},
 'study heavy': {'e_trp.nsv': ''},
 'burden heavy': {'e_trp.nsv': ''},
 'resume heart': {'e_trp.nsv': ''},
 'fill heart': {'e_trp.nsv': ''},
 'dream heart': {'e_trp.nsv': ''},
 'step_in headmaster': {'e_trp.nsv': ''},
 'change hate': {'e_trp.nsv': ''},
 'will haste': {'e_trp.nsv': ''},
 'take haste': {'e_trp.nsv': ''},
 'succeed haste': {'e_trp.nsv': ''},
 'spoil haste': {'e_trp.nsv': ''},
 'save haste': {'e_trp.nsv': ''},
 'let haste': {'e_trp.nsv': ''},
 'kill haste': {'e_trp.nsv': ''},
 'indicate haste': {'e_trp.nsv': ''},
 'improve haste': {'e_trp.nsv': ''},
 'give haste': {'e_trp.nsv': ''},
 'contribute haste': {'e_trp.nsv': ''},
 'can haste': {'e_trp.nsv': ''},
 'wander graduate': {'e_trp.nsv': ''},
 'use graduate': {'e_trp.nsv': ''},
 'hunt graduate': {'e_trp.nsv': ''},
 'feel graduate': {'e_trp.nsv': ''},
 'expect graduate': {'e_trp.nsv': ''},
 'attend graduate': {'e_trp.nsv': ''},
 'work grade': {'e_trp.nsv': ''},
 'hold grade': {'e_trp.nsv': ''},
 'think_out governor': {'e_trp.nsv': ''},
 'legalize government': {'e_trp.nsv': ''},
 'educate government': {'e_trp.nsv': ''},
 'cane government': {'e_trp.nsv': ''},
 'build_up government': {'e_trp.nsv': ''},
 'beat government': {'e_trp.nsv': ''},
 'strengthen goverment': {'e_trp.nsv': ''},
 'do goverment': {'e_trp.nsv': ''},
 'claim goverment': {'e_trp.nsv': ''},
 'assign goverment': {'e_trp.nsv': ''},
 'lose govenment': {'e_trp.nsv': ''},
 'forbid govenment': {'e_trp.nsv': ''},
 'go gorenment': {'e_trp.nsv': ''},
 'display goods': {'e_trp.nsv': ''},
 'appear goods': {'e_trp.nsv': ''},
 'buy gold': {'e_trp.nsv': ''},
 'offer globe': {'e_trp.nsv': ''},
 'put glance': {'e_trp.nsv': ''},
 'point girl': {'e_trp.nsv': ''},
 'concern girl': {'e_trp.nsv': ''},
 'compare geting': {'e_trp.nsv': ''},
 'irritate gas': {'e_trp.nsv': ''},
 'march gang': {'e_trp.nsv': ''},
 'laugh game': {'e_trp.nsv': ''},
 'guess game': {'e_trp.nsv': ''},
 'will future': {'e_trp.nsv': ''},
 'live future': {'e_trp.nsv': ''},
 'bring furniture': {'e_trp.nsv': ''},
 'require fundemental': {'e_trp.nsv': ''},
 'shape full-moon': {'e_trp.nsv': ''},
 'sit fruit': {'e_trp.nsv': ''},
 'exist friendship': {'e_trp.nsv': ''},
 'die friendship': {'e_trp.nsv': ''},
 'see_off friend': {'e_trp.nsv': ''},
 'grow_up friend-ship': {'e_trp.nsv': ''},
 'rain freezer': {'e_trp.nsv': ''},
 'get fracture': {'e_trp.nsv': ''},
 'work_in fortune': {'e_trp.nsv': ''},
 'make former': {'e_trp.nsv': ''},
 'express former': {'e_trp.nsv': ''},
 'suit form': {'e_trp.nsv': ''},
 'join football': {'e_trp.nsv': ''},
 'boxxing football': {'e_trp.nsv': ''},
 'beat football': {'e_trp.nsv': ''},
 'strike foot': {'e_trp.nsv': ''},
 'slide foot': {'e_trp.nsv': ''},
 'force foot': {'e_trp.nsv': ''},
 'start following': {'e_trp.nsv': ''},
 'look following': {'e_trp.nsv': ''},
 'listen focus': {'e_trp.nsv': ''},
 'let flower': {'e_trp.nsv': ''},
 'market flower': {'e_trp.nsv': ''},
 'flutter flower': {'e_trp.nsv': ''},
 'turn floor': {'e_trp.nsv': ''},
 'become flat': {'e_trp.nsv': ''},
 'do fit': {'e_trp.nsv': ''},
 'wait fisherman': {'e_trp.nsv': ''},
 'radiate fire': {'e_trp.nsv': ''},
 'heat fire': {'e_trp.nsv': ''},
 'rebutlling finishs': {'e_trp.nsv': ''},
 'rebuiding finishs': {'e_trp.nsv': ''},
 'play finish': {'e_trp.nsv': ''},
 'work field': {'e_trp.nsv': ''},
 'elevate field': {'e_trp.nsv': ''},
 'crease festival': {'e_trp.nsv': ''},
 'call festival': {'e_trp.nsv': ''},
 'appear festival': {'e_trp.nsv': ''},
 'impel feeling': {'e_trp.nsv': ''},
 'bring feeling': {'e_trp.nsv': ''},
 'spend fee': {'e_trp.nsv': ''},
 'change favorit': {'e_trp.nsv': ''},
 'see_off father': {'e_trp.nsv': ''},
 'change fate': {'e_trp.nsv': ''},
 'trap fashion': {'e_trp.nsv': ''},
 'care farmer': {'e_trp.nsv': ''},
 'do_in fare': {'e_trp.nsv': ''},
 'say fang': {'e_trp.nsv': ''},
 'begin fang': {'e_trp.nsv': ''},
 'lie family': {'e_trp.nsv': ''},
 'dare family': {'e_trp.nsv': ''},
 'electrify fake': {'e_trp.nsv': ''},
 'be fail': {'e_trp.nsv': ''},
 'fall factory': {'e_trp.nsv': ''},
 'fail factory': {'e_trp.nsv': ''},
 'do factor': {'e_trp.nsv': ''},
 'protest facility': {'e_trp.nsv': ''},
 'crack face': {'e_trp.nsv': ''},
 'stareing eye': {'e_trp.nsv': ''},
 'exercise eye': {'e_trp.nsv': ''},
 'lead extension': {'e_trp.nsv': ''},
 'account experience': {'e_trp.nsv': ''},
 'abound experiment': {'e_trp.nsv': ''},
 'continue expectancy': {'e_trp.nsv': ''},
 'substitute excursion': {'e_trp.nsv': ''},
 'match exercise': {'e_trp.nsv': ''},
 'go except': {'e_trp.nsv': ''},
 'do example': {'e_trp.nsv': ''},
 'say examination': {'e_trp.nsv': ''},
 'result evil': {'e_trp.nsv': ''},
 'appear evil': {'e_trp.nsv': ''},
 'stop everyday': {'e_trp.nsv': ''},
 'eat everyday': {'e_trp.nsv': ''},
 'race event': {'e_trp.nsv': ''},
 'say euthanasia': {'e_trp.nsv': ''},
 'ought euthanasia': {'e_trp.nsv': ''},
 'need euthanasia': {'e_trp.nsv': ''},
 'exist euthanasia': {'e_trp.nsv': ''},
 'emerge euthanasia': {'e_trp.nsv': ''},
 'cut_down euthanasia': {'e_trp.nsv': ''},
 'correspond euthanasia': {'e_trp.nsv': ''},
 'begin euthanasia': {'e_trp.nsv': ''},
 'arise euthanasia': {'e_trp.nsv': ''},
 'agree euthanasia': {'e_trp.nsv': ''},
 'accord euthanasia': {'e_trp.nsv': ''},
 'make ethnic': {'e_trp.nsv': ''},
 'wish ethic': {'e_trp.nsv': ''},
 'be estival': {'e_trp.nsv': ''},
 'consist error': {'e_trp.nsv': ''},
 'ensure equipment': {'e_trp.nsv': ''},
 'stop equality': {'e_trp.nsv': ''},
 'serve equalitarianism': {'e_trp.nsv': ''},
 'bring equalitarianism': {'e_trp.nsv': ''},
 'suffer equal': {'e_trp.nsv': ''},
 'right equal': {'e_trp.nsv': ''},
 'chance equal': {'e_trp.nsv': ''},
 'put environment': {'e_trp.nsv': ''},
 'develop environment': {'e_trp.nsv': ''},
 'lie envelope': {'e_trp.nsv': ''},
 'legalize euthanasia': {'e_trp.nsv': ''},
 'invest enterprise': {'e_trp.nsv': ''},
 'find enterprise': {'e_trp.nsv': ''},
 'hate enterprise': {'e_trp.nsv': ''},
 'develop enomyes': {'e_trp.nsv': ''},
 'begin economy': {'e_trp.nsv': ''},
 'play_in enforcement': {'e_trp.nsv': ''},
 'waste energy': {'e_trp.nsv': ''},
 'add ending': {'e_trp.nsv': ''},
 'award end': {'e_trp.nsv': ''},
 'continue economic': {'e_trp.nsv': ''},
 'stand en': {'e_trp.nsv': ''},
 'walk emperor': {'e_trp.nsv': ''},
 'fire emperor': {'e_trp.nsv': ''},
 'order emperor': {'e_trp.nsv': ''},
 'circumstance emergent': {'e_trp.nsv': ''},
 'join_in ember': {'e_trp.nsv': ''},
 'letter email': {'e_trp.nsv': ''},
 'walk elephant': {'e_trp.nsv': ''},
 'think_over elephant': {'e_trp.nsv': ''},
 'stride elephant': {'e_trp.nsv': ''},
 'promise elephant': {'e_trp.nsv': ''},
 'hit electrical': {'e_trp.nsv': ''},
 'see electric': {'e_trp.nsv': ''},
 'come electric': {'e_trp.nsv': ''},
 'begin eldest': {'e_trp.nsv': ''},
 'give eight': {'e_trp.nsv': ''},
 'flower eight': {'e_trp.nsv': ''},
 'pile egg': {'e_trp.nsv': ''},
 'fly egg': {'e_trp.nsv': ''},
 'appear egg': {'e_trp.nsv': ''},
 'waste effort': {'e_trp.nsv': ''},
 'be effectioness': {'e_trp.nsv': ''},
 'leg education': {'e_trp.nsv': ''},
 'lapse education': {'e_trp.nsv': ''},
 'exist education': {'e_trp.nsv': ''},
 'mother ed': {'e_trp.nsv': ''},
 'need eating-water': {'e_trp.nsv': ''},
 'build east': {'e_trp.nsv': ''},
 'say each': {'e_trp.nsv': ''},
 'take e': {'e_trp.nsv': ''},
 'swim e': {'e_trp.nsv': ''},
 'spend e': {'e_trp.nsv': ''},
 'ring e': {'e_trp.nsv': ''},
 'must e': {'e_trp.nsv': ''},
 'make e': {'e_trp.nsv': ''},
 'leave e': {'e_trp.nsv': ''},
 'hope e': {'e_trp.nsv': ''},
 'enjoy e': {'e_trp.nsv': ''},
 'eat e': {'e_trp.nsv': ''},
 'do e': {'e_trp.nsv': ''},
 'stuff dumpling': {'e_trp.nsv': ''},
 'call dumpling': {'e_trp.nsv': ''},
 'dance drum': {'e_trp.nsv': ''},
 'tent driver': {'e_trp.nsv': ''},
 'dive driver': {'e_trp.nsv': ''},
 'spurt drink': {'e_trp.nsv': ''},
 'may drinken': {'e_trp.nsv': ''},
 'exchange dream': {'e_trp.nsv': ''},
 'boat dragon': {'e_trp.nsv': ''},
 'match dragon-boat': {'e_trp.nsv': ''},
 'raise dozen': {'e_trp.nsv': ''},
 'begin down': {'e_trp.nsv': ''},
 "like dosen't": {'e_trp.nsv': ''},
 'howl donkey': {'e_trp.nsv': ''},
 'develop dong': {'e_trp.nsv': ''},
 'catch dong': {'e_trp.nsv': ''},
 "know doesn't": {'e_trp.nsv': ''},
 'lay dog': {'e_trp.nsv': ''},
 "visit doesn't": {'e_trp.nsv': ''},
 "adapt doesn't": {'e_trp.nsv': ''},
 'work doe': {'e_trp.nsv': ''},
 'cope doctor': {'e_trp.nsv': ''},
 'want do': {'e_trp.nsv': ''},
 'shop do': {'e_trp.nsv': ''},
 'run do': {'e_trp.nsv': ''},
 'people do': {'e_trp.nsv': ''},
 'live do': {'e_trp.nsv': ''},
 'enjoy do': {'e_trp.nsv': ''},
 'clean do': {'e_trp.nsv': ''},
 'change do': {'e_trp.nsv': ''},
 'better do': {'e_trp.nsv': ''},
 'allow do': {'e_trp.nsv': ''},
 'belong diversity': {'e_trp.nsv': ''},
 'lie district': {'e_trp.nsv': ''},
 'exist distinction': {'e_trp.nsv': ''},
 'be disappoint': {'e_trp.nsv': ''},
 'do desire': {'e_trp.nsv': ''},
 'suffer disease': {'e_trp.nsv': ''},
 'understand difficulty': {'e_trp.nsv': ''},
 'tend difference': {'e_trp.nsv': ''},
 'reprimand dictate': {'e_trp.nsv': ''},
 'write diary': {'e_trp.nsv': ''},
 'be di': {'e_trp.nsv': ''},
 'rely development': {'e_trp.nsv': ''},
 'consist development': {'e_trp.nsv': ''},
 'stride develop': {'e_trp.nsv': ''},
 'do detergent': {'e_trp.nsv': ''},
 'make destiny': {'e_trp.nsv': ''},
 'want desperately': {'e_trp.nsv': ''},
 'cut desultorily': {'e_trp.nsv': ''},
 'vary desire': {'e_trp.nsv': ''},
 'think demand': {'e_trp.nsv': ''},
 'be diligent': {'e_trp.nsv': ''},
 'study degree': {'e_trp.nsv': ''},
 'guide degree': {'e_trp.nsv': ''},
 'experience degree': {'e_trp.nsv': ''},
 'determine degree': {'e_trp.nsv': ''},
 'hope deformity': {'e_trp.nsv': ''},
 'exceed definitely': {'e_trp.nsv': ''},
 'answer definite': {'e_trp.nsv': ''},
 'be different': {'e_trp.nsv': ''},
 'turn deep': {'e_trp.nsv': ''},
 'breathe deep': {'e_trp.nsv': ''},
 'sleep deel': {'e_trp.nsv': ''},
 'exist deed': {'e_trp.nsv': ''},
 'indicate decreased': {'e_trp.nsv': ''},
 'have decreased': {'e_trp.nsv': ''},
 'attack darkmen': {'e_trp.nsv': ''},
 'go dare': {'e_trp.nsv': ''},
 'use daily': {'e_trp.nsv': ''},
 'gaze dad': {'e_trp.nsv': ''},
 'listen d': {'e_trp.nsv': ''},
 'race custom': {'e_trp.nsv': ''},
 'continue custom': {'e_trp.nsv': ''},
 'wrong criminal': {'e_trp.nsv': ''},
 'shoulder criminal': {'e_trp.nsv': ''},
 'manage criminal': {'e_trp.nsv': ''},
 'dare criminal': {'e_trp.nsv': ''},
 'break criminal': {'e_trp.nsv': ''},
 'benefit criminal': {'e_trp.nsv': ''},
 'be create': {'e_trp.nsv': ''},
 'grass cow': {'e_trp.nsv': ''},
 'face_up courage': {'e_trp.nsv': ''},
 'deal county': {'e_trp.nsv': ''},
 'walk country': {'e_trp.nsv': ''},
 'tring country': {'e_trp.nsv': ''},
 'treasure country': {'e_trp.nsv': ''},
 'stick country': {'e_trp.nsv': ''},
 'shut country': {'e_trp.nsv': ''},
 'rebuting country': {'e_trp.nsv': ''},
 'lie country': {'e_trp.nsv': ''},
 'involve country': {'e_trp.nsv': ''},
 'have_in country': {'e_trp.nsv': ''},
 'do_out country': {'e_trp.nsv': ''},
 'dare country': {'e_trp.nsv': ''},
 'clean country': {'e_trp.nsv': ''},
 'sight cought': {'e_trp.nsv': ''},
 'see corrupt': {'e_trp.nsv': ''},
 'think corporation': {'e_trp.nsv': ''},
 'wind cool': {'e_trp.nsv': ''},
 'be convenient': {'e_trp.nsv': ''},
 'know convenient': {'e_trp.nsv': ''},
 'talk conversation': {'e_trp.nsv': ''},
 'dub conveniently': {'e_trp.nsv': ''},
 'increase control': {'e_trp.nsv': ''},
 'feel contrary': {'e_trp.nsv': ''},
 'take continuously': {'e_trp.nsv': ''},
 'send continuously': {'e_trp.nsv': ''},
 'study consumer': {'e_trp.nsv': ''},
 'high consumer': {'e_trp.nsv': ''},
 'write constitution': {'e_trp.nsv': ''},
 'anguish constant': {'e_trp.nsv': ''},
 'act consideration': {'e_trp.nsv': ''},
 'be consider': {'e_trp.nsv': ''},
 'call consequence': {'e_trp.nsv': ''},
 'do conscious': {'e_trp.nsv': ''},
 'be connented': {'e_trp.nsv': ''},
 'bless congratulation': {'e_trp.nsv': ''},
 'time condition': {'e_trp.nsv': ''},
 'agree condition': {'e_trp.nsv': ''},
 'look consciously': {'e_trp.nsv': ''},
 'vary conception': {'e_trp.nsv': ''},
 'lie concept': {'e_trp.nsv': ''},
 'shift concentration': {'e_trp.nsv': ''},
 'recall computer': {'e_trp.nsv': ''},
 'people computer': {'e_trp.nsv': ''},
 'deal computer': {'e_trp.nsv': ''},
 'firm completion': {'e_trp.nsv': ''},
 'waste commodity': {'e_trp.nsv': ''},
 'extend common': {'e_trp.nsv': ''},
 'spread commodity': {'e_trp.nsv': ''},
 'run commodity': {'e_trp.nsv': ''},
 'rob commodity': {'e_trp.nsv': ''},
 'rise commodity': {'e_trp.nsv': ''},
 'refer commodity': {'e_trp.nsv': ''},
 'reduce commodity': {'e_trp.nsv': ''},
 'protect commodity': {'e_trp.nsv': ''},
 'occuring commodity': {'e_trp.nsv': ''},
 'occur commodity': {'e_trp.nsv': ''},
 'lie commodity': {'e_trp.nsv': ''},
 'lead commodity': {'e_trp.nsv': ''},
 'kill commodity': {'e_trp.nsv': ''},
 'injure commodity': {'e_trp.nsv': ''},
 'impact commodity': {'e_trp.nsv': ''},
 'fill commodity': {'e_trp.nsv': ''},
 'effect commodity': {'e_trp.nsv': ''},
 'disturb commodity': {'e_trp.nsv': ''},
 'deprive commodity': {'e_trp.nsv': ''},
 'decrease commodity': {'e_trp.nsv': ''},
 'die acommodation': {'e_trp.nsv': ''},
 'hoe color': {'e_trp.nsv': ''},
 'shin color': {'e_trp.nsv': ''},
 'refer college': {'e_trp.nsv': ''},
 'participate college': {'e_trp.nsv': ''},
 'ornament college': {'e_trp.nsv': ''},
 'meddle college': {'e_trp.nsv': ''},
 'manage college': {'e_trp.nsv': ''},
 'refuse coffer': {'e_trp.nsv': ''},
 'rush cloud': {'e_trp.nsv': ''},
 'exhibit cloud': {'e_trp.nsv': ''},
 'weave clothes': {'e_trp.nsv': ''},
 'walk clothes': {'e_trp.nsv': ''},
 'slide clothes': {'e_trp.nsv': ''},
 'cover cloth': {'e_trp.nsv': ''},
 'cause close': {'e_trp.nsv': ''},
 'shout client': {'e_trp.nsv': ''},
 'build classroom': {'e_trp.nsv': ''},
 'row classmate': {'e_trp.nsv': ''},
 'rehearse classmate': {'e_trp.nsv': ''},
 'dream classmate': {'e_trp.nsv': ''},
 'say class': {'e_trp.nsv': ''},
 'choose class': {'e_trp.nsv': ''},
 'see civilization': {'e_trp.nsv': ''},
 'visit city': {'e_trp.nsv': ''},
 'continue circle': {'e_trp.nsv': ''},
 'take circumstance': {'e_trp.nsv': ''},
 'take chrysanthemum': {'e_trp.nsv': ''},
 'fit choice': {'e_trp.nsv': ''},
 'use choice': {'e_trp.nsv': ''},
 'pule child': {'e_trp.nsv': ''},
 'settle chicken': {'e_trp.nsv': ''},
 'get_along cheat': {'e_trp.nsv': ''},
 'begin cheat': {'e_trp.nsv': ''},
 'come chat': {'e_trp.nsv': ''},
 'finance charge': {'e_trp.nsv': ''},
 'run characteristic': {'e_trp.nsv': ''},
 'set character': {'e_trp.nsv': ''},
 'think change': {'e_trp.nsv': ''},
 'remember chance': {'e_trp.nsv': ''},
 'obtain chance': {'e_trp.nsv': ''},
 'have_in chance': {'e_trp.nsv': ''},
 'stand chair': {'e_trp.nsv': ''},
 'stand certificate': {'e_trp.nsv': ''},
 'fight century': {'e_trp.nsv': ''},
 'cover cecl': {'e_trp.nsv': ''},
 'fire cease': {'e_trp.nsv': ''},
 'do caution': {'e_trp.nsv': ''},
 'praise cause': {'e_trp.nsv': ''},
 'lie cause': {'e_trp.nsv': ''},
 'improve cause': {'e_trp.nsv': ''},
 'chance catch': {'e_trp.nsv': ''},
 'throw cat': {'e_trp.nsv': ''},
 'fidgetting cat': {'e_trp.nsv': ''},
 'do cash': {'e_trp.nsv': ''},
 'must carry': {'e_trp.nsv': ''},
 'do carot': {'e_trp.nsv': ''},
 'write card': {'e_trp.nsv': ''},
 'create car': {'e_trp.nsv': ''},
 'live capitalist': {'e_trp.nsv': ''},
 'gain capitalist': {'e_trp.nsv': ''},
 'accumulate capitalist': {'e_trp.nsv': ''},
 'do capacity': {'e_trp.nsv': ''},
 "see can't": {'e_trp.nsv': ''},
 "set can't": {'e_trp.nsv': ''},
 "say can't": {'e_trp.nsv': ''},
 "reach can't": {'e_trp.nsv': ''},
 "prove can't": {'e_trp.nsv': ''},
 "change can't": {'e_trp.nsv': ''},
 "be can't": {'e_trp.nsv': ''},
 'reach cancer': {'e_trp.nsv': ''},
 'think can': {'e_trp.nsv': ''},
 'solve can': {'e_trp.nsv': ''},
 'see_through can': {'e_trp.nsv': ''},
 'prove can': {'e_trp.nsv': ''},
 'improve can': {'e_trp.nsv': ''},
 'mark brand': {'e_trp.nsv': ''},
 'ape branch': {'e_trp.nsv': ''},
 'reel brain': {'e_trp.nsv': ''},
 'act brain': {'e_trp.nsv': ''},
 'improve world': {'e_trp.nsv': ''},
 'carry world': {'e_trp.nsv': ''},
 'time work': {'e_trp.nsv': ''},
 'suit work': {'e_trp.nsv': ''},
 'finish work': {'e_trp.nsv': ''},
 'contain word': {'e_trp.nsv': ''},
 'waiking woman': {'e_trp.nsv': ''},
 'keep window': {'e_trp.nsv': ''},
 'shout wind': {'e_trp.nsv': ''},
 'cause will': {'e_trp.nsv': ''},
 'die westerner': {'e_trp.nsv': ''},
 'know way': {'e_trp.nsv': ''},
 'use water': {'e_trp.nsv': ''},
 'reduce water': {'e_trp.nsv': ''},
 'increase water': {'e_trp.nsv': ''},
 'include water': {'e_trp.nsv': ''},
 'drink water': {'e_trp.nsv': ''},
 'need war': {'e_trp.nsv': ''},
 'contain wallet': {'e_trp.nsv': ''},
 'sweat wall': {'e_trp.nsv': ''},
 'leave waiter': {'e_trp.nsv': ''},
 'go villager': {'e_trp.nsv': ''},
 'request university': {'e_trp.nsv': ''},
 'be unequality': {'e_trp.nsv': ''},
 'show tv': {'e_trp.nsv': ''},
 'swim try': {'e_trp.nsv': ''},
 'stop tree': {'e_trp.nsv': ''},
 'have treasure': {'e_trp.nsv': ''},
 'make_up time': {'e_trp.nsv': ''},
 'long thousants': {'e_trp.nsv': ''},
 'influened thing': {'e_trp.nsv': ''},
 'impress thing': {'e_trp.nsv': ''},
 'decide thing': {'e_trp.nsv': ''},
 'play theory': {'e_trp.nsv': ''},
 'wait test': {'e_trp.nsv': ''},
 'draw term': {'e_trp.nsv': ''},
 'cut_off television': {'e_trp.nsv': ''},
 'help telephone': {'e_trp.nsv': ''},
 'respect teacher': {'e_trp.nsv': ''},
 'leak teacher': {'e_trp.nsv': ''},
 'revise task': {'e_trp.nsv': ''},
 'relax tao': {'e_trp.nsv': ''},
 'learn study': {'e_trp.nsv': ''},
 'obey student': {'e_trp.nsv': ''},
 'mean student': {'e_trp.nsv': ''},
 'bow student': {'e_trp.nsv': ''},
 'end_up struggle': {'e_trp.nsv': ''},
 'identify storekeeper': {'e_trp.nsv': ''},
 'increase standard': {'e_trp.nsv': ''},
 'try sportsman': {'e_trp.nsv': ''},
 'match sport': {'e_trp.nsv': ''},
 'keep sport': {'e_trp.nsv': ''},
 'be spon': {'e_trp.nsv': ''},
 'show spirit': {'e_trp.nsv': ''},
 'arrive spirit': {'e_trp.nsv': ''},
 'name song': {'e_trp.nsv': ''},
 'be solider': {'e_trp.nsv': ''},
 'sacrifice soldier': {'e_trp.nsv': ''},
 'welcome society': {'e_trp.nsv': ''},
 'stride society': {'e_trp.nsv': ''},
 'reach society': {'e_trp.nsv': ''},
 'punish society': {'e_trp.nsv': ''},
 'inquire society': {'e_trp.nsv': ''},
 'improve society': {'e_trp.nsv': ''},
 'follow skill': {'e_trp.nsv': ''},
 'be sit': {'e_trp.nsv': ''},
 'let sister': {'e_trp.nsv': ''},
 'retributed sin': {'e_trp.nsv': ''},
 'be similarily': {'e_trp.nsv': ''},
 'lie school': {'e_trp.nsv': ''},
 'impress scences': {'e_trp.nsv': ''},
 'tell saying': {'e_trp.nsv': ''},
 'say saying': {'e_trp.nsv': ''},
 'kill savage': {'e_trp.nsv': ''},
 'go savage': {'e_trp.nsv': ''},
 'eat savage': {'e_trp.nsv': ''},
 'know samplesgetting': {'e_trp.nsv': ''},
 'change room': {'e_trp.nsv': ''},
 'strike rock': {'e_trp.nsv': ''},
 'reflect reward': {'e_trp.nsv': ''},
 'encourage respect': {'e_trp.nsv': ''},
 'pass_away relative': {'e_trp.nsv': ''},
 'be rehabilated': {'e_trp.nsv': ''},
 'cause reason': {'e_trp.nsv': ''},
 'read radio': {'e_trp.nsv': ''},
 'programme radio': {'e_trp.nsv': ''},
 'make punishment': {'e_trp.nsv': ''},
 'emerge project': {'e_trp.nsv': ''},
 'benefit programme': {'e_trp.nsv': ''},
 'establish professionalization': {'e_trp.nsv': ''},
 'fake product': {'e_trp.nsv': ''},
 'commit prinsoners': {'e_trp.nsv': ''},
 'make practise': {'e_trp.nsv': ''},
 'be practise': {'e_trp.nsv': ''},
 'improve practice': {'e_trp.nsv': ''},
 'develop population': {'e_trp.nsv': ''},
 'make polution': {'e_trp.nsv': ''},
 'waste pollution': {'e_trp.nsv': ''},
 'develop policy': {'e_trp.nsv': ''},
 'quicken policeman': {'e_trp.nsv': ''},
 'rise point': {'e_trp.nsv': ''},
 'increase point': {'e_trp.nsv': ''},
 'spare plent': {'e_trp.nsv': ''},
 'complete playground': {'e_trp.nsv': ''},
 'get perseverance': {'e_trp.nsv': ''},
 'celebrate period': {'e_trp.nsv': ''},
 'hang_up people': {'e_trp.nsv': ''},
 'geting people': {'e_trp.nsv': ''},
 'damage people': {'e_trp.nsv': ''},
 'cost patient': {'e_trp.nsv': ''},
 'even parent': {'e_trp.nsv': ''},
 'resolve panelty': {'e_trp.nsv': ''},
 'give_up ou': {'e_trp.nsv': ''},
 'give numbers': {'e_trp.nsv': ''},
 'free no': {'e_trp.nsv': ''},
 'compete newspaper': {'e_trp.nsv': ''},
 'sport necessary': {'e_trp.nsv': ''},
 'suffer nature': {'e_trp.nsv': ''},
 'shrink nature': {'e_trp.nsv': ''},
 'show nature': {'e_trp.nsv': ''},
 'respond nature': {'e_trp.nsv': ''},
 'refer nature': {'e_trp.nsv': ''},
 'dance mum': {'e_trp.nsv': ''},
 'say mouse': {'e_trp.nsv': ''},
 'impel motive': {'e_trp.nsv': ''},
 'spend motherland': {'e_trp.nsv': ''},
 'reduce mortality': {'e_trp.nsv': ''},
 'decrease mortality': {'e_trp.nsv': ''},
 'belowing mortality': {'e_trp.nsv': ''},
 'belowed mortality': {'e_trp.nsv': ''},
 'have mooncake': {'e_trp.nsv': ''},
 'up monkey': {'e_trp.nsv': ''},
 'lead money': {'e_trp.nsv': ''},
 'judge money': {'e_trp.nsv': ''},
 'bother money': {'e_trp.nsv': ''},
 'round mix': {'e_trp.nsv': ''},
 'baby mean': {'e_trp.nsv': ''},
 'be matchs': {'e_trp.nsv': ''},
 'fly manager': {'e_trp.nsv': ''},
 'waste make': {'e_trp.nsv': ''},
 'be main': {'e_trp.nsv': ''},
 'be lifes': {'e_trp.nsv': ''},
 'increase life': {'e_trp.nsv': ''},
 'recieved letter': {'e_trp.nsv': ''},
 'let_out leawies': {'e_trp.nsv': ''},
 'may lead': {'e_trp.nsv': ''},
 'grow language': {'e_trp.nsv': ''},
 'decrease land': {'e_trp.nsv': ''},
 'name lady': {'e_trp.nsv': ''},
 'build lab': {'e_trp.nsv': ''},
 'do knowleguge': {'e_trp.nsv': ''},
 'like kind': {'e_trp.nsv': ''},
 'make intelligence': {'e_trp.nsv': ''},
 'job ideal': {'e_trp.nsv': ''},
 'pay heed': {'e_trp.nsv': ''},
 'congratulate heartity': {'e_trp.nsv': ''},
 'grain health': {'e_trp.nsv': ''},
 'make haster': {'e_trp.nsv': ''},
 'result haste': {'e_trp.nsv': ''},
 'bring haste': {'e_trp.nsv': ''},
 'change great': {'e_trp.nsv': ''},
 'wish good': {'e_trp.nsv': ''},
 'rest good': {'e_trp.nsv': ''},
 'condition good': {'e_trp.nsv': ''},
 'begin good': {'e_trp.nsv': ''},
 'may get': {'e_trp.nsv': ''},
 'know get': {'e_trp.nsv': ''},
 'find general': {'e_trp.nsv': ''},
 'improve gain': {'e_trp.nsv': ''},
 'develop gain': {'e_trp.nsv': ''},
 'change gain': {'e_trp.nsv': ''},
 'water fresh': {'e_trp.nsv': ''},
 'match football': {'e_trp.nsv': ''},
 'eat food': {'e_trp.nsv': ''},
 'touch fist': {'e_trp.nsv': ''},
 'smash fist': {'e_trp.nsv': ''},
 'examine first': {'e_trp.nsv': ''},
 'happen festival': {'e_trp.nsv': ''},
 'hand festival': {'e_trp.nsv': ''},
 'get_along father': {'e_trp.nsv': ''},
 'poluted factory': {'e_trp.nsv': ''},
 'clean factory': {'e_trp.nsv': ''},
 'shrink fact': {'e_trp.nsv': ''},
 'save euthanasia': {'e_trp.nsv': ''},
 'release euthanasia': {'e_trp.nsv': ''},
 'invite euthanasia': {'e_trp.nsv': ''},
 'give euthanasia': {'e_trp.nsv': ''},
 'deteriorate environment': {'e_trp.nsv': ''},
 'say elephant': {'e_trp.nsv': ''},
 'become electric': {'e_trp.nsv': ''},
 'lie doubtely': {'e_trp.nsv': ''},
 'end doctor': {'e_trp.nsv': ''},
 'qualify degree': {'e_trp.nsv': ''},
 'produce degree': {'e_trp.nsv': ''},
 'see decreased': {'e_trp.nsv': ''},
 'have darkmen': {'e_trp.nsv': ''},
 'control dam': {'e_trp.nsv': ''},
 'call custom': {'e_trp.nsv': ''},
 'tend crime': {'e_trp.nsv': ''},
 'bring crime': {'e_trp.nsv': ''},
 'legalize country': {'e_trp.nsv': ''},
 'decline country': {'e_trp.nsv': ''},
 'take contries': {'e_trp.nsv': ''},
 'begin competation': {'e_trp.nsv': ''},
 'take commodity': {'e_trp.nsv': ''},
 'sell commodity': {'e_trp.nsv': ''},
 'do commodity': {'e_trp.nsv': ''},
 'die commodity': {'e_trp.nsv': ''},
 'place choice': {'e_trp.nsv': ''},
 'visit chance': {'e_trp.nsv': ''},
 'pratise chance': {'e_trp.nsv': ''},
 'take certainlly': {'e_trp.nsv': ''},
 'lead cause': {'e_trp.nsv': ''},
 'send card': {'e_trp.nsv': ''},
 'jacket boy': {'e_trp.nsv': ''},
 'stack box': {'e_trp.nsv': ''},
 'house box': {'e_trp.nsv': ''},
 'be bourgeoisie': {'e_trp.nsv': ''},
 'change boulder': {'e_trp.nsv': ''},
 'put boredom': {'e_trp.nsv': ''},
 'have boredom': {'e_trp.nsv': ''},
 'stuff bookcase': {'e_trp.nsv': ''},
 'cut book': {'e_trp.nsv': ''},
 'like bodys': {'e_trp.nsv': ''},
 'wither body': {'e_trp.nsv': ''},
 'straighten body': {'e_trp.nsv': ''},
 'laugh body': {'e_trp.nsv': ''},
 'hurry body': {'e_trp.nsv': ''},
 'dress body': {'e_trp.nsv': ''},
 'close body': {'e_trp.nsv': ''},
 'build body': {'e_trp.nsv': ''},
 'answer body': {'e_trp.nsv': ''},
 'match boat': {'e_trp.nsv': ''},
 'compete boat': {'e_trp.nsv': ''},
 'lift blast': {'e_trp.nsv': ''},
 'coat black': {'e_trp.nsv': ''},
 'rate birth': {'e_trp.nsv': ''},
 'clean bike': {'e_trp.nsv': ''},
 'make bight': {'e_trp.nsv': ''},
 'equip bicyclist': {'e_trp.nsv': ''},
 'ride bicycle': {'e_trp.nsv': ''},
 'refuse bick': {'e_trp.nsv': ''},
 'lose bick': {'e_trp.nsv': ''},
 'walk benifits': {'e_trp.nsv': ''},
 'give belief': {'e_trp.nsv': ''},
 'be befor': {'e_trp.nsv': ''},
 'be beatiful': {'e_trp.nsv': ''},
 'oil bearing': {'e_trp.nsv': ''},
 'gild beam': {'e_trp.nsv': ''},
 'flash beam': {'e_trp.nsv': ''},
 'be beacuse': {'e_trp.nsv': ''},
 'use battlefield': {'e_trp.nsv': ''},
 'wash bath': {'e_trp.nsv': ''},
 'game basketball': {'e_trp.nsv': ''},
 'come basis': {'e_trp.nsv': ''},
 'pump basin': {'e_trp.nsv': ''},
 'appear base': {'e_trp.nsv': ''},
 'match ball': {'e_trp.nsv': ''},
 'keep balance': {'e_trp.nsv': ''},
 'be baggio': {'e_trp.nsv': ''},
 'lie bag': {'e_trp.nsv': ''},
 'be baddage': {'e_trp.nsv': ''},
 'think aways': {'e_trp.nsv': ''},
 'help aways': {'e_trp.nsv': ''},
 'give aways': {'e_trp.nsv': ''},
 'condemn avoide': {'e_trp.nsv': ''},
 'surpass avantages': {'e_trp.nsv': ''},
 'be avantages': {'e_trp.nsv': ''},
 'untill authanasia': {'e_trp.nsv': ''},
 'rule austria': {'e_trp.nsv': ''},
 'rely audience': {'e_trp.nsv': ''},
 'work attention': {'e_trp.nsv': ''},
 'give atmosphere': {'e_trp.nsv': ''},
 'fill atmosphere': {'e_trp.nsv': ''},
 'encourage atmosphere': {'e_trp.nsv': ''},
 'surmount athlete': {'e_trp.nsv': ''},
 'tie assignment': {'e_trp.nsv': ''},
 'make aspect': {'e_trp.nsv': ''},
 'change aspect': {'e_trp.nsv': ''},
 'flow arubptly': {'e_trp.nsv': ''},
 'write article': {'e_trp.nsv': ''},
 'skim article': {'e_trp.nsv': ''},
 'shoot arrow': {'e_trp.nsv': ''},
 'begin arrival': {'e_trp.nsv': ''},
 'have arosen': {'e_trp.nsv': ''},
 'work army': {'e_trp.nsv': ''},
 'savage army': {'e_trp.nsv': ''},
 'match answer': {'e_trp.nsv': ''},
 'make_out answer': {'e_trp.nsv': ''},
 'answer answer': {'e_trp.nsv': ''},
 'have anothers': {'e_trp.nsv': ''},
 'onticed anlan': {'e_trp.nsv': ''},
 'let animal': {'e_trp.nsv': ''},
 'get_up animal': {'e_trp.nsv': ''},
 'ask angried': {'e_trp.nsv': ''},
 'live_on ancient': {'e_trp.nsv': ''},
 'be amphsis': {'e_trp.nsv': ''},
 'face amout': {'e_trp.nsv': ''},
 'water amount': {'e_trp.nsv': ''},
 'extend amount': {'e_trp.nsv': ''},
 'get amnesty': {'e_trp.nsv': ''},
 'come amnesty': {'e_trp.nsv': ''},
 'have ammout': {'e_trp.nsv': ''},
 'turn amateur': {'e_trp.nsv': ''},
 'choose alse': {'e_trp.nsv': ''},
 'have alredy': {'e_trp.nsv': ''},
 'be alot': {'e_trp.nsv': ''},
 'people all': {'e_trp.nsv': ''},
 'heart all': {'e_trp.nsv': ''},
 'live aim': {'e_trp.nsv': ''},
 'arrive aim': {'e_trp.nsv': ''},
 'lose ailment': {'e_trp.nsv': ''},
 'know aid': {'e_trp.nsv': ''},
 'destruct agriculture': {'e_trp.nsv': ''},
 'disappear agony': {'e_trp.nsv': ''},
 'confront agony': {'e_trp.nsv': ''},
 'love age': {'e_trp.nsv': ''},
 'leave age': {'e_trp.nsv': ''},
 'arrive age': {'e_trp.nsv': ''},
 'have afternoon': {'e_trp.nsv': ''},
 'drift affection': {'e_trp.nsv': ''},
 'prove advice': {'e_trp.nsv': ''},
 'mislead advertising': {'e_trp.nsv': ''},
 'influence advertisement': {'e_trp.nsv': ''},
 'fill advertisement': {'e_trp.nsv': ''},
 'cheat advertisement': {'e_trp.nsv': ''},
 'become advertisement': {'e_trp.nsv': ''},
 'overweigh advantage': {'e_trp.nsv': ''},
 'bring advantage': {'e_trp.nsv': ''},
 'be adv': {'e_trp.nsv': ''},
 'take aduts': {'e_trp.nsv': ''},
 'talk adult': {'e_trp.nsv': ''},
 'sweep adult': {'e_trp.nsv': ''},
 'offer adult': {'e_trp.nsv': ''},
 'carry adult': {'e_trp.nsv': ''},
 'fail adolescent': {'e_trp.nsv': ''},
 'treat administrator': {'e_trp.nsv': ''},
 'think administrater': {'e_trp.nsv': ''},
 'be adjudger': {'e_trp.nsv': ''},
 'have ad-designers': {'e_trp.nsv': ''},
 'have addcition': {'e_trp.nsv': ''},
 'true acurately': {'e_trp.nsv': ''},
 'answer activly': {'e_trp.nsv': ''},
 'widen activity': {'e_trp.nsv': ''},
 'serve activity': {'e_trp.nsv': ''},
 'occupy activity': {'e_trp.nsv': ''},
 'lose activity': {'e_trp.nsv': ''},
 'enable activity': {'e_trp.nsv': ''},
 'eat activity': {'e_trp.nsv': ''},
 'color activity': {'e_trp.nsv': ''},
 'protect activist': {'e_trp.nsv': ''},
 'preach activist': {'e_trp.nsv': ''},
 'enhance action': {'e_trp.nsv': ''},
 'cut_down action': {'e_trp.nsv': ''},
 'control action': {'e_trp.nsv': ''},
 'go acting': {'e_trp.nsv': ''},
 'turn acquaintance': {'e_trp.nsv': ''},
 'ask acquainces': {'e_trp.nsv': ''},
 'pay achiever': {'e_trp.nsv': ''},
 'stand achievement': {'e_trp.nsv': ''},
 'reach achievement': {'e_trp.nsv': ''},
 'prove achievement': {'e_trp.nsv': ''},
 'may achievement': {'e_trp.nsv': ''},
 'include achievement': {'e_trp.nsv': ''},
 'waste accident': {'e_trp.nsv': ''},
 'teach accident': {'e_trp.nsv': ''},
 'like accident': {'e_trp.nsv': ''},
 'become accident': {'e_trp.nsv': ''},
 'attribute accident': {'e_trp.nsv': ''},
 'be abuntent': {'e_trp.nsv': ''},
 'mean abortion': {'e_trp.nsv': ''},
 'arouse abortion': {'e_trp.nsv': ''},
 'look aborigine': {'e_trp.nsv': ''},
 'tell abliged': {'e_trp.nsv': ''},
 'rise ability': {'e_trp.nsv': ''},
 'develop ability': {'e_trp.nsv': ''},
 'afford ability': {'e_trp.nsv': ''},
 'shop tailor': {'e_trp.nsv': ''},
 'account take': {'e_trp.nsv': ''},
 'care take': {'e_trp.nsv': ''},
 'manage tao': {'e_trp.nsv': ''},
 'chink teacher': {'e_trp.nsv': ''},
 'disrespect teacher': {'e_trp.nsv': ''},
 'underlook teacher': {'e_trp.nsv': ''},
 'untill teacher': {'e_trp.nsv': ''},
 'out team': {'e_trp.nsv': ''},
 'improve technic': {'e_trp.nsv': ''},
 'develop technical': {'e_trp.nsv': ''},
 'rise technology': {'e_trp.nsv': ''},
 'progress technologys': {'e_trp.nsv': ''},
 'feed television': {'e_trp.nsv': ''},
 'pass_on television': {'e_trp.nsv': ''},
 'persist television': {'e_trp.nsv': ''},
 'poison television': {'e_trp.nsv': ''},
 'be tempereture': {'e_trp.nsv': ''},
 'reach tempiture': {'e_trp.nsv': ''},
 'be temprature': {'e_trp.nsv': ''},
 'zero tempreture': {'e_trp.nsv': ''},
 'spring tennis': {'e_trp.nsv': ''},
 'please tennise': {'e_trp.nsv': ''},
 'pass term': {'e_trp.nsv': ''},
 'telephone thanks': {'e_trp.nsv': ''},
 'book theft': {'e_trp.nsv': ''},
 'give theft': {'e_trp.nsv': ''},
 'act thing': {'e_trp.nsv': ''},
 'challenge thing': {'e_trp.nsv': ''},
 'crawl thing': {'e_trp.nsv': ''},
 'eat thing': {'e_trp.nsv': ''},
 'paper thing': {'e_trp.nsv': ''},
 'plant thing': {'e_trp.nsv': ''},
 'pollute thing': {'e_trp.nsv': ''},
 'time thing': {'e_trp.nsv': ''},
 'say think': {'e_trp.nsv': ''},
 'value think': {'e_trp.nsv': ''},
 'reason third': {'e_trp.nsv': ''},
 'own thire': {'e_trp.nsv': ''},
 'relate thoses': {'e_trp.nsv': ''},
 'say thought': {'e_trp.nsv': ''},
 'feel thousand': {'e_trp.nsv': ''},
 'need thousand': {'e_trp.nsv': ''},
 'receive thousand': {'e_trp.nsv': ''},
 'send throat': {'e_trp.nsv': ''},
 'leave ticket': {'e_trp.nsv': ''},
 'remember till': {'e_trp.nsv': ''},
 'retire till': {'e_trp.nsv': ''},
 'age time': {'e_trp.nsv': ''},
 'cram time': {'e_trp.nsv': ''},
 'dance time': {'e_trp.nsv': ''},
 'file time': {'e_trp.nsv': ''},
 'flyed time': {'e_trp.nsv': ''},
 'get_up time': {'e_trp.nsv': ''},
 'know time': {'e_trp.nsv': ''},
 'practice time': {'e_trp.nsv': ''},
 'like topic': {'e_trp.nsv': ''},
 'like toy': {'e_trp.nsv': ''},
 'like tree': {'e_trp.nsv': ''},
 'sparkle trick': {'e_trp.nsv': ''},
 'decide trip': {'e_trp.nsv': ''},
 'job trouble': {'e_trp.nsv': ''},
 'look trouserses': {'e_trp.nsv': ''},
 'match two': {'e_trp.nsv': ''},
 'study two': {'e_trp.nsv': ''},
 'teach two': {'e_trp.nsv': ''},
 'may uncertainty': {'e_trp.nsv': ''},
 'do undoutably': {'e_trp.nsv': ''},
 'be undoutbly': {'e_trp.nsv': ''},
 'harm undoutbly': {'e_trp.nsv': ''},
 'get undoutedly': {'e_trp.nsv': ''},
 'live undoutedly': {'e_trp.nsv': ''},
 'pay unequal': {'e_trp.nsv': ''},
 'may unequality': {'e_trp.nsv': ''},
 'take unequality': {'e_trp.nsv': ''},
 'bring unequalness': {'e_trp.nsv': ''},
 'find unexpectly': {'e_trp.nsv': ''},
 'couple university': {'e_trp.nsv': ''},
 'work urually': {'e_trp.nsv': ''},
 'be usaully': {'e_trp.nsv': ''},
 'lead vainity': {'e_trp.nsv': ''},
 'cause varities': {'e_trp.nsv': ''},
 'contribute varities': {'e_trp.nsv': ''},
 'be verry': {'e_trp.nsv': ''},
 'take volutarily': {'e_trp.nsv': ''},
 'buy want': {'e_trp.nsv': ''},
 'forget want': {'e_trp.nsv': ''},
 'know want': {'e_trp.nsv': ''},
 'say want': {'e_trp.nsv': ''},
 'share want': {'e_trp.nsv': ''},
 'be warm': {'e_trp.nsv': ''},
 'ask warriers': {'e_trp.nsv': ''},
 'bicycle washing-machine': {'e_trp.nsv': ''},
 'flow wate-water': {'e_trp.nsv': ''},
 'be wate': {'e_trp.nsv': ''},
 'be wated': {'e_trp.nsv': ''},
 'explode water-heater': {'e_trp.nsv': ''},
 'beeing water': {'e_trp.nsv': ''},
 'acknowledge way': {'e_trp.nsv': ''},
 'choose way': {'e_trp.nsv': ''},
 'cure way': {'e_trp.nsv': ''},
 'fleece way': {'e_trp.nsv': ''},
 'live wealth': {'e_trp.nsv': ''},
 'uniform wear': {'e_trp.nsv': ''},
 'effect weather': {'e_trp.nsv': ''},
 'rain weather': {'e_trp.nsv': ''},
 'be weaver': {'e_trp.nsv': ''},
 'be weigh': {'e_trp.nsv': ''},
 'be weling': {'e_trp.nsv': ''},
 'can wheather': {'e_trp.nsv': ''},
 'turn wheather': {'e_trp.nsv': ''},
 'hold while': {'e_trp.nsv': ''},
 'untill while': {'e_trp.nsv': ''},
 'be whis': {'e_trp.nsv': ''},
 'mean wich': {'e_trp.nsv': ''},
 'contrive will': {'e_trp.nsv': ''},
 'worry will': {'e_trp.nsv': ''},
 'fly wind': {'e_trp.nsv': ''},
 'shim wing': {'e_trp.nsv': ''},
 'act word': {'e_trp.nsv': ''},
 'neighbour word': {'e_trp.nsv': ''},
 'recite word': {'e_trp.nsv': ''},
 'smash word': {'e_trp.nsv': ''},
 'do worder': {'e_trp.nsv': ''},
 'tire work': {'e_trp.nsv': ''},
 'want work': {'e_trp.nsv': ''},
 'bjuilting worker': {'e_trp.nsv': ''},
 'exert workload': {'e_trp.nsv': ''},
 'decrease workunits': {'e_trp.nsv': ''},
 'advance world': {'e_trp.nsv': ''},
 'relong world': {'e_trp.nsv': ''},
 'varing world': {'e_trp.nsv': ''},
 'open light': {'e_trp.dobj': ''},
 'AIDS-related': {'jj_ed': ''},
 'Argus-eyed': {'jj_ed': ''},
 'HIV-related': {'jj_ed': ''},
 'Janus-faced': {'jj_ed': ''},
 'L-shaped': {'jj_ed': ''},
 'Reformed': {'jj_ed': ''},
 'V-shaped': {'jj_ed': ''},
 'X-rated': {'jj_ed': ''},
 'abashed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'abbreviated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'able-bodied': {'jj_ed': ''},
 'above-mentioned': {'jj_ed': ''},
 'abridged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'absent-minded': {'jj_ed': ''},
 'abstracted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'accented': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'acclaimed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'accomplished': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'accredited': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'accursed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'acned': {'jj_ed': ''},
 'acquainted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'action-packed': {'jj_ed': ''},
 'affianced': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'aforementioned': {'jj_ed': ''},
 'aged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'aggrieved': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'agitated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'agonised': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'agonized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'air-conditioned': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'air-cooled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'air-dried': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'alienated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'alleged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'allied': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'allotted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'almond-shaped': {'jj_ed': ''},
 'amended': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'anguished': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'animated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'annualized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'antiquated': {'jj_ed': ''},
 'antiqued': {'jj_ed': ''},
 'antlered': {'jj_ed': ''},
 'appalled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'armored': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'armour-plated': {'jj_ed': ''},
 'armoured': {'jj_ed': ''},
 'articulated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'ashen-faced': {'jj_ed': ''},
 'assorted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'attired': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'attuned': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'automated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'avowed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'awed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'baby-faced': {'jj_ed': ''},
 'backhanded': {'jj_ed': ''},
 'bad-tempered': {'jj_ed': ''},
 'bald-faced': {'jj_ed': ''},
 'bannered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'barbed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'bare-assed': {'jj_ed': ''},
 'barefaced': {'jj_ed': ''},
 'bareheaded': {'jj_ed': ''},
 'barelegged': {'jj_ed': ''},
 'barrel-chested': {'jj_ed': ''},
 'barrel-shaped': {'jj_ed': ''},
 'bated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'battered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'battery-operated': {'jj_ed': ''},
 'battery-powered': {'jj_ed': ''},
 'battle-scarred': {'jj_ed': ''},
 'beaded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'becalmed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'bedazzled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'bedraggled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'beetle-browed': {'jj_ed': ''},
 'befuddled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'begrimed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'bejewelled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'belated': {'jj_ed': ''},
 'beleaguered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'bell-shaped': {'jj_ed': ''},
 'bemused': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'bended': {'jj_ed': ''},
 'benighted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'benumbed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'bereaved': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'beribboned': {'jj_ed': ''},
 'besotted': {'jj_ed': ''},
 'bespectacled': {'jj_ed': ''},
 'bevelled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'bewhiskered': {'jj_ed': ''},
 'big-boned': {'jj_ed': ''},
 'big-headed': {'jj_ed': ''},
 'big-hearted': {'jj_ed': ''},
 'bigheaded': {'jj_ed': ''},
 'bigoted': {'jj_ed': ''},
 'birdbrained': {'jj_ed': ''},
 'bite-sized': {'jj_ed': ''},
 'bitmapped': {'jj_ed': ''},
 'blasted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'blemished': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'blightâ€§ed': {'jj_ed': ''},
 'blinkered': {'jj_ed': ''},
 'blistered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'bloated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'blood-red': {'jj_ed': ''},
 'bloodstained': {'jj_ed': ''},
 'bloody-minded': {'jj_ed': ''},
 'blotched': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'blue-blooded': {'jj_ed': ''},
 'blurred': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'boat-shaped': {'jj_ed': ''},
 'boldfaced': {'jj_ed': ''},
 'bonded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'booby-trapped': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'boss-eyed': {'jj_ed': ''},
 'bottle-fed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'bowlegged': {'jj_ed': ''},
 'boxed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'braided': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'brain-damaged': {'jj_ed': ''},
 'braised': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'branded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'brazen-faced': {'jj_ed': ''},
 'breaded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'brick red': {'jj_ed': ''},
 'brindled': {'jj_ed': ''},
 'broad-based': {'jj_ed': ''},
 'broad-brimmed': {'jj_ed': ''},
 'broad-shouldered': {'jj_ed': ''},
 'broadminded': {'jj_ed': ''},
 'brocaded': {'jj_ed': ''},
 'broken-hearted': {'jj_ed': ''},
 'brokenhearted': {'jj_ed': ''},
 'bronzed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'bruised': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'bug-eyed': {'jj_ed': ''},
 'bugeyed': {'jj_ed': ''},
 'buggered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'bull-headed': {'jj_ed': ''},
 'bullet-headed': {'jj_ed': ''},
 'bullnecked': {'jj_ed': ''},
 'bungled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'burnished': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'bushed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'busted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'cack-handed': {'jj_ed': ''},
 'calloused': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'camphorated': {'jj_ed': ''},
 'canopied': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'cantilevered': {'jj_ed': ''},
 'capsulated': {'jj_ed': ''},
 'caramelized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'carbonated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'carbonized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'cash-starved': {'jj_ed': ''},
 'cash-strapped': {'jj_ed': ''},
 'castellated': {'jj_ed': ''},
 'castled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'centered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'centralized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'centrally heated': {'jj_ed': ''},
 'centred': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'certificated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'chambered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'chapped': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'charred': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'chartered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'checkered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'chequered': {'jj_ed': ''},
 'cherry-red': {'jj_ed': ''},
 'chipped': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'chocolate-coloured': {'jj_ed': ''},
 'choked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'chromium-plated': {'jj_ed': ''},
 'chuffed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'cigar-shaped': {'jj_ed': ''},
 'ciliated': {'jj_ed': ''},
 'citrated': {'jj_ed': ''},
 'civilised': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'clean-limbed': {'jj_ed': ''},
 'clear-headed': {'jj_ed': ''},
 'clear-sighted': {'jj_ed': ''},
 'cliched': {'jj_ed': ''},
 'clipped': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'cloaked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'clogged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'cloistered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'close-cropped': {'jj_ed': ''},
 'close-grained': {'jj_ed': ''},
 'close-hauled': {'jj_ed': ''},
 'close-mouthed': {'jj_ed': ''},
 'closed captioned': {'jj_ed': ''},
 'closemouthed': {'jj_ed': ''},
 'cluttered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'coal-fired': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'cobbled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'cobwebbed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'cockeyed': {'jj_ed': ''},
 'cocooned': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'coed': {'jj_ed': ''},
 'coiled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'coin-operated': {'jj_ed': ''},
 'cold-blooded': {'jj_ed': ''},
 'cold-hearted': {'jj_ed': ''},
 'colonnaded': {'jj_ed': ''},
 'colour coded': {'jj_ed': ''},
 'compartmentalized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'compressed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'computer-aided': {'jj_ed': ''},
 'computer-assisted': {'jj_ed': ''},
 'computer-controlled': {'jj_ed': ''},
 'computer-generated': {'jj_ed': ''},
 'conceited': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'condemned': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'congested': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'constricted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'contaminated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'contoured': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'contrived': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'controlled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'contused': {'jj_ed': ''},
 'convoluted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'cool-headed': {'jj_ed': ''},
 'coordinated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'copper-bottomed': {'jj_ed': ''},
 'corded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'corn-fed': {'jj_ed': ''},
 'corrugated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'corseted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'countrified': {'jj_ed': ''},
 'country-bred': {'jj_ed': ''},
 'cowled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'crabbed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'crammed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'cramped': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'crazed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'creased': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'credentialled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'crescent-shaped': {'jj_ed': ''},
 'crested': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'crinkled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'crippled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'crocked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'crooked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'cross-eyed': {'jj_ed': ''},
 'cross-grained': {'jj_ed': ''},
 'cross-legged': {'jj_ed': ''},
 'crumpled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'crusted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'crystallized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'cultured': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'curly-haired': {'jj_ed': ''},
 'curried': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'cut and dried': {'jj_ed': ''},
 'damned': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'dandified': {'jj_ed': ''},
 'dappled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'dark-haired': {'jj_ed': ''},
 'dark-skinned': {'jj_ed': ''},
 'darned': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'dazed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'deadlocked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'debauched': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'decaffeinated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'decentralized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'declassified': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'deconsecrated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'deep-chested': {'jj_ed': ''},
 'deep-rooted': {'jj_ed': ''},
 'deep-seated': {'jj_ed': ''},
 'deformed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'defrocked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'dehydrated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'dejected': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'demented': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'demoralized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'denatured': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'depraved': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'deprived': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'deranged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'desiccated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'desolated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'destined': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'detached': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'dewy-eyed': {'jj_ed': ''},
 'diamond-shaped': {'jj_ed': ''},
 'digitised': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'digitized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'dignified': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'dilapidated': {'jj_ed': ''},
 'dim-witted': {'jj_ed': ''},
 'dimpled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'dirty-minded': {'jj_ed': ''},
 'disabled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'disaffected': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'discombobulated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'disconcerted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'disconnected': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'discontented': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'disembodied': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'disenchanted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'disenfranchised': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'disengaged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'disfigured': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'disgruntled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'disheveled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'dishevelled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'disillusioned': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'disinclined': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'disinterested': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'disjointed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'dislocated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'dismayed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'disordered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'disorganized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'disoriented': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'dispirited': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'displeased': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'disposed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'dissatisfied': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'dissipated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'distended': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'disunited': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'disused': {'jj_ed': ''},
 'dog-eared': {'jj_ed': ''},
 'dog-tired': {'jj_ed': ''},
 'domed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'domesticated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'domiciled': {'jj_ed': ''},
 'doomed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'double-breasted': {'jj_ed': ''},
 'double-edged': {'jj_ed': ''},
 'double-jointed': {'jj_ed': ''},
 'downhearted': {'jj_ed': ''},
 'drained': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'dreaded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'dreadlocked': {'jj_ed': ''},
 'drenched': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'dry-eyed': {'jj_ed': ''},
 'dumbfounded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'dyed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'eagle-eyed': {'jj_ed': ''},
 'eared': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'earnings-related': {'jj_ed': ''},
 'educated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'egg-shaped': {'jj_ed': ''},
 'elasticated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'elated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'electrified': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'elevated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'emaciated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'emancipated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'embattled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'embittered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'emblazoned': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'embossed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'empty-handed': {'jj_ed': ''},
 'empty-headed': {'jj_ed': ''},
 'enamoured': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'encrusted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'encrypted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'endangered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'enervated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'enfeebled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'enfranchised': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'engorged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'engrossed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'enlisted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'enmeshed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'enraptured': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'enriched': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'entangled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'entrenched': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'esteemed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'estranged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'etiolated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'even-handed': {'jj_ed': ''},
 'even-tempered': {'jj_ed': ''},
 'evil-minded': {'jj_ed': ''},
 'exaggerated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'exalted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'exhilarated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'exploded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'export-oriented': {'jj_ed': ''},
 'expurgated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'extroverted': {'jj_ed': ''},
 'fabled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'faceted': {'jj_ed': ''},
 'fagged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'faint-hearted': {'jj_ed': ''},
 'fair-minded': {'jj_ed': ''},
 'fair-sized': {'jj_ed': ''},
 'famed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'famished': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'fan-shaped': {'jj_ed': ''},
 'fanged': {'jj_ed': ''},
 'far-fetched': {'jj_ed': ''},
 'far-sighted': {'jj_ed': ''},
 'fat-headed': {'jj_ed': ''},
 'fated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'fatigued': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'favored': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'featherbrained': {'jj_ed': ''},
 'feeble-minded': {'jj_ed': ''},
 'fevered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'figured': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'filter-tipped': {'jj_ed': ''},
 'finned': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'fissured': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'fixated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'fixed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'flabbergasted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'flagged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'flame-coloured': {'jj_ed': ''},
 'flared': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'flat-footed': {'jj_ed': ''},
 'flattened': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'flattered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'flavored': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'flawed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'flecked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'fledged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'flesh-coloured': {'jj_ed': ''},
 'flounced': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'flummoxed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'flurried': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'flushed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'flustered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'fluted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'focussed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'foliated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'footed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'forearmed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'foreign-owned': {'jj_ed': ''},
 'foreshortened': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'formatted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'fossilised': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'foul-mouthed': {'jj_ed': ''},
 'four-engined': {'jj_ed': ''},
 'four-footed': {'jj_ed': ''},
 'fractured': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'fragmented': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'frayed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'frazzled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'freckled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'free-spirited': {'jj_ed': ''},
 'freeze-dried': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'frenzied': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'fretted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'frilled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'frosted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'fuddled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'full-bodied': {'jj_ed': ''},
 'full-fledged': {'jj_ed': ''},
 'fully-fledged': {'jj_ed': ''},
 'funneled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'funnelled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'furled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'furnished': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'furred': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'furrowed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'fused': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'gabled': {'jj_ed': ''},
 'gaited': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'galvanized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'gap-toothed': {'jj_ed': ''},
 'garbed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'garbled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'gas-fired': {'jj_ed': ''},
 'generalised': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'generalized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'genetically modified': {'jj_ed': ''},
 'giant-sized': {'jj_ed': ''},
 'gilt-edged': {'jj_ed': ''},
 'glaciated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'glazed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'glorified': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'gnarled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'gobsmacked': {'jj_ed': ''},
 'goggle-eyed': {'jj_ed': ''},
 'gold-filled': {'jj_ed': ''},
 'gold-plated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'gold-rimmed': {'jj_ed': ''},
 'good-hearted': {'jj_ed': ''},
 'good-humoured': {'jj_ed': ''},
 'good-natured': {'jj_ed': ''},
 'good-tempered': {'jj_ed': ''},
 'graduated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'grant-maintained': {'jj_ed': ''},
 'granulated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'gravel-voiced': {'jj_ed': ''},
 'gravelled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'grazed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'great-hearted': {'jj_ed': ''},
 'gridlocked': {'jj_ed': ''},
 'grizzled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'grooved': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'gutted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'habited': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'hackneyed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'haired': {'jj_ed': ''},
 'half-baked': {'jj_ed': ''},
 'half-blooded': {'jj_ed': ''},
 'half-crazed': {'jj_ed': ''},
 'half-filled': {'jj_ed': ''},
 'half-hearted': {'jj_ed': ''},
 'half-timbered': {'jj_ed': ''},
 'half-witted': {'jj_ed': ''},
 'hallowed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'ham-fisted': {'jj_ed': ''},
 'hand-delivered': {'jj_ed': ''},
 'hand-painted': {'jj_ed': ''},
 'hand-picked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'handcrafted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'handpicked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'harassed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'hard-boiled': {'jj_ed': ''},
 'hard-earned': {'jj_ed': ''},
 'hard-edged': {'jj_ed': ''},
 'hard-headed': {'jj_ed': ''},
 'hard-nosed': {'jj_ed': ''},
 'hard-pressed': {'jj_ed': ''},
 'hard-wired': {'jj_ed': ''},
 'hardbacked': {'jj_ed': ''},
 'hardened': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'hardheaded': {'jj_ed': ''},
 'hardhearted': {'jj_ed': ''},
 'hare-brained': {'jj_ed': ''},
 'hatchet-faced': {'jj_ed': ''},
 'haunted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'hawk-eyed': {'jj_ed': ''},
 'headquartered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'heaped': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'hearing-impaired': {'jj_ed': ''},
 'heart-shaped': {'jj_ed': ''},
 'heavy-footed': {'jj_ed': ''},
 'heavy-handed': {'jj_ed': ''},
 'helmeted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'henpecked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'high-handed': {'jj_ed': ''},
 'high-heeled': {'jj_ed': ''},
 'high-minded': {'jj_ed': ''},
 'high-necked': {'jj_ed': ''},
 'high-pitched': {'jj_ed': ''},
 'high-powered': {'jj_ed': ''},
 'high-priced': {'jj_ed': ''},
 'high-principled': {'jj_ed': ''},
 'high-speed': {'jj_ed': ''},
 'high-spirited': {'jj_ed': ''},
 'hobnailed': {'jj_ed': ''},
 'home brewed': {'jj_ed': ''},
 'home-baked': {'jj_ed': ''},
 'homogenized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'honey-coloured': {'jj_ed': ''},
 'honeycombed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'honeyed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'honied': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'hooded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'hooped': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'horn-rimmed': {'jj_ed': ''},
 'horned': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'hot-blooded': {'jj_ed': ''},
 'hot-tempered': {'jj_ed': ''},
 'house-trained': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'hunched': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'hushed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'hyphenated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'iced': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'ill-advised': {'jj_ed': ''},
 'ill-affected': {'jj_ed': ''},
 'ill-bred': {'jj_ed': ''},
 'ill-conceived': {'jj_ed': ''},
 'ill-considered': {'jj_ed': ''},
 'ill-defined': {'jj_ed': ''},
 'ill-disposed': {'jj_ed': ''},
 'ill-equipped': {'jj_ed': ''},
 'ill-fated': {'jj_ed': ''},
 'ill-formed': {'jj_ed': ''},
 'ill-founded': {'jj_ed': ''},
 'ill-judged': {'jj_ed': ''},
 'ill-mannered': {'jj_ed': ''},
 'ill-prepared': {'jj_ed': ''},
 'ill-starred': {'jj_ed': ''},
 'ill-suited': {'jj_ed': ''},
 'ill-tempered': {'jj_ed': ''},
 'ill-timed': {'jj_ed': ''},
 'illuminated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'imbalanced': {'jj_ed': ''},
 'immersed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'immunocompromised': {'jj_ed': ''},
 'impaired': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'impassioned': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'impoverished': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'inbred': {'jj_ed': ''},
 'incensed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'inclined': {'jj_ed': '', 'be_jj_to_vb': '', 'vbd_eq_vbn': ''},
 'indebted': {'jj_ed': ''},
 'indented': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'indentured': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'index-linked': {'jj_ed': ''},
 'indisposed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'individualized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'industrialised': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'industrialized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'inebriated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'inexperienced': {'jj_ed': ''},
 'infatuated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'infected': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'inflamed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'inflated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'inflected': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'ingrained': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'institutionalised': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'institutionalized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'intentioned': {'jj_ed': ''},
 'interlaced': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'interrelated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'intoxicated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'intrigued': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'introverted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'italicized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'ivied': {'jj_ed': ''},
 'jackbooted': {'jj_ed': ''},
 'jaded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'jagged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'jam-packed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'jaundiced': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'jellied': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'jet-lagged': {'jj_ed': ''},
 'jewelled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'jinxed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'juiced': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'jury-rigged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'kidney-shaped': {'jj_ed': ''},
 'kilted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'kind-hearted': {'jj_ed': ''},
 'kippered': {'jj_ed': ''},
 'knackered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'knock-kneed': {'jj_ed': ''},
 'labored': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'laminated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'land-based': {'jj_ed': ''},
 'landlocked': {'jj_ed': ''},
 'lapsed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'leaded': {'jj_ed': ''},
 'leaved': {'jj_ed': ''},
 'left-handed': {'jj_ed': ''},
 'legged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'leisured': {'jj_ed': ''},
 'lettered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'level-headed': {'jj_ed': ''},
 'lidded': {'jj_ed': ''},
 'light-coloured': {'jj_ed': ''},
 'light-fingered': {'jj_ed': ''},
 'light-haired': {'jj_ed': ''},
 'light-headed': {'jj_ed': ''},
 'light-hearted': {'jj_ed': ''},
 'lightheaded': {'jj_ed': ''},
 'like-minded': {'jj_ed': ''},
 'lily-livered': {'jj_ed': ''},
 'limbed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'lion-hearted': {'jj_ed': ''},
 'liveried': {'jj_ed': ''},
 'lobed': {'jj_ed': ''},
 'localized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'long-awaited': {'jj_ed': ''},
 'long-haired': {'jj_ed': ''},
 'long-headed': {'jj_ed': ''},
 'long-legged': {'jj_ed': ''},
 'long-lived': {'jj_ed': ''},
 'long-sighted': {'jj_ed': ''},
 'long-winded': {'jj_ed': ''},
 'lopsided': {'jj_ed': ''},
 'louvred': {'jj_ed': ''},
 'low-pitched': {'jj_ed': ''},
 'low-powered': {'jj_ed': ''},
 'low-priced': {'jj_ed': ''},
 'low-spirited': {'jj_ed': ''},
 'magnetised': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'maladjusted': {'jj_ed': ''},
 'male-dominated': {'jj_ed': ''},
 'malformed': {'jj_ed': ''},
 'malnourished': {'jj_ed': ''},
 'malted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'man-sized': {'jj_ed': ''},
 'manacled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'maned': {'jj_ed': ''},
 'mangled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'manicured': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'mannered': {'jj_ed': ''},
 'many-sided': {'jj_ed': ''},
 'marbled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'marginalized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'martyred': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'mashed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'masked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'mass-produced': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'massed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'matted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'mealy-mouthed': {'jj_ed': ''},
 'mean-spirited': {'jj_ed': ''},
 'means-tested': {'jj_ed': ''},
 'mechanized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'medicated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'medium-sized': {'jj_ed': ''},
 'mentally handicapped': {'jj_ed': ''},
 'mentholated': {'jj_ed': ''},
 'middle-aged': {'jj_ed': ''},
 'middle-sized': {'jj_ed': ''},
 'miffed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'mild-mannered': {'jj_ed': ''},
 'mildewed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'militarized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'miniaturized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'minted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'mired': {'jj_ed': ''},
 'misconceived': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'misguided': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'misplaced': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'misty-eyed': {'jj_ed': ''},
 'moated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'moderate-sized': {'jj_ed': ''},
 'moneyed': {'jj_ed': ''},
 'monied': {'jj_ed': ''},
 'monogrammed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'monounsaturated': {'jj_ed': ''},
 'moon-faced': {'jj_ed': ''},
 'mortified': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'motivated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'motorized': {'jj_ed': ''},
 'mottled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'mounted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'moustached': {'jj_ed': ''},
 'moustachioed': {'jj_ed': ''},
 'much-heralded': {'jj_ed': ''},
 'mud-caked': {'jj_ed': ''},
 'muddled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'muffled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'mullioned': {'jj_ed': ''},
 'multicoloured': {'jj_ed': ''},
 'multifaceted': {'jj_ed': ''},
 'multilayered': {'jj_ed': ''},
 'multipronged': {'jj_ed': ''},
 'muscled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'mustachioed': {'jj_ed': ''},
 'muted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'myelinated': {'jj_ed': ''},
 'naked': {'jj_ed': ''},
 'narked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'narrow-minded': {'jj_ed': ''},
 'near-sighted': {'jj_ed': ''},
 'nearsighted': {'jj_ed': ''},
 'newfangled': {'jj_ed': ''},
 'nimble-fingered': {'jj_ed': ''},
 'non-aligned': {'jj_ed': ''},
 'non-disabled': {'jj_ed': ''},
 'nonaligned': {'jj_ed': ''},
 'nonplussed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'nonunionised': {'jj_ed': ''},
 'notarized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'nuanced': {'jj_ed': ''},
 'nuclear-powered': {'jj_ed': ''},
 'object-oriented': {'jj_ed': ''},
 'offended': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'offhanded': {'jj_ed': ''},
 'oil-based': {'jj_ed': ''},
 'oil-fired': {'jj_ed': ''},
 'old-fashioned': {'jj_ed': ''},
 'one-eyed': {'jj_ed': ''},
 'one-handed': {'jj_ed': ''},
 'one-sided': {'jj_ed': ''},
 'op-ed': {'jj_ed': ''},
 'open-ended': {'jj_ed': ''},
 'open-eyed': {'jj_ed': ''},
 'open-handed': {'jj_ed': ''},
 'open-hearted': {'jj_ed': ''},
 'open-minded': {'jj_ed': ''},
 'open-necked': {'jj_ed': ''},
 'openhanded': {'jj_ed': ''},
 'opinionated': {'jj_ed': ''},
 'oppressed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'orientated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'oriented': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'outdated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'outmoded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'outsized': {'jj_ed': ''},
 'outstretched': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'oval-shaped': {'jj_ed': ''},
 'overawed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'overcharged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'overcrowded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'overdeveloped': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'overdressed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'overexcited': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'overextended': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'overheated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'overjoyed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'overmanned': {'jj_ed': ''},
 'overpopulated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'overpriced': {'jj_ed': ''},
 'overrated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'oversexed': {'jj_ed': ''},
 'oversized': {'jj_ed': ''},
 'overstaffed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'overstrained': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'overstuffed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'oversubscribed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'overtired': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'overworked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'owner-occupied': {'jj_ed': ''},
 'padded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'pained': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'pale-faced': {'jj_ed': ''},
 'pan-fried': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'panelled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'panicked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'paralyzed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'parched': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'pasteurized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'patterned': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'peaked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'pear-shaped': {'jj_ed': ''},
 'pearl-handled': {'jj_ed': ''},
 'peeved': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'perforated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'perfumed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'perished': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'periwigged': {'jj_ed': ''},
 'perjured': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'personalized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'perturbed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'perverted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'petrified': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'pickled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'pie-eyed': {'jj_ed': ''},
 'pied': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'pig-headed': {'jj_ed': ''},
 'pigeon-toed': {'jj_ed': ''},
 'pigheaded': {'jj_ed': ''},
 'pigmented': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'pillared': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'pin-striped': {'jj_ed': ''},
 'pinched': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'pinstriped': {'jj_ed': ''},
 'pint-sized': {'jj_ed': ''},
 'pissed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'pitched': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'pitted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'plastered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'pleated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'plumed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'po-faced': {'jj_ed': ''},
 'pocked': {'jj_ed': ''},
 'pocket-sized': {'jj_ed': ''},
 'pockmarked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'poised': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'poker-faced': {'jj_ed': ''},
 'polished': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'politicized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'polluted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'polyunsaturated': {'jj_ed': ''},
 'pooped': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'pop-eyed': {'jj_ed': ''},
 'popeyed': {'jj_ed': ''},
 'pot-holed': {'jj_ed': ''},
 'potholed': {'jj_ed': ''},
 'potted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'potty-trained': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'pouched': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'powdered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'pre-med': {'jj_ed': ''},
 'prearranged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'precedented': {'jj_ed': ''},
 'preconceived': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'precooked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'predestined': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'predetermined': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'predigested': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'predisposed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'prefabricated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'prejudiced': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'premed': {'jj_ed': ''},
 'premeditated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'premised': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'preoccupied': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'preordained': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'prepackaged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'prepacked': {'jj_ed': ''},
 'prescribed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'pressured': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'pressurized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'principled': {'jj_ed': ''},
 'privileged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'prized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'processed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'professed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'prolonged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'pronged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'pronounced': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'propertied': {'jj_ed': ''},
 'proportioned': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'protracted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'public-spirited': {'jj_ed': ''},
 'puckered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'puffed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'pulverized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'quick-tempered': {'jj_ed': ''},
 'quick-witted': {'jj_ed': ''},
 'quilted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'raddled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'radio-controlled': {'jj_ed': ''},
 'ragged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'raked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'rarefied': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'rawboned': {'jj_ed': ''},
 'razor-edged': {'jj_ed': ''},
 'ready-cooked': {'jj_ed': ''},
 'recessed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'red-blooded': {'jj_ed': ''},
 'red-faced': {'jj_ed': ''},
 'red-haired': {'jj_ed': ''},
 'red-handed': {'jj_ed': ''},
 'red-headed': {'jj_ed': ''},
 'refined': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'refreshed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'remote-controlled': {'jj_ed': ''},
 'renewed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'renowned': {'jj_ed': ''},
 'repressed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'reputed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'restrained': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'retarded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'revered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'ribbed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'riddled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'ridged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'right-angled': {'jj_ed': ''},
 'right-handed': {'jj_ed': ''},
 'right-minded': {'jj_ed': ''},
 'robed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'rock-ribbed': {'jj_ed': ''},
 'rocket-propelled': {'jj_ed': ''},
 'rose-coloured': {'jj_ed': ''},
 'rose-red': {'jj_ed': ''},
 'rose-tinted': {'jj_ed': ''},
 'rouged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'round-eyed': {'jj_ed': ''},
 'round-faced': {'jj_ed': ''},
 'round-shouldered': {'jj_ed': ''},
 'roused': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'rubberized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'ruby-red': {'jj_ed': ''},
 'ruched': {'jj_ed': ''},
 'ruffled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'rugged': {'jj_ed': ''},
 'rumpled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'rutted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'sad-faced': {'jj_ed': ''},
 'sainted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'salaried': {'jj_ed': ''},
 'sanitised': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'sated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'satiated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'saturated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'scalloped': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'scatterbrained': {'jj_ed': ''},
 'scattered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'scented': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'schooled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'sclerosed': {'jj_ed': ''},
 'scorched': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'sculpted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'sculptured': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'seamed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'secluded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'segmented': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'segregated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'self-absorbed': {'jj_ed': ''},
 'self-addressed': {'jj_ed': ''},
 'self-appointed': {'jj_ed': ''},
 'self-assured': {'jj_ed': ''},
 'self-centred': {'jj_ed': ''},
 'self-conceited': {'jj_ed': ''},
 'self-confessed': {'jj_ed': ''},
 'self-contained': {'jj_ed': ''},
 'self-controlled': {'jj_ed': ''},
 'self-declared': {'jj_ed': ''},
 'self-directed': {'jj_ed': ''},
 'self-disciplined': {'jj_ed': ''},
 'self-educated': {'jj_ed': ''},
 'self-employed': {'jj_ed': ''},
 'self-imposed': {'jj_ed': ''},
 'self-induced': {'jj_ed': ''},
 'self-inflicted': {'jj_ed': ''},
 'self-interested': {'jj_ed': ''},
 'self-obsessed': {'jj_ed': ''},
 'self-opinionated': {'jj_ed': ''},
 'self-ordained': {'jj_ed': ''},
 'self-possessed': {'jj_ed': ''},
 'self-proclaimed': {'jj_ed': ''},
 'self-satisfied': {'jj_ed': ''},
 'self-seeded': {'jj_ed': ''},
 'self-styled': {'jj_ed': ''},
 'self-willed': {'jj_ed': ''},
 'semi-detached': {'jj_ed': ''},
 'semi-retired': {'jj_ed': ''},
 'semi-skilled': {'jj_ed': ''},
 'semidetached': {'jj_ed': ''},
 'semifinished': {'jj_ed': ''},
 'semiskilled': {'jj_ed': ''},
 'separated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'sequestered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'serrated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'serried': {'jj_ed': ''},
 'shagged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'shamefaced': {'jj_ed': ''},
 'shark-infested': {'jj_ed': ''},
 'sharp-eared': {'jj_ed': ''},
 'sharp-eyed': {'jj_ed': ''},
 'sharp-tongued': {'jj_ed': ''},
 'sharp-witted': {'jj_ed': ''},
 'shattered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'sheet-fed': {'jj_ed': ''},
 'shell-shocked': {'jj_ed': ''},
 'shipwrecked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'shock-headed': {'jj_ed': ''},
 'shopsoiled': {'jj_ed': ''},
 'short-haired': {'jj_ed': ''},
 'short-handed': {'jj_ed': ''},
 'short-lived': {'jj_ed': ''},
 'short-sighted': {'jj_ed': ''},
 'short-staffed': {'jj_ed': ''},
 'short-tempered': {'jj_ed': ''},
 'shorthanded': {'jj_ed': ''},
 'shrink-wrapped': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'silhouetted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'silver-haired': {'jj_ed': ''},
 'silver-plated': {'jj_ed': ''},
 'silver-tongued': {'jj_ed': ''},
 'simple-minded': {'jj_ed': ''},
 'simulated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'single-barrelled': {'jj_ed': ''},
 'single-breasted': {'jj_ed': ''},
 'single-celled': {'jj_ed': ''},
 'single-handed': {'jj_ed': ''},
 'single-minded': {'jj_ed': ''},
 'sissified': {'jj_ed': ''},
 'six-sided': {'jj_ed': ''},
 'slack-jawed': {'jj_ed': ''},
 'slatted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'slaughtered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'sloshed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'slow-witted': {'jj_ed': ''},
 'small-minded': {'jj_ed': ''},
 'smashed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'smocked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'smoking-related': {'jj_ed': ''},
 'smooth-faced': {'jj_ed': ''},
 'snot-nosed': {'jj_ed': ''},
 'snotty-nosed': {'jj_ed': ''},
 'snow-capped': {'jj_ed': ''},
 'snow-covered': {'jj_ed': ''},
 'snub-nosed': {'jj_ed': ''},
 'so-called': {'jj_ed': ''},
 'soaked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'soft-boiled': {'jj_ed': ''},
 'soft-finned': {'jj_ed': ''},
 'soft-footed': {'jj_ed': ''},
 'soft-hearted': {'jj_ed': ''},
 'solar-powered': {'jj_ed': ''},
 'sophisticated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'soused': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'sozzled': {'jj_ed': ''},
 'spavined': {'jj_ed': ''},
 'specialised': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'speckled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'spectacled': {'jj_ed': ''},
 'spiny-finned': {'jj_ed': ''},
 'spirited': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'sprawled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'spreadeagled': {'jj_ed': ''},
 'sprigged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'square-jawed': {'jj_ed': ''},
 'square-shouldered': {'jj_ed': ''},
 'square-toed': {'jj_ed': ''},
 'squared': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'squashed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'stacked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'staggered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'star-crossed': {'jj_ed': ''},
 'star-studded': {'jj_ed': ''},
 'starry-eyed': {'jj_ed': ''},
 'startled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'state-controlled': {'jj_ed': ''},
 'state-owned': {'jj_ed': ''},
 'steep-sided': {'jj_ed': ''},
 'stereotyped': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'stewed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'stiff-necked': {'jj_ed': ''},
 'stilted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'stippled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'stockinged': {'jj_ed': ''},
 'stoked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'stone-washed': {'jj_ed': ''},
 'stony-hearted': {'jj_ed': ''},
 'stooped': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'storied': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'storm-tossed': {'jj_ed': ''},
 'stouthearted': {'jj_ed': ''},
 'strained': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'straitened': {'jj_ed': ''},
 'straitlaced': {'jj_ed': ''},
 'stranded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'strangled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'stratified': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'straw-coloured': {'jj_ed': ''},
 'streamlined': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'stress-related': {'jj_ed': ''},
 'striated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'strong-minded': {'jj_ed': ''},
 'strong-willed': {'jj_ed': ''},
 'structured': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'stubbled': {'jj_ed': ''},
 'studded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'stumped': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'stunned': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'stunted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'stupefied': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'subdued': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'submerged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'subtitled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'suffocated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'sugar-coated': {'jj_ed': ''},
 'sugared': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'sulphured': {'jj_ed': ''},
 'sun-baked': {'jj_ed': ''},
 'sun-drenched': {'jj_ed': ''},
 'sun-dried': {'jj_ed': ''},
 'sun-kissed': {'jj_ed': ''},
 'sunbaked': {'jj_ed': ''},
 'sunburned': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'suntanned': {'jj_ed': ''},
 'superannuated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'supercharged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'supersaturated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'surefooted': {'jj_ed': ''},
 'sussed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'swaybacked': {'jj_ed': ''},
 'sweet-natured': {'jj_ed': ''},
 'sweet-scented': {'jj_ed': ''},
 'swell-headed': {'jj_ed': ''},
 'syncopated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'tainted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'tangled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'tanned': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'tapered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'tattered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'tattooed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'teenaged': {'jj_ed': ''},
 'tender-hearted': {'jj_ed': ''},
 'tenderhearted': {'jj_ed': ''},
 'tenured': {'jj_ed': ''},
 'terraced': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'tessellated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'textured': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'thatched': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'themed': {'jj_ed': ''},
 'thick-lipped': {'jj_ed': ''},
 'thick-skinned': {'jj_ed': ''},
 'thin-lipped': {'jj_ed': ''},
 'thin-skinned': {'jj_ed': ''},
 'three-cornered': {'jj_ed': ''},
 'three-sided': {'jj_ed': ''},
 'thrombosed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'tiered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'tight-fisted': {'jj_ed': ''},
 'tight-lipped': {'jj_ed': ''},
 'tightfisted': {'jj_ed': ''},
 'tiled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'timber-framed': {'jj_ed': ''},
 'timbered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'time-honoured': {'jj_ed': ''},
 'tinged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'tinned': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'tinted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'titled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'toffee-nosed': {'jj_ed': ''},
 'toilet-trained': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'tongue-tied': {'jj_ed': ''},
 'tonsured': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'top-ranked': {'jj_ed': ''},
 'top-rated': {'jj_ed': ''},
 'touristed': {'jj_ed': ''},
 'tousled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'towheaded': {'jj_ed': ''},
 'tracked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'transfixed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'transgendered': {'jj_ed': ''},
 'trashed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'traumatized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'travel-stained': {'jj_ed': ''},
 'treasured': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'tree-lined': {'jj_ed': ''},
 'trilobated': {'jj_ed': ''},
 'troubled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'tufted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'turreted': {'jj_ed': ''},
 'tuxedoed': {'jj_ed': ''},
 'twin-bedded': {'jj_ed': ''},
 'twin-engined': {'jj_ed': ''},
 'two-edged': {'jj_ed': ''},
 'two-faced': {'jj_ed': ''},
 'two-handed': {'jj_ed': ''},
 'two-sided': {'jj_ed': ''},
 'ulcerated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'unabashed': {'jj_ed': ''},
 'unabated': {'jj_ed': ''},
 'unabridged': {'jj_ed': ''},
 'unabsorbed': {'jj_ed': ''},
 'unaccented': {'jj_ed': ''},
 'unaccepted': {'jj_ed': ''},
 'unaccompanied': {'jj_ed': ''},
 'unaccredited': {'jj_ed': ''},
 'unaccustomed': {'jj_ed': ''},
 'unachieved': {'jj_ed': ''},
 'unacknowledged': {'jj_ed': ''},
 'unacquainted': {'jj_ed': ''},
 'unaddressed': {'jj_ed': ''},
 'unadjusted': {'jj_ed': ''},
 'unadorned': {'jj_ed': ''},
 'unadulterated': {'jj_ed': ''},
 'unadvised': {'jj_ed': ''},
 'unaffected': {'jj_ed': ''},
 'unaffiliated': {'jj_ed': ''},
 'unaged': {'jj_ed': ''},
 'unaided': {'jj_ed': ''},
 'unaired': {'jj_ed': ''},
 'unalloyed': {'jj_ed': ''},
 'unaltered': {'jj_ed': ''},
 'unamended': {'jj_ed': ''},
 'unamused': {'jj_ed': ''},
 'unanalyzed': {'jj_ed': ''},
 'unannounced': {'jj_ed': ''},
 'unanswered': {'jj_ed': ''},
 'unanticipated': {'jj_ed': ''},
 'unappreciated': {'jj_ed': ''},
 'unapproved': {'jj_ed': ''},
 'unarmed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'unashamed': {'jj_ed': ''},
 'unasked': {'jj_ed': ''},
 'unassigned': {'jj_ed': ''},
 'unassisted': {'jj_ed': ''},
 'unattached': {'jj_ed': ''},
 'unattended': {'jj_ed': ''},
 'unaudited': {'jj_ed': ''},
 'unauthorized': {'jj_ed': ''},
 'unavenged': {'jj_ed': ''},
 'unawakened': {'jj_ed': ''},
 'unawed': {'jj_ed': ''},
 'unbacked': {'jj_ed': ''},
 'unbalanced': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'unbanded': {'jj_ed': ''},
 'unbeloved': {'jj_ed': ''},
 'unbiased': {'jj_ed': ''},
 'unbleached': {'jj_ed': ''},
 'unblemished': {'jj_ed': ''},
 'unblended': {'jj_ed': ''},
 'unblessed': {'jj_ed': ''},
 'unbolted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'unbounded': {'jj_ed': ''},
 'unbowed': {'jj_ed': ''},
 'unbranched': {'jj_ed': ''},
 'unbranded': {'jj_ed': ''},
 'unbridled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'unbrushed': {'jj_ed': ''},
 'unburied': {'jj_ed': ''},
 'uncapped': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'uncarpeted': {'jj_ed': ''},
 'uncastrated': {'jj_ed': ''},
 'uncaused': {'jj_ed': ''},
 'uncensored': {'jj_ed': ''},
 'uncertified': {'jj_ed': ''},
 'unchallenged': {'jj_ed': ''},
 'unchanged': {'jj_ed': ''},
 'uncharged': {'jj_ed': ''},
 'uncharted': {'jj_ed': ''},
 'unchartered': {'jj_ed': ''},
 'unchecked': {'jj_ed': ''},
 'unchlorinated': {'jj_ed': ''},
 'uncivilized': {'jj_ed': ''},
 'unclaimed': {'jj_ed': ''},
 'unclassified': {'jj_ed': ''},
 'uncleared': {'jj_ed': ''},
 'unclothed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'unclouded': {'jj_ed': ''},
 'uncluttered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'uncoated': {'jj_ed': ''},
 'uncoerced': {'jj_ed': ''},
 'uncollected': {'jj_ed': ''},
 'uncombed': {'jj_ed': ''},
 'uncomforted': {'jj_ed': ''},
 'uncommitted': {'jj_ed': ''},
 'uncompensated': {'jj_ed': ''},
 'uncompleted': {'jj_ed': ''},
 'uncomplicated': {'jj_ed': ''},
 'unconcealed': {'jj_ed': ''},
 'unconcerned': {'jj_ed': ''},
 'unconfessed': {'jj_ed': ''},
 'unconfined': {'jj_ed': ''},
 'unconfirmed': {'jj_ed': ''},
 'unconnected': {'jj_ed': ''},
 'unconquered': {'jj_ed': ''},
 'unconsecrated': {'jj_ed': ''},
 'unconsidered': {'jj_ed': ''},
 'unconsolidated': {'jj_ed': ''},
 'unconstricted': {'jj_ed': ''},
 'unconsummated': {'jj_ed': ''},
 'uncontaminated': {'jj_ed': ''},
 'uncontested': {'jj_ed': ''},
 'uncontrived': {'jj_ed': ''},
 'uncontrolled': {'jj_ed': ''},
 'unconverted': {'jj_ed': ''},
 'unconvinced': {'jj_ed': ''},
 'uncooked': {'jj_ed': ''},
 'uncoordinated': {'jj_ed': ''},
 'uncorrected': {'jj_ed': ''},
 'uncorrelated': {'jj_ed': ''},
 'uncorroborated': {'jj_ed': ''},
 'uncorrupted': {'jj_ed': ''},
 'uncounted': {'jj_ed': ''},
 'uncropped': {'jj_ed': ''},
 'uncrossed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'uncrowded': {'jj_ed': ''},
 'uncrowned': {'jj_ed': ''},
 'uncultivated': {'jj_ed': ''},
 'uncultured': {'jj_ed': ''},
 'uncured': {'jj_ed': ''},
 'undamaged': {'jj_ed': ''},
 'undated': {'jj_ed': ''},
 'undaunted': {'jj_ed': ''},
 'undecided': {'jj_ed': ''},
 'undeciphered': {'jj_ed': ''},
 'undeclared': {'jj_ed': ''},
 'undecomposed': {'jj_ed': ''},
 'undecorated': {'jj_ed': ''},
 'undefeated': {'jj_ed': ''},
 'undefended': {'jj_ed': ''},
 'undefiled': {'jj_ed': ''},
 'undefined': {'jj_ed': ''},
 'undelivered': {'jj_ed': ''},
 'underbred': {'jj_ed': ''},
 'undercapitalized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'underdeveloped': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'underdressed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'undereducated': {'jj_ed': ''},
 'underemployed': {'jj_ed': ''},
 'underexposed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'underfed': {'jj_ed': ''},
 'underfunded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'underhanded': {'jj_ed': ''},
 'undermanned': {'jj_ed': ''},
 'undernourished': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'underpopulated': {'jj_ed': ''},
 'underprepared': {'jj_ed': ''},
 'underpriced': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'underprivileged': {'jj_ed': ''},
 'underrated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'underrepresented': {'jj_ed': ''},
 'underserved': {'jj_ed': ''},
 'undersexed': {'jj_ed': ''},
 'undersigned': {'jj_ed': ''},
 'undersized': {'jj_ed': ''},
 'understaffed': {'jj_ed': ''},
 'understated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'underused': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'underutilized': {'jj_ed': ''},
 'underwhelmed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'undescended': {'jj_ed': ''},
 'undeserved': {'jj_ed': ''},
 'undesired': {'jj_ed': ''},
 'undetected': {'jj_ed': ''},
 'undetermined': {'jj_ed': ''},
 'undeterred': {'jj_ed': ''},
 'undeveloped': {'jj_ed': ''},
 'undiagnosed': {'jj_ed': ''},
 'undifferentiated': {'jj_ed': ''},
 'undigested': {'jj_ed': ''},
 'undignified': {'jj_ed': ''},
 'undiluted': {'jj_ed': ''},
 'undiminished': {'jj_ed': ''},
 'undimmed': {'jj_ed': ''},
 'undirected': {'jj_ed': ''},
 'undischarged': {'jj_ed': ''},
 'undisciplined': {'jj_ed': ''},
 'undisclosed': {'jj_ed': ''},
 'undiscovered': {'jj_ed': ''},
 'undisguised': {'jj_ed': ''},
 'undismayed': {'jj_ed': ''},
 'undisputed': {'jj_ed': ''},
 'undissolved': {'jj_ed': ''},
 'undistinguished': {'jj_ed': ''},
 'undistorted': {'jj_ed': ''},
 'undistributed': {'jj_ed': ''},
 'undisturbed': {'jj_ed': ''},
 'undiversified': {'jj_ed': ''},
 'undivided': {'jj_ed': ''},
 'undocumented': {'jj_ed': ''},
 'undomesticated': {'jj_ed': ''},
 'undoubted': {'jj_ed': ''},
 'undrained': {'jj_ed': ''},
 'undressed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'undried': {'jj_ed': ''},
 'undyed': {'jj_ed': ''},
 'unearned': {'jj_ed': ''},
 'unedited': {'jj_ed': ''},
 'uneducated': {'jj_ed': ''},
 'unelected': {'jj_ed': ''},
 'unembarrassed': {'jj_ed': ''},
 'unembellished': {'jj_ed': ''},
 'unemployed': {'jj_ed': ''},
 'unenclosed': {'jj_ed': ''},
 'unencumbered': {'jj_ed': ''},
 'unendowed': {'jj_ed': ''},
 'unenforced': {'jj_ed': ''},
 'unengaged': {'jj_ed': ''},
 'unenlightened': {'jj_ed': ''},
 'unentitled': {'jj_ed': ''},
 'unequaled': {'jj_ed': ''},
 'unequalled': {'jj_ed': ''},
 'unequipped': {'jj_ed': ''},
 'unescorted': {'jj_ed': ''},
 'unestablished': {'jj_ed': ''},
 'unexamined': {'jj_ed': ''},
 'unexampled': {'jj_ed': ''},
 'unexcelled': {'jj_ed': ''},
 'unexcited': {'jj_ed': ''},
 'unexcused': {'jj_ed': ''},
 'unexercised': {'jj_ed': ''},
 'unexpected': {'jj_ed': ''},
 'unexpended': {'jj_ed': ''},
 'unexpired': {'jj_ed': ''},
 'unexplained': {'jj_ed': ''},
 'unexploded': {'jj_ed': ''},
 'unexploited': {'jj_ed': ''},
 'unexplored': {'jj_ed': ''},
 'unexpressed': {'jj_ed': ''},
 'unexpurgated': {'jj_ed': ''},
 'unextended': {'jj_ed': ''},
 'unfathomed': {'jj_ed': ''},
 'unfazed': {'jj_ed': ''},
 'unfed': {'jj_ed': ''},
 'unfeigned': {'jj_ed': ''},
 'unfenced': {'jj_ed': ''},
 'unfermented': {'jj_ed': ''},
 'unfettered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'unfilled': {'jj_ed': ''},
 'unfilmed': {'jj_ed': ''},
 'unfinished': {'jj_ed': ''},
 'unfired': {'jj_ed': ''},
 'unflavoured': {'jj_ed': ''},
 'unfledged': {'jj_ed': ''},
 'unflustered': {'jj_ed': ''},
 'unfocused': {'jj_ed': ''},
 'unforced': {'jj_ed': ''},
 'unformed': {'jj_ed': ''},
 'unfounded': {'jj_ed': ''},
 'unframed': {'jj_ed': ''},
 'unfrequented': {'jj_ed': ''},
 'unfulfilled': {'jj_ed': ''},
 'unfunded': {'jj_ed': ''},
 'unfurnished': {'jj_ed': ''},
 'unglazed': {'jj_ed': ''},
 'unglued': {'jj_ed': ''},
 'ungoverned': {'jj_ed': ''},
 'ungraded': {'jj_ed': ''},
 'ungreased': {'jj_ed': ''},
 'ungroomed': {'jj_ed': ''},
 'unguarded': {'jj_ed': ''},
 'unguiculated': {'jj_ed': ''},
 'unguided': {'jj_ed': ''},
 'unhallowed': {'jj_ed': ''},
 'unhampered': {'jj_ed': ''},
 'unharmed': {'jj_ed': ''},
 'unhatched': {'jj_ed': ''},
 'unhealed': {'jj_ed': ''},
 'unheated': {'jj_ed': ''},
 'unhedged': {'jj_ed': ''},
 'unheeded': {'jj_ed': ''},
 'unheralded': {'jj_ed': ''},
 'unhindered': {'jj_ed': ''},
 'unhinged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'unhurried': {'jj_ed': ''},
 'unidentified': {'jj_ed': ''},
 'unified': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'uniformed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'unimagined': {'jj_ed': ''},
 'unimpaired': {'jj_ed': ''},
 'unimpeded': {'jj_ed': ''},
 'unimpressed': {'jj_ed': ''},
 'unimproved': {'jj_ed': ''},
 'unincorporated': {'jj_ed': ''},
 'unindicted': {'jj_ed': ''},
 'uninfected': {'jj_ed': ''},
 'uninflected': {'jj_ed': ''},
 'uninfluenced': {'jj_ed': ''},
 'uninformed': {'jj_ed': ''},
 'uninhabited': {'jj_ed': ''},
 'uninhibited': {'jj_ed': ''},
 'uninitiated': {'jj_ed': ''},
 'uninjured': {'jj_ed': ''},
 'uninspected': {'jj_ed': ''},
 'uninspired': {'jj_ed': ''},
 'uninstructed': {'jj_ed': ''},
 'uninsured': {'jj_ed': ''},
 'unintegrated': {'jj_ed': ''},
 'unintended': {'jj_ed': ''},
 'uninterested': {'jj_ed': ''},
 'uninterrupted': {'jj_ed': ''},
 'unintimidated': {'jj_ed': ''},
 'uninvited': {'jj_ed': ''},
 'uninvolved': {'jj_ed': ''},
 'unionised': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'unionized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'unironed': {'jj_ed': ''},
 'unissued': {'jj_ed': ''},
 'united': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'unjustified': {'jj_ed': ''},
 'unlabelled': {'jj_ed': ''},
 'unlaced': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'unlamented': {'jj_ed': ''},
 'unleaded': {'jj_ed': ''},
 'unleavened': {'jj_ed': ''},
 'unlettered': {'jj_ed': ''},
 'unlicensed': {'jj_ed': ''},
 'unlighted': {'jj_ed': ''},
 'unlimited': {'jj_ed': ''},
 'unlined': {'jj_ed': ''},
 'unlisted': {'jj_ed': ''},
 'unloved': {'jj_ed': ''},
 'unmanaged': {'jj_ed': ''},
 'unmanned': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'unmannered': {'jj_ed': ''},
 'unmapped': {'jj_ed': ''},
 'unmarked': {'jj_ed': ''},
 'unmarred': {'jj_ed': ''},
 'unmarried': {'jj_ed': ''},
 'unmatched': {'jj_ed': ''},
 'unmeasured': {'jj_ed': ''},
 'unmediated': {'jj_ed': ''},
 'unmelted': {'jj_ed': ''},
 'unmentioned': {'jj_ed': ''},
 'unmerited': {'jj_ed': ''},
 'unmined': {'jj_ed': ''},
 'unmitigated': {'jj_ed': ''},
 'unmixed': {'jj_ed': ''},
 'unmoderated': {'jj_ed': ''},
 'unmodernised': {'jj_ed': ''},
 'unmodified': {'jj_ed': ''},
 'unmolested': {'jj_ed': ''},
 'unmotivated': {'jj_ed': ''},
 'unmourned': {'jj_ed': ''},
 'unmoved': {'jj_ed': ''},
 'unmutilated': {'jj_ed': ''},
 'unmyelinated': {'jj_ed': ''},
 'unnamed': {'jj_ed': ''},
 'unneeded': {'jj_ed': ''},
 'unnoted': {'jj_ed': ''},
 'unnoticed': {'jj_ed': ''},
 'unnourished': {'jj_ed': ''},
 'unnumbered': {'jj_ed': ''},
 'unobserved': {'jj_ed': ''},
 'unobstructed': {'jj_ed': ''},
 'unoccupied': {'jj_ed': ''},
 'unoiled': {'jj_ed': ''},
 'unopened': {'jj_ed': ''},
 'unopposed': {'jj_ed': ''},
 'unorganized': {'jj_ed': ''},
 'unornamented': {'jj_ed': ''},
 'unowned': {'jj_ed': ''},
 'unpadded': {'jj_ed': ''},
 'unpaired': {'jj_ed': ''},
 'unparalleled': {'jj_ed': ''},
 'unpatterned': {'jj_ed': ''},
 'unpaved': {'jj_ed': ''},
 'unperceived': {'jj_ed': ''},
 'unperformed': {'jj_ed': ''},
 'unperturbed': {'jj_ed': ''},
 'unplaced': {'jj_ed': ''},
 'unplanned': {'jj_ed': ''},
 'unplanted': {'jj_ed': ''},
 'unpleased': {'jj_ed': ''},
 'unplowed': {'jj_ed': ''},
 'unplugged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'unpolished': {'jj_ed': ''},
 'unpolluted': {'jj_ed': ''},
 'unpopulated': {'jj_ed': ''},
 'unposed': {'jj_ed': ''},
 'unprecedented': {'jj_ed': ''},
 'unprejudiced': {'jj_ed': ''},
 'unpremeditated': {'jj_ed': ''},
 'unprepared': {'jj_ed': ''},
 'unpressed': {'jj_ed': ''},
 'unprincipled': {'jj_ed': ''},
 'unprocessed': {'jj_ed': ''},
 'unprompted': {'jj_ed': ''},
 'unprotected': {'jj_ed': ''},
 'unproved': {'jj_ed': ''},
 'unprovoked': {'jj_ed': ''},
 'unpublicized': {'jj_ed': ''},
 'unpublished': {'jj_ed': ''},
 'unpunished': {'jj_ed': ''},
 'unpurified': {'jj_ed': ''},
 'unqualified': {'jj_ed': ''},
 'unquenched': {'jj_ed': ''},
 'unquestioned': {'jj_ed': ''},
 'unranked': {'jj_ed': ''},
 'unratified': {'jj_ed': ''},
 'unreached': {'jj_ed': ''},
 'unrealized': {'jj_ed': ''},
 'unreciprocated': {'jj_ed': ''},
 'unrecognized': {'jj_ed': ''},
 'unreconciled': {'jj_ed': ''},
 'unreconstructed': {'jj_ed': ''},
 'unrecorded': {'jj_ed': ''},
 'unredeemed': {'jj_ed': ''},
 'unreduced': {'jj_ed': ''},
 'unrefined': {'jj_ed': ''},
 'unreformed': {'jj_ed': ''},
 'unrefreshed': {'jj_ed': ''},
 'unrefrigerated': {'jj_ed': ''},
 'unregenerated': {'jj_ed': ''},
 'unregistered': {'jj_ed': ''},
 'unregulated': {'jj_ed': ''},
 'unrehearsed': {'jj_ed': ''},
 'unreinforced': {'jj_ed': ''},
 'unrelated': {'jj_ed': ''},
 'unrelieved': {'jj_ed': ''},
 'unremarked': {'jj_ed': ''},
 'unreported': {'jj_ed': ''},
 'unrepresented': {'jj_ed': ''},
 'unrepressed': {'jj_ed': ''},
 'unrequited': {'jj_ed': ''},
 'unresolved': {'jj_ed': ''},
 'unrestrained': {'jj_ed': ''},
 'unrestricted': {'jj_ed': ''},
 'unrevealed': {'jj_ed': ''},
 'unrevised': {'jj_ed': ''},
 'unrewarded': {'jj_ed': ''},
 'unrifled': {'jj_ed': ''},
 'unrivalled': {'jj_ed': ''},
 'unrouged': {'jj_ed': ''},
 'unruffled': {'jj_ed': ''},
 'unsalaried': {'jj_ed': ''},
 'unsalted': {'jj_ed': ''},
 'unsanctioned': {'jj_ed': ''},
 'unsated': {'jj_ed': ''},
 'unsatisfied': {'jj_ed': ''},
 'unsaturated': {'jj_ed': ''},
 'unsaved': {'jj_ed': ''},
 'unscathed': {'jj_ed': ''},
 'unscented': {'jj_ed': ''},
 'unscheduled': {'jj_ed': ''},
 'unschooled': {'jj_ed': ''},
 'unscripted': {'jj_ed': ''},
 'unsealed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'unseasoned': {'jj_ed': ''},
 'unsecured': {'jj_ed': ''},
 'unseeded': {'jj_ed': ''},
 'unsegregated': {'jj_ed': ''},
 'unselected': {'jj_ed': ''},
 'unsexed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'unshaded': {'jj_ed': ''},
 'unshared': {'jj_ed': ''},
 'unshaved': {'jj_ed': ''},
 'unshed': {'jj_ed': ''},
 'unsheltered': {'jj_ed': ''},
 'unshielded': {'jj_ed': ''},
 'unsighted': {'jj_ed': ''},
 'unsigned': {'jj_ed': ''},
 'unskilled': {'jj_ed': ''},
 'unsoiled': {'jj_ed': ''},
 'unsolicited': {'jj_ed': ''},
 'unsolved': {'jj_ed': ''},
 'unsophisticated': {'jj_ed': ''},
 'unsorted': {'jj_ed': ''},
 'unspecialised': {'jj_ed': ''},
 'unspecified': {'jj_ed': ''},
 'unspoiled': {'jj_ed': ''},
 'unspotted': {'jj_ed': ''},
 'unsprayed': {'jj_ed': ''},
 'unstained': {'jj_ed': ''},
 'unstarred': {'jj_ed': ''},
 'unstated': {'jj_ed': ''},
 'unsterilised': {'jj_ed': ''},
 'unstimulated': {'jj_ed': ''},
 'unstinted': {'jj_ed': ''},
 'unstirred': {'jj_ed': ''},
 'unstrained': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'unstratified': {'jj_ed': ''},
 'unstressed': {'jj_ed': ''},
 'unstructured': {'jj_ed': ''},
 'unstudied': {'jj_ed': ''},
 'unsubdued': {'jj_ed': ''},
 'unsubstantiated': {'jj_ed': ''},
 'unsuited': {'jj_ed': ''},
 'unsullied': {'jj_ed': ''},
 'unsupervised': {'jj_ed': ''},
 'unsupported': {'jj_ed': ''},
 'unsuppressed': {'jj_ed': ''},
 'unsurpassed': {'jj_ed': ''},
 'unsurprised': {'jj_ed': ''},
 'unsuspected': {'jj_ed': ''},
 'unswayed': {'jj_ed': ''},
 'unsweetened': {'jj_ed': ''},
 'unsynchronised': {'jj_ed': ''},
 'untainted': {'jj_ed': ''},
 'untalented': {'jj_ed': ''},
 'untamed': {'jj_ed': ''},
 'untanned': {'jj_ed': ''},
 'untapped': {'jj_ed': ''},
 'untarnished': {'jj_ed': ''},
 'untasted': {'jj_ed': ''},
 'untaxed': {'jj_ed': ''},
 'untempered': {'jj_ed': ''},
 'untenanted': {'jj_ed': ''},
 'untended': {'jj_ed': ''},
 'untenured': {'jj_ed': ''},
 'untested': {'jj_ed': ''},
 'untethered': {'jj_ed': ''},
 'untilled': {'jj_ed': ''},
 'untipped': {'jj_ed': ''},
 'untitled': {'jj_ed': ''},
 'untouched': {'jj_ed': ''},
 'untracked': {'jj_ed': ''},
 'untrained': {'jj_ed': ''},
 'untrammelled': {'jj_ed': ''},
 'untreated': {'jj_ed': ''},
 'untried': {'jj_ed': ''},
 'untroubled': {'jj_ed': ''},
 'unturned': {'jj_ed': ''},
 'untutored': {'jj_ed': ''},
 'unuttered': {'jj_ed': ''},
 'unvaccinated': {'jj_ed': ''},
 'unvalued': {'jj_ed': ''},
 'unvanquished': {'jj_ed': ''},
 'unvaried': {'jj_ed': ''},
 'unvarnished': {'jj_ed': ''},
 'unventilated': {'jj_ed': ''},
 'unverified': {'jj_ed': ''},
 'unversed': {'jj_ed': ''},
 'unvisited': {'jj_ed': ''},
 'unvoiced': {'jj_ed': ''},
 'unwaged': {'jj_ed': ''},
 'unwanted': {'jj_ed': ''},
 'unwarmed': {'jj_ed': ''},
 'unwarranted': {'jj_ed': ''},
 'unwashed': {'jj_ed': ''},
 'unwaxed': {'jj_ed': ''},
 'unweathered': {'jj_ed': ''},
 'unwed': {'jj_ed': ''},
 'unwedded': {'jj_ed': ''},
 'unwished': {'jj_ed': ''},
 'unwonted': {'jj_ed': ''},
 'unwooded': {'jj_ed': ''},
 'unworried': {'jj_ed': ''},
 'unwounded': {'jj_ed': ''},
 'upholstered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'uplifted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'upraised': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'upturned': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'urbanised': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'urbanized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'vacuolated': {'jj_ed': ''},
 'vacuum-packed': {'jj_ed': ''},
 'valued': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'varicolored': {'jj_ed': ''},
 'variegated': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'vaulted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'vaunted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'veiled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'veined': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'versed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'verticillated': {'jj_ed': ''},
 'vested': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'voice-activated': {'jj_ed': ''},
 'volumed': {'jj_ed': ''},
 'waged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'walled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'warm-blooded': {'jj_ed': ''},
 'warm-hearted': {'jj_ed': ''},
 'warped': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'waterlogged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'waterproofed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'wavy-haired': {'jj_ed': ''},
 'weak-kneed': {'jj_ed': ''},
 'web-based': {'jj_ed': ''},
 'web-footed': {'jj_ed': ''},
 'webbed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'wedded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'wedge-shaped': {'jj_ed': ''},
 'weighted': {'jj_ed': ''},
 'well-adjusted': {'jj_ed': ''},
 'well-advised': {'jj_ed': ''},
 'well-appointed': {'jj_ed': ''},
 'well-balanced': {'jj_ed': ''},
 'well-behaved': {'jj_ed': ''},
 'well-bred': {'jj_ed': ''},
 'well-connected': {'jj_ed': ''},
 'well-defined': {'jj_ed': ''},
 'well-designed': {'jj_ed': ''},
 'well-developed': {'jj_ed': ''},
 'well-disposed': {'jj_ed': ''},
 'well-documented': {'jj_ed': ''},
 'well-dressed': {'jj_ed': ''},
 'well-earned': {'jj_ed': ''},
 'well-educated': {'jj_ed': ''},
 'well-endowed': {'jj_ed': ''},
 'well-established': {'jj_ed': ''},
 'well-fed': {'jj_ed': ''},
 'well-founded': {'jj_ed': ''},
 'well-groomed': {'jj_ed': ''},
 'well-grounded': {'jj_ed': ''},
 'well-heeled': {'jj_ed': ''},
 'well-informed': {'jj_ed': ''},
 'well-intentioned': {'jj_ed': ''},
 'well-lined': {'jj_ed': ''},
 'well-mannered': {'jj_ed': ''},
 'well-nourished': {'jj_ed': ''},
 'well-oiled': {'jj_ed': ''},
 'well-preserved': {'jj_ed': ''},
 'well-rounded': {'jj_ed': ''},
 'well-stocked': {'jj_ed': ''},
 'well-thumbed': {'jj_ed': ''},
 'well-timed': {'jj_ed': ''},
 'well-tried': {'jj_ed': ''},
 'well-turned': {'jj_ed': ''},
 'well-ventilated': {'jj_ed': ''},
 'well-versed': {'jj_ed': ''},
 'westernized': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'whacked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'wheeled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'whiskered': {'jj_ed': ''},
 'white-haired': {'jj_ed': ''},
 'white-livered': {'jj_ed': ''},
 'whole-hearted': {'jj_ed': ''},
 'wholehearted': {'jj_ed': ''},
 'whorled': {'jj_ed': ''},
 'wicked': {'jj_ed': '', 'jj_to_jjr': 'wickeder', 'jj_to_jjs': 'wickedest', 'vbd_eq_vbn': ''},
 'widowed': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'winded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'winged': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'wire-haired': {'jj_ed': ''},
 'wired': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'withered': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'wizened': {'jj_ed': ''},
 'wonted': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'wooded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'word processed': {'jj_ed': ''},
 'worded': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'wrecked': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'wretched': {'jj_ed': ''},
 'wrinkled': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'wrongheaded': {'jj_ed': ''},
 'zoned': {'jj_ed': '', 'vbd_eq_vbn': ''},
 'zonked': {'jj_ed': ''},
 'work be busy': {'e_nva.agree': ''},
 'in a minute/_p': {'_nt': ''},
 'at the moment/_p': {'_nt': ''},
 'in the future/_p': {'_nt': ''},
 'in a few days/_p': {'_nt': ''},
 'in a few hours/_p': {'_nt': ''},
 'in the past/_p': {'_nt': ''},
 'in the weekend/_p': {'_nt': ''},
 'in the weekday/_p': {'_nt': ''},
 'in the morning/_p': {'_nt': ''},
 'in the afternoon/_p': {'_nt': ''},
 'in the evening/_p': {'_nt': ''},
 'at night/_p': {'_nt': ''},
 'Monday/_n': {'_nt': ''},
 'Tuesday/_n': {'_nt': ''},
 'Wednesday/_n': {'_nt': ''},
 'Thursday/_n': {'_nt': ''},
 'Friday/_n': {'_nt': ''},
 'Saturday/_n': {'_nt': ''},
 'Sunday/_n': {'_nt': ''},
 'the other day/_n': {'_nt': ''},
 'next month/_n': {'_nt': ''},
 'next year/_n': {'_nt': ''},
 'next day/_n': {'_nt': ''},
 'next week/_n': {'_nt': ''},
 'next minute/_n': {'_nt': ''},
 'next second/_n': {'_nt': ''},
 'next hour/_n': {'_nt': ''},
 'today/_n': {'_nt': ''},
 'yesterday/_n': {'_nt': ''},
 'tomorrow/_n': {'_nt': ''},
 'the day after tomorrow/_n': {'_nt': ''},
 'the day before yesterday/_n': {'_nt': ''},
 'last night/_n': {'_nt': ''},
 'Mon./_n': {'_nt': ''},
 'Tues./_n': {'_nt': ''},
 'Wed./_n': {'_nt': ''},
 'Thur./_n': {'_nt': ''},
 'Fri./_n': {'_nt': ''},
 'Sat./_n': {'_nt': ''},
 'Sun./_n': {'_nt': ''},
 'Thurs./_n': {'_nt': ''},
 'January/_n': {'_nt': ''},
 'February/_n': {'_nt': ''},
 'March/_n': {'_nt': ''},
 'April/_n': {'_nt': ''},
 'May/_n': {'_nt': ''},
 'June/_n': {'_nt': ''},
 'July/_n': {'_nt': ''},
 'August/_n': {'_nt': ''},
 'September/_n': {'_nt': ''},
 'October/_n': {'_nt': ''},
 'November/_n': {'_nt': ''},
 'December/_n': {'_nt': ''},
 'Jan./_n': {'_nt': ''},
 'Feb./_n': {'_nt': ''},
 'Mar./_n': {'_nt': ''},
 'Apr./_n': {'_nt': ''},
 'May./_n': {'_nt': ''},
 'Jun./_n': {'_nt': ''},
 'Jul./_n': {'_nt': ''},
 'Aug./_n': {'_nt': ''},
 'Sep./_n': {'_nt': ''},
 'Oct./_n': {'_nt': ''},
 'Nov./_n': {'_nt': ''},
 'Dec./_n': {'_nt': ''},
 "eight o'clock/_n": {'_nt': ''},
 "8 o'clock/_n": {'_nt': ''},
 'half past ten/_n': {'_nt': ''},
 'a quarter to ten/_n': {'_nt': ''},
 '_jj something/_n': {'e_word.sequ': ''},
 '_jj somebody/_n': {'e_word.sequ': ''},
 '_jj someone/_n': {'e_word.sequ': ''},
 '_jj anything/_n': {'e_word.sequ': ''},
 '_jj anybody/_n': {'e_word.sequ': ''},
 '_jj anyone/_n': {'e_word.sequ': ''},
 '_jj nothing/_n': {'e_word.sequ': ''},
 '_jj nobody/_n': {'e_word.sequ': ''},
 '_jj everything/_n': {'e_word.sequ': ''},
 '_jj everybody/_n': {'e_word.sequ': ''},
 '_jj everyone/_n': {'e_word.sequ': ''},
 'work farm/prep_in': {'e_prep.trp': 'in->on'},
 'price be cheap': {'e_nva.agree': ''},
 'a blessed/_n': {'e_noun._n': 'a blessing'},
 'a bottled/_n': {'e_noun._n': 'a bottle'},
 'a childish/_n': {'e_noun._n': 'a child'},
 'a cloudy/_n': {'e_noun._n': 'a cloud'},
 'a cursed/_n': {'e_noun._n': 'a curse'},
 'a forested/_n': {'e_noun._n': 'a forest'},
 'a good manly/_n': {'e_noun._n': 'a good man'},
 'a handed/_n': {'e_noun._n': 'a hand'},
 'a habitual/_n': {'e_noun._n': 'a habit'},
 'a joking/_n': {'e_noun._n': 'a joke'},
 'a minded/_n': {'e_noun._n': 'a mind'},
 'a sounding/_n': {'e_noun._n': 'a sound'},
 'a sprung/_n': {'e_noun._n': 'a spring'},
 'a studied/_n': {'e_noun._n': 'a study'},
 'a voiced/_n': {'e_noun._n': 'a voice'},
 'academic achievable/_n': {'e_noun._n': 'academic achievement'},
 'academic excellent/_n': {'e_noun._n': 'academic excellence'},
 'administration law/_n': {'e_noun._n': 'administrative law'},
 'administrative lawful/_n': {'e_noun._n': 'administrative law'},
 'adult educational/_n': {'e_noun._n': 'adult education'},
 'advanced technological/_n': {'e_noun._n': 'advanced technology'},
 'aerospace industrial/_n': {'e_noun._n': 'aerospace industry'},
 'adventurous tea/_n': {'e_noun._n': 'afternoon tea'},
 'air travelled/_n': {'e_noun._n': 'air travel'},
 'all timeless/_n': {'e_noun._n': 'all time'},
 'alternative rocky/_n': {'e_noun._n': 'alternative rock'},
 'the averaged american/_n': {'e_noun._n': 'the average american'},
 'american cultural/_n': {'e_noun._n': 'american culture'},
 'american educational/_n': {'e_noun._n': 'american education'},
 'american fashionable/_n': {'e_noun._n': 'american fashion'},
 'american filmed/_n': {'e_noun._n': 'american film'},
 'the american governing/_n': {'e_noun._n': 'the american government'},
 'american governing/_n': {'e_noun._n': 'american government'},
 'american historic/_n': {'e_noun._n': 'american history'},
 'american industrial/_n': {'e_noun._n': 'american industry'},
 'american lawful/_n': {'e_noun._n': 'american law'},
 'american literary/_n': {'e_noun._n': 'american literature'},
 'an american presidential/_n': {'e_noun._n': 'an american president'},
 'the american presidential/_n': {'e_noun._n': 'the american president'},
 'an advantaged/_n': {'e_noun._n': 'an affair'},
 'the angled/_n': {'e_noun._n': 'the angle'},
 'animal controllable/_n': {'e_noun._n': 'animal control'},
 'animal healthy/_n': {'e_noun._n': 'animal health'},
 'annual sprung/_n': {'e_noun._n': 'annual spring'},
 'anxious disorders/_n': {'e_noun._n': 'anxiety disorders'},
 'armed conflictive/_n': {'e_noun._n': 'armed conflict'},
 'an arrowed/_n': {'e_noun._n': 'an arrow'},
 'art historic/_n': {'e_noun._n': 'art history'},
 'arts educational/_n': {'e_noun._n': 'arts education'},
 'the australian governing/_n': {'e_noun._n': 'the australian government'},
 'your balanced/_n': {'e_noun._n': 'your balance'},
 'a barred/_n': {'e_noun._n': 'a bar'},
 'the barred/_n': {'e_noun._n': 'the bar'},
 'base computer/_n': {'e_noun._n': 'basic computer'},
 'basic computational/_n': {'e_noun._n': 'basic computer'},
 'base research/_n': {'e_noun._n': 'basic research'},
 'base skills/_n': {'e_noun._n': 'basic skills'},
 'the bathed/_n': {'e_noun._n': 'the bath'},
 'a bathed/_n': {'e_noun._n': 'a bath'},
 'best dramatic/_n': {'e_noun._n': 'best drama'},
 'best filmed/_n': {'e_noun._n': 'best film'},
 'best friendly/_n': {'e_noun._n': 'best friend'},
 'my best friendly/_n': {'e_noun._n': 'my best friend'},
 'a big different/_n': {'e_noun._n': 'a big difference'},
 'big governing/_n': {'e_noun._n': 'big government'},
 'the big third/_n': {'e_noun._n': 'the big three'},
 'bilingual educational/_n': {'e_noun._n': 'bilingual education'},
 'black cultural/_n': {'e_noun._n': 'black culture'},
 'bodily fat/_n': {'e_noun._n': 'body fat'},
 'boned density/_n': {'e_noun._n': 'bone density'},
 'the bordered/_n': {'e_noun._n': 'the border'},
 'the boston global/_n': {'e_noun._n': 'the boston globe'},
 'boston global/_n': {'e_noun._n': 'boston globe'},
 'bottled waterless/_n': {'e_noun._n': 'bottled water'},
 'brand loyal/_n': {'e_noun._n': 'brand loyalty'},
 'british governing/_n': {'e_noun._n': 'british government'},
 'the british governing/_n': {'e_noun._n': 'the british government'},
 'british historic/_n': {'e_noun._n': 'british history'},
 'british intelligent/_n': {'e_noun._n': 'british intelligence'},
 'the bush administrative/_n': {'e_noun._n': 'the bush administration'},
 'bush administrative/_n': {'e_noun._n': 'bush administration'},
 'business developed/_n': {'e_noun._n': 'business development'},
 'business travelled/_n': {'e_noun._n': 'business travel'},
 'business weekly/_n': {'e_noun._n': 'business week'},
 'the buttoned/_n': {'e_noun._n': 'the button'},
 'the camped/_n': {'e_noun._n': 'the camp'},
 'cardiovascular diseased/_n': {'e_noun._n': 'cardiovascular disease'},
 'center staged/_n': {'e_noun._n': 'center stage'},
 'center business/_n': {'e_noun._n': 'central business'},
 'centre court/_n': {'e_noun._n': 'center court'},
 'a chained/_n': {'e_noun._n': 'a chain'},
 'the chained/_n': {'e_noun._n': 'the chain'},
 'characteristic development/_n': {'e_noun._n': 'character development'},
 'character developed/_n': {'e_noun._n': 'character development'},
 'charity workless/_n': {'e_noun._n': 'charity work'},
 'that childish/_n': {'e_noun._n': 'that child'},
 'her childish/_n': {'e_noun._n': 'her child'},
 'their childish/_n': {'e_noun._n': 'their child'},
 'your childish/_n': {'e_noun._n': 'your child'},
 'one childish/_n': {'e_noun._n': 'one child'},
 'no childish/_n': {'e_noun._n': 'no child'},
 'every childish/_n': {'e_noun._n': 'every child'},
 'our childish/_n': {'e_noun._n': 'our child'},
 'childish abuse/_n': {'e_noun._n': 'child abuse'},
 'childish care/_n': {'e_noun._n': 'child care'},
 'child careful/_n': {'e_noun._n': 'child care'},
 'childish development/_n': {'e_noun._n': 'child development'},
 'child developed/_n': {'e_noun._n': 'child development'},
 'childish support/_n': {'e_noun._n': 'child support'},
 'child supported/_n': {'e_noun._n': 'child support'},
 'childish welfare/_n': {'e_noun._n': 'child welfare'},
 'chinese cultural/_n': {'e_noun._n': 'chinese culture'},
 'chinese governing/_n': {'e_noun._n': 'chinese government'},
 'the chinese governing/_n': {'e_noun._n': 'the chinese government'},
 'chinese historic/_n': {'e_noun._n': 'chinese history'},
 'chinese social/_n': {'e_noun._n': 'chinese society'},
 'city governing/_n': {'e_noun._n': 'city government'},
 'the civil-rights moving/_n': {'e_noun._n': 'the civil-rights movement'},
 'the civil rights moving/_n': {'e_noun._n': 'the civil rights movement'},
 'civil social/_n': {'e_noun._n': 'civil society'},
 'classical musical/_n': {'e_noun._n': 'classical music'},
 'climate changeable/_n': {'e_noun._n': 'climate change'},
 'college educational/_n': {'e_noun._n': 'college education'},
 'commercial secretary/_n': {'e_noun._n': 'commerce secretary'},
 'community developed/_n': {'e_noun._n': 'community development'},
 'community involved/_n': {'e_noun._n': 'community involvement'},
 'company managing/_n': {'e_noun._n': 'company management'},
 'the computational age/_n': {'e_noun._n': 'the computer age'},
 'computational games/_n': {'e_noun._n': 'computer games'},
 'computational graphics/_n': {'e_noun._n': 'computer graphics'},
 'computational hackers/_n': {'e_noun._n': 'computer hackers'},
 'computational networking/_n': {'e_noun._n': 'computer networking'},
 'computational networks/_n': {'e_noun._n': 'computer networks'},
 'computational programming/_n': {'e_noun._n': 'computer programming'},
 'computational security/_n': {'e_noun._n': 'computer security'},
 'computer secure/_n': {'e_noun._n': 'computer security'},
 'computational software/_n': {'e_noun._n': 'computer software'},
 'computational technology/_n': {'e_noun._n': 'computer technology'},
 'computer technological/_n': {'e_noun._n': 'computer technology'},
 'consuming behavior/_n': {'e_noun._n': 'consumer behavior'},
 'consuming products/_n': {'e_noun._n': 'consumer products'},
 'consuming protection/_n': {'e_noun._n': 'consumer protection'},
 'consumer protective/_n': {'e_noun._n': 'consumer protection'},
 'consuming spending/_n': {'e_noun._n': 'consumer spending'},
 'consumer spent/_n': {'e_noun._n': 'consumer spending'},
 'copyright lawful/_n': {'e_noun._n': 'copyright law'},
 'copyright protective/_n': {'e_noun._n': 'copyright protection'},
 'corporate cultural/_n': {'e_noun._n': 'corporate culture'},
 'corporate developed/_n': {'e_noun._n': 'corporate development'},
 'corporate financial/_n': {'e_noun._n': 'corporate finance'},
 'corporate managing/_n': {'e_noun._n': 'corporate management'},
 'corporate travelled/_n': {'e_noun._n': 'corporate travel'},
 'corporation management/_n': {'e_noun._n': 'corporate management'},
 'costly control/_n': {'e_noun._n': 'cost control'},
 'cost controllable/_n': {'e_noun._n': 'cost control'},
 'the countable/_n': {'e_noun._n': 'the count'},
 'critical think/_n': {'e_noun._n': 'critical thinking'},
 'cultural diverse/_n': {'e_noun._n': 'cultural diversity'},
 'culture differences/_n': {'e_noun._n': 'cultural differences'},
 'culture diversity/_n': {'e_noun._n': 'cultural diversity'},
 'dna tested/_n': {'e_noun._n': 'dna testing'},
 'day life/_n': {'e_noun._n': 'daily life'},
 'day news/_n': {'e_noun._n': 'daily news'},
 'day inner/_n': {'e_noun._n': 'day in'},
 'departmental heads/_n': {'e_noun._n': 'department heads'},
 'development countries/_n': {'e_noun._n': 'developed countries'},
 'digital informing/_n': {'e_noun._n': 'digital information'},
 'digital musical/_n': {'e_noun._n': 'digital music'},
 'the digital revolutionary/_n': {'e_noun._n': 'the digital revolution'},
 'digital technological/_n': {'e_noun._n': 'digital technology'},
 'dogged owners/_n': {'e_noun._n': 'dog owners'},
 'domestic violent/_n': {'e_noun._n': 'domestic violence'},
 'drink drivers/_n': {'e_noun._n': 'drunk drivers'},
 'drink driving/_n': {'e_noun._n': 'drunk driving'},
 'drug useful/_n': {'e_noun._n': 'drug use'},
 'electronic commercial/_n': {'e_noun._n': 'electronic commerce'},
 'environmental protective/_n': {'e_noun._n': 'environmental protection'},
 'each hourly/_n': {'e_noun._n': 'each hour'},
 'early sprung/_n': {'e_noun._n': 'early spring'},
 'economic cooperative/_n': {'e_noun._n': 'economic cooperation'},
 'economic developed/_n': {'e_noun._n': 'economic development'},
 'economic grown/_n': {'e_noun._n': 'economic growth'},
 'economic historic/_n': {'e_noun._n': 'economic history'},
 'economic integrate/_n': {'e_noun._n': 'economic integration'},
 'economic prosperous/_n': {'e_noun._n': 'economic prosperity'},
 'electric powerful/_n': {'e_noun._n': 'electric power'},
 'electrical powerful/_n': {'e_noun._n': 'electrical power'},
 'electronic informing/_n': {'e_noun._n': 'electronic information'},
 'emotional intelligent/_n': {'e_noun._n': 'emotional intelligence'},
 'energetic conservation/_n': {'e_noun._n': 'energy conservation'},
 'the energetic crisis/_n': {'e_noun._n': 'the energy crisis'},
 'energetic policy/_n': {'e_noun._n': 'energy policy'},
 'english literary/_n': {'e_noun._n': 'english literature'},
 'environment health/_n': {'e_noun._n': 'environmental health'},
 'environment law/_n': {'e_noun._n': 'environmental law'},
 'environment problems/_n': {'e_noun._n': 'environmental problems'},
 'environmental healthy/_n': {'e_noun._n': 'environmental health'},
 'environmental lawful/_n': {'e_noun._n': 'environmental law'},
 'european integrate/_n': {'e_noun._n': 'european integration'},
 'every manly/_n': {'e_noun._n': 'every man'},
 'everyday useful/_n': {'e_noun._n': 'everyday use'},
 'the exchanging/_n': {'e_noun._n': 'the exchange'},
 'extraterrestrial intelligent/_n': {'e_noun._n': 'extraterrestrial intelligence'},
 'food safe/_n': {'e_noun._n': 'food safety'},
 'fair valuable/_n': {'e_noun._n': 'fair value'},
 'family lawful/_n': {'e_noun._n': 'family law'},
 'family violent/_n': {'e_noun._n': 'family violence'},
 'fashionable magazines/_n': {'e_noun._n': 'fashion magazines'},
 'fashionable shows/_n': {'e_noun._n': 'fashion shows'},
 'fashionable trends/_n': {'e_noun._n': 'fashion trends'},
 'federal governing/_n': {'e_noun._n': 'federal government'},
 'the federal governing/_n': {'e_noun._n': 'the federal government'},
 'filmed festivals/_n': {'e_noun._n': 'film festivals'},
 'filmed history/_n': {'e_noun._n': 'film history'},
 'film historic/_n': {'e_noun._n': 'film history'},
 'filmed noir/_n': {'e_noun._n': 'film noir'},
 'filmed production/_n': {'e_noun._n': 'film production'},
 'film productive/_n': {'e_noun._n': 'film production'},
 'the finance crisis/_n': {'e_noun._n': 'the financial crisis'},
 'finance management/_n': {'e_noun._n': 'financial management'},
 'financial aided/_n': {'e_noun._n': 'financial aid'},
 'financial industrial/_n': {'e_noun._n': 'financial industry'},
 'financial managing/_n': {'e_noun._n': 'financial management'},
 'the food industrial/_n': {'e_noun._n': 'the food industry'},
 'foreign ministerial/_n': {'e_noun._n': 'foreign ministry'},
 'foreign tradable/_n': {'e_noun._n': 'foreign trade'},
 'the forested/_n': {'e_noun._n': 'the forest'},
 'fortunate 500 companies/_n': {'e_noun._n': 'fortune 500 companies'},
 'fortunate magazine/_n': {'e_noun._n': 'fortune magazine'},
 'free musical/_n': {'e_noun._n': 'free music'},
 'free of speech/_n': {'e_noun._n': 'freedom of speech'},
 'freedom of speaking/_n': {'e_noun._n': 'freedom of speech'},
 'french governing/_n': {'e_noun._n': 'french government'},
 'fresh waterless/_n': {'e_noun._n': 'fresh water'},
 'a good friendly/_n': {'e_noun._n': 'a good friend'},
 'her friendly/_n': {'e_noun._n': 'her friend'},
 'our friendly/_n': {'e_noun._n': 'our friend'},
 'my friendly/_n': {'e_noun._n': 'my friend'},
 'your friendly/_n': {'e_noun._n': 'your friend'},
 'old friendly/_n': {'e_noun._n': 'old friend'},
 'further studied/_n': {'e_noun._n': 'further study'},
 'good lucky/_n': {'e_noun._n': 'good luck'},
 'graphic designing/_n': {'e_noun._n': 'graphic design'},
 'gender discriminating/_n': {'e_noun._n': 'gender discrimination'},
 'genetic tested/_n': {'e_noun._n': 'genetic testing'},
 'the global economic/_n': {'e_noun._n': 'the global economy'},
 'global healthy/_n': {'e_noun._n': 'global health'},
 'global informing/_n': {'e_noun._n': 'global information'},
 'global secure/_n': {'e_noun._n': 'global security'},
 'golden medals/_n': {'e_noun._n': 'gold medals'},
 'golden medal/_n': {'e_noun._n': 'gold medal'},
 'the golden medal/_n': {'e_noun._n': 'the gold medal'},
 'good characteristic/_n': {'e_noun._n': 'good character'},
 'a good educational/_n': {'e_noun._n': 'a good education'},
 'good fortunate/_n': {'e_noun._n': 'good fortune'},
 'good healthy/_n': {'e_noun._n': 'good health'},
 'good tasteless/_n': {'e_noun._n': 'good taste'},
 'good useful/_n': {'e_noun._n': 'good use'},
 'governing documents/_n': {'e_noun._n': 'government documents'},
 'governing jobs/_n': {'e_noun._n': 'government jobs'},
 'governing ministers/_n': {'e_noun._n': 'government ministers'},
 'governing officials/_n': {'e_noun._n': 'government officials'},
 'governing policy/_n': {'e_noun._n': 'government policy'},
 'great powerful/_n': {'e_noun._n': 'great power'},
 'hard workless/_n': {'e_noun._n': 'hard work'},
 'hard timeless/_n': {'e_noun._n': 'hard time'},
 'the healthy care system/_n': {'e_noun._n': 'the health care system'},
 'the health careful system/_n': {'e_noun._n': 'the health care system'},
 'the health care systematic/_n': {'e_noun._n': 'the health care system'},
 'the healthy department/_n': {'e_noun._n': 'the health department'},
 'the health departmental/_n': {'e_noun._n': 'the health department'},
 'healthy policy/_n': {'e_noun._n': 'health policy'},
 'healthy services/_n': {'e_noun._n': 'health services'},
 'a healthy bodily/_n': {'e_noun._n': 'a healthy body'},
 'high definable/_n': {'e_noun._n': 'high definition'},
 'high social/_n': {'e_noun._n': 'high society'},
 'high speeding/_n': {'e_noun._n': 'high speed'},
 'the hilly/_n': {'e_noun._n': 'the hill'},
 'his governing/_n': {'e_noun._n': 'his government'},
 'his lovable/_n': {'e_noun._n': 'his love'},
 'his mistaken/_n': {'e_noun._n': 'his mistake'},
 'his wordless/_n': {'e_noun._n': 'his word'},
 'hollywood filmed/_n': {'e_noun._n': 'hollywood film'},
 'home healthy/_n': {'e_noun._n': 'home health'},
 'homeland secure/_n': {'e_noun._n': 'homeland security'},
 'the hooked/_n': {'e_noun._n': 'the hook'},
 'one housed/_n': {'e_noun._n': 'one house'},
 'my housed/_n': {'e_noun._n': 'my house'},
 'each housed/_n': {'e_noun._n': 'each house'},
 'her housed/_n': {'e_noun._n': 'her house'},
 'the housed/_n': {'e_noun._n': 'the house'},
 'a housed/_n': {'e_noun._n': 'a house'},
 'our housed/_n': {'e_noun._n': 'our house'},
 'your housed/_n': {'e_noun._n': 'your house'},
 'housed prices/_n': {'e_noun._n': 'house prices'},
 'human bodily/_n': {'e_noun._n': 'human body'},
 'human developed/_n': {'e_noun._n': 'human development'},
 'human evolutionary/_n': {'e_noun._n': 'human evolution'},
 'human healthy/_n': {'e_noun._n': 'human health'},
 'human historic/_n': {'e_noun._n': 'human history'},
 'human intelligent/_n': {'e_noun._n': 'human intelligence'},
 'human resourceful/_n': {'e_noun._n': 'human resource'},
 'international financial/_n': {'e_noun._n': 'international finance'},
 'their independent/_n': {'e_noun._n': 'their independence'},
 'the indexed/_n': {'e_noun._n': 'the index'},
 'individual free/_n': {'e_noun._n': 'individual freedom'},
 'industrial designing/_n': {'e_noun._n': 'industrial design'},
 'industrial developed/_n': {'e_noun._n': 'industrial development'},
 'industrial productive/_n': {'e_noun._n': 'industrial production'},
 'industry design/_n': {'e_noun._n': 'industrial design'},
 'the informing age/_n': {'e_noun._n': 'the information age'},
 'the informing highway/_n': {'e_noun._n': 'the information highway'},
 'the informing superhighway/_n': {'e_noun._n': 'the information superhighway'},
 'informing systems/_n': {'e_noun._n': 'information systems'},
 'informing technology/_n': {'e_noun._n': 'information technology'},
 'information technological/_n': {'e_noun._n': 'information technology'},
 'informing technology,/_n': {'e_noun._n': 'information technology,'},
 'inner peaceful/_n': {'e_noun._n': 'inner peace'},
 'insured company/_n': {'e_noun._n': 'insurance company'},
 'international cooperative/_n': {'e_noun._n': 'international cooperation'},
 'international developed/_n': {'e_noun._n': 'international development'},
 'international healthy/_n': {'e_noun._n': 'international health'},
 'international peaceful/_n': {'e_noun._n': 'international peace'},
 'international secure/_n': {'e_noun._n': 'international security'},
 'international tradable/_n': {'e_noun._n': 'international trade'},
 'international travelled/_n': {'e_noun._n': 'international travel'},
 'internet accessible/_n': {'e_noun._n': 'internet access'},
 'the internet industrial/_n': {'e_noun._n': 'the internet industry'},
 'internet technological/_n': {'e_noun._n': 'internet technology'},
 'internet timeless/_n': {'e_noun._n': 'internet time'},
 'internet useful/_n': {'e_noun._n': 'internet use'},
 'interracial married/_n': {'e_noun._n': 'interracial marriage'},
 'its applicable/_n': {'e_noun._n': 'its application'},
 'its managing/_n': {'e_noun._n': 'its management'},
 'the japanese governing/_n': {'e_noun._n': 'the japanese government'},
 'japanese governing/_n': {'e_noun._n': 'japanese government'},
 'japanese industrial/_n': {'e_noun._n': 'japanese industry'},
 'job secure/_n': {'e_noun._n': 'job security'},
 'a joyful/_n': {'e_noun._n': 'a joy'},
 'the joyful/_n': {'e_noun._n': 'the joy'},
 'justice departmental/_n': {'e_noun._n': 'justice department'},
 'juvenile criminal/_n': {'e_noun._n': 'juvenile crime'},
 'the kennedy administrative/_n': {'e_noun._n': 'the kennedy administration'},
 'labor lawful/_n': {'e_noun._n': 'labor law'},
 'landed use/_n': {'e_noun._n': 'land use'},
 'land useful/_n': {'e_noun._n': 'land use'},
 'last sprung/_n': {'e_noun._n': 'last spring'},
 'last weekly/_n': {'e_noun._n': 'last week'},
 'lasting spring/_n': {'e_noun._n': 'last spring'},
 'late sprung/_n': {'e_noun._n': 'late spring'},
 'no lawful/_n': {'e_noun._n': 'no law'},
 'california lawful/_n': {'e_noun._n': 'california law'},
 'lawful enforcement/_n': {'e_noun._n': 'law enforcement'},
 'law enforced/_n': {'e_noun._n': 'law enforcement'},
 'the lawful firm/_n': {'e_noun._n': 'the law firm'},
 'lawful school/_n': {'e_noun._n': 'law school'},
 'the lawful school/_n': {'e_noun._n': 'the law school'},
 'leisure timeless/_n': {'e_noun._n': 'leisure time'},
 'limited successful/_n': {'e_noun._n': 'limited success'},
 'little timeless/_n': {'e_noun._n': 'little time'},
 'living music/_n': {'e_noun._n': 'live music'},
 'live musical/_n': {'e_noun._n': 'live music'},
 'living historic/_n': {'e_noun._n': 'living history'},
 'the lower housed/_n': {'e_noun._n': 'the lower house'},
 'manufacturing employed/_n': {'e_noun._n': 'manufacturing employment'},
 'a marching/_n': {'e_noun._n': 'a march'},
 'that marked/_n': {'e_noun._n': 'that mark'},
 'mass transitory/_n': {'e_noun._n': 'mass transit'},
 'medical careful/_n': {'e_noun._n': 'medical care'},
 'medical educational/_n': {'e_noun._n': 'medical education'},
 'medical informing/_n': {'e_noun._n': 'medical information'},
 'medical insured/_n': {'e_noun._n': 'medical insurance'},
 'medical scientific/_n': {'e_noun._n': 'medical science'},
 'medical technological/_n': {'e_noun._n': 'medical technology'},
 'medical treated/_n': {'e_noun._n': 'medical treatment'},
 'mental healthy/_n': {'e_noun._n': 'mental health'},
 'military forceful/_n': {'e_noun._n': 'military force'},
 'military strategic/_n': {'e_noun._n': 'military strategy'},
 'the milled/_n': {'e_noun._n': 'the mill'},
 'minded games/_n': {'e_noun._n': 'mind games'},
 'mission controllable/_n': {'e_noun._n': 'mission control'},
 'modern historic/_n': {'e_noun._n': 'modern history'},
 'modern scientific/_n': {'e_noun._n': 'modern science'},
 'modern social/_n': {'e_noun._n': 'modern society'},
 'modern technological/_n': {'e_noun._n': 'modern technology'},
 'money managing/_n': {'e_noun._n': 'money management'},
 'the movie industrial/_n': {'e_noun._n': 'the movie industry'},
 'municipal governing/_n': {'e_noun._n': 'municipal government'},
 'my computational/_n': {'e_noun._n': 'my computer'},
 'my educational/_n': {'e_noun._n': 'my education'},
 'my lovable/_n': {'e_noun._n': 'my love'},
 'my minded/_n': {'e_noun._n': 'my mind'},
 'my timeless/_n': {'e_noun._n': 'my time'},
 'my turned/_n': {'e_noun._n': 'my turn'},
 'my wordless/_n': {'e_noun._n': 'my word'},
 'my youthful/_n': {'e_noun._n': 'my youth'},
 'nba historic/_n': {'e_noun._n': 'nba history'},
 'no costly/_n': {'e_noun._n': 'no cost'},
 'no manly/_n': {'e_noun._n': 'no man'},
 'no painful/_n': {'e_noun._n': 'no pain'},
 'no peaceful/_n': {'e_noun._n': 'no peace'},
 'the nasdaq composite indexed/_n': {'e_noun._n': 'the nasdaq composite index'},
 'national computational/_n': {'e_noun._n': 'national computer'},
 'the national conventional/_n': {'e_noun._n': 'the national convention'},
 'national educational/_n': {'e_noun._n': 'national education'},
 'national energetic/_n': {'e_noun._n': 'national energy'},
 'national healthy/_n': {'e_noun._n': 'national health'},
 'national powerful/_n': {'e_noun._n': 'national power'},
 'national secure/_n': {'e_noun._n': 'national security'},
 'natural beautiful/_n': {'e_noun._n': 'natural beauty'},
 'nature disaster/_n': {'e_noun._n': 'natural disaster'},
 'the nature world/_n': {'e_noun._n': 'the natural world'},
 'new computational/_n': {'e_noun._n': 'new computer'},
 'new developed/_n': {'e_noun._n': 'new development'},
 'new economic/_n': {'e_noun._n': 'new economy'},
 'new educational/_n': {'e_noun._n': 'new education'},
 'new energetic/_n': {'e_noun._n': 'new energy'},
 'new lined/_n': {'e_noun._n': 'new line'},
 'the new technological/_n': {'e_noun._n': 'the new technology'},
 'new technological/_n': {'e_noun._n': 'new technology'},
 'new timeless/_n': {'e_noun._n': 'new time'},
 'new workless/_n': {'e_noun._n': 'new work'},
 'new york timeless/_n': {'e_noun._n': 'new york time'},
 'next sprung/_n': {'e_noun._n': 'next spring'},
 'next weekly/_n': {'e_noun._n': 'next week'},
 'no powerful/_n': {'e_noun._n': 'no power'},
 'nuclear technological/_n': {'e_noun._n': 'nuclear technology'},
 'office spaced/_n': {'e_noun._n': 'office space'},
 'open waterless/_n': {'e_noun._n': 'open water'},
 'our governing/_n': {'e_noun._n': 'our government'},
 'olympic golden/_n': {'e_noun._n': 'olympic gold'},
 'the olympic moving/_n': {'e_noun._n': 'the olympic movement'},
 'one direct/_n': {'e_noun._n': 'one direction'},
 'one handed/_n': {'e_noun._n': 'one hand'},
 'one lined/_n': {'e_noun._n': 'one line'},
 'one manly/_n': {'e_noun._n': 'one man'},
 'one national/_n': {'e_noun._n': 'one nation'},
 'one wordless/_n': {'e_noun._n': 'one word'},
 'only timeless/_n': {'e_noun._n': 'only time'},
 'open accessible/_n': {'e_noun._n': 'open access'},
 'open sourced/_n': {'e_noun._n': 'open source'},
 'the opening ceremonial/_n': {'e_noun._n': 'the opening ceremony'},
 'oppositional forces/_n': {'e_noun._n': 'opposition forces'},
 'orangish juice/_n': {'e_noun._n': 'orange juice'},
 'orange juicy/_n': {'e_noun._n': 'orange juice'},
 'our advantageous/_n': {'e_noun._n': 'our advantage'},
 'our bodily/_n': {'e_noun._n': 'our body'},
 'our generative/_n': {'e_noun._n': 'our generation'},
 'our healthy/_n': {'e_noun._n': 'our health'},
 'our presidential/_n': {'e_noun._n': 'our president'},
 'our studied/_n': {'e_noun._n': 'our study'},
 'our timeless/_n': {'e_noun._n': 'our time'},
 'our villagey/_n': {'e_noun._n': 'our village'},
 'pop musical/_n': {'e_noun._n': 'pop music'},
 'palliative careful/_n': {'e_noun._n': 'palliative care'},
 'part-time workless/_n': {'e_noun._n': 'part-time work'},
 'party lead/_n': {'e_noun._n': 'party leader'},
 'peer pressured/_n': {'e_noun._n': 'peer pressure'},
 'permanent residential/_n': {'e_noun._n': 'permanent residence'},
 'personal informing/_n': {'e_noun._n': 'personal information'},
 'personal injured/_n': {'e_noun._n': 'personal injury'},
 'personal safe/_n': {'e_noun._n': 'personal safety'},
 'phone numbered/_n': {'e_noun._n': 'phone number'},
 'physical active/_n': {'e_noun._n': 'physical activity'},
 'physical fit/_n': {'e_noun._n': 'physical fitness'},
 'physical healthy/_n': {'e_noun._n': 'physical health'},
 'the police departmental/_n': {'e_noun._n': 'the police department'},
 'pop cultural/_n': {'e_noun._n': 'pop culture'},
 'popular musical/_n': {'e_noun._n': 'popular music'},
 'population grown/_n': {'e_noun._n': 'population growth'},
 'positive think/_n': {'e_noun._n': 'positive thinking'},
 'powerful generation/_n': {'e_noun._n': 'power generation'},
 'power generative/_n': {'e_noun._n': 'power generation'},
 'premarital sexual/_n': {'e_noun._n': 'premarital sex'},
 'the president election/_n': {'e_noun._n': 'the presidential election'},
 'president election/_n': {'e_noun._n': 'presidential election'},
 'presidential debatable/_n': {'e_noun._n': 'presidential debate'},
 'the presidential elect/_n': {'e_noun._n': 'the presidential election'},
 'press free/_n': {'e_noun._n': 'press freedom'},
 'public administrative/_n': {'e_noun._n': 'public administration'},
 'public financial/_n': {'e_noun._n': 'public finance'},
 'public informing/_n': {'e_noun._n': 'public information'},
 'public safe/_n': {'e_noun._n': 'public safety'},
 'public secure/_n': {'e_noun._n': 'public security'},
 'quality timeless/_n': {'e_noun._n': 'quality time'},
 'rocky music/_n': {'e_noun._n': 'rock music'},
 'rock musical/_n': {'e_noun._n': 'rock music'},
 'racial discriminating/_n': {'e_noun._n': 'racial discrimination'},
 'racial equal/_n': {'e_noun._n': 'racial equality'},
 'the reagan administrative/_n': {'e_noun._n': 'the reagan administration'},
 'real shows/_n': {'e_noun._n': 'reality shows'},
 'real tv/_n': {'e_noun._n': 'reality tv'},
 'reasonable doubtful/_n': {'e_noun._n': 'reasonable doubt'},
 'record industrial/_n': {'e_noun._n': 'record industry'},
 'recorded musical/_n': {'e_noun._n': 'recorded music'},
 'regional developed/_n': {'e_noun._n': 'regional development'},
 'regional stable/_n': {'e_noun._n': 'regional stability'},
 'regional tradable/_n': {'e_noun._n': 'regional trade'},
 'religious free/_n': {'e_noun._n': 'religious freedom'},
 'renewable energetic/_n': {'e_noun._n': 'renewable energy'},
 'the right timeless/_n': {'e_noun._n': 'the right time'},
 'risky management/_n': {'e_noun._n': 'risk management'},
 'risk managing/_n': {'e_noun._n': 'risk management'},
 'romantic lovable/_n': {'e_noun._n': 'romantic love'},
 'running waterless/_n': {'e_noun._n': 'running water'},
 'rural developed/_n': {'e_noun._n': 'rural development'},
 'russian social/_n': {'e_noun._n': 'russian society'},
 'same-sex married/_n': {'e_noun._n': 'same-sex marriage'},
 'the sang/_n': {'e_noun._n': 'the singing'},
 'school violent/_n': {'e_noun._n': 'school violence'},
 'scientific and technology/_n': {'e_noun._n': 'science and technology'},
 'science and technological/_n': {'e_noun._n': 'science and technology'},
 'screen timeless/_n': {'e_noun._n': 'screen time'},
 'secure services/_n': {'e_noun._n': 'security services'},
 'secure systems/_n': {'e_noun._n': 'security systems'},
 'senior managing/_n': {'e_noun._n': 'senior management'},
 'a sensible of humor/_n': {'e_noun._n': 'a sense of humor'},
 'sexual discriminating/_n': {'e_noun._n': 'sexual discrimination'},
 'shooting guarding/_n': {'e_noun._n': 'shooting guard'},
 'skinned cancer/_n': {'e_noun._n': 'skin cancer'},
 'social developed/_n': {'e_noun._n': 'social development'},
 'social interactive/_n': {'e_noun._n': 'social interaction'},
 'social responsible/_n': {'e_noun._n': 'social responsibility'},
 'the social secure system/_n': {'e_noun._n': 'the social security system'},
 'the social security systematic/_n': {'e_noun._n': 'the social security system'},
 'social stable/_n': {'e_noun._n': 'social stability'},
 'society unrest/_n': {'e_noun._n': 'social unrest'},
 'software developed/_n': {'e_noun._n': 'software development'},
 'soiled erosion/_n': {'e_noun._n': 'soil erosion'},
 'soil eroding/_n': {'e_noun._n': 'soil erosion'},
 'solar energetic/_n': {'e_noun._n': 'solar energy'},
 'spaced exploration/_n': {'e_noun._n': 'space exploration'},
 'space exploratory/_n': {'e_noun._n': 'space exploration'},
 'the spaced program/_n': {'e_noun._n': 'the space program'},
 'spaced travel/_n': {'e_noun._n': 'space travel'},
 'space travelled/_n': {'e_noun._n': 'space travel'},
 'specialist programs/_n': {'e_noun._n': 'special programs'},
 'speaking recognition/_n': {'e_noun._n': 'speech recognition'},
 'his spiritual/_n': {'e_noun._n': 'his spirit'},
 'your spiritual/_n': {'e_noun._n': 'your spirit'},
 'my spiritual/_n': {'e_noun._n': 'my spirit'},
 'their spiritual/_n': {'e_noun._n': 'their spirit'},
 'spotted news/_n': {'e_noun._n': 'spot news'},
 'the starring/_n': {'e_noun._n': 'the star'},
 'stemmed cell research/_n': {'e_noun._n': 'stem cell research'},
 'street criminal/_n': {'e_noun._n': 'street crime'},
 'summer camped/_n': {'e_noun._n': 'summer camp'},
 'our sunny/_n': {'e_noun._n': 'our sun'},
 'sustainable developed/_n': {'e_noun._n': 'sustainable development'},
 'the answering/_n': {'e_noun._n': 'the answer'},
 'the ended/_n': {'e_noun._n': 'the end'},
 'the telegraphic/_n': {'e_noun._n': 'the telegraph'},
 'the terminate/_n': {'e_noun._n': 'the terminal'},
 'the treated/_n': {'e_noun._n': 'the treatment'},
 'the voiced/_n': {'e_noun._n': 'the voice'},
 'the sprung/_n': {'e_noun._n': 'the spring'},
 'true lovable/_n': {'e_noun._n': 'true love'},
 'talking radio/_n': {'e_noun._n': 'talk radio'},
 'taxable law/_n': {'e_noun._n': 'tax law'},
 'tax lawful/_n': {'e_noun._n': 'tax law'},
 'taxable reform/_n': {'e_noun._n': 'tax reform'},
 'technological innovative/_n': {'e_noun._n': 'technological innovation'},
 'technological progressive/_n': {'e_noun._n': 'technological progress'},
 'technology progress/_n': {'e_noun._n': 'technological progress'},
 'tenth people/_n': {'e_noun._n': 'ten people'},
 'the agreeable/_n': {'e_noun._n': 'the agreement'},
 'the banded/_n': {'e_noun._n': 'the band'},
 'the caved/_n': {'e_noun._n': 'the cave'},
 'the centers for diseased control/_n': {'e_noun._n': 'the centers for disease control'},
 'the centers for disease controllable/_n': {'e_noun._n': 'the centers for disease control'},
 'the changeable/_n': {'e_noun._n': 'the change'},
 'the cloudy/_n': {'e_noun._n': 'the cloud'},
 'the conclusive/_n': {'e_noun._n': 'the conclusion'},
 'the conflictive/_n': {'e_noun._n': 'the conflict'},
 'the constitutive/_n': {'e_noun._n': 'the constitution'},
 'the contactable/_n': {'e_noun._n': 'the contact'},
 'the contextual/_n': {'e_noun._n': 'the context'},
 'the contracted/_n': {'e_noun._n': 'the contract'},
 'the cored/_n': {'e_noun._n': 'the core'},
 'the cornered/_n': {'e_noun._n': 'the corner'},
 'the dayton agreeable/_n': {'e_noun._n': 'the dayton agreement'},
 'the departmental/_n': {'e_noun._n': 'the department'},
 'the flowing/_n': {'e_noun._n': 'the flow'},
 'the formed/_n': {'e_noun._n': 'the form'},
 'the generative/_n': {'e_noun._n': 'the generation'},
 'the informing/_n': {'e_noun._n': 'the information'},
 'the mailed/_n': {'e_noun._n': 'the mail'},
 'the manly/_n': {'e_noun._n': 'the man'},
 'the ministerial/_n': {'e_noun._n': 'the ministry'},
 'the next generative/_n': {'e_noun._n': 'the next generation'},
 'the presidential of the united states/_n': {'e_noun._n': 'the president of the united states'},
 'the resistible/_n': {'e_noun._n': 'the resistance'},
 'the silverish/_n': {'e_noun._n': 'the silver'},
 'the sunk/_n': {'e_noun._n': 'the sink'},
 'the sisterly/_n': {'e_noun._n': 'the sister'},
 'the situated/_n': {'e_noun._n': 'the situation'},
 'the sixteenth/_n': {'e_noun._n': 'the six'},
 'the skinned/_n': {'e_noun._n': 'the skin'},
 'the sourced/_n': {'e_noun._n': 'the source'},
 'the sporting/_n': {'e_noun._n': 'the sport'},
 'the stripped/_n': {'e_noun._n': 'the strip'},
 'the studied/_n': {'e_noun._n': 'the study'},
 'the textual/_n': {'e_noun._n': 'the text'},
 'the touchable/_n': {'e_noun._n': 'the touch'},
 'the tradable/_n': {'e_noun._n': 'the trade'},
 'the votable/_n': {'e_noun._n': 'the vote'},
 'the wasteful/_n': {'e_noun._n': 'the waste'},
 'the waterless/_n': {'e_noun._n': 'the water'},
 'the waveless/_n': {'e_noun._n': 'the wave'},
 'the welfare systematic/_n': {'e_noun._n': 'the welfare system'},
 'the wholeness/_n': {'e_noun._n': 'the whole'},
 'the wintry/_n': {'e_noun._n': 'the winter'},
 'the wordless/_n': {'e_noun._n': 'the word'},
 'their disposable/_n': {'e_noun._n': 'their disposal'},
 'their workless/_n': {'e_noun._n': 'their work'},
 'third democrats/_n': {'e_noun._n': 'three democrats'},
 'the three grade/_n': {'e_noun._n': 'the third grade'},
 'third points/_n': {'e_noun._n': 'three points'},
 'third stories/_n': {'e_noun._n': 'three stories'},
 'third wars/_n': {'e_noun._n': 'three wars'},
 "timeless magazine's/_n": {'e_noun._n': "time magazine's"},
 'timeless magazine/_n': {'e_noun._n': 'time magazine'},
 'timeless management/_n': {'e_noun._n': 'time management'},
 'time managing/_n': {'e_noun._n': 'time management'},
 'timeless travel/_n': {'e_noun._n': 'time travel'},
 'time travelled/_n': {'e_noun._n': 'time travel'},
 'tobacco industrial/_n': {'e_noun._n': 'tobacco industry'},
 'the tobacco industrial/_n': {'e_noun._n': 'the tobacco industry'},
 'top tenth/_n': {'e_noun._n': 'top ten'},
 'tradable relations/_n': {'e_noun._n': 'trade relations'},
 'the us governing/_n': {'e_noun._n': 'the us government'},
 'unemployment insured/_n': {'e_noun._n': 'unemployment insurance'},
 'unfair competing/_n': {'e_noun._n': 'unfair competition'},
 'the united states governing/_n': {'e_noun._n': 'the united states government'},
 'virtual real/_n': {'e_noun._n': 'virtual reality'},
 'voiced recognition/_n': {'e_noun._n': 'voice recognition'},
 'volunteer workless/_n': {'e_noun._n': 'volunteer work'},
 'warm sprung/_n': {'e_noun._n': 'warm spring'},
 'wasteful disposal/_n': {'e_noun._n': 'waste disposal'},
 'waste disposable/_n': {'e_noun._n': 'waste disposal'},
 'a wasteful of time/_n': {'e_noun._n': 'a waste of time'},
 'a waste of timeless/_n': {'e_noun._n': 'a waste of time'},
 'waterless pollution/_n': {'e_noun._n': 'water pollution'},
 'waterless quality/_n': {'e_noun._n': 'water quality'},
 'waterless resources/_n': {'e_noun._n': 'water resources'},
 'western cultural/_n': {'e_noun._n': 'western culture'},
 'western historic/_n': {'e_noun._n': 'western history'},
 'western literary/_n': {'e_noun._n': 'western literature'},
 'your willing/_n': {'e_noun._n': 'your will'},
 'their willing/_n': {'e_noun._n': 'their will'},
 'his willing/_n': {'e_noun._n': 'his will'},
 'windy power/_n': {'e_noun._n': 'wind power'},
 'wind powerful/_n': {'e_noun._n': 'wind power'},
 'wire communication/_n': {'e_noun._n': 'wireless communication'},
 'wireless communicative/_n': {'e_noun._n': 'wireless communication'},
 'no wordless/_n': {'e_noun._n': 'no word'},
 'your wordless/_n': {'e_noun._n': 'your word'},
 'another wordless/_n': {'e_noun._n': 'another word'},
 'a wordless/_n': {'e_noun._n': 'a word'},
 'workless together/_n': {'e_noun._n': 'work together'},
 'the world economic/_n': {'e_noun._n': 'the world economy'},
 'world historic/_n': {'e_noun._n': 'world history'},
 'world peaceful/_n': {'e_noun._n': 'world peace'},
 'world tradable/_n': {'e_noun._n': 'world trade'},
 'year outsider/_n': {'e_noun._n': 'year out'},
 'a young manly/_n': {'e_noun._n': 'a young man'},
 'young manly/_n': {'e_noun._n': 'young man'},
 'younger brotherly/_n': {'e_noun._n': 'younger brother'},
 'your lovable/_n': {'e_noun._n': 'your love'},
 'your minded/_n': {'e_noun._n': 'your mind'},
 'your timeless/_n': {'e_noun._n': 'your time'},
 'your votable/_n': {'e_noun._n': 'your vote'},
 'your weighable/_n': {'e_noun._n': 'your weight'},
 'your workless/_n': {'e_noun._n': 'your work'},
 'youthful sports/_n': {'e_noun._n': 'youth sports'},
 'his able/_n': {'e_noun._n': 'his ability'},
 'her able/_n': {'e_noun._n': 'her ability'},
 'its able/_n': {'e_noun._n': 'its ability'},
 'athletic able/_n': {'e_noun._n': 'athletic ability'},
 'our able/_n': {'e_noun._n': 'our ability'},
 'their able/_n': {'e_noun._n': 'their ability'},
 'my able/_n': {'e_noun._n': 'my ability'},
 'that able/_n': {'e_noun._n': 'that ability'},
 'the absent/_n': {'e_noun._n': 'the absence'},
 'her absent/_n': {'e_noun._n': 'her absence'},
 'its absent/_n': {'e_noun._n': 'its absence'},
 'their absent/_n': {'e_noun._n': 'their absence'},
 'his absent/_n': {'e_noun._n': 'his absence'},
 'abuse of powerful/_n': {'e_noun._n': 'abuse of power'},
 'public acceptable/_n': {'e_noun._n': 'public acceptance'},
 'accessible to the internet/_n': {'e_noun._n': 'access to the internet'},
 'local accessible/_n': {'e_noun._n': 'local access'},
 'unlimited accessible/_n': {'e_noun._n': 'unlimited access'},
 'random accessible/_n': {'e_noun._n': 'random access'},
 'high-speed internet accessible/_n': {'e_noun._n': 'high-speed internet access'},
 'market accessible/_n': {'e_noun._n': 'market access'},
 'easy accessible/_n': {'e_noun._n': 'easy access'},
 'high-speed accessible/_n': {'e_noun._n': 'high-speed access'},
 'the accessible/_n': {'e_noun._n': 'the access'},
 'web accessible/_n': {'e_noun._n': 'web access'},
 'accessible to/_n': {'e_noun._n': 'access to'},
 'remote accessible/_n': {'e_noun._n': 'remote access'},
 'a car accidental/_n': {'e_noun._n': 'a car accident'},
 'an auto accidental/_n': {'e_noun._n': 'an auto accident'},
 'an automobile accidental/_n': {'e_noun._n': 'an automobile accident'},
 'no accidental/_n': {'e_noun._n': 'no accident'},
 'that accidental/_n': {'e_noun._n': 'that accident'},
 'one accountable/_n': {'e_noun._n': 'one account'},
 'his own accountable/_n': {'e_noun._n': 'his own account'},
 'its accountable/_n': {'e_noun._n': 'its account'},
 'his accountable/_n': {'e_noun._n': 'his account'},
 'her accountable/_n': {'e_noun._n': 'her account'},
 'their accountable/_n': {'e_noun._n': 'their account'},
 'your accountable/_n': {'e_noun._n': 'your account'},
 'that accountable/_n': {'e_noun._n': 'that account'},
 'an accountable/_n': {'e_noun._n': 'an account'},
 'the accountable/_n': {'e_noun._n': 'the account'},
 'their accurate/_n': {'e_noun._n': 'their accuracy'},
 'its accurate/_n': {'e_noun._n': 'its accuracy'},
 'an achievable/_n': {'e_noun._n': 'an achievement'},
 'student achievable/_n': {'e_noun._n': 'student achievement'},
 'the achievable/_n': {'e_noun._n': 'the achievement'},
 'their achievable/_n': {'e_noun._n': 'their achievement'},
 'his achievable/_n': {'e_noun._n': 'his achievement'},
 'that achievable/_n': {'e_noun._n': 'that achievement'},
 'an acquisitive/_n': {'e_noun._n': 'an acquisition'},
 'its acquisitive/_n': {'e_noun._n': 'its acquisition'},
 'violence acts/_n': {'e_noun._n': 'violent acts'},
 'this acts/_n': {'e_noun._n': 'those acts'},
 'crime acts/_n': {'e_noun._n': 'criminal acts'},
 'this actions/_n': {'e_noun._n': 'those actions'},
 'living action/_n': {'e_noun._n': 'live action'},
 'governing action/_n': {'e_noun._n': 'government action'},
 'environment activists/_n': {'e_noun._n': 'environmental activists'},
 'this activities/_n': {'e_noun._n': 'those activities'},
 'such active/_n': {'e_noun._n': 'such activity'},
 'their active/_n': {'e_noun._n': 'their activity'},
 'that active/_n': {'e_noun._n': 'that activity'},
 'sexual active/_n': {'e_noun._n': 'sexual activity'},
 'political active/_n': {'e_noun._n': 'political activity'},
 'business active/_n': {'e_noun._n': 'business activity'},
 'criminal active/_n': {'e_noun._n': 'criminal activity'},
 'illegal active/_n': {'e_noun._n': 'illegal activity'},
 'homosexual active/_n': {'e_noun._n': 'homosexual activity'},
 'economic active/_n': {'e_noun._n': 'economic activity'},
 'human active/_n': {'e_noun._n': 'human activity'},
 'this ads/_n': {'e_noun._n': 'those ads'},
 'attacking ads/_n': {'e_noun._n': 'attack ads'},
 'each additive/_n': {'e_noun._n': 'each addition'},
 'an adjusted/_n': {'e_noun._n': 'an adjustment'},
 'the adjusted/_n': {'e_noun._n': 'the adjustment'},
 'whose administrative/_n': {'e_noun._n': 'whose administration'},
 'senior administrative/_n': {'e_noun._n': 'senior administration'},
 'the nixon administrative/_n': {'e_noun._n': 'the nixon administration'},
 'the food and drug administrative/_n': {'e_noun._n': 'the food and drug administration'},
 'the new administrative/_n': {'e_noun._n': 'the new administration'},
 'my administrative/_n': {'e_noun._n': 'my administration'},
 'a new administrative/_n': {'e_noun._n': 'a new administration'},
 'his administrative/_n': {'e_noun._n': 'his administration'},
 'clinton administrative/_n': {'e_noun._n': 'clinton administration'},
 'top administrative/_n': {'e_noun._n': 'top administration'},
 'food and drug administrative/_n': {'e_noun._n': 'food and drug administration'},
 'the clinton administrative/_n': {'e_noun._n': 'the clinton administration'},
 'her administrative/_n': {'e_noun._n': 'her administration'},
 'mutual admirable/_n': {'e_noun._n': 'mutual admiration'},
 'their advantageous/_n': {'e_noun._n': 'their advantage'},
 'competitive advantageous/_n': {'e_noun._n': 'competitive advantage'},
 'the advantageous/_n': {'e_noun._n': 'the advantage'},
 'his advantageous/_n': {'e_noun._n': 'his advantage'},
 'another advantageous/_n': {'e_noun._n': 'another advantage'},
 'advantageous of them/_n': {'e_noun._n': 'advantage of them'},
 'its advantageous/_n': {'e_noun._n': 'its advantage'},
 'advantageous of/_n': {'e_noun._n': 'advantage of'},
 'an advantageous/_n': {'e_noun._n': 'an advantage'},
 'that advantageous/_n': {'e_noun._n': 'that advantage'},
 'advantageous of it/_n': {'e_noun._n': 'advantage of it'},
 'consuming advocates/_n': {'e_noun._n': 'consumer advocates'},
 'healthy advocates/_n': {'e_noun._n': 'health advocates'},
 'private advocates/_n': {'e_noun._n': 'privacy advocates'},
 'governing affairs/_n': {'e_noun._n': 'government affairs'},
 'the whole advantaged/_n': {'e_noun._n': 'the whole affair'},
 'his advantaged/_n': {'e_noun._n': 'his affair'},
 'a family advantaged/_n': {'e_noun._n': 'a family affair'},
 'their advantaged/_n': {'e_noun._n': 'their affair'},
 'economy affairs/_n': {'e_noun._n': 'economic affairs'},
 'nation affairs/_n': {'e_noun._n': 'national affairs'},
 'early adventurous/_n': {'e_noun._n': 'early afternoon'},
 'that adventurous/_n': {'e_noun._n': 'that afternoon'},
 'the late adventurous/_n': {'e_noun._n': 'the late afternoon'},
 'a recent adventurous/_n': {'e_noun._n': 'a recent afternoon'},
 'late adventurous/_n': {'e_noun._n': 'late afternoon'},
 'this ages/_n': {'e_noun._n': 'those ages'},
 'other governing agencies/_n': {'e_noun._n': 'other government agencies'},
 'a governing agency/_n': {'e_noun._n': 'a government agency'},
 'aided agencies/_n': {'e_noun._n': 'aid agencies'},
 'lawful enforcement agencies/_n': {'e_noun._n': 'law enforcement agencies'},
 'law enforced agencies/_n': {'e_noun._n': 'law enforcement agencies'},
 'governing agencies/_n': {'e_noun._n': 'government agencies'},
 'this agencies/_n': {'e_noun._n': 'those agencies'},
 'intelligent agencies/_n': {'e_noun._n': 'intelligence agencies'},
 'enforced agencies/_n': {'e_noun._n': 'enforcement agencies'},
 'online agent/_n': {'e_noun._n': 'online advertising'},
 'governing agents/_n': {'e_noun._n': 'government agents'},
 'one advertising/_n': {'e_noun._n': 'one agent'},
 'their agreeable/_n': {'e_noun._n': 'their agreement'},
 'no agreeable/_n': {'e_noun._n': 'no agreement'},
 'such an agreeable/_n': {'e_noun._n': 'such an agreement'},
 "today's agreeable/_n": {'e_noun._n': "today's agreement"},
 'the peaceful agreement/_n': {'e_noun._n': 'the peace agreement'},
 'the peace agreeable/_n': {'e_noun._n': 'the peace agreement'},
 'that agreeable/_n': {'e_noun._n': 'that agreement'},
 'a final agreeable/_n': {'e_noun._n': 'a final agreement'},
 'a peaceful agreement/_n': {'e_noun._n': 'a peace agreement'},
 'a peace agreeable/_n': {'e_noun._n': 'a peace agreement'},
 'tradable agreements/_n': {'e_noun._n': 'trade agreements'},
 'any agreeable/_n': {'e_noun._n': 'any agreement'},
 'general agreeable/_n': {'e_noun._n': 'general agreement'},
 'its agreeable/_n': {'e_noun._n': 'its agreement'},
 'a new agreeable/_n': {'e_noun._n': 'a new agreement'},
 'this agreements/_n': {'e_noun._n': 'those agreements'},
 'american agricultural/_n': {'e_noun._n': 'american agriculture'},
 'their aided/_n': {'e_noun._n': 'their aid'},
 'such aided/_n': {'e_noun._n': 'such aid'},
 'emergency aided/_n': {'e_noun._n': 'emergency aid'},
 'international aided/_n': {'e_noun._n': 'international aid'},
 'public aided/_n': {'e_noun._n': 'public aid'},
 'private aided/_n': {'e_noun._n': 'private aid'},
 'food aided/_n': {'e_noun._n': 'food aid'},
 'military aided/_n': {'e_noun._n': 'military aid'},
 'governing aid/_n': {'e_noun._n': 'government aid'},
 'government aided/_n': {'e_noun._n': 'government aid'},
 'more aided/_n': {'e_noun._n': 'more aid'},
 'economy aid/_n': {'e_noun._n': 'economic aid'},
 'state aided/_n': {'e_noun._n': 'state aid'},
 'american aided/_n': {'e_noun._n': 'american aid'},
 'finance aid/_n': {'e_noun._n': 'financial aid'},
 'the aided/_n': {'e_noun._n': 'the aid'},
 'humanitarian aided/_n': {'e_noun._n': 'humanitarian aid'},
 'economic aided/_n': {'e_noun._n': 'economic aid'},
 'federal aided/_n': {'e_noun._n': 'federal aid'},
 'their advisory/_n': {'e_noun._n': 'their aim'},
 'whose advisory/_n': {'e_noun._n': 'whose aim'},
 'spaced aliens/_n': {'e_noun._n': 'space aliens'},
 'all i canning say/_n': {'e_noun._n': 'all i can say'},
 'all we canning do/_n': {'e_noun._n': 'all we can do'},
 'all i canning do/_n': {'e_noun._n': 'all i can do'},
 'all you canning do/_n': {'e_noun._n': 'all you can do'},
 'asset allocative/_n': {'e_noun._n': 'asset allocation'},
 'an allowable/_n': {'e_noun._n': 'an allowance'},
 'an amenable/_n': {'e_noun._n': 'an amendment'},
 'his amenable/_n': {'e_noun._n': 'his amendment'},
 'a constitutional amenable/_n': {'e_noun._n': 'a constitutional amendment'},
 'the 14th amenable/_n': {'e_noun._n': 'the 14th amendment'},
 'the amenable/_n': {'e_noun._n': 'the amendment'},
 'constitutional amenable/_n': {'e_noun._n': 'constitutional amendment'},
 'living ammunition/_n': {'e_noun._n': 'live ammunition'},
 'the analogous/_n': {'e_noun._n': 'the analogy'},
 'the final analytic/_n': {'e_noun._n': 'the final analysis'},
 'that analytic/_n': {'e_noun._n': 'that analysis'},
 'his analytic/_n': {'e_noun._n': 'his analysis'},
 'their analytic/_n': {'e_noun._n': 'their analysis'},
 'dna analytic/_n': {'e_noun._n': 'dna analysis'},
 'the analytic/_n': {'e_noun._n': 'the analysis'},
 'intelligent analysts/_n': {'e_noun._n': 'intelligence analysts'},
 'industrial analysts/_n': {'e_noun._n': 'industry analysts'},
 'sixteenth analysts/_n': {'e_noun._n': 'six analysts'},
 'food and waterless/_n': {'e_noun._n': 'food and water'},
 'life and lovable/_n': {'e_noun._n': 'life and love'},
 'my wifelike and i/_n': {'e_noun._n': 'my wife and i'},
 'timeless and money/_n': {'e_noun._n': 'time and money'},
 'filmed and television/_n': {'e_noun._n': 'film and television'},
 'math and scientific/_n': {'e_noun._n': 'math and science'},
 'his wifelike and children/_n': {'e_noun._n': 'his wife and children'},
 'life and dead/_n': {'e_noun._n': 'life and death'},
 'he and his wifelike/_n': {'e_noun._n': 'he and his wife'},
 'research and developed/_n': {'e_noun._n': 'research and development'},
 'healthy and safety/_n': {'e_noun._n': 'health and safety'},
 'health and safe/_n': {'e_noun._n': 'health and safety'},
 'a manly and a womanly/_n': {'e_noun._n': 'a man and a woman'},
 'her angry/_n': {'e_noun._n': 'her anger'},
 'that angry/_n': {'e_noun._n': 'that anger'},
 'public angry/_n': {'e_noun._n': 'public anger'},
 'their angry/_n': {'e_noun._n': 'their anger'},
 'every angled/_n': {'e_noun._n': 'every angle'},
 'wildlife animals/_n': {'e_noun._n': 'wild animals'},
 'this animals/_n': {'e_noun._n': 'those animals'},
 'computational animation/_n': {'e_noun._n': 'computer animation'},
 'another inner/_n': {'e_noun._n': 'another in'},
 'that answering/_n': {'e_noun._n': 'that answer'},
 'the correct answering/_n': {'e_noun._n': 'the correct answer'},
 'their answering/_n': {'e_noun._n': 'their answer'},
 'my answering/_n': {'e_noun._n': 'my answer'},
 'no answering/_n': {'e_noun._n': 'no answer'},
 'this answers/_n': {'e_noun._n': 'those answers'},
 'one answering/_n': {'e_noun._n': 'one answer'},
 'her answering/_n': {'e_noun._n': 'her answer'},
 'the answering to that question/_n': {'e_noun._n': 'the answer to that question'},
 'not the answering/_n': {'e_noun._n': 'not the answer'},
 'the short answering/_n': {'e_noun._n': 'the short answer'},
 'his answering/_n': {'e_noun._n': 'his answer'},
 'an answering/_n': {'e_noun._n': 'an answer'},
 'the answering to that/_n': {'e_noun._n': 'the answer to that'},
 'your answering/_n': {'e_noun._n': 'your answer'},
 'the anticipative/_n': {'e_noun._n': 'the anticipation'},
 'any attentive/_n': {'e_noun._n': 'any attention'},
 'anything like those/_n': {'e_noun._n': 'anything like this'},
 'his apologetical/_n': {'e_noun._n': 'his apology'},
 'an apologetical/_n': {'e_noun._n': 'an apology'},
 'no apologetical/_n': {'e_noun._n': 'no apology'},
 'the apologetical/_n': {'e_noun._n': 'the apology'},
 'thunderous applaudable/_n': {'e_noun._n': 'thunderous applause'},
 'loud applaudable/_n': {'e_noun._n': 'loud applause'},
 'the applaudable/_n': {'e_noun._n': 'the applause'},
 'their applicable/_n': {'e_noun._n': 'their application'},
 'his applicable/_n': {'e_noun._n': 'his application'},
 'an applicable/_n': {'e_noun._n': 'an application'},
 'her applicable/_n': {'e_noun._n': 'her application'},
 'an appointive/_n': {'e_noun._n': 'an appointment'},
 'his appointive/_n': {'e_noun._n': 'his appointment'},
 'the appointive/_n': {'e_noun._n': 'the appointment'},
 'her appointive/_n': {'e_noun._n': 'her appointment'},
 'my approachable/_n': {'e_noun._n': 'my approach'},
 'that approachable/_n': {'e_noun._n': 'that approach'},
 'their approachable/_n': {'e_noun._n': 'their approach'},
 'another approachable/_n': {'e_noun._n': 'another approach'},
 'an approachable/_n': {'e_noun._n': 'an approach'},
 'one approachable/_n': {'e_noun._n': 'one approach'},
 'the new approachable/_n': {'e_noun._n': 'the new approach'},
 'such an approachable/_n': {'e_noun._n': 'such an approach'},
 'our approachable/_n': {'e_noun._n': 'our approach'},
 'the best approachable/_n': {'e_noun._n': 'the best approach'},
 'her approachable/_n': {'e_noun._n': 'her approach'},
 'a new approachable/_n': {'e_noun._n': 'a new approach'},
 'his approachable/_n': {'e_noun._n': 'his approach'},
 'its approachable/_n': {'e_noun._n': 'its approach'},
 'a different approachable/_n': {'e_noun._n': 'a different approach'},
 'governing approval/_n': {'e_noun._n': 'government approval'},
 'government approving/_n': {'e_noun._n': 'government approval'},
 'federal approving/_n': {'e_noun._n': 'federal approval'},
 'their approving/_n': {'e_noun._n': 'their approval'},
 'regulatory approving/_n': {'e_noun._n': 'regulatory approval'},
 'senate approving/_n': {'e_noun._n': 'senate approval'},
 'legislative approving/_n': {'e_noun._n': 'legislative approval'},
 'votable approval/_n': {'e_noun._n': 'voter approval'},
 'voter approving/_n': {'e_noun._n': 'voter approval'},
 'final approving/_n': {'e_noun._n': 'final approval'},
 'his approving/_n': {'e_noun._n': 'his approval'},
 'congressional approving/_n': {'e_noun._n': 'congressional approval'},
 'fda approving/_n': {'e_noun._n': 'fda approval'},
 'its approving/_n': {'e_noun._n': 'its approval'},
 'high approving/_n': {'e_noun._n': 'high approval'},
 'this areas/_n': {'e_noun._n': 'those areas'},
 'surround areas/_n': {'e_noun._n': 'surrounding areas'},
 'the surround area/_n': {'e_noun._n': 'the surrounding area'},
 'third areas/_n': {'e_noun._n': 'three areas'},
 'difference areas/_n': {'e_noun._n': 'different areas'},
 'their arguable/_n': {'e_noun._n': 'their argument'},
 'the arguable/_n': {'e_noun._n': 'the argument'},
 'that arguable/_n': {'e_noun._n': 'that argument'},
 'his arguable/_n': {'e_noun._n': 'his argument'},
 'an arguable/_n': {'e_noun._n': 'an argument'},
 'this arguments/_n': {'e_noun._n': 'those arguments'},
 'no arguable/_n': {'e_noun._n': 'no argument'},
 'my armed/_n': {'e_noun._n': 'my arm'},
 'his left armed/_n': {'e_noun._n': 'his left arm'},
 'right armed/_n': {'e_noun._n': 'right arm'},
 'his right armed/_n': {'e_noun._n': 'his right arm'},
 'one armed/_n': {'e_noun._n': 'one arm'},
 'your armed/_n': {'e_noun._n': 'your arm'},
 'bodily armor/_n': {'e_noun._n': 'body armor'},
 'the arranged/_n': {'e_noun._n': 'the arrangement'},
 'the new arranged/_n': {'e_noun._n': 'the new arrangement'},
 'an arranged/_n': {'e_noun._n': 'an arrangement'},
 'such an arranged/_n': {'e_noun._n': 'such an arrangement'},
 'that arranged/_n': {'e_noun._n': 'that arrangement'},
 'specialist arrangement/_n': {'e_noun._n': 'special arrangement'},
 'special arranged/_n': {'e_noun._n': 'special arrangement'},
 'his arresting/_n': {'e_noun._n': 'his arrest'},
 'her arresting/_n': {'e_noun._n': 'her arrest'},
 'their arresting/_n': {'e_noun._n': 'their arrest'},
 'his arrived/_n': {'e_noun._n': 'his arrival'},
 'her arrived/_n': {'e_noun._n': 'her arrival'},
 'the arrived/_n': {'e_noun._n': 'the arrival'},
 'their arrived/_n': {'e_noun._n': 'their arrival'},
 'its arrived/_n': {'e_noun._n': 'its arrival'},
 'our arrived/_n': {'e_noun._n': 'our arrival'},
 'your articled/_n': {'e_noun._n': 'your article'},
 'that articled/_n': {'e_noun._n': 'that article'},
 'an articled/_n': {'e_noun._n': 'an article'},
 'his articled/_n': {'e_noun._n': 'his article'},
 'a recent articled/_n': {'e_noun._n': 'a recent article'},
 'the articled/_n': {'e_noun._n': 'the article'},
 'the assembling/_n': {'e_noun._n': 'the assembly'},
 'final assembling/_n': {'e_noun._n': 'final assembly'},
 'the assessable/_n': {'e_noun._n': 'the assessment'},
 'that assessable/_n': {'e_noun._n': 'that assessment'},
 'his assessable/_n': {'e_noun._n': 'his assessment'},
 'an assessable/_n': {'e_noun._n': 'an assessment'},
 'finance assets/_n': {'e_noun._n': 'financial assets'},
 'an assigned/_n': {'e_noun._n': 'an assignment'},
 'third assists/_n': {'e_noun._n': 'three assists'},
 'humanitarian assistant/_n': {'e_noun._n': 'humanitarian assistance'},
 'assistance inner/_n': {'e_noun._n': 'assistance in'},
 'economic assistant/_n': {'e_noun._n': 'economic assistance'},
 'financial assistant/_n': {'e_noun._n': 'financial assistance'},
 'technical assistant/_n': {'e_noun._n': 'technical assistance'},
 'governing assistance/_n': {'e_noun._n': 'government assistance'},
 'government assistant/_n': {'e_noun._n': 'government assistance'},
 'federal assistant/_n': {'e_noun._n': 'federal assistance'},
 'such assistant/_n': {'e_noun._n': 'such assistance'},
 'foreign assistant/_n': {'e_noun._n': 'foreign assistance'},
 'international assistant/_n': {'e_noun._n': 'international assistance'},
 'cash assistant/_n': {'e_noun._n': 'cash assistance'},
 'an assistance/_n': {'e_noun._n': 'an assistant'},
 'emergency assistant/_n': {'e_noun._n': 'emergency assistance'},
 'tradable associations/_n': {'e_noun._n': 'trade associations'},
 'that assumed/_n': {'e_noun._n': 'that assumption'},
 'a professional athletic/_n': {'e_noun._n': 'a professional athlete'},
 'the attaching/_n': {'e_noun._n': 'the attachment'},
 'an attaching/_n': {'e_noun._n': 'an attachment'},
 'the terrorist attacking/_n': {'e_noun._n': 'the terrorist attack'},
 'nuclear attacking/_n': {'e_noun._n': 'nuclear attack'},
 'this attacks/_n': {'e_noun._n': 'those attacks'},
 'the attacks on the world tradable center and the pentagon/_n': {'e_noun._n': 'the attacks on the world trade center and the pentagon'},
 'that attacking/_n': {'e_noun._n': 'that attack'},
 'a terrorist attacking/_n': {'e_noun._n': 'a terrorist attack'},
 'such an attacking/_n': {'e_noun._n': 'such an attack'},
 'terrorist attacking/_n': {'e_noun._n': 'terrorist attack'},
 'his attacking/_n': {'e_noun._n': 'his attack'},
 'their attacking/_n': {'e_noun._n': 'their attack'},
 'another attacking/_n': {'e_noun._n': 'another attack'},
 'the attacking on pearl harbor/_n': {'e_noun._n': 'the attack on pearl harbor'},
 'no attempted/_n': {'e_noun._n': 'no attempt'},
 'church attendant/_n': {'e_noun._n': 'church attendance'},
 'this attending/_n': {'e_noun._n': 'those attending'},
 'her attentive/_n': {'e_noun._n': 'her attention'},
 'our attentive/_n': {'e_noun._n': 'our attention'},
 'attentive to/_n': {'e_noun._n': 'attention to'},
 'close attentive/_n': {'e_noun._n': 'close attention'},
 'no attentive/_n': {'e_noun._n': 'no attention'},
 'specialist attention/_n': {'e_noun._n': 'special attention'},
 'special attentive/_n': {'e_noun._n': 'special attention'},
 'the most attentive/_n': {'e_noun._n': 'the most attention'},
 'world attentive/_n': {'e_noun._n': 'world attention'},
 'particular attentive/_n': {'e_noun._n': 'particular attention'},
 'enough attentive/_n': {'e_noun._n': 'enough attention'},
 'less attentive/_n': {'e_noun._n': 'less attention'},
 'public attentive/_n': {'e_noun._n': 'public attention'},
 'immediate attentive/_n': {'e_noun._n': 'immediate attention'},
 'some attentive/_n': {'e_noun._n': 'some attention'},
 "the world's attentive/_n": {'e_noun._n': "the world's attention"},
 'serious attentive/_n': {'e_noun._n': 'serious attention'},
 'their attentive/_n': {'e_noun._n': 'their attention'},
 'much attentive/_n': {'e_noun._n': 'much attention'},
 'too much attentive/_n': {'e_noun._n': 'too much attention'},
 'the attentive/_n': {'e_noun._n': 'the attention'},
 'all the attentive/_n': {'e_noun._n': 'all the attention'},
 'its attentive/_n': {'e_noun._n': 'its attention'},
 "everyone's attentive/_n": {'e_noun._n': "everyone's attention"},
 'medical attentive/_n': {'e_noun._n': 'medical attention'},
 'your attentive/_n': {'e_noun._n': 'your attention'},
 'more attentive/_n': {'e_noun._n': 'more attention'},
 'little attentive/_n': {'e_noun._n': 'little attention'},
 'considerable attentive/_n': {'e_noun._n': 'considerable attention'},
 'such attentive/_n': {'e_noun._n': 'such attention'},
 'my attentive/_n': {'e_noun._n': 'my attention'},
 'national attentive/_n': {'e_noun._n': 'national attention'},
 'international attentive/_n': {'e_noun._n': 'international attention'},
 "people's attentive/_n": {'e_noun._n': "people's attention"},
 'so much attentive/_n': {'e_noun._n': 'so much attention'},
 'media attentive/_n': {'e_noun._n': 'media attention'},
 'worldwide attentive/_n': {'e_noun._n': 'worldwide attention'},
 'his attentive/_n': {'e_noun._n': 'his attention'},
 'a tourist attractive/_n': {'e_noun._n': 'a tourist attraction'},
 'the main attractive/_n': {'e_noun._n': 'the main attraction'},
 'its authoritative/_n': {'e_noun._n': 'its authority'},
 'their authoritative/_n': {'e_noun._n': 'their authority'},
 'more authoritative/_n': {'e_noun._n': 'more authority'},
 'lawful enforcement authorities/_n': {'e_noun._n': 'law enforcement authorities'},
 'law enforced authorities/_n': {'e_noun._n': 'law enforcement authorities'},
 'healthy authorities/_n': {'e_noun._n': 'health authorities'},
 'legal authoritative/_n': {'e_noun._n': 'legal authority'},
 'fast-track authoritative/_n': {'e_noun._n': 'fast-track authority'},
 'that authoritative/_n': {'e_noun._n': 'that authority'},
 'his authoritative/_n': {'e_noun._n': 'his authority'},
 'such authoritative/_n': {'e_noun._n': 'such authority'},
 'immigrant authorities/_n': {'e_noun._n': 'immigration authorities'},
 'federal authoritative/_n': {'e_noun._n': 'federal authority'},
 'moral authoritative/_n': {'e_noun._n': 'moral authority'},
 'governing authorities/_n': {'e_noun._n': 'government authorities'},
 'an automation/_n': {'e_noun._n': 'an automatic'},
 'his available/_n': {'e_noun._n': 'his availability'},
 'an averaged/_n': {'e_noun._n': 'an average'},
 'that averaged/_n': {'e_noun._n': 'that average'},
 'the dow jones industrial averaged/_n': {'e_noun._n': 'the dow jones industrial average'},
 'the averaged/_n': {'e_noun._n': 'the average'},
 'the national averaged/_n': {'e_noun._n': 'the national average'},
 'public aware/_n': {'e_noun._n': 'public awareness'},
 'difference backgrounds/_n': {'e_noun._n': 'different backgrounds'},
 'a badness/_n': {'e_noun._n': 'a bad'},
 'his balanced/_n': {'e_noun._n': 'his balance'},
 'my balanced/_n': {'e_noun._n': 'my balance'},
 'that balanced/_n': {'e_noun._n': 'that balance'},
 'a rocky band/_n': {'e_noun._n': 'a rock band'},
 'a rock banded/_n': {'e_noun._n': 'a rock band'},
 'her banded/_n': {'e_noun._n': 'her band'},
 'rocky bands/_n': {'e_noun._n': 'rock bands'},
 'a banded/_n': {'e_noun._n': 'a band'},
 'his banded/_n': {'e_noun._n': 'his band'},
 'center bankers/_n': {'e_noun._n': 'central bankers'},
 'tradable barriers/_n': {'e_noun._n': 'trade barriers'},
 'this barriers/_n': {'e_noun._n': 'those barriers'},
 'a weekly base/_n': {'e_noun._n': 'a weekly basis'},
 'a day basis,/_n': {'e_noun._n': 'a daily basis,'},
 'a day basis/_n': {'e_noun._n': 'a daily basis'},
 'a daily base/_n': {'e_noun._n': 'a daily basis'},
 'a case-by-case base/_n': {'e_noun._n': 'a case-by-case basis'},
 'a regular base/_n': {'e_noun._n': 'a regular basis'},
 'a day-to-day base/_n': {'e_noun._n': 'a day-to-day basis'},
 'an annual base/_n': {'e_noun._n': 'an annual basis'},
 'private bathed/_n': {'e_noun._n': 'private bath'},
 'the beamed/_n': {'e_noun._n': 'the beam'},
 'his bearded/_n': {'e_noun._n': 'his beard'},
 'nature beauty/_n': {'e_noun._n': 'natural beauty'},
 'their beautiful/_n': {'e_noun._n': 'their beauty'},
 'her beautiful/_n': {'e_noun._n': 'her beauty'},
 'his hospital bedding/_n': {'e_noun._n': 'his hospital bed'},
 'a bedding/_n': {'e_noun._n': 'a bed'},
 'my bedding/_n': {'e_noun._n': 'my bed'},
 'the beginning of those year/_n': {'e_noun._n': 'the beginning of this year'},
 'violence behavior/_n': {'e_noun._n': 'violent behavior'},
 'crime behavior/_n': {'e_noun._n': 'criminal behavior'},
 'sex behavior/_n': {'e_noun._n': 'sexual behavior'},
 'religion beliefs/_n': {'e_noun._n': 'religious beliefs'},
 'religion belief/_n': {'e_noun._n': 'religious belief'},
 'religious believing/_n': {'e_noun._n': 'religious belief'},
 'his believing/_n': {'e_noun._n': 'his belief'},
 'popular believing/_n': {'e_noun._n': 'popular belief'},
 'that believing/_n': {'e_noun._n': 'that belief'},
 'our believing/_n': {'e_noun._n': 'our belief'},
 'my believing/_n': {'e_noun._n': 'my belief'},
 'the belted/_n': {'e_noun._n': 'the belt'},
 'a belted/_n': {'e_noun._n': 'a belt'},
 'her belted/_n': {'e_noun._n': 'her belt'},
 'his belted/_n': {'e_noun._n': 'his belt'},
 'its belted/_n': {'e_noun._n': 'its belt'},
 'my belted/_n': {'e_noun._n': 'my belt'},
 'social secure benefits/_n': {'e_noun._n': 'social security benefits'},
 'a beneficial/_n': {'e_noun._n': 'a benefit'},
 'this benefits/_n': {'e_noun._n': 'those benefits'},
 'healthy benefits/_n': {'e_noun._n': 'health benefits'},
 'no beneficial/_n': {'e_noun._n': 'no benefit'},
 'governing benefits/_n': {'e_noun._n': 'government benefits'},
 'that beneficial/_n': {'e_noun._n': 'that benefit'},
 'society benefits/_n': {'e_noun._n': 'social benefits'},
 'the best inner the world/_n': {'e_noun._n': 'the best in the world'},
 'taxable bills/_n': {'e_noun._n': 'tax bills'},
 'spent bills/_n': {'e_noun._n': 'spending bills'},
 'the housed bill/_n': {'e_noun._n': 'the house bill'},
 'the taxable bill/_n': {'e_noun._n': 'the tax bill'},
 'utilisable bills/_n': {'e_noun._n': 'utility bills'},
 'evolution biology/_n': {'e_noun._n': 'evolutionary biology'},
 'agriculture biotechnology/_n': {'e_noun._n': 'agricultural biotechnology'},
 'the cage bird/_n': {'e_noun._n': 'the caged bird'},
 'multiply births/_n': {'e_noun._n': 'multiple births'},
 'black smoking/_n': {'e_noun._n': 'black smoke'},
 'a blackness/_n': {'e_noun._n': 'a black'},
 'the blamed/_n': {'e_noun._n': 'the blame'},
 'a mixed blessed/_n': {'e_noun._n': 'a mixed blessing'},
 'his blessed/_n': {'e_noun._n': 'his blessing'},
 'third blocks/_n': {'e_noun._n': 'three blocks'},
 'his blocked/_n': {'e_noun._n': 'his block'},
 'sixteenth blocks/_n': {'e_noun._n': 'six blocks'},
 'my bloody/_n': {'e_noun._n': 'my blood'},
 'human bloody/_n': {'e_noun._n': 'human blood'},
 'cord bloody/_n': {'e_noun._n': 'cord blood'},
 'her bloody/_n': {'e_noun._n': 'her blood'},
 'your bloody/_n': {'e_noun._n': 'your blood'},
 'tainted bloody/_n': {'e_noun._n': 'tainted blood'},
 'no bloody/_n': {'e_noun._n': 'no blood'},
 'another blown/_n': {'e_noun._n': 'another blow'},
 'the blueness/_n': {'e_noun._n': 'the blue'},
 'a cut board/_n': {'e_noun._n': 'a cutting board'},
 "one's bodily/_n": {'e_noun._n': "one's body"},
 "a woman's bodily/_n": {'e_noun._n': "a woman's body"},
 'my bodily/_n': {'e_noun._n': 'my body'},
 'your bodily/_n': {'e_noun._n': 'your body'},
 'the human bodily/_n': {'e_noun._n': 'the human body'},
 'upper bodily/_n': {'e_noun._n': 'upper body'},
 'that bodily/_n': {'e_noun._n': 'that body'},
 'a bodily/_n': {'e_noun._n': 'a body'},
 'whose bodily/_n': {'e_noun._n': 'whose body'},
 'his bodily/_n': {'e_noun._n': 'his body'},
 'its bodily/_n': {'e_noun._n': 'its body'},
 'their bodily/_n': {'e_noun._n': 'their body'},
 'the student bodily/_n': {'e_noun._n': 'the student body'},
 'her bodily/_n': {'e_noun._n': 'her body'},
 'no bodily/_n': {'e_noun._n': 'no body'},
 'a health body/_n': {'e_noun._n': 'a healthy body'},
 'a boiling over high heat/_n': {'e_noun._n': 'a boil over high heat'},
 'a boil over high heated/_n': {'e_noun._n': 'a boil over high heat'},
 'international bonding/_n': {'e_noun._n': 'international bond'},
 'corporate bonding/_n': {'e_noun._n': 'corporate bond'},
 'long-term bonding/_n': {'e_noun._n': 'long-term bond'},
 'governing bonds/_n': {'e_noun._n': 'government bonds'},
 'new bonding/_n': {'e_noun._n': 'new bond'},
 'the boned/_n': {'e_noun._n': 'the bone'},
 'a boned/_n': {'e_noun._n': 'a bone'},
 'the historic books/_n': {'e_noun._n': 'the history books'},
 'third books/_n': {'e_noun._n': 'three books'},
 'this books/_n': {'e_noun._n': 'those books'},
 'historic books/_n': {'e_noun._n': 'history books'},
 'illegal bordered/_n': {'e_noun._n': 'illegal border'},
 'a bordered/_n': {'e_noun._n': 'a border'},
 'mexican bordered/_n': {'e_noun._n': 'mexican border'},
 'nation borders/_n': {'e_noun._n': 'national borders'},
 'their bordered/_n': {'e_noun._n': 'their border'},
 'its bordered/_n': {'e_noun._n': 'its border'},
 'the canadian bordered/_n': {'e_noun._n': 'the canadian border'},
 'corporate borrowed/_n': {'e_noun._n': 'corporate borrowing'},
 'a bottled of wine/_n': {'e_noun._n': 'a bottle of wine'},
 'nation boundaries/_n': {'e_noun._n': 'national boundaries'},
 'third boys/_n': {'e_noun._n': 'three boys'},
 'breach of contracted/_n': {'e_noun._n': 'breach of contract'},
 'a breakable/_n': {'e_noun._n': 'a break'},
 'the breakable/_n': {'e_noun._n': 'the break'},
 'taxable breaks/_n': {'e_noun._n': 'tax breaks'},
 'the taxable break/_n': {'e_noun._n': 'the tax break'},
 'the tax breakable/_n': {'e_noun._n': 'the tax break'},
 'a taxable break/_n': {'e_noun._n': 'a tax break'},
 'a tax breakable/_n': {'e_noun._n': 'a tax break'},
 'the taxable breaks/_n': {'e_noun._n': 'the tax breaks'},
 'yellowish brick/_n': {'e_noun._n': 'yellow brick'},
 'the brink of collapsible/_n': {'e_noun._n': 'the brink of collapse'},
 'your brotherly/_n': {'e_noun._n': 'your brother'},
 'older brotherly/_n': {'e_noun._n': 'older brother'},
 'her brotherly/_n': {'e_noun._n': 'her brother'},
 'his younger brotherly/_n': {'e_noun._n': 'his younger brother'},
 'the brotherly/_n': {'e_noun._n': 'the brother'},
 'a brotherly/_n': {'e_noun._n': 'a brother'},
 'third brothers/_n': {'e_noun._n': 'three brothers'},
 'their brotherly/_n': {'e_noun._n': 'their brother'},
 'whose brotherly/_n': {'e_noun._n': 'whose brother'},
 'my brotherly/_n': {'e_noun._n': 'my brother'},
 'one brotherly/_n': {'e_noun._n': 'one brother'},
 'his brotherly/_n': {'e_noun._n': 'his brother'},
 'his older brotherly/_n': {'e_noun._n': 'his older brother'},
 'the brushed/_n': {'e_noun._n': 'the brush'},
 'a brushed/_n': {'e_noun._n': 'a brush'},
 'a balance budget/_n': {'e_noun._n': 'a balanced budget'},
 'historic buffs/_n': {'e_noun._n': 'history buffs'},
 'history buildings/_n': {'e_noun._n': 'historic buildings'},
 'governing buildings/_n': {'e_noun._n': 'government buildings'},
 'this buildings/_n': {'e_noun._n': 'those buildings'},
 'the bulky/_n': {'e_noun._n': 'the bulk'},
 'golden bullion/_n': {'e_noun._n': 'gold bullion'},
 'a bundling/_n': {'e_noun._n': 'a bundle'},
 'the taxable burden/_n': {'e_noun._n': 'the tax burden'},
 'governing bureaucrats/_n': {'e_noun._n': 'government bureaucrats'},
 'success business/_n': {'e_noun._n': 'successful business'},
 'the musical business/_n': {'e_noun._n': 'the music business'},
 'the entertaining business/_n': {'e_noun._n': 'the entertainment business'},
 'the insured business/_n': {'e_noun._n': 'the insurance business'},
 'day business/_n': {'e_noun._n': 'daily business'},
 'sounding business/_n': {'e_noun._n': 'sound business'},
 'the computational business/_n': {'e_noun._n': 'the computer business'},
 'unsalted buttered/_n': {'e_noun._n': 'unsalted butter'},
 'the buttered/_n': {'e_noun._n': 'the butter'},
 'melted buttered/_n': {'e_noun._n': 'melted butter'},
 'a buttoned/_n': {'e_noun._n': 'a button'},
 'a caged/_n': {'e_noun._n': 'a cage'},
 'his caged/_n': {'e_noun._n': 'his cage'},
 'my called/_n': {'e_noun._n': 'my call'},
 'this calls/_n': {'e_noun._n': 'those calls'},
 'his called/_n': {'e_noun._n': 'his call'},
 'another called/_n': {'e_noun._n': 'another call'},
 'that called/_n': {'e_noun._n': 'that call'},
 'your called/_n': {'e_noun._n': 'your call'},
 'secure cameras/_n': {'e_noun._n': 'security cameras'},
 'their camped/_n': {'e_noun._n': 'their camp'},
 'each camped/_n': {'e_noun._n': 'each camp'},
 'one camped/_n': {'e_noun._n': 'one camp'},
 'a camped/_n': {'e_noun._n': 'a camp'},
 'his camped/_n': {'e_noun._n': 'his camp'},
 'training camped/_n': {'e_noun._n': 'training camp'},
 'a refugee camped/_n': {'e_noun._n': 'a refugee camp'},
 'the elect campaign/_n': {'e_noun._n': 'the election campaign'},
 'elect campaigns/_n': {'e_noun._n': 'election campaigns'},
 'the president campaign/_n': {'e_noun._n': 'the presidential campaign'},
 'his president campaign/_n': {'e_noun._n': 'his presidential campaign'},
 'a canning/_n': {'e_noun._n': 'a can'},
 'terminate cancer/_n': {'e_noun._n': 'terminal cancer'},
 'boned cancer/_n': {'e_noun._n': 'bone cancer'},
 'a president candidate/_n': {'e_noun._n': 'a presidential candidate'},
 'president candidates/_n': {'e_noun._n': 'presidential candidates'},
 'president candidate/_n': {'e_noun._n': 'presidential candidate'},
 'the president candidates/_n': {'e_noun._n': 'the presidential candidates'},
 'a baseball capped/_n': {'e_noun._n': 'a baseball cap'},
 'his capped/_n': {'e_noun._n': 'his cap'},
 'a capped/_n': {'e_noun._n': 'a cap'},
 'the capped/_n': {'e_noun._n': 'the cap'},
 'its capable/_n': {'e_noun._n': 'its capacity'},
 'that capable/_n': {'e_noun._n': 'that capacity'},
 'their capable/_n': {'e_noun._n': 'their capacity'},
 'full capable/_n': {'e_noun._n': 'full capacity'},
 'a caped/_n': {'e_noun._n': 'a cape'},
 'society capital/_n': {'e_noun._n': 'social capital'},
 'third cars/_n': {'e_noun._n': 'three cars'},
 'this cards/_n': {'e_noun._n': 'those cards'},
 'dental careful/_n': {'e_noun._n': 'dental care'},
 'critical careful/_n': {'e_noun._n': 'critical care'},
 'emergency careful/_n': {'e_noun._n': 'emergency care'},
 'patient careful/_n': {'e_noun._n': 'patient care'},
 'hospital careful/_n': {'e_noun._n': 'hospital care'},
 'his careful/_n': {'e_noun._n': 'his care'},
 'long-term careful/_n': {'e_noun._n': 'long-term care'},
 'hospice careful/_n': {'e_noun._n': 'hospice care'},
 'great careful/_n': {'e_noun._n': 'great care'},
 'managed careful/_n': {'e_noun._n': 'managed care'},
 'her careful/_n': {'e_noun._n': 'her care'},
 'such careful/_n': {'e_noun._n': 'such care'},
 'preventive careful/_n': {'e_noun._n': 'preventive care'},
 'proper careful/_n': {'e_noun._n': 'proper care'},
 'home careful/_n': {'e_noun._n': 'home care'},
 'healthy care/_n': {'e_noun._n': 'health care'},
 'health careful/_n': {'e_noun._n': 'health care'},
 'patience care/_n': {'e_noun._n': 'patient care'},
 'quality careful/_n': {'e_noun._n': 'quality care'},
 'skinned care/_n': {'e_noun._n': 'skin care'},
 'skin careful/_n': {'e_noun._n': 'skin care'},
 'foster careful/_n': {'e_noun._n': 'foster care'},
 'their careful/_n': {'e_noun._n': 'their care'},
 'charity careful/_n': {'e_noun._n': 'charity care'},
 'dead penalty cases/_n': {'e_noun._n': 'death penalty cases'},
 'this cases/_n': {'e_noun._n': 'those cases'},
 'crime cases/_n': {'e_noun._n': 'criminal cases'},
 'civil casualties/_n': {'e_noun._n': 'civilian casualties'},
 'a catching/_n': {'e_noun._n': 'a catch'},
 'one categorial/_n': {'e_noun._n': 'one category'},
 'each categorial/_n': {'e_noun._n': 'each category'},
 'that categorial/_n': {'e_noun._n': 'that category'},
 'third categories/_n': {'e_noun._n': 'three categories'},
 'a categorial/_n': {'e_noun._n': 'a category'},
 'the categorial/_n': {'e_noun._n': 'the category'},
 'the cause of dead/_n': {'e_noun._n': 'the cause of death'},
 'the cause of the crashed/_n': {'e_noun._n': 'the cause of the crash'},
 'a caved/_n': {'e_noun._n': 'a cave'},
 'skinned cells/_n': {'e_noun._n': 'skin cells'},
 'the tradable center/_n': {'e_noun._n': 'the trade center'},
 'the center of attentive/_n': {'e_noun._n': 'the center of attention'},
 'the centers for diseased control and prevention/_n': {'e_noun._n': 'the centers for disease control and prevention'},
 'the centers for disease controllable and prevention/_n': {'e_noun._n': 'the centers for disease control and prevention'},
 'the centers for disease control and preventable/_n': {'e_noun._n': 'the centers for disease control and prevention'},
 'called centers/_n': {'e_noun._n': 'call centers'},
 'the central of the city/_n': {'e_noun._n': 'the center of the city'},
 'its centre/_n': {'e_noun._n': 'its center'},
 'the centre of the city/_n': {'e_noun._n': 'the center of the city'},
 'the new centre/_n': {'e_noun._n': 'the new center'},
 'the centre of town/_n': {'e_noun._n': 'the center of town'},
 'the centre of attention/_n': {'e_noun._n': 'the center of attention'},
 'any certain/_n': {'e_noun._n': 'any certainty'},
 'that challenging/_n': {'e_noun._n': 'that challenge'},
 'our challenging/_n': {'e_noun._n': 'our challenge'},
 'the biggest challenging/_n': {'e_noun._n': 'the biggest challenge'},
 'his challenging/_n': {'e_noun._n': 'his challenge'},
 'another challenging/_n': {'e_noun._n': 'another challenge'},
 'this challenges/_n': {'e_noun._n': 'those challenges'},
 'a chance to winnable/_n': {'e_noun._n': 'a chance to win'},
 'the name changeable/_n': {'e_noun._n': 'the name change'},
 'rapid changeable/_n': {'e_noun._n': 'rapid change'},
 'technology change/_n': {'e_noun._n': 'technological change'},
 'social changeable/_n': {'e_noun._n': 'social change'},
 'real changeable/_n': {'e_noun._n': 'real change'},
 'one changeable/_n': {'e_noun._n': 'one change'},
 'some changeable/_n': {'e_noun._n': 'some change'},
 'no changeable/_n': {'e_noun._n': 'no change'},
 'economic changeable/_n': {'e_noun._n': 'economic change'},
 'that changeable/_n': {'e_noun._n': 'that change'},
 'technological changeable/_n': {'e_noun._n': 'technological change'},
 'society change/_n': {'e_noun._n': 'social change'},
 'political changeable/_n': {'e_noun._n': 'political change'},
 'any changeable/_n': {'e_noun._n': 'any change'},
 'a changeable/_n': {'e_noun._n': 'a change'},
 'a changeable of/_n': {'e_noun._n': 'a change of'},
 'radical changeable/_n': {'e_noun._n': 'radical change'},
 'fundamental changeable/_n': {'e_noun._n': 'fundamental change'},
 'another changeable/_n': {'e_noun._n': 'another change'},
 'swept changes/_n': {'e_noun._n': 'sweeping changes'},
 'such a changeable/_n': {'e_noun._n': 'such a change'},
 'little changeable/_n': {'e_noun._n': 'little change'},
 'the main characteristic/_n': {'e_noun._n': 'the main character'},
 'its characteristic/_n': {'e_noun._n': 'its character'},
 'this characters/_n': {'e_noun._n': 'those characters'},
 'your characteristic/_n': {'e_noun._n': 'your character'},
 'my characteristic/_n': {'e_noun._n': 'my character'},
 'whose characteristic/_n': {'e_noun._n': 'whose character'},
 'the title characteristic/_n': {'e_noun._n': 'the title character'},
 'her characteristic/_n': {'e_noun._n': 'her character'},
 'each characteristic/_n': {'e_noun._n': 'each character'},
 'this charges/_n': {'e_noun._n': 'those charges'},
 'interesting charges/_n': {'e_noun._n': 'interest charges'},
 'his charming/_n': {'e_noun._n': 'his charm'},
 'its charming/_n': {'e_noun._n': 'its charm'},
 'third charts/_n': {'e_noun._n': 'three charts'},
 'a background checked/_n': {'e_noun._n': 'a background check'},
 'the checked/_n': {'e_noun._n': 'the check'},
 'secure checkpoints/_n': {'e_noun._n': 'security checkpoints'},
 'good cheerful/_n': {'e_noun._n': 'good cheer'},
 'my childish/_n': {'e_noun._n': 'my child'},
 'another childish/_n': {'e_noun._n': 'another child'},
 'an only childish/_n': {'e_noun._n': 'an only child'},
 'this children/_n': {'e_noun._n': 'those children'},
 'his childish/_n': {'e_noun._n': 'his child'},
 'third children/_n': {'e_noun._n': 'three children'},
 'a young childish/_n': {'e_noun._n': 'a young child'},
 'a small childish/_n': {'e_noun._n': 'a small child'},
 'each childish/_n': {'e_noun._n': 'each child'},
 'sixteenth children/_n': {'e_noun._n': 'six children'},
 'any childish/_n': {'e_noun._n': 'any child'},
 'woody chips/_n': {'e_noun._n': 'wood chips'},
 'memorial chips/_n': {'e_noun._n': 'memory chips'},
 'this choices/_n': {'e_noun._n': 'those choices'},
 'consuming choice/_n': {'e_noun._n': 'consumer choice'},
 'the right circular/_n': {'e_noun._n': 'the right circle'},
 'the left circular/_n': {'e_noun._n': 'the left circle'},
 'his circular/_n': {'e_noun._n': 'his circle'},
 'this circumstances,/_n': {'e_noun._n': 'those circumstances,'},
 'this circumstances/_n': {'e_noun._n': 'those circumstances'},
 'specialist circumstances/_n': {'e_noun._n': 'special circumstances'},
 'the averaged citizen/_n': {'e_noun._n': 'the average citizen'},
 'averaged citizens/_n': {'e_noun._n': 'average citizens'},
 'third cities/_n': {'e_noun._n': 'three cities'},
 'this claims/_n': {'e_noun._n': 'those claims'},
 'insured claims/_n': {'e_noun._n': 'insurance claims'},
 'my classified/_n': {'e_noun._n': 'my class'},
 'their classified/_n': {'e_noun._n': 'their class'},
 'the clearness/_n': {'e_noun._n': 'the clear'},
 'a clearness/_n': {'e_noun._n': 'a clear'},
 'globe climate/_n': {'e_noun._n': 'global climate'},
 'healthy clinics/_n': {'e_noun._n': 'health clinics'},
 'filmed clips/_n': {'e_noun._n': 'film clips'},
 'civil clothes/_n': {'e_noun._n': 'civilian clothes'},
 'healthy clubs/_n': {'e_noun._n': 'health clubs'},
 'stripped clubs/_n': {'e_noun._n': 'strip clubs'},
 'computational code/_n': {'e_noun._n': 'computer code'},
 'a code of conductive/_n': {'e_noun._n': 'a code of conduct'},
 'the taxable code/_n': {'e_noun._n': 'the tax code'},
 'golden coins/_n': {'e_noun._n': 'gold coins'},
 'cold waterless/_n': {'e_noun._n': 'cold water'},
 'a coldness/_n': {'e_noun._n': 'a cold'},
 'economic collapsible/_n': {'e_noun._n': 'economic collapse'},
 'the collapsible/_n': {'e_noun._n': 'the collapse'},
 'its collapsible/_n': {'e_noun._n': 'its collapse'},
 'the collapsible of the soviet union/_n': {'e_noun._n': 'the collapse of the soviet union'},
 'economy collapse/_n': {'e_noun._n': 'economic collapse'},
 'a collapsible/_n': {'e_noun._n': 'a collapse'},
 'taxable collection/_n': {'e_noun._n': 'tax collection'},
 'tax collective/_n': {'e_noun._n': 'tax collection'},
 'its collective/_n': {'e_noun._n': 'its collection'},
 'her collective/_n': {'e_noun._n': 'her collection'},
 'skinned color/_n': {'e_noun._n': 'skin color'},
 'that combined/_n': {'e_noun._n': 'that combination'},
 'some comfortable/_n': {'e_noun._n': 'some comfort'},
 'the commanding/_n': {'e_noun._n': 'the command'},
 'his commanding/_n': {'e_noun._n': 'his command'},
 'this comments/_n': {'e_noun._n': 'those comments'},
 'globe commerce/_n': {'e_noun._n': 'global commerce'},
 'international commercial/_n': {'e_noun._n': 'international commerce'},
 'online commercial/_n': {'e_noun._n': 'online commerce'},
 'global commercial/_n': {'e_noun._n': 'global commerce'},
 'interstate commercial/_n': {'e_noun._n': 'interstate commerce'},
 'internet commercial/_n': {'e_noun._n': 'internet commerce'},
 'that committed/_n': {'e_noun._n': 'that commitment'},
 'their committed/_n': {'e_noun._n': 'their commitment'},
 'its committed/_n': {'e_noun._n': 'its commitment'},
 'our committed/_n': {'e_noun._n': 'our commitment'},
 'his committed/_n': {'e_noun._n': 'his commitment'},
 'the selective committee/_n': {'e_noun._n': 'the selection committee'},
 'a commonness/_n': {'e_noun._n': 'a common'},
 'the commonness/_n': {'e_noun._n': 'the common'},
 'electronic communicative/_n': {'e_noun._n': 'electronic communication'},
 'the communicative/_n': {'e_noun._n': 'the communication'},
 'entertaining companies/_n': {'e_noun._n': 'entertainment companies'},
 'technological companies/_n': {'e_noun._n': 'technology companies'},
 'third companies/_n': {'e_noun._n': 'three companies'},
 'the third companies/_n': {'e_noun._n': 'the three companies'},
 'constructive companies/_n': {'e_noun._n': 'construction companies'},
 'the insured company/_n': {'e_noun._n': 'the insurance company'},
 'computational companies/_n': {'e_noun._n': 'computer companies'},
 'insured companies/_n': {'e_noun._n': 'insurance companies'},
 'an insured company/_n': {'e_noun._n': 'an insurance company'},
 'no comparative/_n': {'e_noun._n': 'no comparison'},
 'executive compensatory/_n': {'e_noun._n': 'executive compensation'},
 'total compensatory/_n': {'e_noun._n': 'total compensation'},
 'his compensatory/_n': {'e_noun._n': 'his compensation'},
 'their compensatory/_n': {'e_noun._n': 'their compensation'},
 'intense competing/_n': {'e_noun._n': 'intense competition'},
 'more competing/_n': {'e_noun._n': 'more competition'},
 'increasing competing/_n': {'e_noun._n': 'increasing competition'},
 'fierce competing/_n': {'e_noun._n': 'fierce competition'},
 'tough competing/_n': {'e_noun._n': 'tough competition'},
 'its competing/_n': {'e_noun._n': 'its competition'},
 'greater competing/_n': {'e_noun._n': 'greater competition'},
 'foreign competing/_n': {'e_noun._n': 'foreign competition'},
 'stiff competing/_n': {'e_noun._n': 'stiff competition'},
 'increased competing/_n': {'e_noun._n': 'increased competition'},
 'international competing/_n': {'e_noun._n': 'international competition'},
 'his competing/_n': {'e_noun._n': 'his competition'},
 'new competing/_n': {'e_noun._n': 'new competition'},
 'our competing/_n': {'e_noun._n': 'our competition'},
 'olympic competing/_n': {'e_noun._n': 'olympic competition'},
 'no competing/_n': {'e_noun._n': 'no competition'},
 'growing competing/_n': {'e_noun._n': 'growing competition'},
 'price competing/_n': {'e_noun._n': 'price competition'},
 'your competing/_n': {'e_noun._n': 'your competition'},
 'their competing/_n': {'e_noun._n': 'their competition'},
 'less competing/_n': {'e_noun._n': 'less competition'},
 'global competing/_n': {'e_noun._n': 'global competition'},
 'that competing/_n': {'e_noun._n': 'that competition'},
 'a complaining/_n': {'e_noun._n': 'a complaint'},
 'that complaining/_n': {'e_noun._n': 'that complaint'},
 'her complaining/_n': {'e_noun._n': 'her complaint'},
 'their complaining/_n': {'e_noun._n': 'their complaint'},
 'consuming complaints/_n': {'e_noun._n': 'consumer complaints'},
 'your complaining/_n': {'e_noun._n': 'your complaint'},
 'his complaining/_n': {'e_noun._n': 'his complaint'},
 'the composed/_n': {'e_noun._n': 'the composition'},
 'different computational/_n': {'e_noun._n': 'different computer'},
 'any computational/_n': {'e_noun._n': 'any computer'},
 'another computational/_n': {'e_noun._n': 'another computer'},
 'a new computational/_n': {'e_noun._n': 'a new computer'},
 'american computational/_n': {'e_noun._n': 'american computer'},
 'their computational/_n': {'e_noun._n': 'their computer'},
 'on-line computational/_n': {'e_noun._n': 'on-line computer'},
 'latest computational/_n': {'e_noun._n': 'latest computer'},
 'modern computational/_n': {'e_noun._n': 'modern computer'},
 'his computational/_n': {'e_noun._n': 'his computer'},
 'a laptop computational/_n': {'e_noun._n': 'a laptop computer'},
 'sophisticated computational/_n': {'e_noun._n': 'sophisticated computer'},
 'that computational/_n': {'e_noun._n': 'that computer'},
 'global computational/_n': {'e_noun._n': 'global computer'},
 'one computational/_n': {'e_noun._n': 'one computer'},
 'your computational/_n': {'e_noun._n': 'your computer'},
 'first computational/_n': {'e_noun._n': 'first computer'},
 'complex computational/_n': {'e_noun._n': 'complex computer'},
 'her computational/_n': {'e_noun._n': 'her computer'},
 'large computational/_n': {'e_noun._n': 'large computer'},
 'advanced computational/_n': {'e_noun._n': 'advanced computer'},
 'small computational/_n': {'e_noun._n': 'small computer'},
 'big computational/_n': {'e_noun._n': 'big computer'},
 'his concentrated/_n': {'e_noun._n': 'his concentration'},
 'a conceptual/_n': {'e_noun._n': 'a concept'},
 'that conceptual/_n': {'e_noun._n': 'that concept'},
 'my concerned/_n': {'e_noun._n': 'my concern'},
 'her concerned/_n': {'e_noun._n': 'her concern'},
 'our concerned/_n': {'e_noun._n': 'our concern'},
 'that concerned/_n': {'e_noun._n': 'that concern'},
 'environment concerns/_n': {'e_noun._n': 'environmental concerns'},
 'secure concerns/_n': {'e_noun._n': 'security concerns'},
 'his concerned/_n': {'e_noun._n': 'his concern'},
 'some concerned/_n': {'e_noun._n': 'some concern'},
 'one concerned/_n': {'e_noun._n': 'one concern'},
 'healthy concerns/_n': {'e_noun._n': 'health concerns'},
 'this concerns/_n': {'e_noun._n': 'those concerns'},
 'safe concerns/_n': {'e_noun._n': 'safety concerns'},
 'great concerned/_n': {'e_noun._n': 'great concern'},
 'public concerned/_n': {'e_noun._n': 'public concern'},
 'another concerned/_n': {'e_noun._n': 'another concern'},
 'particular concerned/_n': {'e_noun._n': 'particular concern'},
 'their concerned/_n': {'e_noun._n': 'their concern'},
 'rocky concerts/_n': {'e_noun._n': 'rock concerts'},
 'its conclusive/_n': {'e_noun._n': 'its conclusion'},
 'the same conclusive/_n': {'e_noun._n': 'the same conclusion'},
 'that conclusive/_n': {'e_noun._n': 'that conclusion'},
 'a conclusive/_n': {'e_noun._n': 'a conclusion'},
 'his conclusive/_n': {'e_noun._n': 'his conclusion'},
 'serious conditional/_n': {'e_noun._n': 'serious condition'},
 'employed conditions/_n': {'e_noun._n': 'employment conditions'},
 'live conditions/_n': {'e_noun._n': 'living conditions'},
 'that conditional/_n': {'e_noun._n': 'that condition'},
 'economy conditions/_n': {'e_noun._n': 'economic conditions'},
 'excellent conditional/_n': {'e_noun._n': 'excellent condition'},
 'stable conditional/_n': {'e_noun._n': 'stable condition'},
 'good conditional/_n': {'e_noun._n': 'good condition'},
 'this conditions/_n': {'e_noun._n': 'those conditions'},
 'the human conditional/_n': {'e_noun._n': 'the human condition'},
 'conditional of anonymity/_n': {'e_noun._n': 'condition of anonymity'},
 'her conditional/_n': {'e_noun._n': 'her condition'},
 'a conditional/_n': {'e_noun._n': 'a condition'},
 'critical conditional/_n': {'e_noun._n': 'critical condition'},
 'his conditional/_n': {'e_noun._n': 'his condition'},
 'one conditional/_n': {'e_noun._n': 'one condition'},
 'their conditional/_n': {'e_noun._n': 'their condition'},
 'their conductive/_n': {'e_noun._n': 'their conduct'},
 'the conductive/_n': {'e_noun._n': 'the conduct'},
 'his conductive/_n': {'e_noun._n': 'his conduct'},
 'its conductive/_n': {'e_noun._n': 'its conduct'},
 'criminal conductive/_n': {'e_noun._n': 'criminal conduct'},
 'such conductive/_n': {'e_noun._n': 'such conduct'},
 'his confessed/_n': {'e_noun._n': 'his confession'},
 'the confessed/_n': {'e_noun._n': 'the confession'},
 'a confessed/_n': {'e_noun._n': 'a confession'},
 'my confident/_n': {'e_noun._n': 'my confidence'},
 'consuming confidence/_n': {'e_noun._n': 'consumer confidence'},
 'consumer confident/_n': {'e_noun._n': 'consumer confidence'},
 'more confident/_n': {'e_noun._n': 'more confidence'},
 'no confident/_n': {'e_noun._n': 'no confidence'},
 "investors' confident/_n": {'e_noun._n': "investors' confidence"},
 'investor confident/_n': {'e_noun._n': 'investor confidence'},
 'business confident/_n': {'e_noun._n': 'business confidence'},
 'their confident/_n': {'e_noun._n': 'their confidence'},
 'your confident/_n': {'e_noun._n': 'your confidence'},
 'our confident/_n': {'e_noun._n': 'our confidence'},
 'public confident/_n': {'e_noun._n': 'public confidence'},
 'some confident/_n': {'e_noun._n': 'some confidence'},
 'that confident/_n': {'e_noun._n': 'that confidence'},
 'her confident/_n': {'e_noun._n': 'her confidence'},
 'his confident/_n': {'e_noun._n': 'his confidence'},
 'senate confirmed/_n': {'e_noun._n': 'senate confirmation'},
 'ethnic conflictive/_n': {'e_noun._n': 'ethnic conflict'},
 'the israeli-palestinian conflictive/_n': {'e_noun._n': 'the israeli-palestinian conflict'},
 'a conflictive/_n': {'e_noun._n': 'a conflict'},
 'no conflictive/_n': {'e_noun._n': 'no conflict'},
 'that conflictive/_n': {'e_noun._n': 'that conflict'},
 'some confusing/_n': {'e_noun._n': 'some confusion'},
 'a connected/_n': {'e_noun._n': 'a connection'},
 'an internet connected/_n': {'e_noun._n': 'an internet connection'},
 'no connected/_n': {'e_noun._n': 'no connection'},
 'that connected/_n': {'e_noun._n': 'that connection'},
 'any connected/_n': {'e_noun._n': 'any connection'},
 'their conscientious/_n': {'e_noun._n': 'their conscience'},
 'good conscientious/_n': {'e_noun._n': 'good conscience'},
 'my conscientious/_n': {'e_noun._n': 'my conscience'},
 'his conscientious/_n': {'e_noun._n': 'his conscience'},
 'no consenting/_n': {'e_noun._n': 'no consensus'},
 'the consenting/_n': {'e_noun._n': 'the consensus'},
 'his consenting/_n': {'e_noun._n': 'his consent'},
 'parental consenting/_n': {'e_noun._n': 'parental consent'},
 'serious considerable/_n': {'e_noun._n': 'serious consideration'},
 'our constitutive/_n': {'e_noun._n': 'our constitution'},
 'a new constitutive/_n': {'e_noun._n': 'a new constitution'},
 'a constitutive/_n': {'e_noun._n': 'a constitution'},
 'its constitutive/_n': {'e_noun._n': 'its constitution'},
 'the state constitutive/_n': {'e_noun._n': 'the state constitution'},
 'timeless constraints/_n': {'e_noun._n': 'time constraints'},
 'highway constructive/_n': {'e_noun._n': 'highway construction'},
 'school constructive/_n': {'e_noun._n': 'school construction'},
 'military constructive/_n': {'e_noun._n': 'military construction'},
 'residential constructive/_n': {'e_noun._n': 'residential construction'},
 'heavy constructive/_n': {'e_noun._n': 'heavy construction'},
 'new constructive/_n': {'e_noun._n': 'new construction'},
 'major constructive/_n': {'e_noun._n': 'major construction'},
 'road constructive/_n': {'e_noun._n': 'road construction'},
 'its constructive/_n': {'e_noun._n': 'its construction'},
 'housing constructive/_n': {'e_noun._n': 'housing construction'},
 'prison constructive/_n': {'e_noun._n': 'prison construction'},
 'home constructive/_n': {'e_noun._n': 'home construction'},
 'the consuming/_n': {'e_noun._n': 'the consumer'},
 'increased consuming/_n': {'e_noun._n': 'increased consumer'},
 'high consuming/_n': {'e_noun._n': 'high consumer'},
 'new consuming/_n': {'e_noun._n': 'new consumer'},
 'rising consuming/_n': {'e_noun._n': 'rising consumer'},
 'the averaged consumer/_n': {'e_noun._n': 'the average consumer'},
 'the average consuming/_n': {'e_noun._n': 'the average consumer'},
 'a consuming/_n': {'e_noun._n': 'a consumer'},
 'strong consuming/_n': {'e_noun._n': 'strong consumer'},
 'human consuming/_n': {'e_noun._n': 'human consumption'},
 'personal consuming/_n': {'e_noun._n': 'personal consumption'},
 'alcohol consuming/_n': {'e_noun._n': 'alcohol consumption'},
 'public consuming/_n': {'e_noun._n': 'public consumption'},
 'fuel consuming/_n': {'e_noun._n': 'fuel consumption'},
 'energetic consumption/_n': {'e_noun._n': 'energy consumption'},
 'energy consuming/_n': {'e_noun._n': 'energy consumption'},
 'private consuming/_n': {'e_noun._n': 'private consumption'},
 'any contactable/_n': {'e_noun._n': 'any contact'},
 'human contactable/_n': {'e_noun._n': 'human contact'},
 'sex contact/_n': {'e_noun._n': 'sexual contact'},
 'sexual contactable/_n': {'e_noun._n': 'sexual contact'},
 'no contactable/_n': {'e_noun._n': 'no contact'},
 'physical contactable/_n': {'e_noun._n': 'physical contact'},
 'close contactable/_n': {'e_noun._n': 'close contact'},
 'this contests/_n': {'e_noun._n': 'those contests'},
 'that contextual/_n': {'e_noun._n': 'that context'},
 'a contextual/_n': {'e_noun._n': 'a context'},
 'third continents/_n': {'e_noun._n': 'three continents'},
 'a contracted/_n': {'e_noun._n': 'a contract'},
 'a two-year contracted/_n': {'e_noun._n': 'a two-year contract'},
 'its contracted/_n': {'e_noun._n': 'its contract'},
 'a three-year contracted/_n': {'e_noun._n': 'a three-year contract'},
 'their contracted/_n': {'e_noun._n': 'their contract'},
 'his contracted/_n': {'e_noun._n': 'his contract'},
 'governing contracts/_n': {'e_noun._n': 'government contracts'},
 'a new contracted/_n': {'e_noun._n': 'a new contract'},
 'futures contracted/_n': {'e_noun._n': 'futures contract'},
 'your contracted/_n': {'e_noun._n': 'your contract'},
 'the new contracted/_n': {'e_noun._n': 'the new contract'},
 'my contracted/_n': {'e_noun._n': 'my contract'},
 'a long-term contracted/_n': {'e_noun._n': 'a long-term contract'},
 'her contracted/_n': {'e_noun._n': 'her contract'},
 'that contracted/_n': {'e_noun._n': 'that contract'},
 'the contrastive/_n': {'e_noun._n': 'the contrast'},
 'stark contrastive/_n': {'e_noun._n': 'stark contrast'},
 'defined contributed/_n': {'e_noun._n': 'defined contribution'},
 'a contributed/_n': {'e_noun._n': 'a contribution'},
 'his contributed/_n': {'e_noun._n': 'his contribution'},
 'the contributed/_n': {'e_noun._n': 'the contribution'},
 'full controllable/_n': {'e_noun._n': 'full control'},
 'some controllable/_n': {'e_noun._n': 'some control'},
 'political controllable/_n': {'e_noun._n': 'political control'},
 'state controllable/_n': {'e_noun._n': 'state control'},
 'crowded control/_n': {'e_noun._n': 'crowd control'},
 'crowd controllable/_n': {'e_noun._n': 'crowd control'},
 'more controllable/_n': {'e_noun._n': 'more control'},
 'chinese controllable/_n': {'e_noun._n': 'chinese control'},
 'traction controllable/_n': {'e_noun._n': 'traction control'},
 'arms controllable/_n': {'e_noun._n': 'arms control'},
 'my controllable/_n': {'e_noun._n': 'my control'},
 'its controllable/_n': {'e_noun._n': 'its control'},
 'local controllable/_n': {'e_noun._n': 'local control'},
 'flooded control/_n': {'e_noun._n': 'flood control'},
 'flood controllable/_n': {'e_noun._n': 'flood control'},
 'your controllable/_n': {'e_noun._n': 'your control'},
 'controllable of/_n': {'e_noun._n': 'control of'},
 'their controllable/_n': {'e_noun._n': 'their control'},
 'weighable control/_n': {'e_noun._n': 'weight control'},
 'weight controllable/_n': {'e_noun._n': 'weight control'},
 'financial controllable/_n': {'e_noun._n': 'financial control'},
 'his controllable/_n': {'e_noun._n': 'his control'},
 'total controllable/_n': {'e_noun._n': 'total control'},
 'governing control/_n': {'e_noun._n': 'government control'},
 'government controllable/_n': {'e_noun._n': 'government control'},
 'controllable of the company/_n': {'e_noun._n': 'control of the company'},
 'exchanging controls/_n': {'e_noun._n': 'exchange controls'},
 'no controllable/_n': {'e_noun._n': 'no control'},
 'our controllable/_n': {'e_noun._n': 'our control'},
 'some controversial/_n': {'e_noun._n': 'some controversy'},
 'the convenient/_n': {'e_noun._n': 'the convenience'},
 'the gop conventional/_n': {'e_noun._n': 'the gop convention'},
 'national conventional/_n': {'e_noun._n': 'national convention'},
 'the democratic conventional/_n': {'e_noun._n': 'the democratic convention'},
 'their conventional/_n': {'e_noun._n': 'their convention'},
 'that converse/_n': {'e_noun._n': 'that conversation'},
 'this conversations/_n': {'e_noun._n': 'those conversations'},
 'a converse/_n': {'e_noun._n': 'a conversation'},
 'our converse/_n': {'e_noun._n': 'our conversation'},
 'their converse/_n': {'e_noun._n': 'their conversation'},
 'his converse/_n': {'e_noun._n': 'his conversation'},
 'such cooperative/_n': {'e_noun._n': 'such cooperation'},
 'military cooperative/_n': {'e_noun._n': 'military cooperation'},
 'cooperative in europe/_n': {'e_noun._n': 'cooperation in europe'},
 'cooperation inner europe/_n': {'e_noun._n': 'cooperation in europe'},
 'a copied/_n': {'e_noun._n': 'a copy'},
 'a copied of which/_n': {'e_noun._n': 'a copy of which'},
 'a cored/_n': {'e_noun._n': 'a core'},
 'so-called cored/_n': {'e_noun._n': 'so-called core'},
 'their cored/_n': {'e_noun._n': 'their core'},
 'its cored/_n': {'e_noun._n': 'its core'},
 'the corked/_n': {'e_noun._n': 'the cork'},
 'a street cornered/_n': {'e_noun._n': 'a street corner'},
 'every cornered/_n': {'e_noun._n': 'every corner'},
 'one cornered/_n': {'e_noun._n': 'one corner'},
 'that cornered/_n': {'e_noun._n': 'that corner'},
 'governing corruption/_n': {'e_noun._n': 'government corruption'},
 'officialdom corruption/_n': {'e_noun._n': 'official corruption'},
 'this costs/_n': {'e_noun._n': 'those costs'},
 'high costly/_n': {'e_noun._n': 'high cost'},
 'energetic costs/_n': {'e_noun._n': 'energy costs'},
 'maintained costs/_n': {'e_noun._n': 'maintenance costs'},
 'significant costly/_n': {'e_noun._n': 'significant cost'},
 'lower costly/_n': {'e_noun._n': 'lower cost'},
 'insured costs/_n': {'e_noun._n': 'insurance costs'},
 'productive costs/_n': {'e_noun._n': 'production costs'},
 'healthy costs/_n': {'e_noun._n': 'health costs'},
 'annual costly/_n': {'e_noun._n': 'annual cost'},
 'the costly of/_n': {'e_noun._n': 'the cost of'},
 'its costly/_n': {'e_noun._n': 'its cost'},
 'travelled costs/_n': {'e_noun._n': 'travel costs'},
 'developed costs/_n': {'e_noun._n': 'development costs'},
 'what costly/_n': {'e_noun._n': 'what cost'},
 'employed costs/_n': {'e_noun._n': 'employment costs'},
 'that costly/_n': {'e_noun._n': 'that cost'},
 'healthy care costs/_n': {'e_noun._n': 'health care costs'},
 'health careful costs/_n': {'e_noun._n': 'health care costs'},
 'their costly/_n': {'e_noun._n': 'their cost'},
 'constructive costs/_n': {'e_noun._n': 'construction costs'},
 'last countable/_n': {'e_noun._n': 'last count'},
 'each countable/_n': {'e_noun._n': 'each count'},
 'his countable/_n': {'e_noun._n': 'his count'},
 'one countable/_n': {'e_noun._n': 'one count'},
 'that countable/_n': {'e_noun._n': 'that count'},
 'this countries/_n': {'e_noun._n': 'those countries'},
 'difference countries/_n': {'e_noun._n': 'different countries'},
 'the third countries/_n': {'e_noun._n': 'the three countries'},
 'sixteenth countries/_n': {'e_noun._n': 'six countries'},
 'this counties/_n': {'e_noun._n': 'those counties'},
 'his courageous/_n': {'e_noun._n': 'his courage'},
 'the covering of the book/_n': {'e_noun._n': 'the cover of the book'},
 'its covering/_n': {'e_noun._n': 'its cover'},
 'medical covering/_n': {'e_noun._n': 'medical coverage'},
 'healthy care coverage/_n': {'e_noun._n': 'health care coverage'},
 'health careful coverage/_n': {'e_noun._n': 'health care coverage'},
 'health care covering/_n': {'e_noun._n': 'health care coverage'},
 'tv covering/_n': {'e_noun._n': 'tv coverage'},
 'media covering/_n': {'e_noun._n': 'media coverage'},
 'news covering/_n': {'e_noun._n': 'news coverage'},
 'insured coverage/_n': {'e_noun._n': 'insurance coverage'},
 'healthy coverage/_n': {'e_noun._n': 'health coverage'},
 'health covering/_n': {'e_noun._n': 'health coverage'},
 'such covering/_n': {'e_noun._n': 'such coverage'},
 'elect coverage/_n': {'e_noun._n': 'election coverage'},
 'election covering/_n': {'e_noun._n': 'election coverage'},
 'television covering/_n': {'e_noun._n': 'television coverage'},
 'single covering/_n': {'e_noun._n': 'single coverage'},
 'press covering/_n': {'e_noun._n': 'press coverage'},
 'universal covering/_n': {'e_noun._n': 'universal coverage'},
 'a cowardice/_n': {'e_noun._n': 'a coward'},
 'that crashed/_n': {'e_noun._n': 'that crash'},
 'a car crashed/_n': {'e_noun._n': 'a car crash'},
 'a plane crashed/_n': {'e_noun._n': 'a plane crash'},
 'a crashed/_n': {'e_noun._n': 'a crash'},
 'job creative/_n': {'e_noun._n': 'job creation'},
 'the taxable credit/_n': {'e_noun._n': 'the tax credit'},
 'taxable credits/_n': {'e_noun._n': 'tax credits'},
 'workless crews/_n': {'e_noun._n': 'work crews'},
 'violence crimes/_n': {'e_noun._n': 'violent crimes'},
 'violent criminal/_n': {'e_noun._n': 'violent crime'},
 'rising criminal/_n': {'e_noun._n': 'rising crime'},
 'this crimes/_n': {'e_noun._n': 'those crimes'},
 'serious criminal/_n': {'e_noun._n': 'serious crime'},
 'violence crime/_n': {'e_noun._n': 'violent crime'},
 'low criminal/_n': {'e_noun._n': 'low crime'},
 'international criminal/_n': {'e_noun._n': 'international crime'},
 'overall criminal/_n': {'e_noun._n': 'overall crime'},
 'high criminal/_n': {'e_noun._n': 'high crime'},
 'economy crisis/_n': {'e_noun._n': 'economic crisis'},
 'an economy crisis/_n': {'e_noun._n': 'an economic crisis'},
 'the economy crisis/_n': {'e_noun._n': 'the economic crisis'},
 'finance crisis/_n': {'e_noun._n': 'financial crisis'},
 'social critical/_n': {'e_noun._n': 'social critic'},
 'critic thinking/_n': {'e_noun._n': 'critical thinking'},
 'this critics/_n': {'e_noun._n': 'those critics'},
 'one critical/_n': {'e_noun._n': 'one critic'},
 'their cropped/_n': {'e_noun._n': 'their crop'},
 'the cropped/_n': {'e_noun._n': 'the crop'},
 'a cropped/_n': {'e_noun._n': 'a crop'},
 'bordered crossings/_n': {'e_noun._n': 'border crossings'},
 'that crowded/_n': {'e_noun._n': 'that crowd'},
 'a crowned/_n': {'e_noun._n': 'a crown'},
 'the crowned/_n': {'e_noun._n': 'the crown'},
 'animal cruel/_n': {'e_noun._n': 'animal cruelty'},
 'a crushed/_n': {'e_noun._n': 'a crush'},
 'that cultural/_n': {'e_noun._n': 'that culture'},
 'popular cultural/_n': {'e_noun._n': 'popular culture'},
 'french cultural/_n': {'e_noun._n': 'french culture'},
 'contemporary cultural/_n': {'e_noun._n': 'contemporary culture'},
 'their cultural/_n': {'e_noun._n': 'their culture'},
 'mass cultural/_n': {'e_noun._n': 'mass culture'},
 'our cultural/_n': {'e_noun._n': 'our culture'},
 'difference cultures/_n': {'e_noun._n': 'different cultures'},
 'high cultural/_n': {'e_noun._n': 'high culture'},
 'no curable/_n': {'e_noun._n': 'no cure'},
 'the curable/_n': {'e_noun._n': 'the cure'},
 'his curious/_n': {'e_noun._n': 'his curiosity'},
 'common current/_n': {'e_noun._n': 'common currency'},
 'the common current/_n': {'e_noun._n': 'the common currency'},
 'foreign current/_n': {'e_noun._n': 'foreign currency'},
 'the single current/_n': {'e_noun._n': 'the single currency'},
 'single current/_n': {'e_noun._n': 'single currency'},
 'the single european current/_n': {'e_noun._n': 'the single european currency'},
 'international current/_n': {'e_noun._n': 'international currency'},
 'the local current/_n': {'e_noun._n': 'the local currency'},
 'local current/_n': {'e_noun._n': 'local currency'},
 'european current/_n': {'e_noun._n': 'european currency'},
 'a single current/_n': {'e_noun._n': 'a single currency'},
 'global current/_n': {'e_noun._n': 'global currency'},
 'the cursed/_n': {'e_noun._n': 'the curse'},
 'taxable cuts/_n': {'e_noun._n': 'tax cuts'},
 'spent cuts/_n': {'e_noun._n': 'spending cuts'},
 'costly cuts/_n': {'e_noun._n': 'cost cuts'},
 'the taxable cuts/_n': {'e_noun._n': 'the tax cuts'},
 'costly cutting/_n': {'e_noun._n': 'cost cutting'},
 'cost cut/_n': {'e_noun._n': 'cost cutting'},
 'some daily/_n': {'e_noun._n': 'some day'},
 'open day/_n': {'e_noun._n': 'open daily'},
 'all daily/_n': {'e_noun._n': 'all day'},
 'waterless damage/_n': {'e_noun._n': 'water damage'},
 'water damaging/_n': {'e_noun._n': 'water damage'},
 'nerve damaging/_n': {'e_noun._n': 'nerve damage'},
 'liver damaging/_n': {'e_noun._n': 'liver damage'},
 'any damaging/_n': {'e_noun._n': 'any damage'},
 'property damaging/_n': {'e_noun._n': 'property damage'},
 'permanent damaging/_n': {'e_noun._n': 'permanent damage'},
 'serious damaging/_n': {'e_noun._n': 'serious damage'},
 'environmental damaging/_n': {'e_noun._n': 'environmental damage'},
 'extensive damaging/_n': {'e_noun._n': 'extensive damage'},
 'severe damaging/_n': {'e_noun._n': 'severe damage'},
 'some damaging/_n': {'e_noun._n': 'some damage'},
 'much damaging/_n': {'e_noun._n': 'much damage'},
 'environment damage/_n': {'e_noun._n': 'environmental damage'},
 'little damaging/_n': {'e_noun._n': 'little damage'},
 'no damaging/_n': {'e_noun._n': 'no damage'},
 'major damaging/_n': {'e_noun._n': 'major damage'},
 'any dangerous/_n': {'e_noun._n': 'any danger'},
 'no dangerous/_n': {'e_noun._n': 'no danger'},
 'that dangerous/_n': {'e_noun._n': 'that danger'},
 'that dated/_n': {'e_noun._n': 'that date'},
 'his dated/_n': {'e_noun._n': 'his date'},
 'no dated/_n': {'e_noun._n': 'no date'},
 'a later dated/_n': {'e_noun._n': 'a later date'},
 'the dated/_n': {'e_noun._n': 'the date'},
 'economy data/_n': {'e_noun._n': 'economic data'},
 'computational data/_n': {'e_noun._n': 'computer data'},
 'science data/_n': {'e_noun._n': 'scientific data'},
 'governing data/_n': {'e_noun._n': 'government data'},
 'third daughters/_n': {'e_noun._n': 'three daughters'},
 'this days,/_n': {'e_noun._n': 'those days,'},
 'this days/_n': {'e_noun._n': 'those days'},
 'day outsider/_n': {'e_noun._n': 'day out'},
 'a peaceful deal/_n': {'e_noun._n': 'a peace deal'},
 'specialist deals/_n': {'e_noun._n': 'special deals'},
 'premature dead/_n': {'e_noun._n': 'premature death'},
 "diana's dead/_n": {'e_noun._n': "diana's death"},
 "his wife's dead/_n": {'e_noun._n': "his wife's death"},
 'whose dead/_n': {'e_noun._n': 'whose death'},
 "his father's dead/_n": {'e_noun._n': "his father's death"},
 'civil deaths/_n': {'e_noun._n': 'civilian deaths'},
 'nazi dead/_n': {'e_noun._n': 'nazi death'},
 'wrongful dead/_n': {'e_noun._n': 'wrongful death'},
 "her mother's dead/_n": {'e_noun._n': "her mother's death"},
 "her husband's dead/_n": {'e_noun._n': "her husband's death"},
 'early dead/_n': {'e_noun._n': 'early death'},
 'even dead/_n': {'e_noun._n': 'even death'},
 'possible dead/_n': {'e_noun._n': 'possible death'},
 'much debatable/_n': {'e_noun._n': 'much debate'},
 'some debatable/_n': {'e_noun._n': 'some debate'},
 'a debatable/_n': {'e_noun._n': 'a debate'},
 'the first debatable/_n': {'e_noun._n': 'the first debate'},
 'heat debate/_n': {'e_noun._n': 'heated debate'},
 'that debatable/_n': {'e_noun._n': 'that debate'},
 'no debatable/_n': {'e_noun._n': 'no debate'},
 'public debatable/_n': {'e_noun._n': 'public debate'},
 'heated debatable/_n': {'e_noun._n': 'heated debate'},
 'considerable debatable/_n': {'e_noun._n': 'considerable debate'},
 'political debatable/_n': {'e_noun._n': 'political debate'},
 'intense debatable/_n': {'e_noun._n': 'intense debate'},
 'governing debt/_n': {'e_noun._n': 'government debt'},
 'consuming debt/_n': {'e_noun._n': 'consumer debt'},
 'toothed decay/_n': {'e_noun._n': 'tooth decay'},
 'tooth decayed/_n': {'e_noun._n': 'tooth decay'},
 'this decisions/_n': {'e_noun._n': 'those decisions'},
 'a declared/_n': {'e_noun._n': 'a declaration'},
 'economic declining/_n': {'e_noun._n': 'economic decline'},
 'economy decline/_n': {'e_noun._n': 'economic decline'},
 'their declining/_n': {'e_noun._n': 'their decline'},
 'its declining/_n': {'e_noun._n': 'its decline'},
 'that declining/_n': {'e_noun._n': 'that decline'},
 'a taxable deduction/_n': {'e_noun._n': 'a tax deduction'},
 'a tax deducible/_n': {'e_noun._n': 'a tax deduction'},
 'a deducible/_n': {'e_noun._n': 'a deduction'},
 'taxable deductions/_n': {'e_noun._n': 'tax deductions'},
 'the deducible/_n': {'e_noun._n': 'the deduction'},
 'goodness deeds/_n': {'e_noun._n': 'good deeds'},
 'their defeated/_n': {'e_noun._n': 'their defeat'},
 'its defeated/_n': {'e_noun._n': 'its defeat'},
 'his defeated/_n': {'e_noun._n': 'his defeat'},
 'that defeated/_n': {'e_noun._n': 'that defeat'},
 'nation defense/_n': {'e_noun._n': 'national defense'},
 'tradable deficit/_n': {'e_noun._n': 'trade deficit'},
 'tradable deficits/_n': {'e_noun._n': 'trade deficits'},
 'the tradable deficit/_n': {'e_noun._n': 'the trade deficit'},
 'that definable/_n': {'e_noun._n': 'that definition'},
 'the definable/_n': {'e_noun._n': 'the definition'},
 'environment degradation/_n': {'e_noun._n': 'environmental degradation'},
 'a lawful degree/_n': {'e_noun._n': 'a law degree'},
 'may delivered/_n': {'e_noun._n': 'may delivery'},
 'july delivered/_n': {'e_noun._n': 'july delivery'},
 'his delivered/_n': {'e_noun._n': 'his delivery'},
 'immediate delivered/_n': {'e_noun._n': 'immediate delivery'},
 'the delivered/_n': {'e_noun._n': 'the delivery'},
 'february delivered/_n': {'e_noun._n': 'february delivery'},
 'overnight delivered/_n': {'e_noun._n': 'overnight delivery'},
 'home delivered/_n': {'e_noun._n': 'home delivery'},
 'marching delivery/_n': {'e_noun._n': 'march delivery'},
 'march delivered/_n': {'e_noun._n': 'march delivery'},
 'december delivered/_n': {'e_noun._n': 'december delivery'},
 'peak demanding/_n': {'e_noun._n': 'peak demand'},
 'high demanding/_n': {'e_noun._n': 'high demand'},
 'growing demanding/_n': {'e_noun._n': 'growing demand'},
 'sluggish demanding/_n': {'e_noun._n': 'sluggish demand'},
 'gasoline demanding/_n': {'e_noun._n': 'gasoline demand'},
 'pent-up demanding/_n': {'e_noun._n': 'pent-up demand'},
 'consuming demand/_n': {'e_noun._n': 'consumer demand'},
 'consumer demanding/_n': {'e_noun._n': 'consumer demand'},
 'market demanding/_n': {'e_noun._n': 'market demand'},
 'global demanding/_n': {'e_noun._n': 'global demand'},
 'this demands/_n': {'e_noun._n': 'those demands'},
 'domestic demanding/_n': {'e_noun._n': 'domestic demand'},
 'strong demanding/_n': {'e_noun._n': 'strong demand'},
 'current demanding/_n': {'e_noun._n': 'current demand'},
 'exporting demand/_n': {'e_noun._n': 'export demand'},
 'export demanding/_n': {'e_noun._n': 'export demand'},
 'great demanding/_n': {'e_noun._n': 'great demand'},
 'increased demanding/_n': {'e_noun._n': 'increased demand'},
 'customer demanding/_n': {'e_noun._n': 'customer demand'},
 'liberty democracy/_n': {'e_noun._n': 'liberal democracy'},
 'a demonstrable/_n': {'e_noun._n': 'a demonstration'},
 'the demonstrable/_n': {'e_noun._n': 'the demonstration'},
 'the deniable/_n': {'e_noun._n': 'the denial'},
 'the athletic departmental/_n': {'e_noun._n': 'the athletic department'},
 'athletic departmental/_n': {'e_noun._n': 'athletic department'},
 'whose departmental/_n': {'e_noun._n': 'whose department'},
 'governing departments/_n': {'e_noun._n': 'government departments'},
 'his departmental/_n': {'e_noun._n': 'his department'},
 'that departmental/_n': {'e_noun._n': 'that department'},
 'her departmental/_n': {'e_noun._n': 'her department'},
 'manic depressed/_n': {'e_noun._n': 'manic depression'},
 'postpartum depressed/_n': {'e_noun._n': 'postpartum depression'},
 'clinical depressed/_n': {'e_noun._n': 'clinical depression'},
 'severe depressed/_n': {'e_noun._n': 'severe depression'},
 'major depressed/_n': {'e_noun._n': 'major depression'},
 'sleeping deprivation/_n': {'e_noun._n': 'sleep deprivation'},
 'african descending/_n': {'e_noun._n': 'african descent'},
 'the descending/_n': {'e_noun._n': 'the descent'},
 'asian descending/_n': {'e_noun._n': 'asian descent'},
 'that descriptive/_n': {'e_noun._n': 'that description'},
 'a descriptive/_n': {'e_noun._n': 'a description'},
 'the descriptive/_n': {'e_noun._n': 'the description'},
 'a designing/_n': {'e_noun._n': 'a design'},
 'modern designing/_n': {'e_noun._n': 'modern design'},
 'computer-aided designing/_n': {'e_noun._n': 'computer-aided design'},
 'its designing/_n': {'e_noun._n': 'its design'},
 'new designing/_n': {'e_noun._n': 'new design'},
 'his designing/_n': {'e_noun._n': 'his design'},
 'the new designing/_n': {'e_noun._n': 'the new design'},
 'their designing/_n': {'e_noun._n': 'their design'},
 'their desirable/_n': {'e_noun._n': 'their desire'},
 'that desirable/_n': {'e_noun._n': 'that desire'},
 'his desirable/_n': {'e_noun._n': 'his desire'},
 'sexual desirable/_n': {'e_noun._n': 'sexual desire'},
 'sex desire/_n': {'e_noun._n': 'sexual desire'},
 'more detailed/_n': {'e_noun._n': 'more detail'},
 'every detailed/_n': {'e_noun._n': 'every detail'},
 'great detailed/_n': {'e_noun._n': 'great detail'},
 'greater detailed/_n': {'e_noun._n': 'greater detail'},
 'this details/_n': {'e_noun._n': 'those details'},
 'any detailed/_n': {'e_noun._n': 'any detail'},
 'early detectable/_n': {'e_noun._n': 'early detection'},
 'the determinate/_n': {'e_noun._n': 'the determination'},
 'that determinate/_n': {'e_noun._n': 'that determination'},
 'his determinate/_n': {'e_noun._n': 'his determination'},
 'a determinate/_n': {'e_noun._n': 'a determination'},
 'its developed/_n': {'e_noun._n': 'its development'},
 'commercial developed/_n': {'e_noun._n': 'commercial development'},
 'their developed/_n': {'e_noun._n': 'their development'},
 'professional developed/_n': {'e_noun._n': 'professional development'},
 'his developed/_n': {'e_noun._n': 'his development'},
 'product developed/_n': {'e_noun._n': 'product development'},
 'future developed/_n': {'e_noun._n': 'future development'},
 'brain developed/_n': {'e_noun._n': 'brain development'},
 'industry development/_n': {'e_noun._n': 'industrial development'},
 'urban developed/_n': {'e_noun._n': 'urban development'},
 'that developed/_n': {'e_noun._n': 'that development'},
 'society development/_n': {'e_noun._n': 'social development'},
 'their die/_n': {'e_noun._n': 'their dead'},
 'one different/_n': {'e_noun._n': 'one difference'},
 'the different between/_n': {'e_noun._n': 'the difference between'},
 'the only different/_n': {'e_noun._n': 'the only difference'},
 'that different/_n': {'e_noun._n': 'that difference'},
 'another different/_n': {'e_noun._n': 'another difference'},
 'no different/_n': {'e_noun._n': 'no difference'},
 'any different/_n': {'e_noun._n': 'any difference'},
 'this differences/_n': {'e_noun._n': 'those differences'},
 'little different/_n': {'e_noun._n': 'little difference'},
 'something difference/_n': {'e_noun._n': 'something different'},
 'much different/_n': {'e_noun._n': 'much difference'},
 'the biggest different/_n': {'e_noun._n': 'the biggest difference'},
 'more difficult/_n': {'e_noun._n': 'more difficulty'},
 'little difficult/_n': {'e_noun._n': 'little difficulty'},
 'some difficult/_n': {'e_noun._n': 'some difficulty'},
 'no difficult/_n': {'e_noun._n': 'no difficulty'},
 'great difficult/_n': {'e_noun._n': 'great difficulty'},
 'third dimensions/_n': {'e_noun._n': 'three dimensions'},
 'another dimensional/_n': {'e_noun._n': 'another dimension'},
 'the other direct/_n': {'e_noun._n': 'the other direction'},
 'a different direct/_n': {'e_noun._n': 'a different direction'},
 'the wrong direct/_n': {'e_noun._n': 'the wrong direction'},
 'every direct/_n': {'e_noun._n': 'every direction'},
 'the same direct/_n': {'e_noun._n': 'the same direction'},
 'our direct/_n': {'e_noun._n': 'our direction'},
 'the right direct/_n': {'e_noun._n': 'the right direction'},
 'either direct/_n': {'e_noun._n': 'either direction'},
 'any direct/_n': {'e_noun._n': 'any direction'},
 'that direct/_n': {'e_noun._n': 'that direction'},
 'which direct/_n': {'e_noun._n': 'which direction'},
 'each direct/_n': {'e_noun._n': 'each direction'},
 'the opposite direct/_n': {'e_noun._n': 'the opposite direction'},
 'another direct/_n': {'e_noun._n': 'another direction'},
 'a new direct/_n': {'e_noun._n': 'a new direction'},
 'their disappointing/_n': {'e_noun._n': 'their disappointment'},
 'his disappointing/_n': {'e_noun._n': 'his disappointment'},
 'nature disasters/_n': {'e_noun._n': 'natural disasters'},
 'fiscal disciplinary/_n': {'e_noun._n': 'fiscal discipline'},
 'job discriminating/_n': {'e_noun._n': 'job discrimination'},
 'employed discrimination/_n': {'e_noun._n': 'employment discrimination'},
 'employment discriminating/_n': {'e_noun._n': 'employment discrimination'},
 'the discriminating/_n': {'e_noun._n': 'the discrimination'},
 'age discriminating/_n': {'e_noun._n': 'age discrimination'},
 'past discriminating/_n': {'e_noun._n': 'past discrimination'},
 'sexism discrimination/_n': {'e_noun._n': 'sexual discrimination'},
 'sexuality discrimination/_n': {'e_noun._n': 'sexual discrimination'},
 'her diseased/_n': {'e_noun._n': 'her disease'},
 'human diseased/_n': {'e_noun._n': 'human disease'},
 'his diseased/_n': {'e_noun._n': 'his disease'},
 'mad cow diseased/_n': {'e_noun._n': 'mad cow disease'},
 'kidney diseased/_n': {'e_noun._n': 'kidney disease'},
 'that diseased/_n': {'e_noun._n': 'that disease'},
 'liver diseased/_n': {'e_noun._n': 'liver disease'},
 'infectious diseased/_n': {'e_noun._n': 'infectious disease'},
 'their diseased/_n': {'e_noun._n': 'their disease'},
 'computational disks/_n': {'e_noun._n': 'computer disks'},
 'post-traumatic stressful disorder/_n': {'e_noun._n': 'post-traumatic stress disorder'},
 'his disposable/_n': {'e_noun._n': 'his disposal'},
 'its disposable/_n': {'e_noun._n': 'its disposal'},
 'tradable disputes/_n': {'e_noun._n': 'trade disputes'},
 'a safe distant/_n': {'e_noun._n': 'a safe distance'},
 'striking distant/_n': {'e_noun._n': 'striking distance'},
 'some distant/_n': {'e_noun._n': 'some distance'},
 'walking distant/_n': {'e_noun._n': 'walking distance'},
 'that distant/_n': {'e_noun._n': 'that distance'},
 'his distant/_n': {'e_noun._n': 'his distance'},
 'a short distant/_n': {'e_noun._n': 'a short distance'},
 'that distinct/_n': {'e_noun._n': 'that distinction'},
 'the distributive/_n': {'e_noun._n': 'the distribution'},
 'new distributive/_n': {'e_noun._n': 'new distribution'},
 'its distributive/_n': {'e_noun._n': 'its distribution'},
 'racial diverse/_n': {'e_noun._n': 'racial diversity'},
 'their divided/_n': {'e_noun._n': 'their division'},
 'his divided/_n': {'e_noun._n': 'his division'},
 'its divided/_n': {'e_noun._n': 'its division'},
 'each divided/_n': {'e_noun._n': 'each division'},
 'our divided/_n': {'e_noun._n': 'our division'},
 'first divided/_n': {'e_noun._n': 'first division'},
 'one documented/_n': {'e_noun._n': 'one document'},
 'class documents/_n': {'e_noun._n': 'classified documents'},
 'that documented/_n': {'e_noun._n': 'that document'},
 'this documents/_n': {'e_noun._n': 'those documents'},
 'your dogged/_n': {'e_noun._n': 'your dog'},
 'their dogged/_n': {'e_noun._n': 'their dog'},
 'her dogged/_n': {'e_noun._n': 'her dog'},
 'his dogged/_n': {'e_noun._n': 'his dog'},
 'my dogged/_n': {'e_noun._n': 'my dog'},
 'taxable dollars/_n': {'e_noun._n': 'taxpayer dollars'},
 'several thousandth dollars/_n': {'e_noun._n': 'several thousand dollars'},
 'world dominant/_n': {'e_noun._n': 'world domination'},
 'a doubtful/_n': {'e_noun._n': 'a doubt'},
 'no doubtful/_n': {'e_noun._n': 'no doubt'},
 'little doubtful/_n': {'e_noun._n': 'little doubt'},
 'any doubtful/_n': {'e_noun._n': 'any doubt'},
 'some doubtful/_n': {'e_noun._n': 'some doubt'},
 'a reasonable doubtful/_n': {'e_noun._n': 'a reasonable doubt'},
 'the economy downturn/_n': {'e_noun._n': 'the economic downturn'},
 'a dragging/_n': {'e_noun._n': 'a drag'},
 'high dramatic/_n': {'e_noun._n': 'high drama'},
 'the drawn/_n': {'e_noun._n': 'the draw'},
 'this dreams/_n': {'e_noun._n': 'those dreams'},
 'her dressed/_n': {'e_noun._n': 'her dress'},
 'the dressed/_n': {'e_noun._n': 'the dress'},
 'casual dressed/_n': {'e_noun._n': 'casual dress'},
 'moderation drinking/_n': {'e_noun._n': 'moderate drinking'},
 'the hard driven/_n': {'e_noun._n': 'the hard drive'},
 'that driven/_n': {'e_noun._n': 'that drive'},
 'hard driven/_n': {'e_noun._n': 'hard drive'},
 'his driven/_n': {'e_noun._n': 'his drive'},
 'their driven/_n': {'e_noun._n': 'their drive'},
 'your hard driven/_n': {'e_noun._n': 'your hard drive'},
 'that dropped/_n': {'e_noun._n': 'that drop'},
 'a dropped/_n': {'e_noun._n': 'a drop'},
 'the dropped/_n': {'e_noun._n': 'the drop'},
 'this drugs/_n': {'e_noun._n': 'those drugs'},
 'the drummed/_n': {'e_noun._n': 'the drum'},
 'a drummed/_n': {'e_noun._n': 'a drum'},
 'averaged earnings/_n': {'e_noun._n': 'average earnings'},
 'ease of useful/_n': {'e_noun._n': 'ease of use'},
 'an easiness/_n': {'e_noun._n': 'an easy'},
 "the world's second-largest economic/_n": {'e_noun._n': "the world's second-largest economy"},
 'globe economy/_n': {'e_noun._n': 'global economy'},
 'the local economic/_n': {'e_noun._n': 'the local economy'},
 'a booming economic/_n': {'e_noun._n': 'a booming economy'},
 'the japanese economic/_n': {'e_noun._n': 'the japanese economy'},
 'old economic/_n': {'e_noun._n': 'old economy'},
 'the booming economic/_n': {'e_noun._n': 'the booming economy'},
 'the nation economy/_n': {'e_noun._n': 'the national economy'},
 'the us economic/_n': {'e_noun._n': 'the us economy'},
 "the city's economic/_n": {'e_noun._n': "the city's economy"},
 'a global economic/_n': {'e_noun._n': 'a global economy'},
 'fuel economic/_n': {'e_noun._n': 'fuel economy'},
 'the american economic/_n': {'e_noun._n': 'the american economy'},
 'the overall economic/_n': {'e_noun._n': 'the overall economy'},
 'a market economic/_n': {'e_noun._n': 'a market economy'},
 'whose economic/_n': {'e_noun._n': 'whose economy'},
 "america's economic/_n": {'e_noun._n': "america's economy"},
 'strong economic/_n': {'e_noun._n': 'strong economy'},
 'the internet economic/_n': {'e_noun._n': 'the internet economy'},
 'the strong economic/_n': {'e_noun._n': 'the strong economy'},
 'the new economic/_n': {'e_noun._n': 'the new economy'},
 'the national economic/_n': {'e_noun._n': 'the national economy'},
 'the domestic economic/_n': {'e_noun._n': 'the domestic economy'},
 'a strong economic/_n': {'e_noun._n': 'a strong economy'},
 'any edition/_n': {'e_noun._n': 'any editorial'},
 'more educational/_n': {'e_noun._n': 'more education'},
 'former educational/_n': {'e_noun._n': 'former education'},
 'that educational/_n': {'e_noun._n': 'that education'},
 'a college educational/_n': {'e_noun._n': 'a college education'},
 'her educational/_n': {'e_noun._n': 'her education'},
 'public educational/_n': {'e_noun._n': 'public education'},
 'state educational/_n': {'e_noun._n': 'state education'},
 'little educational/_n': {'e_noun._n': 'little education'},
 'dramatic effective/_n': {'e_noun._n': 'dramatic effect'},
 'the overall effective/_n': {'e_noun._n': 'the overall effect'},
 'the opposite effective/_n': {'e_noun._n': 'the opposite effect'},
 'great effective/_n': {'e_noun._n': 'great effect'},
 'what effective/_n': {'e_noun._n': 'what effect'},
 'some effective/_n': {'e_noun._n': 'some effect'},
 'much effective/_n': {'e_noun._n': 'much effect'},
 'any effective/_n': {'e_noun._n': 'any effect'},
 'little effective/_n': {'e_noun._n': 'little effect'},
 'that effective/_n': {'e_noun._n': 'that effect'},
 'the same effective/_n': {'e_noun._n': 'the same effect'},
 'energetic efficiency/_n': {'e_noun._n': 'energy efficiency'},
 'greater efficient/_n': {'e_noun._n': 'greater efficiency'},
 'this efforts/_n': {'e_noun._n': 'those efforts'},
 'the 1996 elect/_n': {'e_noun._n': 'the 1996 election'},
 'last elect/_n': {'e_noun._n': 'last election'},
 'state elect/_n': {'e_noun._n': 'state election'},
 'the 2000 elect/_n': {'e_noun._n': 'the 2000 election'},
 "sunday's elect/_n": {'e_noun._n': "sunday's election"},
 'every elect/_n': {'e_noun._n': 'every election'},
 'the 1992 elect/_n': {'e_noun._n': 'the 1992 election'},
 'presidential elect/_n': {'e_noun._n': 'presidential election'},
 'the next elect/_n': {'e_noun._n': 'the next election'},
 'that elect/_n': {'e_noun._n': 'that election'},
 'a presidential elect/_n': {'e_noun._n': 'a presidential election'},
 'the last elect/_n': {'e_noun._n': 'the last election'},
 'the next presidential elect/_n': {'e_noun._n': 'the next presidential election'},
 'another elect/_n': {'e_noun._n': 'another election'},
 'an elect/_n': {'e_noun._n': 'an election'},
 'local elect/_n': {'e_noun._n': 'local election'},
 'his elect/_n': {'e_noun._n': 'his election'},
 'the 2000 presidential elect/_n': {'e_noun._n': 'the 2000 presidential election'},
 'the november elect/_n': {'e_noun._n': 'the november election'},
 'regional electric/_n': {'e_noun._n': 'regional electricity'},
 'consuming electronics/_n': {'e_noun._n': 'consumer electronics'},
 'this elements/_n': {'e_noun._n': 'those elements'},
 'this emotions/_n': {'e_noun._n': 'those emotions'},
 'more emphatic/_n': {'e_noun._n': 'more emphasis'},
 'emphatic on/_n': {'e_noun._n': 'emphasis on'},
 'governing employees/_n': {'e_noun._n': 'government employees'},
 'strong employed/_n': {'e_noun._n': 'strong employment'},
 'full employed/_n': {'e_noun._n': 'full employment'},
 'temporary employed/_n': {'e_noun._n': 'temporary employment'},
 'new employed/_n': {'e_noun._n': 'new employment'},
 'total employed/_n': {'e_noun._n': 'total employment'},
 'lifetime employed/_n': {'e_noun._n': 'lifetime employment'},
 'equal employed/_n': {'e_noun._n': 'equal employment'},
 'that ended/_n': {'e_noun._n': 'that end'},
 'the ended of the line/_n': {'e_noun._n': 'the end of the line'},
 'the end of the lined/_n': {'e_noun._n': 'the end of the line'},
 'its ended/_n': {'e_noun._n': 'its end'},
 'the ended of the game/_n': {'e_noun._n': 'the end of the game'},
 'the ended of december/_n': {'e_noun._n': 'the end of december'},
 'the ended of 2000/_n': {'e_noun._n': 'the end of 2000'},
 'the ended of 2001/_n': {'e_noun._n': 'the end of 2001'},
 'the ended of next week/_n': {'e_noun._n': 'the end of next week'},
 'the end of next weekly/_n': {'e_noun._n': 'the end of next week'},
 'the ended of july/_n': {'e_noun._n': 'the end of july'},
 "year's ended/_n": {'e_noun._n': "year's end"},
 'one ended/_n': {'e_noun._n': 'one end'},
 'an ended/_n': {'e_noun._n': 'an end'},
 'the ended of this year/_n': {'e_noun._n': 'the end of this year'},
 'the end of those year/_n': {'e_noun._n': 'the end of this year'},
 'the ended of the cold war/_n': {'e_noun._n': 'the end of the cold war'},
 'the ended of june/_n': {'e_noun._n': 'the end of june'},
 'the ended of it/_n': {'e_noun._n': 'the end of it'},
 'the ended of last year/_n': {'e_noun._n': 'the end of last year'},
 'the ended of march/_n': {'e_noun._n': 'the end of march'},
 'the end of marching/_n': {'e_noun._n': 'the end of march'},
 'the ended of october/_n': {'e_noun._n': 'the end of october'},
 'the ended of the film/_n': {'e_noun._n': 'the end of the film'},
 'the end of the filmed/_n': {'e_noun._n': 'the end of the film'},
 'the ended of the day,/_n': {'e_noun._n': 'the end of the day,'},
 'their ended/_n': {'e_noun._n': 'their end'},
 'the ended of an era/_n': {'e_noun._n': 'the end of an era'},
 'the ended of the day/_n': {'e_noun._n': 'the end of the day'},
 'the ended of the summer/_n': {'e_noun._n': 'the end of the summer'},
 'the ended of the century/_n': {'e_noun._n': 'the end of the century'},
 'the ended of the war/_n': {'e_noun._n': 'the end of the war'},
 'the ended of world war ii/_n': {'e_noun._n': 'the end of world war ii'},
 'the ended of the civil war/_n': {'e_noun._n': 'the end of the civil war'},
 'the ended of/_n': {'e_noun._n': 'the end of'},
 'the ended of next year/_n': {'e_noun._n': 'the end of next year'},
 'ended up/_n': {'e_noun._n': 'end up'},
 'no ended/_n': {'e_noun._n': 'no end'},
 'the ended of his life/_n': {'e_noun._n': 'the end of his life'},
 'the ended of february/_n': {'e_noun._n': 'the end of february'},
 'the ended of january/_n': {'e_noun._n': 'the end of january'},
 'the ended of april/_n': {'e_noun._n': 'the end of april'},
 'the ended of the 20th century/_n': {'e_noun._n': 'the end of the 20th century'},
 'the other ended/_n': {'e_noun._n': 'the other end'},
 'the ended of august/_n': {'e_noun._n': 'the end of august'},
 'the ended of september/_n': {'e_noun._n': 'the end of september'},
 'the other ended of the line/_n': {'e_noun._n': 'the other end of the line'},
 'the other end of the lined/_n': {'e_noun._n': 'the other end of the line'},
 'the ended of the world/_n': {'e_noun._n': 'the end of the world'},
 'the ended of the year/_n': {'e_noun._n': 'the end of the year'},
 "day's ended/_n": {'e_noun._n': "day's end"},
 'the very ended/_n': {'e_noun._n': 'the very end'},
 'the ended of the decade/_n': {'e_noun._n': 'the end of the decade'},
 'the ended of the month/_n': {'e_noun._n': 'the end of the month'},
 'the end of the monthly/_n': {'e_noun._n': 'the end of the month'},
 'the ended of november/_n': {'e_noun._n': 'the end of november'},
 'each ended/_n': {'e_noun._n': 'each end'},
 'his ended/_n': {'e_noun._n': 'his end'},
 'the ended of the week/_n': {'e_noun._n': 'the end of the week'},
 'the end of the weekly/_n': {'e_noun._n': 'the end of the week'},
 'the ended of this month/_n': {'e_noun._n': 'the end of this month'},
 'the end of those month/_n': {'e_noun._n': 'the end of this month'},
 'the end of this monthly/_n': {'e_noun._n': 'the end of this month'},
 'the ended of may/_n': {'e_noun._n': 'the end of may'},
 'the ended of this week/_n': {'e_noun._n': 'the end of this week'},
 'the end of those week/_n': {'e_noun._n': 'the end of this week'},
 'the end of this weekly/_n': {'e_noun._n': 'the end of this week'},
 'the ended of 1994/_n': {'e_noun._n': 'the end of 1994'},
 'the ended of 1995/_n': {'e_noun._n': 'the end of 1995'},
 'the ended of 1997/_n': {'e_noun._n': 'the end of 1997'},
 'either ended/_n': {'e_noun._n': 'either end'},
 'the ended of 1999/_n': {'e_noun._n': 'the end of 1999'},
 'the ended of the tunnel/_n': {'e_noun._n': 'the end of the tunnel'},
 'great energetic/_n': {'e_noun._n': 'great energy'},
 'high energetic/_n': {'e_noun._n': 'high energy'},
 'more energetic/_n': {'e_noun._n': 'more energy'},
 'her energetic/_n': {'e_noun._n': 'her energy'},
 'lower energetic/_n': {'e_noun._n': 'lower energy'},
 'his energetic/_n': {'e_noun._n': 'his energy'},
 'its energetic/_n': {'e_noun._n': 'its energy'},
 'your energetic/_n': {'e_noun._n': 'your energy'},
 'that energetic/_n': {'e_noun._n': 'that energy'},
 'rising energetic/_n': {'e_noun._n': 'rising energy'},
 'alternative energetic/_n': {'e_noun._n': 'alternative energy'},
 'higher energetic/_n': {'e_noun._n': 'higher energy'},
 'their energetic/_n': {'e_noun._n': 'their energy'},
 'lawful enforcement./_n': {'e_noun._n': 'law enforcement.'},
 'lawful enforcement,/_n': {'e_noun._n': 'law enforcement,'},
 'living entertainment/_n': {'e_noun._n': 'live entertainment'},
 'live entertaining/_n': {'e_noun._n': 'live entertainment'},
 'interactive entertaining/_n': {'e_noun._n': 'interactive entertainment'},
 'new entertaining/_n': {'e_noun._n': 'new entertainment'},
 'other entertaining/_n': {'e_noun._n': 'other entertainment'},
 'adult entertaining/_n': {'e_noun._n': 'adult entertainment'},
 'popular entertaining/_n': {'e_noun._n': 'popular entertainment'},
 'family entertaining/_n': {'e_noun._n': 'family entertainment'},
 'his entered/_n': {'e_noun._n': 'his entrance'},
 'the entered/_n': {'e_noun._n': 'the entrance'},
 'that environmental/_n': {'e_noun._n': 'that environment'},
 'their environmental/_n': {'e_noun._n': 'their environment'},
 'an equality/_n': {'e_noun._n': 'an equal'},
 'that equational/_n': {'e_noun._n': 'that equation'},
 'the equational/_n': {'e_noun._n': 'the equation'},
 'exercised equipment/_n': {'e_noun._n': 'exercise equipment'},
 'constructive equipment/_n': {'e_noun._n': 'construction equipment'},
 'computational equipment/_n': {'e_noun._n': 'computer equipment'},
 'the equivalence/_n': {'e_noun._n': 'the equivalent'},
 'the eroding/_n': {'e_noun._n': 'the erosion'},
 'sampling erroneous/_n': {'e_noun._n': 'sampling error'},
 'human erroneous/_n': {'e_noun._n': 'human error'},
 'an erroneous/_n': {'e_noun._n': 'an error'},
 'pilot erroneous/_n': {'e_noun._n': 'pilot error'},
 'the erroneous/_n': {'e_noun._n': 'the error'},
 'the escaped/_n': {'e_noun._n': 'the escape'},
 'no escaped/_n': {'e_noun._n': 'no escape'},
 'his escaped/_n': {'e_noun._n': 'his escape'},
 'their escaped/_n': {'e_noun._n': 'their escape'},
 'its essential/_n': {'e_noun._n': 'its essence'},
 'the medical established/_n': {'e_noun._n': 'the medical establishment'},
 'the political established/_n': {'e_noun._n': 'the political establishment'},
 'industrial estimates/_n': {'e_noun._n': 'industry estimates'},
 'one estimated/_n': {'e_noun._n': 'one estimate'},
 'that estimated/_n': {'e_noun._n': 'that estimate'},
 'governing estimates/_n': {'e_noun._n': 'government estimates'},
 'the estimation/_n': {'e_noun._n': 'the estimated'},
 'an estimation/_n': {'e_noun._n': 'an estimated'},
 'the evaluative/_n': {'e_noun._n': 'the evaluation'},
 'culture events/_n': {'e_noun._n': 'cultural events'},
 'specialist events/_n': {'e_noun._n': 'special events'},
 'this events/_n': {'e_noun._n': 'those events'},
 'science evidence/_n': {'e_noun._n': 'scientific evidence'},
 'closer examining/_n': {'e_noun._n': 'closer examination'},
 'an examining/_n': {'e_noun._n': 'an examination'},
 'an excellence/_n': {'e_noun._n': 'an excellent'},
 'no exceptional/_n': {'e_noun._n': 'no exception'},
 'one exceptional/_n': {'e_noun._n': 'one exception'},
 'regular exchanging/_n': {'e_noun._n': 'regular exchange'},
 'that exchanging/_n': {'e_noun._n': 'that exchange'},
 'each exchanging/_n': {'e_noun._n': 'each exchange'},
 'an exchanging/_n': {'e_noun._n': 'an exchange'},
 'the excited/_n': {'e_noun._n': 'the excitement'},
 'his excited/_n': {'e_noun._n': 'his excitement'},
 'no excusing/_n': {'e_noun._n': 'no excuse'},
 'the excusing/_n': {'e_noun._n': 'the excuse'},
 'an excusing/_n': {'e_noun._n': 'an excuse'},
 'industrial executives/_n': {'e_noun._n': 'industry executives'},
 'the exercised/_n': {'e_noun._n': 'the exercise'},
 'regular exercised/_n': {'e_noun._n': 'regular exercise'},
 'an exercised/_n': {'e_noun._n': 'an exercise'},
 'the exhibited/_n': {'e_noun._n': 'the exhibit'},
 'an exhibited/_n': {'e_noun._n': 'an exhibit'},
 'first exhibited/_n': {'e_noun._n': 'first exhibition'},
 'its existent/_n': {'e_noun._n': 'its existence'},
 'human existent/_n': {'e_noun._n': 'human existence'},
 'our existent/_n': {'e_noun._n': 'our existence'},
 'their existent/_n': {'e_noun._n': 'their existence'},
 'whose existent/_n': {'e_noun._n': 'whose existence'},
 'his existent/_n': {'e_noun._n': 'his existence'},
 'the economic expansive/_n': {'e_noun._n': 'the economic expansion'},
 'international expansive/_n': {'e_noun._n': 'international expansion'},
 'aggressive expansive/_n': {'e_noun._n': 'aggressive expansion'},
 'rapid expansive/_n': {'e_noun._n': 'rapid expansion'},
 'economic expansive/_n': {'e_noun._n': 'economic expansion'},
 'its expansive/_n': {'e_noun._n': 'its expansion'},
 'economy expansion/_n': {'e_noun._n': 'economic expansion'},
 'global expansive/_n': {'e_noun._n': 'global expansion'},
 'that expected/_n': {'e_noun._n': 'that expectation'},
 'live expenses/_n': {'e_noun._n': 'living expenses'},
 'no expensive/_n': {'e_noun._n': 'no expense'},
 'this expenses/_n': {'e_noun._n': 'those expenses'},
 'taxable expense/_n': {'e_noun._n': 'taxpayer expense'},
 'taxpayer expensive/_n': {'e_noun._n': 'taxpayer expense'},
 'the most expense/_n': {'e_noun._n': 'the most expensive'},
 'travelled expenses/_n': {'e_noun._n': 'travel expenses'},
 'interesting expenses/_n': {'e_noun._n': 'interest expenses'},
 'her experienced/_n': {'e_noun._n': 'her experience'},
 'international experienced/_n': {'e_noun._n': 'international experience'},
 'this experiences/_n': {'e_noun._n': 'those experiences'},
 'his experienced/_n': {'e_noun._n': 'his experience'},
 'a learned experience/_n': {'e_noun._n': 'a learning experience'},
 'a learning experienced/_n': {'e_noun._n': 'a learning experience'},
 'personal experienced/_n': {'e_noun._n': 'personal experience'},
 'past experienced/_n': {'e_noun._n': 'past experience'},
 'some experienced/_n': {'e_noun._n': 'some experience'},
 'human experienced/_n': {'e_noun._n': 'human experience'},
 'more experienced/_n': {'e_noun._n': 'more experience'},
 'that experienced/_n': {'e_noun._n': 'that experience'},
 'no experienced/_n': {'e_noun._n': 'no experience'},
 'little experienced/_n': {'e_noun._n': 'little experience'},
 'our experienced/_n': {'e_noun._n': 'our experience'},
 'your experienced/_n': {'e_noun._n': 'your experience'},
 'my experienced/_n': {'e_noun._n': 'my experience'},
 'that experimental/_n': {'e_noun._n': 'that experiment'},
 'his experimental/_n': {'e_noun._n': 'his experiment'},
 'industrial experts/_n': {'e_noun._n': 'industry experts'},
 'secure experts/_n': {'e_noun._n': 'security experts'},
 'computational experts/_n': {'e_noun._n': 'computer experts'},
 'healthy experts/_n': {'e_noun._n': 'health experts'},
 'safe experts/_n': {'e_noun._n': 'safety experts'},
 'no explanatory/_n': {'e_noun._n': 'no explanation'},
 'one explanatory/_n': {'e_noun._n': 'one explanation'},
 'an explanatory/_n': {'e_noun._n': 'an explanation'},
 'the explanatory/_n': {'e_noun._n': 'the explanation'},
 'another explanatory/_n': {'e_noun._n': 'another explanation'},
 'that explanatory/_n': {'e_noun._n': 'that explanation'},
 'his explanatory/_n': {'e_noun._n': 'his explanation'},
 'oil exploratory/_n': {'e_noun._n': 'oil exploration'},
 'new exporting/_n': {'e_noun._n': 'new export'},
 'its exposed/_n': {'e_noun._n': 'its exposure'},
 'their exposed/_n': {'e_noun._n': 'their exposure'},
 'radiation exposed/_n': {'e_noun._n': 'radiation exposure'},
 'freedom expression/_n': {'e_noun._n': 'free expression'},
 'free express/_n': {'e_noun._n': 'free expression'},
 'political express/_n': {'e_noun._n': 'political expression'},
 'artistic express/_n': {'e_noun._n': 'artistic expression'},
 'his express/_n': {'e_noun._n': 'his expression'},
 "children's expression/_n": {'e_noun._n': "children's express"},
 'a faced/_n': {'e_noun._n': 'a face'},
 'your faced/_n': {'e_noun._n': 'your face'},
 'whose faced/_n': {'e_noun._n': 'whose face'},
 'the faced/_n': {'e_noun._n': 'the face'},
 'my faced/_n': {'e_noun._n': 'my face'},
 'his faced/_n': {'e_noun._n': 'his face'},
 'their faced/_n': {'e_noun._n': 'their face'},
 'its faced/_n': {'e_noun._n': 'its face'},
 'that faced/_n': {'e_noun._n': 'that face'},
 'the faced of the earth/_n': {'e_noun._n': 'the face of the earth'},
 'the face of the earthy/_n': {'e_noun._n': 'the face of the earth'},
 'our faced/_n': {'e_noun._n': 'our face'},
 'this facilities/_n': {'e_noun._n': 'those facilities'},
 'a factual/_n': {'e_noun._n': 'a fact'},
 'this facts/_n': {'e_noun._n': 'those facts'},
 'the factual of the matter/_n': {'e_noun._n': 'the fact of the matter'},
 'that factual/_n': {'e_noun._n': 'that fact'},
 'one factual/_n': {'e_noun._n': 'one fact'},
 'one factored/_n': {'e_noun._n': 'one factor'},
 'this factors/_n': {'e_noun._n': 'those factors'},
 'third factors/_n': {'e_noun._n': 'three factors'},
 'a factored/_n': {'e_noun._n': 'a factor'},
 'another factored/_n': {'e_noun._n': 'another factor'},
 'environment factors/_n': {'e_noun._n': 'environmental factors'},
 'a major factored/_n': {'e_noun._n': 'a major factor'},
 'that failed/_n': {'e_noun._n': 'that failure'},
 'liver failed/_n': {'e_noun._n': 'liver failure'},
 'kidney failed/_n': {'e_noun._n': 'kidney failure'},
 'mechanical failed/_n': {'e_noun._n': 'mechanical failure'},
 'their failed/_n': {'e_noun._n': 'their failure'},
 'respiratory failed/_n': {'e_noun._n': 'respiratory failure'},
 'a fairness/_n': {'e_noun._n': 'a fair'},
 'all fair/_n': {'e_noun._n': 'all fairness'},
 'bad faithful/_n': {'e_noun._n': 'bad faith'},
 'your faithful/_n': {'e_noun._n': 'your faith'},
 'that faithful/_n': {'e_noun._n': 'that faith'},
 'religion faith/_n': {'e_noun._n': 'religious faith'},
 'religious faithful/_n': {'e_noun._n': 'religious faith'},
 'full faithful/_n': {'e_noun._n': 'full faith'},
 'the fanned/_n': {'e_noun._n': 'the fan'},
 'musical fans/_n': {'e_noun._n': 'music fans'},
 'this fans/_n': {'e_noun._n': 'those fans'},
 'one fanned/_n': {'e_noun._n': 'one fan'},
 'a fanned/_n': {'e_noun._n': 'a fan'},
 'that fashionable/_n': {'e_noun._n': 'that fashion'},
 'french fashionable/_n': {'e_noun._n': 'french fashion'},
 'some fashionable/_n': {'e_noun._n': 'some fashion'},
 "men's fashionable/_n": {'e_noun._n': "men's fashion"},
 'new fashionable/_n': {'e_noun._n': 'new fashion'},
 'italian fashionable/_n': {'e_noun._n': 'italian fashion'},
 'a fastness/_n': {'e_noun._n': 'a fast'},
 'the fastness/_n': {'e_noun._n': 'the fast'},
 'the fatty/_n': {'e_noun._n': 'the fat'},
 'body fatty/_n': {'e_noun._n': 'body fat'},
 'his faulty/_n': {'e_noun._n': 'his fault'},
 'my faulty/_n': {'e_noun._n': 'my fault'},
 'no fearful/_n': {'e_noun._n': 'no fear'},
 'my fearful/_n': {'e_noun._n': 'my fear'},
 'that fearful/_n': {'e_noun._n': 'that fear'},
 'their fearful/_n': {'e_noun._n': 'their fear'},
 'a feathered/_n': {'e_noun._n': 'a feather'},
 'that featured/_n': {'e_noun._n': 'that feature'},
 'safe features/_n': {'e_noun._n': 'safety features'},
 'a featured/_n': {'e_noun._n': 'a feature'},
 'this features/_n': {'e_noun._n': 'those features'},
 'federal spent/_n': {'e_noun._n': 'federal spending'},
 'managing fees/_n': {'e_noun._n': 'management fees'},
 'useful fees/_n': {'e_noun._n': 'user fees'},
 'this fees/_n': {'e_noun._n': 'those fees'},
 'this feelings/_n': {'e_noun._n': 'those feelings'},
 'inner vitro fertilization/_n': {'e_noun._n': 'in vitro fertilization'},
 'this fields/_n': {'e_noun._n': 'those fields'},
 'their fighting/_n': {'e_noun._n': 'their fight'},
 'the fighting against terrorism/_n': {'e_noun._n': 'the fight against terrorism'},
 'his fighting/_n': {'e_noun._n': 'his fight'},
 'this figures/_n': {'e_noun._n': 'those figures'},
 'industrial figures/_n': {'e_noun._n': 'industry figures'},
 'governing figures/_n': {'e_noun._n': 'government figures'},
 'this files/_n': {'e_noun._n': 'those files'},
 'musical files/_n': {'e_noun._n': 'music files'},
 'computational files/_n': {'e_noun._n': 'computer files'},
 'her filmed/_n': {'e_noun._n': 'her film'},
 'the first filmed/_n': {'e_noun._n': 'the first film'},
 'independent filmed/_n': {'e_noun._n': 'independent film'},
 'foreign filmed/_n': {'e_noun._n': 'foreign film'},
 'the new filmed/_n': {'e_noun._n': 'the new film'},
 'this films/_n': {'e_noun._n': 'those films'},
 'british filmed/_n': {'e_noun._n': 'british film'},
 'animated filmed/_n': {'e_noun._n': 'animated film'},
 'a filmed/_n': {'e_noun._n': 'a film'},
 'each filmed/_n': {'e_noun._n': 'each film'},
 'that filmed/_n': {'e_noun._n': 'that film'},
 'his filmed/_n': {'e_noun._n': 'his film'},
 'featured films/_n': {'e_noun._n': 'feature films'},
 'the filmed/_n': {'e_noun._n': 'the film'},
 'photographic filmed/_n': {'e_noun._n': 'photographic film'},
 'a featured film/_n': {'e_noun._n': 'a feature film'},
 'a feature filmed/_n': {'e_noun._n': 'a feature film'},
 'any filmed/_n': {'e_noun._n': 'any film'},
 'their filmed/_n': {'e_noun._n': 'their film'},
 'new filmed/_n': {'e_noun._n': 'new film'},
 'the filmed itself/_n': {'e_noun._n': 'the film itself'},
 'documentary filmed/_n': {'e_noun._n': 'documentary film'},
 'former financial/_n': {'e_noun._n': 'former finance'},
 'new financial/_n': {'e_noun._n': 'new finance'},
 'global financial/_n': {'e_noun._n': 'global finance'},
 'personal financial/_n': {'e_noun._n': 'personal finance'},
 'this findings/_n': {'e_noun._n': 'those findings'},
 'a fineness/_n': {'e_noun._n': 'a fine'},
 'the fineness/_n': {'e_noun._n': 'the fine'},
 'forested fires/_n': {'e_noun._n': 'forest fires'},
 'lawful firms/_n': {'e_noun._n': 'law firms'},
 'a lawful firm/_n': {'e_noun._n': 'a law firm'},
 'his lawful firm/_n': {'e_noun._n': 'his law firm'},
 'a firmness/_n': {'e_noun._n': 'a firm'},
 'her firmness/_n': {'e_noun._n': 'her firm'},
 'his firmness/_n': {'e_noun._n': 'his firm'},
 'a good fitness/_n': {'e_noun._n': 'a good fit'},
 'this five/_n': {'e_noun._n': 'those five'},
 'a fixable/_n': {'e_noun._n': 'a fix'},
 'the fixable/_n': {'e_noun._n': 'the fix'},
 'greater flexible/_n': {'e_noun._n': 'greater flexibility'},
 'more flexible/_n': {'e_noun._n': 'more flexibility'},
 'some flexible/_n': {'e_noun._n': 'some flexibility'},
 'the three floor/_n': {'e_noun._n': 'the third floor'},
 'bloody flow/_n': {'e_noun._n': 'blood flow'},
 'current fluctuations/_n': {'e_noun._n': 'currency fluctuations'},
 'my focused/_n': {'e_noun._n': 'my focus'},
 'your focused/_n': {'e_noun._n': 'your focus'},
 'its focused/_n': {'e_noun._n': 'its focus'},
 'our focused/_n': {'e_noun._n': 'our focus'},
 'her focused/_n': {'e_noun._n': 'her focus'},
 'their focused/_n': {'e_noun._n': 'their focus'},
 'that focused/_n': {'e_noun._n': 'that focus'},
 'sharp focused/_n': {'e_noun._n': 'sharp focus'},
 'dogged food/_n': {'e_noun._n': 'dog food'},
 'a foolishness/_n': {'e_noun._n': 'a fool'},
 'that forceful/_n': {'e_noun._n': 'that force'},
 'its forceful/_n': {'e_noun._n': 'its force'},
 'full forceful/_n': {'e_noun._n': 'full force'},
 'governing forces/_n': {'e_noun._n': 'government forces'},
 'such a forceful/_n': {'e_noun._n': 'such a force'},
 'overwhelming forceful/_n': {'e_noun._n': 'overwhelming force'},
 'the secure forces/_n': {'e_noun._n': 'the security forces'},
 'brute forceful/_n': {'e_noun._n': 'brute force'},
 'the labor forceful/_n': {'e_noun._n': 'the labor force'},
 'excessive forceful/_n': {'e_noun._n': 'excessive force'},
 'the driving forceful/_n': {'e_noun._n': 'the driving force'},
 'the forceful/_n': {'e_noun._n': 'the force'},
 'deadly forceful/_n': {'e_noun._n': 'deadly force'},
 'secure forces/_n': {'e_noun._n': 'security forces'},
 'variety forms/_n': {'e_noun._n': 'various forms'},
 'his formed/_n': {'e_noun._n': 'his form'},
 'book formed/_n': {'e_noun._n': 'book form'},
 'digital formed/_n': {'e_noun._n': 'digital form'},
 'electronic formed/_n': {'e_noun._n': 'electronic form'},
 'that formed/_n': {'e_noun._n': 'that form'},
 'one formed/_n': {'e_noun._n': 'one form'},
 'a formed/_n': {'e_noun._n': 'a form'},
 'some formed/_n': {'e_noun._n': 'some form'},
 'any formed/_n': {'e_noun._n': 'any form'},
 'difference forms/_n': {'e_noun._n': 'different forms'},
 'its current formed/_n': {'e_noun._n': 'its current form'},
 'top formed/_n': {'e_noun._n': 'top form'},
 'infant formulaic/_n': {'e_noun._n': 'infant formula'},
 'that formulaic/_n': {'e_noun._n': 'that formula'},
 'his fortunate/_n': {'e_noun._n': 'his fortune'},
 'her fortunate/_n': {'e_noun._n': 'her fortune'},
 'his foundational/_n': {'e_noun._n': 'his foundation'},
 'its foundational/_n': {'e_noun._n': 'its foundation'},
 'the foundational/_n': {'e_noun._n': 'the foundation'},
 'a foundational/_n': {'e_noun._n': 'a foundation'},
 'finance fraud/_n': {'e_noun._n': 'financial fraud'},
 'mailed fraud/_n': {'e_noun._n': 'mail fraud'},
 'insured fraud/_n': {'e_noun._n': 'insurance fraud'},
 'taxable fraud/_n': {'e_noun._n': 'tax fraud'},
 'votable fraud/_n': {'e_noun._n': 'voter fraud'},
 'crime fraud/_n': {'e_noun._n': 'criminal fraud'},
 'free of the press/_n': {'e_noun._n': 'freedom of the press'},
 'artistic free/_n': {'e_noun._n': 'artistic freedom'},
 'political free/_n': {'e_noun._n': 'political freedom'},
 'that free/_n': {'e_noun._n': 'that freedom'},
 'free of expression/_n': {'e_noun._n': 'freedom of expression'},
 'freedom of express/_n': {'e_noun._n': 'freedom of expression'},
 'religion freedom/_n': {'e_noun._n': 'religious freedom'},
 'more free/_n': {'e_noun._n': 'more freedom'},
 'personal free/_n': {'e_noun._n': 'personal freedom'},
 'increasing frequent/_n': {'e_noun._n': 'increasing frequency'},
 'his best friendly/_n': {'e_noun._n': 'his best friend'},
 'this friends/_n': {'e_noun._n': 'those friends'},
 'their friendly/_n': {'e_noun._n': 'their friend'},
 'an old friendly/_n': {'e_noun._n': 'an old friend'},
 'a friendly of mine/_n': {'e_noun._n': 'a friend of mine'},
 'close friendly/_n': {'e_noun._n': 'close friend'},
 'her best friendly/_n': {'e_noun._n': 'her best friend'},
 'a close friendly/_n': {'e_noun._n': 'a close friend'},
 'good friendly/_n': {'e_noun._n': 'good friend'},
 'third friends/_n': {'e_noun._n': 'three friends'},
 'another friendly/_n': {'e_noun._n': 'another friend'},
 'one friendly/_n': {'e_noun._n': 'one friend'},
 'averaged fuel/_n': {'e_noun._n': 'average fuel'},
 'any funny/_n': {'e_noun._n': 'any fun'},
 'so much funny/_n': {'e_noun._n': 'so much fun'},
 'more funny/_n': {'e_noun._n': 'more fun'},
 'great funny/_n': {'e_noun._n': 'great fun'},
 'no funny/_n': {'e_noun._n': 'no fun'},
 'much funny/_n': {'e_noun._n': 'much fun'},
 'the funny of it/_n': {'e_noun._n': 'the fun of it'},
 'its functional/_n': {'e_noun._n': 'its function'},
 'a functional/_n': {'e_noun._n': 'a function'},
 'governing funding/_n': {'e_noun._n': 'government funding'},
 'governing funds/_n': {'e_noun._n': 'government funds'},
 'bonding funds/_n': {'e_noun._n': 'bond funds'},
 'this funds/_n': {'e_noun._n': 'those funds'},
 'weighable gain/_n': {'e_noun._n': 'weight gain'},
 'third games/_n': {'e_noun._n': 'three games'},
 'oil and nature gas/_n': {'e_noun._n': 'oil and natural gas'},
 'intelligent gathering/_n': {'e_noun._n': 'intelligence gathering'},
 'the generality/_n': {'e_noun._n': 'the general'},
 'my generative/_n': {'e_noun._n': 'my generation'},
 'every generative/_n': {'e_noun._n': 'every generation'},
 'a new generative/_n': {'e_noun._n': 'a new generation'},
 'that generative/_n': {'e_noun._n': 'that generation'},
 'another generative/_n': {'e_noun._n': 'another generation'},
 'next generative/_n': {'e_noun._n': 'next generation'},
 'the younger generative/_n': {'e_noun._n': 'the younger generation'},
 'his generative/_n': {'e_noun._n': 'his generation'},
 'a generative/_n': {'e_noun._n': 'a generation'},
 'each generative/_n': {'e_noun._n': 'each generation'},
 'her generative/_n': {'e_noun._n': 'her generation'},
 'their generative/_n': {'e_noun._n': 'their generation'},
 'his generous/_n': {'e_noun._n': 'his generosity'},
 'his gifted/_n': {'e_noun._n': 'his gift'},
 'this gifts/_n': {'e_noun._n': 'those gifts'},
 'third girls/_n': {'e_noun._n': 'three girls'},
 'a glass of waterless/_n': {'e_noun._n': 'a glass of water'},
 'a gone/_n': {'e_noun._n': 'a go'},
 'the gone/_n': {'e_noun._n': 'the go'},
 'third goals/_n': {'e_noun._n': 'three goals'},
 'sixteenth goals/_n': {'e_noun._n': 'six goals'},
 'this goals/_n': {'e_noun._n': 'those goals'},
 'much goodness/_n': {'e_noun._n': 'much good'},
 'any goodness/_n': {'e_noun._n': 'any good'},
 'what goodness/_n': {'e_noun._n': 'what good'},
 'no goodness/_n': {'e_noun._n': 'no good'},
 'some goodness/_n': {'e_noun._n': 'some good'},
 'its own goodness/_n': {'e_noun._n': 'its own good'},
 'specialist government/_n': {'e_noun._n': 'special government'},
 'special governing/_n': {'e_noun._n': 'special government'},
 'the local governing/_n': {'e_noun._n': 'the local government'},
 'local governing/_n': {'e_noun._n': 'local government'},
 'their governing/_n': {'e_noun._n': 'their government'},
 "japan's governing/_n": {'e_noun._n': "japan's government"},
 'high-ranking governing/_n': {'e_noun._n': 'high-ranking government'},
 'state governing/_n': {'e_noun._n': 'state government'},
 'limited governing/_n': {'e_noun._n': 'limited government'},
 'any governing/_n': {'e_noun._n': 'any government'},
 'my governing/_n': {'e_noun._n': 'my government'},
 'a coalition governing/_n': {'e_noun._n': 'a coalition government'},
 'official governing/_n': {'e_noun._n': 'official government'},
 'senior governing/_n': {'e_noun._n': 'senior government'},
 'the french governing/_n': {'e_noun._n': 'the french government'},
 'no governing/_n': {'e_noun._n': 'no government'},
 'the new governing/_n': {'e_noun._n': 'the new government'},
 'the hong kong governing/_n': {'e_noun._n': 'the hong kong government'},
 'the governing now/_n': {'e_noun._n': 'the government now'},
 'the state governing/_n': {'e_noun._n': 'the state government'},
 'her governing/_n': {'e_noun._n': 'her government'},
 'what governing/_n': {'e_noun._n': 'what government'},
 'the indian governing/_n': {'e_noun._n': 'the indian government'},
 'not governing/_n': {'e_noun._n': 'not government'},
 'the city governing/_n': {'e_noun._n': 'the city government'},
 "china's governing/_n": {'e_noun._n': "china's government"},
 'its governing/_n': {'e_noun._n': 'its government'},
 'direct governing/_n': {'e_noun._n': 'direct government'},
 'that governing/_n': {'e_noun._n': 'that government'},
 'a new governing/_n': {'e_noun._n': 'a new government'},
 'new governing/_n': {'e_noun._n': 'new government'},
 'a governing/_n': {'e_noun._n': 'a government'},
 'the governing itself/_n': {'e_noun._n': 'the government itself'},
 'your governing/_n': {'e_noun._n': 'your government'},
 'sixteenth grandchildren/_n': {'e_noun._n': 'six grandchildren'},
 'third grandchildren/_n': {'e_noun._n': 'three grandchildren'},
 'governing grants/_n': {'e_noun._n': 'government grants'},
 'the greasy/_n': {'e_noun._n': 'the grease'},
 'third great-grandchildren/_n': {'e_noun._n': 'three great-grandchildren'},
 'a greatness/_n': {'e_noun._n': 'a great'},
 'corporate greedy/_n': {'e_noun._n': 'corporate greed'},
 'the greenness/_n': {'e_noun._n': 'the green'},
 'handed grenades/_n': {'e_noun._n': 'hand grenades'},
 'shake ground/_n': {'e_noun._n': 'shaky ground'},
 'solidified ground/_n': {'e_noun._n': 'solid ground'},
 'consuming groups/_n': {'e_noun._n': 'consumer groups'},
 'third groups/_n': {'e_noun._n': 'three groups'},
 'aided groups/_n': {'e_noun._n': 'aid groups'},
 'supported groups/_n': {'e_noun._n': 'support groups'},
 'current grown/_n': {'e_noun._n': 'current growth'},
 'new grown/_n': {'e_noun._n': 'new growth'},
 'job grown/_n': {'e_noun._n': 'job growth'},
 'no grown/_n': {'e_noun._n': 'no growth'},
 'income grown/_n': {'e_noun._n': 'income growth'},
 'revenue grown/_n': {'e_noun._n': 'revenue growth'},
 'slow economic grown/_n': {'e_noun._n': 'slow economic growth'},
 'tremendous grown/_n': {'e_noun._n': 'tremendous growth'},
 'further grown/_n': {'e_noun._n': 'further growth'},
 'moderate grown/_n': {'e_noun._n': 'moderate growth'},
 'slower grown/_n': {'e_noun._n': 'slower growth'},
 "the economy's grown/_n": {'e_noun._n': "the economy's growth"},
 'earnings grown/_n': {'e_noun._n': 'earnings growth'},
 'continued grown/_n': {'e_noun._n': 'continued growth'},
 'explosive grown/_n': {'e_noun._n': 'explosive growth'},
 'economy growth/_n': {'e_noun._n': 'economic growth'},
 'modest grown/_n': {'e_noun._n': 'modest growth'},
 'personal grown/_n': {'e_noun._n': 'personal growth'},
 'long-term grown/_n': {'e_noun._n': 'long-term growth'},
 'industrial grown/_n': {'e_noun._n': 'industrial growth'},
 'faster grown/_n': {'e_noun._n': 'faster growth'},
 'gdp grown/_n': {'e_noun._n': 'gdp growth'},
 'real grown/_n': {'e_noun._n': 'real growth'},
 'strong grown/_n': {'e_noun._n': 'strong growth'},
 'big grown/_n': {'e_noun._n': 'big growth'},
 'global grown/_n': {'e_noun._n': 'global growth'},
 'steady grown/_n': {'e_noun._n': 'steady growth'},
 'such grown/_n': {'e_noun._n': 'such growth'},
 'high grown/_n': {'e_noun._n': 'high growth'},
 'urban grown/_n': {'e_noun._n': 'urban growth'},
 'annual grown/_n': {'e_noun._n': 'annual growth'},
 'sustained grown/_n': {'e_noun._n': 'sustained growth'},
 'sustainable grown/_n': {'e_noun._n': 'sustainable growth'},
 'robust grown/_n': {'e_noun._n': 'robust growth'},
 'overall grown/_n': {'e_noun._n': 'overall growth'},
 'faster economic grown/_n': {'e_noun._n': 'faster economic growth'},
 'wage grown/_n': {'e_noun._n': 'wage growth'},
 'averaged growth/_n': {'e_noun._n': 'average growth'},
 'average grown/_n': {'e_noun._n': 'average growth'},
 'productivity grown/_n': {'e_noun._n': 'productivity growth'},
 'good grown/_n': {'e_noun._n': 'good growth'},
 'slow grown/_n': {'e_noun._n': 'slow growth'},
 'employed growth/_n': {'e_noun._n': 'employment growth'},
 'employment grown/_n': {'e_noun._n': 'employment growth'},
 'highest grown/_n': {'e_noun._n': 'highest growth'},
 'sales grown/_n': {'e_noun._n': 'sales growth'},
 'fast grown/_n': {'e_noun._n': 'fast growth'},
 'future grown/_n': {'e_noun._n': 'future growth'},
 'exporting growth/_n': {'e_noun._n': 'export growth'},
 'export grown/_n': {'e_noun._n': 'export growth'},
 'more grown/_n': {'e_noun._n': 'more growth'},
 'its grown/_n': {'e_noun._n': 'its growth'},
 'rapid grown/_n': {'e_noun._n': 'rapid growth'},
 'higher grown/_n': {'e_noun._n': 'higher growth'},
 'that grown/_n': {'e_noun._n': 'that growth'},
 'double-digit grown/_n': {'e_noun._n': 'double-digit growth'},
 'our grown/_n': {'e_noun._n': 'our growth'},
 'tumor grown/_n': {'e_noun._n': 'tumor growth'},
 'their grown/_n': {'e_noun._n': 'their growth'},
 'no guaranteed/_n': {'e_noun._n': 'no guarantee'},
 'his guarding/_n': {'e_noun._n': 'his guard'},
 'their guarding/_n': {'e_noun._n': 'their guard'},
 'a point guarding/_n': {'e_noun._n': 'a point guard'},
 'your guarding/_n': {'e_noun._n': 'your guard'},
 'the point guarding/_n': {'e_noun._n': 'the point guard'},
 'the guarding/_n': {'e_noun._n': 'the guard'},
 'point guarding/_n': {'e_noun._n': 'point guard'},
 'a guarding/_n': {'e_noun._n': 'a guard'},
 'any guiding/_n': {'e_noun._n': 'any guide'},
 'our guiding/_n': {'e_noun._n': 'our guide'},
 'this guidelines/_n': {'e_noun._n': 'those guidelines'},
 'his guilty/_n': {'e_noun._n': 'his guilt'},
 'third guys/_n': {'e_noun._n': 'three guys'},
 'this guys/_n': {'e_noun._n': 'those guys'},
 'his habitual/_n': {'e_noun._n': 'his habit'},
 'the habitual/_n': {'e_noun._n': 'the habit'},
 'their habitual/_n': {'e_noun._n': 'their habit'},
 'the second half of those year/_n': {'e_noun._n': 'the second half of this year'},
 'the first half of those year/_n': {'e_noun._n': 'the first half of this year'},
 'a hammered/_n': {'e_noun._n': 'a hammer'},
 'the hammered/_n': {'e_noun._n': 'the hammer'},
 'her handed/_n': {'e_noun._n': 'her hand'},
 'their handed/_n': {'e_noun._n': 'their hand'},
 'its handed/_n': {'e_noun._n': 'its hand'},
 'the handed/_n': {'e_noun._n': 'the hand'},
 'his handed/_n': {'e_noun._n': 'his hand'},
 'the other handed/_n': {'e_noun._n': 'the other hand'},
 'your handed/_n': {'e_noun._n': 'your hand'},
 'each handed/_n': {'e_noun._n': 'each hand'},
 'my handed/_n': {'e_noun._n': 'my hand'},
 'a handling/_n': {'e_noun._n': 'a handle'},
 'computational hardware/_n': {'e_noun._n': 'computer hardware'},
 'bodily harmful/_n': {'e_noun._n': 'bodily harm'},
 'no harmful/_n': {'e_noun._n': 'no harm'},
 'physical harmful/_n': {'e_noun._n': 'physical harm'},
 'more harmful than good/_n': {'e_noun._n': 'more harm than good'},
 'any harmful/_n': {'e_noun._n': 'any harm'},
 'racial harmonious/_n': {'e_noun._n': 'racial harmony'},
 'potential healthy/_n': {'e_noun._n': 'potential health'},
 'personal healthy/_n': {'e_noun._n': 'personal health'},
 'whose healthy/_n': {'e_noun._n': 'whose health'},
 "women's healthy/_n": {'e_noun._n': "women's health"},
 'possible healthy/_n': {'e_noun._n': 'possible health'},
 "men's healthy/_n": {'e_noun._n': "men's health"},
 'poor healthy/_n': {'e_noun._n': 'poor health'},
 'my healthy/_n': {'e_noun._n': 'my health'},
 'his healthy/_n': {'e_noun._n': 'his health'},
 'chronic healthy/_n': {'e_noun._n': 'chronic health'},
 'excellent healthy/_n': {'e_noun._n': 'excellent health'},
 'long-term healthy/_n': {'e_noun._n': 'long-term health'},
 'significant healthy/_n': {'e_noun._n': 'significant health'},
 'reproductive healthy/_n': {'e_noun._n': 'reproductive health'},
 'her healthy/_n': {'e_noun._n': 'her health'},
 "children's healthy/_n": {'e_noun._n': "children's health"},
 'better healthy/_n': {'e_noun._n': 'better health'},
 'economic healthy/_n': {'e_noun._n': 'economic health'},
 'adverse healthy/_n': {'e_noun._n': 'adverse health'},
 'major healthy/_n': {'e_noun._n': 'major health'},
 'local healthy/_n': {'e_noun._n': 'local health'},
 'their healthy/_n': {'e_noun._n': 'their health'},
 'your healthy/_n': {'e_noun._n': 'your health'},
 'new healthy/_n': {'e_noun._n': 'new health'},
 'serious healthy/_n': {'e_noun._n': 'serious health'},
 'health food/_n': {'e_noun._n': 'healthy food'},
 'the heaping/_n': {'e_noun._n': 'the heap'},
 'confirmed hearings/_n': {'e_noun._n': 'confirmation hearings'},
 'some heated/_n': {'e_noun._n': 'some heat'},
 'no heated/_n': {'e_noun._n': 'no heat'},
 'more heated/_n': {'e_noun._n': 'more heat'},
 'medium-high heated/_n': {'e_noun._n': 'medium-high heat'},
 'the summer heated/_n': {'e_noun._n': 'the summer heat'},
 'heated through/_n': {'e_noun._n': 'heat through'},
 'medium heated/_n': {'e_noun._n': 'medium heat'},
 'extreme heated/_n': {'e_noun._n': 'extreme heat'},
 'that heated/_n': {'e_noun._n': 'that heat'},
 'summer heated/_n': {'e_noun._n': 'summer heat'},
 'low heated/_n': {'e_noun._n': 'low heat'},
 'moderate heated/_n': {'e_noun._n': 'moderate heat'},
 'high heated/_n': {'e_noun._n': 'high heat'},
 'no helpful/_n': {'e_noun._n': 'no help'},
 'outside helpful/_n': {'e_noun._n': 'outside help'},
 'such helpful/_n': {'e_noun._n': 'such help'},
 'our helpful/_n': {'e_noun._n': 'our help'},
 'temporary helpful/_n': {'e_noun._n': 'temporary help'},
 "god's helpful/_n": {'e_noun._n': "god's help"},
 'some helpful/_n': {'e_noun._n': 'some help'},
 'much helpful/_n': {'e_noun._n': 'much help'},
 'more helpful/_n': {'e_noun._n': 'more help'},
 'governing help/_n': {'e_noun._n': 'government help'},
 'government helpful/_n': {'e_noun._n': 'government help'},
 'their helpful/_n': {'e_noun._n': 'their help'},
 'your helpful/_n': {'e_noun._n': 'your help'},
 'little helpful/_n': {'e_noun._n': 'little help'},
 'any helpful/_n': {'e_noun._n': 'any help'},
 'professional helpful/_n': {'e_noun._n': 'professional help'},
 'extra helpful/_n': {'e_noun._n': 'extra help'},
 'medical helpful/_n': {'e_noun._n': 'medical help'},
 'financial helpful/_n': {'e_noun._n': 'financial help'},
 'legal helpful/_n': {'e_noun._n': 'legal help'},
 'his helpful/_n': {'e_noun._n': 'his help'},
 'a nation hero/_n': {'e_noun._n': 'a national hero'},
 'the hierarchical/_n': {'e_noun._n': 'the hierarchy'},
 'the highlighted/_n': {'e_noun._n': 'the highlight'},
 'a highlighted/_n': {'e_noun._n': 'a highlight'},
 'taxable hikes/_n': {'e_noun._n': 'tax hikes'},
 "the company's historic/_n": {'e_noun._n': "the company's history"},
 'olympic historic/_n': {'e_noun._n': 'olympic history'},
 'that historic/_n': {'e_noun._n': 'that history'},
 'movie historic/_n': {'e_noun._n': 'movie history'},
 "the nation's historic/_n": {'e_noun._n': "the nation's history"},
 'medical historic/_n': {'e_noun._n': 'medical history'},
 'recent historic/_n': {'e_noun._n': 'recent history'},
 'recorded historic/_n': {'e_noun._n': 'recorded history'},
 'political historic/_n': {'e_noun._n': 'political history'},
 "the country's historic/_n": {'e_noun._n': "the country's history"},
 'military historic/_n': {'e_noun._n': 'military history'},
 'television historic/_n': {'e_noun._n': 'television history'},
 'whose historic/_n': {'e_noun._n': 'whose history'},
 'school historic/_n': {'e_noun._n': 'school history'},
 'a long historic/_n': {'e_noun._n': 'a long history'},
 'black historic/_n': {'e_noun._n': 'black history'},
 'family historic/_n': {'e_noun._n': 'family history'},
 'sports historic/_n': {'e_noun._n': 'sports history'},
 'hollywood historic/_n': {'e_noun._n': 'hollywood history'},
 "the city's historic/_n": {'e_noun._n': "the city's history"},
 'local historic/_n': {'e_noun._n': 'local history'},
 "america's historic/_n": {'e_noun._n': "america's history"},
 'our historic/_n': {'e_noun._n': 'our history'},
 'this hits/_n': {'e_noun._n': 'those hits'},
 'third hits/_n': {'e_noun._n': 'three hits'},
 'specialist holiday/_n': {'e_noun._n': 'special holiday'},
 'his honest/_n': {'e_noun._n': 'his honesty'},
 'a hooked/_n': {'e_noun._n': 'a hook'},
 'little hopeful/_n': {'e_noun._n': 'little hope'},
 'some hopeful/_n': {'e_noun._n': 'some hope'},
 'no hopeful/_n': {'e_noun._n': 'no hope'},
 'their hopeful/_n': {'e_noun._n': 'their hope'},
 'our hopeful/_n': {'e_noun._n': 'our hope'},
 'my hopeful/_n': {'e_noun._n': 'my hope'},
 'that hopeful/_n': {'e_noun._n': 'that hope'},
 'his hopeful/_n': {'e_noun._n': 'his hope'},
 'workless hours/_n': {'e_noun._n': 'work hours'},
 'an hourly later/_n': {'e_noun._n': 'an hour later'},
 'nearly an hourly/_n': {'e_noun._n': 'nearly an hour'},
 'less than an hourly/_n': {'e_noun._n': 'less than an hour'},
 'another hourly/_n': {'e_noun._n': 'another hour'},
 'the 11th hourly/_n': {'e_noun._n': 'the 11th hour'},
 'every hourly/_n': {'e_noun._n': 'every hour'},
 'kilowatt hourly/_n': {'e_noun._n': 'kilowatt hour'},
 'about an hourly/_n': {'e_noun._n': 'about an hour'},
 'the first hourly/_n': {'e_noun._n': 'the first hour'},
 'that hourly/_n': {'e_noun._n': 'that hour'},
 'more than an hourly/_n': {'e_noun._n': 'more than an hour'},
 'his housed/_n': {'e_noun._n': 'his house'},
 'every housed/_n': {'e_noun._n': 'every house'},
 'that housed/_n': {'e_noun._n': 'that house'},
 "someone's housed/_n": {'e_noun._n': "someone's house"},
 'a new housed/_n': {'e_noun._n': 'a new house'},
 'their housed/_n': {'e_noun._n': 'their house'},
 "a friend's housed/_n": {'e_noun._n': "a friend's house"},
 'whose housed/_n': {'e_noun._n': 'whose house'},
 'another housed/_n': {'e_noun._n': 'another house'},
 'the same housed/_n': {'e_noun._n': 'the same house'},
 'world hungry/_n': {'e_noun._n': 'world hunger'},
 'no hurried/_n': {'e_noun._n': 'no hurry'},
 'this ideas/_n': {'e_noun._n': 'those ideas'},
 'personal identifiable/_n': {'e_noun._n': 'personal identification'},
 'nation identity/_n': {'e_noun._n': 'national identity'},
 'his ideological/_n': {'e_noun._n': 'his ideology'},
 'political ideological/_n': {'e_noun._n': 'political ideology'},
 'their ill/_n': {'e_noun._n': 'their illness'},
 'his ill/_n': {'e_noun._n': 'his illness'},
 'a long ill/_n': {'e_noun._n': 'a long illness'},
 'serious ill/_n': {'e_noun._n': 'serious illness'},
 'the illustrative/_n': {'e_noun._n': 'the illustration'},
 'this images/_n': {'e_noun._n': 'those images'},
 'his imaginative/_n': {'e_noun._n': 'his imagination'},
 'her imaginative/_n': {'e_noun._n': 'her imagination'},
 'your imaginative/_n': {'e_noun._n': 'your imagination'},
 'my imaginative/_n': {'e_noun._n': 'my imagination'},
 'an illegal immigration/_n': {'e_noun._n': 'an illegal immigrant'},
 'little impacted/_n': {'e_noun._n': 'little impact'},
 'much impacted/_n': {'e_noun._n': 'much impact'},
 'their impacted/_n': {'e_noun._n': 'their impact'},
 'an impacted/_n': {'e_noun._n': 'an impact'},
 'a major impacted/_n': {'e_noun._n': 'a major impact'},
 'a significant impacted/_n': {'e_noun._n': 'a significant impact'},
 'environmental impacted/_n': {'e_noun._n': 'environmental impact'},
 'no impacted/_n': {'e_noun._n': 'no impact'},
 'the most impacted/_n': {'e_noun._n': 'the most impact'},
 'the impacted/_n': {'e_noun._n': 'the impact'},
 'environment impact/_n': {'e_noun._n': 'environmental impact'},
 'its impacted/_n': {'e_noun._n': 'its impact'},
 'any impacted/_n': {'e_noun._n': 'any impact'},
 'his impacted/_n': {'e_noun._n': 'his impact'},
 'its implemented/_n': {'e_noun._n': 'its implementation'},
 'the implicated/_n': {'e_noun._n': 'the implication'},
 'their important/_n': {'e_noun._n': 'their importance'},
 'the most importance/_n': {'e_noun._n': 'the most important'},
 'no improving/_n': {'e_noun._n': 'no improvement'},
 'home improving/_n': {'e_noun._n': 'home improvement'},
 'taxable incentives/_n': {'e_noun._n': 'tax incentives'},
 'another incidence/_n': {'e_noun._n': 'another incident'},
 'one incidence/_n': {'e_noun._n': 'one incident'},
 'this incidents/_n': {'e_noun._n': 'those incidents'},
 'interesting income/_n': {'e_noun._n': 'interest income'},
 'the inconvenient/_n': {'e_noun._n': 'the inconvenience'},
 'any inconvenient/_n': {'e_noun._n': 'any inconvenience'},
 'no increasing/_n': {'e_noun._n': 'no increase'},
 'the price increasing/_n': {'e_noun._n': 'the price increase'},
 'this increases/_n': {'e_noun._n': 'those increases'},
 'that increasing/_n': {'e_noun._n': 'that increase'},
 'the taxable increase/_n': {'e_noun._n': 'the tax increase'},
 'the tax increasing/_n': {'e_noun._n': 'the tax increase'},
 'taxable increases/_n': {'e_noun._n': 'tax increases'},
 'another increasing/_n': {'e_noun._n': 'another increase'},
 'any increasing/_n': {'e_noun._n': 'any increase'},
 'her independent/_n': {'e_noun._n': 'her independence'},
 'his independent/_n': {'e_noun._n': 'his independence'},
 'its independent/_n': {'e_noun._n': 'its independence'},
 'stock indexed/_n': {'e_noun._n': 'stock index'},
 'an indexed/_n': {'e_noun._n': 'an index'},
 'the main indexed/_n': {'e_noun._n': 'the main index'},
 'every indicative/_n': {'e_noun._n': 'every indication'},
 'no indicative/_n': {'e_noun._n': 'no indication'},
 'an indicative/_n': {'e_noun._n': 'an indication'},
 'any indicative/_n': {'e_noun._n': 'any indication'},
 'every individuality/_n': {'e_noun._n': 'every individual'},
 'an individuality/_n': {'e_noun._n': 'an individual'},
 'each individuality/_n': {'e_noun._n': 'each individual'},
 'the oil industrial/_n': {'e_noun._n': 'the oil industry'},
 'the filmed industry/_n': {'e_noun._n': 'the film industry'},
 'the film industrial/_n': {'e_noun._n': 'the film industry'},
 'the drug industrial/_n': {'e_noun._n': 'the drug industry'},
 'private industrial/_n': {'e_noun._n': 'private industry'},
 'the advertising industrial/_n': {'e_noun._n': 'the advertising industry'},
 'the aerospace industrial/_n': {'e_noun._n': 'the aerospace industry'},
 'the entertaining industry/_n': {'e_noun._n': 'the entertainment industry'},
 'the entertainment industrial/_n': {'e_noun._n': 'the entertainment industry'},
 'the pharmaceutical industrial/_n': {'e_noun._n': 'the pharmaceutical industry'},
 'the travelled industry/_n': {'e_noun._n': 'the travel industry'},
 'the travel industrial/_n': {'e_noun._n': 'the travel industry'},
 'the oil and gas industrial/_n': {'e_noun._n': 'the oil and gas industry'},
 'insured industry/_n': {'e_noun._n': 'insurance industry'},
 'insurance industrial/_n': {'e_noun._n': 'insurance industry'},
 'the fashionable industry/_n': {'e_noun._n': 'the fashion industry'},
 'the fashion industrial/_n': {'e_noun._n': 'the fashion industry'},
 'the publishing industrial/_n': {'e_noun._n': 'the publishing industry'},
 'the mining industrial/_n': {'e_noun._n': 'the mining industry'},
 'the industrial as a whole/_n': {'e_noun._n': 'the industry as a whole'},
 'the electronics industrial/_n': {'e_noun._n': 'the electronics industry'},
 'the tourism industrial/_n': {'e_noun._n': 'the tourism industry'},
 'that industrial/_n': {'e_noun._n': 'that industry'},
 'new industrial/_n': {'e_noun._n': 'new industry'},
 'our industrial/_n': {'e_noun._n': 'our industry'},
 'the auto industrial/_n': {'e_noun._n': 'the auto industry'},
 "the computational industry's/_n": {'e_noun._n': "the computer industry's"},
 'the record industrial/_n': {'e_noun._n': 'the record industry'},
 'the entire industrial/_n': {'e_noun._n': 'the entire industry'},
 'the energetic industry/_n': {'e_noun._n': 'the energy industry'},
 'the energy industrial/_n': {'e_noun._n': 'the energy industry'},
 'pharmaceutical industrial/_n': {'e_noun._n': 'pharmaceutical industry'},
 'their industrial/_n': {'e_noun._n': 'their industry'},
 'the semiconductor industrial/_n': {'e_noun._n': 'the semiconductor industry'},
 'the telecommunications industrial/_n': {'e_noun._n': 'the telecommunications industry'},
 'the pc industrial/_n': {'e_noun._n': 'the pc industry'},
 'the defense industrial/_n': {'e_noun._n': 'the defense industry'},
 'the insured industry/_n': {'e_noun._n': 'the insurance industry'},
 'the insurance industrial/_n': {'e_noun._n': 'the insurance industry'},
 'banking industrial/_n': {'e_noun._n': 'banking industry'},
 'the healthy care industry/_n': {'e_noun._n': 'the health care industry'},
 'the health careful industry/_n': {'e_noun._n': 'the health care industry'},
 'the health care industrial/_n': {'e_noun._n': 'the health care industry'},
 'the aviation industrial/_n': {'e_noun._n': 'the aviation industry'},
 'any industrial/_n': {'e_noun._n': 'any industry'},
 'the hotel industrial/_n': {'e_noun._n': 'the hotel industry'},
 'the musical industry/_n': {'e_noun._n': 'the music industry'},
 'the music industrial/_n': {'e_noun._n': 'the music industry'},
 'the software industrial/_n': {'e_noun._n': 'the software industry'},
 'the automobile industrial/_n': {'e_noun._n': 'the automobile industry'},
 'the cigarette industrial/_n': {'e_noun._n': 'the cigarette industry'},
 'the financial services industrial/_n': {'e_noun._n': 'the financial services industry'},
 'recording industrial/_n': {'e_noun._n': 'recording industry'},
 'the whole industrial/_n': {'e_noun._n': 'the whole industry'},
 'the airline industrial/_n': {'e_noun._n': 'the airline industry'},
 'the financial industrial/_n': {'e_noun._n': 'the financial industry'},
 'the computational industry/_n': {'e_noun._n': 'the computer industry'},
 'the computer industrial/_n': {'e_noun._n': 'the computer industry'},
 'the nuclear industrial/_n': {'e_noun._n': 'the nuclear industry'},
 'the high-tech industrial/_n': {'e_noun._n': 'the high-tech industry'},
 'the technological industry/_n': {'e_noun._n': 'the technology industry'},
 'the technology industrial/_n': {'e_noun._n': 'the technology industry'},
 'the retail industrial/_n': {'e_noun._n': 'the retail industry'},
 'the recording industrial/_n': {'e_noun._n': 'the recording industry'},
 'the communications industrial/_n': {'e_noun._n': 'the communications industry'},
 'the tv industrial/_n': {'e_noun._n': 'the tv industry'},
 'your industrial/_n': {'e_noun._n': 'your industry'},
 'the personal computational industry/_n': {'e_noun._n': 'the personal computer industry'},
 'the personal computer industrial/_n': {'e_noun._n': 'the personal computer industry'},
 'the steel industrial/_n': {'e_noun._n': 'the steel industry'},
 'the constructive industry/_n': {'e_noun._n': 'the construction industry'},
 'the construction industrial/_n': {'e_noun._n': 'the construction industry'},
 'the automotive industrial/_n': {'e_noun._n': 'the automotive industry'},
 'the television industrial/_n': {'e_noun._n': 'the television industry'},
 'the banking industrial/_n': {'e_noun._n': 'the banking industry'},
 'that influential/_n': {'e_noun._n': 'that influence'},
 'whose influential/_n': {'e_noun._n': 'whose influence'},
 'its influential/_n': {'e_noun._n': 'its influence'},
 'their influential/_n': {'e_noun._n': 'their influence'},
 'her influential/_n': {'e_noun._n': 'her influence'},
 'political influential/_n': {'e_noun._n': 'political influence'},
 'further informing/_n': {'e_noun._n': 'further information'},
 'some informing/_n': {'e_noun._n': 'some information'},
 'travelled information/_n': {'e_noun._n': 'travel information'},
 'travel informing/_n': {'e_noun._n': 'travel information'},
 'no informing/_n': {'e_noun._n': 'no information'},
 'general informing/_n': {'e_noun._n': 'general information'},
 'secret informing/_n': {'e_noun._n': 'secret information'},
 'confidential informing/_n': {'e_noun._n': 'confidential information'},
 'more informing/_n': {'e_noun._n': 'more information'},
 'product informing/_n': {'e_noun._n': 'product information'},
 'any informing/_n': {'e_noun._n': 'any information'},
 'new informing/_n': {'e_noun._n': 'new information'},
 'important informing/_n': {'e_noun._n': 'important information'},
 'healthy information/_n': {'e_noun._n': 'health information'},
 'health informing/_n': {'e_noun._n': 'health information'},
 'its informing/_n': {'e_noun._n': 'its information'},
 'what informing/_n': {'e_noun._n': 'what information'},
 'detail information/_n': {'e_noun._n': 'detailed information'},
 'all the informing/_n': {'e_noun._n': 'all the information'},
 'his informing/_n': {'e_noun._n': 'his information'},
 'informing on the internet/_n': {'e_noun._n': 'information on the internet'},
 'enough informing/_n': {'e_noun._n': 'enough information'},
 'that informing/_n': {'e_noun._n': 'that information'},
 'customer informing/_n': {'e_noun._n': 'customer information'},
 'their informing/_n': {'e_noun._n': 'their information'},
 'so-called informing/_n': {'e_noun._n': 'so-called information'},
 'all informing/_n': {'e_noun._n': 'all information'},
 'useful informing/_n': {'e_noun._n': 'useful information'},
 'good informing/_n': {'e_noun._n': 'good information'},
 'your informing/_n': {'e_noun._n': 'your information'},
 'online informing/_n': {'e_noun._n': 'online information'},
 'little informing/_n': {'e_noun._n': 'little information'},
 'such informing/_n': {'e_noun._n': 'such information'},
 'specific informing/_n': {'e_noun._n': 'specific information'},
 'financial informing/_n': {'e_noun._n': 'financial information'},
 'the new informing/_n': {'e_noun._n': 'the new information'},
 'additional informing/_n': {'e_noun._n': 'additional information'},
 'detailed informing/_n': {'e_noun._n': 'detailed information'},
 'user information/_n': {'e_noun._n': 'useful information'},
 'false informing/_n': {'e_noun._n': 'false information'},
 'sensitive informing/_n': {'e_noun._n': 'sensitive information'},
 'other informing/_n': {'e_noun._n': 'other information'},
 'informing about/_n': {'e_noun._n': 'information about'},
 'genetic informing/_n': {'e_noun._n': 'genetic information'},
 'smoking inhalation/_n': {'e_noun._n': 'smoke inhalation'},
 'this initiatives/_n': {'e_noun._n': 'those initiatives'},
 'a knee injured/_n': {'e_noun._n': 'a knee injury'},
 'an ankle injured/_n': {'e_noun._n': 'an ankle injury'},
 'serious injured/_n': {'e_noun._n': 'serious injury'},
 'a foot injured/_n': {'e_noun._n': 'a foot injury'},
 'that injured/_n': {'e_noun._n': 'that injury'},
 'society injustice/_n': {'e_noun._n': 'social injustice'},
 'the inky/_n': {'e_noun._n': 'the ink'},
 'black inky/_n': {'e_noun._n': 'black ink'},
 'dead row inmates/_n': {'e_noun._n': 'death row inmates'},
 'their inquiring/_n': {'e_noun._n': 'their inquiry'},
 'its inquiring/_n': {'e_noun._n': 'its inquiry'},
 'his inquiring/_n': {'e_noun._n': 'his inquiry'},
 'scientific inquiring/_n': {'e_noun._n': 'scientific inquiry'},
 'industrial insiders/_n': {'e_noun._n': 'industry insiders'},
 'inside trading/_n': {'e_noun._n': 'insider trading'},
 'the insightful/_n': {'e_noun._n': 'the insight'},
 'an inspected/_n': {'e_noun._n': 'an inspection'},
 'closer inspected/_n': {'e_noun._n': 'closer inspection'},
 'the inspected/_n': {'e_noun._n': 'the inspection'},
 'this instances/_n': {'e_noun._n': 'those instances'},
 'his institutional/_n': {'e_noun._n': 'his institute'},
 'finance institutions/_n': {'e_noun._n': 'financial institutions'},
 'this institutions/_n': {'e_noun._n': 'those institutions'},
 'education institutions/_n': {'e_noun._n': 'educational institutions'},
 'public instructive/_n': {'e_noun._n': 'public instruction'},
 'the instructive/_n': {'e_noun._n': 'the instruction'},
 'precise instrument/_n': {'e_noun._n': 'precision instrument'},
 'precision instrumental/_n': {'e_noun._n': 'precision instrument'},
 'musician instruments/_n': {'e_noun._n': 'musical instruments'},
 'his instrumental/_n': {'e_noun._n': 'his instrument'},
 'music instruments/_n': {'e_noun._n': 'musical instruments'},
 'the insulting/_n': {'e_noun._n': 'the insult'},
 'no insured/_n': {'e_noun._n': 'no insurance'},
 'earthquake insured/_n': {'e_noun._n': 'earthquake insurance'},
 'private insured/_n': {'e_noun._n': 'private insurance'},
 'car insured/_n': {'e_noun._n': 'car insurance'},
 'their insured/_n': {'e_noun._n': 'their insurance'},
 'healthy insurers/_n': {'e_noun._n': 'health insurers'},
 'the integrate/_n': {'e_noun._n': 'the integration'},
 'economy integration/_n': {'e_noun._n': 'economic integration'},
 'racial integrate/_n': {'e_noun._n': 'racial integration'},
 'their intelligent/_n': {'e_noun._n': 'their intelligence'},
 'western intelligent/_n': {'e_noun._n': 'western intelligence'},
 'foreign intelligent/_n': {'e_noun._n': 'foreign intelligence'},
 'senior intelligent/_n': {'e_noun._n': 'senior intelligence'},
 'american intelligent/_n': {'e_noun._n': 'american intelligence'},
 'its intense/_n': {'e_noun._n': 'its intensity'},
 'society interaction/_n': {'e_noun._n': 'social interaction'},
 'that interesting/_n': {'e_noun._n': 'that interest'},
 'no interesting/_n': {'e_noun._n': 'no interest'},
 'any interesting/_n': {'e_noun._n': 'any interest'},
 'her interesting/_n': {'e_noun._n': 'her interest'},
 'little interesting/_n': {'e_noun._n': 'little interest'},
 'great interesting/_n': {'e_noun._n': 'great interest'},
 'higher interesting/_n': {'e_noun._n': 'higher interest'},
 'our interesting/_n': {'e_noun._n': 'our interest'},
 'lower interesting/_n': {'e_noun._n': 'lower interest'},
 'national interesting/_n': {'e_noun._n': 'national interest'},
 'its interesting/_n': {'e_noun._n': 'its interest'},
 'interesting in/_n': {'e_noun._n': 'interest in'},
 'innerterest inner/_n': {'e_noun._n': 'interest in'},
 'much interesting/_n': {'e_noun._n': 'much interest'},
 'general interesting/_n': {'e_noun._n': 'general interest'},
 'their interesting/_n': {'e_noun._n': 'their interest'},
 'the national interesting/_n': {'e_noun._n': 'the national interest'},
 'particular interesting/_n': {'e_noun._n': 'particular interest'},
 'my interesting/_n': {'e_noun._n': 'my interest'},
 'his interesting/_n': {'e_noun._n': 'his interest'},
 'net interesting/_n': {'e_noun._n': 'net interest'},
 'your interesting/_n': {'e_noun._n': 'your interest'},
 'governing interference/_n': {'e_noun._n': 'government interference'},
 'a white housed intern/_n': {'e_noun._n': 'a white house intern'},
 'military intervening/_n': {'e_noun._n': 'military intervention'},
 'governing intervention/_n': {'e_noun._n': 'government intervention'},
 'government intervening/_n': {'e_noun._n': 'government intervention'},
 'early intervening/_n': {'e_noun._n': 'early intervention'},
 'divine intervening/_n': {'e_noun._n': 'divine intervention'},
 'an invented/_n': {'e_noun._n': 'an invention'},
 'the invented/_n': {'e_noun._n': 'the invention'},
 'his invented/_n': {'e_noun._n': 'his invention'},
 'any investigative/_n': {'e_noun._n': 'any investigation'},
 'further investigative/_n': {'e_noun._n': 'further investigation'},
 'our investigative/_n': {'e_noun._n': 'our investigation'},
 'that investigative/_n': {'e_noun._n': 'that investigation'},
 'criminal investigative/_n': {'e_noun._n': 'criminal investigation'},
 'their investigative/_n': {'e_noun._n': 'their investigation'},
 'the criminal investigative/_n': {'e_noun._n': 'the criminal investigation'},
 'governing investigators/_n': {'e_noun._n': 'government investigators'},
 'valuable investors/_n': {'e_noun._n': 'value investors'},
 'their involved/_n': {'e_noun._n': 'their involvement'},
 'parental involved/_n': {'e_noun._n': 'parental involvement'},
 'its involved/_n': {'e_noun._n': 'its involvement'},
 'his involved/_n': {'e_noun._n': 'his involvement'},
 'its isolate/_n': {'e_noun._n': 'its isolation'},
 'immigrant issues/_n': {'e_noun._n': 'immigration issues'},
 'a major issued/_n': {'e_noun._n': 'a major issue'},
 'another issued/_n': {'e_noun._n': 'another issue'},
 'each issued/_n': {'e_noun._n': 'each issue'},
 'an issued/_n': {'e_noun._n': 'an issue'},
 'the real issued/_n': {'e_noun._n': 'the real issue'},
 'this issues/_n': {'e_noun._n': 'those issues'},
 'every issued/_n': {'e_noun._n': 'every issue'},
 'private issues/_n': {'e_noun._n': 'privacy issues'},
 'energetic issues/_n': {'e_noun._n': 'energy issues'},
 'society issues/_n': {'e_noun._n': 'social issues'},
 'one issued/_n': {'e_noun._n': 'one issue'},
 'the new issued/_n': {'e_noun._n': 'the new issue'},
 'safe issues/_n': {'e_noun._n': 'safety issues'},
 'healthy issues/_n': {'e_noun._n': 'health issues'},
 'the main issued/_n': {'e_noun._n': 'the main issue'},
 'the same issued/_n': {'e_noun._n': 'the same issue'},
 'tradable issues/_n': {'e_noun._n': 'trade issues'},
 'taxable issues/_n': {'e_noun._n': 'tax issues'},
 'secure issues/_n': {'e_noun._n': 'security issues'},
 'no issued/_n': {'e_noun._n': 'no issue'},
 'issued here/_n': {'e_noun._n': 'issue here'},
 'any issued/_n': {'e_noun._n': 'any issue'},
 'not an issued/_n': {'e_noun._n': 'not an issue'},
 'that issued/_n': {'e_noun._n': 'that issue'},
 'a political issued/_n': {'e_noun._n': 'a political issue'},
 'not the issued/_n': {'e_noun._n': 'not the issue'},
 'the first issued/_n': {'e_noun._n': 'the first issue'},
 'this items/_n': {'e_noun._n': 'those items'},
 'specialist items/_n': {'e_noun._n': 'special items'},
 'golden jewelry/_n': {'e_noun._n': 'gold jewelry'},
 'this jobs/_n': {'e_noun._n': 'those jobs'},
 'losing jobs/_n': {'e_noun._n': 'lost jobs'},
 'a join/_n': {'e_noun._n': 'a joint'},
 'the join/_n': {'e_noun._n': 'the joint'},
 'the journal scientific/_n': {'e_noun._n': 'the journal science'},
 'the journal of the american medical associate/_n': {'e_noun._n': 'the journal of the american medical association'},
 'the journal natural/_n': {'e_noun._n': 'the journal nature'},
 'third judges/_n': {'e_noun._n': 'three judges'},
 'their judged/_n': {'e_noun._n': 'their judgment'},
 'that judged/_n': {'e_noun._n': 'that judgment'},
 'good judged/_n': {'e_noun._n': 'good judgment'},
 'a judged/_n': {'e_noun._n': 'a judgment'},
 'bad judged/_n': {'e_noun._n': 'bad judgment'},
 'poor judged/_n': {'e_noun._n': 'poor judgment'},
 'his judged/_n': {'e_noun._n': 'his judgment'},
 'my judged/_n': {'e_noun._n': 'my judgment'},
 'lemon juicy/_n': {'e_noun._n': 'lemon juice'},
 'fruit juicy/_n': {'e_noun._n': 'fruit juice'},
 'apple juicy/_n': {'e_noun._n': 'apple juice'},
 'society justice/_n': {'e_noun._n': 'social justice'},
 'computational keyboards/_n': {'e_noun._n': 'computer keyboards'},
 'this kids/_n': {'e_noun._n': 'those kids'},
 'third kids/_n': {'e_noun._n': 'three kids'},
 'one kindness/_n': {'e_noun._n': 'one kind'},
 'some kindness/_n': {'e_noun._n': 'some kind'},
 'every kindness/_n': {'e_noun._n': 'every kind'},
 'kindness of/_n': {'e_noun._n': 'kind of'},
 'any kindness/_n': {'e_noun._n': 'any kind'},
 'a kissing/_n': {'e_noun._n': 'a kiss'},
 'the knotted/_n': {'e_noun._n': 'the knot'},
 'a knotted/_n': {'e_noun._n': 'a knot'},
 'his labeled/_n': {'e_noun._n': 'his label'},
 'the labeled/_n': {'e_noun._n': 'the label'},
 'private labeled/_n': {'e_noun._n': 'private label'},
 'a labeled/_n': {'e_noun._n': 'a label'},
 'that labeled/_n': {'e_noun._n': 'that label'},
 'lacking thereof/_n': {'e_noun._n': 'lack thereof'},
 'the lacking/_n': {'e_noun._n': 'the lack'},
 'a lacking/_n': {'e_noun._n': 'a lack'},
 'its landed/_n': {'e_noun._n': 'its land'},
 'our landed/_n': {'e_noun._n': 'our land'},
 'his landed/_n': {'e_noun._n': 'his land'},
 'private landed/_n': {'e_noun._n': 'private land'},
 'public landed/_n': {'e_noun._n': 'public land'},
 'state landed/_n': {'e_noun._n': 'state land'},
 'undeveloped landed/_n': {'e_noun._n': 'undeveloped land'},
 'their landed/_n': {'e_noun._n': 'their land'},
 'some landed/_n': {'e_noun._n': 'some land'},
 'that landed/_n': {'e_noun._n': 'that land'},
 'more landed/_n': {'e_noun._n': 'more land'},
 'a landed/_n': {'e_noun._n': 'a land'},
 'memorial lane/_n': {'e_noun._n': 'memory lane'},
 'its lasting/_n': {'e_noun._n': 'its last'},
 'a laughable/_n': {'e_noun._n': 'a laugh'},
 'her laughable/_n': {'e_noun._n': 'her laugh'},
 'the state lawful/_n': {'e_noun._n': 'the state law'},
 'constitutional lawful/_n': {'e_noun._n': 'constitutional law'},
 'british lawful/_n': {'e_noun._n': 'british law'},
 'the new lawful/_n': {'e_noun._n': 'the new law'},
 'federal lawful/_n': {'e_noun._n': 'federal law'},
 'current lawful/_n': {'e_noun._n': 'current law'},
 'immigrant laws/_n': {'e_noun._n': 'immigration laws'},
 'a new lawful/_n': {'e_noun._n': 'a new law'},
 'japanese lawful/_n': {'e_noun._n': 'japanese law'},
 'the current lawful/_n': {'e_noun._n': 'the current law'},
 'islamic lawful/_n': {'e_noun._n': 'islamic law'},
 'german lawful/_n': {'e_noun._n': 'german law'},
 'that lawful/_n': {'e_noun._n': 'that law'},
 'antitrust lawful/_n': {'e_noun._n': 'antitrust law'},
 'the old lawful/_n': {'e_noun._n': 'the old law'},
 'jewish lawful/_n': {'e_noun._n': 'jewish law'},
 'patent lawful/_n': {'e_noun._n': 'patent law'},
 'this laws/_n': {'e_noun._n': 'those laws'},
 'state lawful/_n': {'e_noun._n': 'state law'},
 'local lawful/_n': {'e_noun._n': 'local law'},
 'private laws/_n': {'e_noun._n': 'privacy laws'},
 'church lawful/_n': {'e_noun._n': 'church law'},
 'any lawful/_n': {'e_noun._n': 'any law'},
 'such a lawful/_n': {'e_noun._n': 'such a law'},
 'existing lawful/_n': {'e_noun._n': 'existing law'},
 'new lawful/_n': {'e_noun._n': 'new law'},
 'this lawyers/_n': {'e_noun._n': 'those lawyers'},
 'one layered/_n': {'e_noun._n': 'one layer'},
 'oppositional leaders/_n': {'e_noun._n': 'opposition leaders'},
 'her leader/_n': {'e_noun._n': 'her lead'},
 'a new lead/_n': {'e_noun._n': 'a new leader'},
 'nation leaders/_n': {'e_noun._n': 'national leaders'},
 'governing leaders/_n': {'e_noun._n': 'government leaders'},
 'the leafy/_n': {'e_noun._n': 'the leaf'},
 'that legislative/_n': {'e_noun._n': 'that legislation'},
 'similar legislative/_n': {'e_noun._n': 'similar legislation'},
 'any legislative/_n': {'e_noun._n': 'any legislation'},
 'new legislative/_n': {'e_noun._n': 'new legislation'},
 'federal legislative/_n': {'e_noun._n': 'federal legislation'},
 "arm's lengthy/_n": {'e_noun._n': "arm's length"},
 'any lengthy of time/_n': {'e_noun._n': 'any length of time'},
 'any length of timeless/_n': {'e_noun._n': 'any length of time'},
 'its lengthy/_n': {'e_noun._n': 'its length'},
 'this lessons/_n': {'e_noun._n': 'those lessons'},
 'this letters/_n': {'e_noun._n': 'those letters'},
 'difference levels/_n': {'e_noun._n': 'different levels'},
 'third levels/_n': {'e_noun._n': 'three levels'},
 'tradable liberalization/_n': {'e_noun._n': 'trade liberalization'},
 'individual liberal/_n': {'e_noun._n': 'individual liberty'},
 'a lying/_n': {'e_noun._n': 'a lie'},
 'society life/_n': {'e_noun._n': 'social life'},
 'reality life/_n': {'e_noun._n': 'real life'},
 'their day lives/_n': {'e_noun._n': 'their daily lives'},
 'life on earthy/_n': {'e_noun._n': 'life on earth'},
 'all likely/_n': {'e_noun._n': 'all likelihood'},
 'the debt limited/_n': {'e_noun._n': 'the debt limit'},
 'that limited/_n': {'e_noun._n': 'that limit'},
 'no limited/_n': {'e_noun._n': 'no limit'},
 'this limits/_n': {'e_noun._n': 'those limits'},
 'its lined/_n': {'e_noun._n': 'its line'},
 'a fine lined/_n': {'e_noun._n': 'a fine line'},
 'a phone lined/_n': {'e_noun._n': 'a phone line'},
 'our lined/_n': {'e_noun._n': 'our line'},
 'powerful lines/_n': {'e_noun._n': 'power lines'},
 'a straight lined/_n': {'e_noun._n': 'a straight line'},
 'transmissive lines/_n': {'e_noun._n': 'transmission lines'},
 'another lined/_n': {'e_noun._n': 'another line'},
 'the lined/_n': {'e_noun._n': 'the line'},
 'this lines/_n': {'e_noun._n': 'those lines'},
 'his lined/_n': {'e_noun._n': 'his line'},
 'that lined/_n': {'e_noun._n': 'that line'},
 'every lined/_n': {'e_noun._n': 'every line'},
 'the new lined/_n': {'e_noun._n': 'the new line'},
 'its product lined/_n': {'e_noun._n': 'its product line'},
 'the lined of duty/_n': {'e_noun._n': 'the line of duty'},
 'a lined/_n': {'e_noun._n': 'a line'},
 'my lined/_n': {'e_noun._n': 'my line'},
 'the blue lined/_n': {'e_noun._n': 'the blue line'},
 'that linked/_n': {'e_noun._n': 'that link'},
 'the linked/_n': {'e_noun._n': 'the link'},
 'a linked/_n': {'e_noun._n': 'a link'},
 'no linked/_n': {'e_noun._n': 'no link'},
 'our listed/_n': {'e_noun._n': 'our list'},
 'its listed/_n': {'e_noun._n': 'its list'},
 'his listed/_n': {'e_noun._n': 'his list'},
 'that listed/_n': {'e_noun._n': 'that list'},
 'your listed/_n': {'e_noun._n': 'your list'},
 'the best-seller listed/_n': {'e_noun._n': 'the best-seller list'},
 'my listed/_n': {'e_noun._n': 'my list'},
 'their listed/_n': {'e_noun._n': 'their list'},
 'the new york times best-seller listed/_n': {'e_noun._n': 'the new york times best-seller list'},
 'the guest listed/_n': {'e_noun._n': 'the guest list'},
 'her listed/_n': {'e_noun._n': 'her list'},
 "children's literary/_n": {'e_noun._n': "children's literature"},
 'this loans/_n': {'e_noun._n': 'those loans'},
 'consuming loans/_n': {'e_noun._n': 'consumer loans'},
 'that logical/_n': {'e_noun._n': 'that logic'},
 'a long periodical of time/_n': {'e_noun._n': 'a long period of time'},
 'a long period of timeless/_n': {'e_noun._n': 'a long period of time'},
 'a long way to gone/_n': {'e_noun._n': 'a long way to go'},
 'one looking/_n': {'e_noun._n': 'one look'},
 'her looking/_n': {'e_noun._n': 'her look'},
 'another looking/_n': {'e_noun._n': 'another look'},
 'a second looking/_n': {'e_noun._n': 'a second look'},
 'a looking/_n': {'e_noun._n': 'a look'},
 'a new looking/_n': {'e_noun._n': 'a new look'},
 'a closer looking/_n': {'e_noun._n': 'a closer look'},
 'memorial loss/_n': {'e_noun._n': 'memory loss'},
 'weighable loss/_n': {'e_noun._n': 'weight loss'},
 'boned loss/_n': {'e_noun._n': 'bone loss'},
 'a lot of attentive/_n': {'e_noun._n': 'a lot of attention'},
 'a lot of timeless/_n': {'e_noun._n': 'a lot of time'},
 'a lot of energetic/_n': {'e_noun._n': 'a lot of energy'},
 'a lot of pressured/_n': {'e_noun._n': 'a lot of pressure'},
 'a lot of funny/_n': {'e_noun._n': 'a lot of fun'},
 'a lot of workless/_n': {'e_noun._n': 'a lot of work'},
 'that lovable/_n': {'e_noun._n': 'that love'},
 'tough lovable/_n': {'e_noun._n': 'tough love'},
 'lovable with/_n': {'e_noun._n': 'love with'},
 'truth love/_n': {'e_noun._n': 'TRUE love'},
 'new lovable/_n': {'e_noun._n': 'new love'},
 'their lovable/_n': {'e_noun._n': 'their love'},
 "god's lovable/_n": {'e_noun._n': "god's love"},
 'unconditional lovable/_n': {'e_noun._n': 'unconditional love'},
 'our lovable/_n': {'e_noun._n': 'our love'},
 'her lovable/_n': {'e_noun._n': 'her love'},
 'musical lovers/_n': {'e_noun._n': 'music lovers'},
 'party loyal/_n': {'e_noun._n': 'party loyalty'},
 'their loyal/_n': {'e_noun._n': 'their loyalty'},
 'customer loyal/_n': {'e_noun._n': 'customer loyalty'},
 'no lucky/_n': {'e_noun._n': 'no luck'},
 'bad lucky/_n': {'e_noun._n': 'bad luck'},
 'a little lucky/_n': {'e_noun._n': 'a little luck'},
 'their lucky/_n': {'e_noun._n': 'their luck'},
 'my lucky/_n': {'e_noun._n': 'my luck'},
 'any lucky/_n': {'e_noun._n': 'any luck'},
 'this machines/_n': {'e_noun._n': 'those machines'},
 'computational magazines/_n': {'e_noun._n': 'computer magazines'},
 'regular mailed/_n': {'e_noun._n': 'regular mail'},
 'voiced mail/_n': {'e_noun._n': 'voice mail'},
 'voice mailed/_n': {'e_noun._n': 'voice mail'},
 'my mailed/_n': {'e_noun._n': 'my mail'},
 'his mailed/_n': {'e_noun._n': 'his mail'},
 'your mailed/_n': {'e_noun._n': 'your mail'},
 'their mailed/_n': {'e_noun._n': 'their mail'},
 'snail mailed/_n': {'e_noun._n': 'snail mail'},
 'routine maintained/_n': {'e_noun._n': 'routine maintenance'},
 'annual maintained/_n': {'e_noun._n': 'annual maintenance'},
 'the maintained/_n': {'e_noun._n': 'the maintenance'},
 'the vast major/_n': {'e_noun._n': 'the vast majority'},
 'the major of americans/_n': {'e_noun._n': 'the majority of americans'},
 'a major of americans/_n': {'e_noun._n': 'a majority of americans'},
 'the makable/_n': {'e_noun._n': 'the make'},
 'computational makers/_n': {'e_noun._n': 'computer makers'},
 'filmed makers/_n': {'e_noun._n': 'film makers'},
 'his manly/_n': {'e_noun._n': 'his man'},
 'the other manly/_n': {'e_noun._n': 'the other man'},
 'third men/_n': {'e_noun._n': 'three men'},
 'the young manly/_n': {'e_noun._n': 'the young man'},
 'their manly/_n': {'e_noun._n': 'their man'},
 'a black manly/_n': {'e_noun._n': 'a black man'},
 'a white manly/_n': {'e_noun._n': 'a white man'},
 'the same manly/_n': {'e_noun._n': 'the same man'},
 'that manly/_n': {'e_noun._n': 'that man'},
 'the white manly/_n': {'e_noun._n': 'the white man'},
 'your manly/_n': {'e_noun._n': 'your man'},
 'her manly/_n': {'e_noun._n': 'her man'},
 'my manly/_n': {'e_noun._n': 'my man'},
 'each manly/_n': {'e_noun._n': 'each man'},
 'the third men/_n': {'e_noun._n': 'the three men'},
 'a big manly/_n': {'e_noun._n': 'a big man'},
 'the common manly/_n': {'e_noun._n': 'the common man'},
 'the first manly/_n': {'e_noun._n': 'the first man'},
 'the manly himself/_n': {'e_noun._n': 'the man himself'},
 'any manly/_n': {'e_noun._n': 'any man'},
 'emergency managing/_n': {'e_noun._n': 'emergency management'},
 'their managing/_n': {'e_noun._n': 'their management'},
 "the company's managing/_n": {'e_noun._n': "the company's management"},
 'top managing/_n': {'e_noun._n': 'top management'},
 'strong managing/_n': {'e_noun._n': 'strong management'},
 'asset managing/_n': {'e_noun._n': 'asset management'},
 'poor managing/_n': {'e_noun._n': 'poor management'},
 'new managing/_n': {'e_noun._n': 'new management'},
 'current managing/_n': {'e_noun._n': 'current management'},
 'upper managing/_n': {'e_noun._n': 'upper management'},
 'strength management/_n': {'e_noun._n': 'strong management'},
 'private managing/_n': {'e_noun._n': 'private management'},
 'good managing/_n': {'e_noun._n': 'good management'},
 'wasteful management/_n': {'e_noun._n': 'waste management'},
 'waste managing/_n': {'e_noun._n': 'waste management'},
 'investment managing/_n': {'e_noun._n': 'investment management'},
 'storing managers/_n': {'e_noun._n': 'store managers'},
 'waterless managers/_n': {'e_noun._n': 'water managers'},
 'market manipulative/_n': {'e_noun._n': 'market manipulation'},
 'computational manufacturers/_n': {'e_noun._n': 'computer manufacturers'},
 'many of this/_n': {'e_noun._n': 'many of those'},
 'a wide marginal/_n': {'e_noun._n': 'a wide margin'},
 'gross marginal/_n': {'e_noun._n': 'gross margin'},
 'the marginal of error/_n': {'e_noun._n': 'the margin of error'},
 'the margin of erroneous/_n': {'e_noun._n': 'the margin of error'},
 'its marked/_n': {'e_noun._n': 'its mark'},
 'their marked/_n': {'e_noun._n': 'their mark'},
 'his marked/_n': {'e_noun._n': 'his mark'},
 'the second market/_n': {'e_noun._n': 'the secondary market'},
 'finance market/_n': {'e_noun._n': 'financial market'},
 'bonding markets/_n': {'e_noun._n': 'bond markets'},
 'currency market/_n': {'e_noun._n': 'current market'},
 'the foreign exchanging market/_n': {'e_noun._n': 'the foreign exchange market'},
 'the bonding market/_n': {'e_noun._n': 'the bond market'},
 'the consuming market/_n': {'e_noun._n': 'the consumer market'},
 'our married/_n': {'e_noun._n': 'our marriage'},
 'whose married/_n': {'e_noun._n': 'whose marriage'},
 'your married/_n': {'e_noun._n': 'your marriage'},
 'that married/_n': {'e_noun._n': 'that marriage'},
 'so-called married/_n': {'e_noun._n': 'so-called marriage'},
 'gay married/_n': {'e_noun._n': 'gay marriage'},
 'a previous married/_n': {'e_noun._n': 'a previous marriage'},
 'his married/_n': {'e_noun._n': 'his marriage'},
 'their married/_n': {'e_noun._n': 'their marriage'},
 'a bad married/_n': {'e_noun._n': 'a bad marriage'},
 'his first married/_n': {'e_noun._n': 'his first marriage'},
 'his matched/_n': {'e_noun._n': 'his match'},
 'their matched/_n': {'e_noun._n': 'their match'},
 'a matched/_n': {'e_noun._n': 'a match'},
 'that matched/_n': {'e_noun._n': 'that match'},
 'constructive materials/_n': {'e_noun._n': 'construction materials'},
 'secure matters/_n': {'e_noun._n': 'security matters'},
 'just a matter of timeless/_n': {'e_noun._n': 'just a matter of time'},
 'only a matter of timeless/_n': {'e_noun._n': 'only a matter of time'},
 'new mean/_n': {'e_noun._n': 'new meaning'},
 'its mean/_n': {'e_noun._n': 'its meaning'},
 'any measurable/_n': {'e_noun._n': 'any measure'},
 'one measurable/_n': {'e_noun._n': 'one measure'},
 'large measurable/_n': {'e_noun._n': 'large measure'},
 'this measures/_n': {'e_noun._n': 'those measures'},
 'equal measurable/_n': {'e_noun._n': 'equal measure'},
 'such a measurable/_n': {'e_noun._n': 'such a measure'},
 'secure measures/_n': {'e_noun._n': 'security measures'},
 'his measurable/_n': {'e_noun._n': 'his measure'},
 'a measurable/_n': {'e_noun._n': 'a measure'},
 'the measurable/_n': {'e_noun._n': 'the measure'},
 'that measurable/_n': {'e_noun._n': 'that measure'},
 'good measurable/_n': {'e_noun._n': 'good measure'},
 'an olympic golden medal/_n': {'e_noun._n': 'an olympic gold medal'},
 'a golden medal/_n': {'e_noun._n': 'a gold medal'},
 'the silverish medal/_n': {'e_noun._n': 'the silver medal'},
 'a silverish medal/_n': {'e_noun._n': 'a silver medal'},
 'tradition media/_n': {'e_noun._n': 'traditional media'},
 'this meetings/_n': {'e_noun._n': 'those meetings'},
 'the banded members/_n': {'e_noun._n': 'the band members'},
 'banded members/_n': {'e_noun._n': 'band members'},
 'third members/_n': {'e_noun._n': 'three members'},
 'computational memory/_n': {'e_noun._n': 'computer memory'},
 'computer memorial/_n': {'e_noun._n': 'computer memory'},
 'your memorial/_n': {'e_noun._n': 'your memory'},
 'living memorial/_n': {'e_noun._n': 'living memory'},
 'my memorial/_n': {'e_noun._n': 'my memory'},
 'short-term memorial/_n': {'e_noun._n': 'short-term memory'},
 'more memorial/_n': {'e_noun._n': 'more memory'},
 'flash memorial/_n': {'e_noun._n': 'flash memory'},
 'this memories/_n': {'e_noun._n': 'those memories'},
 'no mentioned/_n': {'e_noun._n': 'no mention'},
 'no merciful/_n': {'e_noun._n': 'no mercy'},
 'this messages/_n': {'e_noun._n': 'those messages'},
 'this methods/_n': {'e_noun._n': 'those methods'},
 'his methodical/_n': {'e_noun._n': 'his method'},
 'that methodical/_n': {'e_noun._n': 'that method'},
 'one methodical/_n': {'e_noun._n': 'one method'},
 'breast milky/_n': {'e_noun._n': 'breast milk'},
 'their milky/_n': {'e_noun._n': 'their milk'},
 'soy milky/_n': {'e_noun._n': 'soy milk'},
 'the milky/_n': {'e_noun._n': 'the milk'},
 'our minded/_n': {'e_noun._n': 'our mind'},
 'its minded/_n': {'e_noun._n': 'its mind'},
 'her minded/_n': {'e_noun._n': 'her mind'},
 'the minded/_n': {'e_noun._n': 'the mind'},
 'their minded/_n': {'e_noun._n': 'their mind'},
 "everyone's minded/_n": {'e_noun._n': "everyone's mind"},
 'an open minded/_n': {'e_noun._n': 'an open mind'},
 'his minded/_n': {'e_noun._n': 'his mind'},
 'the public minded/_n': {'e_noun._n': 'the public mind'},
 'the human minded/_n': {'e_noun._n': 'the human mind'},
 'financial minister/_n': {'e_noun._n': 'finance minister'},
 'governing ministries/_n': {'e_noun._n': 'government ministries'},
 'the financial ministry/_n': {'e_noun._n': 'the finance ministry'},
 'the finance ministerial/_n': {'e_noun._n': 'the finance ministry'},
 'his ministerial/_n': {'e_noun._n': 'his ministry'},
 'their miserable/_n': {'e_noun._n': 'their misery'},
 'that mistaken/_n': {'e_noun._n': 'that mistake'},
 'this mistakes/_n': {'e_noun._n': 'those mistakes'},
 'my mistaken/_n': {'e_noun._n': 'my mistake'},
 'no mistaken about it/_n': {'e_noun._n': 'no mistake about it'},
 'a big mistaken/_n': {'e_noun._n': 'a big mistake'},
 'no mistaken/_n': {'e_noun._n': 'no mistake'},
 'flour mixed/_n': {'e_noun._n': 'flour mixture'},
 'egg mixed/_n': {'e_noun._n': 'egg mixture'},
 'computational models/_n': {'e_noun._n': 'computer models'},
 'a moderation/_n': {'e_noun._n': 'a moderate'},
 'a modesty/_n': {'e_noun._n': 'a modest'},
 'childish molestation/_n': {'e_noun._n': 'child molestation'},
 'childish molesters/_n': {'e_noun._n': 'child molesters'},
 'any given momentary/_n': {'e_noun._n': 'any given moment'},
 'every momentary/_n': {'e_noun._n': 'every moment'},
 'a momentary of silence/_n': {'e_noun._n': 'a moment of silence'},
 'a moment of silent/_n': {'e_noun._n': 'a moment of silence'},
 'his momentary/_n': {'e_noun._n': 'his moment'},
 'the last momentary/_n': {'e_noun._n': 'the last moment'},
 'the momentary/_n': {'e_noun._n': 'the moment'},
 'any momentary/_n': {'e_noun._n': 'any moment'},
 'one momentary/_n': {'e_noun._n': 'one moment'},
 'that momentary/_n': {'e_noun._n': 'that moment'},
 'this moments/_n': {'e_noun._n': 'those moments'},
 'computational monitors/_n': {'e_noun._n': 'computer monitors'},
 'only a monthly/_n': {'e_noun._n': 'only a month'},
 'at least a monthly/_n': {'e_noun._n': 'at least a month'},
 'the wintry months/_n': {'e_noun._n': 'the winter months'},
 'this months/_n': {'e_noun._n': 'those months'},
 'about a monthly/_n': {'e_noun._n': 'about a month'},
 'each monthly/_n': {'e_noun._n': 'each month'},
 'the next monthly/_n': {'e_noun._n': 'the next month'},
 'just a monthly/_n': {'e_noun._n': 'just a month'},
 'every monthly/_n': {'e_noun._n': 'every month'},
 'more than a monthly/_n': {'e_noun._n': 'more than a month'},
 'another monthly/_n': {'e_noun._n': 'another month'},
 'the same monthly/_n': {'e_noun._n': 'the same month'},
 'that monthly/_n': {'e_noun._n': 'that month'},
 'the previous monthly/_n': {'e_noun._n': 'the previous month'},
 'the last monthly/_n': {'e_noun._n': 'the last month'},
 'the first monthly/_n': {'e_noun._n': 'the first month'},
 'almost a monthly/_n': {'e_noun._n': 'almost a month'},
 'nearly a monthly/_n': {'e_noun._n': 'nearly a month'},
 'the past monthly/_n': {'e_noun._n': 'the past month'},
 'third more/_n': {'e_noun._n': 'three more'},
 'most of the timeless/_n': {'e_noun._n': 'most of the time'},
 'most of his timeless/_n': {'e_noun._n': 'most of his time'},
 'most of the workless/_n': {'e_noun._n': 'most of the work'},
 'a motional/_n': {'e_noun._n': 'a motion'},
 'that motional/_n': {'e_noun._n': 'that motion'},
 'his motional/_n': {'e_noun._n': 'his motion'},
 'the motional/_n': {'e_noun._n': 'the motion'},
 'repetitive motional/_n': {'e_noun._n': 'repetitive motion'},
 'a computational mouse/_n': {'e_noun._n': 'a computer mouse'},
 'the next moving/_n': {'e_noun._n': 'the next move'},
 'their moving/_n': {'e_noun._n': 'their move'},
 'his every moving/_n': {'e_noun._n': 'his every move'},
 'his moving/_n': {'e_noun._n': 'his move'},
 'any moving/_n': {'e_noun._n': 'any move'},
 'its moving/_n': {'e_noun._n': 'its move'},
 'that moving/_n': {'e_noun._n': 'that move'},
 'every moving/_n': {'e_noun._n': 'every move'},
 'moving forward./_n': {'e_noun._n': 'move forward.'},
 'moving forward,/_n': {'e_noun._n': 'move forward,'},
 'such a moving/_n': {'e_noun._n': 'such a move'},
 'the labor moving/_n': {'e_noun._n': 'the labor movement'},
 'the environment movement/_n': {'e_noun._n': 'the environmental movement'},
 'the environmental moving/_n': {'e_noun._n': 'the environmental movement'},
 'this movies/_n': {'e_noun._n': 'those movies'},
 'much of those/_n': {'e_noun._n': 'much of this'},
 'much of the workless/_n': {'e_noun._n': 'much of the work'},
 'christian musical/_n': {'e_noun._n': 'christian music'},
 'british musical/_n': {'e_noun._n': 'british music'},
 'online musical/_n': {'e_noun._n': 'online music'},
 'good musical/_n': {'e_noun._n': 'good music'},
 'contemporary musical/_n': {'e_noun._n': 'contemporary music'},
 'local musical/_n': {'e_noun._n': 'local music'},
 'background musical/_n': {'e_noun._n': 'background music'},
 'black musical/_n': {'e_noun._n': 'black music'},
 'world musical/_n': {'e_noun._n': 'world music'},
 'our musical/_n': {'e_noun._n': 'our music'},
 'hip-hop musical/_n': {'e_noun._n': 'hip-hop music'},
 'loud musical/_n': {'e_noun._n': 'loud music'},
 'whose musical/_n': {'e_noun._n': 'whose music'},
 'dance musical/_n': {'e_noun._n': 'dance music'},
 'latin musical/_n': {'e_noun._n': 'latin music'},
 'great musical/_n': {'e_noun._n': 'great music'},
 'rap musical/_n': {'e_noun._n': 'rap music'},
 'your musical/_n': {'e_noun._n': 'your music'},
 'no mysterious/_n': {'e_noun._n': 'no mystery'},
 'a nailing/_n': {'e_noun._n': 'a nail'},
 'useful name/_n': {'e_noun._n': 'user name'},
 'any other national/_n': {'e_noun._n': 'any other nation'},
 'the entire national/_n': {'e_noun._n': 'the entire nation'},
 'the national as a whole/_n': {'e_noun._n': 'the nation as a whole'},
 'each national/_n': {'e_noun._n': 'each nation'},
 'specialist needs/_n': {'e_noun._n': 'special needs'},
 'the needled/_n': {'e_noun._n': 'the needle'},
 'a needled/_n': {'e_noun._n': 'a needle'},
 'contracted negotiations/_n': {'e_noun._n': 'contract negotiations'},
 'tradable negotiations/_n': {'e_noun._n': 'trade negotiations'},
 'the nested/_n': {'e_noun._n': 'the nest'},
 'the global computational network/_n': {'e_noun._n': 'the global computer network'},
 'a computational network/_n': {'e_noun._n': 'a computer network'},
 'a newness/_n': {'e_noun._n': 'a new'},
 'specialist news/_n': {'e_noun._n': 'special news'},
 'day newspapers/_n': {'e_noun._n': 'daily newspapers'},
 'weekend newspaper/_n': {'e_noun._n': 'weekly newspaper'},
 'a niceness/_n': {'e_noun._n': 'a nice'},
 'elect night/_n': {'e_noun._n': 'election night'},
 'third nights/_n': {'e_noun._n': 'three nights'},
 'some noisy/_n': {'e_noun._n': 'some noise'},
 'background noisy/_n': {'e_noun._n': 'background noise'},
 'a normality/_n': {'e_noun._n': 'a normal'},
 'that notable/_n': {'e_noun._n': 'that note'},
 'this notes/_n': {'e_noun._n': 'those notes'},
 'nothing to lost/_n': {'e_noun._n': 'nothing to lose'},
 'nothing specialist/_n': {'e_noun._n': 'nothing special'},
 "a moment's noticeable/_n": {'e_noun._n': "a moment's notice"},
 'little noticeable/_n': {'e_noun._n': 'little notice'},
 'the noticeable/_n': {'e_noun._n': 'the notice'},
 'short noticeable/_n': {'e_noun._n': 'short notice'},
 'further noticeable/_n': {'e_noun._n': 'further notice'},
 'nowhere to gone/_n': {'e_noun._n': 'nowhere to go'},
 'this numbers/_n': {'e_noun._n': 'those numbers'},
 'a numbered of years/_n': {'e_noun._n': 'a number of years'},
 'a numbered of them/_n': {'e_noun._n': 'a number of them'},
 'their numbered/_n': {'e_noun._n': 'their number'},
 'the same numbered/_n': {'e_noun._n': 'the same number'},
 'the numbered of cases/_n': {'e_noun._n': 'the number of cases'},
 'the phone numbered/_n': {'e_noun._n': 'the phone number'},
 'a phone numbered/_n': {'e_noun._n': 'a phone number'},
 'his numbered/_n': {'e_noun._n': 'his number'},
 'the numbered of people/_n': {'e_noun._n': 'the number of people'},
 'that numbered/_n': {'e_noun._n': 'that number'},
 'numbered two/_n': {'e_noun._n': 'number two'},
 'a numbered/_n': {'e_noun._n': 'a number'},
 'a numbered of people/_n': {'e_noun._n': 'a number of people'},
 'telephone numbered/_n': {'e_noun._n': 'telephone number'},
 'my numbered/_n': {'e_noun._n': 'my number'},
 'your numbered/_n': {'e_noun._n': 'your number'},
 'a numbered of reasons/_n': {'e_noun._n': 'a number of reasons'},
 'the numbered of/_n': {'e_noun._n': 'the number of'},
 'any numbered/_n': {'e_noun._n': 'any number'},
 'a numbered of/_n': {'e_noun._n': 'a number of'},
 'a numbered of issues/_n': {'e_noun._n': 'a number of issues'},
 'a numbered of companies/_n': {'e_noun._n': 'a number of companies'},
 'a numbered of factors/_n': {'e_noun._n': 'a number of factors'},
 'a growing numbered/_n': {'e_noun._n': 'a growing number'},
 'industrial observers/_n': {'e_noun._n': 'industry observers'},
 'another occasional/_n': {'e_noun._n': 'another occasion'},
 'every occasional/_n': {'e_noun._n': 'every occasion'},
 'specialist occasions/_n': {'e_noun._n': 'special occasions'},
 'third occasions/_n': {'e_noun._n': 'three occasions'},
 'that occasional/_n': {'e_noun._n': 'that occasion'},
 'one occasional/_n': {'e_noun._n': 'one occasion'},
 'this occasions/_n': {'e_noun._n': 'those occasions'},
 'the occupantional/_n': {'e_noun._n': 'the occupation'},
 'israeli occupantional/_n': {'e_noun._n': 'israeli occupation'},
 'governing offices/_n': {'e_noun._n': 'government offices'},
 'lawful enforcement officers/_n': {'e_noun._n': 'law enforcement officers'},
 'law enforced officers/_n': {'e_noun._n': 'law enforcement officers'},
 'secure officers/_n': {'e_noun._n': 'security officers'},
 'intelligent officers/_n': {'e_noun._n': 'intelligence officers'},
 'industrial officials/_n': {'e_noun._n': 'industry officials'},
 'departmental officials/_n': {'e_noun._n': 'department officials'},
 'administrative officials/_n': {'e_noun._n': 'administration officials'},
 'educational officials/_n': {'e_noun._n': 'education officials'},
 'a white housed official/_n': {'e_noun._n': 'a white house official'},
 'public healthy officials/_n': {'e_noun._n': 'public health officials'},
 'governing officials,/_n': {'e_noun._n': 'government officials,'},
 'lawful enforcement officials/_n': {'e_noun._n': 'law enforcement officials'},
 'law enforced officials/_n': {'e_noun._n': 'law enforcement officials'},
 'elect officials/_n': {'e_noun._n': 'election officials'},
 'ministerial officials/_n': {'e_noun._n': 'ministry officials'},
 'immigrant officials/_n': {'e_noun._n': 'immigration officials'},
 'this officials/_n': {'e_noun._n': 'those officials'},
 'healthy officials/_n': {'e_noun._n': 'health officials'},
 'secure officials/_n': {'e_noun._n': 'security officials'},
 'wild officials/_n': {'e_noun._n': 'wildlife officials'},
 'a governing official/_n': {'e_noun._n': 'a government official'},
 'the officialdom/_n': {'e_noun._n': 'the official'},
 'one of this/_n': {'e_noun._n': 'one of those'},
 'greater open/_n': {'e_noun._n': 'greater openness'},
 'that operational/_n': {'e_noun._n': 'that operation'},
 'governing operations/_n': {'e_noun._n': 'government operations'},
 'an operational/_n': {'e_noun._n': 'an operation'},
 'specialist operations/_n': {'e_noun._n': 'special operations'},
 'his operational/_n': {'e_noun._n': 'his operation'},
 'its operational/_n': {'e_noun._n': 'its operation'},
 'their operational/_n': {'e_noun._n': 'their operation'},
 'education opportunities/_n': {'e_noun._n': 'educational opportunities'},
 'this opportunities/_n': {'e_noun._n': 'those opportunities'},
 'the oppositional/_n': {'e_noun._n': 'the opposition'},
 'their oppositional/_n': {'e_noun._n': 'their opposition'},
 'its oppositional/_n': {'e_noun._n': 'its opposition'},
 'main oppositional/_n': {'e_noun._n': 'main opposition'},
 'local oppositional/_n': {'e_noun._n': 'local opposition'},
 'strong oppositional/_n': {'e_noun._n': 'strong opposition'},
 'no oppositional/_n': {'e_noun._n': 'no opposition'},
 'political oppositional/_n': {'e_noun._n': 'political opposition'},
 'his oppositional/_n': {'e_noun._n': 'his opposition'},
 'no optional/_n': {'e_noun._n': 'no option'},
 'one optional/_n': {'e_noun._n': 'one option'},
 'treated options/_n': {'e_noun._n': 'treatment options'},
 'that optional/_n': {'e_noun._n': 'that option'},
 'another optional/_n': {'e_noun._n': 'another option'},
 'third options/_n': {'e_noun._n': 'three options'},
 'not an optional/_n': {'e_noun._n': 'not an option'},
 'the only optional/_n': {'e_noun._n': 'the only option'},
 'a weekly or two/_n': {'e_noun._n': 'a week or two'},
 'two or third/_n': {'e_noun._n': 'two or three'},
 'third or four/_n': {'e_noun._n': 'three or four'},
 'an orangish/_n': {'e_noun._n': 'an orange'},
 'society order/_n': {'e_noun._n': 'social order'},
 'live organisms/_n': {'e_noun._n': 'living organisms'},
 'the organization for economic cooperative and development/_n': {'e_noun._n': 'the organization for economic cooperation and development'},
 'the organization for economic cooperation and developed/_n': {'e_noun._n': 'the organization for economic cooperation and development'},
 'this organizations/_n': {'e_noun._n': 'those organizations'},
 'environment organizations/_n': {'e_noun._n': 'environmental organizations'},
 'national original/_n': {'e_noun._n': 'national origin'},
 'her outsider/_n': {'e_noun._n': 'her out'},
 'powerful outages/_n': {'e_noun._n': 'power outages'},
 'the outcome of the elect/_n': {'e_noun._n': 'the outcome of the election'},
 'a new own/_n': {'e_noun._n': 'a new owner'},
 'the own/_n': {'e_noun._n': 'the owner'},
 'one own/_n': {'e_noun._n': 'one owner'},
 'the new own/_n': {'e_noun._n': 'the new owner'},
 'storing owners/_n': {'e_noun._n': 'store owners'},
 'whose own/_n': {'e_noun._n': 'whose owner'},
 'an own/_n': {'e_noun._n': 'an owner'},
 'private own/_n': {'e_noun._n': 'private ownership'},
 'foreign own/_n': {'e_noun._n': 'foreign ownership'},
 'the pace of economic grown/_n': {'e_noun._n': 'the pace of economic growth'},
 'travelled package/_n': {'e_noun._n': 'travel package'},
 'beautiful pageants/_n': {'e_noun._n': 'beauty pageants'},
 'back painful/_n': {'e_noun._n': 'back pain'},
 'that painful/_n': {'e_noun._n': 'that pain'},
 'her painful/_n': {'e_noun._n': 'her pain'},
 'your painful/_n': {'e_noun._n': 'your pain'},
 'great painful/_n': {'e_noun._n': 'great pain'},
 'chronic painful/_n': {'e_noun._n': 'chronic pain'},
 'their painful/_n': {'e_noun._n': 'their pain'},
 'severe painful/_n': {'e_noun._n': 'severe pain'},
 'chest painful/_n': {'e_noun._n': 'chest pain'},
 'any painful/_n': {'e_noun._n': 'any pain'},
 'some painful/_n': {'e_noun._n': 'some pain'},
 'this papers/_n': {'e_noun._n': 'those papers'},
 'every parentage/_n': {'e_noun._n': 'every parent'},
 'your parentage/_n': {'e_noun._n': 'your parent'},
 'one parentage/_n': {'e_noun._n': 'one parent'},
 'each parentage/_n': {'e_noun._n': 'each parent'},
 'a parentage/_n': {'e_noun._n': 'a parent'},
 'part of the reasonable/_n': {'e_noun._n': 'part of the reason'},
 'part of the problematic/_n': {'e_noun._n': 'part of the problem'},
 'sparing parts/_n': {'e_noun._n': 'spare parts'},
 'bodily parts/_n': {'e_noun._n': 'body parts'},
 'part of those/_n': {'e_noun._n': 'part of this'},
 'this parts/_n': {'e_noun._n': 'those parts'},
 'third parts/_n': {'e_noun._n': 'three parts'},
 'a participatory/_n': {'e_noun._n': 'a participant'},
 'one participatory/_n': {'e_noun._n': 'one participant'},
 'each participatory/_n': {'e_noun._n': 'each participant'},
 'his participatory/_n': {'e_noun._n': 'his participation'},
 'their participatory/_n': {'e_noun._n': 'their participation'},
 'the major party/_n': {'e_noun._n': 'the majority party'},
 'oppositional parties/_n': {'e_noun._n': 'opposition parties'},
 'third passes/_n': {'e_noun._n': 'three passes'},
 'the passage of timeless/_n': {'e_noun._n': 'the passage of time'},
 'this payments/_n': {'e_noun._n': 'those payments'},
 'interesting payments/_n': {'e_noun._n': 'interest payments'},
 'month payments/_n': {'e_noun._n': 'monthly payments'},
 'relative peaceful/_n': {'e_noun._n': 'relative peace'},
 'current peaceful/_n': {'e_noun._n': 'current peace'},
 'in peace/_n': {'e_noun._n': 'inner peace'},
 'that peaceful/_n': {'e_noun._n': 'that peace'},
 'new peaceful/_n': {'e_noun._n': 'new peace'},
 'peaceful of mind/_n': {'e_noun._n': 'peace of mind'},
 'peace of minded/_n': {'e_noun._n': 'peace of mind'},
 'stalled peaceful/_n': {'e_noun._n': 'stalled peace'},
 'formal peaceful/_n': {'e_noun._n': 'formal peace'},
 'regional peaceful/_n': {'e_noun._n': 'regional peace'},
 'middle east peaceful/_n': {'e_noun._n': 'middle east peace'},
 'permanent peaceful/_n': {'e_noun._n': 'permanent peace'},
 'real peaceful/_n': {'e_noun._n': 'real peace'},
 'peaceful in the middle east/_n': {'e_noun._n': 'peace in the middle east'},
 'peace inner the middle east/_n': {'e_noun._n': 'peace in the middle east'},
 'averaged people/_n': {'e_noun._n': 'average people'},
 'sixteenth people/_n': {'e_noun._n': 'six people'},
 'elder people/_n': {'e_noun._n': 'elderly people'},
 'third people/_n': {'e_noun._n': 'three people'},
 'difference people/_n': {'e_noun._n': 'different people'},
 'people inner/_n': {'e_noun._n': 'people in'},
 'pepper to tasteless/_n': {'e_noun._n': 'pepper to taste'},
 'living performances/_n': {'e_noun._n': 'live performances'},
 'academy performance/_n': {'e_noun._n': 'academic performance'},
 'living performance/_n': {'e_noun._n': 'live performance'},
 'a short periodical of time/_n': {'e_noun._n': 'a short period of time'},
 'a short period of timeless/_n': {'e_noun._n': 'a short period of time'},
 'the same timeless period/_n': {'e_noun._n': 'the same time period'},
 'the same time periodical/_n': {'e_noun._n': 'the same time period'},
 'a periodical of time/_n': {'e_noun._n': 'a period of time'},
 'a period of timeless/_n': {'e_noun._n': 'a period of time'},
 'this periods/_n': {'e_noun._n': 'those periods'},
 'long periods of timeless/_n': {'e_noun._n': 'long periods of time'},
 'that periodical/_n': {'e_noun._n': 'that period'},
 'a periodical of years/_n': {'e_noun._n': 'a period of years'},
 'one periodical/_n': {'e_noun._n': 'one period'},
 'the second periodical/_n': {'e_noun._n': 'the second period'},
 'the tested period/_n': {'e_noun._n': 'the test period'},
 'the test periodical/_n': {'e_noun._n': 'the test period'},
 'the same periodical last year/_n': {'e_noun._n': 'the same period last year'},
 'third periods/_n': {'e_noun._n': 'three periods'},
 'the third periodical/_n': {'e_noun._n': 'the third period'},
 'the same periodical/_n': {'e_noun._n': 'the same period'},
 'religion persecution/_n': {'e_noun._n': 'religious persecution'},
 'only one personality/_n': {'e_noun._n': 'only one person'},
 'a young personality/_n': {'e_noun._n': 'a young person'},
 'the first personality/_n': {'e_noun._n': 'the first person'},
 'the averaged person/_n': {'e_noun._n': 'the average person'},
 'the average personality/_n': {'e_noun._n': 'the average person'},
 'the other personality/_n': {'e_noun._n': 'the other person'},
 'a black personality/_n': {'e_noun._n': 'a black person'},
 'secure personnel/_n': {'e_noun._n': 'security personnel'},
 'a photography/_n': {'e_noun._n': 'a photographer'},
 'this pictures/_n': {'e_noun._n': 'those pictures'},
 'third pieces/_n': {'e_noun._n': 'three pieces'},
 'this places/_n': {'e_noun._n': 'those places'},
 'a safety place/_n': {'e_noun._n': 'a safe place'},
 'difference places/_n': {'e_noun._n': 'different places'},
 'third places/_n': {'e_noun._n': 'three places'},
 'the right place at the right timeless/_n': {'e_noun._n': 'the right place at the right time'},
 'travelled plans/_n': {'e_noun._n': 'travel plans'},
 'this plans/_n': {'e_noun._n': 'those plans'},
 'nuclear powerful plants/_n': {'e_noun._n': 'nuclear power plants'},
 'this plants/_n': {'e_noun._n': 'those plants'},
 'third plays/_n': {'e_noun._n': 'three plays'},
 'talent players/_n': {'e_noun._n': 'talented players'},
 'this players/_n': {'e_noun._n': 'those players'},
 'third players/_n': {'e_noun._n': 'three players'},
 'sixteenth players/_n': {'e_noun._n': 'six players'},
 'plenty of timeless/_n': {'e_noun._n': 'plenty of time'},
 'sixteenth points/_n': {'e_noun._n': 'six points'},
 'this points/_n': {'e_noun._n': 'those points'},
 'specialist police/_n': {'e_noun._n': 'special police'},
 'immigrant policy/_n': {'e_noun._n': 'immigration policy'},
 'tradable policy/_n': {'e_noun._n': 'trade policy'},
 'taxable policy/_n': {'e_noun._n': 'tax policy'},
 'society policy/_n': {'e_noun._n': 'social policy'},
 'environment policy/_n': {'e_noun._n': 'environmental policy'},
 'this policies/_n': {'e_noun._n': 'those policies'},
 'governing policies/_n': {'e_noun._n': 'government policies'},
 'any political/_n': {'e_noun._n': 'any politician'},
 'no political/_n': {'e_noun._n': 'no politician'},
 'whose popular/_n': {'e_noun._n': 'whose popularity'},
 'the most popularity/_n': {'e_noun._n': 'the most popular'},
 "clinton's popular/_n": {'e_noun._n': "clinton's popularity"},
 'her popular/_n': {'e_noun._n': 'her popularity'},
 'childish pornography/_n': {'e_noun._n': 'child pornography'},
 'this positions/_n': {'e_noun._n': 'those positions'},
 'the possible of/_n': {'e_noun._n': 'the possibility of'},
 'that possible/_n': {'e_noun._n': 'that possibility'},
 'one possible/_n': {'e_noun._n': 'one possibility'},
 'childish poverty/_n': {'e_noun._n': 'child poverty'},
 'a powdery/_n': {'e_noun._n': 'a powder'},
 'white powdery/_n': {'e_noun._n': 'white powder'},
 'the powdery/_n': {'e_noun._n': 'the powder'},
 'nation power/_n': {'e_noun._n': 'national power'},
 'such powerful/_n': {'e_noun._n': 'such power'},
 'full powerful/_n': {'e_noun._n': 'full power'},
 'real powerful/_n': {'e_noun._n': 'real power'},
 'more powerful/_n': {'e_noun._n': 'more power'},
 'local powerful/_n': {'e_noun._n': 'local power'},
 'electricity power/_n': {'e_noun._n': 'electric power'},
 'market powerful/_n': {'e_noun._n': 'market power'},
 'political powerful/_n': {'e_noun._n': 'political power'},
 'solar powerful/_n': {'e_noun._n': 'solar power'},
 'hydroelectric powerful/_n': {'e_noun._n': 'hydroelectric power'},
 'military powerful/_n': {'e_noun._n': 'military power'},
 'enormous powerful/_n': {'e_noun._n': 'enormous power'},
 'economic powerful/_n': {'e_noun._n': 'economic power'},
 'new powerful/_n': {'e_noun._n': 'new power'},
 'governing power/_n': {'e_noun._n': 'government power'},
 'government powerful/_n': {'e_noun._n': 'government power'},
 'that powerful/_n': {'e_noun._n': 'that power'},
 'computing powerful/_n': {'e_noun._n': 'computing power'},
 'less powerful/_n': {'e_noun._n': 'less power'},
 'their powerful/_n': {'e_noun._n': 'their power'},
 'federal powerful/_n': {'e_noun._n': 'federal power'},
 'big powerful/_n': {'e_noun._n': 'big power'},
 'star powerful/_n': {'e_noun._n': 'star power'},
 'her powerful/_n': {'e_noun._n': 'her power'},
 'independent powerful/_n': {'e_noun._n': 'independent power'},
 'some powerful/_n': {'e_noun._n': 'some power'},
 'economy power/_n': {'e_noun._n': 'economic power'},
 'state powerful/_n': {'e_noun._n': 'state power'},
 'executive powerful/_n': {'e_noun._n': 'executive power'},
 'american powerful/_n': {'e_noun._n': 'american power'},
 'major powerful/_n': {'e_noun._n': 'major power'},
 'battery powerful/_n': {'e_noun._n': 'battery power'},
 'whose powerful/_n': {'e_noun._n': 'whose power'},
 'targeted practice/_n': {'e_noun._n': 'target practice'},
 'this practices/_n': {'e_noun._n': 'those practices'},
 'a preferable/_n': {'e_noun._n': 'a preference'},
 'sexual preferable/_n': {'e_noun._n': 'sexual preference'},
 'my preferable/_n': {'e_noun._n': 'my preference'},
 'his preferable/_n': {'e_noun._n': 'his preference'},
 'insured premiums/_n': {'e_noun._n': 'insurance premiums'},
 'the next presidential/_n': {'e_noun._n': 'the next president'},
 'presidential of the united states/_n': {'e_noun._n': 'president of the united states'},
 'the russian presidential/_n': {'e_noun._n': 'the russian president'},
 'the former presidential/_n': {'e_noun._n': 'the former president'},
 'acting presidential/_n': {'e_noun._n': 'acting president'},
 'presidential in 2000/_n': {'e_noun._n': 'president in 2000'},
 'president inner 2000/_n': {'e_noun._n': 'president in 2000'},
 'any presidential/_n': {'e_noun._n': 'any president'},
 'no presidential/_n': {'e_noun._n': 'no president'},
 'new presidential/_n': {'e_noun._n': 'new president'},
 'every presidential/_n': {'e_noun._n': 'every president'},
 'a new presidential/_n': {'e_noun._n': 'a new president'},
 'the presidential himself/_n': {'e_noun._n': 'the president himself'},
 'former presidential/_n': {'e_noun._n': 'former president'},
 'second presidential/_n': {'e_noun._n': 'second president'},
 'a former presidential/_n': {'e_noun._n': 'a former president'},
 'the new presidential/_n': {'e_noun._n': 'the new president'},
 "the company's presidential/_n": {'e_noun._n': "the company's president"},
 'whose presidential/_n': {'e_noun._n': 'whose president'},
 'the first presidential/_n': {'e_noun._n': 'the first president'},
 'low pressured/_n': {'e_noun._n': 'low pressure'},
 'no pressured/_n': {'e_noun._n': 'no pressure'},
 'some pressured/_n': {'e_noun._n': 'some pressure'},
 'more pressured/_n': {'e_noun._n': 'more pressure'},
 'intense pressured/_n': {'e_noun._n': 'intense pressure'},
 'that pressured/_n': {'e_noun._n': 'that pressure'},
 'such pressured/_n': {'e_noun._n': 'such pressure'},
 'air pressured/_n': {'e_noun._n': 'air pressure'},
 'increasing pressured/_n': {'e_noun._n': 'increasing pressure'},
 'high pressured/_n': {'e_noun._n': 'high pressure'},
 'enormous pressured/_n': {'e_noun._n': 'enormous pressure'},
 'tremendous pressured/_n': {'e_noun._n': 'tremendous pressure'},
 'the pressured/_n': {'e_noun._n': 'the pressure'},
 'public pressured/_n': {'e_noun._n': 'public pressure'},
 'any pressured/_n': {'e_noun._n': 'any pressure'},
 'heavy pressured/_n': {'e_noun._n': 'heavy pressure'},
 'political pressured/_n': {'e_noun._n': 'political pressure'},
 'this pressures/_n': {'e_noun._n': 'those pressures'},
 'the presumable/_n': {'e_noun._n': 'the presumption'},
 'aids preventable/_n': {'e_noun._n': 'aids prevention'},
 'criminal prevention/_n': {'e_noun._n': 'crime prevention'},
 'crime preventable/_n': {'e_noun._n': 'crime prevention'},
 'energetic prices/_n': {'e_noun._n': 'energy prices'},
 'the averaged price/_n': {'e_noun._n': 'the average price'},
 'golden prices/_n': {'e_noun._n': 'gold prices'},
 'the price of golden/_n': {'e_noun._n': 'the price of gold'},
 'consuming prices/_n': {'e_noun._n': 'consumer prices'},
 'computational prices/_n': {'e_noun._n': 'computer prices'},
 'milky prices/_n': {'e_noun._n': 'milk prices'},
 'landed prices/_n': {'e_noun._n': 'land prices'},
 'electric prices/_n': {'e_noun._n': 'electricity prices'},
 'nation pride/_n': {'e_noun._n': 'national pride'},
 'this principles/_n': {'e_noun._n': 'those principles'},
 'personal private/_n': {'e_noun._n': 'personal privacy'},
 'online private/_n': {'e_noun._n': 'online privacy'},
 'all probable/_n': {'e_noun._n': 'all probability'},
 'a serious problematic/_n': {'e_noun._n': 'a serious problem'},
 'every problematic/_n': {'e_noun._n': 'every problem'},
 'the same problematic/_n': {'e_noun._n': 'the same problem'},
 'the main problematic/_n': {'e_noun._n': 'the main problem'},
 'our problematic/_n': {'e_noun._n': 'our problem'},
 'not a problematic/_n': {'e_noun._n': 'not a problem'},
 'the real problematic/_n': {'e_noun._n': 'the real problem'},
 'the only problematic/_n': {'e_noun._n': 'the only problem'},
 'secure problems/_n': {'e_noun._n': 'security problems'},
 'any problematic/_n': {'e_noun._n': 'any problem'},
 'no problematic/_n': {'e_noun._n': 'no problem'},
 'her problematic/_n': {'e_noun._n': 'her problem'},
 'society problems/_n': {'e_noun._n': 'social problems'},
 'healthy problems/_n': {'e_noun._n': 'health problems'},
 'one problematic/_n': {'e_noun._n': 'one problem'},
 'that problematic/_n': {'e_noun._n': 'that problem'},
 'my problematic/_n': {'e_noun._n': 'my problem'},
 'not the problematic/_n': {'e_noun._n': 'not the problem'},
 'their problematic/_n': {'e_noun._n': 'their problem'},
 'the drug problematic/_n': {'e_noun._n': 'the drug problem'},
 'his problematic/_n': {'e_noun._n': 'his problem'},
 'your problematic/_n': {'e_noun._n': 'your problem'},
 'computational problems/_n': {'e_noun._n': 'computer problems'},
 'a major problematic/_n': {'e_noun._n': 'a major problem'},
 'a big problematic/_n': {'e_noun._n': 'a big problem'},
 'the biggest problematic/_n': {'e_noun._n': 'the biggest problem'},
 'psychology problems/_n': {'e_noun._n': 'psychological problems'},
 'safe problems/_n': {'e_noun._n': 'safety problems'},
 'another problematic/_n': {'e_noun._n': 'another problem'},
 'this problems/_n': {'e_noun._n': 'those problems'},
 'this procedures/_n': {'e_noun._n': 'those procedures'},
 'that procedural/_n': {'e_noun._n': 'that procedure'},
 'the selective process/_n': {'e_noun._n': 'the selection process'},
 'bloody products/_n': {'e_noun._n': 'blood products'},
 'forested products/_n': {'e_noun._n': 'forest products'},
 'this products/_n': {'e_noun._n': 'those products'},
 'woody products/_n': {'e_noun._n': 'wood products'},
 'beautiful products/_n': {'e_noun._n': 'beauty products'},
 'higher productive/_n': {'e_noun._n': 'higher production'},
 'video productive/_n': {'e_noun._n': 'video production'},
 'commercial productive/_n': {'e_noun._n': 'commercial production'},
 'manufacturing productive/_n': {'e_noun._n': 'manufacturing production'},
 'the productive/_n': {'e_noun._n': 'the production'},
 'his productive/_n': {'e_noun._n': 'his production'},
 'full productive/_n': {'e_noun._n': 'full production'},
 'food productive/_n': {'e_noun._n': 'food production'},
 'annual productive/_n': {'e_noun._n': 'annual production'},
 'lower productive/_n': {'e_noun._n': 'lower production'},
 'milky production/_n': {'e_noun._n': 'milk production'},
 'milk productive/_n': {'e_noun._n': 'milk production'},
 'their productive/_n': {'e_noun._n': 'their production'},
 'current productive/_n': {'e_noun._n': 'current production'},
 'steel productive/_n': {'e_noun._n': 'steel production'},
 'lost productive/_n': {'e_noun._n': 'lost production'},
 'oil productive/_n': {'e_noun._n': 'oil production'},
 'high productive/_n': {'e_noun._n': 'high production'},
 'that productive/_n': {'e_noun._n': 'that production'},
 'energetic production/_n': {'e_noun._n': 'energy production'},
 'energy productive/_n': {'e_noun._n': 'energy production'},
 'rising productive/_n': {'e_noun._n': 'rising production'},
 'world productive/_n': {'e_noun._n': 'world production'},
 'new productive/_n': {'e_noun._n': 'new production'},
 'its productive/_n': {'e_noun._n': 'its production'},
 'television productive/_n': {'e_noun._n': 'television production'},
 'auto productive/_n': {'e_noun._n': 'auto production'},
 'industry production/_n': {'e_noun._n': 'industrial production'},
 'increased productive/_n': {'e_noun._n': 'increased production'},
 'domestic productive/_n': {'e_noun._n': 'domestic production'},
 'gas productive/_n': {'e_noun._n': 'gas production'},
 'total productive/_n': {'e_noun._n': 'total production'},
 'workless productivity/_n': {'e_noun._n': 'worker productivity'},
 'healthy professionals/_n': {'e_noun._n': 'health professionals'},
 'a professionalism/_n': {'e_noun._n': 'a professional'},
 'current profitable/_n': {'e_noun._n': 'current profit'},
 'corporate profitable/_n': {'e_noun._n': 'corporate profit'},
 'their profitable/_n': {'e_noun._n': 'their profit'},
 'net profitable/_n': {'e_noun._n': 'net profit'},
 'operating profitable/_n': {'e_noun._n': 'operating profit'},
 'governing programs/_n': {'e_noun._n': 'government programs'},
 'treated programs/_n': {'e_noun._n': 'treatment programs'},
 'computational programs/_n': {'e_noun._n': 'computer programs'},
 'this programs/_n': {'e_noun._n': 'those programs'},
 'a computational program/_n': {'e_noun._n': 'a computer program'},
 'computational programmers/_n': {'e_noun._n': 'computer programmers'},
 'that progressive/_n': {'e_noun._n': 'that progress'},
 'real progressive/_n': {'e_noun._n': 'real progress'},
 'more progressive/_n': {'e_noun._n': 'more progress'},
 'little progressive/_n': {'e_noun._n': 'little progress'},
 'some progressive/_n': {'e_noun._n': 'some progress'},
 'their progressive/_n': {'e_noun._n': 'their progress'},
 'significant progressive/_n': {'e_noun._n': 'significant progress'},
 'economy progress/_n': {'e_noun._n': 'economic progress'},
 'no progressive/_n': {'e_noun._n': 'no progress'},
 'economic progressive/_n': {'e_noun._n': 'economic progress'},
 'its progressive/_n': {'e_noun._n': 'its progress'},
 'any progressive/_n': {'e_noun._n': 'any progress'},
 'his progressive/_n': {'e_noun._n': 'his progress'},
 'much progressive/_n': {'e_noun._n': 'much progress'},
 'the prohibitive/_n': {'e_noun._n': 'the prohibition'},
 'developed projects/_n': {'e_noun._n': 'development projects'},
 'specialist projects/_n': {'e_noun._n': 'special projects'},
 'constructive projects/_n': {'e_noun._n': 'construction projects'},
 'this projects/_n': {'e_noun._n': 'those projects'},
 'society promotion/_n': {'e_noun._n': 'social promotion'},
 'governing property/_n': {'e_noun._n': 'government property'},
 'a specialist prosecutor/_n': {'e_noun._n': 'a special prosecutor'},
 'economy prosperity/_n': {'e_noun._n': 'economic prosperity'},
 'some protective/_n': {'e_noun._n': 'some protection'},
 'environment protections/_n': {'e_noun._n': 'environmental protections'},
 'patent protective/_n': {'e_noun._n': 'patent protection'},
 'their protective/_n': {'e_noun._n': 'their protection'},
 'bankruptcy protective/_n': {'e_noun._n': 'bankruptcy protection'},
 'equal protective/_n': {'e_noun._n': 'equal protection'},
 'such protective/_n': {'e_noun._n': 'such protection'},
 'legal protective/_n': {'e_noun._n': 'legal protection'},
 'healthy care providers/_n': {'e_noun._n': 'health care providers'},
 'health careful providers/_n': {'e_noun._n': 'health care providers'},
 'that provisional/_n': {'e_noun._n': 'that provision'},
 'a clinical psychological/_n': {'e_noun._n': 'a clinical psychologist'},
 'tradable publications/_n': {'e_noun._n': 'trade publications'},
 'bad publical/_n': {'e_noun._n': 'bad publicity'},
 'negative publical/_n': {'e_noun._n': 'negative publicity'},
 'the publical/_n': {'e_noun._n': 'the publicity'},
 'bonding purchases/_n': {'e_noun._n': 'bond purchases'},
 'taxable purposes/_n': {'e_noun._n': 'tax purposes'},
 'a pushy/_n': {'e_noun._n': 'a push'},
 'the pushy/_n': {'e_noun._n': 'the push'},
 'this qualities/_n': {'e_noun._n': 'those qualities'},
 'the second quarter of those year/_n': {'e_noun._n': 'the second quarter of this year'},
 'the first quarter of those year/_n': {'e_noun._n': 'the first quarter of this year'},
 'this questions/_n': {'e_noun._n': 'those questions'},
 'his questionable/_n': {'e_noun._n': 'his quickness'},
 'third races/_n': {'e_noun._n': 'three races'},
 'this races/_n': {'e_noun._n': 'those races'},
 'difference races/_n': {'e_noun._n': 'different races'},
 'living radio/_n': {'e_noun._n': 'live radio'},
 'the taxable rate/_n': {'e_noun._n': 'the tax rate'},
 'taxable rates/_n': {'e_noun._n': 'tax rates'},
 'the criminal rate/_n': {'e_noun._n': 'the crime rate'},
 'grown rates/_n': {'e_noun._n': 'growth rates'},
 'criminal rates/_n': {'e_noun._n': 'crime rates'},
 'the grown rate/_n': {'e_noun._n': 'the growth rate'},
 'their reactive/_n': {'e_noun._n': 'their reaction'},
 'her reactive/_n': {'e_noun._n': 'her reaction'},
 'his reactive/_n': {'e_noun._n': 'his reaction'},
 'that reactive/_n': {'e_noun._n': 'that reaction'},
 'my reactive/_n': {'e_noun._n': 'my reaction'},
 'rapid reactive/_n': {'e_noun._n': 'rapid reaction'},
 'my first reactive/_n': {'e_noun._n': 'my first reaction'},
 'a reactive/_n': {'e_noun._n': 'a reaction'},
 'economic real/_n': {'e_noun._n': 'economic reality'},
 'every reasonable/_n': {'e_noun._n': 'every reason'},
 'any reasonable/_n': {'e_noun._n': 'any reason'},
 'that reasonable/_n': {'e_noun._n': 'that reason'},
 'this reasons/_n': {'e_noun._n': 'those reasons'},
 'safe reasons/_n': {'e_noun._n': 'safety reasons'},
 'main reasonable/_n': {'e_noun._n': 'main reason'},
 'the same reasonable/_n': {'e_noun._n': 'the same reason'},
 'the main reasonable/_n': {'e_noun._n': 'the main reason'},
 'variety reasons/_n': {'e_noun._n': 'various reasons'},
 'one reasonable/_n': {'e_noun._n': 'one reason'},
 'no apparent reasonable/_n': {'e_noun._n': 'no apparent reason'},
 'good reasonable/_n': {'e_noun._n': 'good reason'},
 'healthy reasons/_n': {'e_noun._n': 'health reasons'},
 'a good reasonable/_n': {'e_noun._n': 'a good reason'},
 'some reasonable/_n': {'e_noun._n': 'some reason'},
 'whatever reasonable/_n': {'e_noun._n': 'whatever reason'},
 'third reasons/_n': {'e_noun._n': 'three reasons'},
 'no good reasonable/_n': {'e_noun._n': 'no good reason'},
 'secure reasons/_n': {'e_noun._n': 'security reasons'},
 'no reasonable/_n': {'e_noun._n': 'no reason'},
 'another reasonable/_n': {'e_noun._n': 'another reason'},
 'sixteenth rebounds/_n': {'e_noun._n': 'six rebounds'},
 'taxable receipts/_n': {'e_noun._n': 'tax receipts'},
 'this records/_n': {'e_noun._n': 'those records'},
 'crime records/_n': {'e_noun._n': 'criminal records'},
 'the attendant record/_n': {'e_noun._n': 'the attendance record'},
 'handed recounts/_n': {'e_noun._n': 'hand recounts'},
 'economic recoverable/_n': {'e_noun._n': 'economic recovery'},
 'the economic recoverable/_n': {'e_noun._n': 'the economic recovery'},
 'the recoverable/_n': {'e_noun._n': 'the recovery'},
 'a recoverable/_n': {'e_noun._n': 'a recovery'},
 'its recoverable/_n': {'e_noun._n': 'its recovery'},
 'his recoverable/_n': {'e_noun._n': 'his recovery'},
 'a full recoverable/_n': {'e_noun._n': 'a full recovery'},
 'an economic recoverable/_n': {'e_noun._n': 'an economic recovery'},
 'her recoverable/_n': {'e_noun._n': 'her recovery'},
 'taxable reductions/_n': {'e_noun._n': 'tax reductions'},
 'costly reductions/_n': {'e_noun._n': 'cost reductions'},
 'social secure reform/_n': {'e_noun._n': 'social security reform'},
 'healthy care reform/_n': {'e_noun._n': 'health care reform'},
 'health careful reform/_n': {'e_noun._n': 'health care reform'},
 'this reforms/_n': {'e_noun._n': 'those reforms'},
 'immigrant reform/_n': {'e_noun._n': 'immigration reform'},
 'economy reform/_n': {'e_noun._n': 'economic reform'},
 'the asia-pacific regional/_n': {'e_noun._n': 'the asia-pacific region'},
 'our regional/_n': {'e_noun._n': 'our region'},
 'this regions/_n': {'e_noun._n': 'those regions'},
 'the entire regional/_n': {'e_noun._n': 'the entire region'},
 'his regional/_n': {'e_noun._n': 'his region'},
 'difference regions/_n': {'e_noun._n': 'different regions'},
 'each regional/_n': {'e_noun._n': 'each region'},
 'votable registration/_n': {'e_noun._n': 'voter registration'},
 'the regularity/_n': {'e_noun._n': 'the regular'},
 'this regulations/_n': {'e_noun._n': 'those regulations'},
 'governing regulations/_n': {'e_noun._n': 'government regulations'},
 'governing regulation/_n': {'e_noun._n': 'government regulation'},
 'safe regulations/_n': {'e_noun._n': 'safety regulations'},
 'environment regulation/_n': {'e_noun._n': 'environmental regulation'},
 'governing regulators/_n': {'e_noun._n': 'government regulators'},
 'the rejective/_n': {'e_noun._n': 'the rejection'},
 'governing relations/_n': {'e_noun._n': 'government relations'},
 'this relationships/_n': {'e_noun._n': 'those relationships'},
 'painful relief/_n': {'e_noun._n': 'pain relief'},
 'taxable relief/_n': {'e_noun._n': 'tax relief'},
 'his religious/_n': {'e_noun._n': 'his religion'},
 'organized religious/_n': {'e_noun._n': 'organized religion'},
 'my religious/_n': {'e_noun._n': 'my religion'},
 'her religious/_n': {'e_noun._n': 'her religion'},
 'his reluctant/_n': {'e_noun._n': 'his reluctance'},
 'their reluctant/_n': {'e_noun._n': 'their reluctance'},
 'that remarkable/_n': {'e_noun._n': 'that remark'},
 'this remarks/_n': {'e_noun._n': 'those remarks'},
 'their removable/_n': {'e_noun._n': 'their removal'},
 'a replaceable/_n': {'e_noun._n': 'a replacement'},
 'his replaceable/_n': {'e_noun._n': 'his replacement'},
 'the replaceable/_n': {'e_noun._n': 'the replacement'},
 'hip replaceable/_n': {'e_noun._n': 'hip replacement'},
 'a governing report/_n': {'e_noun._n': 'a government report'},
 'this reports/_n': {'e_noun._n': 'those reports'},
 'governing reports/_n': {'e_noun._n': 'government reports'},
 'legal representative/_n': {'e_noun._n': 'legal representation'},
 'industrial representatives/_n': {'e_noun._n': 'industry representatives'},
 'this requests/_n': {'e_noun._n': 'those requests'},
 'workless requirements/_n': {'e_noun._n': 'work requirements'},
 'this requirements/_n': {'e_noun._n': 'those requirements'},
 'scientist research/_n': {'e_noun._n': 'scientific research'},
 'some reservation/_n': {'e_noun._n': 'some reservations'},
 'golden reserves/_n': {'e_noun._n': 'gold reserves'},
 'his residential/_n': {'e_noun._n': 'his residence'},
 'least resistible/_n': {'e_noun._n': 'least resistance'},
 'drug resistible/_n': {'e_noun._n': 'drug resistance'},
 'no resistible/_n': {'e_noun._n': 'no resistance'},
 'conflictive resolution/_n': {'e_noun._n': 'conflict resolution'},
 'limit resources/_n': {'e_noun._n': 'limited resources'},
 'more respectful/_n': {'e_noun._n': 'more respect'},
 'no respectful/_n': {'e_noun._n': 'no respect'},
 'their respectful/_n': {'e_noun._n': 'their respect'},
 'some respectful/_n': {'e_noun._n': 'some respect'},
 'one respectful/_n': {'e_noun._n': 'one respect'},
 'that respectful/_n': {'e_noun._n': 'that respect'},
 'every respectful/_n': {'e_noun._n': 'every respect'},
 'mutual respectful/_n': {'e_noun._n': 'mutual respect'},
 'their respondent/_n': {'e_noun._n': 'their response'},
 'no respondent/_n': {'e_noun._n': 'no response'},
 'our respondent/_n': {'e_noun._n': 'our response'},
 'emergency respondent/_n': {'e_noun._n': 'emergency response'},
 'her respondent/_n': {'e_noun._n': 'her response'},
 'its respondent/_n': {'e_noun._n': 'its response'},
 'my respondent/_n': {'e_noun._n': 'my response'},
 'his respondent/_n': {'e_noun._n': 'his response'},
 'his responsible/_n': {'e_noun._n': 'his responsibility'},
 'responsible for/_n': {'e_noun._n': 'responsibility for'},
 'their responsible/_n': {'e_noun._n': 'their responsibility'},
 'its responsible/_n': {'e_noun._n': 'its responsibility'},
 'more responsible/_n': {'e_noun._n': 'more responsibility'},
 'society responsibility/_n': {'e_noun._n': 'social responsibility'},
 'that responsible/_n': {'e_noun._n': 'that responsibility'},
 'our responsible/_n': {'e_noun._n': 'our responsibility'},
 'my responsible/_n': {'e_noun._n': 'my responsibility'},
 'corporate responsible/_n': {'e_noun._n': 'corporate responsibility'},
 'some responsible/_n': {'e_noun._n': 'some responsibility'},
 'full responsible/_n': {'e_noun._n': 'full responsibility'},
 'individual responsible/_n': {'e_noun._n': 'individual responsibility'},
 'personal responsible/_n': {'e_noun._n': 'personal responsibility'},
 'the rest of the filmed/_n': {'e_noun._n': 'the rest of the film'},
 'the rest of the weekly/_n': {'e_noun._n': 'the rest of the week'},
 'the rest of the national/_n': {'e_noun._n': 'the rest of the nation'},
 'thematic restaurants/_n': {'e_noun._n': 'theme restaurants'},
 'the restrictive/_n': {'e_noun._n': 'the restriction'},
 'travelled restrictions/_n': {'e_noun._n': 'travel restrictions'},
 'this restrictions/_n': {'e_noun._n': 'those restrictions'},
 'tested results/_n': {'e_noun._n': 'test results'},
 'the ended result/_n': {'e_noun._n': 'the end result'},
 'elect results/_n': {'e_noun._n': 'election results'},
 'the tested results/_n': {'e_noun._n': 'the test results'},
 'this results/_n': {'e_noun._n': 'those results'},
 'governing revenue/_n': {'e_noun._n': 'government revenue'},
 'taxable revenue/_n': {'e_noun._n': 'tax revenue'},
 'governing revenues/_n': {'e_noun._n': 'government revenues'},
 'this revenues/_n': {'e_noun._n': 'those revenues'},
 'taxable revenues/_n': {'e_noun._n': 'tax revenues'},
 'the reversible/_n': {'e_noun._n': 'the reversal'},
 'yellowish ribbons/_n': {'e_noun._n': 'yellow ribbons'},
 'gold rice/_n': {'e_noun._n': 'golden rice'},
 'the right to votable/_n': {'e_noun._n': 'the right to vote'},
 'this rights/_n': {'e_noun._n': 'those rights'},
 'healthy risks/_n': {'e_noun._n': 'health risks'},
 'low risky/_n': {'e_noun._n': 'low risk'},
 'more risky/_n': {'e_noun._n': 'more risk'},
 'little risky/_n': {'e_noun._n': 'little risk'},
 'high risky/_n': {'e_noun._n': 'high risk'},
 'this risks/_n': {'e_noun._n': 'those risks'},
 'greater risky/_n': {'e_noun._n': 'greater risk'},
 'higher risky/_n': {'e_noun._n': 'higher risk'},
 'some risky/_n': {'e_noun._n': 'some risk'},
 'less risky/_n': {'e_noun._n': 'less risk'},
 'that risky/_n': {'e_noun._n': 'that risk'},
 'no risky/_n': {'e_noun._n': 'no risk'},
 'great risky/_n': {'e_noun._n': 'great risk'},
 'their risky/_n': {'e_noun._n': 'their risk'},
 'modern rocky/_n': {'e_noun._n': 'modern rock'},
 'classical rock/_n': {'e_noun._n': 'classic rock'},
 'classic rocky/_n': {'e_noun._n': 'classic rock'},
 'this roles/_n': {'e_noun._n': 'those roles'},
 'a center role/_n': {'e_noun._n': 'a central role'},
 'an importance role/_n': {'e_noun._n': 'an important role'},
 'a significance role/_n': {'e_noun._n': 'a significant role'},
 'third rounds/_n': {'e_noun._n': 'three rounds'},
 'this routes/_n': {'e_noun._n': 'those routes'},
 'this rules/_n': {'e_noun._n': 'those rules'},
 'civil rule/_n': {'e_noun._n': 'civilian rule'},
 'the rule of lawful/_n': {'e_noun._n': 'the rule of law'},
 'safe rules/_n': {'e_noun._n': 'safety rules'},
 'housed rules/_n': {'e_noun._n': 'house rules'},
 'major rule/_n': {'e_noun._n': 'majority rule'},
 'this rumors/_n': {'e_noun._n': 'those rumors'},
 'the sacrificial/_n': {'e_noun._n': 'the sacrifice'},
 'patient safe/_n': {'e_noun._n': 'patient safety'},
 'good safe/_n': {'e_noun._n': 'good safety'},
 'school safe/_n': {'e_noun._n': 'school safety'},
 'strong safe/_n': {'e_noun._n': 'strong safety'},
 'serious safe/_n': {'e_noun._n': 'serious safety'},
 'gun safe/_n': {'e_noun._n': 'gun safety'},
 'nuclear safe/_n': {'e_noun._n': 'nuclear safety'},
 'their safe/_n': {'e_noun._n': 'their safety'},
 'air safe/_n': {'e_noun._n': 'air safety'},
 'computational sales/_n': {'e_noun._n': 'computer sales'},
 'this sales/_n': {'e_noun._n': 'those sales'},
 'landed sales/_n': {'e_noun._n': 'land sales'},
 'exporting sales/_n': {'e_noun._n': 'export sales'},
 'bloody samples/_n': {'e_noun._n': 'blood samples'},
 'tradable sanctions/_n': {'e_noun._n': 'trade sanctions'},
 'costly savings/_n': {'e_noun._n': 'cost savings'},
 'this scenes/_n': {'e_noun._n': 'those scenes'},
 'the criminal scene/_n': {'e_noun._n': 'the crime scene'},
 'criminal scenes/_n': {'e_noun._n': 'crime scenes'},
 'a criminal scene/_n': {'e_noun._n': 'a crime scene'},
 'his schematic/_n': {'e_noun._n': 'his scheme'},
 'rocket scientific/_n': {'e_noun._n': 'rocket science'},
 'base science/_n': {'e_noun._n': 'basic science'},
 'basic scientific/_n': {'e_noun._n': 'basic science'},
 'a rocket scientific/_n': {'e_noun._n': 'a rocket scientist'},
 'computational scientists/_n': {'e_noun._n': 'computer scientists'},
 'tested scores/_n': {'e_noun._n': 'test scores'},
 'the computational screen/_n': {'e_noun._n': 'the computer screen'},
 'computational screens/_n': {'e_noun._n': 'computer screens'},
 'a computational screen/_n': {'e_noun._n': 'a computer screen'},
 'third seasons/_n': {'e_noun._n': 'three seasons'},
 'the exhibited season/_n': {'e_noun._n': 'the exhibition season'},
 'sixteenth seasons/_n': {'e_noun._n': 'six seasons'},
 'this seats/_n': {'e_noun._n': 'those seats'},
 'a secrecy/_n': {'e_noun._n': 'a secret'},
 'specialist section/_n': {'e_noun._n': 'special section'},
 'the technological sector/_n': {'e_noun._n': 'the technology sector'},
 'economic secure/_n': {'e_noun._n': 'economic security'},
 'their secure/_n': {'e_noun._n': 'their security'},
 'tight secure/_n': {'e_noun._n': 'tight security'},
 'financial secure/_n': {'e_noun._n': 'financial security'},
 'regional secure/_n': {'e_noun._n': 'regional security'},
 'home secure/_n': {'e_noun._n': 'home security'},
 'top secure/_n': {'e_noun._n': 'top security'},
 'increased secure/_n': {'e_noun._n': 'increased security'},
 'private secure/_n': {'e_noun._n': 'private security'},
 'american secure/_n': {'e_noun._n': 'american security'},
 'economy security/_n': {'e_noun._n': 'economic security'},
 'its secure/_n': {'e_noun._n': 'its security'},
 'domestic secure/_n': {'e_noun._n': 'domestic security'},
 'maximum secure/_n': {'e_noun._n': 'maximum security'},
 'internal secure/_n': {'e_noun._n': 'internal security'},
 'airport secure/_n': {'e_noun._n': 'airport security'},
 'nation security/_n': {'e_noun._n': 'national security'},
 'privacy security/_n': {'e_noun._n': 'private security'},
 'state secure/_n': {'e_noun._n': 'state security'},
 'high secure/_n': {'e_noun._n': 'high security'},
 'new secure/_n': {'e_noun._n': 'new security'},
 'specialist security/_n': {'e_noun._n': 'special security'},
 'special secure/_n': {'e_noun._n': 'special security'},
 'personal secure/_n': {'e_noun._n': 'personal security'},
 'additional secure/_n': {'e_noun._n': 'additional security'},
 'our secure/_n': {'e_noun._n': 'our security'},
 'more secure/_n': {'e_noun._n': 'more security'},
 'his selective/_n': {'e_noun._n': 'his selection'},
 'much sensible/_n': {'e_noun._n': 'much sense'},
 'another sensible/_n': {'e_noun._n': 'another sense'},
 'good sensible/_n': {'e_noun._n': 'good sense'},
 'perfect sensible/_n': {'e_noun._n': 'perfect sense'},
 'one sensible/_n': {'e_noun._n': 'one sense'},
 'no sensible/_n': {'e_noun._n': 'no sense'},
 'little sensible/_n': {'e_noun._n': 'little sense'},
 'more sensible/_n': {'e_noun._n': 'more sense'},
 'every sensible/_n': {'e_noun._n': 'every sense'},
 'his sensible of humor/_n': {'e_noun._n': 'his sense of humor'},
 'economic sensible/_n': {'e_noun._n': 'economic sense'},
 'our sensible/_n': {'e_noun._n': 'our sense'},
 'any sensible/_n': {'e_noun._n': 'any sense'},
 'some sensible/_n': {'e_noun._n': 'some sense'},
 'that sensible/_n': {'e_noun._n': 'that sense'},
 'a sensible of urgency/_n': {'e_noun._n': 'a sense of urgency'},
 'a sense of urgent/_n': {'e_noun._n': 'a sense of urgency'},
 'my sensible/_n': {'e_noun._n': 'my sense'},
 'dead sentences/_n': {'e_noun._n': 'death sentences'},
 'a dead sentence/_n': {'e_noun._n': 'a death sentence'},
 'the dead sentence/_n': {'e_noun._n': 'the death sentence'},
 'consuming sentiment/_n': {'e_noun._n': 'consumer sentiment'},
 'the sequential/_n': {'e_noun._n': 'the sequence'},
 'governing services/_n': {'e_noun._n': 'government services'},
 'this services/_n': {'e_noun._n': 'those services'},
 'supported services/_n': {'e_noun._n': 'support services'},
 'informing services/_n': {'e_noun._n': 'information services'},
 'base service/_n': {'e_noun._n': 'basic service'},
 'governing service/_n': {'e_noun._n': 'government service'},
 'base services/_n': {'e_noun._n': 'basic services'},
 'specialist services/_n': {'e_noun._n': 'special services'},
 'computational services/_n': {'e_noun._n': 'computer services'},
 'the opposite sexual/_n': {'e_noun._n': 'the opposite sex'},
 'the same sexual/_n': {'e_noun._n': 'the same sex'},
 'explicit sexual/_n': {'e_noun._n': 'explicit sex'},
 'gay sexual/_n': {'e_noun._n': 'gay sex'},
 'unprotected sexual/_n': {'e_noun._n': 'unprotected sex'},
 'his shadowy/_n': {'e_noun._n': 'his shadow'},
 'no shameful/_n': {'e_noun._n': 'no shame'},
 'golden shares/_n': {'e_noun._n': 'gold shares'},
 'storing shelves/_n': {'e_noun._n': 'store shelves'},
 'gifted shops/_n': {'e_noun._n': 'gift shops'},
 'a short timeless/_n': {'e_noun._n': 'a short time'},
 'a shortness/_n': {'e_noun._n': 'a short'},
 'this shots/_n': {'e_noun._n': 'those shots'},
 'third shots/_n': {'e_noun._n': 'three shots'},
 'tradable shows/_n': {'e_noun._n': 'trade shows'},
 'third sides/_n': {'e_noun._n': 'three sides'},
 'both sides of the issued/_n': {'e_noun._n': 'both sides of the issue'},
 'its significant/_n': {'e_noun._n': 'its significance'},
 'historical significant/_n': {'e_noun._n': 'historical significance'},
 'his silent/_n': {'e_noun._n': 'his silence'},
 'her silent/_n': {'e_noun._n': 'her silence'},
 'their silent/_n': {'e_noun._n': 'their silence'},
 'a silverish/_n': {'e_noun._n': 'a silver'},
 'a simpleness/_n': {'e_noun._n': 'a simple'},
 'the simulate/_n': {'e_noun._n': 'the simulation'},
 'computational simulations/_n': {'e_noun._n': 'computer simulations'},
 'his sincere/_n': {'e_noun._n': 'his sincerity'},
 'his sing/_n': {'e_noun._n': 'his singing'},
 'third singles/_n': {'e_noun._n': 'three singles'},
 'the singleness/_n': {'e_noun._n': 'the single'},
 'his sisterly/_n': {'e_noun._n': 'his sister'},
 'your sisterly/_n': {'e_noun._n': 'your sister'},
 'her sisterly/_n': {'e_noun._n': 'her sister'},
 'third sisters/_n': {'e_noun._n': 'three sisters'},
 'a sisterly/_n': {'e_noun._n': 'a sister'},
 'its sisterly/_n': {'e_noun._n': 'its sister'},
 'my sisterly/_n': {'e_noun._n': 'my sister'},
 'their sisterly/_n': {'e_noun._n': 'their sister'},
 'whose sisterly/_n': {'e_noun._n': 'whose sister'},
 'constructive sites/_n': {'e_noun._n': 'construction sites'},
 'history sites/_n': {'e_noun._n': 'historic sites'},
 'the crashed site/_n': {'e_noun._n': 'the crash site'},
 'this sites/_n': {'e_noun._n': 'those sites'},
 'every situated/_n': {'e_noun._n': 'every situation'},
 'a similar situated/_n': {'e_noun._n': 'a similar situation'},
 'their situated/_n': {'e_noun._n': 'their situation'},
 'this situations/_n': {'e_noun._n': 'those situations'},
 'the current situated/_n': {'e_noun._n': 'the current situation'},
 'such a situated/_n': {'e_noun._n': 'such a situation'},
 'our situated/_n': {'e_noun._n': 'our situation'},
 'my situated/_n': {'e_noun._n': 'my situation'},
 'the same situated/_n': {'e_noun._n': 'the same situation'},
 'her situated/_n': {'e_noun._n': 'her situation'},
 'that situated/_n': {'e_noun._n': 'that situation'},
 'any situated/_n': {'e_noun._n': 'any situation'},
 'a situated/_n': {'e_noun._n': 'a situation'},
 'his situated/_n': {'e_noun._n': 'his situation'},
 'the political situated/_n': {'e_noun._n': 'the political situation'},
 'your situated/_n': {'e_noun._n': 'your situation'},
 'a bad situated/_n': {'e_noun._n': 'a bad situation'},
 'all sixteenth/_n': {'e_noun._n': 'all six'},
 'only sixteenth/_n': {'e_noun._n': 'only six'},
 'sixteenth of them/_n': {'e_noun._n': 'six of them'},
 'that sized/_n': {'e_noun._n': 'that size'},
 'same sized/_n': {'e_noun._n': 'same size'},
 'his sized/_n': {'e_noun._n': 'his size'},
 'the sized of government/_n': {'e_noun._n': 'the size of government'},
 'the size of governing/_n': {'e_noun._n': 'the size of government'},
 'sheer sized/_n': {'e_noun._n': 'sheer size'},
 'the sized/_n': {'e_noun._n': 'the size'},
 'its sized/_n': {'e_noun._n': 'its size'},
 'any sized/_n': {'e_noun._n': 'any size'},
 'class sized/_n': {'e_noun._n': 'class size'},
 'the same sized/_n': {'e_noun._n': 'the same size'},
 'their sized/_n': {'e_noun._n': 'their size'},
 'one sized/_n': {'e_noun._n': 'one size'},
 'similar sized/_n': {'e_noun._n': 'similar size'},
 'his skilled/_n': {'e_noun._n': 'his skill'},
 'society skills/_n': {'e_noun._n': 'social skills'},
 'that skilled/_n': {'e_noun._n': 'that skill'},
 'this skills/_n': {'e_noun._n': 'those skills'},
 'its skinned/_n': {'e_noun._n': 'its skin'},
 'her skinned/_n': {'e_noun._n': 'her skin'},
 'our skinned/_n': {'e_noun._n': 'our skin'},
 'his skinned/_n': {'e_noun._n': 'his skin'},
 'their skinned/_n': {'e_noun._n': 'their skin'},
 'your skinned/_n': {'e_noun._n': 'your skin'},
 'dark skinned/_n': {'e_noun._n': 'dark skin'},
 'human skinned/_n': {'e_noun._n': 'human skin'},
 'my skinned/_n': {'e_noun._n': 'my skin'},
 'her sleeping/_n': {'e_noun._n': 'her sleep'},
 'their sleeping/_n': {'e_noun._n': 'their sleep'},
 'some sleeping/_n': {'e_noun._n': 'some sleep'},
 'his sleeping/_n': {'e_noun._n': 'his sleep'},
 'trouble sleep/_n': {'e_noun._n': 'trouble sleeping'},
 'enough sleeping/_n': {'e_noun._n': 'enough sleep'},
 'your sleeping/_n': {'e_noun._n': 'your sleep'},
 'troublesome sleeping/_n': {'e_noun._n': 'trouble sleeping'},
 'a sloped/_n': {'e_noun._n': 'a slope'},
 'the sloped/_n': {'e_noun._n': 'the slope'},
 'economy slowdown/_n': {'e_noun._n': 'economic slowdown'},
 'his smiling/_n': {'e_noun._n': 'his smile'},
 'a big smiling/_n': {'e_noun._n': 'a big smile'},
 'her smiling/_n': {'e_noun._n': 'her smile'},
 'teenage smoke/_n': {'e_noun._n': 'teenage smoking'},
 'youth smoke/_n': {'e_noun._n': 'youth smoking'},
 'second-hand smoking/_n': {'e_noun._n': 'second-hand smoke'},
 'a free social/_n': {'e_noun._n': 'a free society'},
 'that social/_n': {'e_noun._n': 'that society'},
 "today's social/_n": {'e_noun._n': "today's society"},
 'polite social/_n': {'e_noun._n': 'polite society'},
 'specialist software/_n': {'e_noun._n': 'special software'},
 'personal computational software/_n': {'e_noun._n': 'personal computer software'},
 'foreign soiled/_n': {'e_noun._n': 'foreign soil'},
 'its soiled/_n': {'e_noun._n': 'its soil'},
 'american soiled/_n': {'e_noun._n': 'american soil'},
 'their soiled/_n': {'e_noun._n': 'their soil'},
 'governing soldiers/_n': {'e_noun._n': 'government soldiers'},
 'a solidified/_n': {'e_noun._n': 'a solid'},
 'a solved/_n': {'e_noun._n': 'a solution'},
 'the only solved/_n': {'e_noun._n': 'the only solution'},
 'one solved/_n': {'e_noun._n': 'one solution'},
 'no solved/_n': {'e_noun._n': 'no solution'},
 'the solved/_n': {'e_noun._n': 'the solution'},
 'his solved/_n': {'e_noun._n': 'his solution'},
 'any solved/_n': {'e_noun._n': 'any solution'},
 'the best solved/_n': {'e_noun._n': 'the best solution'},
 'another solved/_n': {'e_noun._n': 'another solution'},
 'something like those/_n': {'e_noun._n': 'something like this'},
 'something specialist/_n': {'e_noun._n': 'something special'},
 'third sons/_n': {'e_noun._n': 'three sons'},
 'some sorted/_n': {'e_noun._n': 'some sort'},
 'another sorted/_n': {'e_noun._n': 'another sort'},
 'that sorted/_n': {'e_noun._n': 'that sort'},
 'one sorted/_n': {'e_noun._n': 'one sort'},
 'a different sorted/_n': {'e_noun._n': 'a different sort'},
 'a sorted/_n': {'e_noun._n': 'a sort'},
 'that sorted of thing/_n': {'e_noun._n': 'that sort of thing'},
 'any sorted/_n': {'e_noun._n': 'any sort'},
 'that sounding/_n': {'e_noun._n': 'that sound'},
 'its sounding/_n': {'e_noun._n': 'its sound'},
 'his sounding/_n': {'e_noun._n': 'his sound'},
 'their sounding/_n': {'e_noun._n': 'their sound'},
 'its sourced/_n': {'e_noun._n': 'its source'},
 'a sourced/_n': {'e_noun._n': 'a source'},
 'another sourced/_n': {'e_noun._n': 'another source'},
 'one sourced/_n': {'e_noun._n': 'one source'},
 'their sourced/_n': {'e_noun._n': 'their source'},
 'governing sources/_n': {'e_noun._n': 'government sources'},
 'this sources/_n': {'e_noun._n': 'those sources'},
 'nation sovereignty/_n': {'e_noun._n': 'national sovereignty'},
 'advertising spaced/_n': {'e_noun._n': 'advertising space'},
 'more spaced/_n': {'e_noun._n': 'more space'},
 'the spaced/_n': {'e_noun._n': 'the space'},
 'their spaced/_n': {'e_noun._n': 'their space'},
 'storage spaced/_n': {'e_noun._n': 'storage space'},
 'empty spaced/_n': {'e_noun._n': 'empty space'},
 'that spaced/_n': {'e_noun._n': 'that space'},
 'shelf spaced/_n': {'e_noun._n': 'shelf space'},
 'a spaced/_n': {'e_noun._n': 'a space'},
 'open spaced/_n': {'e_noun._n': 'open space'},
 'floor spaced/_n': {'e_noun._n': 'floor space'},
 'new spaced/_n': {'e_noun._n': 'new space'},
 'its spaced/_n': {'e_noun._n': 'its space'},
 'russian spaced/_n': {'e_noun._n': 'russian space'},
 'speaking of the house/_n': {'e_noun._n': 'speaker of the house'},
 'speaker of the housed/_n': {'e_noun._n': 'speaker of the house'},
 'a specialization/_n': {'e_noun._n': 'a specialist'},
 'commercial speaking/_n': {'e_noun._n': 'commercial speech'},
 'her speaking/_n': {'e_noun._n': 'her speech'},
 'his acceptable speech/_n': {'e_noun._n': 'his acceptance speech'},
 'his acceptance speaking/_n': {'e_noun._n': 'his acceptance speech'},
 "the president's speaking/_n": {'e_noun._n': "the president's speech"},
 'his speaking/_n': {'e_noun._n': 'his speech'},
 "gore's speaking/_n": {'e_noun._n': "gore's speech"},
 'political speaking/_n': {'e_noun._n': 'political speech'},
 'hate speaking/_n': {'e_noun._n': 'hate speech'},
 'his speeding/_n': {'e_noun._n': 'his speed'},
 'their speeding/_n': {'e_noun._n': 'their speed'},
 'warp speeding/_n': {'e_noun._n': 'warp speed'},
 'the speeding of sound/_n': {'e_noun._n': 'the speed of sound'},
 'the speed of sounding/_n': {'e_noun._n': 'the speed of sound'},
 'low speeding/_n': {'e_noun._n': 'low speed'},
 'its speeding/_n': {'e_noun._n': 'its speed'},
 'top speeding/_n': {'e_noun._n': 'top speed'},
 'breakneck speeding/_n': {'e_noun._n': 'breakneck speed'},
 'lightning speeding/_n': {'e_noun._n': 'lightning speed'},
 'great speeding/_n': {'e_noun._n': 'great speed'},
 'full speeding/_n': {'e_noun._n': 'full speed'},
 'more speeding/_n': {'e_noun._n': 'more speed'},
 'the speeding of light/_n': {'e_noun._n': 'the speed of light'},
 'personal spent/_n': {'e_noun._n': 'personal spending'},
 'state spent/_n': {'e_noun._n': 'state spending'},
 'time spending/_n': {'e_noun._n': 'time spent'},
 'domestic spent/_n': {'e_noun._n': 'domestic spending'},
 'governing spending/_n': {'e_noun._n': 'government spending'},
 'government spent/_n': {'e_noun._n': 'government spending'},
 'welfare spent/_n': {'e_noun._n': 'welfare spending'},
 'that spent/_n': {'e_noun._n': 'that spending'},
 'new spent/_n': {'e_noun._n': 'new spending'},
 'social spent/_n': {'e_noun._n': 'social spending'},
 'increased spent/_n': {'e_noun._n': 'increased spending'},
 'such spent/_n': {'e_noun._n': 'such spending'},
 'a spun/_n': {'e_noun._n': 'a spin'},
 'the spun/_n': {'e_noun._n': 'the spin'},
 'its spiritual/_n': {'e_noun._n': 'its spirit'},
 'the human spiritual/_n': {'e_noun._n': 'the human spirit'},
 'that spiritual/_n': {'e_noun._n': 'that spirit'},
 'her spiritual/_n': {'e_noun._n': 'her spirit'},
 'a splitting/_n': {'e_noun._n': 'a split'},
 'every sporting/_n': {'e_noun._n': 'every sport'},
 'waterless sports/_n': {'e_noun._n': 'water sports'},
 'his sporting/_n': {'e_noun._n': 'his sport'},
 'new sporting/_n': {'e_noun._n': 'new sport'},
 'their sporting/_n': {'e_noun._n': 'their sport'},
 'a sporting/_n': {'e_noun._n': 'a sport'},
 'large sporting/_n': {'e_noun._n': 'large sport'},
 'any sporting/_n': {'e_noun._n': 'any sport'},
 'our sporting/_n': {'e_noun._n': 'our sport'},
 'that spotted/_n': {'e_noun._n': 'that spot'},
 'a spotted/_n': {'e_noun._n': 'a spot'},
 'another spotted/_n': {'e_noun._n': 'another spot'},
 'the same spotted/_n': {'e_noun._n': 'the same spot'},
 'his spotted/_n': {'e_noun._n': 'his spot'},
 'one spotted/_n': {'e_noun._n': 'one spot'},
 'the top spotted/_n': {'e_noun._n': 'the top spot'},
 'dead squads/_n': {'e_noun._n': 'death squads'},
 'a squareness/_n': {'e_noun._n': 'a square'},
 'the squarer/_n': {'e_noun._n': 'the square'},
 'economy stability/_n': {'e_noun._n': 'economic stability'},
 'political stable/_n': {'e_noun._n': 'political stability'},
 'economic stable/_n': {'e_noun._n': 'economic stability'},
 'financial stable/_n': {'e_noun._n': 'financial stability'},
 'price stable/_n': {'e_noun._n': 'price stability'},
 'society stability/_n': {'e_noun._n': 'social stability'},
 'supported staff/_n': {'e_noun._n': 'support staff'},
 'centre stage/_n': {'e_noun._n': 'center stage'},
 'the national staged/_n': {'e_noun._n': 'the national stage'},
 'one staged/_n': {'e_noun._n': 'one stage'},
 'that staged/_n': {'e_noun._n': 'that stage'},
 'the world staged/_n': {'e_noun._n': 'the world stage'},
 'a stained/_n': {'e_noun._n': 'a stain'},
 'a stamped/_n': {'e_noun._n': 'a stamp'},
 'the stamped/_n': {'e_noun._n': 'the stamp'},
 'long stand/_n': {'e_noun._n': 'long standing'},
 'safe standards/_n': {'e_noun._n': 'safety standards'},
 'ethic standards/_n': {'e_noun._n': 'ethical standards'},
 'this standards/_n': {'e_noun._n': 'those standards'},
 'rocky stars/_n': {'e_noun._n': 'rock stars'},
 'a rocky star/_n': {'e_noun._n': 'a rock star'},
 'third stars/_n': {'e_noun._n': 'three stars'},
 'start to finished/_n': {'e_noun._n': 'start to finish'},
 'the state of the economic/_n': {'e_noun._n': 'the state of the economy'},
 'third states/_n': {'e_noun._n': 'three states'},
 'this states/_n': {'e_noun._n': 'those states'},
 'sixteenth states/_n': {'e_noun._n': 'six states'},
 'his opening state/_n': {'e_noun._n': 'his opening statement'},
 'a brief state/_n': {'e_noun._n': 'a brief statement'},
 'this statements/_n': {'e_noun._n': 'those statements'},
 'a joint state/_n': {'e_noun._n': 'a joint statement'},
 'a written state/_n': {'e_noun._n': 'a written statement'},
 'workless stations/_n': {'e_noun._n': 'work stations'},
 'this stations/_n': {'e_noun._n': 'those stations'},
 'governing statistics/_n': {'e_noun._n': 'government statistics'},
 'that statistical/_n': {'e_noun._n': 'that statistic'},
 'this statistics/_n': {'e_noun._n': 'those statistics'},
 'society status/_n': {'e_noun._n': 'social status'},
 'the stemmed/_n': {'e_noun._n': 'the stem'},
 'a step inner the right direction/_n': {'e_noun._n': 'a step in the right direction'},
 'a step in the right direct/_n': {'e_noun._n': 'a step in the right direction'},
 'third steps/_n': {'e_noun._n': 'three steps'},
 'this steps/_n': {'e_noun._n': 'those steps'},
 'a sticking/_n': {'e_noun._n': 'a stick'},
 'his sticking/_n': {'e_noun._n': 'his stick'},
 'valuable stocks/_n': {'e_noun._n': 'value stocks'},
 'golden stocks/_n': {'e_noun._n': 'gold stocks'},
 'variety stocks/_n': {'e_noun._n': 'various stocks'},
 'every stopped/_n': {'e_noun._n': 'every stop'},
 'the stopped/_n': {'e_noun._n': 'the stop'},
 'a stopped/_n': {'e_noun._n': 'a stop'},
 'each stopped/_n': {'e_noun._n': 'each stop'},
 'one stopped/_n': {'e_noun._n': 'one stop'},
 'the next stopped/_n': {'e_noun._n': 'the next stop'},
 'that storing/_n': {'e_noun._n': 'that store'},
 'any storing/_n': {'e_noun._n': 'any store'},
 'her storing/_n': {'e_noun._n': 'her store'},
 'new storing/_n': {'e_noun._n': 'new store'},
 'each storing/_n': {'e_noun._n': 'each store'},
 'this stores/_n': {'e_noun._n': 'those stores'},
 'one storing/_n': {'e_noun._n': 'one store'},
 'his storing/_n': {'e_noun._n': 'his store'},
 'the storing/_n': {'e_noun._n': 'the store'},
 'computational stores/_n': {'e_noun._n': 'computer stores'},
 'video storing/_n': {'e_noun._n': 'video store'},
 'a storing/_n': {'e_noun._n': 'a store'},
 'the video storing/_n': {'e_noun._n': 'the video store'},
 'wintry storms/_n': {'e_noun._n': 'winter storms'},
 'successful stories/_n': {'e_noun._n': 'success stories'},
 'this stories/_n': {'e_noun._n': 'those stories'},
 'a lovable story/_n': {'e_noun._n': 'a love story'},
 'that strategic/_n': {'e_noun._n': 'that strategy'},
 'corporate strategic/_n': {'e_noun._n': 'corporate strategy'},
 'such a strategic/_n': {'e_noun._n': 'such a strategy'},
 'the new strategic/_n': {'e_noun._n': 'the new strategy'},
 'his strategic/_n': {'e_noun._n': 'his strategy'},
 'that strong/_n': {'e_noun._n': 'that strength'},
 'armed strength/_n': {'e_noun._n': 'arm strength'},
 'arm strong/_n': {'e_noun._n': 'arm strength'},
 'economy strength/_n': {'e_noun._n': 'economic strength'},
 'economic strong/_n': {'e_noun._n': 'economic strength'},
 'full strong/_n': {'e_noun._n': 'full strength'},
 'financial strong/_n': {'e_noun._n': 'financial strength'},
 'the stressful/_n': {'e_noun._n': 'the stress'},
 'post-traumatic stressful/_n': {'e_noun._n': 'post-traumatic stress'},
 'a stretching/_n': {'e_noun._n': 'a stretch'},
 'their striking/_n': {'e_noun._n': 'their strike'},
 'another striking/_n': {'e_noun._n': 'another strike'},
 'a stringed/_n': {'e_noun._n': 'a string'},
 'the stringed/_n': {'e_noun._n': 'the string'},
 'third strokes/_n': {'e_noun._n': 'three strokes'},
 'their struggling/_n': {'e_noun._n': 'their struggle'},
 'armed struggling/_n': {'e_noun._n': 'armed struggle'},
 'third students/_n': {'e_noun._n': 'three students'},
 'this students/_n': {'e_noun._n': 'those students'},
 'filmed studios/_n': {'e_noun._n': 'film studios'},
 'a new studied/_n': {'e_noun._n': 'a new study'},
 'his studied/_n': {'e_noun._n': 'his study'},
 'a recent studied/_n': {'e_noun._n': 'a recent study'},
 'new studied/_n': {'e_noun._n': 'new study'},
 'its studied/_n': {'e_noun._n': 'its study'},
 'their studied/_n': {'e_noun._n': 'their study'},
 'that studied/_n': {'e_noun._n': 'that study'},
 'another studied/_n': {'e_noun._n': 'another study'},
 'more studied/_n': {'e_noun._n': 'more study'},
 'her studied/_n': {'e_noun._n': 'her study'},
 'one studied/_n': {'e_noun._n': 'one study'},
 'the new studied/_n': {'e_noun._n': 'the new study'},
 'his stuffed/_n': {'e_noun._n': 'his stuff'},
 'that stuffed/_n': {'e_noun._n': 'that stuff'},
 'more stuffed/_n': {'e_noun._n': 'more stuff'},
 'their stuffed/_n': {'e_noun._n': 'their stuff'},
 'our stuffed/_n': {'e_noun._n': 'our stuff'},
 'my stuffed/_n': {'e_noun._n': 'my stuff'},
 'the good stuffed/_n': {'e_noun._n': 'the good stuff'},
 'other stuffed/_n': {'e_noun._n': 'other stuff'},
 'good stuffed/_n': {'e_noun._n': 'good stuff'},
 'all those stuff/_n': {'e_noun._n': 'all this stuff'},
 'all this stuffed/_n': {'e_noun._n': 'all this stuff'},
 'some stuffed/_n': {'e_noun._n': 'some stuff'},
 'the small stuffed/_n': {'e_noun._n': 'the small stuff'},
 'all that stuffed/_n': {'e_noun._n': 'all that stuff'},
 'your stuffed/_n': {'e_noun._n': 'your stuff'},
 'her stylized/_n': {'e_noun._n': 'her style'},
 'our stylized/_n': {'e_noun._n': 'our style'},
 'their stylized/_n': {'e_noun._n': 'their style'},
 'personal stylized/_n': {'e_noun._n': 'personal style'},
 'its stylized/_n': {'e_noun._n': 'its style'},
 'whose stylized/_n': {'e_noun._n': 'whose style'},
 'that stylized/_n': {'e_noun._n': 'that style'},
 'his stylized/_n': {'e_noun._n': 'his style'},
 'your stylized/_n': {'e_noun._n': 'your style'},
 'my stylized/_n': {'e_noun._n': 'my style'},
 'this subjects/_n': {'e_noun._n': 'those subjects'},
 'governing subsidies/_n': {'e_noun._n': 'government subsidies'},
 'the subsidized/_n': {'e_noun._n': 'the subsidy'},
 'a substitutive/_n': {'e_noun._n': 'a substitute'},
 'no successful/_n': {'e_noun._n': 'no success'},
 'some successful/_n': {'e_noun._n': 'some success'},
 'little successful/_n': {'e_noun._n': 'little success'},
 'great successful/_n': {'e_noun._n': 'great success'},
 'much successful/_n': {'e_noun._n': 'much success'},
 'our successful/_n': {'e_noun._n': 'our success'},
 'a huge successful/_n': {'e_noun._n': 'a huge success'},
 'economic successful/_n': {'e_noun._n': 'economic success'},
 'commercial successful/_n': {'e_noun._n': 'commercial success'},
 'such successful/_n': {'e_noun._n': 'such success'},
 'that successful/_n': {'e_noun._n': 'that success'},
 'financial successful/_n': {'e_noun._n': 'financial success'},
 'my successful/_n': {'e_noun._n': 'my success'},
 "the company's successful/_n": {'e_noun._n': "the company's success"},
 'whose successful/_n': {'e_noun._n': 'whose success'},
 'her successful/_n': {'e_noun._n': 'her success'},
 'their successful/_n': {'e_noun._n': 'their success'},
 'the successive/_n': {'e_noun._n': 'the succession'},
 'rapid successive/_n': {'e_noun._n': 'rapid succession'},
 'quick successive/_n': {'e_noun._n': 'quick succession'},
 'its successive/_n': {'e_noun._n': 'its successor'},
 'her successive/_n': {'e_noun._n': 'her successor'},
 'powdered sugary/_n': {'e_noun._n': 'powdered sugar'},
 'that suggested/_n': {'e_noun._n': 'that suggestion'},
 'the suggested/_n': {'e_noun._n': 'the suggestion'},
 'my suggested/_n': {'e_noun._n': 'my suggestion'},
 'dark suited/_n': {'e_noun._n': 'dark suit'},
 'a suited/_n': {'e_noun._n': 'a suit'},
 'his suited/_n': {'e_noun._n': 'his suit'},
 'her suited/_n': {'e_noun._n': 'her suit'},
 'the suited/_n': {'e_noun._n': 'the suit'},
 'their suited/_n': {'e_noun._n': 'their suit'},
 'that suited/_n': {'e_noun._n': 'that suit'},
 'that summing/_n': {'e_noun._n': 'that sum'},
 'the summing/_n': {'e_noun._n': 'the sum'},
 'ample shiny/_n': {'e_noun._n': 'ample sunshine'},
 'abundant shiny/_n': {'e_noun._n': 'abundant sunshine'},
 'dietary supplementary/_n': {'e_noun._n': 'dietary supplement'},
 'the supplementary/_n': {'e_noun._n': 'the supplement'},
 'the supplied/_n': {'e_noun._n': 'the supplier'},
 'a supplied/_n': {'e_noun._n': 'a supplier'},
 'medical supplied/_n': {'e_noun._n': 'medical supply'},
 'short supplied/_n': {'e_noun._n': 'short supply'},
 'the food supplied/_n': {'e_noun._n': 'the food supply'},
 'governing support/_n': {'e_noun._n': 'government support'},
 'government supported/_n': {'e_noun._n': 'government support'},
 'political supported/_n': {'e_noun._n': 'political support'},
 'international supported/_n': {'e_noun._n': 'international support'},
 'their supported/_n': {'e_noun._n': 'their support'},
 'customer supported/_n': {'e_noun._n': 'customer support'},
 'financial supported/_n': {'e_noun._n': 'financial support'},
 'tech supported/_n': {'e_noun._n': 'tech support'},
 'that supported/_n': {'e_noun._n': 'that support'},
 'whose supported/_n': {'e_noun._n': 'whose support'},
 'strong supported/_n': {'e_noun._n': 'strong support'},
 'broad supported/_n': {'e_noun._n': 'broad support'},
 'bipartisan supported/_n': {'e_noun._n': 'bipartisan support'},
 'little supported/_n': {'e_noun._n': 'little support'},
 'our supported/_n': {'e_noun._n': 'our support'},
 'some supported/_n': {'e_noun._n': 'some support'},
 'such supported/_n': {'e_noun._n': 'such support'},
 'family supported/_n': {'e_noun._n': 'family support'},
 'logistical supported/_n': {'e_noun._n': 'logistical support'},
 'life supported/_n': {'e_noun._n': 'life support'},
 'much supported/_n': {'e_noun._n': 'much support'},
 'his supported/_n': {'e_noun._n': 'his support'},
 'widespread supported/_n': {'e_noun._n': 'widespread support'},
 'her supported/_n': {'e_noun._n': 'her support'},
 'moral supported/_n': {'e_noun._n': 'moral support'},
 'the supported/_n': {'e_noun._n': 'the support'},
 'finance support/_n': {'e_noun._n': 'financial support'},
 'technical supported/_n': {'e_noun._n': 'technical support'},
 'american supported/_n': {'e_noun._n': 'american support'},
 'no supported/_n': {'e_noun._n': 'no support'},
 'more supported/_n': {'e_noun._n': 'more support'},
 'emotional supported/_n': {'e_noun._n': 'emotional support'},
 'public supported/_n': {'e_noun._n': 'public support'},
 'its supported/_n': {'e_noun._n': 'its support'},
 'popular supported/_n': {'e_noun._n': 'popular support'},
 'wide supported/_n': {'e_noun._n': 'wide support'},
 'enough supported/_n': {'e_noun._n': 'enough support'},
 'your supported/_n': {'e_noun._n': 'your support'},
 'the tradable surplus/_n': {'e_noun._n': 'the trade surplus'},
 'my surprised/_n': {'e_noun._n': 'my surprise'},
 'little surprised/_n': {'e_noun._n': 'little surprise'},
 'their surprised/_n': {'e_noun._n': 'their surprise'},
 'no surprised/_n': {'e_noun._n': 'no surprise'},
 'not a surprised/_n': {'e_noun._n': 'not a surprise'},
 'a pleasant surprised/_n': {'e_noun._n': 'a pleasant surprise'},
 'his surprised/_n': {'e_noun._n': 'his surprise'},
 'a surprised/_n': {'e_noun._n': 'a surprise'},
 'the biggest surprised/_n': {'e_noun._n': 'the biggest surprise'},
 'her surprised/_n': {'e_noun._n': 'her surprise'},
 'its survived/_n': {'e_noun._n': 'its survival'},
 'his survived/_n': {'e_noun._n': 'his survival'},
 'their survived/_n': {'e_noun._n': 'their survival'},
 'my suspicious/_n': {'e_noun._n': 'my suspicion'},
 'the swept/_n': {'e_noun._n': 'the sweep'},
 'a swept/_n': {'e_noun._n': 'a sweep'},
 'the swellish/_n': {'e_noun._n': 'the swelling'},
 'public sympathetic/_n': {'e_noun._n': 'public sympathy'},
 'their systematic/_n': {'e_noun._n': 'their system'},
 'the systematic/_n': {'e_noun._n': 'the system'},
 'the judicial systematic/_n': {'e_noun._n': 'the judicial system'},
 'the sounding system/_n': {'e_noun._n': 'the sound system'},
 'the sound systematic/_n': {'e_noun._n': 'the sound system'},
 'the current systematic/_n': {'e_noun._n': 'the current system'},
 'the political systematic/_n': {'e_noun._n': 'the political system'},
 'political systematic/_n': {'e_noun._n': 'political system'},
 'your systematic/_n': {'e_noun._n': 'your system'},
 'no systematic/_n': {'e_noun._n': 'no system'},
 'the school systematic/_n': {'e_noun._n': 'the school system'},
 'the computational system/_n': {'e_noun._n': 'the computer system'},
 'the computer systematic/_n': {'e_noun._n': 'the computer system'},
 'the financial systematic/_n': {'e_noun._n': 'the financial system'},
 'the present systematic/_n': {'e_noun._n': 'the present system'},
 'the new systematic/_n': {'e_noun._n': 'the new system'},
 'the whole systematic/_n': {'e_noun._n': 'the whole system'},
 'the taxable system/_n': {'e_noun._n': 'the tax system'},
 'the tax systematic/_n': {'e_noun._n': 'the tax system'},
 'the legal systematic/_n': {'e_noun._n': 'the legal system'},
 'the entire systematic/_n': {'e_noun._n': 'the entire system'},
 'the public school systematic/_n': {'e_noun._n': 'the public school system'},
 'the court systematic/_n': {'e_noun._n': 'the court system'},
 'a new systematic/_n': {'e_noun._n': 'a new system'},
 'the banking systematic/_n': {'e_noun._n': 'the banking system'},
 'financial systematic/_n': {'e_noun._n': 'financial system'},
 'the justice systematic/_n': {'e_noun._n': 'the justice system'},
 'that systematic/_n': {'e_noun._n': 'that system'},
 'any systematic/_n': {'e_noun._n': 'any system'},
 'the old systematic/_n': {'e_noun._n': 'the old system'},
 'computational systems/_n': {'e_noun._n': 'computer systems'},
 'its systematic/_n': {'e_noun._n': 'its system'},
 'our systematic/_n': {'e_noun._n': 'our system'},
 'the american systematic/_n': {'e_noun._n': 'the american system'},
 'one systematic/_n': {'e_noun._n': 'one system'},
 'new systematic/_n': {'e_noun._n': 'new system'},
 'such a systematic/_n': {'e_noun._n': 'such a system'},
 'my systematic/_n': {'e_noun._n': 'my system'},
 'the criminal justice systematic/_n': {'e_noun._n': 'the criminal justice system'},
 'his systematic/_n': {'e_noun._n': 'his system'},
 'great talented/_n': {'e_noun._n': 'great talent'},
 'top talented/_n': {'e_noun._n': 'top talent'},
 'new talented/_n': {'e_noun._n': 'new talent'},
 'her talented/_n': {'e_noun._n': 'her talent'},
 'their talented/_n': {'e_noun._n': 'their talent'},
 'young talented/_n': {'e_noun._n': 'young talent'},
 'that talented/_n': {'e_noun._n': 'that talent'},
 'more talented/_n': {'e_noun._n': 'more talent'},
 'such talking/_n': {'e_noun._n': 'such talk'},
 'peaceful talks/_n': {'e_noun._n': 'peace talks'},
 'his talking/_n': {'e_noun._n': 'his talk'},
 'the peaceful talks/_n': {'e_noun._n': 'the peace talks'},
 'the tapped/_n': {'e_noun._n': 'the tap'},
 'duct taped/_n': {'e_noun._n': 'duct tape'},
 'that taped/_n': {'e_noun._n': 'that tape'},
 'his targeted/_n': {'e_noun._n': 'his target'},
 'their targeted/_n': {'e_noun._n': 'their target'},
 'this targets/_n': {'e_noun._n': 'those targets'},
 'that targeted/_n': {'e_noun._n': 'that target'},
 'the task at handed/_n': {'e_noun._n': 'the task at hand'},
 'this tasks/_n': {'e_noun._n': 'those tasks'},
 'my tasteless/_n': {'e_noun._n': 'my taste'},
 'bad tasteless/_n': {'e_noun._n': 'bad taste'},
 'a tasteless/_n': {'e_noun._n': 'a taste'},
 'your tasteless/_n': {'e_noun._n': 'your taste'},
 'his tasteless/_n': {'e_noun._n': 'his taste'},
 'their tasteless/_n': {'e_noun._n': 'their taste'},
 'no taxable/_n': {'e_noun._n': 'no tax'},
 'marginal taxable/_n': {'e_noun._n': 'marginal tax'},
 'existing taxable/_n': {'e_noun._n': 'existing tax'},
 'corporate taxable/_n': {'e_noun._n': 'corporate tax'},
 'large taxable/_n': {'e_noun._n': 'large tax'},
 'massive taxable/_n': {'e_noun._n': 'massive tax'},
 'lost taxable/_n': {'e_noun._n': 'lost tax'},
 'major taxable/_n': {'e_noun._n': 'major tax'},
 'future taxable/_n': {'e_noun._n': 'future tax'},
 'general taxable/_n': {'e_noun._n': 'general tax'},
 'increased taxable/_n': {'e_noun._n': 'increased tax'},
 'his taxable/_n': {'e_noun._n': 'his tax'},
 'substantial taxable/_n': {'e_noun._n': 'substantial tax'},
 'additional taxable/_n': {'e_noun._n': 'additional tax'},
 'current taxable/_n': {'e_noun._n': 'current tax'},
 'high taxable/_n': {'e_noun._n': 'high tax'},
 'that taxable/_n': {'e_noun._n': 'that tax'},
 'largest taxable/_n': {'e_noun._n': 'largest tax'},
 'lower taxable/_n': {'e_noun._n': 'lower tax'},
 'state taxable/_n': {'e_noun._n': 'state tax'},
 'huge taxable/_n': {'e_noun._n': 'huge tax'},
 'taxable free/_n': {'e_noun._n': 'tax free'},
 'the capital gains taxable/_n': {'e_noun._n': 'the capital gains tax'},
 'currency tax/_n': {'e_noun._n': 'current tax'},
 'low taxable/_n': {'e_noun._n': 'low tax'},
 'big taxable/_n': {'e_noun._n': 'big tax'},
 'same taxable/_n': {'e_noun._n': 'same tax'},
 'social secure taxes/_n': {'e_noun._n': 'social security taxes'},
 'annual taxable/_n': {'e_noun._n': 'annual tax'},
 'federal taxable/_n': {'e_noun._n': 'federal tax'},
 'across-the-board taxable/_n': {'e_noun._n': 'across-the-board tax'},
 'any taxable/_n': {'e_noun._n': 'any tax'},
 'significant taxable/_n': {'e_noun._n': 'significant tax'},
 'bigger taxable/_n': {'e_noun._n': 'bigger tax'},
 'new taxable/_n': {'e_noun._n': 'new tax'},
 'total taxable/_n': {'e_noun._n': 'total tax'},
 'top taxable/_n': {'e_noun._n': 'top tax'},
 'higher taxable/_n': {'e_noun._n': 'higher tax'},
 'local taxable/_n': {'e_noun._n': 'local tax'},
 'a flat taxable/_n': {'e_noun._n': 'a flat tax'},
 'a taxable/_n': {'e_noun._n': 'a tax'},
 'the consuming tax/_n': {'e_noun._n': 'the consumption tax'},
 'the consumption taxable/_n': {'e_noun._n': 'the consumption tax'},
 'specialist tax/_n': {'e_noun._n': 'special tax'},
 'special taxable/_n': {'e_noun._n': 'special tax'},
 'nation team/_n': {'e_noun._n': 'national team'},
 'the managing team/_n': {'e_noun._n': 'the management team'},
 'third teams/_n': {'e_noun._n': 'three teams'},
 'sixteenth teams/_n': {'e_noun._n': 'six teams'},
 'a tearing/_n': {'e_noun._n': 'a tear'},
 'our technological/_n': {'e_noun._n': 'our technology'},
 'advance technology/_n': {'e_noun._n': 'advanced technology'},
 'its technological/_n': {'e_noun._n': 'its technology'},
 'wireless technological/_n': {'e_noun._n': 'wireless technology'},
 'american technological/_n': {'e_noun._n': 'american technology'},
 'better technological/_n': {'e_noun._n': 'better technology'},
 'that technological/_n': {'e_noun._n': 'that technology'},
 'a new technological/_n': {'e_noun._n': 'a new technology'},
 'current technological/_n': {'e_noun._n': 'current technology'},
 'military technological/_n': {'e_noun._n': 'military technology'},
 'the latest technological/_n': {'e_noun._n': 'the latest technology'},
 'their technological/_n': {'e_noun._n': 'their technology'},
 'satellite technological/_n': {'e_noun._n': 'satellite technology'},
 'existing technological/_n': {'e_noun._n': 'existing technology'},
 "today's technological/_n": {'e_noun._n': "today's technology"},
 'cutting-edge technological/_n': {'e_noun._n': 'cutting-edge technology'},
 'majority telecommunications/_n': {'e_noun._n': 'major telecommunications'},
 'living television/_n': {'e_noun._n': 'live television'},
 'bodily temperature/_n': {'e_noun._n': 'body temperature'},
 'racial tense/_n': {'e_noun._n': 'racial tension'},
 'third terms/_n': {'e_noun._n': 'three terms'},
 'the terms of the agreeable/_n': {'e_noun._n': 'the terms of the agreement'},
 'this terms/_n': {'e_noun._n': 'those terms'},
 'computational terminals/_n': {'e_noun._n': 'computer terminals'},
 'wrongful terminate/_n': {'e_noun._n': 'wrongful termination'},
 'that tested/_n': {'e_noun._n': 'that test'},
 'his tested/_n': {'e_noun._n': 'his test'},
 'nuclear tested/_n': {'e_noun._n': 'nuclear test'},
 'the real tested/_n': {'e_noun._n': 'the real test'},
 'another tested/_n': {'e_noun._n': 'another test'},
 'further tested/_n': {'e_noun._n': 'further testing'},
 'this tests/_n': {'e_noun._n': 'those tests'},
 'one tested/_n': {'e_noun._n': 'one test'},
 'the tested of time/_n': {'e_noun._n': 'the test of time'},
 'the test of timeless/_n': {'e_noun._n': 'the test of time'},
 'the new tested/_n': {'e_noun._n': 'the new test'},
 'his textual/_n': {'e_noun._n': 'his text'},
 'a textual/_n': {'e_noun._n': 'a text'},
 'those inner/_n': {'e_noun._n': 'those in'},
 'that inner the past/_n': {'e_noun._n': 'that in the past'},
 'that inner/_n': {'e_noun._n': 'that in'},
 'that inner minnerd/_n': {'e_noun._n': 'that in mind'},
 'that in minded/_n': {'e_noun._n': 'that in mind'},
 'that thematic/_n': {'e_noun._n': 'that theme'},
 'its thematic/_n': {'e_noun._n': 'its theme'},
 'his thematic/_n': {'e_noun._n': 'his theme'},
 'the thematic/_n': {'e_noun._n': 'the theme'},
 'another theoretical/_n': {'e_noun._n': 'another theory'},
 'their theoretical/_n': {'e_noun._n': 'their theory'},
 'one theoretical/_n': {'e_noun._n': 'one theory'},
 'my theoretical/_n': {'e_noun._n': 'my theory'},
 'his theoretical/_n': {'e_noun._n': 'his theory'},
 'economic theoretical/_n': {'e_noun._n': 'economic theory'},
 'that theoretical/_n': {'e_noun._n': 'that theory'},
 'things like those/_n': {'e_noun._n': 'things like this'},
 'all this things/_n': {'e_noun._n': 'all those things'},
 'third things/_n': {'e_noun._n': 'three things'},
 'your think/_n': {'e_noun._n': 'your thinking'},
 'such think/_n': {'e_noun._n': 'such thinking'},
 'that think/_n': {'e_noun._n': 'that thinking'},
 'his think/_n': {'e_noun._n': 'his thinking'},
 'our think/_n': {'e_noun._n': 'our thinking'},
 'their think/_n': {'e_noun._n': 'their thinking'},
 'what those/_n': {'e_noun._n': 'what this'},
 'the those/_n': {'e_noun._n': 'the this'},
 'first think/_n': {'e_noun._n': 'first thought'},
 'this thoughts/_n': {'e_noun._n': 'those thoughts'},
 'several thousandth/_n': {'e_noun._n': 'several thousand'},
 'a threaded/_n': {'e_noun._n': 'a thread'},
 'the threaded/_n': {'e_noun._n': 'the thread'},
 'no threatened/_n': {'e_noun._n': 'no threat'},
 'that threatened/_n': {'e_noun._n': 'that threat'},
 'dead threats/_n': {'e_noun._n': 'death threats'},
 'a serious threatened/_n': {'e_noun._n': 'a serious threat'},
 'just third/_n': {'e_noun._n': 'just three'},
 'all third/_n': {'e_noun._n': 'all three'},
 'third of them/_n': {'e_noun._n': 'three of them'},
 'the third of us/_n': {'e_noun._n': 'the three of us'},
 'third of whom/_n': {'e_noun._n': 'three of whom'},
 'the third of them/_n': {'e_noun._n': 'the three of them'},
 'these third/_n': {'e_noun._n': 'these three'},
 'the next third/_n': {'e_noun._n': 'the next three'},
 'third of which/_n': {'e_noun._n': 'three of which'},
 'the three day/_n': {'e_noun._n': 'the third day'},
 'three quarter/_n': {'e_noun._n': 'third quarter'},
 'the three year/_n': {'e_noun._n': 'the third year'},
 'a tieless/_n': {'e_noun._n': 'a tie'},
 'his tieless/_n': {'e_noun._n': 'his tie'},
 'good timeless/_n': {'e_noun._n': 'good time'},
 'the same timeless/_n': {'e_noun._n': 'the same time'},
 'vacation timeless/_n': {'e_noun._n': 'vacation time'},
 'value time/_n': {'e_noun._n': 'valuable time'},
 'timeless to/_n': {'e_noun._n': 'time to'},
 'precious timeless/_n': {'e_noun._n': 'precious time'},
 'third times/_n': {'e_noun._n': 'three times'},
 'lost timeless/_n': {'e_noun._n': 'lost time'},
 'the wrong timeless/_n': {'e_noun._n': 'the wrong time'},
 'the first timeless/_n': {'e_noun._n': 'the first time'},
 'a hard timeless/_n': {'e_noun._n': 'a hard time'},
 'sixteenth times/_n': {'e_noun._n': 'six times'},
 'any given timeless/_n': {'e_noun._n': 'any given time'},
 'different timeless/_n': {'e_noun._n': 'different time'},
 'that timeless/_n': {'e_noun._n': 'that time'},
 'too much timeless/_n': {'e_noun._n': 'too much time'},
 'no timeless/_n': {'e_noun._n': 'no time'},
 'a difficult timeless/_n': {'e_noun._n': 'a difficult time'},
 'valuable timeless/_n': {'e_noun._n': 'valuable time'},
 'second timeless/_n': {'e_noun._n': 'second time'},
 'timeless together/_n': {'e_noun._n': 'time together'},
 'next timeless/_n': {'e_noun._n': 'next time'},
 'considerable timeless/_n': {'e_noun._n': 'considerable time'},
 'any timeless/_n': {'e_noun._n': 'any time'},
 'his sparing time/_n': {'e_noun._n': 'his spare time'},
 'his spare timeless/_n': {'e_noun._n': 'his spare time'},
 'dinner timeless/_n': {'e_noun._n': 'dinner time'},
 'quite some timeless/_n': {'e_noun._n': 'quite some time'},
 'timeless off/_n': {'e_noun._n': 'time off'},
 'a great timeless/_n': {'e_noun._n': 'a great time'},
 'the second timeless/_n': {'e_noun._n': 'the second time'},
 'which timeless/_n': {'e_noun._n': 'which time'},
 'what timeless/_n': {'e_noun._n': 'what time'},
 'a long timeless/_n': {'e_noun._n': 'a long time'},
 'timeless for/_n': {'e_noun._n': 'time for'},
 'every timeless/_n': {'e_noun._n': 'every time'},
 'due timeless/_n': {'e_noun._n': 'due time'},
 'so much timeless/_n': {'e_noun._n': 'so much time'},
 'tough timeless/_n': {'e_noun._n': 'tough time'},
 'a certain timeless/_n': {'e_noun._n': 'a certain time'},
 'his own timeless/_n': {'e_noun._n': 'his own time'},
 'its timeless/_n': {'e_noun._n': 'its time'},
 'this times/_n': {'e_noun._n': 'those times'},
 'whose timeless/_n': {'e_noun._n': 'whose time'},
 'their timeless/_n': {'e_noun._n': 'their time'},
 'first timeless/_n': {'e_noun._n': 'first time'},
 'less timeless/_n': {'e_noun._n': 'less time'},
 'the longest timeless/_n': {'e_noun._n': 'the longest time'},
 'much timeless/_n': {'e_noun._n': 'much time'},
 'free timeless/_n': {'e_noun._n': 'free time'},
 'same timeless/_n': {'e_noun._n': 'same time'},
 'how much timeless/_n': {'e_noun._n': 'how much time'},
 'each timeless/_n': {'e_noun._n': 'each time'},
 'more timeless/_n': {'e_noun._n': 'more time'},
 'enough timeless/_n': {'e_noun._n': 'enough time'},
 'some timeless/_n': {'e_noun._n': 'some time'},
 'a wonderful timeless/_n': {'e_noun._n': 'a wonderful time'},
 'travelled time/_n': {'e_noun._n': 'travel time'},
 'travel timeless/_n': {'e_noun._n': 'travel time'},
 'a tough timeless/_n': {'e_noun._n': 'a tough time'},
 'another timeless/_n': {'e_noun._n': 'another time'},
 'his timeless/_n': {'e_noun._n': 'his time'},
 'extra timeless/_n': {'e_noun._n': 'extra time'},
 'lunch timeless/_n': {'e_noun._n': 'lunch time'},
 'all the timeless/_n': {'e_noun._n': 'all the time'},
 'difficult timeless/_n': {'e_noun._n': 'difficult time'},
 'a very long timeless/_n': {'e_noun._n': 'a very long time'},
 'the third timeless/_n': {'e_noun._n': 'the third time'},
 'long timeless/_n': {'e_noun._n': 'long time'},
 'timeless there/_n': {'e_noun._n': 'time there'},
 'her timeless/_n': {'e_noun._n': 'her time'},
 'one timeless/_n': {'e_noun._n': 'one time'},
 'a second timeless/_n': {'e_noun._n': 'a second time'},
 'a good timeless/_n': {'e_noun._n': 'a good time'},
 'the last timeless/_n': {'e_noun._n': 'the last time'},
 'ample timeless/_n': {'e_noun._n': 'ample time'},
 'the timeless being/_n': {'e_noun._n': 'the time being'},
 'last timeless/_n': {'e_noun._n': 'last time'},
 'the best timeless/_n': {'e_noun._n': 'the best time'},
 'a little timeless/_n': {'e_noun._n': 'a little time'},
 'a flat tired/_n': {'e_noun._n': 'a flat tire'},
 'the divided title/_n': {'e_noun._n': 'the division title'},
 'your tongueless/_n': {'e_noun._n': 'your tongue'},
 'his tongueless/_n': {'e_noun._n': 'his tongue'},
 'her tongueless/_n': {'e_noun._n': 'her tongue'},
 'my tongueless/_n': {'e_noun._n': 'my tongue'},
 'the tongueless/_n': {'e_noun._n': 'the tongue'},
 'the toothed/_n': {'e_noun._n': 'the tooth'},
 'a toothed/_n': {'e_noun._n': 'a tooth'},
 'the top of the listed/_n': {'e_noun._n': 'the top of the list'},
 'that topical/_n': {'e_noun._n': 'that topic'},
 'his touchable/_n': {'e_noun._n': 'his touch'},
 'a touchable/_n': {'e_noun._n': 'a touch'},
 'third touchdowns/_n': {'e_noun._n': 'three touchdowns'},
 'mental tough/_n': {'e_noun._n': 'mental toughness'},
 'his tough/_n': {'e_noun._n': 'his toughness'},
 'a traceless/_n': {'e_noun._n': 'a trace'},
 'expanded tradable/_n': {'e_noun._n': 'expanded trade'},
 'normal tradable/_n': {'e_noun._n': 'normal trade'},
 'permanent normal tradable/_n': {'e_noun._n': 'permanent normal trade'},
 'freer tradable/_n': {'e_noun._n': 'freer trade'},
 'growing tradable/_n': {'e_noun._n': 'growing trade'},
 'their tradable/_n': {'e_noun._n': 'their trade'},
 'increased tradable/_n': {'e_noun._n': 'increased trade'},
 'national tradable/_n': {'e_noun._n': 'national trade'},
 'japanese tradable/_n': {'e_noun._n': 'japanese trade'},
 'that tradable/_n': {'e_noun._n': 'that trade'},
 'recent tradable/_n': {'e_noun._n': 'recent trade'},
 'american tradable/_n': {'e_noun._n': 'american trade'},
 'the drug tradable/_n': {'e_noun._n': 'the drug trade'},
 'a tradable/_n': {'e_noun._n': 'a trade'},
 'global tradable/_n': {'e_noun._n': 'global trade'},
 'globe trade/_n': {'e_noun._n': 'global trade'},
 'annual tradable/_n': {'e_noun._n': 'annual trade'},
 'future tradable/_n': {'e_noun._n': 'future trade'},
 'his tradable/_n': {'e_noun._n': 'his trade'},
 'bilateral tradable/_n': {'e_noun._n': 'bilateral trade'},
 'open tradable/_n': {'e_noun._n': 'open trade'},
 'preferential tradable/_n': {'e_noun._n': 'preferential trade'},
 'total tradable/_n': {'e_noun._n': 'total trade'},
 'huge tradable/_n': {'e_noun._n': 'huge trade'},
 'major tradable/_n': {'e_noun._n': 'major trade'},
 'new tradable/_n': {'e_noun._n': 'new trade'},
 'chinese tradable/_n': {'e_noun._n': 'chinese trade'},
 'this trades/_n': {'e_noun._n': 'those trades'},
 'unfair tradable/_n': {'e_noun._n': 'unfair trade'},
 'jewish traditional/_n': {'e_noun._n': 'jewish tradition'},
 'that traditional/_n': {'e_noun._n': 'that tradition'},
 'weighable training/_n': {'e_noun._n': 'weight training'},
 'this traits/_n': {'e_noun._n': 'those traits'},
 'this transactions/_n': {'e_noun._n': 'those transactions'},
 'a transferable/_n': {'e_noun._n': 'a transfer'},
 'the transferable/_n': {'e_noun._n': 'the transfer'},
 'the transformational/_n': {'e_noun._n': 'the transformation'},
 'that transformational/_n': {'e_noun._n': 'that transformation'},
 'public transitory/_n': {'e_noun._n': 'public transit'},
 'that transitory/_n': {'e_noun._n': 'that transition'},
 'automatic transmissive/_n': {'e_noun._n': 'automatic transmission'},
 'the transmissive/_n': {'e_noun._n': 'the transmission'},
 'new travelled/_n': {'e_noun._n': 'new travel'},
 'foreign travelled/_n': {'e_noun._n': 'foreign travel'},
 'online travelled/_n': {'e_noun._n': 'online travel'},
 'the travelled/_n': {'e_noun._n': 'the travel'},
 'a treated/_n': {'e_noun._n': 'a treat'},
 'preferential treated/_n': {'e_noun._n': 'preferential treatment'},
 'drug treated/_n': {'e_noun._n': 'drug treatment'},
 'aids treated/_n': {'e_noun._n': 'aids treatment'},
 'equal treated/_n': {'e_noun._n': 'equal treatment'},
 'equality treatment/_n': {'e_noun._n': 'equal treatment'},
 'cancer treated/_n': {'e_noun._n': 'cancer treatment'},
 'new treated/_n': {'e_noun._n': 'new treatment'},
 'such treated/_n': {'e_noun._n': 'such treatment'},
 'specialist treatment/_n': {'e_noun._n': 'special treatment'},
 'residential treated/_n': {'e_noun._n': 'residential treatment'},
 'psychiatric treated/_n': {'e_noun._n': 'psychiatric treatment'},
 'better treated/_n': {'e_noun._n': 'better treatment'},
 'a peaceful treaty/_n': {'e_noun._n': 'a peace treaty'},
 'this trends/_n': {'e_noun._n': 'those trends'},
 'a new tried/_n': {'e_noun._n': 'a new trial'},
 'the first tried/_n': {'e_noun._n': 'the first trial'},
 'clinical tried/_n': {'e_noun._n': 'clinical trial'},
 'that tried/_n': {'e_noun._n': 'that trial'},
 'the criminal tried/_n': {'e_noun._n': 'the criminal trial'},
 'a tried/_n': {'e_noun._n': 'a trial'},
 'a fair tried/_n': {'e_noun._n': 'a fair trial'},
 'a jury tried/_n': {'e_noun._n': 'a jury trial'},
 'their tried/_n': {'e_noun._n': 'their trial'},
 'his tried/_n': {'e_noun._n': 'his trial'},
 'her tried/_n': {'e_noun._n': 'her trial'},
 'another tried/_n': {'e_noun._n': 'another trial'},
 'a trickish/_n': {'e_noun._n': 'a trick'},
 'the trickish/_n': {'e_noun._n': 'the trick'},
 'this trips/_n': {'e_noun._n': 'those trips'},
 'this troops/_n': {'e_noun._n': 'those troops'},
 'governing troops/_n': {'e_noun._n': 'government troops'},
 'heart troublesome/_n': {'e_noun._n': 'heart trouble'},
 'no troublesome/_n': {'e_noun._n': 'no trouble'},
 'enough troublesome/_n': {'e_noun._n': 'enough trouble'},
 'much troublesome/_n': {'e_noun._n': 'much trouble'},
 'real troublesome/_n': {'e_noun._n': 'real trouble'},
 'some troublesome/_n': {'e_noun._n': 'some trouble'},
 'more troublesome/_n': {'e_noun._n': 'more trouble'},
 'financial troublesome/_n': {'e_noun._n': 'financial trouble'},
 'serious troublesome/_n': {'e_noun._n': 'serious trouble'},
 'big troublesome/_n': {'e_noun._n': 'big trouble'},
 'little troublesome/_n': {'e_noun._n': 'little trouble'},
 'any troublesome/_n': {'e_noun._n': 'any trouble'},
 'deep troublesome/_n': {'e_noun._n': 'deep trouble'},
 'a trustable/_n': {'e_noun._n': 'a trust'},
 'mutual trustable/_n': {'e_noun._n': 'mutual trust'},
 'the trustable/_n': {'e_noun._n': 'the trust'},
 'their trustable/_n': {'e_noun._n': 'their trust'},
 'that trustable/_n': {'e_noun._n': 'that trust'},
 'public trustable/_n': {'e_noun._n': 'public trust'},
 'the whole TRUE/_n': {'e_noun._n': 'the whole truth'},
 'the TRUE of the matter/_n': {'e_noun._n': 'the truth of the matter'},
 'some TRUE/_n': {'e_noun._n': 'some truth'},
 'the tuneless/_n': {'e_noun._n': 'the tune'},
 'a tuneless/_n': {'e_noun._n': 'a tune'},
 'his tuneless/_n': {'e_noun._n': 'his tune'},
 'your turned/_n': {'e_noun._n': 'your turn'},
 'the turned of the century,/_n': {'e_noun._n': 'the turn of the century,'},
 'her turned/_n': {'e_noun._n': 'her turn'},
 'the turned of the century/_n': {'e_noun._n': 'the turn of the century'},
 'the turned/_n': {'e_noun._n': 'the turn'},
 'the first turned/_n': {'e_noun._n': 'the first turn'},
 'every turned/_n': {'e_noun._n': 'every turn'},
 'their turned/_n': {'e_noun._n': 'their turn'},
 'his turned/_n': {'e_noun._n': 'his turn'},
 'votable turnout/_n': {'e_noun._n': 'voter turnout'},
 'this two/_n': {'e_noun._n': 'those two'},
 'the unionism/_n': {'e_noun._n': 'the union'},
 'party unitive/_n': {'e_noun._n': 'party unity'},
 'nation unity/_n': {'e_noun._n': 'national unity'},
 'national unitive/_n': {'e_noun._n': 'national unity'},
 'the upsetting/_n': {'e_noun._n': 'the upset'},
 'an upsetting/_n': {'e_noun._n': 'an upset'},
 'tobacco useful/_n': {'e_noun._n': 'tobacco use'},
 'alcohol useful/_n': {'e_noun._n': 'alcohol use'},
 'better useful/_n': {'e_noun._n': 'better use'},
 'military useful/_n': {'e_noun._n': 'military use'},
 'home useful/_n': {'e_noun._n': 'home use'},
 'public useful/_n': {'e_noun._n': 'public use'},
 'computational use/_n': {'e_noun._n': 'computer use'},
 'computer useful/_n': {'e_noun._n': 'computer use'},
 'its useful/_n': {'e_noun._n': 'its use'},
 'steroid useful/_n': {'e_noun._n': 'steroid use'},
 'commercial useful/_n': {'e_noun._n': 'commercial use'},
 'the useful of force/_n': {'e_noun._n': 'the use of force'},
 'the use of forceful/_n': {'e_noun._n': 'the use of force'},
 'widespread useful/_n': {'e_noun._n': 'widespread use'},
 'little useful/_n': {'e_noun._n': 'little use'},
 'future useful/_n': {'e_noun._n': 'future use'},
 'medical useful/_n': {'e_noun._n': 'medical use'},
 'their useful/_n': {'e_noun._n': 'their use'},
 'personal useful/_n': {'e_noun._n': 'personal use'},
 'energetic use/_n': {'e_noun._n': 'energy use'},
 'energy useful/_n': {'e_noun._n': 'energy use'},
 'useful today/_n': {'e_noun._n': 'use today'},
 'another useful/_n': {'e_noun._n': 'another use'},
 'no useful/_n': {'e_noun._n': 'no use'},
 'computational users/_n': {'e_noun._n': 'computer users'},
 'waterless utilities/_n': {'e_noun._n': 'water utilities'},
 'a utilisable/_n': {'e_noun._n': 'a utility'},
 'the utilisable/_n': {'e_noun._n': 'the utility'},
 'capable utilization/_n': {'e_noun._n': 'capacity utilization'},
 'capacity utilisable/_n': {'e_noun._n': 'capacity utilization'},
 'entertaining value/_n': {'e_noun._n': 'entertainment value'},
 'entertainment valuable/_n': {'e_noun._n': 'entertainment value'},
 'no valuable/_n': {'e_noun._n': 'no value'},
 'shareholder valuable/_n': {'e_noun._n': 'shareholder value'},
 'whose valuable/_n': {'e_noun._n': 'whose value'},
 'tradition values/_n': {'e_noun._n': 'traditional values'},
 'that valuable/_n': {'e_noun._n': 'that value'},
 'his valuable/_n': {'e_noun._n': 'his value'},
 'landed values/_n': {'e_noun._n': 'land values'},
 'the valuable of the dollar/_n': {'e_noun._n': 'the value of the dollar'},
 'this values/_n': {'e_noun._n': 'those values'},
 'a various of ways/_n': {'e_noun._n': 'a variety of ways'},
 'a various of reasons/_n': {'e_noun._n': 'a variety of reasons'},
 'this vehicles/_n': {'e_noun._n': 'those vehicles'},
 'electricity vehicles/_n': {'e_noun._n': 'electric vehicles'},
 'utilisable vehicles/_n': {'e_noun._n': 'utility vehicles'},
 'criminal victims/_n': {'e_noun._n': 'crime victims'},
 'another victorious/_n': {'e_noun._n': 'another victory'},
 'its victorious/_n': {'e_noun._n': 'its victory'},
 'their victorious/_n': {'e_noun._n': 'their victory'},
 'one victorious/_n': {'e_noun._n': 'one victory'},
 'her victorious/_n': {'e_noun._n': 'her victory'},
 'a victorious/_n': {'e_noun._n': 'a victory'},
 'that victorious/_n': {'e_noun._n': 'that victory'},
 'his victorious/_n': {'e_noun._n': 'his victory'},
 'this views/_n': {'e_noun._n': 'those views'},
 'the villagey/_n': {'e_noun._n': 'the village'},
 'their villagey/_n': {'e_noun._n': 'their village'},
 'his villagey/_n': {'e_noun._n': 'his village'},
 'a villagey/_n': {'e_noun._n': 'a village'},
 'her villagey/_n': {'e_noun._n': 'her village'},
 'a violable/_n': {'e_noun._n': 'a violation'},
 'the violable/_n': {'e_noun._n': 'the violation'},
 'some violent/_n': {'e_noun._n': 'some violence'},
 'gang violent/_n': {'e_noun._n': 'gang violence'},
 'physical violent/_n': {'e_noun._n': 'physical violence'},
 'street violent/_n': {'e_noun._n': 'street violence'},
 'such violent/_n': {'e_noun._n': 'such violence'},
 'television violent/_n': {'e_noun._n': 'television violence'},
 'terrorist violent/_n': {'e_noun._n': 'terrorist violence'},
 'extreme violent/_n': {'e_noun._n': 'extreme violence'},
 'political violent/_n': {'e_noun._n': 'political violence'},
 'no violent/_n': {'e_noun._n': 'no violence'},
 'graphic violent/_n': {'e_noun._n': 'graphic violence'},
 'gun violent/_n': {'e_noun._n': 'gun violence'},
 'violent against women/_n': {'e_noun._n': 'violence against women'},
 'more violent/_n': {'e_noun._n': 'more violence'},
 'a virtuous/_n': {'e_noun._n': 'a virtue'},
 'his visional/_n': {'e_noun._n': 'his vision'},
 'my visional/_n': {'e_noun._n': 'my vision'},
 'that visional/_n': {'e_noun._n': 'that vision'},
 'the visional/_n': {'e_noun._n': 'the vision'},
 'her visional/_n': {'e_noun._n': 'her vision'},
 'their visional/_n': {'e_noun._n': 'their vision'},
 'a visional/_n': {'e_noun._n': 'a vision'},
 'our visional/_n': {'e_noun._n': 'our vision'},
 'your voiced/_n': {'e_noun._n': 'your voice'},
 'my voiced/_n': {'e_noun._n': 'my voice'},
 'that voiced/_n': {'e_noun._n': 'that voice'},
 'his voiced/_n': {'e_noun._n': 'his voice'},
 'whose voiced/_n': {'e_noun._n': 'whose voice'},
 'one voiced/_n': {'e_noun._n': 'one voice'},
 'its voiced/_n': {'e_noun._n': 'its voice'},
 'their voiced/_n': {'e_noun._n': 'their voice'},
 'the final votable/_n': {'e_noun._n': 'the final vote'},
 'another votable/_n': {'e_noun._n': 'another vote'},
 'their votable/_n': {'e_noun._n': 'their vote'},
 'a votable/_n': {'e_noun._n': 'a vote'},
 'that votable/_n': {'e_noun._n': 'that vote'},
 'the popular votable/_n': {'e_noun._n': 'the popular vote'},
 'the hispanic votable/_n': {'e_noun._n': 'the hispanic vote'},
 'my votable/_n': {'e_noun._n': 'my vote'},
 "tuesday's votable/_n": {'e_noun._n': "tuesday's vote"},
 'every votable/_n': {'e_noun._n': 'every vote'},
 'her votable/_n': {'e_noun._n': 'her vote'},
 'his votable/_n': {'e_noun._n': 'his vote'},
 'no votable/_n': {'e_noun._n': 'no vote'},
 'popular votable/_n': {'e_noun._n': 'popular vote'},
 'its votable/_n': {'e_noun._n': 'its vote'},
 'one votable/_n': {'e_noun._n': 'one vote'},
 'the voyageable/_n': {'e_noun._n': 'the voyage'},
 'this walls/_n': {'e_noun._n': 'those walls'},
 'the war inner vietnam/_n': {'e_noun._n': 'the war in vietnam'},
 'a tradable war/_n': {'e_noun._n': 'a trade war'},
 'the war inner afghanistan/_n': {'e_noun._n': 'the war in afghanistan'},
 'arresting warrants/_n': {'e_noun._n': 'arrest warrants'},
 'an arresting warrant/_n': {'e_noun._n': 'an arrest warrant'},
 'the washed/_n': {'e_noun._n': 'the wash'},
 'a washed/_n': {'e_noun._n': 'a wash'},
 'toxic wasteful/_n': {'e_noun._n': 'toxic waste'},
 'radioactive wasteful/_n': {'e_noun._n': 'radioactive waste'},
 'nuclear wasteful/_n': {'e_noun._n': 'nuclear waste'},
 'human wasteful/_n': {'e_noun._n': 'human waste'},
 'a wasteful/_n': {'e_noun._n': 'a waste'},
 'industrial watchers/_n': {'e_noun._n': 'industry watchers'},
 'that waterless/_n': {'e_noun._n': 'that water'},
 'enough waterless/_n': {'e_noun._n': 'enough water'},
 'shallow waterless/_n': {'e_noun._n': 'shallow water'},
 'liquid waterless/_n': {'e_noun._n': 'liquid water'},
 'salt waterless/_n': {'e_noun._n': 'salt water'},
 'some waterless/_n': {'e_noun._n': 'some water'},
 'bottle water/_n': {'e_noun._n': 'bottled water'},
 'wasteful water/_n': {'e_noun._n': 'waste water'},
 'waste waterless/_n': {'e_noun._n': 'waste water'},
 'local waterless/_n': {'e_noun._n': 'local water'},
 'sea waterless/_n': {'e_noun._n': 'sea water'},
 'new waterless/_n': {'e_noun._n': 'new water'},
 'no waterless/_n': {'e_noun._n': 'no water'},
 'deep waterless/_n': {'e_noun._n': 'deep water'},
 'clean waterless/_n': {'e_noun._n': 'clean water'},
 'their waterless/_n': {'e_noun._n': 'their water'},
 'contaminated waterless/_n': {'e_noun._n': 'contaminated water'},
 'its waterless/_n': {'e_noun._n': 'its water'},
 'more waterless/_n': {'e_noun._n': 'more water'},
 'warm waterless/_n': {'e_noun._n': 'warm water'},
 'the waveless of the future/_n': {'e_noun._n': 'the wave of the future'},
 'a waveless/_n': {'e_noun._n': 'a wave'},
 'the waxy/_n': {'e_noun._n': 'the wax'},
 'third ways/_n': {'e_noun._n': 'three ways'},
 'variety ways/_n': {'e_noun._n': 'various ways'},
 'that weak/_n': {'e_noun._n': 'that weakness'},
 'its weak/_n': {'e_noun._n': 'its weakness'},
 'great wealthy/_n': {'e_noun._n': 'great wealth'},
 'personal wealthy/_n': {'e_noun._n': 'personal wealth'},
 'his wealthy/_n': {'e_noun._n': 'his wealth'},
 'this weapons/_n': {'e_noun._n': 'those weapons'},
 'evening wearable/_n': {'e_noun._n': 'evening wear'},
 'nearly a weekly/_n': {'e_noun._n': 'nearly a week'},
 'the past weekly/_n': {'e_noun._n': 'the past week'},
 'weekly in/_n': {'e_noun._n': 'week in'},
 'week inner/_n': {'e_noun._n': 'week in'},
 'the next weekly/_n': {'e_noun._n': 'the next week'},
 'every weekly/_n': {'e_noun._n': 'every week'},
 'just a weekly/_n': {'e_noun._n': 'just a week'},
 'that weekly/_n': {'e_noun._n': 'that week'},
 'the workless week/_n': {'e_noun._n': 'the work week'},
 'the work weekly/_n': {'e_noun._n': 'the work week'},
 'the coming weekly/_n': {'e_noun._n': 'the coming week'},
 'at least a weekly/_n': {'e_noun._n': 'at least a week'},
 'the latest weekly/_n': {'e_noun._n': 'the latest week'},
 'another weekly/_n': {'e_noun._n': 'another week'},
 'once a weekly/_n': {'e_noun._n': 'once a week'},
 'the same weekly/_n': {'e_noun._n': 'the same week'},
 'only a weekly/_n': {'e_noun._n': 'only a week'},
 'about a weekly/_n': {'e_noun._n': 'about a week'},
 'each weekly/_n': {'e_noun._n': 'each week'},
 'all weekly/_n': {'e_noun._n': 'all week'},
 'the last weekly/_n': {'e_noun._n': 'the last week'},
 'the previous weekly/_n': {'e_noun._n': 'the previous week'},
 'the first weekly/_n': {'e_noun._n': 'the first week'},
 'labor day weekly/_n': {'e_noun._n': 'labor day weekend'},
 'all-star weekly/_n': {'e_noun._n': 'all-star weekend'},
 'my weighable/_n': {'e_noun._n': 'my weight'},
 'its weighable/_n': {'e_noun._n': 'its weight'},
 'bodily weight/_n': {'e_noun._n': 'body weight'},
 'body weighable/_n': {'e_noun._n': 'body weight'},
 'some weighable/_n': {'e_noun._n': 'some weight'},
 'more weighable/_n': {'e_noun._n': 'more weight'},
 'their weighable/_n': {'e_noun._n': 'their weight'},
 'his weighable/_n': {'e_noun._n': 'his weight'},
 'that weighable/_n': {'e_noun._n': 'that weight'},
 'a weighable/_n': {'e_noun._n': 'a weight'},
 'her weighable/_n': {'e_noun._n': 'her weight'},
 'society welfare/_n': {'e_noun._n': 'social welfare'},
 'which willing/_n': {'e_noun._n': 'which will'},
 'a whisppery/_n': {'e_noun._n': 'a whisper'},
 'his wifelike/_n': {'e_noun._n': 'his wife'},
 'a wifelike/_n': {'e_noun._n': 'a wife'},
 'his new wifelike/_n': {'e_noun._n': 'his new wife'},
 'my wifelike/_n': {'e_noun._n': 'my wife'},
 'your wifelike/_n': {'e_noun._n': 'your wife'},
 'the wifelike/_n': {'e_noun._n': 'the wife'},
 'his first wifelike/_n': {'e_noun._n': 'his first wife'},
 'his former wifelike/_n': {'e_noun._n': 'his former wife'},
 'his second wifelike/_n': {'e_noun._n': 'his second wife'},
 'whose wifelike/_n': {'e_noun._n': 'whose wife'},
 'other wild/_n': {'e_noun._n': 'other wildlife'},
 'a wildness/_n': {'e_noun._n': 'a wild'},
 "god's willing/_n": {'e_noun._n': "god's will"},
 'political willing/_n': {'e_noun._n': 'political will'},
 'its willing/_n': {'e_noun._n': 'its will'},
 'her willing/_n': {'e_noun._n': 'her will'},
 'that willing/_n': {'e_noun._n': 'that will'},
 'the willing of the people/_n': {'e_noun._n': 'the will of the people'},
 'a winnable/_n': {'e_noun._n': 'a win'},
 'the winnable/_n': {'e_noun._n': 'the win'},
 'his winnable/_n': {'e_noun._n': 'his win'},
 'storing windows/_n': {'e_noun._n': 'store windows'},
 'late wintry/_n': {'e_noun._n': 'late winter'},
 'harsh wintry/_n': {'e_noun._n': 'harsh winter'},
 'cold wintry/_n': {'e_noun._n': 'cold winter'},
 'last wintry/_n': {'e_noun._n': 'last winter'},
 'mild wintry/_n': {'e_noun._n': 'mild winter'},
 'lasting winter/_n': {'e_noun._n': 'last winter'},
 'severe wintry/_n': {'e_noun._n': 'severe winter'},
 'early wintry/_n': {'e_noun._n': 'early winter'},
 'copper wireless/_n': {'e_noun._n': 'copper wire'},
 'wire service/_n': {'e_noun._n': 'wireless service'},
 'his wise/_n': {'e_noun._n': 'his wisdom'},
 'conventional wise/_n': {'e_noun._n': 'conventional wisdom'},
 'the conventional wise/_n': {'e_noun._n': 'the conventional wisdom'},
 'their wishful/_n': {'e_noun._n': 'their wish'},
 'a wishful/_n': {'e_noun._n': 'a wish'},
 'his wishful/_n': {'e_noun._n': 'his wish'},
 'third witnesses/_n': {'e_noun._n': 'three witnesses'},
 'the third women/_n': {'e_noun._n': 'the three women'},
 'third women/_n': {'e_noun._n': 'three women'},
 'sixteenth women/_n': {'e_noun._n': 'six women'},
 'this women/_n': {'e_noun._n': 'those women'},
 'no wonderful/_n': {'e_noun._n': 'no wonder'},
 'this words/_n': {'e_noun._n': 'those words'},
 'third words/_n': {'e_noun._n': 'three words'},
 'the right wordless/_n': {'e_noun._n': 'the right word'},
 'that wordless/_n': {'e_noun._n': 'that word'},
 'its wordless/_n': {'e_noun._n': 'its word'},
 'the written wordless/_n': {'e_noun._n': 'the written word'},
 'each wordless/_n': {'e_noun._n': 'each word'},
 'every wordless/_n': {'e_noun._n': 'every word'},
 'their wordless/_n': {'e_noun._n': 'their word'},
 'whose workless/_n': {'e_noun._n': 'whose work'},
 'his own workless/_n': {'e_noun._n': 'his own work'},
 'flexible workless/_n': {'e_noun._n': 'flexible work'},
 'our workless/_n': {'e_noun._n': 'our work'},
 'no workless/_n': {'e_noun._n': 'no work'},
 'good workless/_n': {'e_noun._n': 'good work'},
 'similar workless/_n': {'e_noun._n': 'similar work'},
 'full-time workless/_n': {'e_noun._n': 'full-time work'},
 'workless to do/_n': {'e_noun._n': 'work to do'},
 'other workless/_n': {'e_noun._n': 'other work'},
 'steady workless/_n': {'e_noun._n': 'steady work'},
 'some workless/_n': {'e_noun._n': 'some work'},
 'the hard workless/_n': {'e_noun._n': 'the hard work'},
 'the workless/_n': {'e_noun._n': 'the work'},
 'extra workless/_n': {'e_noun._n': 'extra work'},
 'workless there/_n': {'e_noun._n': 'work there'},
 'temporary workless/_n': {'e_noun._n': 'temporary work'},
 'such workless/_n': {'e_noun._n': 'such work'},
 'workless here/_n': {'e_noun._n': 'work here'},
 'her workless/_n': {'e_noun._n': 'her work'},
 'governing work/_n': {'e_noun._n': 'government work'},
 'government workless/_n': {'e_noun._n': 'government work'},
 'workless today/_n': {'e_noun._n': 'work today'},
 'the new workless/_n': {'e_noun._n': 'the new work'},
 'more workless/_n': {'e_noun._n': 'more work'},
 'that workless/_n': {'e_noun._n': 'that work'},
 'its workless/_n': {'e_noun._n': 'its work'},
 'all the workless/_n': {'e_noun._n': 'all the work'},
 'much workless/_n': {'e_noun._n': 'much work'},
 'any workless/_n': {'e_noun._n': 'any work'},
 'my workless/_n': {'e_noun._n': 'my work'},
 'his workless/_n': {'e_noun._n': 'his work'},
 'all workless/_n': {'e_noun._n': 'all work'},
 'a workless/_n': {'e_noun._n': 'a work'},
 'healthy care workers/_n': {'e_noun._n': 'health care workers'},
 'health careful workers/_n': {'e_noun._n': 'health care workers'},
 'migration workers/_n': {'e_noun._n': 'migrant workers'},
 'constructive workers/_n': {'e_noun._n': 'construction workers'},
 'this workers/_n': {'e_noun._n': 'those workers'},
 'governing workers/_n': {'e_noun._n': 'government workers'},
 'aided workers/_n': {'e_noun._n': 'aid workers'},
 'reality world/_n': {'e_noun._n': 'real world'},
 'the reality world/_n': {'e_noun._n': 'the real world'},
 'the computational world/_n': {'e_noun._n': 'the computer world'},
 'the fashionable world/_n': {'e_noun._n': 'the fashion world'},
 'the world we living in/_n': {'e_noun._n': 'the world we live in'},
 'the world we live inner/_n': {'e_noun._n': 'the world we live in'},
 'this worries/_n': {'e_noun._n': 'those worries'},
 'their worthy/_n': {'e_noun._n': 'their worth'},
 'his worthy/_n': {'e_noun._n': 'his worth'},
 'its worthy/_n': {'e_noun._n': 'its worth'},
 'year inner/_n': {'e_noun._n': 'year in'},
 'this years,/_n': {'e_noun._n': 'those years,'},
 'this years/_n': {'e_noun._n': 'those years'},
 'treasury bonding yields/_n': {'e_noun._n': 'treasury bond yields'},
 'our youthful/_n': {'e_noun._n': 'our youth'},
 "today's youthful/_n": {'e_noun._n': "today's youth"},
 'their youthful/_n': {'e_noun._n': 'their youth'},
 'her youthful/_n': {'e_noun._n': 'her youth'},
 'every day/_n': {'_nt': ''},
 'this morning/_n': {'_nt': ''},
 'provide effectiveness': {'e_trp.dobj': ''},
 'halfway': {'be_jj_to_vbg': ''},
 'unable': {'be_jj_to_vb': ''},
 'afraid': {'be_jj_to_vb': ''},
 'careless': {'be_jj_to_vb': ''},
 'liable': {'be_jj_to_vb': ''},
 'proud': {'be_jj_to_vb': '', 'jj_to_jjr': 'prouder', 'jj_to_jjs': 'proudest'},
 'apt': {'be_jj_to_vb': ''},
 'impossible': {'be_jj_to_vb': ''},
 'seem weakness/xcomp': {'e_trp.xcomp': ''},
 'their ankle/_n': {'e_noun.form': ''},
 'their arm/_n': {'e_noun.form': ''},
 'their artery/_n': {'e_noun.form': ''},
 'their back/_n': {'e_noun.form': ''},
 'their beard/_n': {'e_noun.form': ''},
 'their bone/_n': {'e_noun.form': ''},
 'their brain/_n': {'e_noun.form': ''},
 'their cheek/_n': {'e_noun.form': ''},
 'their chest/_n': {'e_noun.form': ''},
 'their chin/_n': {'e_noun.form': ''},
 'their ear/_n': {'e_noun.form': ''},
 'their elbow/_n': {'e_noun.form': ''},
 'their eye/_n': {'e_noun.form': ''},
 'their eyebrow/_n': {'e_noun.form': ''},
 'their eyelash/_n': {'e_noun.form': ''},
 'their finger/_n': {'e_noun.form': ''},
 'their fist/_n': {'e_noun.form': ''},
 'their foot/_n': {'e_noun.form': ''},
 'their forehead/_n': {'e_noun.form': ''},
 'their hair/_n': {'e_noun.form': ''},
 'their hand/_n': {'e_noun.form': ''},
 'their head/_n': {'e_noun.form': ''},
 'their heart/_n': {'e_noun.form': ''},
 'their heel/_n': {'e_noun.form': ''},
 'their hip/_n': {'e_noun.form': ''},
 'their husband/_n': {'e_noun.form': ''},
 'their instep/_n': {'e_noun.form': ''},
 'their joint/_n': {'e_noun.form': ''},
 'their kidney/_n': {'e_noun.form': ''},
 'their knee/_n': {'e_noun.form': ''},
 'their leg/_n': {'e_noun.form': ''},
 'their lip/_n': {'e_noun.form': ''},
 'their lung/_n': {'e_noun.form': ''},
 'their mole/_n': {'e_noun.form': ''},
 'their mouth/_n': {'e_noun.form': ''},
 'their muscle/_n': {'e_noun.form': ''},
 'their mustache/_n': {'e_noun.form': ''},
 'their nail/_n': {'e_noun.form': ''},
 'their navel/_n': {'e_noun.form': ''},
 'their neck/_n': {'e_noun.form': ''},
 'their nerve/_n': {'e_noun.form': ''},
 'their nipple/_n': {'e_noun.form': ''},
 'their nose/_n': {'e_noun.form': ''},
 'their palm/_n': {'e_noun.form': ''},
 'their pit/_n': {'e_noun.form': ''},
 'their rib/_n': {'e_noun.form': ''},
 'their shoulder/_n': {'e_noun.form': ''},
 'their skull/_n': {'e_noun.form': ''},
 'their stomach/_n': {'e_noun.form': ''},
 'their thigh/_n': {'e_noun.form': ''},
 'their throat/_n': {'e_noun.form': ''},
 'their toes/_n': {'e_noun.form': ''},
 'their tongue/_n': {'e_noun.form': ''},
 'their tooth/_n': {'e_noun.form': ''},
 'their vein/_n': {'e_noun.form': ''},
 'their waist/_n': {'e_noun.form': ''},
 'their wife/_n': {'e_noun.form': ''},
 'their wrist/_n': {'e_noun.form': ''},
 'our ankle/_n': {'e_noun.form': ''},
 'our arm/_n': {'e_noun.form': ''},
 'our artery/_n': {'e_noun.form': ''},
 'our back/_n': {'e_noun.form': ''},
 'our beard/_n': {'e_noun.form': ''},
 'our bone/_n': {'e_noun.form': ''},
 'our brain/_n': {'e_noun.form': ''},
 'our cheek/_n': {'e_noun.form': ''},
 'our chest/_n': {'e_noun.form': ''},
 'our chin/_n': {'e_noun.form': ''},
 'our ear/_n': {'e_noun.form': ''},
 'our elbow/_n': {'e_noun.form': ''},
 'our eye/_n': {'e_noun.form': ''},
 'our eyebrow/_n': {'e_noun.form': ''},
 'our eyelash/_n': {'e_noun.form': ''},
 'our finger/_n': {'e_noun.form': ''},
 'our fist/_n': {'e_noun.form': ''},
 'our foot/_n': {'e_noun.form': ''},
 'our forehead/_n': {'e_noun.form': ''},
 'our hair/_n': {'e_noun.form': ''},
 'our hand/_n': {'e_noun.form': ''},
 'our head/_n': {'e_noun.form': ''},
 'our heart/_n': {'e_noun.form': ''},
 'our heel/_n': {'e_noun.form': ''},
 'our hip/_n': {'e_noun.form': ''},
 'our husband/_n': {'e_noun.form': ''},
 'our instep/_n': {'e_noun.form': ''},
 'our joint/_n': {'e_noun.form': ''},
 'our kidney/_n': {'e_noun.form': ''},
 'our knee/_n': {'e_noun.form': ''},
 'our leg/_n': {'e_noun.form': ''},
 'our lip/_n': {'e_noun.form': ''},
 'our lung/_n': {'e_noun.form': ''},
 'our mole/_n': {'e_noun.form': ''},
 'our mouth/_n': {'e_noun.form': ''},
 'our muscle/_n': {'e_noun.form': ''},
 'our mustache/_n': {'e_noun.form': ''},
 'our nail/_n': {'e_noun.form': ''},
 'our navel/_n': {'e_noun.form': ''},
 'our neck/_n': {'e_noun.form': ''},
 'our nerve/_n': {'e_noun.form': ''},
 'our nipple/_n': {'e_noun.form': ''},
 'our nose/_n': {'e_noun.form': ''},
 'our palm/_n': {'e_noun.form': ''},
 'our pit/_n': {'e_noun.form': ''},
 'our rib/_n': {'e_noun.form': ''},
 'our shoulder/_n': {'e_noun.form': ''},
 'our skull/_n': {'e_noun.form': ''},
 'our stomach/_n': {'e_noun.form': ''},
 'our thigh/_n': {'e_noun.form': ''},
 'our throat/_n': {'e_noun.form': ''},
 'our toes/_n': {'e_noun.form': ''},
 'our tongue/_n': {'e_noun.form': ''},
 'our tooth/_n': {'e_noun.form': ''},
 'our vein/_n': {'e_noun.form': ''},
 'our waist/_n': {'e_noun.form': ''},
 'our wife/_n': {'e_noun.form': ''},
 'our wrist/_n': {'e_noun.form': ''},
 'house be empty': {'e_trpx.nva': ''},
 'fearless': {'jj_to_nn': 'fearlessness'},
 'practice strength/dobj_v_n': {'': ''},
 'store/dobj_v_exc': {'': ''},
 'believe/dobj_v_exc': {'': ''},
 'enrol student/dobj_v_n': {'': ''},
 'expand quantity/dobj_v_n': {'': ''},
 'convert challenge/dobj_v_n': {'': ''},
 'regard dedication/dobj_v_n': {'': ''},
 'perceive gender/dobj_v_n': {'': ''},
 'occupy activity/nsubj': {'': ''},
 'devote love/dobj_v_n': {'': ''},
 'wu': {'cap_word': 'Wu'},
 'jinping': {'cap_word': 'Jinping'},
 'luoyang': {'cap_word': 'Luoyang'},
 'cuju': {'cap_word': 'Cuju'},
 'hawking': {'cap_word': 'Hawking', 'n_is_sth': '0'},
 'hamlets': {'cap_word': 'Hamlets'},
 'chaijing': {'cap_word': 'Chaijing'},
 'decorate world/dobj_v_n': {'': ''},
 'know hobby/dobj_v_n': {'': ''},
 'preciousness': {'nn_to_jj': 'precious'},
 'dispirit': {'vt_typical': ''},
 'ensure assumption/dobj_v_n': {'': ''},
 'leap fire/dobj_v_n': {'': ''},
 'hostile': {'v_to': ''},
 'pledge supporter/dobj_v_n': {'': ''},
 'tvs': {'cap_word': 'TVs'},
 'pregnant': {'jj_to_nn': 'pregnance'},
 'many meaningful books': {'_n': ''},
 'a cat burst/_n': {'': ''},
 'felling': {'spell_err': 'feeling'},
 'fascinative': {'confu_pair': 'fascinating'},
 'tough cookie': {'n_is_sb': 'noun_attr'},
 'madras': {'n_is_sth': ''},
 'hypokalaemia': {'n_is_nu': '', 'n_is_sth': ''},
 'hypoxaemia': {'n_is_nu': '', 'n_is_sth': ''},
 'eateries': {'nns_to_nn': 'eatery'},
 'physic': {'n_is_nu': '', 'vb_to_vbz': 'physics', 'vb_to_vbg': 'physicking', 'vb_to_vbd': 'physicked', 'vb_to_vbn': 'physicked', 'vbd_eq_vbn': ''},
 'family rajidae': {'n_is_sth': '0'},
 'abomasum': {'n_is_sth': '0'},
 'aculea': {'n_is_sth': '0'},
 'aculeus': {'n_is_sth': '0'},
 'adalia': {'n_is_sth': '0'},
 'aeon': {'n_is_sth': '0'},
 'aftershaft': {'n_is_sth': '0'},
 'air bladder': {'n_is_sth': '0'},
 'air sac': {'n_is_sth': '0'},
 'allantois': {'n_is_sth': '0'},
 'alula': {'n_is_sth': '0'},
 'amnion': {'n_is_sth': '0'},
 'amnios': {'n_is_sth': '0'},
 'amniotic sac': {'n_is_sth': '0'},
 'amoebida': {'n_is_sth': '0'},
 'amoebina': {'n_is_sth': '0'},
 'aneides': {'n_is_sth': '0'},
 'anguillidae': {'n_is_sth': '0'},
 'anguilliformes': {'n_is_sth': '0'},
 'anhima': {'n_is_sth': '0'},
 'anhingidae': {'n_is_sth': '0'},
 'animal kingdom': {'n_is_sth': '0'},
 'animal leg': {'n_is_sth': '0'},
 'animal order': {'n_is_sth': '0'},
 'annelida': {'n_is_sth': '0'},
 'anniellidae': {'n_is_sth': '0'},
 'anobiidae': {'n_is_sth': '0'},
 'anolis': {'n_is_sth': '0'},
 'anomala': {'n_is_sth': '0'},
 'anomalopidae': {'n_is_sth': '0'},
 'anomalops': {'n_is_sth': '0'},
 'anomia': {'n_is_sth': '0'},
 'anomiidae': {'n_is_sth': '0'},
 'anostraca': {'n_is_sth': '0'},
 'anseres': {'n_is_sth': '0'},
 'anserinae': {'n_is_sth': '0'},
 'anser': {'n_is_sth': '0'},
 'antedonidae': {'n_is_sth': '0'},
 'antedon': {'n_is_sth': '0'},
 'antennariidae': {'n_is_sth': '0'},
 'antheraea': {'n_is_sth': '0'},
 'anthidium': {'n_is_sth': '0'},
 'anthonomus': {'n_is_sth': '0'},
 'anthropoidea': {'n_is_sth': '0'},
 'anthus': {'n_is_sth': '0'},
 'antigonia': {'n_is_sth': '0'},
 'antilocapridae': {'n_is_sth': '0'},
 'antrozous': {'n_is_sth': '0'},
 'apatura': {'n_is_sth': '0'},
 'aphasmidia': {'n_is_sth': '0'},
 'aphriza': {'n_is_sth': '0'},
 'aphrophora': {'n_is_sth': '0'},
 'apidae': {'n_is_sth': '0'},
 'aplacophora': {'n_is_sth': '0'},
 'aplodontiidae': {'n_is_sth': '0'},
 'aplysia': {'n_is_sth': '0'},
 'apodeme': {'n_is_sth': '0'},
 'apodidae': {'n_is_sth': '0'},
 'apodiformes': {'n_is_sth': '0'},
 'apogonidae': {'n_is_sth': '0'},
 'apogon': {'n_is_sth': '0'},
 'aptenodytes': {'n_is_sth': '0'},
 'apterygidae': {'n_is_sth': '0'},
 'apterygiformes': {'n_is_sth': '0'},
 'apus': {'n_is_sth': '0'},
 'arachnida': {'n_is_sth': '0'},
 'araneae': {'n_is_sth': '0'},
 'aranea': {'n_is_sth': '0'},
 'araneus': {'n_is_sth': '0'},
 'arcellidae': {'n_is_sth': '0'},
 'archaeornithes': {'n_is_sth': '0'},
 'archenteron': {'n_is_sth': '0'},
 'archidiskidon': {'n_is_sth': '0'},
 'archosargus': {'n_is_sth': '0'},
 'arctocebus': {'n_is_sth': '0'},
 'arctonyx': {'n_is_sth': '0'},
 'arenaviridae': {'n_is_sth': '0'},
 'argasidae': {'n_is_sth': '0'},
 'argentinidae': {'n_is_sth': '0'},
 'argiope': {'n_is_sth': '0'},
 'argonauta': {'n_is_sth': '0'},
 'argonautidae': {'n_is_sth': '0'},
 'argusianus': {'n_is_sth': '0'},
 'argynnis': {'n_is_sth': '0'},
 'argyrotaenia': {'n_is_sth': '0'},
 'ariidae': {'n_is_sth': '0'},
 'arilus': {'n_is_sth': '0'},
 'ariomma': {'n_is_sth': '0'},
 'armadillidiidae': {'n_is_sth': '0'},
 'artamidae': {'n_is_sth': '0'},
 'artamus': {'n_is_sth': '0'},
 'arthropod family': {'n_is_sth': '0'},
 'arthropod genus': {'n_is_sth': '0'},
 'arthropoda': {'n_is_sth': '0'},
 'artiodactyla': {'n_is_sth': '0'},
 'arvicola': {'n_is_sth': '0'},
 'ascaphidae': {'n_is_sth': '0'},
 'ascidiaceae': {'n_is_sth': '0'},
 'asilidae': {'n_is_sth': '0'},
 'asio': {'n_is_sth': '0'},
 'aspidiotus': {'n_is_sth': '0'},
 'astacidae': {'n_is_sth': '0'},
 'astacus': {'n_is_sth': '0'},
 'astrophyton': {'n_is_sth': '0'},
 'astropogon': {'n_is_sth': '0'},
 'atherinidae': {'n_is_sth': '0'},
 'atherinopsis': {'n_is_sth': '0'},
 'athiorhodaceae': {'n_is_sth': '0'},
 'atrichornis': {'n_is_sth': '0'},
 'atrichornithidae': {'n_is_sth': '0'},
 'atropidae': {'n_is_sth': '0'},
 'aulacorhyncus': {'n_is_sth': '0'},
 'aulostomidae': {'n_is_sth': '0'},
 'auriparus': {'n_is_sth': '0'},
 'automeris': {'n_is_sth': '0'},
 'aythya': {'n_is_sth': '0'},
 'babesiidae': {'n_is_sth': '0'},
 'bacteria family': {'n_is_sth': '0'},
 'bacteria genus': {'n_is_sth': '0'},
 'bacteria order': {'n_is_sth': '0'},
 'bacteria species': {'n_is_sth': '0'},
 'bacteriochlorophyll': {'n_is_sth': '0'},
 'balaena': {'n_is_sth': '0'},
 'balaeniceps': {'n_is_sth': '0'},
 'balaenicipitidae': {'n_is_sth': '0'},
 'balaenidae': {'n_is_sth': '0'},
 'balaenoptera': {'n_is_sth': '0'},
 'balaenopteridae': {'n_is_sth': '0'},
 'balanidae': {'n_is_sth': '0'},
 'balanus': {'n_is_sth': '0'},
 'balistidae': {'n_is_sth': '0'},
 'bangiaceae': {'n_is_sth': '0'},
 'bartramia': {'n_is_sth': '0'},
 'basiliscus': {'n_is_sth': '0'},
 'bassariscidae': {'n_is_sth': '0'},
 'bastard wing': {'n_is_sth': '0'},
 'bathyergus': {'n_is_sth': '0'},
 'batrachoididae': {'n_is_sth': '0'},
 'bear claw': {'n_is_sth': '0'},
 'belemnitidae': {'n_is_sth': '0'},
 'belemnoidea': {'n_is_sth': '0'},
 'belonidae': {'n_is_sth': '0'},
 'belostomatidae': {'n_is_sth': '0'},
 'berycomorphi': {'n_is_sth': '0'},
 'bird family': {'n_is_sth': '0'},
 'bird genus': {'n_is_sth': '0'},
 "bird's foot": {'n_is_sth': '0'},
 'bitis': {'n_is_sth': '0'},
 'bittacidae': {'n_is_sth': '0'},
 'bivalvia': {'n_is_sth': '0'},
 'blackburn': {'n_is_sth': '0'},
 'blastocele': {'n_is_sth': '0'},
 'blastocoele': {'n_is_sth': '0'},
 'blastocoel': {'n_is_sth': '0'},
 'blastocyst': {'n_is_sth': '0'},
 'blastodermic vesicle': {'n_is_sth': '0'},
 'blastoderm': {'n_is_sth': '0'},
 'blastodisc': {'n_is_sth': '0'},
 'blastomere': {'n_is_sth': '0'},
 'blastopore': {'n_is_sth': '0'},
 'blastosphere': {'n_is_sth': '0'},
 'blastula': {'n_is_sth': '0'},
 'blattella': {'n_is_sth': '0'},
 'blattidae': {'n_is_sth': '0'},
 'blenniidae': {'n_is_sth': '0'},
 'blennius': {'n_is_sth': '0'},
 'boidae': {'n_is_sth': '0'},
 'bombycidae': {'n_is_sth': '0'},
 'bombycillidae': {'n_is_sth': '0'},
 'bothidae': {'n_is_sth': '0'},
 'bothrops': {'n_is_sth': '0'},
 'bovinae': {'n_is_sth': '0'},
 'brachiopoda': {'n_is_sth': '0'},
 'brachyura': {'n_is_sth': '0'},
 'bradypodidae': {'n_is_sth': '0'},
 'bramidae': {'n_is_sth': '0'},
 'branchial arch': {'n_is_sth': '0'},
 'branchial cleft': {'n_is_sth': '0'},
 'branchia': {'n_is_sth': '0'},
 'branchiobdella': {'n_is_sth': '0'},
 'branchiopoda': {'n_is_sth': '0'},
 'branchiostegidae': {'n_is_sth': '0'},
 'branchiostomidae': {'n_is_sth': '0'},
 'bruchidae': {'n_is_sth': '0'},
 'bruchus': {'n_is_sth': '0'},
 'bubo': {'n_is_sth': '0'},
 'buccinidae': {'n_is_sth': '0'},
 'bucconidae': {'n_is_sth': '0'},
 'budorcas': {'n_is_sth': '0'},
 'bunyaviridae': {'n_is_sth': '0'},
 'burhinidae': {'n_is_sth': '0'},
 'burhinus': {'n_is_sth': '0'},
 'burmeisteria': {'n_is_sth': '0'},
 'c. diphtheriae': {'n_is_sth': '0'},
 'cacatua': {'n_is_sth': '0'},
 'cacicus': {'n_is_sth': '0'},
 'caenolestidae': {'n_is_sth': '0'},
 'cairina': {'n_is_sth': '0'},
 'caliculus': {'n_is_sth': '0'},
 'calidris': {'n_is_sth': '0'},
 'callicebus': {'n_is_sth': '0'},
 'calliophis': {'n_is_sth': '0'},
 'calliphora': {'n_is_sth': '0'},
 'calliphoridae': {'n_is_sth': '0'},
 'callisaurus': {'n_is_sth': '0'},
 'callithricidae': {'n_is_sth': '0'},
 'callithrix': {'n_is_sth': '0'},
 'callorhinus': {'n_is_sth': '0'},
 'calypter': {'n_is_sth': '0'},
 'cambarus': {'n_is_sth': '0'},
 'camelus': {'n_is_sth': '0'},
 'campylorhynchus': {'n_is_sth': '0'},
 'cancridae': {'n_is_sth': '0'},
 'canecutter': {'n_is_sth': '0'},
 'canis': {'n_is_sth': '0'},
 'cannon bone': {'n_is_sth': '0'},
 'capella': {'n_is_sth': '0'},
 'capitonidae': {'n_is_sth': '0'},
 'caprella': {'n_is_sth': '0'},
 'caprimulgidae': {'n_is_sth': '0'},
 'caprimulgiformes': {'n_is_sth': '0'},
 'caprimulgus': {'n_is_sth': '0'},
 'caproidae': {'n_is_sth': '0'},
 'capromyidae': {'n_is_sth': '0'},
 'capros': {'n_is_sth': '0'},
 'capsidae': {'n_is_sth': '0'},
 'carabidae': {'n_is_sth': '0'},
 'carangidae': {'n_is_sth': '0'},
 'caranx': {'n_is_sth': '0'},
 'carapidae': {'n_is_sth': '0'},
 'carcase': {'n_is_sth': '0'},
 'carcharhinidae': {'n_is_sth': '0'},
 'carchariidae': {'n_is_sth': '0'},
 'carcharodon': {'n_is_sth': '0'},
 'cardium': {'n_is_sth': '0'},
 'carduelinae': {'n_is_sth': '0'},
 'carduelis': {'n_is_sth': '0'},
 'cariamidae': {'n_is_sth': '0'},
 'carnivora': {'n_is_sth': '0'},
 'carnosaura': {'n_is_sth': '0'},
 'carphophis': {'n_is_sth': '0'},
 'carpodacus': {'n_is_sth': '0'},
 'casmerodius': {'n_is_sth': '0'},
 'castoridae': {'n_is_sth': '0'},
 'casuaridae': {'n_is_sth': '0'},
 'casuariiformes': {'n_is_sth': '0'},
 'casuarius': {'n_is_sth': '0'},
 'catharacta': {'n_is_sth': '0'},
 'cathartidae': {'n_is_sth': '0'},
 'catostomidae': {'n_is_sth': '0'},
 'catostomus': {'n_is_sth': '0'},
 'caudal appendage': {'n_is_sth': '0'},
 'caudal fin': {'n_is_sth': '0'},
 'caudata': {'n_is_sth': '0'},
 'caviidae': {'n_is_sth': '0'},
 'cebidae': {'n_is_sth': '0'},
 'cebuella': {'n_is_sth': '0'},
 'cebus': {'n_is_sth': '0'},
 'cecidomyidae': {'n_is_sth': '0'},
 'centrarchidae': {'n_is_sth': '0'},
 'centriscidae': {'n_is_sth': '0'},
 'centrocercus': {'n_is_sth': '0'},
 'centropomidae': {'n_is_sth': '0'},
 'centropomus': {'n_is_sth': '0'},
 'centropristis': {'n_is_sth': '0'},
 'centropus': {'n_is_sth': '0'},
 'cephalaspida': {'n_is_sth': '0'},
 'cephalaspid': {'n_is_sth': '0'},
 'cephalobidae': {'n_is_sth': '0'},
 'cephalochordata': {'n_is_sth': '0'},
 'cepphus': {'n_is_sth': '0'},
 'ceratodontidae': {'n_is_sth': '0'},
 'ceratopogonidae': {'n_is_sth': '0'},
 'ceratopogon': {'n_is_sth': '0'},
 'ceratopsia': {'n_is_sth': '0'},
 'ceratopsidae': {'n_is_sth': '0'},
 'cercocebus3': {'n_is_sth': '0'},
 'cercopidae': {'n_is_sth': '0'},
 'cercopithecidae': {'n_is_sth': '0'},
 'cercopithecus': {'n_is_sth': '0'},
 'certhia': {'n_is_sth': '0'},
 'certhiidae': {'n_is_sth': '0'},
 'cervidae': {'n_is_sth': '0'},
 'cervus': {'n_is_sth': '0'},
 'ceryle': {'n_is_sth': '0'},
 'cestidae': {'n_is_sth': '0'},
 'cestoda': {'n_is_sth': '0'},
 'cetacea': {'n_is_sth': '0'},
 'cetonia': {'n_is_sth': '0'},
 'cetoniidae': {'n_is_sth': '0'},
 'cetorhinidae': {'n_is_sth': '0'},
 'cetorhinus': {'n_is_sth': '0'},
 'chaenopsis': {'n_is_sth': '0'},
 'chaetodipterus': {'n_is_sth': '0'},
 'chaetodon': {'n_is_sth': '0'},
 'chaetognatha': {'n_is_sth': '0'},
 'chalcidae': {'n_is_sth': '0'},
 'chalcididae': {'n_is_sth': '0'},
 'chalcis': {'n_is_sth': '0'},
 'chalcostigma': {'n_is_sth': '0'},
 'chamaeleonidae': {'n_is_sth': '0'},
 'chamaeleontidae': {'n_is_sth': '0'},
 'chamaeleo': {'n_is_sth': '0'},
 'channidae': {'n_is_sth': '0'},
 'characeae': {'n_is_sth': '0'},
 'characidae': {'n_is_sth': '0'},
 'characid': {'n_is_sth': '0'},
 'characinidae': {'n_is_sth': '0'},
 'charadriidae': {'n_is_sth': '0'},
 'charadriiformes': {'n_is_sth': '0'},
 'charadrii': {'n_is_sth': '0'},
 'charadrius': {'n_is_sth': '0'},
 'charales': {'n_is_sth': '0'},
 'charina': {'n_is_sth': '0'},
 'charophyceae': {'n_is_sth': '0'},
 'chelonethida': {'n_is_sth': '0'},
 'chelonia': {'n_is_sth': '0'},
 'chelonidae': {'n_is_sth': '0'},
 'cheloniidae': {'n_is_sth': '0'},
 'chelydra': {'n_is_sth': '0'},
 'chelydridae': {'n_is_sth': '0'},
 'chermidae': {'n_is_sth': '0'},
 'chilomastix': {'n_is_sth': '0'},
 'chilomeniscus': {'n_is_sth': '0'},
 'chilomycterus': {'n_is_sth': '0'},
 'chilopoda': {'n_is_sth': '0'},
 'chimaeridae': {'n_is_sth': '0'},
 'chiroptera': {'n_is_sth': '0'},
 'chlamydera': {'n_is_sth': '0'},
 'chlamydiaceae': {'n_is_sth': '0'},
 'chlamydomonadaceae': {'n_is_sth': '0'},
 'chlamydosaurus': {'n_is_sth': '0'},
 'chlamyphorus': {'n_is_sth': '0'},
 'chlorophyceae': {'n_is_sth': '0'},
 'chlorophyll a': {'n_is_sth': '0'},
 'chlorophyll b': {'n_is_sth': '0'},
 'chlorophyl': {'n_is_sth': '0'},
 'choanocyte': {'n_is_sth': '0'},
 'choeronycteris': {'n_is_sth': '0'},
 'chondrichthyes': {'n_is_sth': '0'},
 'chondrus': {'n_is_sth': '0'},
 'chordamesoderm': {'n_is_sth': '0'},
 'chordate genus': {'n_is_sth': '0'},
 'chordeiles': {'n_is_sth': '0'},
 'chordomesoderm': {'n_is_sth': '0'},
 'chorioallantoic membrane': {'n_is_sth': '0'},
 'chorioallantois': {'n_is_sth': '0'},
 'chorionic villus': {'n_is_sth': '0'},
 'chorion': {'n_is_sth': '0'},
 'chrysochloridae': {'n_is_sth': '0'},
 'chrysophyceae': {'n_is_sth': '0'},
 'cicadellidae': {'n_is_sth': '0'},
 'cichlidae': {'n_is_sth': '0'},
 'cicindelidae': {'n_is_sth': '0'},
 'ciliophora': {'n_is_sth': '0'},
 'cilium': {'n_is_sth': '0'},
 'cimicidae': {'n_is_sth': '0'},
 'cinclidae': {'n_is_sth': '0'},
 'cirripedia': {'n_is_sth': '0'},
 'citharichthys': {'n_is_sth': '0'},
 'cladorhyncus': {'n_is_sth': '0'},
 'class actinozoa': {'n_is_sth': '0'},
 'class anthozoa': {'n_is_sth': '0'},
 'class aphasmidia': {'n_is_sth': '0'},
 'class archiannelida': {'n_is_sth': '0'},
 'class ascidiaceae': {'n_is_sth': '0'},
 'cleavage cavity': {'n_is_sth': '0'},
 'clinidae': {'n_is_sth': '0'},
 'clinid': {'n_is_sth': '0'},
 'cloven foot': {'n_is_sth': '0'},
 'clypeus': {'n_is_sth': '0'},
 'cnidosporidia': {'n_is_sth': '0'},
 'coccidia': {'n_is_sth': '0'},
 'coccinellidae': {'n_is_sth': '0'},
 'coccoidea': {'n_is_sth': '0'},
 'coelenterata': {'n_is_sth': '0'},
 'coelenterate family': {'n_is_sth': '0'},
 'coelenteron': {'n_is_sth': '0'},
 'coerebidae': {'n_is_sth': '0'},
 'collembola': {'n_is_sth': '0'},
 'colubridae': {'n_is_sth': '0'},
 'columba': {'n_is_sth': '0'},
 'colymbiformes': {'n_is_sth': '0'},
 'conceptus': {'n_is_sth': '0'},
 'conodontophorida': {'n_is_sth': '0'},
 'contopus': {'n_is_sth': '0'},
 'contour feather': {'n_is_sth': '0'},
 'cooky': {'n_is_sth': '0'},
 'copepoda': {'n_is_sth': '0'},
 'coracias': {'n_is_sth': '0'},
 'coraciidae': {'n_is_sth': '0'},
 'coraciiformes': {'n_is_sth': '0'},
 'cordylidae': {'n_is_sth': '0'},
 'cordylus': {'n_is_sth': '0'},
 'coregonidae': {'n_is_sth': '0'},
 'coregonus': {'n_is_sth': '0'},
 'corixa': {'n_is_sth': '0'},
 'corrodentia': {'n_is_sth': '0'},
 'corvus': {'n_is_sth': '0'},
 'corydalidae': {'n_is_sth': '0'},
 'corynebacteriaceae': {'n_is_sth': '0'},
 'coryphaenidae': {'n_is_sth': '0'},
 'coscoroba': {'n_is_sth': '0'},
 'cosmocampus': {'n_is_sth': '0'},
 'cotingidae': {'n_is_sth': '0'},
 'cottidae': {'n_is_sth': '0'},
 'cracidae': {'n_is_sth': '0'},
 'cracticidae': {'n_is_sth': '0'},
 'cracticus': {'n_is_sth': '0'},
 'crangonidae': {'n_is_sth': '0'},
 'crangon': {'n_is_sth': '0'},
 'cricetidae': {'n_is_sth': '0'},
 'cricetus': {'n_is_sth': '0'},
 'crocethia': {'n_is_sth': '0'},
 'crocodilia': {'n_is_sth': '0'},
 'crocodylia': {'n_is_sth': '0'},
 'crocodylidae': {'n_is_sth': '0'},
 'crocodylus': {'n_is_sth': '0'},
 'crossopterygii': {'n_is_sth': '0'},
 'crotalidae': {'n_is_sth': '0'},
 'crotaphytus': {'n_is_sth': '0'},
 'crotophaga': {'n_is_sth': '0'},
 'croupe': {'n_is_sth': '0'},
 'cryptacanthodes': {'n_is_sth': '0'},
 'cryptobranchidae': {'n_is_sth': '0'},
 'cryptobranchus': {'n_is_sth': '0'},
 'cryptocercidae': {'n_is_sth': '0'},
 'cryptocercus': {'n_is_sth': '0'},
 'cryptophyceae': {'n_is_sth': '0'},
 'cryptotermes': {'n_is_sth': '0'},
 'cryptotis': {'n_is_sth': '0'},
 'ctenizidae': {'n_is_sth': '0'},
 'ctenocephalides': {'n_is_sth': '0'},
 'ctenocephalus': {'n_is_sth': '0'},
 'cuculus': {'n_is_sth': '0'},
 'culicidae': {'n_is_sth': '0'},
 'cuniculus': {'n_is_sth': '0'},
 'cupule': {'n_is_sth': '0'},
 'curculionidae': {'n_is_sth': '0'},
 'cursorius': {'n_is_sth': '0'},
 'cuterebra': {'n_is_sth': '0'},
 'cuterebridae': {'n_is_sth': '0'},
 'cuticula': {'n_is_sth': '0'},
 'cyanocitta': {'n_is_sth': '0'},
 'cyanophyta': {'n_is_sth': '0'},
 'cycliophora': {'n_is_sth': '0'},
 'cyclopteridae': {'n_is_sth': '0'},
 'cyclopterus': {'n_is_sth': '0'},
 'cyclosporeae': {'n_is_sth': '0'},
 'cyclostomata': {'n_is_sth': '0'},
 'cydippea': {'n_is_sth': '0'},
 'cydippida': {'n_is_sth': '0'},
 'cydippidea': {'n_is_sth': '0'},
 'cymatiidae': {'n_is_sth': '0'},
 'cynipidae': {'n_is_sth': '0'},
 'cynocephalidae': {'n_is_sth': '0'},
 'cynodontia': {'n_is_sth': '0'},
 'cynoglossidae': {'n_is_sth': '0'},
 'cynopterus': {'n_is_sth': '0'},
 'cynoscion': {'n_is_sth': '0'},
 'cypraea': {'n_is_sth': '0'},
 'cypraeidae': {'n_is_sth': '0'},
 'cyprinidae': {'n_is_sth': '0'},
 'cypriniformes': {'n_is_sth': '0'},
 'cyprinodontidae': {'n_is_sth': '0'},
 'cystophora': {'n_is_sth': '0'},
 'cytostome': {'n_is_sth': '0'},
 'dacninae': {'n_is_sth': '0'},
 'dactylopiidae': {'n_is_sth': '0'},
 'dactylopius': {'n_is_sth': '0'},
 'dactylopteridae': {'n_is_sth': '0'},
 'dactylopterus': {'n_is_sth': '0'},
 'dactyloscopidae': {'n_is_sth': '0'},
 'dasyatidae': {'n_is_sth': '0'},
 'dasyatis': {'n_is_sth': '0'},
 'dasypodidae': {'n_is_sth': '0'},
 'dasyproctidae': {'n_is_sth': '0'},
 'dasypus': {'n_is_sth': '0'},
 'dasyuridae': {'n_is_sth': '0'},
 'dasyurid': {'n_is_sth': '0'},
 'dasyurus': {'n_is_sth': '0'},
 'daubentoniidae': {'n_is_sth': '0'},
 'decapoda': {'n_is_sth': '0'},
 'decapterus': {'n_is_sth': '0'},
 'delichon': {'n_is_sth': '0'},
 'delphinus': {'n_is_sth': '0'},
 'dendrocolaptidae': {'n_is_sth': '0'},
 'denticle': {'n_is_sth': '0'},
 'dermaptera': {'n_is_sth': '0'},
 'dermatobia': {'n_is_sth': '0'},
 'dermestidae': {'n_is_sth': '0'},
 'desmidiaceae': {'n_is_sth': '0'},
 'desmodontidae': {'n_is_sth': '0'},
 'diapsida': {'n_is_sth': '0'},
 'diaspididae': {'n_is_sth': '0'},
 'dibranchiata': {'n_is_sth': '0'},
 'dibranchia': {'n_is_sth': '0'},
 'dicrostonyx': {'n_is_sth': '0'},
 'dicynodontia': {'n_is_sth': '0'},
 'dinocerata': {'n_is_sth': '0'},
 'dinocerate': {'n_is_sth': '0'},
 'dinoflagellata': {'n_is_sth': '0'},
 'dinornithiformes': {'n_is_sth': '0'},
 'diodontidae': {'n_is_sth': '0'},
 'diodon': {'n_is_sth': '0'},
 'diphylla': {'n_is_sth': '0'},
 'diploid': {'n_is_sth': '0'},
 'dipnoi': {'n_is_sth': '0'},
 'dipsosaurus': {'n_is_sth': '0'},
 'diptera': {'n_is_sth': '0'},
 'discocephali': {'n_is_sth': '0'},
 'discoglossidae': {'n_is_sth': '0'},
 'division archaebacteria': {'n_is_sth': '0'},
 'division chlorophyta': {'n_is_sth': '0'},
 'division eubacteria': {'n_is_sth': '0'},
 'division phaeophyta': {'n_is_sth': '0'},
 'division rhodophyta': {'n_is_sth': '0'},
 'division schizophyta': {'n_is_sth': '0'},
 'dorsal fin': {'n_is_sth': '0'},
 'dorylinae': {'n_is_sth': '0'},
 'down feather': {'n_is_sth': '0'},
 'dracunculidae': {'n_is_sth': '0'},
 'dracunculus': {'n_is_sth': '0'},
 'drepanididae': {'n_is_sth': '0'},
 'dromaius': {'n_is_sth': '0'},
 'drymarchon': {'n_is_sth': '0'},
 'duck down': {'n_is_sth': '0'},
 'dugongidae': {'n_is_sth': '0'},
 'duplicidentata': {'n_is_sth': '0'},
 'dysdercus': {'n_is_sth': '0'},
 'echeneididae': {'n_is_sth': '0'},
 'echeneis': {'n_is_sth': '0'},
 'echidnophaga': {'n_is_sth': '0'},
 'echinoderm genus': {'n_is_sth': '0'},
 'ectoblast': {'n_is_sth': '0'},
 'ectopistes': {'n_is_sth': '0'},
 'edaphosauridae': {'n_is_sth': '0'},
 'edentata': {'n_is_sth': '0'},
 'eimeriidae': {'n_is_sth': '0'},
 'elagatis': {'n_is_sth': '0'},
 'elanus': {'n_is_sth': '0'},
 'elapidae': {'n_is_sth': '0'},
 'elasmobranchii': {'n_is_sth': '0'},
 'elaterid': {'n_is_sth': '0'},
 'electrophoridae': {'n_is_sth': '0'},
 'electrophorus': {'n_is_sth': '0'},
 'eleotridae': {'n_is_sth': '0'},
 'elephantidae': {'n_is_sth': '0'},
 'elephas': {'n_is_sth': '0'},
 'elopidae': {'n_is_sth': '0'},
 'emberiza': {'n_is_sth': '0'},
 'emberizidae': {'n_is_sth': '0'},
 'embiodea': {'n_is_sth': '0'},
 'embioptera': {'n_is_sth': '0'},
 'embiotocidae': {'n_is_sth': '0'},
 'embryonic tissue': {'n_is_sth': '0'},
 'emydidae': {'n_is_sth': '0'},
 'encolure': {'n_is_sth': '0'},
 'endamoebidae': {'n_is_sth': '0'},
 'endoblast': {'n_is_sth': '0'},
 'endoderm': {'n_is_sth': '0'},
 'engraulidae': {'n_is_sth': '0'},
 'entoblast': {'n_is_sth': '0'},
 'entoderm': {'n_is_sth': '0'},
 'entomostraca': {'n_is_sth': '0'},
 'ephemeridae': {'n_is_sth': '0'},
 'ephemerida': {'n_is_sth': '0'},
 'ephemeropteran': {'n_is_sth': '0'},
 'ephippidae': {'n_is_sth': '0'},
 'eptatretus': {'n_is_sth': '0'},
 'equus': {'n_is_sth': '0'},
 'erethizontidae': {'n_is_sth': '0'},
 'erignathus': {'n_is_sth': '0'},
 'erinaceidae': {'n_is_sth': '0'},
 'erinaceus': {'n_is_sth': '0'},
 'erithacus': {'n_is_sth': '0'},
 'erolia': {'n_is_sth': '0'},
 'escherichia': {'n_is_sth': '0'},
 'eschrichtiidae': {'n_is_sth': '0'},
 'eschrichtius': {'n_is_sth': '0'},
 'esox': {'n_is_sth': '0'},
 'essayer': {'n_is_sth': '0'},
 'estrilda': {'n_is_sth': '0'},
 'etropus': {'n_is_sth': '0'},
 'eubacteriales': {'n_is_sth': '0'},
 'eucinostomus': {'n_is_sth': '0'},
 'euderma': {'n_is_sth': '0'},
 'eudyptes': {'n_is_sth': '0'},
 'euglenaceae': {'n_is_sth': '0'},
 'eumetopias': {'n_is_sth': '0'},
 'eumops': {'n_is_sth': '0'},
 'euplectella': {'n_is_sth': '0'},
 'euproctis': {'n_is_sth': '0'},
 'euryalida': {'n_is_sth': '0'},
 'eurylaimidae': {'n_is_sth': '0'},
 'eurylaimi': {'n_is_sth': '0'},
 'eurypterida': {'n_is_sth': '0'},
 'eutheria': {'n_is_sth': '0'},
 'euthynnus': {'n_is_sth': '0'},
 'exocoetidae': {'n_is_sth': '0'},
 'exocycloida': {'n_is_sth': '0'},
 'exoderm': {'n_is_sth': '0'},
 'exopterygota': {'n_is_sth': '0'},
 'external gill': {'n_is_sth': '0'},
 'eyecup': {'n_is_sth': '0'},
 'falconidae': {'n_is_sth': '0'},
 'falconiformes': {'n_is_sth': '0'},
 'falco': {'n_is_sth': '0'},
 'family acanthisittidae': {'n_is_sth': '0'},
 'family acanthuridae': {'n_is_sth': '0'},
 'family acaridae': {'n_is_sth': '0'},
 'family accipitridae': {'n_is_sth': '0'},
 'family acipenseridae': {'n_is_sth': '0'},
 'family acrididae': {'n_is_sth': '0'},
 'family actinomycetaceae': {'n_is_sth': '0'},
 'family adelgidae': {'n_is_sth': '0'},
 'family aegypiidae': {'n_is_sth': '0'},
 'family aepyornidae': {'n_is_sth': '0'},
 'family agamidae': {'n_is_sth': '0'},
 'family agonidae': {'n_is_sth': '0'},
 'family ailuropodidae': {'n_is_sth': '0'},
 'family akeridae': {'n_is_sth': '0'},
 'family alaudidae': {'n_is_sth': '0'},
 'family albulidae': {'n_is_sth': '0'},
 'family alcedinidae': {'n_is_sth': '0'},
 'family alcidae': {'n_is_sth': '0'},
 'family aleyrodidae': {'n_is_sth': '0'},
 'family alligatoridae': {'n_is_sth': '0'},
 'family alopiidae': {'n_is_sth': '0'},
 'family ambystomatidae': {'n_is_sth': '0'},
 'family ameiuridae': {'n_is_sth': '0'},
 'family amiidae': {'n_is_sth': '0'},
 'family ammodytidae': {'n_is_sth': '0'},
 'family amphioxidae': {'n_is_sth': '0'},
 'family amphisbaenidae': {'n_is_sth': '0'},
 'family amphiumidae': {'n_is_sth': '0'},
 'family anabantidae': {'n_is_sth': '0'},
 'family anarhichadidae': {'n_is_sth': '0'},
 'family anatidae': {'n_is_sth': '0'},
 'family ancylidae': {'n_is_sth': '0'},
 'family ancylostomatidae': {'n_is_sth': '0'},
 'family andrenidae': {'n_is_sth': '0'},
 'family anguidae': {'n_is_sth': '0'},
 'family anguillidae': {'n_is_sth': '0'},
 'family anhimidae': {'n_is_sth': '0'},
 'family anhingidae': {'n_is_sth': '0'},
 'family anniellidae': {'n_is_sth': '0'},
 'family anobiidae': {'n_is_sth': '0'},
 'family anomalopidae': {'n_is_sth': '0'},
 'family anomiidae': {'n_is_sth': '0'},
 'family antedonidae': {'n_is_sth': '0'},
 'family antennariidae': {'n_is_sth': '0'},
 'family antilocapridae': {'n_is_sth': '0'},
 'family aphididae': {'n_is_sth': '0'},
 'family apidae': {'n_is_sth': '0'},
 'family aplodontiidae': {'n_is_sth': '0'},
 'family aplysiidae': {'n_is_sth': '0'},
 'family apodidae': {'n_is_sth': '0'},
 'family apogonidae': {'n_is_sth': '0'},
 'family apterygidae': {'n_is_sth': '0'},
 'family arcellidae': {'n_is_sth': '0'},
 'family arcidae': {'n_is_sth': '0'},
 'family arctiidae': {'n_is_sth': '0'},
 'family ardeidae': {'n_is_sth': '0'},
 'family argasidae': {'n_is_sth': '0'},
 'family argentinidae': {'n_is_sth': '0'},
 'family argiopidae': {'n_is_sth': '0'},
 'family argonautidae': {'n_is_sth': '0'},
 'family ariidae': {'n_is_sth': '0'},
 'family armadillidiidae': {'n_is_sth': '0'},
 'family artamidae': {'n_is_sth': '0'},
 'family ascaphidae': {'n_is_sth': '0'},
 'family ascaridae': {'n_is_sth': '0'},
 'family asilidae': {'n_is_sth': '0'},
 'family astacidae': {'n_is_sth': '0'},
 'family atherinidae': {'n_is_sth': '0'},
 'family athiorhodaceae': {'n_is_sth': '0'},
 'family atrichornithidae': {'n_is_sth': '0'},
 'family atropidae': {'n_is_sth': '0'},
 'family aulostomidae': {'n_is_sth': '0'},
 'family babesiidae': {'n_is_sth': '0'},
 'family bacillaceae': {'n_is_sth': '0'},
 'family bacteroidaceae': {'n_is_sth': '0'},
 'family balaenicipitidae': {'n_is_sth': '0'},
 'family balaenidae': {'n_is_sth': '0'},
 'family balaenopteridae': {'n_is_sth': '0'},
 'family balanidae': {'n_is_sth': '0'},
 'family belemnitidae': {'n_is_sth': '0'},
 'family belonidae': {'n_is_sth': '0'},
 'family belostomatidae': {'n_is_sth': '0'},
 'family bittacidae': {'n_is_sth': '0'},
 'family blattidae': {'n_is_sth': '0'},
 'family blenniidae': {'n_is_sth': '0'},
 'family boidae': {'n_is_sth': '0'},
 'family bombycidae': {'n_is_sth': '0'},
 'family bombycillidae': {'n_is_sth': '0'},
 'family bombyliidae': {'n_is_sth': '0'},
 'family bothidae': {'n_is_sth': '0'},
 'family bovidae': {'n_is_sth': '0'},
 'family bradypodidae': {'n_is_sth': '0'},
 'family bramidae': {'n_is_sth': '0'},
 'family branchiobdellidae': {'n_is_sth': '0'},
 'family branchiostegidae': {'n_is_sth': '0'},
 'family branchiostomidae': {'n_is_sth': '0'},
 'family brevicipitidae': {'n_is_sth': '0'},
 'family brotulidae': {'n_is_sth': '0'},
 'family bruchidae': {'n_is_sth': '0'},
 'family buccinidae': {'n_is_sth': '0'},
 'family bucconidae': {'n_is_sth': '0'},
 'family bucerotidae': {'n_is_sth': '0'},
 'family bufonidae': {'n_is_sth': '0'},
 'family burhinidae': {'n_is_sth': '0'},
 'family caeciliadae': {'n_is_sth': '0'},
 'family caeciliidae': {'n_is_sth': '0'},
 'family caenolestidae': {'n_is_sth': '0'},
 'family callionymidae': {'n_is_sth': '0'},
 'family calliphoridae': {'n_is_sth': '0'},
 'family callithricidae': {'n_is_sth': '0'},
 'family camelidae': {'n_is_sth': '0'},
 'family cancridae': {'n_is_sth': '0'},
 'family canidae': {'n_is_sth': '0'},
 'family capitonidae': {'n_is_sth': '0'},
 'family caprimulgidae': {'n_is_sth': '0'},
 'family caproidae': {'n_is_sth': '0'},
 'family capromyidae': {'n_is_sth': '0'},
 'family capsidae': {'n_is_sth': '0'},
 'family carabidae': {'n_is_sth': '0'},
 'family carangidae': {'n_is_sth': '0'},
 'family carapidae': {'n_is_sth': '0'},
 'family carcharhinidae': {'n_is_sth': '0'},
 'family carchariidae': {'n_is_sth': '0'},
 'family cardiidae': {'n_is_sth': '0'},
 'family cariamidae': {'n_is_sth': '0'},
 'family castoridae': {'n_is_sth': '0'},
 'family casuaridae': {'n_is_sth': '0'},
 'family cathartidae': {'n_is_sth': '0'},
 'family catostomidae': {'n_is_sth': '0'},
 'family caviidae': {'n_is_sth': '0'},
 'family cebidae': {'n_is_sth': '0'},
 'family cecidomyidae': {'n_is_sth': '0'},
 'family centrarchidae': {'n_is_sth': '0'},
 'family centriscidae': {'n_is_sth': '0'},
 'family centropomidae': {'n_is_sth': '0'},
 'family cephalobidae': {'n_is_sth': '0'},
 'family cerambycidae': {'n_is_sth': '0'},
 'family ceratodontidae': {'n_is_sth': '0'},
 'family ceratopogonidae': {'n_is_sth': '0'},
 'family ceratopsidae': {'n_is_sth': '0'},
 'family cercopidae': {'n_is_sth': '0'},
 'family cercopithecidae': {'n_is_sth': '0'},
 'family certhiidae': {'n_is_sth': '0'},
 'family cervidae': {'n_is_sth': '0'},
 'family cestidae': {'n_is_sth': '0'},
 'family cetorhinidae': {'n_is_sth': '0'},
 'family chaetodontidae': {'n_is_sth': '0'},
 'family chalcidae': {'n_is_sth': '0'},
 'family chalcididae': {'n_is_sth': '0'},
 'family chamaeleonidae': {'n_is_sth': '0'},
 'family chamaeleontidae': {'n_is_sth': '0'},
 'family characeae': {'n_is_sth': '0'},
 'family characidae': {'n_is_sth': '0'},
 'family characinidae': {'n_is_sth': '0'},
 'family charadriidae': {'n_is_sth': '0'},
 'family chelonidae': {'n_is_sth': '0'},
 'family cheloniidae': {'n_is_sth': '0'},
 'family chelydridae': {'n_is_sth': '0'},
 'family chermidae': {'n_is_sth': '0'},
 'family chimaeridae': {'n_is_sth': '0'},
 'family chinchillidae': {'n_is_sth': '0'},
 'family chironomidae': {'n_is_sth': '0'},
 'family chlamydiaceae': {'n_is_sth': '0'},
 'family chlamydomonadaceae': {'n_is_sth': '0'},
 'family chlorophthalmidae': {'n_is_sth': '0'},
 'family chrysochloridae': {'n_is_sth': '0'},
 'family chrysomelidae': {'n_is_sth': '0'},
 'family chrysopidae': {'n_is_sth': '0'},
 'family cicadellidae': {'n_is_sth': '0'},
 'family cicadidae': {'n_is_sth': '0'},
 'family cichlidae': {'n_is_sth': '0'},
 'family cicindelidae': {'n_is_sth': '0'},
 'family ciconiidae': {'n_is_sth': '0'},
 'family cimicidae': {'n_is_sth': '0'},
 'family cinclidae': {'n_is_sth': '0'},
 'family cleridae': {'n_is_sth': '0'},
 'family clinidae': {'n_is_sth': '0'},
 'family clupeidae': {'n_is_sth': '0'},
 'family cobitidae': {'n_is_sth': '0'},
 'family coccidae': {'n_is_sth': '0'},
 'family coccinellidae': {'n_is_sth': '0'},
 'family coerebidae': {'n_is_sth': '0'},
 'family colubridae': {'n_is_sth': '0'},
 'family columbidae': {'n_is_sth': '0'},
 'family comatulidae': {'n_is_sth': '0'},
 'family congridae': {'n_is_sth': '0'},
 'family coraciidae': {'n_is_sth': '0'},
 'family cordylidae': {'n_is_sth': '0'},
 'family coregonidae': {'n_is_sth': '0'},
 'family coreidae': {'n_is_sth': '0'},
 'family corixidae': {'n_is_sth': '0'},
 'family corvidae': {'n_is_sth': '0'},
 'family corydalidae': {'n_is_sth': '0'},
 'family corynebacteriaceae': {'n_is_sth': '0'},
 'family coryphaenidae': {'n_is_sth': '0'},
 'family cotingidae': {'n_is_sth': '0'},
 'family cottidae': {'n_is_sth': '0'},
 'family cracidae': {'n_is_sth': '0'},
 'family cracticidae': {'n_is_sth': '0'},
 'family crangonidae': {'n_is_sth': '0'},
 'family cricetidae': {'n_is_sth': '0'},
 'family crocodylidae': {'n_is_sth': '0'},
 'family crotalidae': {'n_is_sth': '0'},
 'family cryptobranchidae': {'n_is_sth': '0'},
 'family cryptocercidae': {'n_is_sth': '0'},
 'family ctenizidae': {'n_is_sth': '0'},
 'family cuculidae': {'n_is_sth': '0'},
 'family culicidae': {'n_is_sth': '0'},
 'family curculionidae': {'n_is_sth': '0'},
 'family cuterebridae': {'n_is_sth': '0'},
 'family cyclopteridae': {'n_is_sth': '0'},
 'family cymatiidae': {'n_is_sth': '0'},
 'family cynipidae': {'n_is_sth': '0'},
 'family cynocephalidae': {'n_is_sth': '0'},
 'family cynoglossidae': {'n_is_sth': '0'},
 'family cypraeidae': {'n_is_sth': '0'},
 'family cyprinidae': {'n_is_sth': '0'},
 'family cyprinodontidae': {'n_is_sth': '0'},
 'family dacninae': {'n_is_sth': '0'},
 'family dactylopiidae': {'n_is_sth': '0'},
 'family dactylopteridae': {'n_is_sth': '0'},
 'family dactyloscopidae': {'n_is_sth': '0'},
 'family danaidae': {'n_is_sth': '0'},
 'family dasyatidae': {'n_is_sth': '0'},
 'family dasypodidae': {'n_is_sth': '0'},
 'family dasyproctidae': {'n_is_sth': '0'},
 'family dasyuridae': {'n_is_sth': '0'},
 'family dasyurinae': {'n_is_sth': '0'},
 'family daubentoniidae': {'n_is_sth': '0'},
 'family delphinidae': {'n_is_sth': '0'},
 'family dendrocolaptidae': {'n_is_sth': '0'},
 'family dermestidae': {'n_is_sth': '0'},
 'family dermochelyidae': {'n_is_sth': '0'},
 'family desmidiaceae': {'n_is_sth': '0'},
 'family desmodontidae': {'n_is_sth': '0'},
 'family diaspididae': {'n_is_sth': '0'},
 'family dicamptodontidae': {'n_is_sth': '0'},
 'family didelphidae': {'n_is_sth': '0'},
 'family dinornithidae': {'n_is_sth': '0'},
 'family diodontidae': {'n_is_sth': '0'},
 'family diomedeidae': {'n_is_sth': '0'},
 'family dipodidae': {'n_is_sth': '0'},
 'family discoglossidae': {'n_is_sth': '0'},
 'family doliolidae': {'n_is_sth': '0'},
 'family dracunculidae': {'n_is_sth': '0'},
 'family drepanididae': {'n_is_sth': '0'},
 'family dromaeosauridae': {'n_is_sth': '0'},
 'family drosophilidae': {'n_is_sth': '0'},
 'family dugongidae': {'n_is_sth': '0'},
 'family dytiscidae': {'n_is_sth': '0'},
 'family echeneidae': {'n_is_sth': '0'},
 'family echeneididae': {'n_is_sth': '0'},
 'family edaphosauridae': {'n_is_sth': '0'},
 'family eimeriidae': {'n_is_sth': '0'},
 'family elapidae': {'n_is_sth': '0'},
 'family elateridae': {'n_is_sth': '0'},
 'family electrophoridae': {'n_is_sth': '0'},
 'family eleotridae': {'n_is_sth': '0'},
 'family elephantidae': {'n_is_sth': '0'},
 'family elopidae': {'n_is_sth': '0'},
 'family embiotocidae': {'n_is_sth': '0'},
 'family emydidae': {'n_is_sth': '0'},
 'family endamoebidae': {'n_is_sth': '0'},
 'family engraulidae': {'n_is_sth': '0'},
 'family enterobacteriaceae': {'n_is_sth': '0'},
 'family ephemeridae': {'n_is_sth': '0'},
 'family ephippidae': {'n_is_sth': '0'},
 'family equidae': {'n_is_sth': '0'},
 'family erethizontidae': {'n_is_sth': '0'},
 'family erinaceidae': {'n_is_sth': '0'},
 'family eschrichtiidae': {'n_is_sth': '0'},
 'family esocidae': {'n_is_sth': '0'},
 'family euglenaceae': {'n_is_sth': '0'},
 'family eurylaimidae': {'n_is_sth': '0'},
 'family exocoetidae': {'n_is_sth': '0'},
 'family falconidae': {'n_is_sth': '0'},
 'family fasciolidae': {'n_is_sth': '0'},
 'family felidae': {'n_is_sth': '0'},
 'family filariidae': {'n_is_sth': '0'},
 'family fissurellidae': {'n_is_sth': '0'},
 'family fistulariidae': {'n_is_sth': '0'},
 'family forficulidae': {'n_is_sth': '0'},
 'family formicariidae': {'n_is_sth': '0'},
 'family formicidae': {'n_is_sth': '0'},
 'family fregatidae': {'n_is_sth': '0'},
 'family fringillidae': {'n_is_sth': '0'},
 'family fucaceae': {'n_is_sth': '0'},
 'family fulgoridae': {'n_is_sth': '0'},
 'family furnariidae': {'n_is_sth': '0'},
 'family gadidae': {'n_is_sth': '0'},
 'family galbulidae': {'n_is_sth': '0'},
 'family gasterophilidae': {'n_is_sth': '0'},
 'family gasterosteidae': {'n_is_sth': '0'},
 'family gavialidae': {'n_is_sth': '0'},
 'family gavidae': {'n_is_sth': '0'},
 'family gekkonidae': {'n_is_sth': '0'},
 'family gelechiidae': {'n_is_sth': '0'},
 'family gempylidae': {'n_is_sth': '0'},
 'family geometridae': {'n_is_sth': '0'},
 'family geomyidae': {'n_is_sth': '0'},
 'family geophilidae': {'n_is_sth': '0'},
 'family gerreidae': {'n_is_sth': '0'},
 'family gerridae': {'n_is_sth': '0'},
 'family gerrididae': {'n_is_sth': '0'},
 'family gigartinaceae': {'n_is_sth': '0'},
 'family giraffidae': {'n_is_sth': '0'},
 'family glareolidae': {'n_is_sth': '0'},
 'family gliridae': {'n_is_sth': '0'},
 'family globigerinidae': {'n_is_sth': '0'},
 'family glossinidae': {'n_is_sth': '0'},
 'family gobiesocidae': {'n_is_sth': '0'},
 'family gobiidae': {'n_is_sth': '0'},
 'family gomphotheriidae': {'n_is_sth': '0'},
 'family gonorhynchidae': {'n_is_sth': '0'},
 'family gracilariidae': {'n_is_sth': '0'},
 'family gruidae': {'n_is_sth': '0'},
 'family gryllidae': {'n_is_sth': '0'},
 'family gyrinidae': {'n_is_sth': '0'},
 'family hadrosauridae': {'n_is_sth': '0'},
 'family haematopodidae': {'n_is_sth': '0'},
 'family haemoproteidae': {'n_is_sth': '0'},
 'family haemulidae': {'n_is_sth': '0'},
 'family halictidae': {'n_is_sth': '0'},
 'family haliotidae': {'n_is_sth': '0'},
 'family helicidae': {'n_is_sth': '0'},
 'family helodermatidae': {'n_is_sth': '0'},
 'family hemerobiidae': {'n_is_sth': '0'},
 'family hemiprocnidae': {'n_is_sth': '0'},
 'family hemiramphidae': {'n_is_sth': '0'},
 'family heteromyidae': {'n_is_sth': '0'},
 'family hexagrammidae': {'n_is_sth': '0'},
 'family hexanchidae': {'n_is_sth': '0'},
 'family hippoboscidae': {'n_is_sth': '0'},
 'family hippopotamidae': {'n_is_sth': '0'},
 'family hipposideridae': {'n_is_sth': '0'},
 'family hirudinidae': {'n_is_sth': '0'},
 'family hirundinidae': {'n_is_sth': '0'},
 'family holocentridae': {'n_is_sth': '0'},
 'family holothuridae': {'n_is_sth': '0'},
 'family homaridae': {'n_is_sth': '0'},
 'family hominidae': {'n_is_sth': '0'},
 'family hyaenidae': {'n_is_sth': '0'},
 'family hydrobatidae': {'n_is_sth': '0'},
 'family hydrochoeridae': {'n_is_sth': '0'},
 'family hydrophidae': {'n_is_sth': '0'},
 'family hylidae': {'n_is_sth': '0'},
 'family hylobatidae': {'n_is_sth': '0'},
 'family hyperodontidae': {'n_is_sth': '0'},
 'family hypodermatidae': {'n_is_sth': '0'},
 'family hystricidae': {'n_is_sth': '0'},
 'family ibidiidae': {'n_is_sth': '0'},
 'family ichneumonidae': {'n_is_sth': '0'},
 'family ichthyosauridae': {'n_is_sth': '0'},
 'family icteridae': {'n_is_sth': '0'},
 'family iguania': {'n_is_sth': '0'},
 'family iguanidae': {'n_is_sth': '0'},
 'family iguanodontidae': {'n_is_sth': '0'},
 'family indicatoridae': {'n_is_sth': '0'},
 'family indriidae': {'n_is_sth': '0'},
 'family ipidae': {'n_is_sth': '0'},
 'family irenidae': {'n_is_sth': '0'},
 'family istiophoridae': {'n_is_sth': '0'},
 'family isuridae': {'n_is_sth': '0'},
 'family ixodidae': {'n_is_sth': '0'},
 'family jassidae': {'n_is_sth': '0'},
 'family kalotermitidae': {'n_is_sth': '0'},
 'family kasuwonidae': {'n_is_sth': '0'},
 'family kinosternidae': {'n_is_sth': '0'},
 'family kyphosidae': {'n_is_sth': '0'},
 'family labridae': {'n_is_sth': '0'},
 'family lacertidae': {'n_is_sth': '0'},
 'family lactobacillaceae': {'n_is_sth': '0'},
 'family lactobacteriaceae': {'n_is_sth': '0'},
 'family laminariaceae': {'n_is_sth': '0'},
 'family lamnidae': {'n_is_sth': '0'},
 'family lampridae': {'n_is_sth': '0'},
 'family lampyridae': {'n_is_sth': '0'},
 'family laniidae': {'n_is_sth': '0'},
 'family lanthanotidae': {'n_is_sth': '0'},
 'family laricariidae': {'n_is_sth': '0'},
 'family laridae': {'n_is_sth': '0'},
 'family lasiocampidae': {'n_is_sth': '0'},
 'family latimeridae': {'n_is_sth': '0'},
 'family leiopelmatidae': {'n_is_sth': '0'},
 'family lemuridae': {'n_is_sth': '0'},
 'family lepadidae': {'n_is_sth': '0'},
 'family lepismatidae': {'n_is_sth': '0'},
 'family lepisosteidae': {'n_is_sth': '0'},
 'family leporidae': {'n_is_sth': '0'},
 'family leptodactylidae': {'n_is_sth': '0'},
 'family leptotyphlopidae': {'n_is_sth': '0'},
 'family limacidae': {'n_is_sth': '0'},
 'family limulidae': {'n_is_sth': '0'},
 'family liopelmidae': {'n_is_sth': '0'},
 'family liparidae': {'n_is_sth': '0'},
 'family liparididae': {'n_is_sth': '0'},
 'family lithodidae': {'n_is_sth': '0'},
 'family littorinidae': {'n_is_sth': '0'},
 'family lobotidae': {'n_is_sth': '0'},
 'family locustidae': {'n_is_sth': '0'},
 'family lophiidae': {'n_is_sth': '0'},
 'family lorisidae': {'n_is_sth': '0'},
 'family lucanidae': {'n_is_sth': '0'},
 'family lutjanidae': {'n_is_sth': '0'},
 'family luvaridae': {'n_is_sth': '0'},
 'family lycaenidae': {'n_is_sth': '0'},
 'family lycosidae': {'n_is_sth': '0'},
 'family lygaeidae': {'n_is_sth': '0'},
 'family lymantriidae': {'n_is_sth': '0'},
 'family machilidae': {'n_is_sth': '0'},
 'family macropodidae': {'n_is_sth': '0'},
 'family macrorhamphosidae': {'n_is_sth': '0'},
 'family macrouridae': {'n_is_sth': '0'},
 'family macruridae': {'n_is_sth': '0'},
 'family majidae': {'n_is_sth': '0'},
 'family malacanthidae': {'n_is_sth': '0'},
 'family mammutidae': {'n_is_sth': '0'},
 'family manidae': {'n_is_sth': '0'},
 'family manteidae': {'n_is_sth': '0'},
 'family mantidae': {'n_is_sth': '0'},
 'family mantispidae': {'n_is_sth': '0'},
 'family mastodontidae': {'n_is_sth': '0'},
 'family mastotermitidae': {'n_is_sth': '0'},
 'family megachilidae': {'n_is_sth': '0'},
 'family megadermatidae': {'n_is_sth': '0'},
 'family megalonychidae': {'n_is_sth': '0'},
 'family megalosauridae': {'n_is_sth': '0'},
 'family megapodiidae': {'n_is_sth': '0'},
 'family megatheriidae': {'n_is_sth': '0'},
 'family meleagrididae': {'n_is_sth': '0'},
 'family meliphagidae': {'n_is_sth': '0'},
 'family meloidae': {'n_is_sth': '0'},
 'family membracidae': {'n_is_sth': '0'},
 'family menuridae': {'n_is_sth': '0'},
 'family meropidae': {'n_is_sth': '0'},
 'family micrococcaceae': {'n_is_sth': '0'},
 'family microdesmidae': {'n_is_sth': '0'},
 'family microhylidae': {'n_is_sth': '0'},
 'family mimidae': {'n_is_sth': '0'},
 'family miridae': {'n_is_sth': '0'},
 'family mobulidae': {'n_is_sth': '0'},
 'family molidae': {'n_is_sth': '0'},
 'family molossidae': {'n_is_sth': '0'},
 'family momotidae': {'n_is_sth': '0'},
 'family monocanthidae': {'n_is_sth': '0'},
 'family monodontidae': {'n_is_sth': '0'},
 'family motacillidae': {'n_is_sth': '0'},
 'family mugilidae': {'n_is_sth': '0'},
 'family mullidae': {'n_is_sth': '0'},
 'family muraenidae': {'n_is_sth': '0'},
 'family muridae': {'n_is_sth': '0'},
 'family muscicapidae': {'n_is_sth': '0'},
 'family muscidae': {'n_is_sth': '0'},
 'family musophagidae': {'n_is_sth': '0'},
 'family mustelidae': {'n_is_sth': '0'},
 'family mutillidae': {'n_is_sth': '0'},
 'family myacidae': {'n_is_sth': '0'},
 'family mycetophylidae': {'n_is_sth': '0'},
 'family mycobacteriaceae': {'n_is_sth': '0'},
 'family mycoplasmataceae': {'n_is_sth': '0'},
 'family myctophidae': {'n_is_sth': '0'},
 'family myliobatidae': {'n_is_sth': '0'},
 'family mylodontidae': {'n_is_sth': '0'},
 'family myrmecophagidae': {'n_is_sth': '0'},
 'family myrmeleontidae': {'n_is_sth': '0'},
 'family mysidae': {'n_is_sth': '0'},
 'family mytilidae': {'n_is_sth': '0'},
 'family myxinidae': {'n_is_sth': '0'},
 'family myxobacteriaceae': {'n_is_sth': '0'},
 'family myxophyceae': {'n_is_sth': '0'},
 'family naticidae': {'n_is_sth': '0'},
 'family nautilidae': {'n_is_sth': '0'},
 'family nephropsidae': {'n_is_sth': '0'},
 'family nepidae': {'n_is_sth': '0'},
 'family neritidae': {'n_is_sth': '0'},
 'family nitrobacteriaceae': {'n_is_sth': '0'},
 'family noctuidae': {'n_is_sth': '0'},
 'family nostocaceae': {'n_is_sth': '0'},
 'family notonectidae': {'n_is_sth': '0'},
 'family notoryctidae': {'n_is_sth': '0'},
 'family nummulitidae': {'n_is_sth': '0'},
 'family nymphalidae': {'n_is_sth': '0'},
 'family ochotonidae': {'n_is_sth': '0'},
 'family octopodidae': {'n_is_sth': '0'},
 'family odobenidae': {'n_is_sth': '0'},
 'family odontaspididae': {'n_is_sth': '0'},
 'family oedogoniaceae': {'n_is_sth': '0'},
 'family oestridae': {'n_is_sth': '0'},
 'family ogcocephalidae': {'n_is_sth': '0'},
 'family oniscidae': {'n_is_sth': '0'},
 'family ophidiidae': {'n_is_sth': '0'},
 'family ophiodontidae': {'n_is_sth': '0'},
 'family opisthocomidae': {'n_is_sth': '0'},
 'family opisthognathidae': {'n_is_sth': '0'},
 'family orchestiidae': {'n_is_sth': '0'},
 'family orectolobidae': {'n_is_sth': '0'},
 'family oriolidae': {'n_is_sth': '0'},
 'family ornithorhynchidae': {'n_is_sth': '0'},
 'family orycteropodidae': {'n_is_sth': '0'},
 'family oscillatoriaceae': {'n_is_sth': '0'},
 'family osmeridae': {'n_is_sth': '0'},
 'family ostraciidae': {'n_is_sth': '0'},
 'family ostraciontidae': {'n_is_sth': '0'},
 'family ostreidae': {'n_is_sth': '0'},
 'family otariidae': {'n_is_sth': '0'},
 'family otididae': {'n_is_sth': '0'},
 'family oxyuridae': {'n_is_sth': '0'},
 'family paguridae': {'n_is_sth': '0'},
 'family palaemonidae': {'n_is_sth': '0'},
 'family palinuridae': {'n_is_sth': '0'},
 'family pandionidae': {'n_is_sth': '0'},
 'family panorpidae': {'n_is_sth': '0'},
 'family paradisaeidae': {'n_is_sth': '0'},
 'family paridae': {'n_is_sth': '0'},
 'family parulidae': {'n_is_sth': '0'},
 'family passeridae': {'n_is_sth': '0'},
 'family patellidae': {'n_is_sth': '0'},
 'family pectinidae': {'n_is_sth': '0'},
 'family pediculidae': {'n_is_sth': '0'},
 'family pelecanidae': {'n_is_sth': '0'},
 'family pelecanoididae': {'n_is_sth': '0'},
 'family pelobatidae': {'n_is_sth': '0'},
 'family pempheridae': {'n_is_sth': '0'},
 'family peneidae': {'n_is_sth': '0'},
 'family pennatulidae': {'n_is_sth': '0'},
 'family peramelidae': {'n_is_sth': '0'},
 'family percidae': {'n_is_sth': '0'},
 'family percophidae': {'n_is_sth': '0'},
 'family peridiniidae': {'n_is_sth': '0'},
 'family peripatidae': {'n_is_sth': '0'},
 'family peripatopsidae': {'n_is_sth': '0'},
 'family petromyzontidae': {'n_is_sth': '0'},
 'family phaethontidae': {'n_is_sth': '0'},
 'family phalacrocoracidae': {'n_is_sth': '0'},
 'family phalangeridae': {'n_is_sth': '0'},
 'family phalangiidae': {'n_is_sth': '0'},
 'family phalaropidae': {'n_is_sth': '0'},
 'family phasianidae': {'n_is_sth': '0'},
 'family phasmatidae': {'n_is_sth': '0'},
 'family phasmidae': {'n_is_sth': '0'},
 'family phillidae': {'n_is_sth': '0'},
 'family phocidae': {'n_is_sth': '0'},
 'family phoenicopteridae': {'n_is_sth': '0'},
 'family phoeniculidae': {'n_is_sth': '0'},
 'family pholadidae': {'n_is_sth': '0'},
 'family pholidae': {'n_is_sth': '0'},
 'family pholididae': {'n_is_sth': '0'},
 'family phthiriidae': {'n_is_sth': '0'},
 'family phyllidae': {'n_is_sth': '0'},
 'family phyllostomatidae': {'n_is_sth': '0'},
 'family phyllostomidae': {'n_is_sth': '0'},
 'family phylloxeridae': {'n_is_sth': '0'},
 'family physeteridae': {'n_is_sth': '0'},
 'family physidae': {'n_is_sth': '0'},
 'family picidae': {'n_is_sth': '0'},
 'family pieridae': {'n_is_sth': '0'},
 'family pinnotheridae': {'n_is_sth': '0'},
 'family pipidae': {'n_is_sth': '0'},
 'family pipridae': {'n_is_sth': '0'},
 'family pittidae': {'n_is_sth': '0'},
 'family plasmodiidae': {'n_is_sth': '0'},
 'family plataleidae': {'n_is_sth': '0'},
 'family platanistidae': {'n_is_sth': '0'},
 'family platycephalidae': {'n_is_sth': '0'},
 'family plethodontidae': {'n_is_sth': '0'},
 'family pleurobrachiidae': {'n_is_sth': '0'},
 'family pleuronectidae': {'n_is_sth': '0'},
 'family ploceidae': {'n_is_sth': '0'},
 'family podargidae': {'n_is_sth': '0'},
 'family podicipedidae': {'n_is_sth': '0'},
 'family poeciliidae': {'n_is_sth': '0'},
 'family polyangiaceae': {'n_is_sth': '0'},
 'family polynemidae': {'n_is_sth': '0'},
 'family polyodontidae': {'n_is_sth': '0'},
 'family polypedatidae': {'n_is_sth': '0'},
 'family pomacentridae': {'n_is_sth': '0'},
 'family pomatomidae': {'n_is_sth': '0'},
 'family pongidae': {'n_is_sth': '0'},
 'family porcellionidae': {'n_is_sth': '0'},
 'family portunidae': {'n_is_sth': '0'},
 'family potamogalidae': {'n_is_sth': '0'},
 'family priacanthidae': {'n_is_sth': '0'},
 'family pristidae': {'n_is_sth': '0'},
 'family procaviidae': {'n_is_sth': '0'},
 'family procellariidae': {'n_is_sth': '0'},
 'family procyonidae': {'n_is_sth': '0'},
 'family proteidae': {'n_is_sth': '0'},
 'family prunellidae': {'n_is_sth': '0'},
 'family pseudococcidae': {'n_is_sth': '0'},
 'family pseudomonodaceae': {'n_is_sth': '0'},
 'family psittacidae': {'n_is_sth': '0'},
 'family psocidae': {'n_is_sth': '0'},
 'family psophiidae': {'n_is_sth': '0'},
 'family psychodidae': {'n_is_sth': '0'},
 'family psyllidae': {'n_is_sth': '0'},
 'family pteriidae': {'n_is_sth': '0'},
 'family pteroclididae': {'n_is_sth': '0'},
 'family pterodactylidae': {'n_is_sth': '0'},
 'family ptilonorhynchidae': {'n_is_sth': '0'},
 'family pulicidae': {'n_is_sth': '0'},
 'family pygopodidae': {'n_is_sth': '0'},
 'family pyralidae': {'n_is_sth': '0'},
 'family pyralididae': {'n_is_sth': '0'},
 'family pyrrhocoridae': {'n_is_sth': '0'},
 'family pythonidae': {'n_is_sth': '0'},
 'family rachycentridae': {'n_is_sth': '0'},
 'family rallidae': {'n_is_sth': '0'},
 'family ramphastidae': {'n_is_sth': '0'},
 'family ranidae': {'n_is_sth': '0'},
 'family raphidae': {'n_is_sth': '0'},
 'family raphidiidae': {'n_is_sth': '0'},
 'family recurvirostridae': {'n_is_sth': '0'},
 'family reduviidae': {'n_is_sth': '0'},
 'family regalecidae': {'n_is_sth': '0'},
 'family rheidae': {'n_is_sth': '0'},
 'family rhincodontidae': {'n_is_sth': '0'},
 'family rhinobatidae': {'n_is_sth': '0'},
 'family rhinocerotidae': {'n_is_sth': '0'},
 'family rhinolophidae': {'n_is_sth': '0'},
 'family rhinotermitidae': {'n_is_sth': '0'},
 'family rhiptoglossa': {'n_is_sth': '0'},
 'family rhizobiaceae': {'n_is_sth': '0'},
 'family rhodymeniaceae': {'n_is_sth': '0'},
 'family rickettsiaceae': {'n_is_sth': '0'},
 'family rynchopidae': {'n_is_sth': '0'},
 'family sagittariidae': {'n_is_sth': '0'},
 'family salamandridae': {'n_is_sth': '0'},
 'family salmonidae': {'n_is_sth': '0'},
 'family salpidae': {'n_is_sth': '0'},
 'family sarcoptidae': {'n_is_sth': '0'},
 'family saturniidae': {'n_is_sth': '0'},
 'family satyridae': {'n_is_sth': '0'},
 'family scarabaeidae': {'n_is_sth': '0'},
 'family scaridae': {'n_is_sth': '0'},
 'family schistosomatidae': {'n_is_sth': '0'},
 'family schizophyceae': {'n_is_sth': '0'},
 'family sciaenidae': {'n_is_sth': '0'},
 'family sciaridae': {'n_is_sth': '0'},
 'family scincidae': {'n_is_sth': '0'},
 'family sciuridae': {'n_is_sth': '0'},
 'family scolopacidae': {'n_is_sth': '0'},
 'family scolytidae': {'n_is_sth': '0'},
 'family scomberesocidae': {'n_is_sth': '0'},
 'family scombresocidae': {'n_is_sth': '0'},
 'family scombridae': {'n_is_sth': '0'},
 'family scorpaenidae': {'n_is_sth': '0'},
 'family scutigeridae': {'n_is_sth': '0'},
 'family scyliorhinidae': {'n_is_sth': '0'},
 'family sepiidae': {'n_is_sth': '0'},
 'family serranidae': {'n_is_sth': '0'},
 'family sialidae': {'n_is_sth': '0'},
 'family sillaginidae': {'n_is_sth': '0'},
 'family siluridae': {'n_is_sth': '0'},
 'family simuliidae': {'n_is_sth': '0'},
 'family sirenidae': {'n_is_sth': '0'},
 'family sisyridae': {'n_is_sth': '0'},
 'family sittidae': {'n_is_sth': '0'},
 'family soleidae': {'n_is_sth': '0'},
 'family solenidae': {'n_is_sth': '0'},
 'family soricidae': {'n_is_sth': '0'},
 'family spalacidae': {'n_is_sth': '0'},
 'family sparidae': {'n_is_sth': '0'},
 'family sphecidae': {'n_is_sth': '0'},
 'family spheniscidae': {'n_is_sth': '0'},
 'family sphingidae': {'n_is_sth': '0'},
 'family sphyraenidae': {'n_is_sth': '0'},
 'family sphyrnidae': {'n_is_sth': '0'},
 'family spirillaceae': {'n_is_sth': '0'},
 'family spirochaetaceae': {'n_is_sth': '0'},
 'family spirulidae': {'n_is_sth': '0'},
 'family squalidae': {'n_is_sth': '0'},
 'family squatinidae': {'n_is_sth': '0'},
 'family squillidae': {'n_is_sth': '0'},
 'family staphylinidae': {'n_is_sth': '0'},
 'family steatornithidae': {'n_is_sth': '0'},
 'family stenopelmatidae': {'n_is_sth': '0'},
 'family stercorariidae': {'n_is_sth': '0'},
 'family stichaeidae': {'n_is_sth': '0'},
 'family stizidae': {'n_is_sth': '0'},
 'family streptomycetaceae': {'n_is_sth': '0'},
 'family strigidae': {'n_is_sth': '0'},
 'family stromateidae': {'n_is_sth': '0'},
 'family strombidae': {'n_is_sth': '0'},
 'family struthionidae': {'n_is_sth': '0'},
 'family sturnidae': {'n_is_sth': '0'},
 'family suidae': {'n_is_sth': '0'},
 'family sulidae': {'n_is_sth': '0'},
 'family sylviidae': {'n_is_sth': '0'},
 'family syngnathidae': {'n_is_sth': '0'},
 'family synodontidae': {'n_is_sth': '0'},
 'family tabanidae': {'n_is_sth': '0'},
 'family tachinidae': {'n_is_sth': '0'},
 'family tachyglossidae': {'n_is_sth': '0'},
 'family taeniidae': {'n_is_sth': '0'},
 'family talpidae': {'n_is_sth': '0'},
 'family tapiridae': {'n_is_sth': '0'},
 'family tarsiidae': {'n_is_sth': '0'},
 'family tayassuidae': {'n_is_sth': '0'},
 'family teiidae': {'n_is_sth': '0'},
 'family tenebrionidae': {'n_is_sth': '0'},
 'family tenrecidae': {'n_is_sth': '0'},
 'family tenthredinidae': {'n_is_sth': '0'},
 'family terebellidae': {'n_is_sth': '0'},
 'family teredinidae': {'n_is_sth': '0'},
 'family termitidae': {'n_is_sth': '0'},
 'family testudinidae': {'n_is_sth': '0'},
 'family tethyidae': {'n_is_sth': '0'},
 'family tetranychidae': {'n_is_sth': '0'},
 'family tetraodontidae': {'n_is_sth': '0'},
 'family tetraonidae': {'n_is_sth': '0'},
 'family tettigoniidae': {'n_is_sth': '0'},
 'family theraphosidae': {'n_is_sth': '0'},
 'family theridiidae': {'n_is_sth': '0'},
 'family thiobacteriaceae': {'n_is_sth': '0'},
 'family thraupidae': {'n_is_sth': '0'},
 'family threskiornithidae': {'n_is_sth': '0'},
 'family thripidae': {'n_is_sth': '0'},
 'family timaliidae': {'n_is_sth': '0'},
 'family tinamidae': {'n_is_sth': '0'},
 'family tineidae': {'n_is_sth': '0'},
 'family tingidae': {'n_is_sth': '0'},
 'family tipulidae': {'n_is_sth': '0'},
 'family titanosauridae': {'n_is_sth': '0'},
 'family todidae': {'n_is_sth': '0'},
 'family torpedinidae': {'n_is_sth': '0'},
 'family tortricidae': {'n_is_sth': '0'},
 'family toxotidae': {'n_is_sth': '0'},
 'family trachipteridae': {'n_is_sth': '0'},
 'family tragulidae': {'n_is_sth': '0'},
 'family trephritidae': {'n_is_sth': '0'},
 'family treponemataceae': {'n_is_sth': '0'},
 'family triakidae': {'n_is_sth': '0'},
 'family tribonemaceae': {'n_is_sth': '0'},
 'family trichechidae': {'n_is_sth': '0'},
 'family trichiuridae': {'n_is_sth': '0'},
 'family trichodontidae': {'n_is_sth': '0'},
 'family tridacnidae': {'n_is_sth': '0'},
 'family triglidae': {'n_is_sth': '0'},
 'family trionychidae': {'n_is_sth': '0'},
 'family triopidae': {'n_is_sth': '0'},
 'family trochilidae': {'n_is_sth': '0'},
 'family troglodytidae': {'n_is_sth': '0'},
 'family trogonidae': {'n_is_sth': '0'},
 'family trombiculidae': {'n_is_sth': '0'},
 'family trombidiidae': {'n_is_sth': '0'},
 'family trypetidae': {'n_is_sth': '0'},
 'family tupaiidae': {'n_is_sth': '0'},
 'family turdidae': {'n_is_sth': '0'},
 'family turnicidae': {'n_is_sth': '0'},
 'family tylenchidae': {'n_is_sth': '0'},
 'family typhlopidae': {'n_is_sth': '0'},
 'family tytonidae': {'n_is_sth': '0'},
 'family uintatheriidae': {'n_is_sth': '0'},
 'family ulvaceae': {'n_is_sth': '0'},
 'family unionidae': {'n_is_sth': '0'},
 'family upupidae': {'n_is_sth': '0'},
 'family uranoscopidae': {'n_is_sth': '0'},
 'family ursidae': {'n_is_sth': '0'},
 'family varanidae': {'n_is_sth': '0'},
 'family veneridae': {'n_is_sth': '0'},
 'family vespertilionidae': {'n_is_sth': '0'},
 'family vespidae': {'n_is_sth': '0'},
 'family viperidae': {'n_is_sth': '0'},
 'family vireonidae': {'n_is_sth': '0'},
 'family viverridae': {'n_is_sth': '0'},
 'family viverrinae': {'n_is_sth': '0'},
 'family volvocaceae': {'n_is_sth': '0'},
 'family vombatidae': {'n_is_sth': '0'},
 'family xantusiidae': {'n_is_sth': '0'},
 'family xenicidae': {'n_is_sth': '0'},
 'family xenopodidae': {'n_is_sth': '0'},
 'family xenosauridae': {'n_is_sth': '0'},
 'family xiphiidae': {'n_is_sth': '0'},
 'family zapodidae': {'n_is_sth': '0'},
 'family zeidae': {'n_is_sth': '0'},
 'family ziphiidae': {'n_is_sth': '0'},
 'family zoarcidae': {'n_is_sth': '0'},
 'family zygnemataceae': {'n_is_sth': '0'},
 'fasciolidae': {'n_is_sth': '0'},
 'fatherhood': {'n_is_sth': '0'},
 'fertilized egg': {'n_is_sth': '0'},
 'fetlock joint': {'n_is_sth': '0'},
 'fetlock': {'n_is_sth': '0'},
 'fetter bone': {'n_is_sth': '0'},
 'filariidae': {'n_is_sth': '0'},
 'filoviridae': {'n_is_sth': '0'},
 'first stomach': {'n_is_sth': '0'},
 'fish scale': {'n_is_sth': '0'},
 'fistularia': {'n_is_sth': '0'},
 'fistulariidae': {'n_is_sth': '0'},
 'flagellata': {'n_is_sth': '0'},
 'flagellated cell': {'n_is_sth': '0'},
 'flagellum': {'n_is_sth': '0'},
 'flame cell': {'n_is_sth': '0'},
 'flaviviridae': {'n_is_sth': '0'},
 'flight feather': {'n_is_sth': '0'},
 'forelimb': {'n_is_sth': '0'},
 'forelock': {'n_is_sth': '0'},
 'forepaw': {'n_is_sth': '0'},
 'foretop': {'n_is_sth': '0'},
 'forewing': {'n_is_sth': '0'},
 'forficula': {'n_is_sth': '0'},
 'forficulidae': {'n_is_sth': '0'},
 'form genus': {'n_is_sth': '0'},
 'formicariidae': {'n_is_sth': '0'},
 'formicarius': {'n_is_sth': '0'},
 'fossorial foot': {'n_is_sth': '0'},
 'fourth stomach': {'n_is_sth': '0'},
 'francisella': {'n_is_sth': '0'},
 'frankliniella': {'n_is_sth': '0'},
 'fregata': {'n_is_sth': '0'},
 'fregatidae': {'n_is_sth': '0'},
 'fringilla': {'n_is_sth': '0'},
 'fringillidae': {'n_is_sth': '0'},
 'fucaceae': {'n_is_sth': '0'},
 'fucales': {'n_is_sth': '0'},
 'fulgoridae': {'n_is_sth': '0'},
 'fulica': {'n_is_sth': '0'},
 'fulmarus': {'n_is_sth': '0'},
 'fundulus': {'n_is_sth': '0'},
 'furnariidae': {'n_is_sth': '0'},
 'furnarius': {'n_is_sth': '0'},
 'gadidae': {'n_is_sth': '0'},
 'gadiformes': {'n_is_sth': '0'},
 'galbulidae': {'n_is_sth': '0'},
 'galeocerdo': {'n_is_sth': '0'},
 'galeorhinus': {'n_is_sth': '0'},
 'galleria': {'n_is_sth': '0'},
 'galliformes': {'n_is_sth': '0'},
 'gallinago': {'n_is_sth': '0'},
 'gallinula': {'n_is_sth': '0'},
 'gallirallus': {'n_is_sth': '0'},
 'ganoidei': {'n_is_sth': '0'},
 'ganoine': {'n_is_sth': '0'},
 'ganoin': {'n_is_sth': '0'},
 'garrulinae': {'n_is_sth': '0'},
 'garrulus': {'n_is_sth': '0'},
 'gaskin': {'n_is_sth': '0'},
 'gasterophilidae': {'n_is_sth': '0'},
 'gasterophilus': {'n_is_sth': '0'},
 'gasteropoda': {'n_is_sth': '0'},
 'gasterosteidae': {'n_is_sth': '0'},
 'gasterosteus': {'n_is_sth': '0'},
 'gastric mill': {'n_is_sth': '0'},
 'gastrophryne': {'n_is_sth': '0'},
 'gastropoda': {'n_is_sth': '0'},
 'gastrula': {'n_is_sth': '0'},
 'gavialidae': {'n_is_sth': '0'},
 'gavialis': {'n_is_sth': '0'},
 'gavia': {'n_is_sth': '0'},
 'gavidae': {'n_is_sth': '0'},
 'gaviiformes': {'n_is_sth': '0'},
 'gekkonidae': {'n_is_sth': '0'},
 'gelechia': {'n_is_sth': '0'},
 'gelechiidae': {'n_is_sth': '0'},
 'gempylidae': {'n_is_sth': '0'},
 'gempylus': {'n_is_sth': '0'},
 'genus abramis': {'n_is_sth': '0'},
 'genus abrocoma': {'n_is_sth': '0'},
 'genus abudefduf': {'n_is_sth': '0'},
 'genus acanthisitta': {'n_is_sth': '0'},
 'genus acanthocybium': {'n_is_sth': '0'},
 'genus acanthophis': {'n_is_sth': '0'},
 'genus acanthoscelides': {'n_is_sth': '0'},
 'genus acanthurus': {'n_is_sth': '0'},
 'genus accipiter': {'n_is_sth': '0'},
 'genus acherontia': {'n_is_sth': '0'},
 'genus acheta': {'n_is_sth': '0'},
 'genus achoerodus': {'n_is_sth': '0'},
 'genus acinonyx': {'n_is_sth': '0'},
 'genus acipenser': {'n_is_sth': '0'},
 'genus acridotheres': {'n_is_sth': '0'},
 'genus acris': {'n_is_sth': '0'},
 'genus acrobates': {'n_is_sth': '0'},
 'genus acrocephalus': {'n_is_sth': '0'},
 'genus acropora': {'n_is_sth': '0'},
 'genus actias': {'n_is_sth': '0'},
 'genus actinia': {'n_is_sth': '0'},
 'genus actinomyces': {'n_is_sth': '0'},
 'genus actitis': {'n_is_sth': '0'},
 'genus adalia': {'n_is_sth': '0'},
 'genus addax': {'n_is_sth': '0'},
 'genus adelges': {'n_is_sth': '0'},
 'genus adenota': {'n_is_sth': '0'},
 'genus aedes': {'n_is_sth': '0'},
 'genus aegypius': {'n_is_sth': '0'},
 'genus aegyptopithecus': {'n_is_sth': '0'},
 'genus aepyceros': {'n_is_sth': '0'},
 'genus aepyornis': {'n_is_sth': '0'},
 'genus aerobacter': {'n_is_sth': '0'},
 'genus aetobatus': {'n_is_sth': '0'},
 'genus afropavo': {'n_is_sth': '0'},
 'genus agama': {'n_is_sth': '0'},
 'genus agapornis': {'n_is_sth': '0'},
 'genus agelaius': {'n_is_sth': '0'},
 'genus agkistrodon': {'n_is_sth': '0'},
 'genus agonus': {'n_is_sth': '0'},
 'genus agriocharis': {'n_is_sth': '0'},
 'genus agrobacterium': {'n_is_sth': '0'},
 'genus ailuropoda': {'n_is_sth': '0'},
 'genus ailurus': {'n_is_sth': '0'},
 'genus aix': {'n_is_sth': '0'},
 'genus ajaia': {'n_is_sth': '0'},
 'genus alauda': {'n_is_sth': '0'},
 'genus albula': {'n_is_sth': '0'},
 'genus alca': {'n_is_sth': '0'},
 'genus alcedo': {'n_is_sth': '0'},
 'genus alcelaphus': {'n_is_sth': '0'},
 'genus alces': {'n_is_sth': '0'},
 'genus alectis': {'n_is_sth': '0'},
 'genus alectoris': {'n_is_sth': '0'},
 'genus alectura': {'n_is_sth': '0'},
 'genus alepisaurus': {'n_is_sth': '0'},
 'genus aleyrodes': {'n_is_sth': '0'},
 'genus algeripithecus': {'n_is_sth': '0'},
 'genus alligator': {'n_is_sth': '0'},
 'genus allosaurus': {'n_is_sth': '0'},
 'genus alopex': {'n_is_sth': '0'},
 'genus alopius': {'n_is_sth': '0'},
 'genus alosa': {'n_is_sth': '0'},
 'genus alouatta': {'n_is_sth': '0'},
 'genus alsophila': {'n_is_sth': '0'},
 'genus alytes': {'n_is_sth': '0'},
 'genus amazona': {'n_is_sth': '0'},
 'genus ambloplites': {'n_is_sth': '0'},
 'genus amblyrhynchus': {'n_is_sth': '0'},
 'genus ambystoma': {'n_is_sth': '0'},
 'genus ameiurus': {'n_is_sth': '0'},
 'genus amia': {'n_is_sth': '0'},
 'genus ammodytes': {'n_is_sth': '0'},
 'genus ammotragus': {'n_is_sth': '0'},
 'genus amphibolips': {'n_is_sth': '0'},
 'genus amphioxus': {'n_is_sth': '0'},
 'genus amphiprion': {'n_is_sth': '0'},
 'genus amphisbaena': {'n_is_sth': '0'},
 'genus amphiuma': {'n_is_sth': '0'},
 'genus anabas': {'n_is_sth': '0'},
 'genus anabrus': {'n_is_sth': '0'},
 'genus anagasta': {'n_is_sth': '0'},
 'genus anarhichas': {'n_is_sth': '0'},
 'genus anas': {'n_is_sth': '0'},
 'genus anatotitan': {'n_is_sth': '0'},
 'genus ancistrodon': {'n_is_sth': '0'},
 'genus ancylus': {'n_is_sth': '0'},
 'genus andrena': {'n_is_sth': '0'},
 'genus andricus': {'n_is_sth': '0'},
 'genus aneides': {'n_is_sth': '0'},
 'genus anguilla': {'n_is_sth': '0'},
 'genus anguis': {'n_is_sth': '0'},
 'genus anhima': {'n_is_sth': '0'},
 'genus anhinga': {'n_is_sth': '0'},
 'genus anisotremus': {'n_is_sth': '0'},
 'genus ankylosaurus': {'n_is_sth': '0'},
 'genus anoa': {'n_is_sth': '0'},
 'genus anodonta': {'n_is_sth': '0'},
 'genus anolis': {'n_is_sth': '0'},
 'genus anomala': {'n_is_sth': '0'},
 'genus anomalops': {'n_is_sth': '0'},
 'genus anomalopteryx': {'n_is_sth': '0'},
 'genus anomia': {'n_is_sth': '0'},
 'genus anopheles': {'n_is_sth': '0'},
 'genus anser': {'n_is_sth': '0'},
 'genus antedon': {'n_is_sth': '0'},
 'genus antheraea': {'n_is_sth': '0'},
 'genus anthidium': {'n_is_sth': '0'},
 'genus anthonomus': {'n_is_sth': '0'},
 'genus anthus': {'n_is_sth': '0'},
 'genus antidorcas': {'n_is_sth': '0'},
 'genus antigonia': {'n_is_sth': '0'},
 'genus antilocapra': {'n_is_sth': '0'},
 'genus antilope': {'n_is_sth': '0'},
 'genus antrodemus': {'n_is_sth': '0'},
 'genus antrozous': {'n_is_sth': '0'},
 'genus apatosaurus': {'n_is_sth': '0'},
 'genus apatura': {'n_is_sth': '0'},
 'genus aphis': {'n_is_sth': '0'},
 'genus aphriza': {'n_is_sth': '0'},
 'genus aphrophora': {'n_is_sth': '0'},
 'genus apis': {'n_is_sth': '0'},
 'genus aplodontia': {'n_is_sth': '0'},
 'genus aplysia': {'n_is_sth': '0'},
 'genus apodemus': {'n_is_sth': '0'},
 'genus apogon': {'n_is_sth': '0'},
 'genus appendicularia': {'n_is_sth': '0'},
 'genus aptenodytes': {'n_is_sth': '0'},
 'genus apteryx': {'n_is_sth': '0'},
 'genus apus': {'n_is_sth': '0'},
 'genus aquila': {'n_is_sth': '0'},
 'genus araneus': {'n_is_sth': '0'},
 'genus arca': {'n_is_sth': '0'},
 'genus arcella': {'n_is_sth': '0'},
 'genus archaeopteryx': {'n_is_sth': '0'},
 'genus archeopteryx': {'n_is_sth': '0'},
 'genus archidiskidon': {'n_is_sth': '0'},
 'genus archilochus': {'n_is_sth': '0'},
 'genus architeuthis': {'n_is_sth': '0'},
 'genus archosargus': {'n_is_sth': '0'},
 'genus arctictis': {'n_is_sth': '0'},
 'genus arctocebus': {'n_is_sth': '0'},
 'genus arctocephalus': {'n_is_sth': '0'},
 'genus arctonyx': {'n_is_sth': '0'},
 'genus ardea': {'n_is_sth': '0'},
 'genus arenaria': {'n_is_sth': '0'},
 'genus argentina': {'n_is_sth': '0'},
 'genus argiope': {'n_is_sth': '0'},
 'genus argonauta': {'n_is_sth': '0'},
 'genus argusianus': {'n_is_sth': '0'},
 'genus argynnis': {'n_is_sth': '0'},
 'genus argyrotaenia': {'n_is_sth': '0'},
 'genus arilus': {'n_is_sth': '0'},
 'genus ariomma': {'n_is_sth': '0'},
 'genus arius': {'n_is_sth': '0'},
 'genus armadillidium': {'n_is_sth': '0'},
 'genus artamus': {'n_is_sth': '0'},
 'genus artemia': {'n_is_sth': '0'},
 'genus arvicola': {'n_is_sth': '0'},
 'genus ascaphus': {'n_is_sth': '0'},
 'genus ascaridia': {'n_is_sth': '0'},
 'genus ascaris': {'n_is_sth': '0'},
 'genus ascophyllum': {'n_is_sth': '0'},
 'genus aspidelaps': {'n_is_sth': '0'},
 'genus aspidiotus': {'n_is_sth': '0'},
 'genus astacus': {'n_is_sth': '0'},
 'genus astrophyton': {'n_is_sth': '0'},
 'genus astropogon': {'n_is_sth': '0'},
 'genus ateles': {'n_is_sth': '0'},
 'genus athene': {'n_is_sth': '0'},
 'genus atherinopsis': {'n_is_sth': '0'},
 'genus atherurus': {'n_is_sth': '0'},
 'genus atrichornis': {'n_is_sth': '0'},
 'genus aulacorhyncus': {'n_is_sth': '0'},
 'genus aulostomus': {'n_is_sth': '0'},
 'genus australopithecus': {'n_is_sth': '0'},
 'genus automeris': {'n_is_sth': '0'},
 'genus avahi': {'n_is_sth': '0'},
 'genus aythya': {'n_is_sth': '0'},
 'genus babesia': {'n_is_sth': '0'},
 'genus bacillus': {'n_is_sth': '0'},
 'genus bacteroides': {'n_is_sth': '0'},
 'genus baiomys': {'n_is_sth': '0'},
 'genus bairdiella': {'n_is_sth': '0'},
 'genus balaena': {'n_is_sth': '0'},
 'genus balaeniceps': {'n_is_sth': '0'},
 'genus balaenoptera': {'n_is_sth': '0'},
 'genus balanus': {'n_is_sth': '0'},
 'genus balistes': {'n_is_sth': '0'},
 'genus barosaurus': {'n_is_sth': '0'},
 'genus bartramia': {'n_is_sth': '0'},
 'genus basiliscus': {'n_is_sth': '0'},
 'genus bassariscus': {'n_is_sth': '0'},
 'genus bathyergus': {'n_is_sth': '0'},
 'genus batrachoseps': {'n_is_sth': '0'},
 'genus bemisia': {'n_is_sth': '0'},
 'genus beroe': {'n_is_sth': '0'},
 'genus bibos': {'n_is_sth': '0'},
 'genus bison': {'n_is_sth': '0'},
 'genus bitis': {'n_is_sth': '0'},
 'genus blarina': {'n_is_sth': '0'},
 'genus blatta': {'n_is_sth': '0'},
 'genus blattella': {'n_is_sth': '0'},
 'genus blennius': {'n_is_sth': '0'},
 'genus blissus': {'n_is_sth': '0'},
 'genus bombina': {'n_is_sth': '0'},
 'genus bombus': {'n_is_sth': '0'},
 'genus bombycilla': {'n_is_sth': '0'},
 'genus bombyx': {'n_is_sth': '0'},
 'genus bonasa': {'n_is_sth': '0'},
 'genus borrelia': {'n_is_sth': '0'},
 'genus boselaphus': {'n_is_sth': '0'},
 'genus bos': {'n_is_sth': '0'},
 'genus botaurus': {'n_is_sth': '0'},
 'genus bothrops': {'n_is_sth': '0'},
 'genus brachinus': {'n_is_sth': '0'},
 'genus bradypus': {'n_is_sth': '0'},
 'genus brama': {'n_is_sth': '0'},
 'genus branchiobdella': {'n_is_sth': '0'},
 'genus brevoortia': {'n_is_sth': '0'},
 'genus brontosaurus': {'n_is_sth': '0'},
 'genus bruchus': {'n_is_sth': '0'},
 'genus bubalus': {'n_is_sth': '0'},
 'genus bubo': {'n_is_sth': '0'},
 'genus bubulcus': {'n_is_sth': '0'},
 'genus bucephala': {'n_is_sth': '0'},
 'genus buceros': {'n_is_sth': '0'},
 'genus budorcas': {'n_is_sth': '0'},
 'genus bufo': {'n_is_sth': '0'},
 'genus bungarus': {'n_is_sth': '0'},
 'genus burmeisteria': {'n_is_sth': '0'},
 'genus buteo': {'n_is_sth': '0'},
 'genus cabassous': {'n_is_sth': '0'},
 'genus cacajao': {'n_is_sth': '0'},
 'genus cacatua': {'n_is_sth': '0'},
 'genus cacicus': {'n_is_sth': '0'},
 'genus cadra': {'n_is_sth': '0'},
 'genus caiman': {'n_is_sth': '0'},
 'genus cairina': {'n_is_sth': '0'},
 'genus calidris': {'n_is_sth': '0'},
 'genus callicebus': {'n_is_sth': '0'},
 'genus callinectes': {'n_is_sth': '0'},
 'genus calliophis': {'n_is_sth': '0'},
 'genus calliphora': {'n_is_sth': '0'},
 'genus callisaurus': {'n_is_sth': '0'},
 'genus callithrix': {'n_is_sth': '0'},
 'genus callophis': {'n_is_sth': '0'},
 'genus callorhinus': {'n_is_sth': '0'},
 'genus calosoma': {'n_is_sth': '0'},
 'genus calymmatobacterium': {'n_is_sth': '0'},
 'genus cambarus': {'n_is_sth': '0'},
 'genus camelus': {'n_is_sth': '0'},
 'genus campephilus': {'n_is_sth': '0'},
 'genus camponotus': {'n_is_sth': '0'},
 'genus campylorhynchus': {'n_is_sth': '0'},
 'genus cancer': {'n_is_sth': '0'},
 'genus canis': {'n_is_sth': '0'},
 'genus capella': {'n_is_sth': '0'},
 'genus capra': {'n_is_sth': '0'},
 'genus caprella': {'n_is_sth': '0'},
 'genus caprimulgus': {'n_is_sth': '0'},
 'genus capros': {'n_is_sth': '0'},
 'genus caranx': {'n_is_sth': '0'},
 'genus carassius': {'n_is_sth': '0'},
 'genus carcharhinus': {'n_is_sth': '0'},
 'genus carcharias': {'n_is_sth': '0'},
 'genus carcharodon': {'n_is_sth': '0'},
 'genus cardium': {'n_is_sth': '0'},
 'genus carduelis': {'n_is_sth': '0'},
 'genus cariama': {'n_is_sth': '0'},
 'genus casmerodius': {'n_is_sth': '0'},
 'genus castoroides': {'n_is_sth': '0'},
 'genus casuarius': {'n_is_sth': '0'},
 'genus catacala': {'n_is_sth': '0'},
 'genus catharacta': {'n_is_sth': '0'},
 'genus catoptrophorus': {'n_is_sth': '0'},
 'genus catostomus': {'n_is_sth': '0'},
 'genus cavia': {'n_is_sth': '0'},
 'genus cebuella': {'n_is_sth': '0'},
 'genus cebus': {'n_is_sth': '0'},
 'genus centropomus': {'n_is_sth': '0'},
 'genus centropus': {'n_is_sth': '0'},
 'genus cepphus': {'n_is_sth': '0'},
 'genus cerapteryx': {'n_is_sth': '0'},
 'genus cerastes': {'n_is_sth': '0'},
 'genus ceratitis': {'n_is_sth': '0'},
 'genus ceratodus': {'n_is_sth': '0'},
 'genus ceratopogon': {'n_is_sth': '0'},
 'genus ceratosaurus': {'n_is_sth': '0'},
 'genus ceratotherium': {'n_is_sth': '0'},
 'genus cercocebus': {'n_is_sth': '0'},
 'genus certhia': {'n_is_sth': '0'},
 'genus cervus': {'n_is_sth': '0'},
 'genus ceryle': {'n_is_sth': '0'},
 'genus cetonia': {'n_is_sth': '0'},
 'genus cetorhinus': {'n_is_sth': '0'},
 'genus chaenopsis': {'n_is_sth': '0'},
 'genus chaetodon': {'n_is_sth': '0'},
 'genus chalcostigma': {'n_is_sth': '0'},
 'genus chamaea': {'n_is_sth': '0'},
 'genus chamaeleon': {'n_is_sth': '0'},
 'genus chamaeleo': {'n_is_sth': '0'},
 'genus charadrius': {'n_is_sth': '0'},
 'genus charina': {'n_is_sth': '0'},
 'genus charronia': {'n_is_sth': '0'},
 'genus chateura': {'n_is_sth': '0'},
 'genus chelifer': {'n_is_sth': '0'},
 'genus chelonia': {'n_is_sth': '0'},
 'genus chelydra': {'n_is_sth': '0'},
 'genus chilomastix': {'n_is_sth': '0'},
 'genus chilomeniscus': {'n_is_sth': '0'},
 'genus chilomycterus': {'n_is_sth': '0'},
 'genus chimaera': {'n_is_sth': '0'},
 'genus chinchilla': {'n_is_sth': '0'},
 'genus chironomus': {'n_is_sth': '0'},
 'genus chiton': {'n_is_sth': '0'},
 'genus chlamydera': {'n_is_sth': '0'},
 'genus chlamydia': {'n_is_sth': '0'},
 'genus chlamydomonas': {'n_is_sth': '0'},
 'genus chlamydosaurus': {'n_is_sth': '0'},
 'genus chlamyphorus': {'n_is_sth': '0'},
 'genus chlorella': {'n_is_sth': '0'},
 'genus chlorococcum': {'n_is_sth': '0'},
 'genus chlorophis': {'n_is_sth': '0'},
 'genus chlorophoneus': {'n_is_sth': '0'},
 'genus choeronycteris': {'n_is_sth': '0'},
 'genus choloepus': {'n_is_sth': '0'},
 'genus chondrus': {'n_is_sth': '0'},
 'genus chronoperates': {'n_is_sth': '0'},
 'genus chrysaora': {'n_is_sth': '0'},
 'genus chrysemys': {'n_is_sth': '0'},
 'genus chrysochloris': {'n_is_sth': '0'},
 'genus chrysolophus': {'n_is_sth': '0'},
 'genus chrysophrys': {'n_is_sth': '0'},
 'genus chunga': {'n_is_sth': '0'},
 'genus cicada': {'n_is_sth': '0'},
 'genus ciconia': {'n_is_sth': '0'},
 'genus cimex': {'n_is_sth': '0'},
 'genus cinclus': {'n_is_sth': '0'},
 'genus circaetus': {'n_is_sth': '0'},
 'genus circus': {'n_is_sth': '0'},
 'genus cistothorus': {'n_is_sth': '0'},
 'genus citellus': {'n_is_sth': '0'},
 'genus citharichthys': {'n_is_sth': '0'},
 'genus cladorhyncus': {'n_is_sth': '0'},
 'genus clangula': {'n_is_sth': '0'},
 'genus clostridium': {'n_is_sth': '0'},
 'genus clupea': {'n_is_sth': '0'},
 'genus cnemidophorus': {'n_is_sth': '0'},
 'genus coccothraustes': {'n_is_sth': '0'},
 'genus coccus': {'n_is_sth': '0'},
 'genus coccyzus': {'n_is_sth': '0'},
 'genus cochlearius': {'n_is_sth': '0'},
 'genus coelophysis': {'n_is_sth': '0'},
 'genus colaptes': {'n_is_sth': '0'},
 'genus coleonyx': {'n_is_sth': '0'},
 'genus colobus': {'n_is_sth': '0'},
 'genus coluber': {'n_is_sth': '0'},
 'genus columba': {'n_is_sth': '0'},
 'genus comatula': {'n_is_sth': '0'},
 'genus compsognathus': {'n_is_sth': '0'},
 'genus condylura': {'n_is_sth': '0'},
 'genus conepatus': {'n_is_sth': '0'},
 'genus conferva': {'n_is_sth': '0'},
 'genus conilurus': {'n_is_sth': '0'},
 'genus connochaetes': {'n_is_sth': '0'},
 'genus contopus': {'n_is_sth': '0'},
 'genus conuropsis': {'n_is_sth': '0'},
 'genus coracias': {'n_is_sth': '0'},
 'genus coragyps': {'n_is_sth': '0'},
 'genus cordylus': {'n_is_sth': '0'},
 'genus coregonus': {'n_is_sth': '0'},
 'genus corixa': {'n_is_sth': '0'},
 'genus corvus': {'n_is_sth': '0'},
 'genus corydalis': {'n_is_sth': '0'},
 'genus corydalus': {'n_is_sth': '0'},
 'genus corynebacterium': {'n_is_sth': '0'},
 'genus corythosaurus': {'n_is_sth': '0'},
 'genus coscoroba': {'n_is_sth': '0'},
 'genus cosmocampus': {'n_is_sth': '0'},
 'genus costia': {'n_is_sth': '0'},
 'genus cotinga': {'n_is_sth': '0'},
 'genus cottus': {'n_is_sth': '0'},
 'genus coturnix': {'n_is_sth': '0'},
 'genus cracticus': {'n_is_sth': '0'},
 'genus crangon': {'n_is_sth': '0'},
 'genus crassostrea': {'n_is_sth': '0'},
 'genus crax': {'n_is_sth': '0'},
 'genus crex': {'n_is_sth': '0'},
 'genus cricetus': {'n_is_sth': '0'},
 'genus crocethia': {'n_is_sth': '0'},
 'genus crocodilus': {'n_is_sth': '0'},
 'genus crocodylus': {'n_is_sth': '0'},
 'genus crocuta': {'n_is_sth': '0'},
 'genus crotalus': {'n_is_sth': '0'},
 'genus crotaphytus': {'n_is_sth': '0'},
 'genus crotophaga': {'n_is_sth': '0'},
 'genus cryptacanthodes': {'n_is_sth': '0'},
 'genus cryptobranchus': {'n_is_sth': '0'},
 'genus cryptoprocta': {'n_is_sth': '0'},
 'genus cryptotermes': {'n_is_sth': '0'},
 'genus cryptotis': {'n_is_sth': '0'},
 'genus ctenocephalides': {'n_is_sth': '0'},
 'genus ctenocephalus': {'n_is_sth': '0'},
 'genus cuculus': {'n_is_sth': '0'},
 'genus culex': {'n_is_sth': '0'},
 'genus cuniculus': {'n_is_sth': '0'},
 'genus cursorius': {'n_is_sth': '0'},
 'genus cuterebra': {'n_is_sth': '0'},
 'genus cyamus': {'n_is_sth': '0'},
 'genus cyanocitta': {'n_is_sth': '0'},
 'genus cyclopes': {'n_is_sth': '0'},
 'genus cyclops': {'n_is_sth': '0'},
 'genus cyclopterus': {'n_is_sth': '0'},
 'genus cygnus': {'n_is_sth': '0'},
 'genus cynips': {'n_is_sth': '0'},
 'genus cynocephalus': {'n_is_sth': '0'},
 'genus cynomys': {'n_is_sth': '0'},
 'genus cynopterus': {'n_is_sth': '0'},
 'genus cynoscion': {'n_is_sth': '0'},
 'genus cyon': {'n_is_sth': '0'},
 'genus cypraea': {'n_is_sth': '0'},
 'genus cyprinus': {'n_is_sth': '0'},
 'genus cystophora': {'n_is_sth': '0'},
 'genus dacelo': {'n_is_sth': '0'},
 'genus dactylopius': {'n_is_sth': '0'},
 'genus dactylopterus': {'n_is_sth': '0'},
 'genus damaliscus': {'n_is_sth': '0'},
 'genus danaus': {'n_is_sth': '0'},
 'genus daphnia': {'n_is_sth': '0'},
 'genus dasyatis': {'n_is_sth': '0'},
 'genus dasyprocta': {'n_is_sth': '0'},
 'genus dasypus': {'n_is_sth': '0'},
 'genus dasyurus': {'n_is_sth': '0'},
 'genus daubentonia': {'n_is_sth': '0'},
 'genus decapterus': {'n_is_sth': '0'},
 'genus deinocheirus': {'n_is_sth': '0'},
 'genus delichon': {'n_is_sth': '0'},
 'genus delphinapterus': {'n_is_sth': '0'},
 'genus delphinus': {'n_is_sth': '0'},
 'genus dendraspis': {'n_is_sth': '0'},
 'genus dendroaspis': {'n_is_sth': '0'},
 'genus dendrocolaptes': {'n_is_sth': '0'},
 'genus dendroctonus': {'n_is_sth': '0'},
 'genus dendroica': {'n_is_sth': '0'},
 'genus dendrolagus': {'n_is_sth': '0'},
 'genus denisonia': {'n_is_sth': '0'},
 'genus dermacentor': {'n_is_sth': '0'},
 'genus dermatobia': {'n_is_sth': '0'},
 'genus dermochelys': {'n_is_sth': '0'},
 'genus desmidium': {'n_is_sth': '0'},
 'genus desmodus': {'n_is_sth': '0'},
 'genus desmograthus': {'n_is_sth': '0'},
 'genus diadophis': {'n_is_sth': '0'},
 'genus dialeurodes': {'n_is_sth': '0'},
 'genus diapheromera': {'n_is_sth': '0'},
 'genus dicamptodon': {'n_is_sth': '0'},
 'genus diceros': {'n_is_sth': '0'},
 'genus dicrostonyx': {'n_is_sth': '0'},
 'genus didelphis': {'n_is_sth': '0'},
 'genus difflugia': {'n_is_sth': '0'},
 'genus dimetrodon': {'n_is_sth': '0'},
 'genus dinornis': {'n_is_sth': '0'},
 'genus diodon': {'n_is_sth': '0'},
 'genus diomedea': {'n_is_sth': '0'},
 'genus diphylla': {'n_is_sth': '0'},
 'genus diplococcus': {'n_is_sth': '0'},
 'genus diplodocus': {'n_is_sth': '0'},
 'genus dipodomys': {'n_is_sth': '0'},
 'genus dipsosaurus': {'n_is_sth': '0'},
 'genus dipus': {'n_is_sth': '0'},
 'genus dolichonyx': {'n_is_sth': '0'},
 'genus dolichotis': {'n_is_sth': '0'},
 'genus doliolum': {'n_is_sth': '0'},
 'genus dracunculus': {'n_is_sth': '0'},
 'genus dreissena': {'n_is_sth': '0'},
 'genus drepanis': {'n_is_sth': '0'},
 'genus dromaius': {'n_is_sth': '0'},
 'genus drosophila': {'n_is_sth': '0'},
 'genus drymarchon': {'n_is_sth': '0'},
 'genus dryopithecus': {'n_is_sth': '0'},
 'genus dugong': {'n_is_sth': '0'},
 'genus dumetella': {'n_is_sth': '0'},
 'genus dusicyon': {'n_is_sth': '0'},
 'genus dysdercus': {'n_is_sth': '0'},
 'genus echeneis': {'n_is_sth': '0'},
 'genus echidnophaga': {'n_is_sth': '0'},
 'genus echinococcus': {'n_is_sth': '0'},
 'genus ectopistes': {'n_is_sth': '0'},
 'genus edaphosaurus': {'n_is_sth': '0'},
 'genus edmontosaurus': {'n_is_sth': '0'},
 'genus egretta': {'n_is_sth': '0'},
 'genus eimeria': {'n_is_sth': '0'},
 'genus eira': {'n_is_sth': '0'},
 'genus elagatis': {'n_is_sth': '0'},
 'genus elanoides': {'n_is_sth': '0'},
 'genus elanus': {'n_is_sth': '0'},
 'genus elaphe': {'n_is_sth': '0'},
 'genus elaphurus': {'n_is_sth': '0'},
 'genus electrophorus': {'n_is_sth': '0'},
 'genus elephas': {'n_is_sth': '0'},
 'genus eleutherodactylus': {'n_is_sth': '0'},
 'genus eliomys': {'n_is_sth': '0'},
 'genus elops': {'n_is_sth': '0'},
 'genus emberiza': {'n_is_sth': '0'},
 'genus endamoeba': {'n_is_sth': '0'},
 'genus engraulis': {'n_is_sth': '0'},
 'genus enhydra': {'n_is_sth': '0'},
 'genus ensis': {'n_is_sth': '0'},
 'genus enterobius': {'n_is_sth': '0'},
 'genus ephestia': {'n_is_sth': '0'},
 'genus ephippiorhynchus': {'n_is_sth': '0'},
 'genus epilachna': {'n_is_sth': '0'},
 'genus epinephelus': {'n_is_sth': '0'},
 'genus eptatretus': {'n_is_sth': '0'},
 'genus eptesicus': {'n_is_sth': '0'},
 'genus equetus': {'n_is_sth': '0'},
 'genus equus': {'n_is_sth': '0'},
 'genus erethizon': {'n_is_sth': '0'},
 'genus eretmochelys': {'n_is_sth': '0'},
 'genus erignathus': {'n_is_sth': '0'},
 'genus erinaceus': {'n_is_sth': '0'},
 'genus eriosoma': {'n_is_sth': '0'},
 'genus erithacus': {'n_is_sth': '0'},
 'genus erolia': {'n_is_sth': '0'},
 'genus erwinia': {'n_is_sth': '0'},
 'genus erythrocebus': {'n_is_sth': '0'},
 'genus escherichia': {'n_is_sth': '0'},
 'genus eschrichtius': {'n_is_sth': '0'},
 'genus esox': {'n_is_sth': '0'},
 'genus estrilda': {'n_is_sth': '0'},
 'genus etropus': {'n_is_sth': '0'},
 'genus euarctos': {'n_is_sth': '0'},
 'genus eucinostomus': {'n_is_sth': '0'},
 'genus euderma': {'n_is_sth': '0'},
 'genus eudyptes': {'n_is_sth': '0'},
 'genus euglena': {'n_is_sth': '0'},
 'genus eumeces': {'n_is_sth': '0'},
 'genus eumenes': {'n_is_sth': '0'},
 'genus eumetopias': {'n_is_sth': '0'},
 'genus eumops': {'n_is_sth': '0'},
 'genus eunectes': {'n_is_sth': '0'},
 'genus euphagus': {'n_is_sth': '0'},
 'genus euphractus': {'n_is_sth': '0'},
 'genus euplectella': {'n_is_sth': '0'},
 'genus euproctis': {'n_is_sth': '0'},
 'genus euryale': {'n_is_sth': '0'},
 'genus eutamias': {'n_is_sth': '0'},
 'genus euthynnus': {'n_is_sth': '0'},
 'genus falco': {'n_is_sth': '0'},
 'genus fasciola': {'n_is_sth': '0'},
 'genus fasciolopsis': {'n_is_sth': '0'},
 'genus felis': {'n_is_sth': '0'},
 'genus fissurella': {'n_is_sth': '0'},
 'genus fistularia': {'n_is_sth': '0'},
 'genus forficula': {'n_is_sth': '0'},
 'genus formicarius': {'n_is_sth': '0'},
 'genus formica': {'n_is_sth': '0'},
 'genus fossa': {'n_is_sth': '0'},
 'genus francisella': {'n_is_sth': '0'},
 'genus frankliniella': {'n_is_sth': '0'},
 'genus fratercula': {'n_is_sth': '0'},
 'genus fregata': {'n_is_sth': '0'},
 'genus fringilla': {'n_is_sth': '0'},
 'genus fucus': {'n_is_sth': '0'},
 'genus fulica': {'n_is_sth': '0'},
 'genus fulmarus': {'n_is_sth': '0'},
 'genus fundulus': {'n_is_sth': '0'},
 'genus fungia': {'n_is_sth': '0'},
 'genus furnarius': {'n_is_sth': '0'},
 'genus gadus': {'n_is_sth': '0'},
 'genus galago': {'n_is_sth': '0'},
 'genus galeocerdo': {'n_is_sth': '0'},
 'genus galeorhinus': {'n_is_sth': '0'},
 'genus galictis': {'n_is_sth': '0'},
 'genus galleria': {'n_is_sth': '0'},
 'genus gallinago': {'n_is_sth': '0'},
 'genus gallinula': {'n_is_sth': '0'},
 'genus gallirallus': {'n_is_sth': '0'},
 'genus gallus': {'n_is_sth': '0'},
 'genus gambusia': {'n_is_sth': '0'},
 'genus garrulus': {'n_is_sth': '0'},
 'genus gasterophilus': {'n_is_sth': '0'},
 'genus gasterosteus': {'n_is_sth': '0'},
 'genus gastrophryne': {'n_is_sth': '0'},
 'genus gavialis': {'n_is_sth': '0'},
 'genus gavia': {'n_is_sth': '0'},
 'genus gazella': {'n_is_sth': '0'},
 'genus gempylus': {'n_is_sth': '0'},
 'genus genetta': {'n_is_sth': '0'},
 'genus genyonemus': {'n_is_sth': '0'},
 'genus geochelone': {'n_is_sth': '0'},
 'genus geococcyx': {'n_is_sth': '0'},
 'genus geomys': {'n_is_sth': '0'},
 'genus geophilus': {'n_is_sth': '0'},
 'genus geothlypis': {'n_is_sth': '0'},
 'genus gerbillus': {'n_is_sth': '0'},
 'genus gerres': {'n_is_sth': '0'},
 'genus gerris': {'n_is_sth': '0'},
 'genus giardia': {'n_is_sth': '0'},
 'genus ginglymostoma': {'n_is_sth': '0'},
 'genus giraffa': {'n_is_sth': '0'},
 'genus glareola': {'n_is_sth': '0'},
 'genus glaucomys': {'n_is_sth': '0'},
 'genus glis': {'n_is_sth': '0'},
 'genus globicephala': {'n_is_sth': '0'},
 'genus globigerina': {'n_is_sth': '0'},
 'genus glossina': {'n_is_sth': '0'},
 'genus glossopsitta': {'n_is_sth': '0'},
 'genus gobiesox': {'n_is_sth': '0'},
 'genus gobio': {'n_is_sth': '0'},
 'genus gomphotherium': {'n_is_sth': '0'},
 'genus gonorhynchus': {'n_is_sth': '0'},
 'genus gopherus': {'n_is_sth': '0'},
 'genus gorgonocephalus': {'n_is_sth': '0'},
 'genus gorilla': {'n_is_sth': '0'},
 'genus gracula': {'n_is_sth': '0'},
 'genus grampus': {'n_is_sth': '0'},
 'genus grison': {'n_is_sth': '0'},
 'genus grus': {'n_is_sth': '0'},
 'genus gulo': {'n_is_sth': '0'},
 'genus gymnelis': {'n_is_sth': '0'},
 'genus gymnogyps': {'n_is_sth': '0'},
 'genus gymnorhina': {'n_is_sth': '0'},
 'genus gymnura': {'n_is_sth': '0'},
 'genus gypaetus': {'n_is_sth': '0'},
 'genus gyps': {'n_is_sth': '0'},
 'genus haematobia': {'n_is_sth': '0'},
 'genus haematopus': {'n_is_sth': '0'},
 'genus haemopis': {'n_is_sth': '0'},
 'genus haemoproteus': {'n_is_sth': '0'},
 'genus haemulon': {'n_is_sth': '0'},
 'genus halcyon': {'n_is_sth': '0'},
 'genus haliaeetus': {'n_is_sth': '0'},
 'genus halicoeres': {'n_is_sth': '0'},
 'genus haliotis': {'n_is_sth': '0'},
 'genus haminoea': {'n_is_sth': '0'},
 'genus harpia': {'n_is_sth': '0'},
 'genus heleodytes': {'n_is_sth': '0'},
 'genus heliobacter': {'n_is_sth': '0'},
 'genus heliothis': {'n_is_sth': '0'},
 'genus helix': {'n_is_sth': '0'},
 'genus heloderma': {'n_is_sth': '0'},
 'genus hemachatus': {'n_is_sth': '0'},
 'genus hemigalus': {'n_is_sth': '0'},
 'genus hemigrammus': {'n_is_sth': '0'},
 'genus hemitripterus': {'n_is_sth': '0'},
 'genus hermissenda': {'n_is_sth': '0'},
 'genus herpestes': {'n_is_sth': '0'},
 'genus herrerasaurus': {'n_is_sth': '0'},
 'genus heterocephalus': {'n_is_sth': '0'},
 'genus heterodon': {'n_is_sth': '0'},
 'genus heteroscelus': {'n_is_sth': '0'},
 'genus hexagrammos': {'n_is_sth': '0'},
 'genus hexamita': {'n_is_sth': '0'},
 'genus hexanchus': {'n_is_sth': '0'},
 'genus himantopus': {'n_is_sth': '0'},
 'genus hippobosca': {'n_is_sth': '0'},
 'genus hippocampus': {'n_is_sth': '0'},
 'genus hippodamia': {'n_is_sth': '0'},
 'genus hippoglossoides': {'n_is_sth': '0'},
 'genus hippoglossus': {'n_is_sth': '0'},
 'genus hippopotamus': {'n_is_sth': '0'},
 'genus hipposideros': {'n_is_sth': '0'},
 'genus hippotragus': {'n_is_sth': '0'},
 'genus hipsurus': {'n_is_sth': '0'},
 'genus hirudo': {'n_is_sth': '0'},
 'genus hirundo': {'n_is_sth': '0'},
 'genus holbrookia': {'n_is_sth': '0'},
 'genus holocentrus': {'n_is_sth': '0'},
 'genus holothuria': {'n_is_sth': '0'},
 'genus homarus': {'n_is_sth': '0'},
 'genus homona': {'n_is_sth': '0'},
 'genus homo': {'n_is_sth': '0'},
 'genus hyaena': {'n_is_sth': '0'},
 'genus hyalophora': {'n_is_sth': '0'},
 'genus hydra': {'n_is_sth': '0'},
 'genus hydrobates': {'n_is_sth': '0'},
 'genus hydrochoerus': {'n_is_sth': '0'},
 'genus hydrodamalis': {'n_is_sth': '0'},
 'genus hydromantes': {'n_is_sth': '0'},
 'genus hydromys': {'n_is_sth': '0'},
 'genus hyemoschus': {'n_is_sth': '0'},
 'genus hylactophryne': {'n_is_sth': '0'},
 'genus hyla': {'n_is_sth': '0'},
 'genus hylobates': {'n_is_sth': '0'},
 'genus hylocichla': {'n_is_sth': '0'},
 'genus hylophylax': {'n_is_sth': '0'},
 'genus hynerpeton': {'n_is_sth': '0'},
 'genus hypentelium': {'n_is_sth': '0'},
 'genus hyperoglyphe': {'n_is_sth': '0'},
 'genus hyperoodon': {'n_is_sth': '0'},
 'genus hyphantria': {'n_is_sth': '0'},
 'genus hypoderma': {'n_is_sth': '0'},
 'genus hypopachus': {'n_is_sth': '0'},
 'genus hypsiglena': {'n_is_sth': '0'},
 'genus hypsiprymnodon': {'n_is_sth': '0'},
 'genus hyracotherium': {'n_is_sth': '0'},
 'genus ibero-mesornis': {'n_is_sth': '0'},
 'genus ibis': {'n_is_sth': '0'},
 'genus ichthyosaurus': {'n_is_sth': '0'},
 'genus ichthyostega': {'n_is_sth': '0'},
 'genus ictalurus': {'n_is_sth': '0'},
 'genus icteria': {'n_is_sth': '0'},
 'genus icterus': {'n_is_sth': '0'},
 'genus ictiobus': {'n_is_sth': '0'},
 'genus ictonyx': {'n_is_sth': '0'},
 'genus iguana': {'n_is_sth': '0'},
 'genus inachis': {'n_is_sth': '0'},
 'genus indri': {'n_is_sth': '0'},
 'genus irena': {'n_is_sth': '0'},
 'genus iridoprocne': {'n_is_sth': '0'},
 'genus ischigualastia': {'n_is_sth': '0'},
 'genus istiophorus': {'n_is_sth': '0'},
 'genus isurus': {'n_is_sth': '0'},
 'genus ixobrychus': {'n_is_sth': '0'},
 'genus ixodes': {'n_is_sth': '0'},
 'genus jabiru': {'n_is_sth': '0'},
 'genus jaculus': {'n_is_sth': '0'},
 'genus javanthropus': {'n_is_sth': '0'},
 'genus jordanella': {'n_is_sth': '0'},
 'genus junco': {'n_is_sth': '0'},
 'genus jynx': {'n_is_sth': '0'},
 'genus kakatoe': {'n_is_sth': '0'},
 'genus kalotermes': {'n_is_sth': '0'},
 'genus katsuwonus': {'n_is_sth': '0'},
 'genus kenyapithecus': {'n_is_sth': '0'},
 'genus kinosternon': {'n_is_sth': '0'},
 'genus klebsiella': {'n_is_sth': '0'},
 'genus kobus': {'n_is_sth': '0'},
 'genus kogia': {'n_is_sth': '0'},
 'genus krypterophaneron': {'n_is_sth': '0'},
 'genus kyphosus': {'n_is_sth': '0'},
 'genus lacerta': {'n_is_sth': '0'},
 'genus lachnolaimus': {'n_is_sth': '0'},
 'genus lactobacillus': {'n_is_sth': '0'},
 'genus lactophrys': {'n_is_sth': '0'},
 'genus lagidium': {'n_is_sth': '0'},
 'genus lagodon': {'n_is_sth': '0'},
 'genus lagopus': {'n_is_sth': '0'},
 'genus lagorchestes': {'n_is_sth': '0'},
 'genus lagostomus': {'n_is_sth': '0'},
 'genus lagothrix': {'n_is_sth': '0'},
 'genus lama': {'n_is_sth': '0'},
 'genus lambis': {'n_is_sth': '0'},
 'genus laminaria': {'n_is_sth': '0'},
 'genus lamna': {'n_is_sth': '0'},
 'genus lampris': {'n_is_sth': '0'},
 'genus lampropeltis': {'n_is_sth': '0'},
 'genus lanius': {'n_is_sth': '0'},
 'genus lanthanotus': {'n_is_sth': '0'},
 'genus larus': {'n_is_sth': '0'},
 'genus lasiocampa': {'n_is_sth': '0'},
 'genus latimeria': {'n_is_sth': '0'},
 'genus latrodectus': {'n_is_sth': '0'},
 'genus leiopelma': {'n_is_sth': '0'},
 'genus leipoa': {'n_is_sth': '0'},
 'genus leishmania': {'n_is_sth': '0'},
 'genus lemmus': {'n_is_sth': '0'},
 'genus lemur': {'n_is_sth': '0'},
 'genus leontideus': {'n_is_sth': '0'},
 'genus leontocebus': {'n_is_sth': '0'},
 'genus lepas': {'n_is_sth': '0'},
 'genus lepidochelys': {'n_is_sth': '0'},
 'genus lepidocybium': {'n_is_sth': '0'},
 'genus lepisma': {'n_is_sth': '0'},
 'genus lepisosteus': {'n_is_sth': '0'},
 'genus lepomis': {'n_is_sth': '0'},
 'genus leptinotarsa': {'n_is_sth': '0'},
 'genus leptodactylus': {'n_is_sth': '0'},
 'genus leptoglossus': {'n_is_sth': '0'},
 'genus leptoptilus': {'n_is_sth': '0'},
 'genus leptospira': {'n_is_sth': '0'},
 'genus leptotyphlops': {'n_is_sth': '0'},
 'genus lepus': {'n_is_sth': '0'},
 'genus leuciscus': {'n_is_sth': '0'},
 'genus leucocytozoan': {'n_is_sth': '0'},
 'genus leucocytozoon': {'n_is_sth': '0'},
 'genus lichanura': {'n_is_sth': '0'},
 'genus limanda': {'n_is_sth': '0'},
 'genus limax': {'n_is_sth': '0'},
 'genus limenitis': {'n_is_sth': '0'},
 'genus limnocryptes': {'n_is_sth': '0'},
 'genus limnodromus': {'n_is_sth': '0'},
 'genus limosa': {'n_is_sth': '0'},
 'genus limulus': {'n_is_sth': '0'},
 'genus liomys': {'n_is_sth': '0'},
 'genus liopelma': {'n_is_sth': '0'},
 'genus liparis': {'n_is_sth': '0'},
 'genus liposcelis': {'n_is_sth': '0'},
 'genus listeria': {'n_is_sth': '0'},
 'genus litocranius': {'n_is_sth': '0'},
 'genus littorina': {'n_is_sth': '0'},
 'genus lobipes': {'n_is_sth': '0'},
 'genus lobotes': {'n_is_sth': '0'},
 'genus locusta': {'n_is_sth': '0'},
 'genus loligo': {'n_is_sth': '0'},
 'genus lophius': {'n_is_sth': '0'},
 'genus lopholatilus': {'n_is_sth': '0'},
 'genus loris': {'n_is_sth': '0'},
 'genus lota': {'n_is_sth': '0'},
 'genus loxia': {'n_is_sth': '0'},
 'genus loxodonta': {'n_is_sth': '0'},
 'genus loxostege': {'n_is_sth': '0'},
 'genus lucilia': {'n_is_sth': '0'},
 'genus lufengpithecus': {'n_is_sth': '0'},
 'genus lumpenus': {'n_is_sth': '0'},
 'genus lunda': {'n_is_sth': '0'},
 'genus luscinia': {'n_is_sth': '0'},
 'genus lutjanus': {'n_is_sth': '0'},
 'genus lutra': {'n_is_sth': '0'},
 'genus luvarus': {'n_is_sth': '0'},
 'genus lycaena': {'n_is_sth': '0'},
 'genus lycaeon': {'n_is_sth': '0'},
 'genus lycosa': {'n_is_sth': '0'},
 'genus lygus': {'n_is_sth': '0'},
 'genus lymantria': {'n_is_sth': '0'},
 'genus lynx': {'n_is_sth': '0'},
 'genus lyrurus': {'n_is_sth': '0'},
 'genus macaca': {'n_is_sth': '0'},
 'genus macrocephalon': {'n_is_sth': '0'},
 'genus macrocheira': {'n_is_sth': '0'},
 'genus macroclemys': {'n_is_sth': '0'},
 'genus macronectes': {'n_is_sth': '0'},
 'genus macropus': {'n_is_sth': '0'},
 'genus macrotis': {'n_is_sth': '0'},
 'genus macrotus': {'n_is_sth': '0'},
 'genus macrozoarces': {'n_is_sth': '0'},
 'genus madoqua': {'n_is_sth': '0'},
 'genus maeandra': {'n_is_sth': '0'},
 'genus magicicada': {'n_is_sth': '0'},
 'genus maia': {'n_is_sth': '0'},
 'genus maja': {'n_is_sth': '0'},
 'genus makaira': {'n_is_sth': '0'},
 'genus malaclemys': {'n_is_sth': '0'},
 'genus malacosoma': {'n_is_sth': '0'},
 'genus mallotus': {'n_is_sth': '0'},
 'genus malopterurus': {'n_is_sth': '0'},
 'genus mammuthus': {'n_is_sth': '0'},
 'genus mammut': {'n_is_sth': '0'},
 'genus mandrillus': {'n_is_sth': '0'},
 'genus manduca': {'n_is_sth': '0'},
 'genus manis': {'n_is_sth': '0'},
 'genus manta': {'n_is_sth': '0'},
 'genus mantis': {'n_is_sth': '0'},
 'genus marmota': {'n_is_sth': '0'},
 'genus martes': {'n_is_sth': '0'},
 'genus masticophis': {'n_is_sth': '0'},
 'genus mastigoproctus': {'n_is_sth': '0'},
 'genus mastodon': {'n_is_sth': '0'},
 'genus mastotermes': {'n_is_sth': '0'},
 'genus maxostoma': {'n_is_sth': '0'},
 'genus mayetiola': {'n_is_sth': '0'},
 'genus mazama': {'n_is_sth': '0'},
 'genus megachile': {'n_is_sth': '0'},
 'genus megaderma': {'n_is_sth': '0'},
 'genus megalobatrachus': {'n_is_sth': '0'},
 'genus megalosaurus': {'n_is_sth': '0'},
 'genus megaptera': {'n_is_sth': '0'},
 'genus megatherium': {'n_is_sth': '0'},
 'genus melanerpes': {'n_is_sth': '0'},
 'genus melanitta': {'n_is_sth': '0'},
 'genus melanogrammus': {'n_is_sth': '0'},
 'genus melanoplus': {'n_is_sth': '0'},
 'genus melanotis': {'n_is_sth': '0'},
 'genus meles': {'n_is_sth': '0'},
 'genus mellivora': {'n_is_sth': '0'},
 'genus melogale': {'n_is_sth': '0'},
 'genus melolontha': {'n_is_sth': '0'},
 'genus melophagus': {'n_is_sth': '0'},
 'genus melopsittacus': {'n_is_sth': '0'},
 'genus melospiza': {'n_is_sth': '0'},
 'genus melursus': {'n_is_sth': '0'},
 'genus menippe': {'n_is_sth': '0'},
 'genus menopon': {'n_is_sth': '0'},
 'genus menticirrhus': {'n_is_sth': '0'},
 'genus menura': {'n_is_sth': '0'},
 'genus mephitis': {'n_is_sth': '0'},
 'genus mercenaria': {'n_is_sth': '0'},
 'genus mergus': {'n_is_sth': '0'},
 'genus meriones': {'n_is_sth': '0'},
 'genus merlangus': {'n_is_sth': '0'},
 'genus merluccius': {'n_is_sth': '0'},
 'genus merops': {'n_is_sth': '0'},
 'genus mesocricetus': {'n_is_sth': '0'},
 'genus mesohippus': {'n_is_sth': '0'},
 'genus microcentrum': {'n_is_sth': '0'},
 'genus micrococcus': {'n_is_sth': '0'},
 'genus micropogonias': {'n_is_sth': '0'},
 'genus micropterus': {'n_is_sth': '0'},
 'genus microstomus': {'n_is_sth': '0'},
 'genus microtus': {'n_is_sth': '0'},
 'genus micruroides': {'n_is_sth': '0'},
 'genus micrurus': {'n_is_sth': '0'},
 'genus mimus': {'n_is_sth': '0'},
 'genus mirounga': {'n_is_sth': '0'},
 'genus mobula': {'n_is_sth': '0'},
 'genus mola': {'n_is_sth': '0'},
 'genus mollienesia': {'n_is_sth': '0'},
 'genus molothrus': {'n_is_sth': '0'},
 'genus molva': {'n_is_sth': '0'},
 'genus momotus': {'n_is_sth': '0'},
 'genus monocanthus': {'n_is_sth': '0'},
 'genus monochamus': {'n_is_sth': '0'},
 'genus monodon': {'n_is_sth': '0'},
 'genus monomorium': {'n_is_sth': '0'},
 'genus morone': {'n_is_sth': '0'},
 'genus moschus': {'n_is_sth': '0'},
 'genus motacilla': {'n_is_sth': '0'},
 'genus mugil': {'n_is_sth': '0'},
 'genus mulloidichthys': {'n_is_sth': '0'},
 'genus mullus': {'n_is_sth': '0'},
 'genus muntiacus': {'n_is_sth': '0'},
 'genus muscardinus': {'n_is_sth': '0'},
 'genus musca': {'n_is_sth': '0'},
 'genus muscicapa': {'n_is_sth': '0'},
 'genus muscivora': {'n_is_sth': '0'},
 'genus musophaga': {'n_is_sth': '0'},
 'genus mustela': {'n_is_sth': '0'},
 'genus mustelus': {'n_is_sth': '0'},
 'genus mus': {'n_is_sth': '0'},
 'genus myadestes': {'n_is_sth': '0'},
 'genus mya': {'n_is_sth': '0'},
 'genus mycobacterium': {'n_is_sth': '0'},
 'genus mycoplasma': {'n_is_sth': '0'},
 'genus mycteria': {'n_is_sth': '0'},
 'genus mycteroperca': {'n_is_sth': '0'},
 'genus mylodon': {'n_is_sth': '0'},
 'genus myocastor': {'n_is_sth': '0'},
 'genus myopus': {'n_is_sth': '0'},
 'genus myotis': {'n_is_sth': '0'},
 'genus myrmecia': {'n_is_sth': '0'},
 'genus myrmecobius': {'n_is_sth': '0'},
 'genus myrmecophaga': {'n_is_sth': '0'},
 'genus myrmeleon': {'n_is_sth': '0'},
 'genus mysis': {'n_is_sth': '0'},
 'genus mytilus': {'n_is_sth': '0'},
 'genus myxine': {'n_is_sth': '0'},
 'genus myxocephalus': {'n_is_sth': '0'},
 'genus naemorhedus': {'n_is_sth': '0'},
 'genus naja': {'n_is_sth': '0'},
 'genus nanomia': {'n_is_sth': '0'},
 'genus nasalis': {'n_is_sth': '0'},
 'genus nasua': {'n_is_sth': '0'},
 'genus natrix': {'n_is_sth': '0'},
 'genus naucrates': {'n_is_sth': '0'},
 'genus nautilus': {'n_is_sth': '0'},
 'genus necturus': {'n_is_sth': '0'},
 'genus negaprion': {'n_is_sth': '0'},
 'genus neoceratodus': {'n_is_sth': '0'},
 'genus neofiber': {'n_is_sth': '0'},
 'genus neomys': {'n_is_sth': '0'},
 'genus nepa': {'n_is_sth': '0'},
 'genus nephrops': {'n_is_sth': '0'},
 'genus nerita': {'n_is_sth': '0'},
 'genus neritina': {'n_is_sth': '0'},
 'genus nerodia': {'n_is_sth': '0'},
 'genus nesokia': {'n_is_sth': '0'},
 'genus nestor': {'n_is_sth': '0'},
 'genus neurotrichus': {'n_is_sth': '0'},
 'genus nimravus': {'n_is_sth': '0'},
 'genus nitella': {'n_is_sth': '0'},
 'genus nitrobacter': {'n_is_sth': '0'},
 'genus nitrosomonas': {'n_is_sth': '0'},
 'genus noctiluca': {'n_is_sth': '0'},
 'genus noctua': {'n_is_sth': '0'},
 'genus nomia': {'n_is_sth': '0'},
 'genus nostoc': {'n_is_sth': '0'},
 'genus notechis': {'n_is_sth': '0'},
 'genus notemigonus': {'n_is_sth': '0'},
 'genus nothosaurus': {'n_is_sth': '0'},
 'genus notomys': {'n_is_sth': '0'},
 'genus notonecta': {'n_is_sth': '0'},
 'genus notophthalmus': {'n_is_sth': '0'},
 'genus notornis': {'n_is_sth': '0'},
 'genus notoryctus': {'n_is_sth': '0'},
 'genus notropis': {'n_is_sth': '0'},
 'genus nucifraga': {'n_is_sth': '0'},
 'genus numenius': {'n_is_sth': '0'},
 'genus numida': {'n_is_sth': '0'},
 'genus nyctanassa': {'n_is_sth': '0'},
 'genus nyctereutes': {'n_is_sth': '0'},
 'genus nycticebus': {'n_is_sth': '0'},
 'genus nycticorax': {'n_is_sth': '0'},
 'genus nyctimene': {'n_is_sth': '0'},
 'genus nymphalis': {'n_is_sth': '0'},
 'genus nymphicus': {'n_is_sth': '0'},
 'genus oceanites': {'n_is_sth': '0'},
 'genus ochotona': {'n_is_sth': '0'},
 'genus octopus': {'n_is_sth': '0'},
 'genus ocyurus': {'n_is_sth': '0'},
 'genus odobenus': {'n_is_sth': '0'},
 'genus odocoileus': {'n_is_sth': '0'},
 'genus odontaspis': {'n_is_sth': '0'},
 'genus odontophorus': {'n_is_sth': '0'},
 'genus oecanthus': {'n_is_sth': '0'},
 'genus oedogonium': {'n_is_sth': '0'},
 'genus oenanthe': {'n_is_sth': '0'},
 'genus oestrus': {'n_is_sth': '0'},
 'genus okapia': {'n_is_sth': '0'},
 'genus oligoplites': {'n_is_sth': '0'},
 'genus ommastrephes': {'n_is_sth': '0'},
 'genus onchorynchus': {'n_is_sth': '0'},
 'genus ondatra': {'n_is_sth': '0'},
 'genus oniscus': {'n_is_sth': '0'},
 'genus onychomys': {'n_is_sth': '0'},
 'genus opheodrys': {'n_is_sth': '0'},
 'genus ophiodon': {'n_is_sth': '0'},
 'genus ophiophagus': {'n_is_sth': '0'},
 'genus ophisaurus': {'n_is_sth': '0'},
 'genus opisthocomus': {'n_is_sth': '0'},
 'genus orchestia': {'n_is_sth': '0'},
 'genus orcinus': {'n_is_sth': '0'},
 'genus oreamnos': {'n_is_sth': '0'},
 'genus orectolobus': {'n_is_sth': '0'},
 'genus oreortyx': {'n_is_sth': '0'},
 'genus oriolus': {'n_is_sth': '0'},
 'genus ornithorhynchus': {'n_is_sth': '0'},
 'genus ortalis': {'n_is_sth': '0'},
 'genus orthopristis': {'n_is_sth': '0'},
 'genus orthotomus': {'n_is_sth': '0'},
 'genus orycteropus': {'n_is_sth': '0'},
 'genus oryctolagus': {'n_is_sth': '0'},
 'genus oryx': {'n_is_sth': '0'},
 'genus oryzomys': {'n_is_sth': '0'},
 'genus osmerus': {'n_is_sth': '0'},
 'genus ostrea': {'n_is_sth': '0'},
 'genus otaria': {'n_is_sth': '0'},
 'genus otis': {'n_is_sth': '0'},
 'genus otus': {'n_is_sth': '0'},
 'genus ouranopithecus': {'n_is_sth': '0'},
 'genus ovalipes': {'n_is_sth': '0'},
 'genus ovibos': {'n_is_sth': '0'},
 'genus ovis': {'n_is_sth': '0'},
 'genus oxybelis': {'n_is_sth': '0'},
 'genus oxylebius': {'n_is_sth': '0'},
 'genus oxyuranus': {'n_is_sth': '0'},
 'genus oxyura': {'n_is_sth': '0'},
 'genus pachycephala': {'n_is_sth': '0'},
 'genus padda': {'n_is_sth': '0'},
 'genus pagellus': {'n_is_sth': '0'},
 'genus pagophila': {'n_is_sth': '0'},
 'genus pagophilus': {'n_is_sth': '0'},
 'genus pagrus': {'n_is_sth': '0'},
 'genus pagurus': {'n_is_sth': '0'},
 'genus paleacrita': {'n_is_sth': '0'},
 'genus palinurus': {'n_is_sth': '0'},
 'genus palometa': {'n_is_sth': '0'},
 'genus pandion': {'n_is_sth': '0'},
 'genus panonychus': {'n_is_sth': '0'},
 'genus panthera': {'n_is_sth': '0'},
 'genus pan': {'n_is_sth': '0'},
 'genus papio': {'n_is_sth': '0'},
 'genus paprilus': {'n_is_sth': '0'},
 'genus paracheirodon': {'n_is_sth': '0'},
 'genus paradoxurus': {'n_is_sth': '0'},
 'genus paralichthys': {'n_is_sth': '0'},
 'genus paralithodes': {'n_is_sth': '0'},
 'genus paramecium': {'n_is_sth': '0'},
 'genus paranthias': {'n_is_sth': '0'},
 'genus paranthropus': {'n_is_sth': '0'},
 'genus parascalops': {'n_is_sth': '0'},
 'genus parophrys': {'n_is_sth': '0'},
 'genus parula': {'n_is_sth': '0'},
 'genus parus': {'n_is_sth': '0'},
 'genus passer': {'n_is_sth': '0'},
 'genus patella': {'n_is_sth': '0'},
 'genus pavo': {'n_is_sth': '0'},
 'genus pecari': {'n_is_sth': '0'},
 'genus pecten': {'n_is_sth': '0'},
 'genus pediculus': {'n_is_sth': '0'},
 'genus pedioecetes': {'n_is_sth': '0'},
 'genus pedionomus': {'n_is_sth': '0'},
 'genus pelecanus': {'n_is_sth': '0'},
 'genus peneus': {'n_is_sth': '0'},
 'genus pennatula': {'n_is_sth': '0'},
 'genus perca': {'n_is_sth': '0'},
 'genus percina': {'n_is_sth': '0'},
 'genus perdix': {'n_is_sth': '0'},
 'genus peridinium': {'n_is_sth': '0'},
 'genus periophthalmus': {'n_is_sth': '0'},
 'genus peripatus': {'n_is_sth': '0'},
 'genus periplaneta': {'n_is_sth': '0'},
 'genus perisoreus': {'n_is_sth': '0'},
 'genus peristedion': {'n_is_sth': '0'},
 'genus pernis': {'n_is_sth': '0'},
 'genus perodicticus': {'n_is_sth': '0'},
 'genus perognathus': {'n_is_sth': '0'},
 'genus peromyscus': {'n_is_sth': '0'},
 'genus petaurista': {'n_is_sth': '0'},
 'genus petaurus': {'n_is_sth': '0'},
 'genus petrogale': {'n_is_sth': '0'},
 'genus petromyzon': {'n_is_sth': '0'},
 'genus pezophaps': {'n_is_sth': '0'},
 'genus phacochoerus': {'n_is_sth': '0'},
 'genus phaethon': {'n_is_sth': '0'},
 'genus phalacrocorax': {'n_is_sth': '0'},
 'genus phalaenoptilus': {'n_is_sth': '0'},
 'genus phalanger': {'n_is_sth': '0'},
 'genus phalangium': {'n_is_sth': '0'},
 'genus phalaropus': {'n_is_sth': '0'},
 'genus pharomacrus': {'n_is_sth': '0'},
 'genus phascogale': {'n_is_sth': '0'},
 'genus phascolarctos': {'n_is_sth': '0'},
 'genus phasianus': {'n_is_sth': '0'},
 'genus phenacomys': {'n_is_sth': '0'},
 'genus philaenus': {'n_is_sth': '0'},
 'genus philohela': {'n_is_sth': '0'},
 'genus philomachus': {'n_is_sth': '0'},
 'genus philophylla': {'n_is_sth': '0'},
 'genus phlebotomus': {'n_is_sth': '0'},
 'genus phocaena': {'n_is_sth': '0'},
 'genus phoca': {'n_is_sth': '0'},
 'genus phoeniculus': {'n_is_sth': '0'},
 'genus phoenicurus': {'n_is_sth': '0'},
 'genus pholas': {'n_is_sth': '0'},
 'genus photoblepharon': {'n_is_sth': '0'},
 'genus phoxinus': {'n_is_sth': '0'},
 'genus phrynosoma': {'n_is_sth': '0'},
 'genus phthirius': {'n_is_sth': '0'},
 'genus phthirus': {'n_is_sth': '0'},
 'genus phthorimaea': {'n_is_sth': '0'},
 'genus phyllium': {'n_is_sth': '0'},
 'genus phyllorhynchus': {'n_is_sth': '0'},
 'genus phylloscopus': {'n_is_sth': '0'},
 'genus phyllostomus': {'n_is_sth': '0'},
 'genus phylloxera': {'n_is_sth': '0'},
 'genus physalia': {'n_is_sth': '0'},
 'genus physa': {'n_is_sth': '0'},
 'genus physeter': {'n_is_sth': '0'},
 'genus pica': {'n_is_sth': '0'},
 'genus picoides': {'n_is_sth': '0'},
 'genus picumnus': {'n_is_sth': '0'},
 'genus picus': {'n_is_sth': '0'},
 'genus pieris': {'n_is_sth': '0'},
 'genus pinctada': {'n_is_sth': '0'},
 'genus pineus': {'n_is_sth': '0'},
 'genus pinguinus': {'n_is_sth': '0'},
 'genus pinicola': {'n_is_sth': '0'},
 'genus pinnotheres': {'n_is_sth': '0'},
 'genus pipa': {'n_is_sth': '0'},
 'genus pipile': {'n_is_sth': '0'},
 'genus pipilo': {'n_is_sth': '0'},
 'genus pipistrellus': {'n_is_sth': '0'},
 'genus pipra': {'n_is_sth': '0'},
 'genus piranga': {'n_is_sth': '0'},
 'genus piroplasma': {'n_is_sth': '0'},
 'genus pisanosaurus': {'n_is_sth': '0'},
 'genus pithecanthropus': {'n_is_sth': '0'},
 'genus pithecia': {'n_is_sth': '0'},
 'genus pitta': {'n_is_sth': '0'},
 'genus pituophis': {'n_is_sth': '0'},
 'genus pitymys': {'n_is_sth': '0'},
 'genus placuna': {'n_is_sth': '0'},
 'genus planococcus': {'n_is_sth': '0'},
 'genus plasmodium': {'n_is_sth': '0'},
 'genus platalea': {'n_is_sth': '0'},
 'genus platichthys': {'n_is_sth': '0'},
 'genus platypoecilus': {'n_is_sth': '0'},
 'genus plautus': {'n_is_sth': '0'},
 'genus plecotus': {'n_is_sth': '0'},
 'genus plectrophenax': {'n_is_sth': '0'},
 'genus plesianthropus': {'n_is_sth': '0'},
 'genus plesiosaurus': {'n_is_sth': '0'},
 'genus plethodon': {'n_is_sth': '0'},
 'genus pleuronectes': {'n_is_sth': '0'},
 'genus plicatoperipatus': {'n_is_sth': '0'},
 'genus ploceus': {'n_is_sth': '0'},
 'genus pluvialis': {'n_is_sth': '0'},
 'genus pluvianus': {'n_is_sth': '0'},
 'genus podargus': {'n_is_sth': '0'},
 'genus podiceps': {'n_is_sth': '0'},
 'genus podilymbus': {'n_is_sth': '0'},
 'genus poecilocapsus': {'n_is_sth': '0'},
 'genus poecilogale': {'n_is_sth': '0'},
 'genus poephila': {'n_is_sth': '0'},
 'genus polioptila': {'n_is_sth': '0'},
 'genus polistes': {'n_is_sth': '0'},
 'genus pollachius': {'n_is_sth': '0'},
 'genus polyangium': {'n_is_sth': '0'},
 'genus polyborus': {'n_is_sth': '0'},
 'genus polycirrus': {'n_is_sth': '0'},
 'genus polydactylus': {'n_is_sth': '0'},
 'genus polyergus': {'n_is_sth': '0'},
 'genus polygonia': {'n_is_sth': '0'},
 'genus polyodon': {'n_is_sth': '0'},
 'genus polypedates': {'n_is_sth': '0'},
 'genus polyprion': {'n_is_sth': '0'},
 'genus pomacanthus': {'n_is_sth': '0'},
 'genus pomacentrus': {'n_is_sth': '0'},
 'genus pomatomus': {'n_is_sth': '0'},
 'genus pomolobus': {'n_is_sth': '0'},
 'genus pomoxis': {'n_is_sth': '0'},
 'genus pongo': {'n_is_sth': '0'},
 'genus pooecetes': {'n_is_sth': '0'},
 'genus popillia': {'n_is_sth': '0'},
 'genus porcellio': {'n_is_sth': '0'},
 'genus poronotus': {'n_is_sth': '0'},
 'genus porphyra': {'n_is_sth': '0'},
 'genus porphyrio': {'n_is_sth': '0'},
 'genus porphyrula': {'n_is_sth': '0'},
 'genus portunus': {'n_is_sth': '0'},
 'genus porzana': {'n_is_sth': '0'},
 'genus potamogale': {'n_is_sth': '0'},
 'genus potamophis': {'n_is_sth': '0'},
 'genus potorous': {'n_is_sth': '0'},
 'genus potos': {'n_is_sth': '0'},
 'genus praunus': {'n_is_sth': '0'},
 'genus presbytes': {'n_is_sth': '0'},
 'genus priacanthus': {'n_is_sth': '0'},
 'genus prinia': {'n_is_sth': '0'},
 'genus priodontes': {'n_is_sth': '0'},
 'genus prionace': {'n_is_sth': '0'},
 'genus prionotus': {'n_is_sth': '0'},
 'genus pristis': {'n_is_sth': '0'},
 'genus procavia': {'n_is_sth': '0'},
 'genus procellaria': {'n_is_sth': '0'},
 'genus prociphilus': {'n_is_sth': '0'},
 'genus procnias': {'n_is_sth': '0'},
 'genus proconsul': {'n_is_sth': '0'},
 'genus procyon': {'n_is_sth': '0'},
 'genus progne': {'n_is_sth': '0'},
 'genus prosopium': {'n_is_sth': '0'},
 'genus proteles': {'n_is_sth': '0'},
 'genus proterochampsa': {'n_is_sth': '0'},
 'genus proteus': {'n_is_sth': '0'},
 'genus protoavis': {'n_is_sth': '0'},
 'genus protoceratops': {'n_is_sth': '0'},
 'genus protohippus': {'n_is_sth': '0'},
 'genus prunella': {'n_is_sth': '0'},
 'genus psaltriparus': {'n_is_sth': '0'},
 'genus psenes': {'n_is_sth': '0'},
 'genus psephurus': {'n_is_sth': '0'},
 'genus psetta': {'n_is_sth': '0'},
 'genus psettichthys': {'n_is_sth': '0'},
 'genus pseudacris': {'n_is_sth': '0'},
 'genus pseudaletia': {'n_is_sth': '0'},
 'genus pseudechis': {'n_is_sth': '0'},
 'genus pseudemys': {'n_is_sth': '0'},
 'genus pseudococcus': {'n_is_sth': '0'},
 'genus pseudomonas': {'n_is_sth': '0'},
 'genus pseudopleuronectes': {'n_is_sth': '0'},
 'genus pseudoryx': {'n_is_sth': '0'},
 'genus psithyrus': {'n_is_sth': '0'},
 'genus psittacosaurus': {'n_is_sth': '0'},
 'genus psittacula': {'n_is_sth': '0'},
 'genus psittacus': {'n_is_sth': '0'},
 'genus psophia': {'n_is_sth': '0'},
 'genus pternohyla': {'n_is_sth': '0'},
 'genus pterocles': {'n_is_sth': '0'},
 'genus pterocnemia': {'n_is_sth': '0'},
 'genus pterodactylus': {'n_is_sth': '0'},
 'genus pterois': {'n_is_sth': '0'},
 'genus pteropus': {'n_is_sth': '0'},
 'genus ptilocercus': {'n_is_sth': '0'},
 'genus ptilocrinus': {'n_is_sth': '0'},
 'genus ptilonorhynchus': {'n_is_sth': '0'},
 'genus ptloris': {'n_is_sth': '0'},
 'genus ptyas': {'n_is_sth': '0'},
 'genus ptychozoon': {'n_is_sth': '0'},
 'genus puffinus': {'n_is_sth': '0'},
 'genus pulex': {'n_is_sth': '0'},
 'genus pygopus': {'n_is_sth': '0'},
 'genus pygoscelis': {'n_is_sth': '0'},
 'genus pylodictus': {'n_is_sth': '0'},
 'genus pyralis': {'n_is_sth': '0'},
 'genus pyrausta': {'n_is_sth': '0'},
 'genus pyrocephalus': {'n_is_sth': '0'},
 'genus pyrrhula': {'n_is_sth': '0'},
 'genus pyrrhuloxia': {'n_is_sth': '0'},
 'genus python': {'n_is_sth': '0'},
 'genus quiscalus': {'n_is_sth': '0'},
 'genus rachycentron': {'n_is_sth': '0'},
 'genus raja': {'n_is_sth': '0'},
 'genus ramphomicron': {'n_is_sth': '0'},
 'genus ranatra': {'n_is_sth': '0'},
 'genus rana': {'n_is_sth': '0'},
 'genus rangifer': {'n_is_sth': '0'},
 'genus raphicerus': {'n_is_sth': '0'},
 'genus raphus': {'n_is_sth': '0'},
 'genus rattus': {'n_is_sth': '0'},
 'genus recurvirostra': {'n_is_sth': '0'},
 'genus regalecus': {'n_is_sth': '0'},
 'genus regulus': {'n_is_sth': '0'},
 'genus reithrodontomys': {'n_is_sth': '0'},
 'genus remilegia': {'n_is_sth': '0'},
 'genus reticulitermes': {'n_is_sth': '0'},
 'genus rhagoletis': {'n_is_sth': '0'},
 'genus rhea': {'n_is_sth': '0'},
 'genus rhincodon': {'n_is_sth': '0'},
 'genus rhinoceros': {'n_is_sth': '0'},
 'genus rhinonicteris': {'n_is_sth': '0'},
 'genus rhinoptera': {'n_is_sth': '0'},
 'genus rhizobium': {'n_is_sth': '0'},
 'genus rhodymenia': {'n_is_sth': '0'},
 'genus rhyacotriton': {'n_is_sth': '0'},
 'genus rhynchoelaps': {'n_is_sth': '0'},
 'genus richmondena': {'n_is_sth': '0'},
 'genus rickettsia': {'n_is_sth': '0'},
 'genus riparia': {'n_is_sth': '0'},
 'genus rissa': {'n_is_sth': '0'},
 'genus rivulus': {'n_is_sth': '0'},
 'genus roccus': {'n_is_sth': '0'},
 'genus rupicapra': {'n_is_sth': '0'},
 'genus rupicola': {'n_is_sth': '0'},
 'genus rutilus': {'n_is_sth': '0'},
 'genus rynchops': {'n_is_sth': '0'},
 'genus rypticus': {'n_is_sth': '0'},
 'genus sagittarius': {'n_is_sth': '0'},
 'genus sagitta': {'n_is_sth': '0'},
 'genus saiga': {'n_is_sth': '0'},
 'genus saimiri': {'n_is_sth': '0'},
 'genus salmo': {'n_is_sth': '0'},
 'genus salpa': {'n_is_sth': '0'},
 'genus salpinctes': {'n_is_sth': '0'},
 'genus salvelinus': {'n_is_sth': '0'},
 'genus samia': {'n_is_sth': '0'},
 'genus sarcocystis': {'n_is_sth': '0'},
 'genus sarcophaga': {'n_is_sth': '0'},
 'genus sarcophilus': {'n_is_sth': '0'},
 'genus sarcoptes': {'n_is_sth': '0'},
 'genus sarcorhamphus': {'n_is_sth': '0'},
 'genus sarda': {'n_is_sth': '0'},
 'genus sardina': {'n_is_sth': '0'},
 'genus sardinia': {'n_is_sth': '0'},
 'genus sardinops': {'n_is_sth': '0'},
 'genus sargassum': {'n_is_sth': '0'},
 'genus sauromalus': {'n_is_sth': '0'},
 'genus saurosuchus': {'n_is_sth': '0'},
 'genus saxicola': {'n_is_sth': '0'},
 'genus sayornis': {'n_is_sth': '0'},
 'genus scaphiopus': {'n_is_sth': '0'},
 'genus scarabaeus': {'n_is_sth': '0'},
 'genus scardinius': {'n_is_sth': '0'},
 'genus scartella': {'n_is_sth': '0'},
 'genus sceliphron': {'n_is_sth': '0'},
 'genus sceloglaux': {'n_is_sth': '0'},
 'genus sceloporus': {'n_is_sth': '0'},
 'genus schistosoma': {'n_is_sth': '0'},
 'genus sciaena': {'n_is_sth': '0'},
 'genus sciaenops': {'n_is_sth': '0'},
 'genus sciara': {'n_is_sth': '0'},
 'genus scincella': {'n_is_sth': '0'},
 'genus scincus': {'n_is_sth': '0'},
 'genus sciurus': {'n_is_sth': '0'},
 'genus scolopax': {'n_is_sth': '0'},
 'genus scolytus': {'n_is_sth': '0'},
 'genus scomberesox': {'n_is_sth': '0'},
 'genus scomberomorus': {'n_is_sth': '0'},
 'genus scomber': {'n_is_sth': '0'},
 'genus scombresox': {'n_is_sth': '0'},
 'genus scophthalmus': {'n_is_sth': '0'},
 'genus scorpaena': {'n_is_sth': '0'},
 'genus scutigera': {'n_is_sth': '0'},
 'genus scutigerella': {'n_is_sth': '0'},
 'genus sebastodes': {'n_is_sth': '0'},
 'genus seismosaurus': {'n_is_sth': '0'},
 'genus seiurus': {'n_is_sth': '0'},
 'genus selar': {'n_is_sth': '0'},
 'genus selenarctos': {'n_is_sth': '0'},
 'genus selene': {'n_is_sth': '0'},
 'genus sepia': {'n_is_sth': '0'},
 'genus serinus': {'n_is_sth': '0'},
 'genus seriola': {'n_is_sth': '0'},
 'genus seriphus': {'n_is_sth': '0'},
 'genus serranus': {'n_is_sth': '0'},
 'genus serrasalmus': {'n_is_sth': '0'},
 'genus serratia': {'n_is_sth': '0'},
 'genus sertularia': {'n_is_sth': '0'},
 'genus setophaga': {'n_is_sth': '0'},
 'genus shigella': {'n_is_sth': '0'},
 'genus sialia': {'n_is_sth': '0'},
 'genus sialis': {'n_is_sth': '0'},
 'genus sigmodon': {'n_is_sth': '0'},
 'genus sillago': {'n_is_sth': '0'},
 'genus silurus': {'n_is_sth': '0'},
 'genus silvia': {'n_is_sth': '0'},
 'genus simulium': {'n_is_sth': '0'},
 'genus sinanthropus': {'n_is_sth': '0'},
 'genus sinornis': {'n_is_sth': '0'},
 'genus siren': {'n_is_sth': '0'},
 'genus sistrurus': {'n_is_sth': '0'},
 'genus sitophylus': {'n_is_sth': '0'},
 'genus sitotroga': {'n_is_sth': '0'},
 'genus sitta': {'n_is_sth': '0'},
 'genus sivapithecus': {'n_is_sth': '0'},
 'genus smiledon': {'n_is_sth': '0'},
 'genus solea': {'n_is_sth': '0'},
 'genus solenopsis': {'n_is_sth': '0'},
 'genus somateria': {'n_is_sth': '0'},
 'genus sorex': {'n_is_sth': '0'},
 'genus spadella': {'n_is_sth': '0'},
 'genus spalax': {'n_is_sth': '0'},
 'genus spermophilus': {'n_is_sth': '0'},
 'genus sphecius': {'n_is_sth': '0'},
 'genus sphecotheres': {'n_is_sth': '0'},
 'genus spheniscus': {'n_is_sth': '0'},
 'genus sphenodon': {'n_is_sth': '0'},
 'genus sphyraena': {'n_is_sth': '0'},
 'genus sphyrapicus': {'n_is_sth': '0'},
 'genus sphyrna': {'n_is_sth': '0'},
 'genus spilogale': {'n_is_sth': '0'},
 'genus spinus': {'n_is_sth': '0'},
 'genus spirillum': {'n_is_sth': '0'},
 'genus spirochaeta': {'n_is_sth': '0'},
 'genus spirogyra': {'n_is_sth': '0'},
 'genus spirula': {'n_is_sth': '0'},
 'genus spizella': {'n_is_sth': '0'},
 'genus spodoptera': {'n_is_sth': '0'},
 'genus spyeria': {'n_is_sth': '0'},
 'genus squalus': {'n_is_sth': '0'},
 'genus squatina': {'n_is_sth': '0'},
 'genus squilla': {'n_is_sth': '0'},
 'genus staphylococcus': {'n_is_sth': '0'},
 'genus staurikosaurus': {'n_is_sth': '0'},
 'genus steatornis': {'n_is_sth': '0'},
 'genus steganopus': {'n_is_sth': '0'},
 'genus stegosaurus': {'n_is_sth': '0'},
 'genus stenopelmatus': {'n_is_sth': '0'},
 'genus stenopterygius': {'n_is_sth': '0'},
 'genus stenotomus': {'n_is_sth': '0'},
 'genus stentor': {'n_is_sth': '0'},
 'genus stercorarius': {'n_is_sth': '0'},
 'genus sterna': {'n_is_sth': '0'},
 'genus sternotherus': {'n_is_sth': '0'},
 'genus stictomys': {'n_is_sth': '0'},
 'genus stictopelia': {'n_is_sth': '0'},
 'genus stizostedion': {'n_is_sth': '0'},
 'genus storeria': {'n_is_sth': '0'},
 'genus strepera': {'n_is_sth': '0'},
 'genus strepsiceros': {'n_is_sth': '0'},
 'genus streptococcus': {'n_is_sth': '0'},
 'genus streptomyces': {'n_is_sth': '0'},
 'genus streptopelia': {'n_is_sth': '0'},
 'genus strix': {'n_is_sth': '0'},
 'genus strombus': {'n_is_sth': '0'},
 'genus struthiomimus': {'n_is_sth': '0'},
 'genus struthio': {'n_is_sth': '0'},
 'genus sturnella': {'n_is_sth': '0'},
 'genus sturnus': {'n_is_sth': '0'},
 'genus styracosaurus': {'n_is_sth': '0'},
 'genus sula': {'n_is_sth': '0'},
 'genus suricata': {'n_is_sth': '0'},
 'genus surnia': {'n_is_sth': '0'},
 'genus sus': {'n_is_sth': '0'},
 'genus sylvilagus': {'n_is_sth': '0'},
 'genus symphalangus': {'n_is_sth': '0'},
 'genus synagrops': {'n_is_sth': '0'},
 'genus synanceja': {'n_is_sth': '0'},
 'genus synaptomys': {'n_is_sth': '0'},
 'genus synercus': {'n_is_sth': '0'},
 'genus syngnathus': {'n_is_sth': '0'},
 'genus syrrhaptes': {'n_is_sth': '0'},
 'genus tachyglossus': {'n_is_sth': '0'},
 'genus tachypleus': {'n_is_sth': '0'},
 'genus tadarida': {'n_is_sth': '0'},
 'genus tadorna': {'n_is_sth': '0'},
 'genus taenia': {'n_is_sth': '0'},
 'genus tamandua': {'n_is_sth': '0'},
 'genus tamiasciurus': {'n_is_sth': '0'},
 'genus tamias': {'n_is_sth': '0'},
 'genus tantilla': {'n_is_sth': '0'},
 'genus tapirus': {'n_is_sth': '0'},
 'genus taricha': {'n_is_sth': '0'},
 'genus tarpon': {'n_is_sth': '0'},
 'genus tarsius': {'n_is_sth': '0'},
 'genus taurotragus': {'n_is_sth': '0'},
 'genus tautogolabrus': {'n_is_sth': '0'},
 'genus taxidea': {'n_is_sth': '0'},
 'genus tayassu': {'n_is_sth': '0'},
 'genus tenrec': {'n_is_sth': '0'},
 'genus teredo': {'n_is_sth': '0'},
 'genus termes': {'n_is_sth': '0'},
 'genus terrapene': {'n_is_sth': '0'},
 'genus testudo': {'n_is_sth': '0'},
 'genus tethus': {'n_is_sth': '0'},
 'genus tetragonurus': {'n_is_sth': '0'},
 'genus tetrahymena': {'n_is_sth': '0'},
 'genus tetrao': {'n_is_sth': '0'},
 'genus tetrapturus': {'n_is_sth': '0'},
 'genus thalarctos': {'n_is_sth': '0'},
 'genus thalassoma': {'n_is_sth': '0'},
 'genus thamnophilus': {'n_is_sth': '0'},
 'genus thamnophis': {'n_is_sth': '0'},
 'genus thiobacillus': {'n_is_sth': '0'},
 'genus thomomys': {'n_is_sth': '0'},
 'genus threskiornis': {'n_is_sth': '0'},
 'genus thrips': {'n_is_sth': '0'},
 'genus thryothorus': {'n_is_sth': '0'},
 'genus thunnus': {'n_is_sth': '0'},
 'genus thylacinus': {'n_is_sth': '0'},
 'genus thylogale': {'n_is_sth': '0'},
 'genus tibicen': {'n_is_sth': '0'},
 'genus tichodroma': {'n_is_sth': '0'},
 'genus tilapia': {'n_is_sth': '0'},
 'genus timalia': {'n_is_sth': '0'},
 'genus tinca': {'n_is_sth': '0'},
 'genus tinea': {'n_is_sth': '0'},
 'genus tineola': {'n_is_sth': '0'},
 'genus titanosaurus': {'n_is_sth': '0'},
 'genus todus': {'n_is_sth': '0'},
 'genus tolypeutes': {'n_is_sth': '0'},
 'genus tomistoma': {'n_is_sth': '0'},
 'genus tortrix': {'n_is_sth': '0'},
 'genus toxostoma': {'n_is_sth': '0'},
 'genus toxotes': {'n_is_sth': '0'},
 'genus trachinotus': {'n_is_sth': '0'},
 'genus trachipterus': {'n_is_sth': '0'},
 'genus trachodon': {'n_is_sth': '0'},
 'genus trachurus': {'n_is_sth': '0'},
 'genus tragelaphus': {'n_is_sth': '0'},
 'genus tragopan': {'n_is_sth': '0'},
 'genus tragulus': {'n_is_sth': '0'},
 'genus treponema': {'n_is_sth': '0'},
 'genus triaenodon': {'n_is_sth': '0'},
 'genus trialeurodes': {'n_is_sth': '0'},
 'genus triatoma': {'n_is_sth': '0'},
 'genus tribolium': {'n_is_sth': '0'},
 'genus tribonema': {'n_is_sth': '0'},
 'genus triceratops': {'n_is_sth': '0'},
 'genus trichecus': {'n_is_sth': '0'},
 'genus trichodesmium': {'n_is_sth': '0'},
 'genus trichoglossus': {'n_is_sth': '0'},
 'genus trichomonas': {'n_is_sth': '0'},
 'genus trichophaga': {'n_is_sth': '0'},
 'genus trichosurus': {'n_is_sth': '0'},
 'genus trichys': {'n_is_sth': '0'},
 'genus tridacna': {'n_is_sth': '0'},
 'genus triga': {'n_is_sth': '0'},
 'genus trimorphodon': {'n_is_sth': '0'},
 'genus trinectes': {'n_is_sth': '0'},
 'genus tringa': {'n_is_sth': '0'},
 'genus trionyx': {'n_is_sth': '0'},
 'genus triops': {'n_is_sth': '0'},
 'genus triturus': {'n_is_sth': '0'},
 'genus trogium': {'n_is_sth': '0'},
 'genus troglodytes': {'n_is_sth': '0'},
 'genus trogon': {'n_is_sth': '0'},
 'genus trombicula': {'n_is_sth': '0'},
 'genus tropidoclonion': {'n_is_sth': '0'},
 'genus tunga': {'n_is_sth': '0'},
 'genus tupaia': {'n_is_sth': '0'},
 'genus tupinambis': {'n_is_sth': '0'},
 'genus turbatrix': {'n_is_sth': '0'},
 'genus turdus': {'n_is_sth': '0'},
 'genus turnix': {'n_is_sth': '0'},
 'genus tursiops': {'n_is_sth': '0'},
 'genus tylenchus': {'n_is_sth': '0'},
 'genus tympanuchus': {'n_is_sth': '0'},
 'genus tyrannosaurus': {'n_is_sth': '0'},
 'genus tyrannus': {'n_is_sth': '0'},
 'genus tyto': {'n_is_sth': '0'},
 'genus uca': {'n_is_sth': '0'},
 'genus uintatherium': {'n_is_sth': '0'},
 'genus ulva': {'n_is_sth': '0'},
 'genus uma': {'n_is_sth': '0'},
 'genus umbrina': {'n_is_sth': '0'},
 'genus unio': {'n_is_sth': '0'},
 'genus upupa': {'n_is_sth': '0'},
 'genus uria': {'n_is_sth': '0'},
 'genus urocyon': {'n_is_sth': '0'},
 'genus urophycis': {'n_is_sth': '0'},
 'genus uropsilus': {'n_is_sth': '0'},
 'genus urosaurus': {'n_is_sth': '0'},
 'genus ursus': {'n_is_sth': '0'},
 'genus utahraptor': {'n_is_sth': '0'},
 'genus uta': {'n_is_sth': '0'},
 'genus vanellus': {'n_is_sth': '0'},
 'genus vanessa': {'n_is_sth': '0'},
 'genus varanus': {'n_is_sth': '0'},
 'genus vedalia': {'n_is_sth': '0'},
 'genus velociraptor': {'n_is_sth': '0'},
 'genus venus': {'n_is_sth': '0'},
 'genus vespa': {'n_is_sth': '0'},
 'genus vespertilio': {'n_is_sth': '0'},
 'genus vespula': {'n_is_sth': '0'},
 'genus vibrio': {'n_is_sth': '0'},
 'genus vicugna': {'n_is_sth': '0'},
 'genus vidua': {'n_is_sth': '0'},
 'genus vipera': {'n_is_sth': '0'},
 'genus vireo': {'n_is_sth': '0'},
 'genus viverra': {'n_is_sth': '0'},
 'genus viverricula': {'n_is_sth': '0'},
 'genus volvox': {'n_is_sth': '0'},
 'genus vorticella': {'n_is_sth': '0'},
 'genus vulpes': {'n_is_sth': '0'},
 'genus vultur': {'n_is_sth': '0'},
 'genus xanthomonas': {'n_is_sth': '0'},
 'genus xenicus': {'n_is_sth': '0'},
 'genus xenopus': {'n_is_sth': '0'},
 'genus xenorhyncus': {'n_is_sth': '0'},
 'genus xenosaurus': {'n_is_sth': '0'},
 'genus xerobates': {'n_is_sth': '0'},
 'genus xiphias': {'n_is_sth': '0'},
 'genus xylocopa': {'n_is_sth': '0'},
 'genus xyphophorus': {'n_is_sth': '0'},
 'genus zaglossus': {'n_is_sth': '0'},
 'genus zalophus': {'n_is_sth': '0'},
 'genus zapus': {'n_is_sth': '0'},
 'genus zenaidura': {'n_is_sth': '0'},
 'genus zeus': {'n_is_sth': '0'},
 'genus zinjanthropus': {'n_is_sth': '0'},
 'genus zoarces': {'n_is_sth': '0'},
 'genus zonotrichia': {'n_is_sth': '0'},
 'genus zygnema': {'n_is_sth': '0'},
 'genus-fenusa': {'n_is_sth': '0'},
 'genus-megapodius': {'n_is_sth': '0'},
 'genus-milvus': {'n_is_sth': '0'},
 'genyonemus': {'n_is_sth': '0'},
 'geomys': {'n_is_sth': '0'},
 'gerbillinae': {'n_is_sth': '0'},
 'gerbillus': {'n_is_sth': '0'},
 'germ layer': {'n_is_sth': '0'},
 'germinal area': {'n_is_sth': '0'},
 'germinal disc': {'n_is_sth': '0'},
 'gerres': {'n_is_sth': '0'},
 'gerrididae': {'n_is_sth': '0'},
 'gerris': {'n_is_sth': '0'},
 'gigartinaceae': {'n_is_sth': '0'},
 'gill arch': {'n_is_sth': '0'},
 'gill bar': {'n_is_sth': '0'},
 'gill cleft': {'n_is_sth': '0'},
 'gill slit': {'n_is_sth': '0'},
 'glareola': {'n_is_sth': '0'},
 'globigerinidae': {'n_is_sth': '0'},
 'glossinidae': {'n_is_sth': '0'},
 'glossopsitta': {'n_is_sth': '0'},
 'gnathostomata': {'n_is_sth': '0'},
 'gobiesocidae': {'n_is_sth': '0'},
 'gobiesox': {'n_is_sth': '0'},
 'gobiidae': {'n_is_sth': '0'},
 'goffer': {'n_is_sth': '0'},
 'gomphotheriidae': {'n_is_sth': '0'},
 'gomphotherium': {'n_is_sth': '0'},
 'gonorhynchidae': {'n_is_sth': '0'},
 'goose down': {'n_is_sth': '0'},
 'gordius': {'n_is_sth': '0'},
 'gorgonacea': {'n_is_sth': '0'},
 'gracilariidae': {'n_is_sth': '0'},
 'gracula': {'n_is_sth': '0'},
 'green gland': {'n_is_sth': '0'},
 'gregarinida': {'n_is_sth': '0'},
 'gruidae': {'n_is_sth': '0'},
 'gruiformes': {'n_is_sth': '0'},
 'gryllidae': {'n_is_sth': '0'},
 'guard hair': {'n_is_sth': '0'},
 'gulo': {'n_is_sth': '0'},
 'gymnelis': {'n_is_sth': '0'},
 'gymnophiona': {'n_is_sth': '0'},
 'gymnorhina': {'n_is_sth': '0'},
 'gypaetus': {'n_is_sth': '0'},
 'gyrinidae': {'n_is_sth': '0'},
 'hackle': {'n_is_sth': '0'},
 'haematobia': {'n_is_sth': '0'},
 'haematopus': {'n_is_sth': '0'},
 'haemoproteus': {'n_is_sth': '0'},
 'haemosporidia': {'n_is_sth': '0'},
 'haemulon': {'n_is_sth': '0'},
 'haliaeetus': {'n_is_sth': '0'},
 'halicoeres': {'n_is_sth': '0'},
 'halictidae': {'n_is_sth': '0'},
 'haltere': {'n_is_sth': '0'},
 'haploid': {'n_is_sth': '0'},
 'haplosporidia': {'n_is_sth': '0'},
 'harpia': {'n_is_sth': '0'},
 'heleodytes': {'n_is_sth': '0'},
 'heliothis': {'n_is_sth': '0'},
 'heliozoa': {'n_is_sth': '0'},
 'helodermatidae': {'n_is_sth': '0'},
 'heloderma': {'n_is_sth': '0'},
 'hemiprocnidae': {'n_is_sth': '0'},
 'hemiramphidae': {'n_is_sth': '0'},
 'hermissenda': {'n_is_sth': '0'},
 'herpes zoster': {'n_is_sth': '0'},
 'heterocercal fin': {'n_is_sth': '0'},
 'heterodactyl foot': {'n_is_sth': '0'},
 'heterodon': {'n_is_sth': '0'},
 'heterokontae': {'n_is_sth': '0'},
 'heteromyidae': {'n_is_sth': '0'},
 'heteroploid': {'n_is_sth': '0'},
 'heteroptera': {'n_is_sth': '0'},
 'heteroscelus': {'n_is_sth': '0'},
 'heterosomata': {'n_is_sth': '0'},
 'heterostraci': {'n_is_sth': '0'},
 'heterotrichales': {'n_is_sth': '0'},
 'hexagrammidae': {'n_is_sth': '0'},
 'hexagrammos': {'n_is_sth': '0'},
 'hexanchidae': {'n_is_sth': '0'},
 'hexanchus': {'n_is_sth': '0'},
 'hexapoda': {'n_is_sth': '0'},
 'himantopus': {'n_is_sth': '0'},
 'hind leg': {'n_is_sth': '0'},
 'hind limb': {'n_is_sth': '0'},
 'hindfoot': {'n_is_sth': '0'},
 'hippobosca': {'n_is_sth': '0'},
 'hippoboscidae': {'n_is_sth': '0'},
 'hippoboscid': {'n_is_sth': '0'},
 'hippodamia': {'n_is_sth': '0'},
 'hippoglossoides': {'n_is_sth': '0'},
 'hippopotamidae': {'n_is_sth': '0'},
 'hipposideridae': {'n_is_sth': '0'},
 'hippotragus': {'n_is_sth': '0'},
 'hipsurus': {'n_is_sth': '0'},
 'hirudinea': {'n_is_sth': '0'},
 'hirudinidae': {'n_is_sth': '0'},
 'hirundinidae': {'n_is_sth': '0'},
 'hirundo': {'n_is_sth': '0'},
 'holbrookia': {'n_is_sth': '0'},
 'holocentridae': {'n_is_sth': '0'},
 'holocentrus': {'n_is_sth': '0'},
 'holocephali': {'n_is_sth': '0'},
 'holometabola': {'n_is_sth': '0'},
 'holothuria': {'n_is_sth': '0'},
 'holothuridae': {'n_is_sth': '0'},
 'holothuroidea': {'n_is_sth': '0'},
 'homaridae': {'n_is_sth': '0'},
 'hominidae': {'n_is_sth': '0'},
 'hominoidea': {'n_is_sth': '0'},
 'homoptera': {'n_is_sth': '0'},
 "horse's foot": {'n_is_sth': '0'},
 "horse's hoof": {'n_is_sth': '0'},
 'hyades': {'n_is_sth': '0'},
 'hyaenidae': {'n_is_sth': '0'},
 'hyalospongiae': {'n_is_sth': '0'},
 'hydrobates': {'n_is_sth': '0'},
 'hydrobatidae': {'n_is_sth': '0'},
 'hydrochoeridae': {'n_is_sth': '0'},
 'hydrodamalis': {'n_is_sth': '0'},
 'hydromantes': {'n_is_sth': '0'},
 'hydromyinae': {'n_is_sth': '0'},
 'hydrophidae': {'n_is_sth': '0'},
 'hyemoschus': {'n_is_sth': '0'},
 'hylidae': {'n_is_sth': '0'},
 'hylobates': {'n_is_sth': '0'},
 'hylobatidae': {'n_is_sth': '0'},
 'hymenoptera': {'n_is_sth': '0'},
 'hypermastigina': {'n_is_sth': '0'},
 'hyperoartia': {'n_is_sth': '0'},
 'hyperoglyphe': {'n_is_sth': '0'},
 'hyperoodon': {'n_is_sth': '0'},
 'hyphantria': {'n_is_sth': '0'},
 'hypoblast': {'n_is_sth': '0'},
 'hypodermatidae': {'n_is_sth': '0'},
 'hypoderma': {'n_is_sth': '0'},
 'hypodermis': {'n_is_sth': '0'},
 'hyracoidea': {'n_is_sth': '0'},
 'hyracotherium': {'n_is_sth': '0'},
 'hystricidae': {'n_is_sth': '0'},
 'ichneumonidae': {'n_is_sth': '0'},
 'ichthyosauria': {'n_is_sth': '0'},
 'ichthyosauridae': {'n_is_sth': '0'},
 'ictalurus': {'n_is_sth': '0'},
 'icteridae': {'n_is_sth': '0'},
 'ictiobus': {'n_is_sth': '0'},
 'ictonyx': {'n_is_sth': '0'},
 'iguania': {'n_is_sth': '0'},
 'iguanidae': {'n_is_sth': '0'},
 'iguanodontidae': {'n_is_sth': '0'},
 'inachis': {'n_is_sth': '0'},
 'indicatoridae': {'n_is_sth': '0'},
 'indriidae': {'n_is_sth': '0'},
 'infusoria': {'n_is_sth': '0'},
 'insecta': {'n_is_sth': '0'},
 'insectivora': {'n_is_sth': '0'},
 'invertebrate foot': {'n_is_sth': '0'},
 'ipidae': {'n_is_sth': '0'},
 'irenidae': {'n_is_sth': '0'},
 'iridoprocne': {'n_is_sth': '0'},
 'ischigualastia': {'n_is_sth': '0'},
 'isopoda': {'n_is_sth': '0'},
 'isoptera': {'n_is_sth': '0'},
 'isospondyli': {'n_is_sth': '0'},
 'istiophoridae': {'n_is_sth': '0'},
 'istiophorus': {'n_is_sth': '0'},
 'isuridae': {'n_is_sth': '0'},
 'isurus': {'n_is_sth': '0'},
 'junior featherweight': {'n_is_sth': '0'},
 'katsuwonidae': {'n_is_sth': '0'},
 'kingdom animalia': {'n_is_sth': '0'},
 'kingdom monera': {'n_is_sth': '0'},
 'kingdom protoctista': {'n_is_sth': '0'},
 'kinosternidae': {'n_is_sth': '0'},
 'kinosternon': {'n_is_sth': '0'},
 'kyphosidae': {'n_is_sth': '0'},
 'kyphosus': {'n_is_sth': '0'},
 'labridae': {'n_is_sth': '0'},
 'labyrinthodontia': {'n_is_sth': '0'},
 'lacerta': {'n_is_sth': '0'},
 'lacertidae': {'n_is_sth': '0'},
 'lacertilia': {'n_is_sth': '0'},
 'lachnolaimus': {'n_is_sth': '0'},
 'lactobacteriaceae': {'n_is_sth': '0'},
 'lactophrys': {'n_is_sth': '0'},
 'lagidium': {'n_is_sth': '0'},
 'lagodon': {'n_is_sth': '0'},
 'lagomorpha': {'n_is_sth': '0'},
 'lagostomus': {'n_is_sth': '0'},
 'lagothrix': {'n_is_sth': '0'},
 'lamellibranchia': {'n_is_sth': '0'},
 'lamellicornia': {'n_is_sth': '0'},
 'laminariaceae': {'n_is_sth': '0'},
 'laminariales': {'n_is_sth': '0'},
 'lamna nasus': {'n_is_sth': '0'},
 'lamna': {'n_is_sth': '0'},
 'lamnidae': {'n_is_sth': '0'},
 'lampridae': {'n_is_sth': '0'},
 'lampris': {'n_is_sth': '0'},
 'lampyridae': {'n_is_sth': '0'},
 'laniidae': {'n_is_sth': '0'},
 'lanius': {'n_is_sth': '0'},
 'lanthanotidae': {'n_is_sth': '0'},
 'lanthanotus': {'n_is_sth': '0'},
 'lappet': {'n_is_sth': '0'},
 'laridae': {'n_is_sth': '0'},
 'larus': {'n_is_sth': '0'},
 'larvacea': {'n_is_sth': '0'},
 'lasiocampa': {'n_is_sth': '0'},
 'lasiocampidae': {'n_is_sth': '0'},
 'lateral line organ': {'n_is_sth': '0'},
 'lateral line': {'n_is_sth': '0'},
 'latimeridae': {'n_is_sth': '0'},
 'leiopelmatidae': {'n_is_sth': '0'},
 'leiopelma': {'n_is_sth': '0'},
 'lemmus': {'n_is_sth': '0'},
 'lemuridae': {'n_is_sth': '0'},
 'lemuroidea': {'n_is_sth': '0'},
 'leontocebus': {'n_is_sth': '0'},
 'lepadidae': {'n_is_sth': '0'},
 'lepidochelys': {'n_is_sth': '0'},
 'lepidocybium': {'n_is_sth': '0'},
 'lepidopteran': {'n_is_sth': '0'},
 'lepidoptera': {'n_is_sth': '0'},
 'lepidosauria': {'n_is_sth': '0'},
 'lepismatidae': {'n_is_sth': '0'},
 'lepisma': {'n_is_sth': '0'},
 'lepisosteidae': {'n_is_sth': '0'},
 'lepisosteus': {'n_is_sth': '0'},
 'lepomis': {'n_is_sth': '0'},
 'leporidae': {'n_is_sth': '0'},
 'leptinotarsa': {'n_is_sth': '0'},
 'leptodactylidae': {'n_is_sth': '0'},
 'leptodactylus': {'n_is_sth': '0'},
 'leptoglossus': {'n_is_sth': '0'},
 'leptoptilus': {'n_is_sth': '0'},
 'leptotyphlopidae': {'n_is_sth': '0'},
 'leptotyphlops': {'n_is_sth': '0'},
 'lepus': {'n_is_sth': '0'},
 'leuciscus': {'n_is_sth': '0'},
 'leucocytozoon': {'n_is_sth': '0'},
 'lichanura': {'n_is_sth': '0'},
 'limacidae': {'n_is_sth': '0'},
 'limanda': {'n_is_sth': '0'},
 'limenitis': {'n_is_sth': '0'},
 'limicolae': {'n_is_sth': '0'},
 'limnocryptes': {'n_is_sth': '0'},
 'limnodromus': {'n_is_sth': '0'},
 'limulidae': {'n_is_sth': '0'},
 'liomys': {'n_is_sth': '0'},
 'liopelma': {'n_is_sth': '0'},
 'liopelmidae': {'n_is_sth': '0'},
 'liparidae': {'n_is_sth': '0'},
 'liparididae': {'n_is_sth': '0'},
 'liparis': {'n_is_sth': '0'},
 'liposcelis': {'n_is_sth': '0'},
 'lipotyphla': {'n_is_sth': '0'},
 'listeria': {'n_is_sth': '0'},
 'lithodidae': {'n_is_sth': '0'},
 'litocranius': {'n_is_sth': '0'},
 'lobata': {'n_is_sth': '0'},
 'lobate foot': {'n_is_sth': '0'},
 'lobefin': {'n_is_sth': '0'},
 'lobotes': {'n_is_sth': '0'},
 'lobotidae': {'n_is_sth': '0'},
 'locustidae': {'n_is_sth': '0'},
 'long-legs': {'n_is_sth': '0'},
 'lophiidae': {'n_is_sth': '0'},
 'lophius': {'n_is_sth': '0'},
 'lophodytes': {'n_is_sth': '0'},
 'lopholatilus': {'n_is_sth': '0'},
 'lophophorus': {'n_is_sth': '0'},
 'loricata': {'n_is_sth': '0'},
 'loriinae': {'n_is_sth': '0'},
 'lorisidae': {'n_is_sth': '0'},
 'loxia': {'n_is_sth': '0'},
 'loxostege': {'n_is_sth': '0'},
 'lucanidae': {'n_is_sth': '0'},
 'lumbus': {'n_is_sth': '0'},
 'lumpenus': {'n_is_sth': '0'},
 'lumpfish': {'n_is_sth': '0'},
 'lutjanidae': {'n_is_sth': '0'},
 'lutrinae': {'n_is_sth': '0'},
 'luvaridae': {'n_is_sth': '0'},
 'luvarus': {'n_is_sth': '0'},
 'lycaena': {'n_is_sth': '0'},
 'lycaenidae': {'n_is_sth': '0'},
 'lycaenid': {'n_is_sth': '0'},
 'lycosa': {'n_is_sth': '0'},
 'lycosidae': {'n_is_sth': '0'},
 'lygaeidae': {'n_is_sth': '0'},
 'lymantriidae': {'n_is_sth': '0'},
 'lyrurus': {'n_is_sth': '0'},
 'lyssavirus': {'n_is_sth': '0'},
 'machilidae': {'n_is_sth': '0'},
 'machilid': {'n_is_sth': '0'},
 'macrocephalon': {'n_is_sth': '0'},
 'macrocheira': {'n_is_sth': '0'},
 'macroclemys': {'n_is_sth': '0'},
 'macrodactylus': {'n_is_sth': '0'},
 'macronectes': {'n_is_sth': '0'},
 'macropodidae': {'n_is_sth': '0'},
 'macropus': {'n_is_sth': '0'},
 'macrorhamphosidae': {'n_is_sth': '0'},
 'macrotis': {'n_is_sth': '0'},
 'macrouridae': {'n_is_sth': '0'},
 'macruridae': {'n_is_sth': '0'},
 'madoqua': {'n_is_sth': '0'},
 'madreporaria': {'n_is_sth': '0'},
 'maeandra': {'n_is_sth': '0'},
 'majidae': {'n_is_sth': '0'},
 'makaira': {'n_is_sth': '0'},
 'malacanthidae': {'n_is_sth': '0'},
 'malaclemys': {'n_is_sth': '0'},
 'malaconotinae': {'n_is_sth': '0'},
 'malacopterygii': {'n_is_sth': '0'},
 'malacostraca': {'n_is_sth': '0'},
 'mallotus': {'n_is_sth': '0'},
 'mammal family': {'n_is_sth': '0'},
 'mammal genus': {'n_is_sth': '0'},
 'mandrillus': {'n_is_sth': '0'},
 'manidae': {'n_is_sth': '0'},
 'manteidae': {'n_is_sth': '0'},
 'manteodea': {'n_is_sth': '0'},
 'mantidae': {'n_is_sth': '0'},
 'mantispidae': {'n_is_sth': '0'},
 'marginocephalian': {'n_is_sth': '0'},
 'marginocephalia': {'n_is_sth': '0'},
 'marsupialia': {'n_is_sth': '0'},
 'masticophis': {'n_is_sth': '0'},
 'mastigophora': {'n_is_sth': '0'},
 'mastotermes': {'n_is_sth': '0'},
 'mastotermitidae': {'n_is_sth': '0'},
 'mayetiola': {'n_is_sth': '0'},
 'mazama': {'n_is_sth': '0'},
 'mecoptera': {'n_is_sth': '0'},
 'megabat': {'n_is_sth': '0'},
 'megachile': {'n_is_sth': '0'},
 'megachilidae': {'n_is_sth': '0'},
 'megachiroptera': {'n_is_sth': '0'},
 'megadermatidae': {'n_is_sth': '0'},
 'megaderma': {'n_is_sth': '0'},
 'megalonychidae': {'n_is_sth': '0'},
 'megaloptera': {'n_is_sth': '0'},
 'megalosauridae': {'n_is_sth': '0'},
 'megapodiidae': {'n_is_sth': '0'},
 'megapodius': {'n_is_sth': '0'},
 'megatheriidae': {'n_is_sth': '0'},
 'megatherium': {'n_is_sth': '0'},
 'melanerpes': {'n_is_sth': '0'},
 'melanitta': {'n_is_sth': '0'},
 'melanogrammus': {'n_is_sth': '0'},
 'melanoplus': {'n_is_sth': '0'},
 'melanotis': {'n_is_sth': '0'},
 'meleagrididae': {'n_is_sth': '0'},
 'melinae': {'n_is_sth': '0'},
 'meliphagidae': {'n_is_sth': '0'},
 'mellivora': {'n_is_sth': '0'},
 'melogale': {'n_is_sth': '0'},
 'meloidae': {'n_is_sth': '0'},
 'meloid': {'n_is_sth': '0'},
 'melolontha': {'n_is_sth': '0'},
 'melolonthidae': {'n_is_sth': '0'},
 'melophagus': {'n_is_sth': '0'},
 'melopsittacus': {'n_is_sth': '0'},
 'melospiza': {'n_is_sth': '0'},
 'membracidae': {'n_is_sth': '0'},
 'menopon': {'n_is_sth': '0'},
 'menotyphla': {'n_is_sth': '0'},
 'menticirrhus': {'n_is_sth': '0'},
 'menurae': {'n_is_sth': '0'},
 'menura': {'n_is_sth': '0'},
 'menuridae': {'n_is_sth': '0'},
 'mephitinae': {'n_is_sth': '0'},
 'mephitis': {'n_is_sth': '0'},
 'mercenaria': {'n_is_sth': '0'},
 'merginae': {'n_is_sth': '0'},
 'mergus': {'n_is_sth': '0'},
 'meriones': {'n_is_sth': '0'},
 'meropidae': {'n_is_sth': '0'},
 'merostomata': {'n_is_sth': '0'},
 'mesenchyme': {'n_is_sth': '0'},
 'mesoblast': {'n_is_sth': '0'},
 'mesoderm': {'n_is_sth': '0'},
 'metamere': {'n_is_sth': '0'},
 'metatheria': {'n_is_sth': '0'},
 'microchiroptera': {'n_is_sth': '0'},
 'micrococcaceae': {'n_is_sth': '0'},
 'microdesmidae': {'n_is_sth': '0'},
 'microhylidae': {'n_is_sth': '0'},
 'micropterus': {'n_is_sth': '0'},
 'microstomus': {'n_is_sth': '0'},
 'microtus': {'n_is_sth': '0'},
 'micruroides': {'n_is_sth': '0'},
 'micrurus': {'n_is_sth': '0'},
 'mimidae': {'n_is_sth': '0'},
 'mimus': {'n_is_sth': '0'},
 'miridae': {'n_is_sth': '0'},
 'mobulidae': {'n_is_sth': '0'},
 'molidae': {'n_is_sth': '0'},
 'mollienesia': {'n_is_sth': '0'},
 'mollusca': {'n_is_sth': '0'},
 'mollusk family': {'n_is_sth': '0'},
 'mollusk genus': {'n_is_sth': '0'},
 'molossidae': {'n_is_sth': '0'},
 'molothrus': {'n_is_sth': '0'},
 'molva': {'n_is_sth': '0'},
 'momotidae': {'n_is_sth': '0'},
 'moneron': {'n_is_sth': '0'},
 'monocanthidae': {'n_is_sth': '0'},
 'monocanthus': {'n_is_sth': '0'},
 'monochamus': {'n_is_sth': '0'},
 'monodontidae': {'n_is_sth': '0'},
 'monodon': {'n_is_sth': '0'},
 'monohybrid': {'n_is_sth': '0'},
 'monomorium': {'n_is_sth': '0'},
 'monotremata': {'n_is_sth': '0'},
 'morula': {'n_is_sth': '0'},
 'motacilla': {'n_is_sth': '0'},
 'motacillidae': {'n_is_sth': '0'},
 'mouthpart': {'n_is_sth': '0'},
 'mugilidae': {'n_is_sth': '0'},
 'mugiloidea': {'n_is_sth': '0'},
 'mugil': {'n_is_sth': '0'},
 'mullidae': {'n_is_sth': '0'},
 'mulloidichthys': {'n_is_sth': '0'},
 'mullus': {'n_is_sth': '0'},
 'muntiacus': {'n_is_sth': '0'},
 'muraenidae': {'n_is_sth': '0'},
 'muridae': {'n_is_sth': '0'},
 'muscardinus': {'n_is_sth': '0'},
 'musca': {'n_is_sth': '0'},
 'muscicapa': {'n_is_sth': '0'},
 'muscicapidae': {'n_is_sth': '0'},
 'muscidae': {'n_is_sth': '0'},
 'muscivora': {'n_is_sth': '0'},
 'muscoidea': {'n_is_sth': '0'},
 'musophaga': {'n_is_sth': '0'},
 'musophagidae': {'n_is_sth': '0'},
 'mustelidae': {'n_is_sth': '0'},
 'mustelus': {'n_is_sth': '0'},
 'mus': {'n_is_sth': '0'},
 'mutillidae': {'n_is_sth': '0'},
 'myaceae': {'n_is_sth': '0'},
 'myadestes': {'n_is_sth': '0'},
 'mycetophilidae': {'n_is_sth': '0'},
 'mycobacteriaceae': {'n_is_sth': '0'},
 'mycoplasmataceae': {'n_is_sth': '0'},
 'mycoplasmatales': {'n_is_sth': '0'},
 'mycrosporidia': {'n_is_sth': '0'},
 'mycteria': {'n_is_sth': '0'},
 'mycteroperca': {'n_is_sth': '0'},
 'myctophidae': {'n_is_sth': '0'},
 'myliobatidae': {'n_is_sth': '0'},
 'mylodontidae': {'n_is_sth': '0'},
 'myocastor': {'n_is_sth': '0'},
 'myomorpha': {'n_is_sth': '0'},
 'myopus': {'n_is_sth': '0'},
 'myotis': {'n_is_sth': '0'},
 'myriapoda': {'n_is_sth': '0'},
 'myrmecophaga': {'n_is_sth': '0'},
 'myrmecophagidae': {'n_is_sth': '0'},
 'myrmeleontidae': {'n_is_sth': '0'},
 'myrmeleon': {'n_is_sth': '0'},
 'mysidacea': {'n_is_sth': '0'},
 'mysidae': {'n_is_sth': '0'},
 'mysticeti': {'n_is_sth': '0'},
 'mytilidae': {'n_is_sth': '0'},
 'mytilus': {'n_is_sth': '0'},
 'myxinidae': {'n_is_sth': '0'},
 'myxiniformes': {'n_is_sth': '0'},
 'myxinoidea': {'n_is_sth': '0'},
 'myxobacterales': {'n_is_sth': '0'},
 'myxobacteriaceae': {'n_is_sth': '0'},
 'myxobacteriales': {'n_is_sth': '0'},
 'myxocephalus': {'n_is_sth': '0'},
 'myxophyceae': {'n_is_sth': '0'},
 'naemorhedus': {'n_is_sth': '0'},
 'naja': {'n_is_sth': '0'},
 'nasua': {'n_is_sth': '0'},
 'natantia': {'n_is_sth': '0'},
 'naticidae': {'n_is_sth': '0'},
 'natrix': {'n_is_sth': '0'},
 'naucrates': {'n_is_sth': '0'},
 'nautilidae': {'n_is_sth': '0'},
 'neb': {'n_is_sth': '0'},
 'necturus': {'n_is_sth': '0'},
 'negaprion': {'n_is_sth': '0'},
 'nematocera': {'n_is_sth': '0'},
 'nematoda': {'n_is_sth': '0'},
 'nemertea': {'n_is_sth': '0'},
 'nemertina': {'n_is_sth': '0'},
 'neofiber': {'n_is_sth': '0'},
 'neomys': {'n_is_sth': '0'},
 'neotoma': {'n_is_sth': '0'},
 'nepa': {'n_is_sth': '0'},
 'nephropsidae': {'n_is_sth': '0'},
 'nephrops': {'n_is_sth': '0'},
 'nepidae': {'n_is_sth': '0'},
 'nerita': {'n_is_sth': '0'},
 'neritidae': {'n_is_sth': '0'},
 'neritina': {'n_is_sth': '0'},
 'nerodia': {'n_is_sth': '0'},
 'nervure': {'n_is_sth': '0'},
 'nesokia': {'n_is_sth': '0'},
 'neural tube': {'n_is_sth': '0'},
 'neuroptera': {'n_is_sth': '0'},
 'neurotrichus': {'n_is_sth': '0'},
 'nibbler': {'n_is_sth': '0'},
 'nitrobacteriaceae': {'n_is_sth': '0'},
 'nitrobacter': {'n_is_sth': '0'},
 'noctua': {'n_is_sth': '0'},
 'noctuidae': {'n_is_sth': '0'},
 'nomia': {'n_is_sth': '0'},
 'nostocaceae': {'n_is_sth': '0'},
 'nostoc': {'n_is_sth': '0'},
 'notechis': {'n_is_sth': '0'},
 'notemigonus': {'n_is_sth': '0'},
 'nothosauria': {'n_is_sth': '0'},
 'notochord': {'n_is_sth': '0'},
 'notonectidae': {'n_is_sth': '0'},
 'notophthalmus': {'n_is_sth': '0'},
 'notoryctidae': {'n_is_sth': '0'},
 'notoryctus': {'n_is_sth': '0'},
 'notostraca': {'n_is_sth': '0'},
 'notropis': {'n_is_sth': '0'},
 'nucifraga': {'n_is_sth': '0'},
 'nudibranchia': {'n_is_sth': '0'},
 'numenius': {'n_is_sth': '0'},
 'numida': {'n_is_sth': '0'},
 'numididae': {'n_is_sth': '0'},
 'numidinae': {'n_is_sth': '0'},
 'nummulitidae': {'n_is_sth': '0'},
 'nyctanassa': {'n_is_sth': '0'},
 'nycticebus': {'n_is_sth': '0'},
 'nycticorax': {'n_is_sth': '0'},
 'nyctimene': {'n_is_sth': '0'},
 'nymphalidae': {'n_is_sth': '0'},
 'nymphalis': {'n_is_sth': '0'},
 'nymphicus': {'n_is_sth': '0'},
 'occult': {'n_is_sth': '0'},
 'oceanites': {'n_is_sth': '0'},
 'ochotona': {'n_is_sth': '0'},
 'ochotonidae': {'n_is_sth': '0'},
 'octopoda': {'n_is_sth': '0'},
 'octopodidae': {'n_is_sth': '0'},
 'ocyurus': {'n_is_sth': '0'},
 'odobenidae': {'n_is_sth': '0'},
 'odobenus': {'n_is_sth': '0'},
 'odocoileus': {'n_is_sth': '0'},
 'odonata': {'n_is_sth': '0'},
 'odontaspididae': {'n_is_sth': '0'},
 'odontaspis': {'n_is_sth': '0'},
 'odontoceti': {'n_is_sth': '0'},
 'odontophorus': {'n_is_sth': '0'},
 'oecanthus': {'n_is_sth': '0'},
 'oedogoniaceae': {'n_is_sth': '0'},
 'oedogoniales': {'n_is_sth': '0'},
 'oedogonium': {'n_is_sth': '0'},
 'oenanthe': {'n_is_sth': '0'},
 'oestridae': {'n_is_sth': '0'},
 'ogcocephalidae': {'n_is_sth': '0'},
 'okapia': {'n_is_sth': '0'},
 'oligochaeta': {'n_is_sth': '0'},
 'omasum': {'n_is_sth': '0'},
 'ommastrephes': {'n_is_sth': '0'},
 'omomyid': {'n_is_sth': '0'},
 'onchorynchus': {'n_is_sth': '0'},
 'ondatra': {'n_is_sth': '0'},
 'oniscidae': {'n_is_sth': '0'},
 'oniscus': {'n_is_sth': '0'},
 'onychomys': {'n_is_sth': '0'},
 'onychophoran': {'n_is_sth': '0'},
 'onychophora': {'n_is_sth': '0'},
 'operculum': {'n_is_sth': '0'},
 'opheodrys': {'n_is_sth': '0'},
 'ophidiidae': {'n_is_sth': '0'},
 'ophiodontidae': {'n_is_sth': '0'},
 'ophiophagus': {'n_is_sth': '0'},
 'ophiurida': {'n_is_sth': '0'},
 'ophiuroidea': {'n_is_sth': '0'},
 'opiliones': {'n_is_sth': '0'},
 'opisthobranchia': {'n_is_sth': '0'},
 'opisthocomidae': {'n_is_sth': '0'},
 'opisthocomus': {'n_is_sth': '0'},
 'opisthognathidae': {'n_is_sth': '0'},
 'optic cup': {'n_is_sth': '0'},
 'orchestia': {'n_is_sth': '0'},
 'orchestiidae': {'n_is_sth': '0'},
 'orcinus': {'n_is_sth': '0'},
 'order acarina': {'n_is_sth': '0'},
 'order accipitriformes': {'n_is_sth': '0'},
 'oreamnos': {'n_is_sth': '0'},
 'orectolobidae': {'n_is_sth': '0'},
 'oreortyx': {'n_is_sth': '0'},
 'oriolidae': {'n_is_sth': '0'},
 'oriolus': {'n_is_sth': '0'},
 'ornithischia': {'n_is_sth': '0'},
 'ornithomimid': {'n_is_sth': '0'},
 'ornithopoda': {'n_is_sth': '0'},
 'ornithorhynchidae': {'n_is_sth': '0'},
 'ortalis': {'n_is_sth': '0'},
 'orthopristis': {'n_is_sth': '0'},
 'orthoptera': {'n_is_sth': '0'},
 'orycteropodidae': {'n_is_sth': '0'},
 'orycteropus': {'n_is_sth': '0'},
 'oryzomys': {'n_is_sth': '0'},
 'oscillatoriaceae': {'n_is_sth': '0'},
 'osmeridae': {'n_is_sth': '0'},
 'osmerus': {'n_is_sth': '0'},
 'ostariophysi': {'n_is_sth': '0'},
 'osteichthyes': {'n_is_sth': '0'},
 'osteostraci': {'n_is_sth': '0'},
 'ostraciidae': {'n_is_sth': '0'},
 'ostracoda': {'n_is_sth': '0'},
 'ostracodermi': {'n_is_sth': '0'},
 'ostracoderm': {'n_is_sth': '0'},
 'ostrea': {'n_is_sth': '0'},
 'ostreidae': {'n_is_sth': '0'},
 'otaria': {'n_is_sth': '0'},
 'otariidae': {'n_is_sth': '0'},
 'otus': {'n_is_sth': '0'},
 'ovalipes': {'n_is_sth': '0'},
 'ovibos': {'n_is_sth': '0'},
 'ovipositor': {'n_is_sth': '0'},
 'oviraptorid': {'n_is_sth': '0'},
 'ovis': {'n_is_sth': '0'},
 'oxtail': {'n_is_sth': '0'},
 'oxybelis': {'n_is_sth': '0'},
 'oxylebius': {'n_is_sth': '0'},
 'oxyuranus': {'n_is_sth': '0'},
 'oxyura': {'n_is_sth': '0'},
 'oxyuridae': {'n_is_sth': '0'},
 'pachycephala': {'n_is_sth': '0'},
 'padda': {'n_is_sth': '0'},
 'pagellus': {'n_is_sth': '0'},
 'pagophila': {'n_is_sth': '0'},
 'pagophilus': {'n_is_sth': '0'},
 'pagrus': {'n_is_sth': '0'},
 'paguridae': {'n_is_sth': '0'},
 'pagurus': {'n_is_sth': '0'},
 'palaemonidae': {'n_is_sth': '0'},
 'palinuridae': {'n_is_sth': '0'},
 'pandionidae': {'n_is_sth': '0'},
 'panorpidae': {'n_is_sth': '0'},
 'panthera': {'n_is_sth': '0'},
 'pantotheria': {'n_is_sth': '0'},
 'paprilus': {'n_is_sth': '0'},
 'paracheirodon': {'n_is_sth': '0'},
 'paralichthys': {'n_is_sth': '0'},
 'paralithodes': {'n_is_sth': '0'},
 'paranthias': {'n_is_sth': '0'},
 'parapodium': {'n_is_sth': '0'},
 'parascalops': {'n_is_sth': '0'},
 'paridae': {'n_is_sth': '0'},
 'parophrys': {'n_is_sth': '0'},
 'parula': {'n_is_sth': '0'},
 'parulidae': {'n_is_sth': '0'},
 'passeres': {'n_is_sth': '0'},
 'passeridae': {'n_is_sth': '0'},
 'passeriformes': {'n_is_sth': '0'},
 'pastern': {'n_is_sth': '0'},
 'patellidae': {'n_is_sth': '0'},
 'pauropoda': {'n_is_sth': '0'},
 'pavo': {'n_is_sth': '0'},
 'peccary': {'n_is_sth': '0'},
 'pectinibranchia': {'n_is_sth': '0'},
 'pectinidae': {'n_is_sth': '0'},
 'pectoral fin': {'n_is_sth': '0'},
 'pediculati': {'n_is_sth': '0'},
 'pediculidae': {'n_is_sth': '0'},
 'pedionomus': {'n_is_sth': '0'},
 'pelage': {'n_is_sth': '0'},
 'pelecanidae': {'n_is_sth': '0'},
 'pelecaniformes': {'n_is_sth': '0'},
 'pelecanoididae': {'n_is_sth': '0'},
 'pellicle': {'n_is_sth': '0'},
 'pelobatidae': {'n_is_sth': '0'},
 'pelycosauria': {'n_is_sth': '0'},
 'pembroke': {'n_is_sth': '0'},
 'pempheridae': {'n_is_sth': '0'},
 'pennatulidae': {'n_is_sth': '0'},
 'pentastomida': {'n_is_sth': '0'},
 'peramelidae': {'n_is_sth': '0'},
 'percidae': {'n_is_sth': '0'},
 'perciformes': {'n_is_sth': '0'},
 'percina': {'n_is_sth': '0'},
 'percoidea': {'n_is_sth': '0'},
 'percomorphi': {'n_is_sth': '0'},
 'percophidae': {'n_is_sth': '0'},
 'perdicidae': {'n_is_sth': '0'},
 'perdicinae': {'n_is_sth': '0'},
 'perdix': {'n_is_sth': '0'},
 'peripatidae': {'n_is_sth': '0'},
 'peripatopsidae': {'n_is_sth': '0'},
 'peripatopsis': {'n_is_sth': '0'},
 'periplaneta': {'n_is_sth': '0'},
 'perisoreus': {'n_is_sth': '0'},
 'peristediinae': {'n_is_sth': '0'},
 'peristedion': {'n_is_sth': '0'},
 'peristome': {'n_is_sth': '0'},
 'perodicticus': {'n_is_sth': '0'},
 'perognathus': {'n_is_sth': '0'},
 'petaurista': {'n_is_sth': '0'},
 'petauristidae': {'n_is_sth': '0'},
 'petromyzoniformes': {'n_is_sth': '0'},
 'petromyzontidae': {'n_is_sth': '0'},
 'phacochoerus': {'n_is_sth': '0'},
 'phaeophyceae': {'n_is_sth': '0'},
 'phaeophyta': {'n_is_sth': '0'},
 'phaethontidae': {'n_is_sth': '0'},
 'phalacrocoracidae': {'n_is_sth': '0'},
 'phalaenoptilus': {'n_is_sth': '0'},
 'phalangeridae': {'n_is_sth': '0'},
 'phalangiidae': {'n_is_sth': '0'},
 'phalaropidae': {'n_is_sth': '0'},
 'phalaropus': {'n_is_sth': '0'},
 'pharomacrus': {'n_is_sth': '0'},
 'phascogale': {'n_is_sth': '0'},
 'phasianidae': {'n_is_sth': '0'},
 'phasianid': {'n_is_sth': '0'},
 'phasianus': {'n_is_sth': '0'},
 'phasmatidae': {'n_is_sth': '0'},
 'phasmatodea': {'n_is_sth': '0'},
 'phasmidae': {'n_is_sth': '0'},
 'phasmidia': {'n_is_sth': '0'},
 'philaenus': {'n_is_sth': '0'},
 'phillidae': {'n_is_sth': '0'},
 'philomachus': {'n_is_sth': '0'},
 'phlebotomus': {'n_is_sth': '0'},
 'phoca': {'n_is_sth': '0'},
 'phocidae': {'n_is_sth': '0'},
 'phoenicopteridae': {'n_is_sth': '0'},
 'phoeniculidae': {'n_is_sth': '0'},
 'phoeniculus': {'n_is_sth': '0'},
 'phoenicurus': {'n_is_sth': '0'},
 'pholadidae': {'n_is_sth': '0'},
 'pholidae': {'n_is_sth': '0'},
 'pholidota': {'n_is_sth': '0'},
 'pholis': {'n_is_sth': '0'},
 'phoronida': {'n_is_sth': '0'},
 'phoronidea': {'n_is_sth': '0'},
 'photoblepharon': {'n_is_sth': '0'},
 'phoxinus': {'n_is_sth': '0'},
 'phthiriidae': {'n_is_sth': '0'},
 'phyllidae': {'n_is_sth': '0'},
 'phyllium': {'n_is_sth': '0'},
 'phyllorhynchus': {'n_is_sth': '0'},
 'phylloscopus': {'n_is_sth': '0'},
 'phyllostomatidae': {'n_is_sth': '0'},
 'phyllostomidae': {'n_is_sth': '0'},
 'phyllostomus': {'n_is_sth': '0'},
 'phylloxeridae': {'n_is_sth': '0'},
 'phylum acanthocephala': {'n_is_sth': '0'},
 'phylum annelida': {'n_is_sth': '0'},
 'phylum arthropoda': {'n_is_sth': '0'},
 'phylum aschelminthes': {'n_is_sth': '0'},
 'phylum brachiopoda': {'n_is_sth': '0'},
 'phylum bryozoa': {'n_is_sth': '0'},
 'phylum chaetognatha': {'n_is_sth': '0'},
 'phylum chordata': {'n_is_sth': '0'},
 'phylum cnidaria': {'n_is_sth': '0'},
 'phylum coelenterata': {'n_is_sth': '0'},
 'phylum cryptophyta': {'n_is_sth': '0'},
 'phylum ctenophora': {'n_is_sth': '0'},
 'phylum cycliophora': {'n_is_sth': '0'},
 'phylum echinodermata': {'n_is_sth': '0'},
 'phylum ectoprocta': {'n_is_sth': '0'},
 'phylum entoprocta': {'n_is_sth': '0'},
 'phylum mollusca': {'n_is_sth': '0'},
 'phylum nematoda': {'n_is_sth': '0'},
 'phylum nemertea': {'n_is_sth': '0'},
 'phylum nemertina': {'n_is_sth': '0'},
 'phylum phoronida': {'n_is_sth': '0'},
 'phylum platyhelminthes': {'n_is_sth': '0'},
 'phylum pogonophora': {'n_is_sth': '0'},
 'phylum porifera': {'n_is_sth': '0'},
 'phylum protozoa': {'n_is_sth': '0'},
 'phylum pyrrophyta': {'n_is_sth': '0'},
 'phylum rotifera': {'n_is_sth': '0'},
 'phylum sipuncula': {'n_is_sth': '0'},
 'physalia': {'n_is_sth': '0'},
 'physeteridae': {'n_is_sth': '0'},
 'physeter': {'n_is_sth': '0'},
 'physidae': {'n_is_sth': '0'},
 'phytomastigina': {'n_is_sth': '0'},
 'picariae': {'n_is_sth': '0'},
 'piciformes': {'n_is_sth': '0'},
 'picoides': {'n_is_sth': '0'},
 'pieridae': {'n_is_sth': '0'},
 'pilus': {'n_is_sth': '0'},
 'pinctada': {'n_is_sth': '0'},
 'pineus': {'n_is_sth': '0'},
 'pinguinus': {'n_is_sth': '0'},
 'pinicola': {'n_is_sth': '0'},
 'pinnipedia': {'n_is_sth': '0'},
 'pinniped': {'n_is_sth': '0'},
 'pinnotheres': {'n_is_sth': '0'},
 'pinnotheridae': {'n_is_sth': '0'},
 'pipidae': {'n_is_sth': '0'},
 'pipile': {'n_is_sth': '0'},
 'pipilo': {'n_is_sth': '0'},
 'pipistrellus': {'n_is_sth': '0'},
 'pipridae': {'n_is_sth': '0'},
 'pithecia': {'n_is_sth': '0'},
 'pittidae': {'n_is_sth': '0'},
 'pituophis': {'n_is_sth': '0'},
 'pitymys': {'n_is_sth': '0'},
 'placodermi': {'n_is_sth': '0'},
 'placuna': {'n_is_sth': '0'},
 'planktonic algae': {'n_is_sth': '0'},
 'planococcus': {'n_is_sth': '0'},
 'plasmodiidae': {'n_is_sth': '0'},
 'plastron': {'n_is_sth': '0'},
 'platalea': {'n_is_sth': '0'},
 'platanistidae': {'n_is_sth': '0'},
 'platichthys': {'n_is_sth': '0'},
 'platycephalidae': {'n_is_sth': '0'},
 'platyctenea': {'n_is_sth': '0'},
 'plecoptera': {'n_is_sth': '0'},
 'plecotus': {'n_is_sth': '0'},
 'plectognathi': {'n_is_sth': '0'},
 'plectrophenax': {'n_is_sth': '0'},
 'pleopod': {'n_is_sth': '0'},
 'plesiosauria': {'n_is_sth': '0'},
 'plethodontidae': {'n_is_sth': '0'},
 'plethodont': {'n_is_sth': '0'},
 'plethodon': {'n_is_sth': '0'},
 'pleuronectes': {'n_is_sth': '0'},
 'plicatoperipatus': {'n_is_sth': '0'},
 'ploceidae': {'n_is_sth': '0'},
 'ploceus': {'n_is_sth': '0'},
 'pluvialis': {'n_is_sth': '0'},
 'podargidae': {'n_is_sth': '0'},
 'podargus': {'n_is_sth': '0'},
 'podiceps': {'n_is_sth': '0'},
 'podicipedidae': {'n_is_sth': '0'},
 'podicipediformes': {'n_is_sth': '0'},
 'podicipitiformes': {'n_is_sth': '0'},
 'podilymbus': {'n_is_sth': '0'},
 'poeciliidae': {'n_is_sth': '0'},
 'poeciliid': {'n_is_sth': '0'},
 'poecilocapsus': {'n_is_sth': '0'},
 'poephila': {'n_is_sth': '0'},
 'pogonophora': {'n_is_sth': '0'},
 'polioptila': {'n_is_sth': '0'},
 'pollachius': {'n_is_sth': '0'},
 'pollyfish': {'n_is_sth': '0'},
 'polyangiaceae': {'n_is_sth': '0'},
 'polyangium': {'n_is_sth': '0'},
 'polychaeta': {'n_is_sth': '0'},
 'polycirrus': {'n_is_sth': '0'},
 'polydactylus': {'n_is_sth': '0'},
 'polyergus': {'n_is_sth': '0'},
 'polygonia': {'n_is_sth': '0'},
 'polymastigina': {'n_is_sth': '0'},
 'polymorph': {'n_is_sth': '0'},
 'polynemidae': {'n_is_sth': '0'},
 'polyodontidae': {'n_is_sth': '0'},
 'polyodon': {'n_is_sth': '0'},
 'polypedates': {'n_is_sth': '0'},
 'polypedatidae': {'n_is_sth': '0'},
 'polyplacophora': {'n_is_sth': '0'},
 'polyprion': {'n_is_sth': '0'},
 'pomacanthus': {'n_is_sth': '0'},
 'pomacentridae': {'n_is_sth': '0'},
 'pomacentrus': {'n_is_sth': '0'},
 'pomatomidae': {'n_is_sth': '0'},
 'pomoxis': {'n_is_sth': '0'},
 'pongidae': {'n_is_sth': '0'},
 'pooecetes': {'n_is_sth': '0'},
 'popillia': {'n_is_sth': '0'},
 'porcellionidae': {'n_is_sth': '0'},
 'porphyrio': {'n_is_sth': '0'},
 'portunidae': {'n_is_sth': '0'},
 'portunus': {'n_is_sth': '0'},
 'porzana': {'n_is_sth': '0'},
 'potamogalidae': {'n_is_sth': '0'},
 'potamophis': {'n_is_sth': '0'},
 'potoroinae': {'n_is_sth': '0'},
 'potorous': {'n_is_sth': '0'},
 'potos': {'n_is_sth': '0'},
 'pouched mammal': {'n_is_sth': '0'},
 'pouf': {'n_is_sth': '0'},
 'preen gland': {'n_is_sth': '0'},
 'priacanthidae': {'n_is_sth': '0'},
 'primary feather': {'n_is_sth': '0'},
 'primary quill': {'n_is_sth': '0'},
 'primum mobile': {'n_is_sth': '0'},
 'priodontes': {'n_is_sth': '0'},
 'prionace': {'n_is_sth': '0'},
 'prionotus': {'n_is_sth': '0'},
 'pristidae': {'n_is_sth': '0'},
 'pristis': {'n_is_sth': '0'},
 'proboscidea': {'n_is_sth': '0'},
 'proboscidian': {'n_is_sth': '0'},
 'proboscis worm': {'n_is_sth': '0'},
 'procavia': {'n_is_sth': '0'},
 'procaviidae': {'n_is_sth': '0'},
 'procellaria': {'n_is_sth': '0'},
 'procellariidae': {'n_is_sth': '0'},
 'procellariiformes': {'n_is_sth': '0'},
 'prociphilus': {'n_is_sth': '0'},
 'procyonidae': {'n_is_sth': '0'},
 'procyon': {'n_is_sth': '0'},
 'prosauropoda': {'n_is_sth': '0'},
 'prosimii': {'n_is_sth': '0'},
 'proteidae': {'n_is_sth': '0'},
 'prothorax': {'n_is_sth': '0'},
 'protoctist family': {'n_is_sth': '0'},
 'protoctist genus': {'n_is_sth': '0'},
 'protoctist order': {'n_is_sth': '0'},
 'protoctista': {'n_is_sth': '0'},
 'prototheria': {'n_is_sth': '0'},
 'protura': {'n_is_sth': '0'},
 'prunellidae': {'n_is_sth': '0'},
 'psalterium': {'n_is_sth': '0'},
 'psephurus': {'n_is_sth': '0'},
 'psetta': {'n_is_sth': '0'},
 'psettichthys': {'n_is_sth': '0'},
 'pseudacris': {'n_is_sth': '0'},
 'pseudaletia': {'n_is_sth': '0'},
 'pseudechis': {'n_is_sth': '0'},
 'pseudemys': {'n_is_sth': '0'},
 'pseudococcidae': {'n_is_sth': '0'},
 'pseudococcus': {'n_is_sth': '0'},
 'pseudomonadales': {'n_is_sth': '0'},
 'pseudopleuronectes': {'n_is_sth': '0'},
 'pseudopodium': {'n_is_sth': '0'},
 'pseudopod': {'n_is_sth': '0'},
 'pseudoryx': {'n_is_sth': '0'},
 'pseudoscorpiones': {'n_is_sth': '0'},
 'pseudoscorpionida': {'n_is_sth': '0'},
 'psithyrus': {'n_is_sth': '0'},
 'psittacidae': {'n_is_sth': '0'},
 'psittaciformes': {'n_is_sth': '0'},
 'psocidae': {'n_is_sth': '0'},
 'psocoptera': {'n_is_sth': '0'},
 'psophia': {'n_is_sth': '0'},
 'psophiidae': {'n_is_sth': '0'},
 'psychodidae': {'n_is_sth': '0'},
 'psyllidae': {'n_is_sth': '0'},
 'pteriidae': {'n_is_sth': '0'},
 'pterodactylus': {'n_is_sth': '0'},
 'pteropus': {'n_is_sth': '0'},
 'pterosauria': {'n_is_sth': '0'},
 'ptyas': {'n_is_sth': '0'},
 'pulex': {'n_is_sth': '0'},
 'pulmonata': {'n_is_sth': '0'},
 'pycnogonida': {'n_is_sth': '0'},
 'pygopodidae': {'n_is_sth': '0'},
 'pyralidae': {'n_is_sth': '0'},
 'pyralididae': {'n_is_sth': '0'},
 'pyrrhocoridae': {'n_is_sth': '0'},
 'pyrrophyta': {'n_is_sth': '0'},
 'quill feather': {'n_is_sth': '0'},
 'quiscalus': {'n_is_sth': '0'},
 'rachycentridae': {'n_is_sth': '0'},
 'rachycentron': {'n_is_sth': '0'},
 'rajidae': {'n_is_sth': '0'},
 'rajiformes': {'n_is_sth': '0'},
 'rallidae': {'n_is_sth': '0'},
 'ramphastidae': {'n_is_sth': '0'},
 'ranidae': {'n_is_sth': '0'},
 'raphicerus': {'n_is_sth': '0'},
 'raphidae': {'n_is_sth': '0'},
 'raphidiidae': {'n_is_sth': '0'},
 'raphus': {'n_is_sth': '0'},
 'rasher': {'n_is_sth': '0'},
 'ratitae': {'n_is_sth': '0'},
 'recurvirostra': {'n_is_sth': '0'},
 'recurvirostridae': {'n_is_sth': '0'},
 'reduviidae': {'n_is_sth': '0'},
 'regalecidae': {'n_is_sth': '0'},
 'reglaecus': {'n_is_sth': '0'},
 'regulus': {'n_is_sth': '0'},
 'reithrodontomys': {'n_is_sth': '0'},
 'remilegia': {'n_is_sth': '0'},
 'reptantia': {'n_is_sth': '0'},
 'reptile genus': {'n_is_sth': '0'},
 'reticulum': {'n_is_sth': '0'},
 'rhabdoviridae': {'n_is_sth': '0'},
 'rhagoletis': {'n_is_sth': '0'},
 'rheidae': {'n_is_sth': '0'},
 'rheiformes': {'n_is_sth': '0'},
 'rhincodontidae': {'n_is_sth': '0'},
 'rhincodon': {'n_is_sth': '0'},
 'rhinobatidae': {'n_is_sth': '0'},
 'rhinocerotidae': {'n_is_sth': '0'},
 'rhinolophidae': {'n_is_sth': '0'},
 'rhinonicteris': {'n_is_sth': '0'},
 'rhinoptera': {'n_is_sth': '0'},
 'rhinotermitidae': {'n_is_sth': '0'},
 'rhizobiaceae': {'n_is_sth': '0'},
 'rhizopoda': {'n_is_sth': '0'},
 'rhodophyceae': {'n_is_sth': '0'},
 'rhodophyta': {'n_is_sth': '0'},
 'rhodymeniaceae': {'n_is_sth': '0'},
 'rhodymenia': {'n_is_sth': '0'},
 'rhyacotriton': {'n_is_sth': '0'},
 'rhynchocephalia': {'n_is_sth': '0'},
 'rickettsiaceae': {'n_is_sth': '0'},
 'rickettsiales': {'n_is_sth': '0'},
 'ring rot bacteria': {'n_is_sth': '0'},
 'ringlet': {'n_is_sth': '0'},
 'riparia': {'n_is_sth': '0'},
 'rivera': {'n_is_sth': '0'},
 'rivulus': {'n_is_sth': '0'},
 'roccus': {'n_is_sth': '0'},
 'rodentia': {'n_is_sth': '0'},
 'rodolia': {'n_is_sth': '0'},
 'rumen': {'n_is_sth': '0'},
 'ruminantia': {'n_is_sth': '0'},
 'rupicapra': {'n_is_sth': '0'},
 'rynchopidae': {'n_is_sth': '0'},
 'rynchops': {'n_is_sth': '0'},
 'rypticus': {'n_is_sth': '0'},
 'saddle feather': {'n_is_sth': '0'},
 'saddle hackle': {'n_is_sth': '0'},
 'sagittariidae': {'n_is_sth': '0'},
 'sagitta': {'n_is_sth': '0'},
 'saimiri': {'n_is_sth': '0'},
 'saint john': {'n_is_sth': '0'},
 'salamandridae': {'n_is_sth': '0'},
 'salientia': {'n_is_sth': '0'},
 'salmonidae': {'n_is_sth': '0'},
 'salmo': {'n_is_sth': '0'},
 'salpidae': {'n_is_sth': '0'},
 'sand stargazer': {'n_is_sth': '0'},
 'sarcocystis': {'n_is_sth': '0'},
 'sarcodina': {'n_is_sth': '0'},
 'sarcoptes': {'n_is_sth': '0'},
 'sarcoptidae': {'n_is_sth': '0'},
 'sarcosporidia': {'n_is_sth': '0'},
 'sardinops': {'n_is_sth': '0'},
 'saturnia': {'n_is_sth': '0'},
 'saturniidae': {'n_is_sth': '0'},
 'satyridae': {'n_is_sth': '0'},
 'sauria': {'n_is_sth': '0'},
 'saurischian': {'n_is_sth': '0'},
 'saurischia': {'n_is_sth': '0'},
 'sauropoda': {'n_is_sth': '0'},
 'sauropodomorpha': {'n_is_sth': '0'},
 'sauropterygia': {'n_is_sth': '0'},
 'saxicola': {'n_is_sth': '0'},
 'scallop shell': {'n_is_sth': '0'},
 'scandentia': {'n_is_sth': '0'},
 'scaphiopus': {'n_is_sth': '0'},
 'scaphopoda': {'n_is_sth': '0'},
 'scarabaeidae': {'n_is_sth': '0'},
 'scardinius': {'n_is_sth': '0'},
 'scaridae': {'n_is_sth': '0'},
 'sceliphron': {'n_is_sth': '0'},
 'sceloglaux': {'n_is_sth': '0'},
 'sceloporus': {'n_is_sth': '0'},
 'schistosomatidae': {'n_is_sth': '0'},
 'schizophyceae': {'n_is_sth': '0'},
 'schizophyta': {'n_is_sth': '0'},
 'sciaena': {'n_is_sth': '0'},
 'sciaenidae': {'n_is_sth': '0'},
 'sciaenops': {'n_is_sth': '0'},
 'scincidae': {'n_is_sth': '0'},
 'scincus': {'n_is_sth': '0'},
 'sciuridae': {'n_is_sth': '0'},
 'sciuromorpha': {'n_is_sth': '0'},
 'sciurus': {'n_is_sth': '0'},
 'sclerite': {'n_is_sth': '0'},
 'scolopacidae': {'n_is_sth': '0'},
 'scolopax': {'n_is_sth': '0'},
 'scolytidae': {'n_is_sth': '0'},
 'scolytus': {'n_is_sth': '0'},
 'scombresocidae': {'n_is_sth': '0'},
 'scombresox': {'n_is_sth': '0'},
 'scombridae': {'n_is_sth': '0'},
 'scombroidea': {'n_is_sth': '0'},
 'scooter': {'n_is_sth': '0'},
 'scopes': {'n_is_sth': '0'},
 'scophthalmus': {'n_is_sth': '0'},
 'scorpaena': {'n_is_sth': '0'},
 'scorpaenidae': {'n_is_sth': '0'},
 'scorpionida': {'n_is_sth': '0'},
 'scute': {'n_is_sth': '0'},
 'scyliorhinidae': {'n_is_sth': '0'},
 'scyphozoa': {'n_is_sth': '0'},
 'sebastodes': {'n_is_sth': '0'},
 'second stomach': {'n_is_sth': '0'},
 'segmentation cavity': {'n_is_sth': '0'},
 'seiurus': {'n_is_sth': '0'},
 'selachii': {'n_is_sth': '0'},
 'selar': {'n_is_sth': '0'},
 'selenarctos': {'n_is_sth': '0'},
 'sensory hair': {'n_is_sth': '0'},
 'sepiidae': {'n_is_sth': '0'},
 'sericterium': {'n_is_sth': '0'},
 'serictery': {'n_is_sth': '0'},
 'serinus': {'n_is_sth': '0'},
 'seriola': {'n_is_sth': '0'},
 'seriphus': {'n_is_sth': '0'},
 'serpentes': {'n_is_sth': '0'},
 'serranidae': {'n_is_sth': '0'},
 'serranus': {'n_is_sth': '0'},
 'serrasalmus': {'n_is_sth': '0'},
 'serratia': {'n_is_sth': '0'},
 'setophaga': {'n_is_sth': '0'},
 'sewing needle': {'n_is_sth': '0'},
 'shadfly': {'n_is_sth': '0'},
 'shetland': {'n_is_sth': '0'},
 'shore bird': {'n_is_sth': '0'},
 'shute': {'n_is_sth': '0'},
 'sialia': {'n_is_sth': '0'},
 'sialidae': {'n_is_sth': '0'},
 'sialis': {'n_is_sth': '0'},
 'sickle feather': {'n_is_sth': '0'},
 'sigmodon': {'n_is_sth': '0'},
 'silk gland': {'n_is_sth': '0'},
 'sillago': {'n_is_sth': '0'},
 'siluridae': {'n_is_sth': '0'},
 'siluriformes': {'n_is_sth': '0'},
 'silurus': {'n_is_sth': '0'},
 'silver whiting': {'n_is_sth': '0'},
 'simuliidae': {'n_is_sth': '0'},
 'simulium': {'n_is_sth': '0'},
 'siphonophora': {'n_is_sth': '0'},
 'sirenia': {'n_is_sth': '0'},
 'sistrurus': {'n_is_sth': '0'},
 'sisyridae': {'n_is_sth': '0'},
 'sitophylus': {'n_is_sth': '0'},
 'sitotroga': {'n_is_sth': '0'},
 'sitta': {'n_is_sth': '0'},
 'sittidae': {'n_is_sth': '0'},
 'smuts': {'n_is_sth': '0'},
 'soleidae': {'n_is_sth': '0'},
 'solenichthyes': {'n_is_sth': '0'},
 'solenogaster': {'n_is_sth': '0'},
 'solenogastres': {'n_is_sth': '0'},
 'solenopsis': {'n_is_sth': '0'},
 'somateria': {'n_is_sth': '0'},
 'somite': {'n_is_sth': '0'},
 'sonora': {'n_is_sth': '0'},
 'sorex': {'n_is_sth': '0'},
 'soricidae': {'n_is_sth': '0'},
 'spalacidae': {'n_is_sth': '0'},
 'sparidae': {'n_is_sth': '0'},
 'spatangoida': {'n_is_sth': '0'},
 'spermophilus': {'n_is_sth': '0'},
 'sphecidae': {'n_is_sth': '0'},
 'sphecius': {'n_is_sth': '0'},
 'sphecoidea': {'n_is_sth': '0'},
 'sphecotheres': {'n_is_sth': '0'},
 'sphenisciformes': {'n_is_sth': '0'},
 'spheniscus': {'n_is_sth': '0'},
 'sphingidae': {'n_is_sth': '0'},
 'sphyraenidae': {'n_is_sth': '0'},
 'sphyrapicus': {'n_is_sth': '0'},
 'sphyrna': {'n_is_sth': '0'},
 'sphyrnidae': {'n_is_sth': '0'},
 'spilogale': {'n_is_sth': '0'},
 'spirillaceae': {'n_is_sth': '0'},
 'spirochaetaceae': {'n_is_sth': '0'},
 'spirochaetales': {'n_is_sth': '0'},
 'spirulidae': {'n_is_sth': '0'},
 'splint bone': {'n_is_sth': '0'},
 'spodoptera': {'n_is_sth': '0'},
 'sponge genus': {'n_is_sth': '0'},
 'spurious wing': {'n_is_sth': '0'},
 'squalidae': {'n_is_sth': '0'},
 'squamata': {'n_is_sth': '0'},
 'squama': {'n_is_sth': '0'},
 'squatina': {'n_is_sth': '0'},
 'squatinidae': {'n_is_sth': '0'},
 'squillidae': {'n_is_sth': '0'},
 'staphylinidae': {'n_is_sth': '0'},
 'steamroller': {'n_is_sth': '0'},
 'steatornis': {'n_is_sth': '0'},
 'steatornithidae': {'n_is_sth': '0'},
 'steganopus': {'n_is_sth': '0'},
 'stercorarius': {'n_is_sth': '0'},
 'sterna': {'n_is_sth': '0'},
 'stichaeidae': {'n_is_sth': '0'},
 'stizidae': {'n_is_sth': '0'},
 'stizostedion': {'n_is_sth': '0'},
 'storeria': {'n_is_sth': '0'},
 'strepsirhini': {'n_is_sth': '0'},
 'streptomycetaceae': {'n_is_sth': '0'},
 'strigidae': {'n_is_sth': '0'},
 'strigiformes': {'n_is_sth': '0'},
 'strombidae': {'n_is_sth': '0'},
 'strombus': {'n_is_sth': '0'},
 'struthionidae': {'n_is_sth': '0'},
 'struthioniformes': {'n_is_sth': '0'},
 'strymon': {'n_is_sth': '0'},
 'sturnella': {'n_is_sth': '0'},
 'sturnidae': {'n_is_sth': '0'},
 'sturnus': {'n_is_sth': '0'},
 'stylet': {'n_is_sth': '0'},
 'subclass acnidosporidia': {'n_is_sth': '0'},
 'subclass actinopoda': {'n_is_sth': '0'},
 'subclass amphineura': {'n_is_sth': '0'},
 'subclass anapsida': {'n_is_sth': '0'},
 'subclass archaeornithes': {'n_is_sth': '0'},
 'subclass archosauria': {'n_is_sth': '0'},
 'subclass branchiopoda': {'n_is_sth': '0'},
 'subclass cirripedia': {'n_is_sth': '0'},
 'subclass cnidosporidia': {'n_is_sth': '0'},
 'subclass copepoda': {'n_is_sth': '0'},
 'subclass crossopterygii': {'n_is_sth': '0'},
 'subclass diapsida': {'n_is_sth': '0'},
 'subclass dibranchiata': {'n_is_sth': '0'},
 'subclass dibranchia': {'n_is_sth': '0'},
 'subclass dipnoi': {'n_is_sth': '0'},
 'subclass elasmobranchii': {'n_is_sth': '0'},
 'subclass entomostraca': {'n_is_sth': '0'},
 'subclass euryalida': {'n_is_sth': '0'},
 'subclass eutheria': {'n_is_sth': '0'},
 'subclass exopterygota': {'n_is_sth': '0'},
 'subclass holocephali': {'n_is_sth': '0'},
 'subclass infusoria': {'n_is_sth': '0'},
 'subclass lepidosauria': {'n_is_sth': '0'},
 'subclass malacostraca': {'n_is_sth': '0'},
 'subclass metatheria': {'n_is_sth': '0'},
 'subclass ophiurida': {'n_is_sth': '0'},
 'subclass opisthobranchia': {'n_is_sth': '0'},
 'subclass ostracoda': {'n_is_sth': '0'},
 'subclass pantotheria': {'n_is_sth': '0'},
 'subclass phytomastigina': {'n_is_sth': '0'},
 'subclass prototheria': {'n_is_sth': '0'},
 'subclass rhizopoda': {'n_is_sth': '0'},
 'subclass selachii': {'n_is_sth': '0'},
 'subclass synapsida': {'n_is_sth': '0'},
 'subclass teleostei': {'n_is_sth': '0'},
 'subclass telosporidia': {'n_is_sth': '0'},
 'subclass zoomastigina': {'n_is_sth': '0'},
 'subfamily anserinae': {'n_is_sth': '0'},
 'subfamily bassariscidae': {'n_is_sth': '0'},
 'subfamily bovinae': {'n_is_sth': '0'},
 'subfamily carduelinae': {'n_is_sth': '0'},
 'subfamily cetoniidae': {'n_is_sth': '0'},
 'subfamily dorylinae': {'n_is_sth': '0'},
 'subfamily emberizidae': {'n_is_sth': '0'},
 'subfamily emberizinae': {'n_is_sth': '0'},
 'subfamily garrulinae': {'n_is_sth': '0'},
 'subfamily gerbillinae': {'n_is_sth': '0'},
 'subfamily hydromyinae': {'n_is_sth': '0'},
 'subfamily loriinae': {'n_is_sth': '0'},
 'subfamily lutrinae': {'n_is_sth': '0'},
 'subfamily malaconotinae': {'n_is_sth': '0'},
 'subfamily melinae': {'n_is_sth': '0'},
 'subfamily melolonthidae': {'n_is_sth': '0'},
 'subfamily mephitinae': {'n_is_sth': '0'},
 'subfamily merginae': {'n_is_sth': '0'},
 'subfamily numididae': {'n_is_sth': '0'},
 'subfamily numidinae': {'n_is_sth': '0'},
 'subfamily perdicidae': {'n_is_sth': '0'},
 'subfamily perdicinae': {'n_is_sth': '0'},
 'subfamily peristediinae': {'n_is_sth': '0'},
 'subfamily petauristidae': {'n_is_sth': '0'},
 'subfamily potoroinae': {'n_is_sth': '0'},
 'subfamily pythoninae': {'n_is_sth': '0'},
 'subfamily sterninae': {'n_is_sth': '0'},
 'subfamily sylviinae': {'n_is_sth': '0'},
 'subfamily triglinae': {'n_is_sth': '0'},
 'subfamily turdinae': {'n_is_sth': '0'},
 'suborder alcyonacea': {'n_is_sth': '0'},
 'suborder anisoptera': {'n_is_sth': '0'},
 'suborder anseres': {'n_is_sth': '0'},
 'suborder anthropoidea': {'n_is_sth': '0'},
 'suborder blattaria': {'n_is_sth': '0'},
 'suborder blattodea': {'n_is_sth': '0'},
 'suborder blennioidea': {'n_is_sth': '0'},
 'suborder brachyura': {'n_is_sth': '0'},
 'suborder cephalaspida': {'n_is_sth': '0'},
 'suborder ceratopsia': {'n_is_sth': '0'},
 'suborder charadrii': {'n_is_sth': '0'},
 'suborder clamatores': {'n_is_sth': '0'},
 'suborder euronithopoda': {'n_is_sth': '0'},
 'suborder eurylaimi': {'n_is_sth': '0'},
 'suborder gorgonacea': {'n_is_sth': '0'},
 'suborder gorgoniacea': {'n_is_sth': '0'},
 'suborder heteroptera': {'n_is_sth': '0'},
 'suborder heterostraci': {'n_is_sth': '0'},
 'suborder homoptera': {'n_is_sth': '0'},
 'suborder hyperoartia': {'n_is_sth': '0'},
 'suborder hyperotreta': {'n_is_sth': '0'},
 'suborder hystricomorpha': {'n_is_sth': '0'},
 'suborder lacertilia': {'n_is_sth': '0'},
 'suborder lemuroidea': {'n_is_sth': '0'},
 'suborder lipotyphla': {'n_is_sth': '0'},
 'suborder maniraptora': {'n_is_sth': '0'},
 'suborder manteodea': {'n_is_sth': '0'},
 'suborder marginocephalia': {'n_is_sth': '0'},
 'suborder megachiroptera': {'n_is_sth': '0'},
 'suborder megaloptera': {'n_is_sth': '0'},
 'suborder menotyphla': {'n_is_sth': '0'},
 'suborder menurae': {'n_is_sth': '0'},
 'suborder microchiroptera': {'n_is_sth': '0'},
 'suborder mugiloidea': {'n_is_sth': '0'},
 'suborder myomorpha': {'n_is_sth': '0'},
 'suborder mysticeti': {'n_is_sth': '0'},
 'suborder myxiniformes': {'n_is_sth': '0'},
 'suborder myxinoidei': {'n_is_sth': '0'},
 'suborder natantia': {'n_is_sth': '0'},
 'suborder nematocera': {'n_is_sth': '0'},
 'suborder nothosauria': {'n_is_sth': '0'},
 'suborder odontoceti': {'n_is_sth': '0'},
 'suborder ophidia': {'n_is_sth': '0'},
 'suborder ornithopoda': {'n_is_sth': '0'},
 'suborder oscines': {'n_is_sth': '0'},
 'suborder osteostraci': {'n_is_sth': '0'},
 'suborder otides': {'n_is_sth': '0'},
 'suborder passeres': {'n_is_sth': '0'},
 'suborder percoidea': {'n_is_sth': '0'},
 'suborder petromyzoniformes': {'n_is_sth': '0'},
 'suborder pinnipedia': {'n_is_sth': '0'},
 'suborder plesiosauria': {'n_is_sth': '0'},
 'suborder prosauropoda': {'n_is_sth': '0'},
 'suborder prosimii': {'n_is_sth': '0'},
 'suborder reptantia': {'n_is_sth': '0'},
 'suborder ruminantia': {'n_is_sth': '0'},
 'suborder sauria': {'n_is_sth': '0'},
 'suborder sauropoda': {'n_is_sth': '0'},
 'suborder sauropodomorpha': {'n_is_sth': '0'},
 'suborder sciuromorpha': {'n_is_sth': '0'},
 'suborder scombroidea': {'n_is_sth': '0'},
 'suborder serpentes': {'n_is_sth': '0'},
 'suborder strepsirhini': {'n_is_sth': '0'},
 'suborder tarsioidea': {'n_is_sth': '0'},
 'suborder theropoda': {'n_is_sth': '0'},
 'suborder thyreophora': {'n_is_sth': '0'},
 'suborder tyranni': {'n_is_sth': '0'},
 'suborder xenarthra': {'n_is_sth': '0'},
 'suborder zygoptera': {'n_is_sth': '0'},
 'suidae': {'n_is_sth': '0'},
 'sula': {'n_is_sth': '0'},
 'sulidae': {'n_is_sth': '0'},
 'superclass agnatha': {'n_is_sth': '0'},
 'superclass chelicerata': {'n_is_sth': '0'},
 'superclass gnathostomata': {'n_is_sth': '0'},
 'superclass myriapoda': {'n_is_sth': '0'},
 'superfamily aphidoidea': {'n_is_sth': '0'},
 'superfamily apoidea': {'n_is_sth': '0'},
 'superfamily coccoidea': {'n_is_sth': '0'},
 'superfamily hominoidea': {'n_is_sth': '0'},
 'superfamily lamellicornia': {'n_is_sth': '0'},
 'superfamily platyrrhini': {'n_is_sth': '0'},
 'superfamily sphecoidea': {'n_is_sth': '0'},
 'superfamily tineoidea': {'n_is_sth': '0'},
 'superfamily tyrannidae': {'n_is_sth': '0'},
 'superorder acanthopterygii': {'n_is_sth': '0'},
 'superorder labyrinthodonta': {'n_is_sth': '0'},
 'superorder labyrinthodontia': {'n_is_sth': '0'},
 'superorder malacopterygii': {'n_is_sth': '0'},
 'superorder ratitae': {'n_is_sth': '0'},
 "swan's down": {'n_is_sth': '0'},
 'swim bladder': {'n_is_sth': '0'},
 'swimmeret': {'n_is_sth': '0'},
 'sylviidae': {'n_is_sth': '0'},
 'sylviinae': {'n_is_sth': '0'},
 'symphalangus': {'n_is_sth': '0'},
 'symphyla': {'n_is_sth': '0'},
 'synagrops': {'n_is_sth': '0'},
 'synapsida': {'n_is_sth': '0'},
 'synapsid': {'n_is_sth': '0'},
 'syngnathidae': {'n_is_sth': '0'},
 'syngnathus': {'n_is_sth': '0'},
 'syrrhaptes': {'n_is_sth': '0'},
 'tabanidae': {'n_is_sth': '0'},
 'tachinidae': {'n_is_sth': '0'},
 'tachyglossidae': {'n_is_sth': '0'},
 'tachyglossus': {'n_is_sth': '0'},
 'tachypleus': {'n_is_sth': '0'},
 'taeniidae': {'n_is_sth': '0'},
 'tail feather': {'n_is_sth': '0'},
 'tail fin': {'n_is_sth': '0'},
 'talpidae': {'n_is_sth': '0'},
 'tapiridae': {'n_is_sth': '0'},
 'tapirus': {'n_is_sth': '0'},
 'tardigrada': {'n_is_sth': '0'},
 'tarsiidae': {'n_is_sth': '0'},
 'tarsioidea': {'n_is_sth': '0'},
 'tarsius': {'n_is_sth': '0'},
 'tautogolabrus': {'n_is_sth': '0'},
 'taxidea': {'n_is_sth': '0'},
 'tayassu': {'n_is_sth': '0'},
 'telosporidia': {'n_is_sth': '0'},
 'temnospondyli': {'n_is_sth': '0'},
 'tenebrionidae': {'n_is_sth': '0'},
 'tenrecidae': {'n_is_sth': '0'},
 'tentaculata': {'n_is_sth': '0'},
 'tenthredinidae': {'n_is_sth': '0'},
 'terebella': {'n_is_sth': '0'},
 'teredinidae': {'n_is_sth': '0'},
 'termitidae': {'n_is_sth': '0'},
 'testudines': {'n_is_sth': '0'},
 'testudinidae': {'n_is_sth': '0'},
 'testudo': {'n_is_sth': '0'},
 'tetragonurus': {'n_is_sth': '0'},
 'tetranychidae': {'n_is_sth': '0'},
 'tetraodontidae': {'n_is_sth': '0'},
 'tetraonidae': {'n_is_sth': '0'},
 'tetrapturus': {'n_is_sth': '0'},
 'tettigoniidae': {'n_is_sth': '0'},
 'thalassoma': {'n_is_sth': '0'},
 'thaliacea': {'n_is_sth': '0'},
 'thamnophilus': {'n_is_sth': '0'},
 'thecodontia': {'n_is_sth': '0'},
 'theraphosidae': {'n_is_sth': '0'},
 'therapsida': {'n_is_sth': '0'},
 'theridiidae': {'n_is_sth': '0'},
 'thermobia': {'n_is_sth': '0'},
 'theropoda': {'n_is_sth': '0'},
 'third stomach': {'n_is_sth': '0'},
 'thomomys': {'n_is_sth': '0'},
 'threskiornis': {'n_is_sth': '0'},
 'threskiornithidae': {'n_is_sth': '0'},
 'thripidae': {'n_is_sth': '0'},
 'thysanoptera': {'n_is_sth': '0'},
 'thysanura': {'n_is_sth': '0'},
 'timaliidae': {'n_is_sth': '0'},
 'tinamidae': {'n_is_sth': '0'},
 'tinamiformes': {'n_is_sth': '0'},
 'tinca': {'n_is_sth': '0'},
 'tinea': {'n_is_sth': '0'},
 'tineidae': {'n_is_sth': '0'},
 'tineoidea': {'n_is_sth': '0'},
 'tingidae': {'n_is_sth': '0'},
 'tipulidae': {'n_is_sth': '0'},
 'todidae': {'n_is_sth': '0'},
 'todus': {'n_is_sth': '0'},
 'togaviridae': {'n_is_sth': '0'},
 'tolypeutes': {'n_is_sth': '0'},
 'tomistoma': {'n_is_sth': '0'},
 'torpedinidae': {'n_is_sth': '0'},
 'torpediniformes': {'n_is_sth': '0'},
 'tortricidae': {'n_is_sth': '0'},
 'toxostoma': {'n_is_sth': '0'},
 'toxotes': {'n_is_sth': '0'},
 'toxotidae': {'n_is_sth': '0'},
 'trachinotus': {'n_is_sth': '0'},
 'trachipterus': {'n_is_sth': '0'},
 'trachurus': {'n_is_sth': '0'},
 'tragulidae': {'n_is_sth': '0'},
 'triaenodon': {'n_is_sth': '0'},
 'triakidae': {'n_is_sth': '0'},
 'trialeurodes': {'n_is_sth': '0'},
 'triatoma': {'n_is_sth': '0'},
 'tribolium': {'n_is_sth': '0'},
 'tribonema': {'n_is_sth': '0'},
 'trichechidae': {'n_is_sth': '0'},
 'trichechus': {'n_is_sth': '0'},
 'trichiuridae': {'n_is_sth': '0'},
 'trichodesmium': {'n_is_sth': '0'},
 'trichodontidae': {'n_is_sth': '0'},
 'trichophaga': {'n_is_sth': '0'},
 'trichoptera': {'n_is_sth': '0'},
 'trichosurus': {'n_is_sth': '0'},
 'trichys': {'n_is_sth': '0'},
 'tridacna': {'n_is_sth': '0'},
 'tridacnidae': {'n_is_sth': '0'},
 'triga': {'n_is_sth': '0'},
 'triglidae': {'n_is_sth': '0'},
 'triglinae': {'n_is_sth': '0'},
 'trimorphodon': {'n_is_sth': '0'},
 'tringa': {'n_is_sth': '0'},
 'trionychidae': {'n_is_sth': '0'},
 'triopidae': {'n_is_sth': '0'},
 'trochilidae': {'n_is_sth': '0'},
 'trogium': {'n_is_sth': '0'},
 'troglodytidae': {'n_is_sth': '0'},
 'trogonidae': {'n_is_sth': '0'},
 'trogoniformes': {'n_is_sth': '0'},
 'trombicula': {'n_is_sth': '0'},
 'trombiculidae': {'n_is_sth': '0'},
 'trombidiidae': {'n_is_sth': '0'},
 'trophoblast': {'n_is_sth': '0'},
 'tropicbird': {'n_is_sth': '0'},
 'tropidoclonion': {'n_is_sth': '0'},
 'true toad': {'n_is_sth': '0'},
 'trypetidae': {'n_is_sth': '0'},
 'tube foot': {'n_is_sth': '0'},
 'tubulidentata': {'n_is_sth': '0'},
 'tunga': {'n_is_sth': '0'},
 'tungusic': {'n_is_sth': '0'},
 'tunicata': {'n_is_sth': '0'},
 'tunicate': {'n_is_sth': '0'},
 'tupaiidae': {'n_is_sth': '0'},
 'tupinambis': {'n_is_sth': '0'},
 'turbatrix': {'n_is_sth': '0'},
 'turbellaria': {'n_is_sth': '0'},
 'turdidae': {'n_is_sth': '0'},
 'turdinae': {'n_is_sth': '0'},
 'turdus': {'n_is_sth': '0'},
 'turnicidae': {'n_is_sth': '0'},
 'turnix': {'n_is_sth': '0'},
 'tursiops': {'n_is_sth': '0'},
 'tusk shell': {'n_is_sth': '0'},
 'tylenchidae': {'n_is_sth': '0'},
 'tylenchus': {'n_is_sth': '0'},
 'typhlopidae': {'n_is_sth': '0'},
 'tyrannidae': {'n_is_sth': '0'},
 'tyrannid': {'n_is_sth': '0'},
 'tyranni': {'n_is_sth': '0'},
 'tyrannus': {'n_is_sth': '0'},
 'tytonidae': {'n_is_sth': '0'},
 'tyto': {'n_is_sth': '0'},
 'uintatheriidae': {'n_is_sth': '0'},
 'uintatherium': {'n_is_sth': '0'},
 'ulvaceae': {'n_is_sth': '0'},
 'ulvales': {'n_is_sth': '0'},
 'ulvophyceae': {'n_is_sth': '0'},
 'umbilical vesicle': {'n_is_sth': '0'},
 'underfur': {'n_is_sth': '0'},
 'unguiculata': {'n_is_sth': '0'},
 'ungulata': {'n_is_sth': '0'},
 'unionidae': {'n_is_sth': '0'},
 'upupa': {'n_is_sth': '0'},
 'upupidae': {'n_is_sth': '0'},
 'uranoscopidae': {'n_is_sth': '0'},
 'urocyon': {'n_is_sth': '0'},
 'urodele': {'n_is_sth': '0'},
 'urophycis': {'n_is_sth': '0'},
 'uropsilus': {'n_is_sth': '0'},
 'uropygial gland': {'n_is_sth': '0'},
 'uropygium': {'n_is_sth': '0'},
 'uropygi': {'n_is_sth': '0'},
 'urosaurus': {'n_is_sth': '0'},
 'ursidae': {'n_is_sth': '0'},
 'ursus': {'n_is_sth': '0'},
 'vajra': {'n_is_sth': '0'},
 'varanidae': {'n_is_sth': '0'},
 'varanus': {'n_is_sth': '0'},
 'variola major': {'n_is_sth': '0'},
 'variola minor': {'n_is_sth': '0'},
 'veneridae': {'n_is_sth': '0'},
 'ventral fin': {'n_is_sth': '0'},
 'ventriculus': {'n_is_sth': '0'},
 'vertebrata': {'n_is_sth': '0'},
 'vesicula umbilicus': {'n_is_sth': '0'},
 'vespa': {'n_is_sth': '0'},
 'vespertilionidae': {'n_is_sth': '0'},
 'vespertilio': {'n_is_sth': '0'},
 'vespidae': {'n_is_sth': '0'},
 'vespula': {'n_is_sth': '0'},
 'vibrissa': {'n_is_sth': '0'},
 'vidua': {'n_is_sth': '0'},
 'villus': {'n_is_sth': '0'},
 'vipera': {'n_is_sth': '0'},
 'viperidae': {'n_is_sth': '0'},
 'vireonidae': {'n_is_sth': '0'},
 'vital principle': {'n_is_sth': '0'},
 'vitelline sac': {'n_is_sth': '0'},
 'vitellus': {'n_is_sth': '0'},
 'viverra': {'n_is_sth': '0'},
 'viverricula': {'n_is_sth': '0'},
 'viverridae': {'n_is_sth': '0'},
 'viverrinae': {'n_is_sth': '0'},
 'volvocaceae': {'n_is_sth': '0'},
 'volvocales': {'n_is_sth': '0'},
 'vombatidae': {'n_is_sth': '0'},
 'vulpes': {'n_is_sth': '0'},
 'water bearer': {'n_is_sth': '0'},
 'water vascular system': {'n_is_sth': '0'},
 'watts': {'n_is_sth': '0'},
 'webbed foot': {'n_is_sth': '0'},
 'welfare case': {'n_is_sth': '0'},
 'whiff': {'n_is_sth': '0'},
 'whirlaway': {'n_is_sth': '0'},
 'white tail': {'n_is_sth': '0'},
 'wing case': {'n_is_sth': '0'},
 'wishbone': {'n_is_sth': '0'},
 'wishing bone': {'n_is_sth': '0'},
 'withers': {'n_is_sth': '0'},
 'worm family': {'n_is_sth': '0'},
 'worm genus': {'n_is_sth': '0'},
 'xanthomonas': {'n_is_sth': '0'},
 'xanthophyceae': {'n_is_sth': '0'},
 'xantusiidae': {'n_is_sth': '0'},
 'xenicidae': {'n_is_sth': '0'},
 'xenicus': {'n_is_sth': '0'},
 'xenopodidae': {'n_is_sth': '0'},
 'xenosaurus': {'n_is_sth': '0'},
 'xiphias': {'n_is_sth': '0'},
 'xiphiidae': {'n_is_sth': '0'},
 'xiphosura': {'n_is_sth': '0'},
 'xyphophorus': {'n_is_sth': '0'},
 'yolk sac': {'n_is_sth': '0'},
 'zaglossus': {'n_is_sth': '0'},
 'zapodidae': {'n_is_sth': '0'},
 'zapus': {'n_is_sth': '0'},
 'zeidae': {'n_is_sth': '0'},
 'zenaidura': {'n_is_sth': '0'},
 'ziphiidae': {'n_is_sth': '0'},
 'zoarces': {'n_is_sth': '0'},
 'zoarcidae': {'n_is_sth': '0'},
 'zombi spirit': {'n_is_sth': '0'},
 'zombie spirit': {'n_is_sth': '0'},
 'zooid': {'n_is_sth': '0'},
 'zoomastigina': {'n_is_sth': '0'},
 'zoophyte': {'n_is_sth': '0'},
 'zooplankton': {'n_is_sth': '0'},
 'zygnemataceae': {'n_is_sth': '0'},
 'zygnematales': {'n_is_sth': '0'},
 'zygnema': {'n_is_sth': '0'},
 'zygodactyl foot': {'n_is_sth': '0'},
 'zygoptera': {'n_is_sth': '0'},
 'Rasdaq': {'n_is_sth': '0'},
 'whacko': {'n_is_sth': '0'},
 'dci': {'n_is_sth': '0'},
 'mix truth/dobj_v_n': {'': ''},
 'precent': {'spell_err': 'percent'},
 'jinan': {'cap_word': 'Jinan'},
 "'m": {'func_word': ''},
 "'d": {'func_word': ''},
 "'ve": {'func_word': ''},
 'good security condition/_n': {'': ''},
 '℃': {'n_is_unit': ''},
 "o'clock": {'n_is_unit': '', 'nns_exp_exc': ''},
 'saw seal/dobj_v_n': {'': ''},
 'annoy girlfriend/dobj_v_n': {'': ''},
 'arrive hour/dobj_v_n': {'': ''},
 'safeguard planet/dobj_v_n': {'': ''},
 'ended lesson/dobj_v_n': {'': ''},
 'cost people': {'e_trp.nsv': ''},
 'withdraw pound/dobj_v_n': {'': ''},
 'decorate dormitory/dobj_v_n': {'': ''},
 'cover belongings/dobj_v_n': {'': ''},
 'introduce hometown/dobj_v_n': {'': ''},
 'taste specials/dobj_v_n': {'': ''},
 'prefer hamburger/dobj_v_n': {'': ''},
 'see laborer/dobj_v_n': {'': ''},
 'get interview/von': {'': ''},
 'afford fact/dobj_v_n': {'': ''},
 'choose milk/dobj_v_n': {'': ''},
 'knowledges': {'nns_to_nn': 'knowledge', '$born':'e_noun.nu_nns'},
 'fully': {'rb_to_jj': 'full'},
 'fuck': {'dirtyword': ''},
 'Shit': {'dirtyword': ''},
 'shitface': {'dirtyword': ''},
 'tits': {'dirtyword': ''},
 'clit': {'dirtyword': ''},
 'Jackass': {'dirtyword': ''},
 'bulldager': {'dirtyword': ''},
 'lessy': {'dirtyword': ''},
 'millilitre': {'quantifier': ''},
 'enjoy moon/dobj_v_n': {'': ''},
 'rend house/dobj_v_n': {'': ''},
 'live way/dobj_v_n': {'': ''},
 'change smile/von': {'': ''},
 'feed user/dobj_v_n': {'': ''},
 'sharpen axe/von': {'': ''},
 'communicate face/dobj_v_n': {'': ''},
 'washing clothes/dobj_v_n': {'': ''},
 'watch gala/dobj_v_n': {'': ''},
 'downloading essay/dobj_v_n': {'': ''},
 'admit news/dobj_v_n': {'': ''},
 'fucking': {'dirtyword': ''},
 'suggest souvenir/dobj_v_n': {'': ''},
 'eliminate resident/dobj_v_n': {'': ''},
 'strange but useful tips/_n': {'': ''},
 'mean diploma/dobj_v_n': {'': ''},
 'the advantage of phones/_n': {'': ''},
 'afford/dobj_v_exc': {'': ''},
 'illustrate bank/dobj_v_n': {'': ''},
 'pocketful': {'n_of_nns': ''},
 'phubbing': {'n_is_sb': ''},
 'phubber': {'n_is_sb': ''},
 'most of the latest information/_n': {'': ''},
 'a few foreign stamps/_n': {'': ''},
 'few foreign stamps/_n': {'': ''},
 'found money': {'e_trp.dobj': ''},
 'Eskimo': {'nn_eq_nns': ''},
 'Frenchman': {'nn_to_nns': 'Frenchmen'},
 'Hebrew': {'nn_to_nns': 'Hebrews'},
 'Kleenex': {'nn_eq_nns': '', 'nn_to_nns': 'Kleenexes'},
 'Plexiglas': {'n_is_nu': ''},
 'Sinhalese': {'nn_eq_nns': ''},
 'Xerox': {'nn_to_nns': 'Xeroxes', 'vb_to_vbd': 'Xeroxed', 'vb_to_vbn': 'Xeroxed', 'vb_to_vbg': 'Xeroxing', 'vbd_eq_vbn': '', 'v_n': ''},
 'abase': {'vb_to_vbd': 'abased', 'vb_to_vbn': 'abased', 'vb_to_vbg': 'abasing', 'vbd_eq_vbn': '', 'vb_to_vbz': 'abases'},
 'baht': {'nn_eq_nns': ''},
 'extraordinary': {'jj_to_rb': 'extraordinarily'},
 'knowlege': {'e_spell': 'knowledge'},
 'konwledge': {'e_spell': 'knowledge'},
 'k.p.h': {'n_is_nu': ''},
 'al': {'prefix': ''},
 'commonality  ': {'n_is_nc': ''},
 'bebop': {'n_is_nu': ''},
 'somethings': {'suffix': 'cd'},
 'esque': {'suffix': 'nn'},
 'proto': {'prefix': ''},
 'non': {'prefix': 'jj|nn'},
 'impetus ': {'n_usu_singular': ''},
 ' return': {'n_is_nc': ''},
 'anatomo': {'prefix': ''},
 '%': {'nns_exp_exc': ''},
 'AD': {'nns_exp_exc': ''},
 'BC': {'nns_exp_exc': ''},
 'bald': {'jj_to_jjr': 'balder', 'jj_to_jjs': 'baldest'},
 'homy': {'jj_to_jjr': 'homier', 'jj_to_jjs': 'homiest'},
 'pricey': {'jj_to_jjr': 'pricier', 'jj_to_jjs': 'priciest'},
 'steamy': {'jj_to_jjr': 'steamier', 'jj_to_jjs': 'steamiest'},
 'sticky': {'jj_to_jjr': 'stickier', 'jj_to_jjs': 'stickiest'},
 'remote': {'jj_to_jjr': 'remoter', 'jj_to_jjs': 'remotest'},
 'far': {'jj_to_jjr': 'farther', 'jj_to_jjs': 'farthest', 'rb_to_rbr': 'farther', 'rb_to_rbs': 'farthest'},
 'nimble': {'jj_to_jjr': 'nimbler', 'jj_to_jjs': 'nimblest'},
 'swanky': {'jj_to_jjr': 'swankier', 'jj_to_jjs': 'swankiest'},
 'tricky': {'jj_to_jjr': 'trickier', 'jj_to_jjs': 'trickiest'},
 'seamy': {'jj_to_jjr': 'seamier', 'jj_to_jjs': 'seamiest'},
 'vague': {'jj_to_jjr': 'vaguer', 'jj_to_jjs': 'vaguest'},
 'creamy': {'jj_to_jjr': 'creamier', 'jj_to_jjs': 'creamiest'},
 'sane': {'jj_to_jjr': 'saner', 'jj_to_jjs': 'sanest'},
 'frothy': {'jj_to_jjr': 'frothier', 'jj_to_jjs': 'frothiest'},
 'bleak': {'jj_to_jjr': 'bleaker', 'jj_to_jjs': 'bleakest'},
 'flashy': {'jj_to_jjr': 'flashier', 'jj_to_jjs': 'flashiest'},
 'feisty': {'jj_to_jjr': 'feistier', 'jj_to_jjs': 'feistiest'},
 'nasty': {'jj_to_jjr': 'nastier', 'jj_to_jjs': 'nastiest'},
 'big': {'jj_to_jjr': 'bigger', 'jj_to_jjs': 'biggest'},
 'vast': {'jj_to_jjr': 'vaster', 'jj_to_jjs': 'vastest'},
 'choosy': {'jj_to_jjr': 'choosier', 'jj_to_jjs': 'choosiest'},
 'subtle': {'jj_to_jjr': 'subtler', 'jj_to_jjs': 'subtlest'},
 'cozy': {'jj_to_jjr': 'cozier', 'jj_to_jjs': 'coziest'},
 'tiny': {'jj_to_jjr': 'tinier', 'jj_to_jjs': 'tiniest'},
 'profound': {'jj_to_jjr': 'profounder', 'jj_to_jjs': 'profoundest'},
 'stormy': {'jj_to_jjr': 'stormier', 'jj_to_jjs': 'stormiest'},
 'roomy': {'jj_to_jjr': 'roomier', 'jj_to_jjs': 'roomiest'},
 'stingy': {'jj_to_jjr': 'stingier', 'jj_to_jjs': 'stingiest'},
 'soggy': {'jj_to_jjr': 'soggier', 'jj_to_jjs': 'soggiest'},
 'hefty': {'jj_to_jjr': 'heftier', 'jj_to_jjs': 'heftiest'},
 'little': {'jj_to_jjr': 'less', 'jj_to_jjs': 'least', 'rb_to_rbr': 'less', 'rb_to_rbs': 'least'},
 'shady': {'jj_to_jjr': 'shadier', 'jj_to_jjs': 'shadiest'},
 'rainy': {'jj_to_jjr': 'rainier', 'jj_to_jjs': 'rainiest'},
 'well-known': {'jj_to_jjr': 'better-known', 'jj_to_jjs': 'best-known'},
 'strange': {'jj_to_jjr': 'stranger', 'jj_to_jjs': 'strangest'},
 'high-quality': {'jj_to_jjr': 'higher-quality', 'jj_to_jjs': 'highest-quality'},
 'shrewd': {'jj_to_jjr': 'shrewder', 'jj_to_jjs': 'shrewdest'},
 'furry': {'jj_to_jjr': 'furrier', 'jj_to_jjs': 'furriest'},
 'gloomy': {'jj_to_jjr': 'gloomier', 'jj_to_jjs': 'gloomiest'},
 'stark': {'jj_to_jjr': 'starker', 'jj_to_jjs': 'starkest'},
 'cocky': {'jj_to_jjr': 'cockier', 'jj_to_jjs': 'cockiest'},
 'tall': {'jj_to_jjr': 'taller', 'jj_to_jjs': 'tallest'},
 'murky': {'jj_to_jjr': 'murkier', 'jj_to_jjs': 'murkiest'},
 'bland': {'jj_to_jjr': 'blander', 'jj_to_jjs': 'blandest'},
 'chilly': {'jj_to_jjr': 'chillier', 'jj_to_jjs': 'chilliest'},
 'cute': {'jj_to_jjr': 'cuter', 'jj_to_jjs': 'cutest'},
 'spooky': {'jj_to_jjr': 'spookier', 'jj_to_jjs': 'spookiest'},
 'rosy': {'jj_to_jjr': 'rosier', 'jj_to_jjs': 'rosiest'},
 'well-off': {'jj_to_jjr': 'better-off', 'jj_to_jjs': 'best-off'},
 'poor': {'jj_to_jjr': 'poorer', 'jj_to_jjs': 'poorest'},
 'picky': {'jj_to_jjr': 'pickier', 'jj_to_jjs': 'pickiest'},
 'trendy': {'jj_to_jjr': 'trendier', 'jj_to_jjs': 'trendiest'},
 'grim': {'jj_to_jjr': 'grimmer', 'jj_to_jjs': 'grimmest'},
 'prickly': {'jj_to_jjr': 'pricklier', 'jj_to_jjs': 'prickliest'},
 'tangy': {'jj_to_jjr': 'tangier', 'jj_to_jjs': 'tangiest'},
 'dreary': {'jj_to_jjr': 'drearier', 'jj_to_jjs': 'dreariest'},
 'harsh': {'jj_to_jjr': 'harsher', 'jj_to_jjs': 'harshest'},
 'dumb': {'jj_to_jjr': 'dumber', 'jj_to_jjs': 'dumbest'},
 'long-term': {'jj_to_jjr': 'longer-term'},
 'breezy': {'jj_to_jjr': 'breezier', 'jj_to_jjs': 'breeziest'},
 'brisk': {'jj_to_jjr': 'brisker', 'jj_to_jjs': 'briskest'},
 'crunchy': {'jj_to_jjr': 'crunchier', 'jj_to_jjs': 'crunchiest'},
 'fuzzy': {'jj_to_jjr': 'fuzzier', 'jj_to_jjs': 'fuzziest'},
 'lumpy': {'jj_to_jjr': 'lumpier', 'jj_to_jjs': 'lumpiest'},
 'pudgy': {'jj_to_jjr': 'pudgier', 'jj_to_jjs': 'pudgiest'},
 'slender': {'jj_to_jjr': 'slenderer', 'jj_to_jjs': 'slenderest'},
 'snazzy': {'jj_to_jjr': 'snazzier', 'jj_to_jjs': 'snazziest'},
 'wiggy': {'jj_to_jjr': 'wiggier', 'jj_to_jjs': 'wiggiest'},
 'prissy': {'jj_to_jjr': 'prissier', 'jj_to_jjs': 'prissiest'},
 'lofty': {'jj_to_jjr': 'loftier', 'jj_to_jjs': 'loftiest'},
 'teeny-weeny': {'jj_to_jjr': 'teeny-weenier', 'jj_to_jjs': 'teeny-weeniest'},
 'stealthy': {'jj_to_jjr': 'stealthier', 'jj_to_jjs': 'stealthiest'},
 'deathly': {'jj_to_jjr': 'deathlier', 'jj_to_jjs': 'deathliest'},
 'freaky': {'jj_to_jjr': 'freakier', 'jj_to_jjs': 'freakiest'},
 'godly': {'jj_to_jjr': 'godlier', 'jj_to_jjs': 'godliest'},
 'courtly': {'jj_to_jjr': 'courtlier', 'jj_to_jjs': 'courtliest', 'rb_to_rbr': 'courtliest'},
 'shoddy': {'jj_to_jjr': 'shoddier', 'jj_to_jjs': 'shoddiest'},
 'surly': {'jj_to_jjr': 'surlier', 'jj_to_jjs': 'surliest'},
 'fratty': {'jj_to_jjr': 'frattier', 'jj_to_jjs': 'frattiest'},
 'crinkly': {'jj_to_jjr': 'crinklier', 'jj_to_jjs': 'crinkliest'},
 'teensy-weensy': {'jj_to_jjr': 'teensy-weensier', 'jj_to_jjs': 'teensy-weensiest'},
 'peaky': {'jj_to_jjr': 'peakier', 'jj_to_jjs': 'peakiest'},
 'smelly': {'jj_to_jjr': 'smellier', 'jj_to_jjs': 'smelliest'},
 'ropy': {'jj_to_jjr': 'ropier', 'jj_to_jjs': 'ropiest'},
 'squeaky': {'jj_to_jjr': 'squeakier', 'jj_to_jjs': 'squeakiest'},
 'crispy': {'jj_to_jjr': 'crispier', 'jj_to_jjs': 'crispiest'},
 'spunky': {'jj_to_jjr': 'spunkier', 'jj_to_jjs': 'spunkiest'},
 'baggy': {'jj_to_jjr': 'baggier', 'jj_to_jjs': 'baggiest'},
 'beefy': {'jj_to_jjr': 'beefier', 'jj_to_jjs': 'beefiest'},
 'bonny': {'jj_to_jjr': 'bonnier', 'jj_to_jjs': 'bonniest'},
 'bony': {'jj_to_jjr': 'bonier', 'jj_to_jjs': 'boniest'},
 'bossy': {'jj_to_jjr': 'bossier', 'jj_to_jjs': 'bossiest'},
 'brawny': {'jj_to_jjr': 'brawnier', 'jj_to_jjs': 'brawniest'},
 'bumpy': {'jj_to_jjr': 'bumpier', 'jj_to_jjs': 'bumpiest'},
 'catchy': {'jj_to_jjr': 'catchier', 'jj_to_jjs': 'catchiest'},
 'chirpy': {'jj_to_jjr': 'chirpier', 'jj_to_jjs': 'chirpiest'},
 'choppy': {'jj_to_jjr': 'choppier', 'jj_to_jjs': 'choppiest'},
 'cosy': {'jj_to_jjr': 'cosier', 'jj_to_jjs': 'cosiest'},
 'crass': {'jj_to_jjr': 'crasser', 'jj_to_jjs': 'crassest'},
 'crabby': {'jj_to_jjr': 'crabbier', 'jj_to_jjs': 'crabbiest'},
 'crafty': {'jj_to_jjr': 'craftier', 'jj_to_jjs': 'craftiest'},
 'cranky': {'jj_to_jjr': 'crankier', 'jj_to_jjs': 'crankiest'},
 'crappy': {'jj_to_jjr': 'crappier', 'jj_to_jjs': 'crappiest'},
 'creaky': {'jj_to_jjr': 'creakier', 'jj_to_jjs': 'creakiest'},
 'creepy': {'jj_to_jjr': 'creepier', 'jj_to_jjs': 'creepiest'},
 'crumbly': {'jj_to_jjr': 'crumblier', 'jj_to_jjs': 'crumbliest'},
 'cuddly': {'jj_to_jjr': 'cuddlier', 'jj_to_jjs': 'cuddliest'},
 'curvy': {'jj_to_jjr': 'curvier', 'jj_to_jjs': 'curviest'},
 'dingy': {'jj_to_jjr': 'dingier', 'jj_to_jjs': 'dingiest'},
 'dinky': {'jj_to_jjr': 'dinkier', 'jj_to_jjs': 'dinkiest'},
 'dishy': {'jj_to_jjr': 'dishier', 'jj_to_jjs': 'dishiest'},
 'dodgy': {'jj_to_jjr': 'dodgier', 'jj_to_jjs': 'dodgiest'},
 'dopey': {'jj_to_jjr': 'dopeier', 'jj_to_jjs': 'dopeiest'},
 'dotty': {'jj_to_jjr': 'dottier', 'jj_to_jjs': 'dottiest'},
 'downy': {'jj_to_jjr': 'downier', 'jj_to_jjs': 'downiest'},
 'dressy': {'jj_to_jjr': 'dressier', 'jj_to_jjs': 'dressiest'},
 'droopy': {'jj_to_jjr': 'droopier', 'jj_to_jjs': 'droopiest'},
 'drowsy': {'jj_to_jjr': 'drowsier', 'jj_to_jjs': 'drowsiest'},
 'dusky': {'jj_to_jjr': 'duskier', 'jj_to_jjs': 'duskiest'},
 'edgy': {'jj_to_jjr': 'edgier', 'jj_to_jjs': 'edgiest'},
 'feeble': {'jj_to_jjr': 'feebler', 'jj_to_jjs': 'feeblest'},
 'fiery': {'jj_to_jjr': 'fierier', 'jj_to_jjs': 'fieriest'},
 'filmy': {'jj_to_jjr': 'filmier', 'jj_to_jjs': 'filmiest'},
 'filthy': {'jj_to_jjr': 'filthier', 'jj_to_jjs': 'filthiest'},
 'fishy': {'jj_to_jjr': 'fishier', 'jj_to_jjs': 'fishiest'},
 'fizzy': {'jj_to_jjr': 'fizzier', 'jj_to_jjs': 'fizziest'},
 'flabby': {'jj_to_jjr': 'flabbier', 'jj_to_jjs': 'flabbiest'},
 'flaky': {'jj_to_jjr': 'flakier', 'jj_to_jjs': 'flakiest'},
 'fleecy': {'jj_to_jjr': 'fleecier', 'jj_to_jjs': 'fleeciest'},
 'flighty': {'jj_to_jjr': 'flightier', 'jj_to_jjs': 'flightiest'},
 'flinty': {'jj_to_jjr': 'flintier', 'jj_to_jjs': 'flintiest'},
 'floppy': {'jj_to_jjr': 'floppier', 'jj_to_jjs': 'floppiest'},
 'flowery': {'jj_to_jjr': 'flowerier', 'jj_to_jjs': 'floweriest'},
 'fluffy': {'jj_to_jjr': 'fluffier', 'jj_to_jjs': 'fluffiest'},
 'foggy': {'jj_to_jjr': 'foggier', 'jj_to_jjs': 'foggiest'},
 'foxy': {'jj_to_jjr': 'foxier', 'jj_to_jjs': 'foxiest'},
 'frisky': {'jj_to_jjr': 'friskier', 'jj_to_jjs': 'friskiest'},
 'frizzy': {'jj_to_jjr': 'frizzier', 'jj_to_jjs': 'frizziest'},
 'frosty': {'jj_to_jjr': 'frostier', 'jj_to_jjs': 'frostiest'},
 'fruity': {'jj_to_jjr': 'fruitier', 'jj_to_jjs': 'fruitiest'},
 'funky': {'jj_to_jjr': 'funkier', 'jj_to_jjs': 'funkiest'},
 'fussy': {'jj_to_jjr': 'fussier', 'jj_to_jjs': 'fussiest'},
 'fusty': {'jj_to_jjr': 'fustier', 'jj_to_jjs': 'fustiest'},
 'gassy': {'jj_to_jjr': 'gassier', 'jj_to_jjs': 'gassiest'},
 'gaudy': {'jj_to_jjr': 'gaudier', 'jj_to_jjs': 'gaudiest'},
 'gawky': {'jj_to_jjr': 'gawkier', 'jj_to_jjs': 'gawkiest'},
 'ghastly': {'jj_to_jjr': 'ghastlier', 'jj_to_jjs': 'ghastliest'},
 'ghostly': {'jj_to_jjr': 'ghostlier', 'jj_to_jjs': 'ghostliest'},
 'giddy': {'jj_to_jjr': 'giddier', 'jj_to_jjs': 'giddiest'},
 'glary': {'jj_to_jjr': 'glarier', 'jj_to_jjs': 'glariest'},
 'glassy': {'jj_to_jjr': 'glassier', 'jj_to_jjs': 'glassiest'},
 'glib': {'jj_to_jjr': 'glibber', 'jj_to_jjs': 'glibbest'},
 'glitzy': {'jj_to_jjr': 'glitzier', 'jj_to_jjs': 'glitziest'},
 'glossy': {'jj_to_jjr': 'glossier', 'jj_to_jjs': 'glossiest'},
 'glum': {'jj_to_jjr': 'glummer', 'jj_to_jjs': 'glummest'},
 'goodly': {'jj_to_jjr': 'goodlier', 'jj_to_jjs': 'goodliest'},
 'gooey': {'jj_to_jjr': 'gooier', 'jj_to_jjs': 'gooiest'},
 'gory': {'jj_to_jjr': 'gorier', 'jj_to_jjs': 'goriest'},
 'grimy': {'jj_to_jjr': 'grimier', 'jj_to_jjs': 'grimiest'},
 'grisly': {'jj_to_jjr': 'grislier', 'jj_to_jjs': 'grisliest'},
 'gritty': {'jj_to_jjr': 'grittier', 'jj_to_jjs': 'grittiest'},
 'groggy': {'jj_to_jjr': 'groggier', 'jj_to_jjs': 'groggiest'},
 'groovy': {'jj_to_jjr': 'groovier', 'jj_to_jjs': 'grooviest'},
 'grotty': {'jj_to_jjr': 'grottier', 'jj_to_jjs': 'grottiest'},
 'grouchy': {'jj_to_jjr': 'grouchier', 'jj_to_jjs': 'grouchiest'},
 'grumpy': {'jj_to_jjr': 'grumpier', 'jj_to_jjs': 'grumpiest'},
 'gummy': {'jj_to_jjr': 'gummier', 'jj_to_jjs': 'gummiest'},
 'gunky': {'jj_to_jjr': 'gunkier', 'jj_to_jjs': 'gunkiest'},
 'gushy': {'jj_to_jjr': 'gushier', 'jj_to_jjs': 'gushiest'},
 'gusty': {'jj_to_jjr': 'gustier', 'jj_to_jjs': 'gustiest'},
 'gutsy': {'jj_to_jjr': 'gutsier', 'jj_to_jjs': 'gutsiest'},
 'haughty': {'jj_to_jjr': 'haughtier', 'jj_to_jjs': 'haughtiest'},
 'hazy': {'jj_to_jjr': 'hazier', 'jj_to_jjs': 'haziest'},
 'heady': {'jj_to_jjr': 'headier', 'jj_to_jjs': 'headiest'},
 'hearty': {'jj_to_jjr': 'heartier', 'jj_to_jjs': 'heartiest'},
 'hoary': {'jj_to_jjr': 'hoarier', 'jj_to_jjs': 'hoariest'},
 'homely': {'jj_to_jjr': 'homelier', 'jj_to_jjs': 'homeliest'},
 'homey': {'jj_to_jjr': 'homeier', 'jj_to_jjs': 'homeiest'},
 'horny': {'jj_to_jjr': 'hornier', 'jj_to_jjs': 'horniest'},
 'jaunty': {'jj_to_jjr': 'jauntier', 'jj_to_jjs': 'jauntiest'},
 'jazzy': {'jj_to_jjr': 'jazzier', 'jj_to_jjs': 'jazziest'},
 'jerky': {'jj_to_jjr': 'jerkier', 'jj_to_jjs': 'jerkiest'},
 'jumpy': {'jj_to_jjr': 'jumpier', 'jj_to_jjs': 'jumpiest'},
 'kinky': {'jj_to_jjr': 'kinkier', 'jj_to_jjs': 'kinkiest'},
 'knotty': {'jj_to_jjr': 'knottier', 'jj_to_jjs': 'knottiest'},
 'lacy': {'jj_to_jjr': 'lacier', 'jj_to_jjs': 'laciest'},
 'lanky': {'jj_to_jjr': 'lankier', 'jj_to_jjs': 'lankiest'},
 'lax': {'jj_to_jjr': 'laxer', 'jj_to_jjs': 'laxest'},
 'lordly': {'jj_to_jjr': 'lordlier', 'jj_to_jjs': 'lordliest'},
 'lousy': {'jj_to_jjr': 'lousier', 'jj_to_jjs': 'lousiest'},
 'lowly': {'jj_to_jjr': 'lowlier', 'jj_to_jjs': 'lowliest'},
 'lusty': {'jj_to_jjr': 'lustier', 'jj_to_jjs': 'lustiest'},
 'mangy': {'jj_to_jjr': 'mangier', 'jj_to_jjs': 'mangiest'},
 'mealy': {'jj_to_jjr': 'mealier', 'jj_to_jjs': 'mealiest'},
 'meaty': {'jj_to_jjr': 'meatier', 'jj_to_jjs': 'meatiest'},
 'meek': {'jj_to_jjr': 'meeker', 'jj_to_jjs': 'meekest'},
 'messy': {'jj_to_jjr': 'messier', 'jj_to_jjs': 'messiest'},
 'mighty': {'jj_to_jjr': 'mightier', 'jj_to_jjs': 'mightiest'},
 'mingy': {'jj_to_jjr': 'mingier', 'jj_to_jjs': 'mingiest'},
 'moist': {'jj_to_jjr': 'moister', 'jj_to_jjs': 'moistest'},
 'moony': {'jj_to_jjr': 'moonier', 'jj_to_jjs': 'mooniest'},
 'mousy': {'jj_to_jjr': 'mousier', 'jj_to_jjs': 'mousiest'},
 'mucky': {'jj_to_jjr': 'muckier', 'jj_to_jjs': 'muckiest'},
 'muggy': {'jj_to_jjr': 'muggier', 'jj_to_jjs': 'muggiest'},
 'musty': {'jj_to_jjr': 'mustier', 'jj_to_jjs': 'mustiest'},
 'muzzy': {'jj_to_jjr': 'muzzier', 'jj_to_jjs': 'muzziest'},
 'natty': {'jj_to_jjr': 'nattier', 'jj_to_jjs': 'nattiest'},
 'needy': {'jj_to_jjr': 'needier', 'jj_to_jjs': 'neediest'},
 'nerdy': {'jj_to_jjr': 'nerdier', 'jj_to_jjs': 'nerdiest'},
 'nervy': {'jj_to_jjr': 'nervier', 'jj_to_jjs': 'nerviest'},
 'newsy': {'jj_to_jjr': 'newsier', 'jj_to_jjs': 'newsiest'},
 'nosy': {'jj_to_jjr': 'nosier', 'jj_to_jjs': 'nosiest'},
 'odd': {'jj_to_jjr': 'odder', 'jj_to_jjs': 'oddest'},
 'palmy': {'jj_to_jjr': 'palmier', 'jj_to_jjs': 'palmiest'},
 'patchy': {'jj_to_jjr': 'patchier', 'jj_to_jjs': 'patchiest'},
 'pawky': {'jj_to_jjr': 'pawkier', 'jj_to_jjs': 'pawkiest'},
 'peachy': {'jj_to_jjr': 'peachier', 'jj_to_jjs': 'peachiest'},
 'pearly': {'jj_to_jjr': 'pearlier', 'jj_to_jjs': 'pearliest'},
 'perky': {'jj_to_jjr': 'perkier', 'jj_to_jjs': 'perkiest'},
 'pesky': {'jj_to_jjr': 'peskier', 'jj_to_jjs': 'peskiest'},
 'petty': {'jj_to_jjr': 'pettier', 'jj_to_jjs': 'pettiest'},
 'pithy': {'jj_to_jjr': 'pithier', 'jj_to_jjs': 'pithiest'},
 'plucky': {'jj_to_jjr': 'pluckier', 'jj_to_jjs': 'pluckiest'},
 'plummy': {'jj_to_jjr': 'plummier', 'jj_to_jjs': 'plummiest'},
 'plushy': {'jj_to_jjr': 'plushier', 'jj_to_jjs': 'plushiest'},
 'pocky': {'jj_to_jjr': 'pockier', 'jj_to_jjs': 'pockiest'},
 'podgy': {'jj_to_jjr': 'podgier', 'jj_to_jjs': 'podgiest'},
 'pointy': {'jj_to_jjr': 'pointier', 'jj_to_jjs': 'pointiest'},
 'poky': {'jj_to_jjr': 'pokier', 'jj_to_jjs': 'pokiest'},
 'portly': {'jj_to_jjr': 'portlier', 'jj_to_jjs': 'portliest'},
 'posh': {'jj_to_jjr': 'posher', 'jj_to_jjs': 'poshest'},
 'prosy': {'jj_to_jjr': 'prosier', 'jj_to_jjs': 'prosiest'},
 'puffy': {'jj_to_jjr': 'puffier', 'jj_to_jjs': 'puffiest'},
 'pulpy': {'jj_to_jjr': 'pulpier', 'jj_to_jjs': 'pulpiest'},
 'punchy': {'jj_to_jjr': 'punchier', 'jj_to_jjs': 'punchiest'},
 'puny': {'jj_to_jjr': 'punier', 'jj_to_jjs': 'puniest'},
 'pursy': {'jj_to_jjr': 'pursier', 'jj_to_jjs': 'pursiest'},
 'purty': {'jj_to_jjr': 'purtier', 'jj_to_jjs': 'purtiest'},
 'quaint': {'jj_to_jjr': 'quainter', 'jj_to_jjs': 'quaintest'},
 'queasy': {'jj_to_jjr': 'queasier', 'jj_to_jjs': 'queasiest'},
 'quirky': {'jj_to_jjr': 'quirkier', 'jj_to_jjs': 'quirkiest'},
 'racy': {'jj_to_jjr': 'racier', 'jj_to_jjs': 'raciest'},
 'randy': {'jj_to_jjr': 'randier', 'jj_to_jjs': 'randiest'},
 'ratty': {'jj_to_jjr': 'rattier', 'jj_to_jjs': 'rattiest'},
 'raunchy': {'jj_to_jjr': 'raunchier', 'jj_to_jjs': 'raunchiest'},
 'reedy': {'jj_to_jjr': 'reedier', 'jj_to_jjs': 'reediest'},
 'reefy': {'jj_to_jjr': 'reefier', 'jj_to_jjs': 'reefiest'},
 'ritzy': {'jj_to_jjr': 'ritzier', 'jj_to_jjs': 'ritziest'},
 'roofy': {'jj_to_jjr': 'roofier', 'jj_to_jjs': 'roofiest'},
 'ruddy': {'jj_to_jjr': 'ruddier', 'jj_to_jjs': 'ruddiest'},
 'runny': {'jj_to_jjr': 'runnier', 'jj_to_jjs': 'runniest'},
 'rushy': {'jj_to_jjr': 'rushier', 'jj_to_jjs': 'rushiest'},
 'saggy': {'jj_to_jjr': 'saggier', 'jj_to_jjs': 'saggiest'},
 'sallow': {'jj_to_jjr': 'sallower', 'jj_to_jjs': 'sallowest'},
 'saucy': {'jj_to_jjr': 'saucier', 'jj_to_jjs': 'sauciest'},
 'scabby': {'jj_to_jjr': 'scabbier', 'jj_to_jjs': 'scabbiest'},
 'scanty': {'jj_to_jjr': 'scantier', 'jj_to_jjs': 'scantiest'},
 'scary': {'jj_to_jjr': 'scarier', 'jj_to_jjs': 'scariest'},
 'scatty': {'jj_to_jjr': 'scattier', 'jj_to_jjs': 'scattiest'},
 'schmaltzy': {'jj_to_jjr': 'schmaltzier', 'jj_to_jjs': 'schmaltziest'},
 'schmalzy': {'jj_to_jjr': 'schmalzier', 'jj_to_jjs': 'schmalziest'},
 'scraggly': {'jj_to_jjr': 'scragglier', 'jj_to_jjs': 'scraggliest'},
 'scraggy': {'jj_to_jjr': 'scraggier', 'jj_to_jjs': 'scraggiest'},
 'scratchy': {'jj_to_jjr': 'scratchier', 'jj_to_jjs': 'scratchiest'},
 'scrawny': {'jj_to_jjr': 'scrawnier', 'jj_to_jjs': 'scrawniest'},
 'screwy': {'jj_to_jjr': 'screwier', 'jj_to_jjs': 'screwiest'},
 'scrubby': {'jj_to_jjr': 'scrubbier', 'jj_to_jjs': 'scrubbiest'},
 'scruffy': {'jj_to_jjr': 'scruffier', 'jj_to_jjs': 'scruffiest'},
 'scummy': {'jj_to_jjr': 'scummier', 'jj_to_jjs': 'scummiest'},
 'seedy': {'jj_to_jjr': 'seedier', 'jj_to_jjs': 'seediest'},
 'seemly': {'jj_to_jjr': 'seemlier', 'jj_to_jjs': 'seemliest'},
 'sexy': {'jj_to_jjr': 'sexier', 'jj_to_jjs': 'sexiest'},
 'shabby': {'jj_to_jjr': 'shabbier', 'jj_to_jjs': 'shabbiest'},
 'shapely': {'jj_to_jjr': 'shapelier', 'jj_to_jjs': 'shapeliest'},
 'shelvy': {'jj_to_jjr': 'shelvier', 'jj_to_jjs': 'shelviest'},
 'shifty': {'jj_to_jjr': 'shiftier', 'jj_to_jjs': 'shiftiest'},
 'shirty': {'jj_to_jjr': 'shirtier', 'jj_to_jjs': 'shirtiest'},
 'shitty': {'jj_to_jjr': 'shittier', 'jj_to_jjs': 'shittiest'},
 'showy': {'jj_to_jjr': 'showier', 'jj_to_jjs': 'showiest'},
 'shrill': {'jj_to_jjr': 'shriller', 'jj_to_jjs': 'shrillest'},
 'silky': {'jj_to_jjr': 'silkier', 'jj_to_jjs': 'silkiest'},
 'silty': {'jj_to_jjr': 'siltier', 'jj_to_jjs': 'siltiest'},
 'sketchy': {'jj_to_jjr': 'sketchier', 'jj_to_jjs': 'sketchiest'},
 'skimpy': {'jj_to_jjr': 'skimpier', 'jj_to_jjs': 'skimpiest'},
 'skinny': {'jj_to_jjr': 'skinnier', 'jj_to_jjs': 'skinniest'},
 'sleazy': {'jj_to_jjr': 'sleazier', 'jj_to_jjs': 'sleaziest'},
 'slimy': {'jj_to_jjr': 'slimier', 'jj_to_jjs': 'slimiest'},
 'slinky': {'jj_to_jjr': 'slinkier', 'jj_to_jjs': 'slinkiest'},
 'slippery': {'jj_to_jjr': 'slipperier', 'jj_to_jjs': 'slipperiest'},
 'slippy': {'jj_to_jjr': 'slippier', 'jj_to_jjs': 'slippiest'},
 'sloppy': {'jj_to_jjr': 'sloppier', 'jj_to_jjs': 'sloppiest'},
 'sludgy': {'jj_to_jjr': 'sludgier', 'jj_to_jjs': 'sludgiest'},
 'slummy': {'jj_to_jjr': 'slummier', 'jj_to_jjs': 'slummiest'},
 'slushy': {'jj_to_jjr': 'slushier', 'jj_to_jjs': 'slushiest'},
 'sly': {'jj_to_jjr': 'slyer', 'jj_to_jjs': 'slyest'},
 'smarmy': {'jj_to_jjr': 'smarmier', 'jj_to_jjs': 'smarmiest'},
 'smeary': {'jj_to_jjr': 'smearier', 'jj_to_jjs': 'smeariest'},
 'smoggy': {'jj_to_jjr': 'smoggier', 'jj_to_jjs': 'smoggiest'},
 'smoky': {'jj_to_jjr': 'smokier', 'jj_to_jjs': 'smokiest'},
 'smudgy': {'jj_to_jjr': 'smudgier', 'jj_to_jjs': 'smudgiest'},
 'smug': {'jj_to_jjr': 'smugger', 'jj_to_jjs': 'smuggest'},
 'smutty': {'jj_to_jjr': 'smuttier', 'jj_to_jjs': 'smuttiest'},
 'smutchy': {'jj_to_jjr': 'smutchier', 'jj_to_jjs': 'smutchiest'},
 'snappy': {'jj_to_jjr': 'snappier', 'jj_to_jjs': 'snappiest'},
 'sneaky': {'jj_to_jjr': 'sneakier', 'jj_to_jjs': 'sneakiest'},
 'sniffy': {'jj_to_jjr': 'sniffier', 'jj_to_jjs': 'sniffiest'},
 'snobby': {'jj_to_jjr': 'snobbier', 'jj_to_jjs': 'snobbiest'},
 'snooty': {'jj_to_jjr': 'snootier', 'jj_to_jjs': 'snootiest'},
 'snotty': {'jj_to_jjr': 'snottier', 'jj_to_jjs': 'snottiest'},
 'snowy': {'jj_to_jjr': 'snowier', 'jj_to_jjs': 'snowiest'},
 'soapy': {'jj_to_jjr': 'soapier', 'jj_to_jjs': 'soapiest'},
 'soppy': {'jj_to_jjr': 'soppier', 'jj_to_jjs': 'soppiest'},
 'spacey': {'jj_to_jjr': 'spaceier', 'jj_to_jjs': 'spaceiest'},
 'spicy': {'jj_to_jjr': 'spicier', 'jj_to_jjs': 'spiciest'},
 'spiky': {'jj_to_jjr': 'spikier', 'jj_to_jjs': 'spikiest'},
 'spongy': {'jj_to_jjr': 'spongier', 'jj_to_jjs': 'spongiest'},
 'sporty': {'jj_to_jjr': 'sportier', 'jj_to_jjs': 'sportiest'},
 'spotty': {'jj_to_jjr': 'spottier', 'jj_to_jjs': 'spottiest'},
 'sprightly': {'jj_to_jjr': 'sprightlier', 'jj_to_jjs': 'sprightliest'},
 'springy': {'jj_to_jjr': 'springier', 'jj_to_jjs': 'springiest'},
 'spry': {'jj_to_jjr': 'sprier', 'jj_to_jjs': 'spriest'},
 'squiffy': {'jj_to_jjr': 'squiffier', 'jj_to_jjs': 'squiffiest'},
 'squishy': {'jj_to_jjr': 'squishier', 'jj_to_jjs': 'squishiest'},
 'stagy': {'jj_to_jjr': 'stagier', 'jj_to_jjs': 'stagiest'},
 'starchy': {'jj_to_jjr': 'starchier', 'jj_to_jjs': 'starchiest'},
 'stately': {'jj_to_jjr': 'statelier', 'jj_to_jjs': 'stateliest'},
 'steely': {'jj_to_jjr': 'steelier', 'jj_to_jjs': 'steeliest'},
 'stinky': {'jj_to_jjr': 'stinkier', 'jj_to_jjs': 'stinkiest'},
 'stocky': {'jj_to_jjr': 'stockier', 'jj_to_jjs': 'stockiest'},
 'stodgy': {'jj_to_jjr': 'stodgier', 'jj_to_jjs': 'stodgiest'},
 'streaky': {'jj_to_jjr': 'streakier', 'jj_to_jjs': 'streakiest'},
 'stretchy': {'jj_to_jjr': 'stretchier', 'jj_to_jjs': 'stretchiest'},
 'stringy': {'jj_to_jjr': 'stringier', 'jj_to_jjs': 'stringiest'},
 'stroppy': {'jj_to_jjr': 'stroppier', 'jj_to_jjs': 'stroppiest'},
 'stuffy': {'jj_to_jjr': 'stuffier', 'jj_to_jjs': 'stuffiest'},
 'stumpy': {'jj_to_jjr': 'stumpier', 'jj_to_jjs': 'stumpiest'},
 'sturdy': {'jj_to_jjr': 'sturdier', 'jj_to_jjs': 'sturdiest'},
 'suave': {'jj_to_jjr': 'suaver', 'jj_to_jjs': 'suavest'},
 'sulky': {'jj_to_jjr': 'sulkier', 'jj_to_jjs': 'sulkiest'},
 'sultry': {'jj_to_jjr': 'sultrier', 'jj_to_jjs': 'sultriest'},
 'swampy': {'jj_to_jjr': 'swampier', 'jj_to_jjs': 'swampiest'},
 'swarthy': {'jj_to_jjr': 'swarthier', 'jj_to_jjs': 'swarthiest'},
 'sweaty': {'jj_to_jjr': 'sweatier', 'jj_to_jjs': 'sweatiest'},
 'swingy': {'jj_to_jjr': 'swingier', 'jj_to_jjs': 'swingiest'},
 'swishy': {'jj_to_jjr': 'swishier', 'jj_to_jjs': 'swishiest'},
 'spindly': {'jj_to_jjr': 'spindlier', 'jj_to_jjs': 'spindliest'},
 'stilly': {'jj_to_jjr': 'stillier', 'jj_to_jjs': 'stilliest'},
 'tacky': {'jj_to_jjr': 'tackier', 'jj_to_jjs': 'tackiest'},
 'tardy': {'jj_to_jjr': 'tardier', 'jj_to_jjs': 'tardiest'},
 'tatty': {'jj_to_jjr': 'tattier', 'jj_to_jjs': 'tattiest'},
 'taut': {'jj_to_jjr': 'tauter', 'jj_to_jjs': 'tautest'},
 'tawdry': {'jj_to_jjr': 'tawdrier', 'jj_to_jjs': 'tawdriest'},
 'techy': {'jj_to_jjr': 'techier', 'jj_to_jjs': 'techiest'},
 'teensy': {'jj_to_jjr': 'teensier', 'jj_to_jjs': 'teensiest'},
 'teeny': {'jj_to_jjr': 'teenier', 'jj_to_jjs': 'teeniest'},
 'testy': {'jj_to_jjr': 'testier', 'jj_to_jjs': 'testiest'},
 'tetchy': {'jj_to_jjr': 'tetchier', 'jj_to_jjs': 'tetchiest'},
 'thirsty': {'jj_to_jjr': 'thirstier', 'jj_to_jjs': 'thirstiest'},
 'thorny': {'jj_to_jjr': 'thornier', 'jj_to_jjs': 'thorniest'},
 'thrifty': {'jj_to_jjr': 'thriftier', 'jj_to_jjs': 'thriftiest'},
 'throaty': {'jj_to_jjr': 'throatier', 'jj_to_jjs': 'throatiest'},
 'tiddly': {'jj_to_jjr': 'tiddlier', 'jj_to_jjs': 'tiddliest'},
 'tinny': {'jj_to_jjr': 'tinnier', 'jj_to_jjs': 'tinniest'},
 'tippy': {'jj_to_jjr': 'tippier', 'jj_to_jjs': 'tippiest'},
 'tipsy': {'jj_to_jjr': 'tipsier', 'jj_to_jjs': 'tipsiest'},
 'tony': {'jj_to_jjr': 'tonier', 'jj_to_jjs': 'toniest'},
 'touchy': {'jj_to_jjr': 'touchier', 'jj_to_jjs': 'touchiest'},
 'trashy': {'jj_to_jjr': 'trashier', 'jj_to_jjs': 'trashiest'},
 'trusty': {'jj_to_jjr': 'trustier', 'jj_to_jjs': 'trustiest'},
 'tubby': {'jj_to_jjr': 'tubbier', 'jj_to_jjs': 'tubbiest'},
 'uncanny': {'jj_to_jjr': 'uncannier', 'jj_to_jjs': 'uncanniest'},
 'unco': {'jj_to_jjr': 'uncoer', 'jj_to_jjs': 'uncoest'},
 'uneasy': {'jj_to_jjr': 'uneasier', 'jj_to_jjs': 'uneasiest'},
 'unfriendly': {'jj_to_jjr': 'unfriendlier', 'jj_to_jjs': 'unfriendliest'},
 'unhappy': {'jj_to_jjr': 'unhappier', 'jj_to_jjs': 'unhappiest'},
 'unholy': {'jj_to_jjr': 'unholier', 'jj_to_jjs': 'unholiest'},
 'unkind': {'jj_to_jjr': 'unkinder', 'jj_to_jjs': 'unkindest'},
 'unlikely': {'jj_to_jjr': 'unlikelier', 'jj_to_jjs': 'unlikeliest'},
 'unlucky': {'jj_to_jjr': 'unluckier', 'jj_to_jjs': 'unluckiest'},
 'unsexy': {'jj_to_jjr': 'unsexier', 'jj_to_jjs': 'unsexiest'},
 'unstuffy': {'jj_to_jjr': 'unstuffier', 'jj_to_jjs': 'unstuffiest'},
 'untidy': {'jj_to_jjr': 'untidier', 'jj_to_jjs': 'untidiest'},
 'vain': {'jj_to_jjr': 'vainer', 'jj_to_jjs': 'vainest'},
 'vile': {'jj_to_jjr': 'viler', 'jj_to_jjs': 'vilest'},
 'wacky': {'jj_to_jjr': 'wackier', 'jj_to_jjs': 'wackiest'},
 'wary': {'jj_to_jjr': 'warier', 'jj_to_jjs': 'wariest'},
 'wavy': {'jj_to_jjr': 'wavier', 'jj_to_jjs': 'waviest'},
 'weedy': {'jj_to_jjr': 'weedier', 'jj_to_jjs': 'weediest'},
 'weeny': {'jj_to_jjr': 'weenier', 'jj_to_jjs': 'weeniest'},
 'weensy': {'jj_to_jjr': 'weensier', 'jj_to_jjs': 'weensiest'},
 'weighty': {'jj_to_jjr': 'weightier', 'jj_to_jjs': 'weightiest'},
 'whiny': {'jj_to_jjr': 'whinier', 'jj_to_jjs': 'whiniest'},
 'wieldy': {'jj_to_jjr': 'wieldier', 'jj_to_jjs': 'wieldiest'},
 'wily': {'jj_to_jjr': 'wilier', 'jj_to_jjs': 'wiliest'},
 'winy': {'jj_to_jjr': 'winier', 'jj_to_jjs': 'winiest'},
 'witty': {'jj_to_jjr': 'wittier', 'jj_to_jjs': 'wittiest'},
 'wonky': {'jj_to_jjr': 'wonkier', 'jj_to_jjs': 'wonkiest'},
 'wooly': {'jj_to_jjr': 'woolier', 'jj_to_jjs': 'wooliest'},
 'woozy': {'jj_to_jjr': 'woozier', 'jj_to_jjs': 'wooziest'},
 'worldly': {'jj_to_jjr': 'worldlier', 'jj_to_jjs': 'worldliest'},
 'wry': {'jj_to_jjr': 'wryer', 'jj_to_jjs': 'wryest'},
 'wussy': {'jj_to_jjr': 'wussier', 'jj_to_jjs': 'wussiest'},
 'zippy': {'jj_to_jjr': 'zippier', 'jj_to_jjs': 'zippiest'},
 'hacky': {'jj_to_jjr': 'hackier', 'jj_to_jjs': 'hackiest'},
 'crusty': {'jj_to_jjr': 'crustier', 'jj_to_jjs': 'crustiest'},
 'twitchy': {'jj_to_jjr': 'twitchier', 'jj_to_jjs': 'twitchiest'},
 'superdainty': {'jj_to_jjr': 'superdaintier', 'jj_to_jjs': 'superdaintiest'},
 'handsy': {'jj_to_jjr': 'handsier', 'jj_to_jjs': 'handsiest'},
 'high-resolution': {'jj_to_jjr': 'higher-resolution', 'jj_to_jjs': 'highest-resolution'},
 'high-risk': {'jj_to_jjr': 'higher-risk', 'jj_to_jjs': 'highest-risk'},
 'mothy': {'jj_to_jjr': 'mothier', 'jj_to_jjs': 'mothiest'},
 'brash': {'jj_to_jjr': 'brasher', 'jj_to_jjs': 'brashest'},
 'classy': {'jj_to_jjr': 'classier', 'jj_to_jjs': 'classiest'},
 'corny': {'jj_to_jjr': 'cornier', 'jj_to_jjs': 'corniest'},
 'dense': {'jj_to_jjr': 'denser', 'jj_to_jjs': 'densest'},
 'leaky': {'jj_to_jjr': 'leakier', 'jj_to_jjs': 'leakiest'},
 'soon': {'rb_to_rbr': 'sooner', 'rb_to_rbs': 'soonest'},
 'snow ': {'nn_to_vbg': 'snowing'},
 'aahed': {'vbd_eq_vbn': ''},
 'abacinated': {'vbd_eq_vbn': ''},
 'abased': {'vbd_eq_vbn': ''},
 'abated': {'vbd_eq_vbn': ''},
 'abdicated': {'vbd_eq_vbn': ''},
 'abducted': {'vbd_eq_vbn': ''},
 'aberrated': {'vbd_eq_vbn': ''},
 'abetted': {'vbd_eq_vbn': ''},
 'abhorred': {'vbd_eq_vbn': ''},
 'abided': {'vbd_eq_vbn': ''},
 'ablactated': {'vbd_eq_vbn': ''},
 'ablated': {'vbd_eq_vbn': ''},
 'abolished': {'vbd_eq_vbn': ''},
 'abominated': {'vbd_eq_vbn': ''},
 'aborted': {'vbd_eq_vbn': ''},
 'abought': {'vbd_eq_vbn': ''},
 'abounded': {'vbd_eq_vbn': ''},
 'about-faced': {'vbd_eq_vbn': ''},
 'abraded': {'vbd_eq_vbn': ''},
 'abrased': {'vbd_eq_vbn': ''},
 'abrogated': {'vbd_eq_vbn': ''},
 'abscessed': {'vbd_eq_vbn': ''},
 'abscised': {'vbd_eq_vbn': ''},
 'absconded': {'vbd_eq_vbn': ''},
 'absented': {'vbd_eq_vbn': ''},
 'absolved': {'vbd_eq_vbn': ''},
 'absquatulated': {'vbd_eq_vbn': ''},
 'abstained': {'vbd_eq_vbn': ''},
 'abutted': {'vbd_eq_vbn': ''},
 'acceded': {'vbd_eq_vbn': ''},
 'accelerated': {'vbd_eq_vbn': ''},
 'accentuated': {'vbd_eq_vbn': ''},
 'accessioned': {'vbd_eq_vbn': ''},
 'acclimated': {'vbd_eq_vbn': ''},
 'acclimatised': {'vbd_eq_vbn': ''},
 'acclimatized': {'vbd_eq_vbn': ''},
 'accoladed': {'vbd_eq_vbn': ''},
 'accommodated': {'vbd_eq_vbn': ''},
 'accorded': {'vbd_eq_vbn': ''},
 'accosted': {'vbd_eq_vbn': ''},
 'accoutered': {'vbd_eq_vbn': ''},
 'accoutred': {'vbd_eq_vbn': ''},
 'accreted': {'vbd_eq_vbn': ''},
 'accrued': {'vbd_eq_vbn': ''},
 'acculturated': {'vbd_eq_vbn': ''},
 'accumulated': {'vbd_eq_vbn': ''},
 'aced': {'vbd_eq_vbn': ''},
 'acerbated': {'vbd_eq_vbn': ''},
 'acetified': {'vbd_eq_vbn': ''},
 'acetylated': {'vbd_eq_vbn': ''},
 'acetylised': {'vbd_eq_vbn': ''},
 'acetylized': {'vbd_eq_vbn': ''},
 'ached': {'vbd_eq_vbn': ''},
 'achromatised': {'vbd_eq_vbn': ''},
 'achromatized': {'vbd_eq_vbn': ''},
 'acid-washed': {'vbd_eq_vbn': ''},
 'acidified': {'vbd_eq_vbn': ''},
 'acidulated': {'vbd_eq_vbn': ''},
 'acquiesced': {'vbd_eq_vbn': ''},
 'acquitted': {'vbd_eq_vbn': ''},
 'actioned': {'vbd_eq_vbn': ''},
 'activated': {'vbd_eq_vbn': ''},
 'actualised': {'vbd_eq_vbn': ''},
 'actualized': {'vbd_eq_vbn': ''},
 'actuated': {'vbd_eq_vbn': ''},
 'acuminated': {'vbd_eq_vbn': ''},
 'acupunctured': {'vbd_eq_vbn': ''},
 'ad-libbed': {'vbd_eq_vbn': ''},
 'addled': {'vbd_eq_vbn': ''},
 'adduced': {'vbd_eq_vbn': ''},
 'adducted': {'vbd_eq_vbn': ''},
 'adhered': {'vbd_eq_vbn': ''},
 'adjoined': {'vbd_eq_vbn': ''},
 'adjourned': {'vbd_eq_vbn': ''},
 'adjudged': {'vbd_eq_vbn': ''},
 'adjudicated': {'vbd_eq_vbn': ''},
 'adjured': {'vbd_eq_vbn': ''},
 'admeasured': {'vbd_eq_vbn': ''},
 'administered': {'vbd_eq_vbn': ''},
 'administrated': {'vbd_eq_vbn': ''},
 'admixed': {'vbd_eq_vbn': ''},
 'admonished': {'vbd_eq_vbn': ''},
 'adolesced': {'vbd_eq_vbn': ''},
 'adored': {'vbd_eq_vbn': ''},
 'adorned': {'vbd_eq_vbn': ''},
 'adsorbed': {'vbd_eq_vbn': ''},
 'adulated': {'vbd_eq_vbn': ''},
 'adulterated': {'vbd_eq_vbn': ''},
 'adumbrated': {'vbd_eq_vbn': ''},
 'advected': {'vbd_eq_vbn': ''},
 'adventured': {'vbd_eq_vbn': ''},
 'advertised': {'vbd_eq_vbn': ''},
 'advocated': {'vbd_eq_vbn': ''},
 'aerated': {'vbd_eq_vbn': ''},
 'aerosolised': {'vbd_eq_vbn': ''},
 'aerosolized': {'vbd_eq_vbn': ''},
 'affiliated': {'vbd_eq_vbn': ''},
 'affixed': {'vbd_eq_vbn': ''},
 'afflicted': {'vbd_eq_vbn': ''},
 'afforded': {'vbd_eq_vbn': ''},
 'afforested': {'vbd_eq_vbn': ''},
 'affrighted': {'vbd_eq_vbn': ''},
 'affronted': {'vbd_eq_vbn': ''},
 'agglomerated': {'vbd_eq_vbn': ''},
 'agglutinated': {'vbd_eq_vbn': ''},
 'aggrandised': {'vbd_eq_vbn': ''},
 'aggrandized': {'vbd_eq_vbn': ''},
 'aggregated': {'vbd_eq_vbn': ''},
 'ailed': {'vbd_eq_vbn': ''},
 'air-dropped': {'vbd_eq_vbn': ''},
 'air-freighted': {'vbd_eq_vbn': ''},
 'airbrushed': {'vbd_eq_vbn': ''},
 'airdropped': {'vbd_eq_vbn': ''},
 'airlifted': {'vbd_eq_vbn': ''},
 'airmailed': {'vbd_eq_vbn': ''},
 'alerted': {'vbd_eq_vbn': ''},
 'aliened': {'vbd_eq_vbn': ''},
 'alighted': {'vbd_eq_vbn': ''},
 'aligned': {'vbd_eq_vbn': ''},
 'alimented': {'vbd_eq_vbn': ''},
 'alined': {'vbd_eq_vbn': ''},
 'alit': {'vbd_eq_vbn': ''},
 'allayed': {'vbd_eq_vbn': ''},
 'alleviated': {'vbd_eq_vbn': ''},
 'alliterated': {'vbd_eq_vbn': ''},
 'allocated': {'vbd_eq_vbn': ''},
 'allowanced': {'vbd_eq_vbn': ''},
 'alloyed': {'vbd_eq_vbn': ''},
 'alluded': {'vbd_eq_vbn': ''},
 'allured': {'vbd_eq_vbn': ''},
 'alphabetised': {'vbd_eq_vbn': ''},
 'alphabetized': {'vbd_eq_vbn': ''},
 'alternated': {'vbd_eq_vbn': ''},
 'amalgamated': {'vbd_eq_vbn': ''},
 'amassed': {'vbd_eq_vbn': ''},
 'ambitioned': {'vbd_eq_vbn': ''},
 'ambled': {'vbd_eq_vbn': ''},
 'ambuscaded': {'vbd_eq_vbn': ''},
 'ambushed': {'vbd_eq_vbn': ''},
 'ameliorated': {'vbd_eq_vbn': ''},
 'Americanised': {'vbd_eq_vbn': ''},
 'Americanized': {'vbd_eq_vbn': ''},
 'amnestied': {'vbd_eq_vbn': ''},
 'amortised': {'vbd_eq_vbn': ''},
 'amortized': {'vbd_eq_vbn': ''},
 'amped': {'vbd_eq_vbn': ''},
 'amplified': {'vbd_eq_vbn': ''},
 'amputated': {'vbd_eq_vbn': ''},
 'anaesthetised': {'vbd_eq_vbn': ''},
 'anaesthetized': {'vbd_eq_vbn': ''},
 'analogized': {'vbd_eq_vbn': ''},
 'analyzed': {'vbd_eq_vbn': ''},
 'anatomised': {'vbd_eq_vbn': ''},
 'anatomized': {'vbd_eq_vbn': ''},
 'anchored': {'vbd_eq_vbn': ''},
 'anesthetised': {'vbd_eq_vbn': ''},
 'anesthetized': {'vbd_eq_vbn': ''},
 'angered': {'vbd_eq_vbn': ''},
 'anglicised': {'vbd_eq_vbn': ''},
 'anglicized': {'vbd_eq_vbn': ''},
 'animadverted': {'vbd_eq_vbn': ''},
 'annealed': {'vbd_eq_vbn': ''},
 'annexed': {'vbd_eq_vbn': ''},
 'annihilated': {'vbd_eq_vbn': ''},
 'annotated': {'vbd_eq_vbn': ''},
 'annualised': {'vbd_eq_vbn': ''},
 'annulled': {'vbd_eq_vbn': ''},
 'anointed': {'vbd_eq_vbn': ''},
 'anonymised': {'vbd_eq_vbn': ''},
 'anonymized': {'vbd_eq_vbn': ''},
 'antagonised': {'vbd_eq_vbn': ''},
 'antagonized': {'vbd_eq_vbn': ''},
 'anted': {'vbd_eq_vbn': ''},
 'antedated': {'vbd_eq_vbn': ''},
 'anteed': {'vbd_eq_vbn': ''},
 'anthropologised': {'vbd_eq_vbn': ''},
 'anthropologized': {'vbd_eq_vbn': ''},
 'anthropomorphized': {'vbd_eq_vbn': ''},
 'aped': {'vbd_eq_vbn': ''},
 'apologised': {'vbd_eq_vbn': ''},
 'apostatized': {'vbd_eq_vbn': ''},
 'apparated': {'vbd_eq_vbn': ''},
 'appareled': {'vbd_eq_vbn': ''},
 'apparelled': {'vbd_eq_vbn': ''},
 'appeased': {'vbd_eq_vbn': ''},
 'appended': {'vbd_eq_vbn': ''},
 'appertained': {'vbd_eq_vbn': ''},
 'applauded': {'vbd_eq_vbn': ''},
 'appliqued': {'vbd_eq_vbn': ''},
 'apportioned': {'vbd_eq_vbn': ''},
 'appraised': {'vbd_eq_vbn': ''},
 'apprehended': {'vbd_eq_vbn': ''},
 'apprenticed': {'vbd_eq_vbn': ''},
 'apprised': {'vbd_eq_vbn': ''},
 'apprized': {'vbd_eq_vbn': ''},
 'aproned': {'vbd_eq_vbn': ''},
 'aquaplaned': {'vbd_eq_vbn': ''},
 'arbitraged': {'vbd_eq_vbn': ''},
 'arbitrated': {'vbd_eq_vbn': ''},
 'arcaded': {'vbd_eq_vbn': ''},
 'arced': {'vbd_eq_vbn': ''},
 'archaised': {'vbd_eq_vbn': ''},
 'archaized': {'vbd_eq_vbn': ''},
 'archived': {'vbd_eq_vbn': ''},
 'arcked': {'vbd_eq_vbn': ''},
 'aroused': {'vbd_eq_vbn': ''},
 'arraigned': {'vbd_eq_vbn': ''},
 'arrayed': {'vbd_eq_vbn': ''},
 'arrogated': {'vbd_eq_vbn': ''},
 'arsed': {'vbd_eq_vbn': ''},
 'ascended': {'vbd_eq_vbn': ''},
 'ascertained': {'vbd_eq_vbn': ''},
 'ascribed': {'vbd_eq_vbn': ''},
 'asphalted': {'vbd_eq_vbn': ''},
 'asphyxiated': {'vbd_eq_vbn': ''},
 'aspirated': {'vbd_eq_vbn': ''},
 'aspired': {'vbd_eq_vbn': ''},
 'assailed': {'vbd_eq_vbn': ''},
 'assassinated': {'vbd_eq_vbn': ''},
 'assaulted': {'vbd_eq_vbn': ''},
 'assayed': {'vbd_eq_vbn': ''},
 'assembled': {'vbd_eq_vbn': ''},
 'assented': {'vbd_eq_vbn': ''},
 'asserted': {'vbd_eq_vbn': ''},
 'asseverated': {'vbd_eq_vbn': ''},
 'assimilated': {'vbd_eq_vbn': ''},
 'assoiled': {'vbd_eq_vbn': ''},
 'assuaged': {'vbd_eq_vbn': ''},
 'asterisked': {'vbd_eq_vbn': ''},
 'atom-bombed': {'vbd_eq_vbn': ''},
 'atomised': {'vbd_eq_vbn': ''},
 'atomized': {'vbd_eq_vbn': ''},
 'atoned': {'vbd_eq_vbn': ''},
 'atrophied': {'vbd_eq_vbn': ''},
 'attained': {'vbd_eq_vbn': ''},
 'attainted': {'vbd_eq_vbn': ''},
 'attenuated': {'vbd_eq_vbn': ''},
 'attested': {'vbd_eq_vbn': ''},
 'attributed': {'vbd_eq_vbn': ''},
 'auctioned': {'vbd_eq_vbn': ''},
 'audiotaped': {'vbd_eq_vbn': ''},
 'audited': {'vbd_eq_vbn': ''},
 'auditioned': {'vbd_eq_vbn': ''},
 'augmented': {'vbd_eq_vbn': ''},
 'augured': {'vbd_eq_vbn': ''},
 'authenticated': {'vbd_eq_vbn': ''},
 'authored': {'vbd_eq_vbn': ''},
 'authorised': {'vbd_eq_vbn': ''},
 'authorized': {'vbd_eq_vbn': ''},
 'autoclaved': {'vbd_eq_vbn': ''},
 'autocorrected': {'vbd_eq_vbn': ''},
 'autoed': {'vbd_eq_vbn': ''},
 'autographed': {'vbd_eq_vbn': ''},
 'automatized': {'vbd_eq_vbn': ''},
 'availed': {'vbd_eq_vbn': ''},
 'avenged': {'vbd_eq_vbn': ''},
 'averred': {'vbd_eq_vbn': ''},
 'averted': {'vbd_eq_vbn': ''},
 'awaited': {'vbd_eq_vbn': ''},
 'awakened': {'vbd_eq_vbn': ''},
 'axed': {'vbd_eq_vbn': ''},
 'baaed': {'vbd_eq_vbn': ''},
 'babbitted': {'vbd_eq_vbn': ''},
 'babbled': {'vbd_eq_vbn': ''},
 'babied': {'vbd_eq_vbn': ''},
 'baby-sat': {'vbd_eq_vbn': ''},
 'babysat': {'vbd_eq_vbn': ''},
 'bachelored': {'vbd_eq_vbn': ''},
 'back-heeled': {'vbd_eq_vbn': ''},
 'backcrossed': {'vbd_eq_vbn': ''},
 'backdated': {'vbd_eq_vbn': ''},
 'backed': {'vbd_eq_vbn': ''},
 'backfired': {'vbd_eq_vbn': ''},
 'backgrounded': {'vbd_eq_vbn': ''},
 'backheeled': {'vbd_eq_vbn': ''},
 'backlogged': {'vbd_eq_vbn': ''},
 'backpacked': {'vbd_eq_vbn': ''},
 'backpedaled': {'vbd_eq_vbn': ''},
 'backpedalled': {'vbd_eq_vbn': ''},
 'backscattered': {'vbd_eq_vbn': ''},
 'backslapped': {'vbd_eq_vbn': ''},
 'backslid': {'vbd_eq_vbn': ''},
 'backstabbed': {'vbd_eq_vbn': ''},
 'backstitched': {'vbd_eq_vbn': ''},
 'backstopped': {'vbd_eq_vbn': ''},
 'backtracked': {'vbd_eq_vbn': ''},
 'bad-mouthed': {'vbd_eq_vbn': ''},
 'badgered': {'vbd_eq_vbn': ''},
 'badmouthed': {'vbd_eq_vbn': ''},
 'baffled': {'vbd_eq_vbn': ''},
 'bagged': {'vbd_eq_vbn': ''},
 'bailed': {'vbd_eq_vbn': ''},
 'baited': {'vbd_eq_vbn': ''},
 'baled': {'vbd_eq_vbn': ''},
 'balkanised': {'vbd_eq_vbn': ''},
 'Balkanized': {'vbd_eq_vbn': ''},
 'balked': {'vbd_eq_vbn': ''},
 'ballasted': {'vbd_eq_vbn': ''},
 'balled': {'vbd_eq_vbn': ''},
 'ballooned': {'vbd_eq_vbn': ''},
 'balloted': {'vbd_eq_vbn': ''},
 'ballsed': {'vbd_eq_vbn': ''},
 'ballyhooed': {'vbd_eq_vbn': ''},
 'bamboozled': {'vbd_eq_vbn': ''},
 'bandaged': {'vbd_eq_vbn': ''},
 'bandied': {'vbd_eq_vbn': ''},
 'banished': {'vbd_eq_vbn': ''},
 'banked': {'vbd_eq_vbn': ''},
 'bankrolled': {'vbd_eq_vbn': ''},
 'bankrupted': {'vbd_eq_vbn': ''},
 'banqueted': {'vbd_eq_vbn': ''},
 'bantered': {'vbd_eq_vbn': ''},
 'baptised': {'vbd_eq_vbn': ''},
 'baptized': {'vbd_eq_vbn': ''},
 'barbarised': {'vbd_eq_vbn': ''},
 'barbarized': {'vbd_eq_vbn': ''},
 'barbecued': {'vbd_eq_vbn': ''},
 'barbequed': {'vbd_eq_vbn': ''},
 'barbered': {'vbd_eq_vbn': ''},
 'barded': {'vbd_eq_vbn': ''},
 'bared': {'vbd_eq_vbn': ''},
 'barfed': {'vbd_eq_vbn': ''},
 'bargained': {'vbd_eq_vbn': ''},
 'barged': {'vbd_eq_vbn': ''},
 'barked': {'vbd_eq_vbn': ''},
 'barnstormed': {'vbd_eq_vbn': ''},
 'barracked': {'vbd_eq_vbn': ''},
 'barraged': {'vbd_eq_vbn': ''},
 'barreled': {'vbd_eq_vbn': ''},
 'barrelled': {'vbd_eq_vbn': ''},
 'barricaded': {'vbd_eq_vbn': ''},
 'bartered': {'vbd_eq_vbn': ''},
 'bashed': {'vbd_eq_vbn': ''},
 'basked': {'vbd_eq_vbn': ''},
 'bastardised': {'vbd_eq_vbn': ''},
 'bastardized': {'vbd_eq_vbn': ''},
 'basted': {'vbd_eq_vbn': ''},
 'bastinadoed': {'vbd_eq_vbn': ''},
 'batched': {'vbd_eq_vbn': ''},
 'battened': {'vbd_eq_vbn': ''},
 'baulked': {'vbd_eq_vbn': ''},
 'bawled': {'vbd_eq_vbn': ''},
 'bayed': {'vbd_eq_vbn': ''},
 'bayoneted': {'vbd_eq_vbn': ''},
 'bayonetted': {'vbd_eq_vbn': ''},
 'beaconed': {'vbd_eq_vbn': ''},
 'beaned': {'vbd_eq_vbn': ''},
 'beatified': {'vbd_eq_vbn': ''},
 'beautified': {'vbd_eq_vbn': ''},
 'beavered': {'vbd_eq_vbn': ''},
 'bebopped': {'vbd_eq_vbn': ''},
 'beckoned': {'vbd_eq_vbn': ''},
 'beclouded': {'vbd_eq_vbn': ''},
 'bed-hopped': {'vbd_eq_vbn': ''},
 'bedaubed': {'vbd_eq_vbn': ''},
 'bedded': {'vbd_eq_vbn': ''},
 'bedecked': {'vbd_eq_vbn': ''},
 'bedeviled': {'vbd_eq_vbn': ''},
 'bedevilled': {'vbd_eq_vbn': ''},
 'bedighted': {'vbd_eq_vbn': ''},
 'bedimmed': {'vbd_eq_vbn': ''},
 'bedizened': {'vbd_eq_vbn': ''},
 'beefed': {'vbd_eq_vbn': ''},
 'beelined': {'vbd_eq_vbn': ''},
 'beeped': {'vbd_eq_vbn': ''},
 'beetled': {'vbd_eq_vbn': ''},
 'befitted': {'vbd_eq_vbn': ''},
 'befogged': {'vbd_eq_vbn': ''},
 'befooled': {'vbd_eq_vbn': ''},
 'befouled': {'vbd_eq_vbn': ''},
 'befriended': {'vbd_eq_vbn': ''},
 'beggared': {'vbd_eq_vbn': ''},
 'begged': {'vbd_eq_vbn': ''},
 'begrudged': {'vbd_eq_vbn': ''},
 'beguiled': {'vbd_eq_vbn': ''},
 'beheaded': {'vbd_eq_vbn': ''},
 'beheld': {'vbd_eq_vbn': ''},
 'behooved': {'vbd_eq_vbn': ''},
 'behoved': {'vbd_eq_vbn': ''},
 'beined': {'vbd_eq_vbn': ''},
 'bejeweled': {'vbd_eq_vbn': ''},
 'belabored': {'vbd_eq_vbn': ''},
 'belaboured': {'vbd_eq_vbn': ''},
 'belayed': {'vbd_eq_vbn': ''},
 'belched': {'vbd_eq_vbn': ''},
 'belied': {'vbd_eq_vbn': ''},
 'belittled': {'vbd_eq_vbn': ''},
 'bellied': {'vbd_eq_vbn': ''},
 'bellowed': {'vbd_eq_vbn': ''},
 'belly-flopped': {'vbd_eq_vbn': ''},
 'bellyached': {'vbd_eq_vbn': ''},
 'bellyflopped': {'vbd_eq_vbn': ''},
 'bemoaned': {'vbd_eq_vbn': ''},
 'bemocked': {'vbd_eq_vbn': ''},
 'benched': {'vbd_eq_vbn': ''},
 'benchmarked': {'vbd_eq_vbn': ''},
 'benefited': {'vbd_eq_vbn': ''},
 'benefitted': {'vbd_eq_vbn': ''},
 'benniseed': {'vbd_eq_vbn': ''},
 'benweed': {'vbd_eq_vbn': ''},
 'bequeathed': {'vbd_eq_vbn': ''},
 'berated': {'vbd_eq_vbn': ''},
 'bereft': {'vbd_eq_vbn': ''},
 'berried': {'vbd_eq_vbn': ''},
 'berthed': {'vbd_eq_vbn': ''},
 'beseeched': {'vbd_eq_vbn': ''},
 'beseemed': {'vbd_eq_vbn': ''},
 'besieged': {'vbd_eq_vbn': ''},
 'besmeared': {'vbd_eq_vbn': ''},
 'besmirched': {'vbd_eq_vbn': ''},
 'besought': {'vbd_eq_vbn': ''},
 'bespattered': {'vbd_eq_vbn': ''},
 'bespoke': {'vbd_eq_vbn': ''},
 'bespoted': {'vbd_eq_vbn': ''},
 'bested': {'vbd_eq_vbn': ''},
 'bestialised': {'vbd_eq_vbn': ''},
 'bestialized': {'vbd_eq_vbn': ''},
 'bestirred': {'vbd_eq_vbn': ''},
 'bestowed': {'vbd_eq_vbn': ''},
 'bestrewed': {'vbd_eq_vbn': ''},
 'bethought': {'vbd_eq_vbn': ''},
 'betided': {'vbd_eq_vbn': ''},
 'betokened': {'vbd_eq_vbn': ''},
 'betrayed': {'vbd_eq_vbn': ''},
 'betted': {'vbd_eq_vbn': ''},
 'beveled': {'vbd_eq_vbn': ''},
 'bewailed': {'vbd_eq_vbn': ''},
 'bewared': {'vbd_eq_vbn': ''},
 'bewitched': {'vbd_eq_vbn': ''},
 'bewrayed': {'vbd_eq_vbn': ''},
 'biassed': {'vbd_eq_vbn': ''},
 'bibbed': {'vbd_eq_vbn': ''},
 'bickered': {'vbd_eq_vbn': ''},
 'bided': {'vbd_eq_vbn': ''},
 'biffed': {'vbd_eq_vbn': ''},
 'bifurcated': {'vbd_eq_vbn': ''},
 'bigged': {'vbd_eq_vbn': ''},
 'bighted': {'vbd_eq_vbn': ''},
 'bilged': {'vbd_eq_vbn': ''},
 'bilked': {'vbd_eq_vbn': ''},
 'billboarded': {'vbd_eq_vbn': ''},
 'billeted': {'vbd_eq_vbn': ''},
 'billowed': {'vbd_eq_vbn': ''},
 'bilsted': {'vbd_eq_vbn': ''},
 'binged': {'vbd_eq_vbn': ''},
 'binned': {'vbd_eq_vbn': ''},
 'biodegraded': {'vbd_eq_vbn': ''},
 'birched': {'vbd_eq_vbn': ''},
 'birded': {'vbd_eq_vbn': ''},
 'birdied': {'vbd_eq_vbn': ''},
 'birthed': {'vbd_eq_vbn': ''},
 'bisected': {'vbd_eq_vbn': ''},
 'bitched': {'vbd_eq_vbn': ''},
 'bitted': {'vbd_eq_vbn': ''},
 'bittered': {'vbd_eq_vbn': ''},
 'bivouacked': {'vbd_eq_vbn': ''},
 'blabbed': {'vbd_eq_vbn': ''},
 'blabbered': {'vbd_eq_vbn': ''},
 'blackballed': {'vbd_eq_vbn': ''},
 'blacked': {'vbd_eq_vbn': ''},
 'blackened': {'vbd_eq_vbn': ''},
 'blackguarded': {'vbd_eq_vbn': ''},
 'blackjacked': {'vbd_eq_vbn': ''},
 'blacklisted': {'vbd_eq_vbn': ''},
 'blackmailed': {'vbd_eq_vbn': ''},
 'blanched': {'vbd_eq_vbn': ''},
 'blandished': {'vbd_eq_vbn': ''},
 'blanked': {'vbd_eq_vbn': ''},
 'blanketed': {'vbd_eq_vbn': ''},
 'blared': {'vbd_eq_vbn': ''},
 'blasphemed': {'vbd_eq_vbn': ''},
 'blathered': {'vbd_eq_vbn': ''},
 'blazed': {'vbd_eq_vbn': ''},
 'blazoned': {'vbd_eq_vbn': ''},
 'bleached': {'vbd_eq_vbn': ''},
 'bleared': {'vbd_eq_vbn': ''},
 'bleated': {'vbd_eq_vbn': ''},
 'bled': {'vbd_eq_vbn': ''},
 'bleeped': {'vbd_eq_vbn': ''},
 'blenched': {'vbd_eq_vbn': ''},
 'blended': {'vbd_eq_vbn': ''},
 'blent': {'vbd_eq_vbn': ''},
 'blest': {'vbd_eq_vbn': ''},
 'blethered': {'vbd_eq_vbn': ''},
 'blighted': {'vbd_eq_vbn': ''},
 'blindfolded': {'vbd_eq_vbn': ''},
 'blindsided': {'vbd_eq_vbn': ''},
 'blinked': {'vbd_eq_vbn': ''},
 'blipped': {'vbd_eq_vbn': ''},
 'blithered': {'vbd_eq_vbn': ''},
 'blitzed': {'vbd_eq_vbn': ''},
 'blobbed': {'vbd_eq_vbn': ''},
 'blockaded': {'vbd_eq_vbn': ''},
 'blogged': {'vbd_eq_vbn': ''},
 'bloodied': {'vbd_eq_vbn': ''},
 'bloomed': {'vbd_eq_vbn': ''},
 'blossomed': {'vbd_eq_vbn': ''},
 'blotted': {'vbd_eq_vbn': ''},
 'bloused': {'vbd_eq_vbn': ''},
 'bloviated': {'vbd_eq_vbn': ''},
 'blow-dried': {'vbd_eq_vbn': ''},
 'blubbed': {'vbd_eq_vbn': ''},
 'blubbered': {'vbd_eq_vbn': ''},
 'bludgeoned': {'vbd_eq_vbn': ''},
 'blue-penciled': {'vbd_eq_vbn': ''},
 'blue-pencilled': {'vbd_eq_vbn': ''},
 'blueprinted': {'vbd_eq_vbn': ''},
 'bluffed': {'vbd_eq_vbn': ''},
 'blundered': {'vbd_eq_vbn': ''},
 'blunted': {'vbd_eq_vbn': ''},
 'blurted': {'vbd_eq_vbn': ''},
 'blushed': {'vbd_eq_vbn': ''},
 'blustered': {'vbd_eq_vbn': ''},
 'boasted': {'vbd_eq_vbn': ''},
 'bobbed': {'vbd_eq_vbn': ''},
 'bobbled': {'vbd_eq_vbn': ''},
 'bobsledded': {'vbd_eq_vbn': ''},
 'bobsleighed': {'vbd_eq_vbn': ''},
 'boded': {'vbd_eq_vbn': ''},
 'bodged': {'vbd_eq_vbn': ''},
 'bodied': {'vbd_eq_vbn': ''},
 'bogarted': {'vbd_eq_vbn': ''},
 'bogged': {'vbd_eq_vbn': ''},
 'boggled': {'vbd_eq_vbn': ''},
 'bollocked': {'vbd_eq_vbn': ''},
 'bolstered': {'vbd_eq_vbn': ''},
 'bolted': {'vbd_eq_vbn': ''},
 'bombarded': {'vbd_eq_vbn': ''},
 'bombinated': {'vbd_eq_vbn': ''},
 'bonked': {'vbd_eq_vbn': ''},
 'booed': {'vbd_eq_vbn': ''},
 'book-ended': {'vbd_eq_vbn': ''},
 'bookended': {'vbd_eq_vbn': ''},
 'bookmarked': {'vbd_eq_vbn': ''},
 'boomed': {'vbd_eq_vbn': ''},
 'boomeranged': {'vbd_eq_vbn': ''},
 'boosted': {'vbd_eq_vbn': ''},
 'bootlegged': {'vbd_eq_vbn': ''},
 'bootlicked': {'vbd_eq_vbn': ''},
 'bootstrapped': {'vbd_eq_vbn': ''},
 'boozed': {'vbd_eq_vbn': ''},
 'bopped': {'vbd_eq_vbn': ''},
 'bosomed': {'vbd_eq_vbn': ''},
 'botched': {'vbd_eq_vbn': ''},
 'bottlefed': {'vbd_eq_vbn': ''},
 'bottlenecked': {'vbd_eq_vbn': ''},
 'bottomed': {'vbd_eq_vbn': ''},
 'bowdlerised': {'vbd_eq_vbn': ''},
 'bowdlerized': {'vbd_eq_vbn': ''},
 'bowered': {'vbd_eq_vbn': ''},
 'boycotted': {'vbd_eq_vbn': ''},
 'braced': {'vbd_eq_vbn': ''},
 'bracketed': {'vbd_eq_vbn': ''},
 'bradded': {'vbd_eq_vbn': ''},
 'bragged': {'vbd_eq_vbn': ''},
 'Brailled': {'vbd_eq_vbn': ''},
 'brained': {'vbd_eq_vbn': ''},
 'brainstormed': {'vbd_eq_vbn': ''},
 'brainwashed': {'vbd_eq_vbn': ''},
 'braked': {'vbd_eq_vbn': ''},
 'brandied': {'vbd_eq_vbn': ''},
 'brandished': {'vbd_eq_vbn': ''},
 'bravoed': {'vbd_eq_vbn': ''},
 'brawled': {'vbd_eq_vbn': ''},
 'brayed': {'vbd_eq_vbn': ''},
 'brazened': {'vbd_eq_vbn': ''},
 'breached': {'vbd_eq_vbn': ''},
 'break-danced': {'vbd_eq_vbn': ''},
 'breakdanced': {'vbd_eq_vbn': ''},
 'breakfasted': {'vbd_eq_vbn': ''},
 'breamed': {'vbd_eq_vbn': ''},
 'breast-fed': {'vbd_eq_vbn': ''},
 'breastfed': {'vbd_eq_vbn': ''},
 'breathalysed': {'vbd_eq_vbn': ''},
 'breathalyzed': {'vbd_eq_vbn': ''},
 'bred': {'vbd_eq_vbn': ''},
 'breezed': {'vbd_eq_vbn': ''},
 'breveted': {'vbd_eq_vbn': ''},
 'brevetted': {'vbd_eq_vbn': ''},
 'brewed': {'vbd_eq_vbn': ''},
 'bribed': {'vbd_eq_vbn': ''},
 'bridled': {'vbd_eq_vbn': ''},
 'briefed': {'vbd_eq_vbn': ''},
 'brigaded': {'vbd_eq_vbn': ''},
 'brightened': {'vbd_eq_vbn': ''},
 'brimmed': {'vbd_eq_vbn': ''},
 'brined': {'vbd_eq_vbn': ''},
 'brisked': {'vbd_eq_vbn': ''},
 'bristled': {'vbd_eq_vbn': ''},
 'broached': {'vbd_eq_vbn': ''},
 'broadened': {'vbd_eq_vbn': ''},
 'broadsided': {'vbd_eq_vbn': ''},
 'broidered': {'vbd_eq_vbn': ''},
 'broiled': {'vbd_eq_vbn': ''},
 'brokered': {'vbd_eq_vbn': ''},
 'bromated': {'vbd_eq_vbn': ''},
 'brooded': {'vbd_eq_vbn': ''},
 'brooked': {'vbd_eq_vbn': ''},
 'brown-nosed': {'vbd_eq_vbn': ''},
 'browned': {'vbd_eq_vbn': ''},
 'browsed': {'vbd_eq_vbn': ''},
 'bruited': {'vbd_eq_vbn': ''},
 'brutalised': {'vbd_eq_vbn': ''},
 'brutalized': {'vbd_eq_vbn': ''},
 'bubbled': {'vbd_eq_vbn': ''},
 'buckled': {'vbd_eq_vbn': ''},
 'buckramed': {'vbd_eq_vbn': ''},
 'budded': {'vbd_eq_vbn': ''},
 'buddied': {'vbd_eq_vbn': ''},
 'budged': {'vbd_eq_vbn': ''},
 'buffaloed': {'vbd_eq_vbn': ''},
 'buffed': {'vbd_eq_vbn': ''},
 'buffered': {'vbd_eq_vbn': ''},
 'buffeted': {'vbd_eq_vbn': ''},
 'bugled': {'vbd_eq_vbn': ''},
 'bulged': {'vbd_eq_vbn': ''},
 'bulked': {'vbd_eq_vbn': ''},
 'bulldogged': {'vbd_eq_vbn': ''},
 'bulldozed': {'vbd_eq_vbn': ''},
 'bulled': {'vbd_eq_vbn': ''},
 'bulletined': {'vbd_eq_vbn': ''},
 'bullied': {'vbd_eq_vbn': ''},
 'bullshitted': {'vbd_eq_vbn': ''},
 'bulwarked': {'vbd_eq_vbn': ''},
 'bumbled': {'vbd_eq_vbn': ''},
 'bummed': {'vbd_eq_vbn': ''},
 'buncoed': {'vbd_eq_vbn': ''},
 'bundled': {'vbd_eq_vbn': ''},
 'bunged': {'vbd_eq_vbn': ''},
 'bunked': {'vbd_eq_vbn': ''},
 'bunkered': {'vbd_eq_vbn': ''},
 'bunkoed': {'vbd_eq_vbn': ''},
 'bunted': {'vbd_eq_vbn': ''},
 'buoyed': {'vbd_eq_vbn': ''},
 'burbled': {'vbd_eq_vbn': ''},
 'burdened': {'vbd_eq_vbn': ''},
 'burgeoned': {'vbd_eq_vbn': ''},
 'burglarized': {'vbd_eq_vbn': ''},
 'burgled': {'vbd_eq_vbn': ''},
 'burked': {'vbd_eq_vbn': ''},
 'burled': {'vbd_eq_vbn': ''},
 'burlesqued': {'vbd_eq_vbn': ''},
 'burnt': {'vbd_eq_vbn': ''},
 'burped': {'vbd_eq_vbn': ''},
 'burred': {'vbd_eq_vbn': ''},
 'burrowed': {'vbd_eq_vbn': ''},
 'bused': {'vbd_eq_vbn': ''},
 'busheled': {'vbd_eq_vbn': ''},
 'bushelled': {'vbd_eq_vbn': ''},
 'bushwhacked': {'vbd_eq_vbn': ''},
 'busied': {'vbd_eq_vbn': ''},
 'busked': {'vbd_eq_vbn': ''},
 'bussed': {'vbd_eq_vbn': ''},
 'bustled': {'vbd_eq_vbn': ''},
 'butted': {'vbd_eq_vbn': ''},
 'butterflied': {'vbd_eq_vbn': ''},
 'buttonholed': {'vbd_eq_vbn': ''},
 'buttressed': {'vbd_eq_vbn': ''},
 'buzzed': {'vbd_eq_vbn': ''},
 'bypassed': {'vbd_eq_vbn': ''},
 'cabbed': {'vbd_eq_vbn': ''},
 'cabined': {'vbd_eq_vbn': ''},
 'cached': {'vbd_eq_vbn': ''},
 'cachinnated': {'vbd_eq_vbn': ''},
 'cackled': {'vbd_eq_vbn': ''},
 'caddied': {'vbd_eq_vbn': ''},
 'cadged': {'vbd_eq_vbn': ''},
 'cajoled': {'vbd_eq_vbn': ''},
 'caked': {'vbd_eq_vbn': ''},
 'calcified': {'vbd_eq_vbn': ''},
 'calcimined': {'vbd_eq_vbn': ''},
 'calcined': {'vbd_eq_vbn': ''},
 'calendered': {'vbd_eq_vbn': ''},
 'calibrated': {'vbd_eq_vbn': ''},
 'calked': {'vbd_eq_vbn': ''},
 'callused': {'vbd_eq_vbn': ''},
 'calumniated': {'vbd_eq_vbn': ''},
 'calved': {'vbd_eq_vbn': ''},
 'cambered': {'vbd_eq_vbn': ''},
 'camouflaged': {'vbd_eq_vbn': ''},
 'canaled': {'vbd_eq_vbn': ''},
 'canalised': {'vbd_eq_vbn': ''},
 'canalized': {'vbd_eq_vbn': ''},
 'canalled': {'vbd_eq_vbn': ''},
 'cancelled': {'vbd_eq_vbn': ''},
 'candled': {'vbd_eq_vbn': ''},
 'candyweed': {'vbd_eq_vbn': ''},
 'caned': {'vbd_eq_vbn': ''},
 'cankered': {'vbd_eq_vbn': ''},
 'cannibalised': {'vbd_eq_vbn': ''},
 'cannibalized': {'vbd_eq_vbn': ''},
 'cannonballed': {'vbd_eq_vbn': ''},
 'cannoned': {'vbd_eq_vbn': ''},
 'canoed': {'vbd_eq_vbn': ''},
 'canonised': {'vbd_eq_vbn': ''},
 'canonized': {'vbd_eq_vbn': ''},
 'canoodled': {'vbd_eq_vbn': ''},
 'canted': {'vbd_eq_vbn': ''},
 'cantered': {'vbd_eq_vbn': ''},
 'cantoned': {'vbd_eq_vbn': ''},
 'canvassed': {'vbd_eq_vbn': ''},
 'caparisoned': {'vbd_eq_vbn': ''},
 'capered': {'vbd_eq_vbn': ''},
 'capeweed': {'vbd_eq_vbn': ''},
 'capitalised': {'vbd_eq_vbn': ''},
 'capitalized': {'vbd_eq_vbn': ''},
 'capitulated': {'vbd_eq_vbn': ''},
 'caprioled': {'vbd_eq_vbn': ''},
 'capsized': {'vbd_eq_vbn': ''},
 'capsuled': {'vbd_eq_vbn': ''},
 'capsulised': {'vbd_eq_vbn': ''},
 'capsulized': {'vbd_eq_vbn': ''},
 'captioned': {'vbd_eq_vbn': ''},
 'car-pooled': {'vbd_eq_vbn': ''},
 'caracoled': {'vbd_eq_vbn': ''},
 'caramelised': {'vbd_eq_vbn': ''},
 'caravaned': {'vbd_eq_vbn': ''},
 'caravanned': {'vbd_eq_vbn': ''},
 'carbonised': {'vbd_eq_vbn': ''},
 'carbureted': {'vbd_eq_vbn': ''},
 'carburetted': {'vbd_eq_vbn': ''},
 'carded': {'vbd_eq_vbn': ''},
 'careened': {'vbd_eq_vbn': ''},
 'careered': {'vbd_eq_vbn': ''},
 'caressed': {'vbd_eq_vbn': ''},
 'caricatured': {'vbd_eq_vbn': ''},
 'carjacked': {'vbd_eq_vbn': ''},
 'carnalised': {'vbd_eq_vbn': ''},
 'carnalized': {'vbd_eq_vbn': ''},
 'caroled': {'vbd_eq_vbn': ''},
 'carolled': {'vbd_eq_vbn': ''},
 'caromed': {'vbd_eq_vbn': ''},
 'caroused': {'vbd_eq_vbn': ''},
 'carped': {'vbd_eq_vbn': ''},
 'carpentered': {'vbd_eq_vbn': ''},
 'carpetweed': {'vbd_eq_vbn': ''},
 'carpooled': {'vbd_eq_vbn': ''},
 'carshared': {'vbd_eq_vbn': ''},
 'carted': {'vbd_eq_vbn': ''},
 'cartoned': {'vbd_eq_vbn': ''},
 'cartooned': {'vbd_eq_vbn': ''},
 'cartwheeled': {'vbd_eq_vbn': ''},
 'carved': {'vbd_eq_vbn': ''},
 'cascaded': {'vbd_eq_vbn': ''},
 'cased': {'vbd_eq_vbn': ''},
 'cashiered': {'vbd_eq_vbn': ''},
 'casketed': {'vbd_eq_vbn': ''},
 'castigated': {'vbd_eq_vbn': ''},
 'castrated': {'vbd_eq_vbn': ''},
 'cataloged': {'vbd_eq_vbn': ''},
 'catalogued': {'vbd_eq_vbn': ''},
 'catalysed': {'vbd_eq_vbn': ''},
 'catalyzed': {'vbd_eq_vbn': ''},
 'catapulted': {'vbd_eq_vbn': ''},
 'catcalled': {'vbd_eq_vbn': ''},
 'categorised': {'vbd_eq_vbn': ''},
 'categorized': {'vbd_eq_vbn': ''},
 'catered': {'vbd_eq_vbn': ''},
 'caterwauled': {'vbd_eq_vbn': ''},
 'cathected': {'vbd_eq_vbn': ''},
 'catnapped': {'vbd_eq_vbn': ''},
 'catted': {'vbd_eq_vbn': ''},
 'caucused': {'vbd_eq_vbn': ''},
 'caulked': {'vbd_eq_vbn': ''},
 'causewayed': {'vbd_eq_vbn': ''},
 'cauterised': {'vbd_eq_vbn': ''},
 'cauterized': {'vbd_eq_vbn': ''},
 'cautioned': {'vbd_eq_vbn': ''},
 'caveated': {'vbd_eq_vbn': ''},
 'caveatted': {'vbd_eq_vbn': ''},
 'caverned': {'vbd_eq_vbn': ''},
 'caviled': {'vbd_eq_vbn': ''},
 'cavilled': {'vbd_eq_vbn': ''},
 'cavorted': {'vbd_eq_vbn': ''},
 'cawed': {'vbd_eq_vbn': ''},
 'ceded': {'vbd_eq_vbn': ''},
 'ceiled': {'vbd_eq_vbn': ''},
 'cellared': {'vbd_eq_vbn': ''},
 'celled': {'vbd_eq_vbn': ''},
 'cemented': {'vbd_eq_vbn': ''},
 'censed': {'vbd_eq_vbn': ''},
 'censored': {'vbd_eq_vbn': ''},
 'censured': {'vbd_eq_vbn': ''},
 'centralised': {'vbd_eq_vbn': ''},
 'centrifuged': {'vbd_eq_vbn': ''},
 'cerebrated': {'vbd_eq_vbn': ''},
 'certified': {'vbd_eq_vbn': ''},
 'cha-cha-chaed': {'vbd_eq_vbn': ''},
 'cha-chaed': {'vbd_eq_vbn': ''},
 'chafed': {'vbd_eq_vbn': ''},
 'chaffed': {'vbd_eq_vbn': ''},
 'chaffered': {'vbd_eq_vbn': ''},
 'chagrined': {'vbd_eq_vbn': ''},
 'chain-smoked': {'vbd_eq_vbn': ''},
 'chaired': {'vbd_eq_vbn': ''},
 'chairmaned': {'vbd_eq_vbn': ''},
 'chairmanned': {'vbd_eq_vbn': ''},
 'chalked': {'vbd_eq_vbn': ''},
 'chamfered': {'vbd_eq_vbn': ''},
 'champed': {'vbd_eq_vbn': ''},
 'championed': {'vbd_eq_vbn': ''},
 'chanced': {'vbd_eq_vbn': ''},
 'chandelled': {'vbd_eq_vbn': ''},
 'channel-surfed': {'vbd_eq_vbn': ''},
 'channeled': {'vbd_eq_vbn': ''},
 'channelled': {'vbd_eq_vbn': ''},
 'chanted': {'vbd_eq_vbn': ''},
 'chaperoned': {'vbd_eq_vbn': ''},
 'charactered': {'vbd_eq_vbn': ''},
 'characterised': {'vbd_eq_vbn': ''},
 'charbroiled': {'vbd_eq_vbn': ''},
 'charcoaled': {'vbd_eq_vbn': ''},
 'charioted': {'vbd_eq_vbn': ''},
 'charted': {'vbd_eq_vbn': ''},
 'chastened': {'vbd_eq_vbn': ''},
 'chastised': {'vbd_eq_vbn': ''},
 'chatted': {'vbd_eq_vbn': ''},
 'chattered': {'vbd_eq_vbn': ''},
 'chauffeured': {'vbd_eq_vbn': ''},
 'chawed': {'vbd_eq_vbn': ''},
 'cheapened': {'vbd_eq_vbn': ''},
 'checkmated': {'vbd_eq_vbn': ''},
 'cheeked': {'vbd_eq_vbn': ''},
 'cheeped': {'vbd_eq_vbn': ''},
 'cheered': {'vbd_eq_vbn': ''},
 'cheesed': {'vbd_eq_vbn': ''},
 'chelated': {'vbd_eq_vbn': ''},
 'cherished': {'vbd_eq_vbn': ''},
 'chewed': {'vbd_eq_vbn': ''},
 'chickened': {'vbd_eq_vbn': ''},
 'chid': {'vbd_eq_vbn': ''},
 'chided': {'vbd_eq_vbn': ''},
 'child-proofed': {'vbd_eq_vbn': ''},
 'chillaxed': {'vbd_eq_vbn': ''},
 'chilled': {'vbd_eq_vbn': ''},
 'chimed': {'vbd_eq_vbn': ''},
 'chined': {'vbd_eq_vbn': ''},
 'chinked': {'vbd_eq_vbn': ''},
 'chinned': {'vbd_eq_vbn': ''},
 'chirked': {'vbd_eq_vbn': ''},
 'chirped': {'vbd_eq_vbn': ''},
 'chirruped': {'vbd_eq_vbn': ''},
 'chiseled': {'vbd_eq_vbn': ''},
 'chiselled': {'vbd_eq_vbn': ''},
 'chit-chated': {'vbd_eq_vbn': ''},
 'chitchatted': {'vbd_eq_vbn': ''},
 'chittered': {'vbd_eq_vbn': ''},
 'chivied': {'vbd_eq_vbn': ''},
 'chivvied': {'vbd_eq_vbn': ''},
 'chlorinated': {'vbd_eq_vbn': ''},
 'chloroformed': {'vbd_eq_vbn': ''},
 'chocked': {'vbd_eq_vbn': ''},
 'choired': {'vbd_eq_vbn': ''},
 'chomped': {'vbd_eq_vbn': ''},
 'chopped': {'vbd_eq_vbn': ''},
 'chorded': {'vbd_eq_vbn': ''},
 'choreographed': {'vbd_eq_vbn': ''},
 'chortled': {'vbd_eq_vbn': ''},
 'chorused': {'vbd_eq_vbn': ''},
 'choused': {'vbd_eq_vbn': ''},
 'chowed': {'vbd_eq_vbn': ''},
 'christened': {'vbd_eq_vbn': ''},
 'chromed': {'vbd_eq_vbn': ''},
 'chronicled': {'vbd_eq_vbn': ''},
 'chuckled': {'vbd_eq_vbn': ''},
 'chugged': {'vbd_eq_vbn': ''},
 'chummed': {'vbd_eq_vbn': ''},
 'chumped': {'vbd_eq_vbn': ''},
 'chunked': {'vbd_eq_vbn': ''},
 'churched': {'vbd_eq_vbn': ''},
 'churned': {'vbd_eq_vbn': ''},
 'churred': {'vbd_eq_vbn': ''},
 'cinched': {'vbd_eq_vbn': ''},
 'cindered': {'vbd_eq_vbn': ''},
 'ciphered': {'vbd_eq_vbn': ''},
 'circled': {'vbd_eq_vbn': ''},
 'circuited': {'vbd_eq_vbn': ''},
 'circulated': {'vbd_eq_vbn': ''},
 'circumambulated': {'vbd_eq_vbn': ''},
 'circumcised': {'vbd_eq_vbn': ''},
 'circumnavigated': {'vbd_eq_vbn': ''},
 'circumscribed': {'vbd_eq_vbn': ''},
 'circumstanced': {'vbd_eq_vbn': ''},
 'circumvented': {'vbd_eq_vbn': ''},
 'cited': {'vbd_eq_vbn': ''},
 'clabbered': {'vbd_eq_vbn': ''},
 'clacked': {'vbd_eq_vbn': ''},
 'clad': {'vbd_eq_vbn': ''},
 'clambered': {'vbd_eq_vbn': ''},
 'clammed': {'vbd_eq_vbn': ''},
 'clamored': {'vbd_eq_vbn': ''},
 'clamoured': {'vbd_eq_vbn': ''},
 'clamped': {'vbd_eq_vbn': ''},
 'clanged': {'vbd_eq_vbn': ''},
 'clangored': {'vbd_eq_vbn': ''},
 'clangoured': {'vbd_eq_vbn': ''},
 'clanked': {'vbd_eq_vbn': ''},
 'clapped': {'vbd_eq_vbn': ''},
 'clapperclawed': {'vbd_eq_vbn': ''},
 'clashed': {'vbd_eq_vbn': ''},
 'clasped': {'vbd_eq_vbn': ''},
 'classed': {'vbd_eq_vbn': ''},
 'classicised': {'vbd_eq_vbn': ''},
 'classicized': {'vbd_eq_vbn': ''},
 'clattered': {'vbd_eq_vbn': ''},
 'clawed': {'vbd_eq_vbn': ''},
 'cleaned': {'vbd_eq_vbn': ''},
 'cleansed': {'vbd_eq_vbn': ''},
 'cleated': {'vbd_eq_vbn': ''},
 'cleaved': {'vbd_eq_vbn': ''},
 'clenched': {'vbd_eq_vbn': ''},
 'clewed': {'vbd_eq_vbn': ''},
 'climaxed': {'vbd_eq_vbn': ''},
 'clinched': {'vbd_eq_vbn': ''},
 'clinked': {'vbd_eq_vbn': ''},
 'clinkered': {'vbd_eq_vbn': ''},
 'clip-clopped': {'vbd_eq_vbn': ''},
 'cliqued': {'vbd_eq_vbn': ''},
 'clobbered': {'vbd_eq_vbn': ''},
 'clomped': {'vbd_eq_vbn': ''},
 'cloned': {'vbd_eq_vbn': ''},
 'clopped': {'vbd_eq_vbn': ''},
 'closured': {'vbd_eq_vbn': ''},
 'clothed': {'vbd_eq_vbn': ''},
 'clotheslined': {'vbd_eq_vbn': ''},
 'clotted': {'vbd_eq_vbn': ''},
 'clouted': {'vbd_eq_vbn': ''},
 'clowned': {'vbd_eq_vbn': ''},
 'cloyed': {'vbd_eq_vbn': ''},
 'clucked': {'vbd_eq_vbn': ''},
 'clumped': {'vbd_eq_vbn': ''},
 'clung': {'vbd_eq_vbn': ''},
 'clunked': {'vbd_eq_vbn': ''},
 'clustered': {'vbd_eq_vbn': ''},
 'clutched': {'vbd_eq_vbn': ''},
 'co-authored': {'vbd_eq_vbn': ''},
 'co-chaired': {'vbd_eq_vbn': ''},
 'co-developed': {'vbd_eq_vbn': ''},
 'co-discovered': {'vbd_eq_vbn': ''},
 'co-existed': {'vbd_eq_vbn': ''},
 'co-managed': {'vbd_eq_vbn': ''},
 'co-occurred': {'vbd_eq_vbn': ''},
 'co-operated': {'vbd_eq_vbn': ''},
 'co-opted': {'vbd_eq_vbn': ''},
 'co-ordinated': {'vbd_eq_vbn': ''},
 'co-owned': {'vbd_eq_vbn': ''},
 'co-parented': {'vbd_eq_vbn': ''},
 'co-produced': {'vbd_eq_vbn': ''},
 'co-starred': {'vbd_eq_vbn': ''},
 'coagulated': {'vbd_eq_vbn': ''},
 'coalesced': {'vbd_eq_vbn': ''},
 'coarsened': {'vbd_eq_vbn': ''},
 'coauthored': {'vbd_eq_vbn': ''},
 'coaxed': {'vbd_eq_vbn': ''},
 'cochaired': {'vbd_eq_vbn': ''},
 'cocked': {'vbd_eq_vbn': ''},
 'cockered': {'vbd_eq_vbn': ''},
 'cockled': {'vbd_eq_vbn': ''},
 'codded': {'vbd_eq_vbn': ''},
 'coddled': {'vbd_eq_vbn': ''},
 'code-named': {'vbd_eq_vbn': ''},
 'codeveloped': {'vbd_eq_vbn': ''},
 'codified': {'vbd_eq_vbn': ''},
 'codirected': {'vbd_eq_vbn': ''},
 'codiscovered': {'vbd_eq_vbn': ''},
 'coerced': {'vbd_eq_vbn': ''},
 'coexisted': {'vbd_eq_vbn': ''},
 'coffered': {'vbd_eq_vbn': ''},
 'coffined': {'vbd_eq_vbn': ''},
 'cofinanced': {'vbd_eq_vbn': ''},
 'cofounded': {'vbd_eq_vbn': ''},
 'cogged': {'vbd_eq_vbn': ''},
 'cogitated': {'vbd_eq_vbn': ''},
 'cohabited': {'vbd_eq_vbn': ''},
 'cohered': {'vbd_eq_vbn': ''},
 'coifed': {'vbd_eq_vbn': ''},
 'coiffed': {'vbd_eq_vbn': ''},
 'coincided': {'vbd_eq_vbn': ''},
 'coked': {'vbd_eq_vbn': ''},
 'cold-shouldered': {'vbd_eq_vbn': ''},
 'collaborated': {'vbd_eq_vbn': ''},
 'collaged': {'vbd_eq_vbn': ''},
 'collated': {'vbd_eq_vbn': ''},
 'collateralized': {'vbd_eq_vbn': ''},
 'collectivised': {'vbd_eq_vbn': ''},
 'collectivized': {'vbd_eq_vbn': ''},
 'collided': {'vbd_eq_vbn': ''},
 'collied': {'vbd_eq_vbn': ''},
 'collocated': {'vbd_eq_vbn': ''},
 'colluded': {'vbd_eq_vbn': ''},
 'colonised': {'vbd_eq_vbn': ''},
 'colonized': {'vbd_eq_vbn': ''},
 'color-coded': {'vbd_eq_vbn': ''},
 'colorcast': {'vbd_eq_vbn': ''},
 'colorcasted': {'vbd_eq_vbn': ''},
 'colorized': {'vbd_eq_vbn': ''},
 'colourized': {'vbd_eq_vbn': ''},
 'combated': {'vbd_eq_vbn': ''},
 'combatted': {'vbd_eq_vbn': ''},
 'combed': {'vbd_eq_vbn': ''},
 'combusted': {'vbd_eq_vbn': ''},
 'comforted': {'vbd_eq_vbn': ''},
 'commandeered': {'vbd_eq_vbn': ''},
 'commando-trained': {'vbd_eq_vbn': ''},
 'commemorated': {'vbd_eq_vbn': ''},
 'commenced': {'vbd_eq_vbn': ''},
 'commended': {'vbd_eq_vbn': ''},
 'commentated': {'vbd_eq_vbn': ''},
 'commercialised': {'vbd_eq_vbn': ''},
 'commercialized': {'vbd_eq_vbn': ''},
 'commingled': {'vbd_eq_vbn': ''},
 'commiserated': {'vbd_eq_vbn': ''},
 'commixed': {'vbd_eq_vbn': ''},
 'commoditised': {'vbd_eq_vbn': ''},
 'commoditized': {'vbd_eq_vbn': ''},
 'commoved': {'vbd_eq_vbn': ''},
 'communed': {'vbd_eq_vbn': ''},
 'commuted': {'vbd_eq_vbn': ''},
 'compacted': {'vbd_eq_vbn': ''},
 'companied': {'vbd_eq_vbn': ''},
 'companioned': {'vbd_eq_vbn': ''},
 'comparted': {'vbd_eq_vbn': ''},
 'compartmentalised': {'vbd_eq_vbn': ''},
 'compartmented': {'vbd_eq_vbn': ''},
 'compassed': {'vbd_eq_vbn': ''},
 'compassionated': {'vbd_eq_vbn': ''},
 'comped': {'vbd_eq_vbn': ''},
 'compelled': {'vbd_eq_vbn': ''},
 'compensated': {'vbd_eq_vbn': ''},
 'compered': {'vbd_eq_vbn': ''},
 'complected': {'vbd_eq_vbn': ''},
 'complemented': {'vbd_eq_vbn': ''},
 'complexified': {'vbd_eq_vbn': ''},
 'complied': {'vbd_eq_vbn': ''},
 'complimented': {'vbd_eq_vbn': ''},
 'complotted': {'vbd_eq_vbn': ''},
 'comported': {'vbd_eq_vbn': ''},
 'composted': {'vbd_eq_vbn': ''},
 'comprehended': {'vbd_eq_vbn': ''},
 'compromised': {'vbd_eq_vbn': ''},
 'computed': {'vbd_eq_vbn': ''},
 'computerised': {'vbd_eq_vbn': ''},
 'computerized': {'vbd_eq_vbn': ''},
 'concaved': {'vbd_eq_vbn': ''},
 'concealed': {'vbd_eq_vbn': ''},
 'conceded': {'vbd_eq_vbn': ''},
 'conceived': {'vbd_eq_vbn': ''},
 'concentred': {'vbd_eq_vbn': ''},
 'conceptualised': {'vbd_eq_vbn': ''},
 'conceptualized': {'vbd_eq_vbn': ''},
 'concertinaed': {'vbd_eq_vbn': ''},
 'conciliated': {'vbd_eq_vbn': ''},
 'concocted': {'vbd_eq_vbn': ''},
 'concreted': {'vbd_eq_vbn': ''},
 'concretised': {'vbd_eq_vbn': ''},
 'concretized': {'vbd_eq_vbn': ''},
 'concurred': {'vbd_eq_vbn': ''},
 'concussed': {'vbd_eq_vbn': ''},
 'condensed': {'vbd_eq_vbn': ''},
 'condescended': {'vbd_eq_vbn': ''},
 'condoled': {'vbd_eq_vbn': ''},
 'condoned': {'vbd_eq_vbn': ''},
 'conduced': {'vbd_eq_vbn': ''},
 'coned': {'vbd_eq_vbn': ''},
 'confected': {'vbd_eq_vbn': ''},
 'confederated': {'vbd_eq_vbn': ''},
 'conferred': {'vbd_eq_vbn': ''},
 'confided': {'vbd_eq_vbn': ''},
 'configured': {'vbd_eq_vbn': ''},
 'confiscated': {'vbd_eq_vbn': ''},
 'conflated': {'vbd_eq_vbn': ''},
 'conformed': {'vbd_eq_vbn': ''},
 'confounded': {'vbd_eq_vbn': ''},
 'confronted': {'vbd_eq_vbn': ''},
 'confuted': {'vbd_eq_vbn': ''},
 'congaed': {'vbd_eq_vbn': ''},
 'congealed': {'vbd_eq_vbn': ''},
 'congeed': {'vbd_eq_vbn': ''},
 'conglomerated': {'vbd_eq_vbn': ''},
 'congratulated': {'vbd_eq_vbn': ''},
 'congregated': {'vbd_eq_vbn': ''},
 'conjectured': {'vbd_eq_vbn': ''},
 'conjoined': {'vbd_eq_vbn': ''},
 'conjugated': {'vbd_eq_vbn': ''},
 'conjured': {'vbd_eq_vbn': ''},
 'conked': {'vbd_eq_vbn': ''},
 'conned': {'vbd_eq_vbn': ''},
 'connived': {'vbd_eq_vbn': ''},
 'connoted': {'vbd_eq_vbn': ''},
 'conquered': {'vbd_eq_vbn': ''},
 'conscripted': {'vbd_eq_vbn': ''},
 'consecrated': {'vbd_eq_vbn': ''},
 'conserved': {'vbd_eq_vbn': ''},
 'consigned': {'vbd_eq_vbn': ''},
 'consociated': {'vbd_eq_vbn': ''},
 'consoled': {'vbd_eq_vbn': ''},
 'consolidated': {'vbd_eq_vbn': ''},
 'consorted': {'vbd_eq_vbn': ''},
 'conspired': {'vbd_eq_vbn': ''},
 'constellated': {'vbd_eq_vbn': ''},
 'constipated': {'vbd_eq_vbn': ''},
 'construed': {'vbd_eq_vbn': ''},
 'consumed': {'vbd_eq_vbn': ''},
 'consummated': {'vbd_eq_vbn': ''},
 'containerised': {'vbd_eq_vbn': ''},
 'containerized': {'vbd_eq_vbn': ''},
 'contemned': {'vbd_eq_vbn': ''},
 'contemplated': {'vbd_eq_vbn': ''},
 'contended': {'vbd_eq_vbn': ''},
 'contorted': {'vbd_eq_vbn': ''},
 'contradicted': {'vbd_eq_vbn': ''},
 'contravened': {'vbd_eq_vbn': ''},
 'controverted': {'vbd_eq_vbn': ''},
 'convalesced': {'vbd_eq_vbn': ''},
 'convected': {'vbd_eq_vbn': ''},
 'convened': {'vbd_eq_vbn': ''},
 'conventionalised': {'vbd_eq_vbn': ''},
 'conventionalized': {'vbd_eq_vbn': ''},
 'converged': {'vbd_eq_vbn': ''},
 'conversed': {'vbd_eq_vbn': ''},
 'conveyed': {'vbd_eq_vbn': ''},
 'convicted': {'vbd_eq_vbn': ''},
 'convoked': {'vbd_eq_vbn': ''},
 'convoyed': {'vbd_eq_vbn': ''},
 'convulsed': {'vbd_eq_vbn': ''},
 'cooed': {'vbd_eq_vbn': ''},
 'cooped': {'vbd_eq_vbn': ''},
 'cooperated': {'vbd_eq_vbn': ''},
 'coopered': {'vbd_eq_vbn': ''},
 'coopted': {'vbd_eq_vbn': ''},
 'copped': {'vbd_eq_vbn': ''},
 'coppered': {'vbd_eq_vbn': ''},
 'coppiced': {'vbd_eq_vbn': ''},
 'coproduced': {'vbd_eq_vbn': ''},
 'copulated': {'vbd_eq_vbn': ''},
 'copycatted': {'vbd_eq_vbn': ''},
 'copyrighted': {'vbd_eq_vbn': ''},
 'corbeled': {'vbd_eq_vbn': ''},
 'corbelled': {'vbd_eq_vbn': ''},
 'cordoned': {'vbd_eq_vbn': ''},
 'corduroyed': {'vbd_eq_vbn': ''},
 'corkscrewed': {'vbd_eq_vbn': ''},
 'corned': {'vbd_eq_vbn': ''},
 'corniced': {'vbd_eq_vbn': ''},
 'coronated': {'vbd_eq_vbn': ''},
 'corraled': {'vbd_eq_vbn': ''},
 'corralled': {'vbd_eq_vbn': ''},
 'corrected': {'vbd_eq_vbn': ''},
 'correlated': {'vbd_eq_vbn': ''},
 'corresponded': {'vbd_eq_vbn': ''},
 'corroborated': {'vbd_eq_vbn': ''},
 'corrupted': {'vbd_eq_vbn': ''},
 'coruscated': {'vbd_eq_vbn': ''},
 'coshed': {'vbd_eq_vbn': ''},
 'cosied': {'vbd_eq_vbn': ''},
 'cosigned': {'vbd_eq_vbn': ''},
 'cosplayed': {'vbd_eq_vbn': ''},
 'cosponsored': {'vbd_eq_vbn': ''},
 'cosseted': {'vbd_eq_vbn': ''},
 'costumed': {'vbd_eq_vbn': ''},
 'couched': {'vbd_eq_vbn': ''},
 'coughed': {'vbd_eq_vbn': ''},
 'counseled': {'vbd_eq_vbn': ''},
 'counselled': {'vbd_eq_vbn': ''},
 'countenanced': {'vbd_eq_vbn': ''},
 'counter-attacked': {'vbd_eq_vbn': ''},
 'counteracted': {'vbd_eq_vbn': ''},
 'counterattacked': {'vbd_eq_vbn': ''},
 'counterbalanced': {'vbd_eq_vbn': ''},
 'counterchanged': {'vbd_eq_vbn': ''},
 'countercharged': {'vbd_eq_vbn': ''},
 'counterchecked': {'vbd_eq_vbn': ''},
 'counterclaimed': {'vbd_eq_vbn': ''},
 'counterfeited': {'vbd_eq_vbn': ''},
 'countermanded': {'vbd_eq_vbn': ''},
 'countermarched': {'vbd_eq_vbn': ''},
 'countermined': {'vbd_eq_vbn': ''},
 'countermoved': {'vbd_eq_vbn': ''},
 'counterplotted': {'vbd_eq_vbn': ''},
 'counterpointed': {'vbd_eq_vbn': ''},
 'counterpoised': {'vbd_eq_vbn': ''},
 'counterposed': {'vbd_eq_vbn': ''},
 'counterprogrammed': {'vbd_eq_vbn': ''},
 'counterpunched': {'vbd_eq_vbn': ''},
 'countersigned': {'vbd_eq_vbn': ''},
 'counterstriked': {'vbd_eq_vbn': ''},
 'countersued': {'vbd_eq_vbn': ''},
 'countervailed': {'vbd_eq_vbn': ''},
 'couriered': {'vbd_eq_vbn': ''},
 'court-martialed': {'vbd_eq_vbn': ''},
 'court-martialled': {'vbd_eq_vbn': ''},
 'coved': {'vbd_eq_vbn': ''},
 'covenanted': {'vbd_eq_vbn': ''},
 'coveted': {'vbd_eq_vbn': ''},
 'cowered': {'vbd_eq_vbn': ''},
 'cowhided': {'vbd_eq_vbn': ''},
 'coxed': {'vbd_eq_vbn': ''},
 'cozened': {'vbd_eq_vbn': ''},
 'cozied': {'vbd_eq_vbn': ''},
 'crackled': {'vbd_eq_vbn': ''},
 'cradled': {'vbd_eq_vbn': ''},
 'crafted': {'vbd_eq_vbn': ''},
 'craned': {'vbd_eq_vbn': ''},
 'cranked': {'vbd_eq_vbn': ''},
 'craped': {'vbd_eq_vbn': ''},
 'crapped': {'vbd_eq_vbn': ''},
 'crash-dived': {'vbd_eq_vbn': ''},
 'crash-landed': {'vbd_eq_vbn': ''},
 'crated': {'vbd_eq_vbn': ''},
 'cratered': {'vbd_eq_vbn': ''},
 'craved': {'vbd_eq_vbn': ''},
 'crawled': {'vbd_eq_vbn': ''},
 'crayoned': {'vbd_eq_vbn': ''},
 'creaked': {'vbd_eq_vbn': ''},
 'creamed': {'vbd_eq_vbn': ''},
 'credentialed': {'vbd_eq_vbn': ''},
 'cremated': {'vbd_eq_vbn': ''},
 'creolized': {'vbd_eq_vbn': ''},
 'creosoted': {'vbd_eq_vbn': ''},
 'crepitated': {'vbd_eq_vbn': ''},
 'crept': {'vbd_eq_vbn': ''},
 'crescendoed': {'vbd_eq_vbn': ''},
 'crevassed': {'vbd_eq_vbn': ''},
 'cribbed': {'vbd_eq_vbn': ''},
 'cricked': {'vbd_eq_vbn': ''},
 'cricketed': {'vbd_eq_vbn': ''},
 'criminalised': {'vbd_eq_vbn': ''},
 'criminalized': {'vbd_eq_vbn': ''},
 'crimped': {'vbd_eq_vbn': ''},
 'crimsoned': {'vbd_eq_vbn': ''},
 'cringed': {'vbd_eq_vbn': ''},
 'crisped': {'vbd_eq_vbn': ''},
 'crispened': {'vbd_eq_vbn': ''},
 'criss-crossed': {'vbd_eq_vbn': ''},
 'crisscrossed': {'vbd_eq_vbn': ''},
 'criticised': {'vbd_eq_vbn': ''},
 'critiqued': {'vbd_eq_vbn': ''},
 'croaked': {'vbd_eq_vbn': ''},
 'crocheted': {'vbd_eq_vbn': ''},
 'crooned': {'vbd_eq_vbn': ''},
 'croqueted': {'vbd_eq_vbn': ''},
 'cross-checked': {'vbd_eq_vbn': ''},
 'cross-dressed': {'vbd_eq_vbn': ''},
 'cross-examined': {'vbd_eq_vbn': ''},
 'cross-fertilised': {'vbd_eq_vbn': ''},
 'cross-fertilized': {'vbd_eq_vbn': ''},
 'cross-indexed': {'vbd_eq_vbn': ''},
 'cross-pollinated': {'vbd_eq_vbn': ''},
 'cross-referenced': {'vbd_eq_vbn': ''},
 'cross-referred': {'vbd_eq_vbn': ''},
 'cross-stitched': {'vbd_eq_vbn': ''},
 'cross-trained': {'vbd_eq_vbn': ''},
 'crosschecked': {'vbd_eq_vbn': ''},
 'crosshatched': {'vbd_eq_vbn': ''},
 'crouched': {'vbd_eq_vbn': ''},
 'crowbarred': {'vbd_eq_vbn': ''},
 'crowdfunded': {'vbd_eq_vbn': ''},
 'crowed': {'vbd_eq_vbn': ''},
 'crucified': {'vbd_eq_vbn': ''},
 'cruised': {'vbd_eq_vbn': ''},
 'crumbed': {'vbd_eq_vbn': ''},
 'crumbled': {'vbd_eq_vbn': ''},
 'crumped': {'vbd_eq_vbn': ''},
 'crunched': {'vbd_eq_vbn': ''},
 'crusaded': {'vbd_eq_vbn': ''},
 'crutched': {'vbd_eq_vbn': ''},
 'crystalised': {'vbd_eq_vbn': ''},
 'crystalized': {'vbd_eq_vbn': ''},
 'crystallised': {'vbd_eq_vbn': ''},
 'cubed': {'vbd_eq_vbn': ''},
 'cuckolded': {'vbd_eq_vbn': ''},
 'cuckooed': {'vbd_eq_vbn': ''},
 'cuddled': {'vbd_eq_vbn': ''},
 'cudgeled': {'vbd_eq_vbn': ''},
 'cudgelled': {'vbd_eq_vbn': ''},
 'cued': {'vbd_eq_vbn': ''},
 'cuffed': {'vbd_eq_vbn': ''},
 'culled': {'vbd_eq_vbn': ''},
 'culminated': {'vbd_eq_vbn': ''},
 'cumbered': {'vbd_eq_vbn': ''},
 'cumulated': {'vbd_eq_vbn': ''},
 'cupped': {'vbd_eq_vbn': ''},
 'curated': {'vbd_eq_vbn': ''},
 'curbed': {'vbd_eq_vbn': ''},
 'curded': {'vbd_eq_vbn': ''},
 'curdled': {'vbd_eq_vbn': ''},
 'cured': {'vbd_eq_vbn': ''},
 'curled': {'vbd_eq_vbn': ''},
 'currycombed': {'vbd_eq_vbn': ''},
 'curst': {'vbd_eq_vbn': ''},
 'curtailed': {'vbd_eq_vbn': ''},
 'curtseyed': {'vbd_eq_vbn': ''},
 'curtsied': {'vbd_eq_vbn': ''},
 'curveted': {'vbd_eq_vbn': ''},
 'curvetted': {'vbd_eq_vbn': ''},
 'cussed': {'vbd_eq_vbn': ''},
 'custom-made': {'vbd_eq_vbn': ''},
 'customised': {'vbd_eq_vbn': ''},
 'customized': {'vbd_eq_vbn': ''},
 'cyanided': {'vbd_eq_vbn': ''},
 'cyberattacked': {'vbd_eq_vbn': ''},
 'cyberbullied': {'vbd_eq_vbn': ''},
 'cybernated': {'vbd_eq_vbn': ''},
 'cyclostyled': {'vbd_eq_vbn': ''},
 'cyphered': {'vbd_eq_vbn': ''},
 'dabbed': {'vbd_eq_vbn': ''},
 'dabbled': {'vbd_eq_vbn': ''},
 'daisy-chained': {'vbd_eq_vbn': ''},
 'dallied': {'vbd_eq_vbn': ''},
 'damascened': {'vbd_eq_vbn': ''},
 'damed': {'vbd_eq_vbn': ''},
 'dammed': {'vbd_eq_vbn': ''},
 'damped': {'vbd_eq_vbn': ''},
 'dampened': {'vbd_eq_vbn': ''},
 'dandled': {'vbd_eq_vbn': ''},
 'danged': {'vbd_eq_vbn': ''},
 'dangled': {'vbd_eq_vbn': ''},
 'dapped': {'vbd_eq_vbn': ''},
 'darkened': {'vbd_eq_vbn': ''},
 'darted': {'vbd_eq_vbn': ''},
 'dashed': {'vbd_eq_vbn': ''},
 'databased': {'vbd_eq_vbn': ''},
 'datelined': {'vbd_eq_vbn': ''},
 'daubed': {'vbd_eq_vbn': ''},
 'daunted': {'vbd_eq_vbn': ''},
 'dawdled': {'vbd_eq_vbn': ''},
 'dawned': {'vbd_eq_vbn': ''},
 'daydreamed': {'vbd_eq_vbn': ''},
 'dazzled': {'vbd_eq_vbn': ''},
 'de-emphasised': {'vbd_eq_vbn': ''},
 'de-emphasized': {'vbd_eq_vbn': ''},
 'de-escalated': {'vbd_eq_vbn': ''},
 'de-iced': {'vbd_eq_vbn': ''},
 'de-stressed': {'vbd_eq_vbn': ''},
 'deaccessioned': {'vbd_eq_vbn': ''},
 'deactivated': {'vbd_eq_vbn': ''},
 'deadened': {'vbd_eq_vbn': ''},
 'deadheaded': {'vbd_eq_vbn': ''},
 'deadpanned': {'vbd_eq_vbn': ''},
 'deafened': {'vbd_eq_vbn': ''},
 'debarked': {'vbd_eq_vbn': ''},
 'debarred': {'vbd_eq_vbn': ''},
 'debased': {'vbd_eq_vbn': ''},
 'debilitated': {'vbd_eq_vbn': ''},
 'debited': {'vbd_eq_vbn': ''},
 'deboned': {'vbd_eq_vbn': ''},
 'debouched': {'vbd_eq_vbn': ''},
 'debriefed': {'vbd_eq_vbn': ''},
 'debugged': {'vbd_eq_vbn': ''},
 'debunked': {'vbd_eq_vbn': ''},
 'debuted': {'vbd_eq_vbn': ''},
 'decamped': {'vbd_eq_vbn': ''},
 'decanted': {'vbd_eq_vbn': ''},
 'decapitated': {'vbd_eq_vbn': ''},
 'decelerated': {'vbd_eq_vbn': ''},
 'decentralised': {'vbd_eq_vbn': ''},
 'decerebrated': {'vbd_eq_vbn': ''},
 'decertified': {'vbd_eq_vbn': ''},
 'decimalized': {'vbd_eq_vbn': ''},
 'decimated': {'vbd_eq_vbn': ''},
 'deciphered': {'vbd_eq_vbn': ''},
 'decisioned': {'vbd_eq_vbn': ''},
 'decked': {'vbd_eq_vbn': ''},
 'declaimed': {'vbd_eq_vbn': ''},
 'declassed': {'vbd_eq_vbn': ''},
 'declutched': {'vbd_eq_vbn': ''},
 'decluttered': {'vbd_eq_vbn': ''},
 'decocted': {'vbd_eq_vbn': ''},
 'decoded': {'vbd_eq_vbn': ''},
 'decolonised': {'vbd_eq_vbn': ''},
 'decolonized': {'vbd_eq_vbn': ''},
 'decolored': {'vbd_eq_vbn': ''},
 'decommissioned': {'vbd_eq_vbn': ''},
 'decomposed': {'vbd_eq_vbn': ''},
 'decompressed': {'vbd_eq_vbn': ''},
 'deconcentrated': {'vbd_eq_vbn': ''},
 'deconstructed': {'vbd_eq_vbn': ''},
 'decontaminated': {'vbd_eq_vbn': ''},
 'decontrolled': {'vbd_eq_vbn': ''},
 'decorated': {'vbd_eq_vbn': ''},
 'decorticated': {'vbd_eq_vbn': ''},
 'decoupled': {'vbd_eq_vbn': ''},
 'decoyed': {'vbd_eq_vbn': ''},
 'decreased': {'vbd_eq_vbn': ''},
 'decreed': {'vbd_eq_vbn': ''},
 'decried': {'vbd_eq_vbn': ''},
 'decriminalised': {'vbd_eq_vbn': ''},
 'decriminalized': {'vbd_eq_vbn': ''},
 'decrypted': {'vbd_eq_vbn': ''},
 'deduced': {'vbd_eq_vbn': ''},
 'deducted': {'vbd_eq_vbn': ''},
 'deeded': {'vbd_eq_vbn': ''},
 'deemed': {'vbd_eq_vbn': ''},
 'deep-fried': {'vbd_eq_vbn': ''},
 'deep-sixed': {'vbd_eq_vbn': ''},
 'deepened': {'vbd_eq_vbn': ''},
 'defaced': {'vbd_eq_vbn': ''},
 'defamed': {'vbd_eq_vbn': ''},
 'defatted': {'vbd_eq_vbn': ''},
 'defaulted': {'vbd_eq_vbn': ''},
 'defecated': {'vbd_eq_vbn': ''},
 'defected': {'vbd_eq_vbn': ''},
 'defensed': {'vbd_eq_vbn': ''},
 'deferred': {'vbd_eq_vbn': ''},
 'defervesced': {'vbd_eq_vbn': ''},
 'defibrillated': {'vbd_eq_vbn': ''},
 'defied': {'vbd_eq_vbn': ''},
 'defiled': {'vbd_eq_vbn': ''},
 'defined': {'vbd_eq_vbn': ''},
 'deflated': {'vbd_eq_vbn': ''},
 'deflected': {'vbd_eq_vbn': ''},
 'deflowered': {'vbd_eq_vbn': ''},
 'defogged': {'vbd_eq_vbn': ''},
 'defoliated': {'vbd_eq_vbn': ''},
 'deforested': {'vbd_eq_vbn': ''},
 'defrauded': {'vbd_eq_vbn': ''},
 'defrayed': {'vbd_eq_vbn': ''},
 'defriended': {'vbd_eq_vbn': ''},
 'defrosted': {'vbd_eq_vbn': ''},
 'defused': {'vbd_eq_vbn': ''},
 'degassed': {'vbd_eq_vbn': ''},
 'degenerated': {'vbd_eq_vbn': ''},
 'deglazed': {'vbd_eq_vbn': ''},
 'degraded': {'vbd_eq_vbn': ''},
 'degreased': {'vbd_eq_vbn': ''},
 'dehumanised': {'vbd_eq_vbn': ''},
 'dehumanized': {'vbd_eq_vbn': ''},
 'dehumidified': {'vbd_eq_vbn': ''},
 'deified': {'vbd_eq_vbn': ''},
 'deigned': {'vbd_eq_vbn': ''},
 'delegated': {'vbd_eq_vbn': ''},
 'deleted': {'vbd_eq_vbn': ''},
 'deleveraged': {'vbd_eq_vbn': ''},
 'deliberated': {'vbd_eq_vbn': ''},
 'delimitated': {'vbd_eq_vbn': ''},
 'delimited': {'vbd_eq_vbn': ''},
 'delineated': {'vbd_eq_vbn': ''},
 'delisted': {'vbd_eq_vbn': ''},
 'deloused': {'vbd_eq_vbn': ''},
 'deluded': {'vbd_eq_vbn': ''},
 'deluged': {'vbd_eq_vbn': ''},
 'delved': {'vbd_eq_vbn': ''},
 'demagnetised': {'vbd_eq_vbn': ''},
 'demagnetized': {'vbd_eq_vbn': ''},
 'demarcated': {'vbd_eq_vbn': ''},
 'dematerialized': {'vbd_eq_vbn': ''},
 'demeaned': {'vbd_eq_vbn': ''},
 'demilitarised': {'vbd_eq_vbn': ''},
 'demilitarized': {'vbd_eq_vbn': ''},
 'demised': {'vbd_eq_vbn': ''},
 'demisted': {'vbd_eq_vbn': ''},
 'demobbed': {'vbd_eq_vbn': ''},
 'demobilised': {'vbd_eq_vbn': ''},
 'demobilized': {'vbd_eq_vbn': ''},
 'democratised': {'vbd_eq_vbn': ''},
 'democratized': {'vbd_eq_vbn': ''},
 'demodulated': {'vbd_eq_vbn': ''},
 'demoed': {'vbd_eq_vbn': ''},
 'demolished': {'vbd_eq_vbn': ''},
 'demonetised': {'vbd_eq_vbn': ''},
 'demonetized': {'vbd_eq_vbn': ''},
 'demonised': {'vbd_eq_vbn': ''},
 'demonized': {'vbd_eq_vbn': ''},
 'demoralised': {'vbd_eq_vbn': ''},
 'demoted': {'vbd_eq_vbn': ''},
 'demotivated': {'vbd_eq_vbn': ''},
 'demurred': {'vbd_eq_vbn': ''},
 'demystified': {'vbd_eq_vbn': ''},
 'demythologised': {'vbd_eq_vbn': ''},
 'demythologized': {'vbd_eq_vbn': ''},
 'denationalised': {'vbd_eq_vbn': ''},
 'denationalized': {'vbd_eq_vbn': ''},
 'denaturised': {'vbd_eq_vbn': ''},
 'denaturized': {'vbd_eq_vbn': ''},
 'denazified': {'vbd_eq_vbn': ''},
 'denigrated': {'vbd_eq_vbn': ''},
 'denned': {'vbd_eq_vbn': ''},
 'denominated': {'vbd_eq_vbn': ''},
 'denoted': {'vbd_eq_vbn': ''},
 'denounced': {'vbd_eq_vbn': ''},
 'dented': {'vbd_eq_vbn': ''},
 'denudated': {'vbd_eq_vbn': ''},
 'denuded': {'vbd_eq_vbn': ''},
 'deodorised': {'vbd_eq_vbn': ''},
 'deodorized': {'vbd_eq_vbn': ''},
 'depersonalised': {'vbd_eq_vbn': ''},
 'depersonalized': {'vbd_eq_vbn': ''},
 'depicted': {'vbd_eq_vbn': ''},
 'depilated': {'vbd_eq_vbn': ''},
 'deplaned': {'vbd_eq_vbn': ''},
 'depleted': {'vbd_eq_vbn': ''},
 'deplored': {'vbd_eq_vbn': ''},
 'deployed': {'vbd_eq_vbn': ''},
 'depopulated': {'vbd_eq_vbn': ''},
 'deported': {'vbd_eq_vbn': ''},
 'deposed': {'vbd_eq_vbn': ''},
 'deprecated': {'vbd_eq_vbn': ''},
 'depreciated': {'vbd_eq_vbn': ''},
 'depressurised': {'vbd_eq_vbn': ''},
 'depressurized': {'vbd_eq_vbn': ''},
 'deputed': {'vbd_eq_vbn': ''},
 'deputised': {'vbd_eq_vbn': ''},
 'deputized': {'vbd_eq_vbn': ''},
 'derailed': {'vbd_eq_vbn': ''},
 'deregistered': {'vbd_eq_vbn': ''},
 'deregulated': {'vbd_eq_vbn': ''},
 'derided': {'vbd_eq_vbn': ''},
 'derogated': {'vbd_eq_vbn': ''},
 'desalted': {'vbd_eq_vbn': ''},
 'descaled': {'vbd_eq_vbn': ''},
 'descanted': {'vbd_eq_vbn': ''},
 'descended': {'vbd_eq_vbn': ''},
 'descried': {'vbd_eq_vbn': ''},
 'desecrated': {'vbd_eq_vbn': ''},
 'desegregated': {'vbd_eq_vbn': ''},
 'desensitised': {'vbd_eq_vbn': ''},
 'desensitized': {'vbd_eq_vbn': ''},
 'desertified': {'vbd_eq_vbn': ''},
 'designated': {'vbd_eq_vbn': ''},
 'desisted': {'vbd_eq_vbn': ''},
 'despaired': {'vbd_eq_vbn': ''},
 'despatched': {'vbd_eq_vbn': ''},
 'despised': {'vbd_eq_vbn': ''},
 'despoiled': {'vbd_eq_vbn': ''},
 'desponded': {'vbd_eq_vbn': ''},
 'destabilised': {'vbd_eq_vbn': ''},
 'destabilized': {'vbd_eq_vbn': ''},
 'destocked': {'vbd_eq_vbn': ''},
 'destressed': {'vbd_eq_vbn': ''},
 'detained': {'vbd_eq_vbn': ''},
 'deterged': {'vbd_eq_vbn': ''},
 'deteriorated': {'vbd_eq_vbn': ''},
 'deterred': {'vbd_eq_vbn': ''},
 'detested': {'vbd_eq_vbn': ''},
 'dethroned': {'vbd_eq_vbn': ''},
 'detonated': {'vbd_eq_vbn': ''},
 'detoured': {'vbd_eq_vbn': ''},
 'detoxed': {'vbd_eq_vbn': ''},
 'detoxicated': {'vbd_eq_vbn': ''},
 'detoxified': {'vbd_eq_vbn': ''},
 'detracted': {'vbd_eq_vbn': ''},
 'detrained': {'vbd_eq_vbn': ''},
 'deuterated': {'vbd_eq_vbn': ''},
 'devaluated': {'vbd_eq_vbn': ''},
 'devalued': {'vbd_eq_vbn': ''},
 'deveined': {'vbd_eq_vbn': ''},
 'deviated': {'vbd_eq_vbn': ''},
 'deviled': {'vbd_eq_vbn': ''},
 'devilled': {'vbd_eq_vbn': ''},
 'devised': {'vbd_eq_vbn': ''},
 'devolved': {'vbd_eq_vbn': ''},
 'devoured': {'vbd_eq_vbn': ''},
 'dewatered': {'vbd_eq_vbn': ''},
 'dewed': {'vbd_eq_vbn': ''},
 'dewormed': {'vbd_eq_vbn': ''},
 'diademed': {'vbd_eq_vbn': ''},
 'diagnosed': {'vbd_eq_vbn': ''},
 'diagrammed': {'vbd_eq_vbn': ''},
 'dialed': {'vbd_eq_vbn': ''},
 'dialled': {'vbd_eq_vbn': ''},
 'dialoged': {'vbd_eq_vbn': ''},
 'dialogued': {'vbd_eq_vbn': ''},
 'dialysed': {'vbd_eq_vbn': ''},
 'dialyzed': {'vbd_eq_vbn': ''},
 'diamond-studded': {'vbd_eq_vbn': ''},
 'diamonded': {'vbd_eq_vbn': ''},
 'diapered': {'vbd_eq_vbn': ''},
 'dibbled': {'vbd_eq_vbn': ''},
 'diced': {'vbd_eq_vbn': ''},
 'dicked': {'vbd_eq_vbn': ''},
 'dickered': {'vbd_eq_vbn': ''},
 'dictated': {'vbd_eq_vbn': ''},
 'diddled': {'vbd_eq_vbn': ''},
 'dieted': {'vbd_eq_vbn': ''},
 'differed': {'vbd_eq_vbn': ''},
 'differenced': {'vbd_eq_vbn': ''},
 'diffracted': {'vbd_eq_vbn': ''},
 'diffused': {'vbd_eq_vbn': ''},
 'digested': {'vbd_eq_vbn': ''},
 'digitalised': {'vbd_eq_vbn': ''},
 'digitalized': {'vbd_eq_vbn': ''},
 'digressed': {'vbd_eq_vbn': ''},
 'diked': {'vbd_eq_vbn': ''},
 'dilated': {'vbd_eq_vbn': ''},
 'dilly-dallied': {'vbd_eq_vbn': ''},
 'dillydallied': {'vbd_eq_vbn': ''},
 'diluted': {'vbd_eq_vbn': ''},
 'dimensioned': {'vbd_eq_vbn': ''},
 'dimmed': {'vbd_eq_vbn': ''},
 'dined': {'vbd_eq_vbn': ''},
 'dinged': {'vbd_eq_vbn': ''},
 'dinked': {'vbd_eq_vbn': ''},
 'dinned': {'vbd_eq_vbn': ''},
 'dinted': {'vbd_eq_vbn': ''},
 'diphthongised': {'vbd_eq_vbn': ''},
 'diphthongized': {'vbd_eq_vbn': ''},
 'dipped': {'vbd_eq_vbn': ''},
 'disabused': {'vbd_eq_vbn': ''},
 'disaccorded': {'vbd_eq_vbn': ''},
 'disadvantaged': {'vbd_eq_vbn': ''},
 'disaffiliated': {'vbd_eq_vbn': ''},
 'disallowed': {'vbd_eq_vbn': ''},
 'disapproved': {'vbd_eq_vbn': ''},
 'disarmed': {'vbd_eq_vbn': ''},
 'disarranged': {'vbd_eq_vbn': ''},
 'disarrayed': {'vbd_eq_vbn': ''},
 'disarticulated': {'vbd_eq_vbn': ''},
 'disassembled': {'vbd_eq_vbn': ''},
 'disassociated': {'vbd_eq_vbn': ''},
 'disavowed': {'vbd_eq_vbn': ''},
 'disbanded': {'vbd_eq_vbn': ''},
 'disbarred': {'vbd_eq_vbn': ''},
 'disbelieved': {'vbd_eq_vbn': ''},
 'disburdened': {'vbd_eq_vbn': ''},
 'disbursed': {'vbd_eq_vbn': ''},
 'discarded': {'vbd_eq_vbn': ''},
 'disced': {'vbd_eq_vbn': ''},
 'discerned': {'vbd_eq_vbn': ''},
 'discharged': {'vbd_eq_vbn': ''},
 'disclaimed': {'vbd_eq_vbn': ''},
 'disclosed': {'vbd_eq_vbn': ''},
 'discoed': {'vbd_eq_vbn': ''},
 'discolored': {'vbd_eq_vbn': ''},
 'discoloured': {'vbd_eq_vbn': ''},
 'discomfited': {'vbd_eq_vbn': ''},
 'discomforted': {'vbd_eq_vbn': ''},
 'discommoded': {'vbd_eq_vbn': ''},
 'discomposed': {'vbd_eq_vbn': ''},
 'discontinued': {'vbd_eq_vbn': ''},
 'discorded': {'vbd_eq_vbn': ''},
 'discountenanced': {'vbd_eq_vbn': ''},
 'discoursed': {'vbd_eq_vbn': ''},
 'discredited': {'vbd_eq_vbn': ''},
 'discriminated': {'vbd_eq_vbn': ''},
 'disdained': {'vbd_eq_vbn': ''},
 'disembarked': {'vbd_eq_vbn': ''},
 'disemboweled': {'vbd_eq_vbn': ''},
 'disembowelled': {'vbd_eq_vbn': ''},
 'disencumbered': {'vbd_eq_vbn': ''},
 'disentangled': {'vbd_eq_vbn': ''},
 'disestablished': {'vbd_eq_vbn': ''},
 'disesteemed': {'vbd_eq_vbn': ''},
 'disfavored': {'vbd_eq_vbn': ''},
 'disfranchised': {'vbd_eq_vbn': ''},
 'disgorged': {'vbd_eq_vbn': ''},
 'disgraced': {'vbd_eq_vbn': ''},
 'disguised': {'vbd_eq_vbn': ''},
 'dishonored': {'vbd_eq_vbn': ''},
 'dishonoured': {'vbd_eq_vbn': ''},
 'disinfected': {'vbd_eq_vbn': ''},
 'disinherited': {'vbd_eq_vbn': ''},
 'disinhibited': {'vbd_eq_vbn': ''},
 'disintegrated': {'vbd_eq_vbn': ''},
 'disinterred': {'vbd_eq_vbn': ''},
 'disinvested': {'vbd_eq_vbn': ''},
 'disinvolved': {'vbd_eq_vbn': ''},
 'disjoined': {'vbd_eq_vbn': ''},
 'disked': {'vbd_eq_vbn': ''},
 'dislodged': {'vbd_eq_vbn': ''},
 'dismantled': {'vbd_eq_vbn': ''},
 'dismembered': {'vbd_eq_vbn': ''},
 'dismounted': {'vbd_eq_vbn': ''},
 'disobeyed': {'vbd_eq_vbn': ''},
 'disobliged': {'vbd_eq_vbn': ''},
 'disorganised': {'vbd_eq_vbn': ''},
 'disorientated': {'vbd_eq_vbn': ''},
 'disowned': {'vbd_eq_vbn': ''},
 'disparaged': {'vbd_eq_vbn': ''},
 'dispatched': {'vbd_eq_vbn': ''},
 'dispelled': {'vbd_eq_vbn': ''},
 'dispensed': {'vbd_eq_vbn': ''},
 'dispersed': {'vbd_eq_vbn': ''},
 'displumed': {'vbd_eq_vbn': ''},
 'disported': {'vbd_eq_vbn': ''},
 'dispossessed': {'vbd_eq_vbn': ''},
 'dispreaded': {'vbd_eq_vbn': ''},
 'disproved': {'vbd_eq_vbn': ''},
 'disqualified': {'vbd_eq_vbn': ''},
 'disquieted': {'vbd_eq_vbn': ''},
 'disregarded': {'vbd_eq_vbn': ''},
 'disrespected': {'vbd_eq_vbn': ''},
 'disrobed': {'vbd_eq_vbn': ''},
 'disrupted': {'vbd_eq_vbn': ''},
 'dissected': {'vbd_eq_vbn': ''},
 'dissed': {'vbd_eq_vbn': ''},
 'dissembled': {'vbd_eq_vbn': ''},
 'disseminated': {'vbd_eq_vbn': ''},
 'dissented': {'vbd_eq_vbn': ''},
 'dissertated': {'vbd_eq_vbn': ''},
 'dissevered': {'vbd_eq_vbn': ''},
 'dissimilated': {'vbd_eq_vbn': ''},
 'dissimulated': {'vbd_eq_vbn': ''},
 'dissociated': {'vbd_eq_vbn': ''},
 'dissolved': {'vbd_eq_vbn': ''},
 'dissuaded': {'vbd_eq_vbn': ''},
 'distasted': {'vbd_eq_vbn': ''},
 'distempered': {'vbd_eq_vbn': ''},
 'distilled': {'vbd_eq_vbn': ''},
 'distrained': {'vbd_eq_vbn': ''},
 'districted': {'vbd_eq_vbn': ''},
 'distrusted': {'vbd_eq_vbn': ''},
 'ditched': {'vbd_eq_vbn': ''},
 'dithered': {'vbd_eq_vbn': ''},
 'dittoed': {'vbd_eq_vbn': ''},
 'divagated': {'vbd_eq_vbn': ''},
 'divaricated': {'vbd_eq_vbn': ''},
 'dive-bombed': {'vbd_eq_vbn': ''},
 'dived': {'vbd_eq_vbn': ''},
 'diverged': {'vbd_eq_vbn': ''},
 'diversified': {'vbd_eq_vbn': ''},
 'diverted': {'vbd_eq_vbn': ''},
 'divested': {'vbd_eq_vbn': ''},
 'divined': {'vbd_eq_vbn': ''},
 'divulged': {'vbd_eq_vbn': ''},
 'divvied': {'vbd_eq_vbn': ''},
 'dizened': {'vbd_eq_vbn': ''},
 'dizzied': {'vbd_eq_vbn': ''},
 'do-si-doed': {'vbd_eq_vbn': ''},
 'docked': {'vbd_eq_vbn': ''},
 'docketed': {'vbd_eq_vbn': ''},
 'doddered': {'vbd_eq_vbn': ''},
 'dodged': {'vbd_eq_vbn': ''},
 'doffed': {'vbd_eq_vbn': ''},
 'dog-paddled': {'vbd_eq_vbn': ''},
 'dogmatised': {'vbd_eq_vbn': ''},
 'dogmatized': {'vbd_eq_vbn': ''},
 'doled': {'vbd_eq_vbn': ''},
 'dolled': {'vbd_eq_vbn': ''},
 'dollied': {'vbd_eq_vbn': ''},
 'dollopped': {'vbd_eq_vbn': ''},
 'domiciliated': {'vbd_eq_vbn': ''},
 'domineered': {'vbd_eq_vbn': ''},
 'donated': {'vbd_eq_vbn': ''},
 'donned': {'vbd_eq_vbn': ''},
 'doodled': {'vbd_eq_vbn': ''},
 'doomsaid': {'vbd_eq_vbn': ''},
 'doorstepped': {'vbd_eq_vbn': ''},
 'doped': {'vbd_eq_vbn': ''},
 'dosed': {'vbd_eq_vbn': ''},
 'dossed': {'vbd_eq_vbn': ''},
 'doted': {'vbd_eq_vbn': ''},
 'double-checked': {'vbd_eq_vbn': ''},
 'double-crossed': {'vbd_eq_vbn': ''},
 'double-dated': {'vbd_eq_vbn': ''},
 'double-glazed': {'vbd_eq_vbn': ''},
 'double-parked': {'vbd_eq_vbn': ''},
 'double-spaced': {'vbd_eq_vbn': ''},
 'double-teamed': {'vbd_eq_vbn': ''},
 'double-tongued': {'vbd_eq_vbn': ''},
 'douched': {'vbd_eq_vbn': ''},
 'doused': {'vbd_eq_vbn': ''},
 'dovetailed': {'vbd_eq_vbn': ''},
 'dowered': {'vbd_eq_vbn': ''},
 'downed': {'vbd_eq_vbn': ''},
 'downgraded': {'vbd_eq_vbn': ''},
 'downloaded': {'vbd_eq_vbn': ''},
 'downplayed': {'vbd_eq_vbn': ''},
 'downscaled': {'vbd_eq_vbn': ''},
 'downshifted': {'vbd_eq_vbn': ''},
 'downsized': {'vbd_eq_vbn': ''},
 'dowsed': {'vbd_eq_vbn': ''},
 'doxed': {'vbd_eq_vbn': ''},
 'dozed': {'vbd_eq_vbn': ''},
 'drabbed': {'vbd_eq_vbn': ''},
 'drafted': {'vbd_eq_vbn': ''},
 'draggled': {'vbd_eq_vbn': ''},
 'dragooned': {'vbd_eq_vbn': ''},
 'dramatised': {'vbd_eq_vbn': ''},
 'dramatized': {'vbd_eq_vbn': ''},
 'draped': {'vbd_eq_vbn': ''},
 'draughted': {'vbd_eq_vbn': ''},
 'drawled': {'vbd_eq_vbn': ''},
 'dreamed': {'vbd_eq_vbn': ''},
 'dreamt': {'vbd_eq_vbn': ''},
 'dredged': {'vbd_eq_vbn': ''},
 'dribbled': {'vbd_eq_vbn': ''},
 'drifted': {'vbd_eq_vbn': ''},
 'drilled': {'vbd_eq_vbn': ''},
 'drip-dried': {'vbd_eq_vbn': ''},
 'dripped': {'vbd_eq_vbn': ''},
 'driveled': {'vbd_eq_vbn': ''},
 'drivelled': {'vbd_eq_vbn': ''},
 'drizzled': {'vbd_eq_vbn': ''},
 'droned': {'vbd_eq_vbn': ''},
 'drooled': {'vbd_eq_vbn': ''},
 'drooped': {'vbd_eq_vbn': ''},
 'drop-kicked': {'vbd_eq_vbn': ''},
 'drowned': {'vbd_eq_vbn': ''},
 'drowsed': {'vbd_eq_vbn': ''},
 'drubbed': {'vbd_eq_vbn': ''},
 'drudged': {'vbd_eq_vbn': ''},
 'dry-cleaned': {'vbd_eq_vbn': ''},
 'dry-farmed': {'vbd_eq_vbn': ''},
 'dry-walled': {'vbd_eq_vbn': ''},
 'dubbed': {'vbd_eq_vbn': ''},
 'dubbined': {'vbd_eq_vbn': ''},
 'ducted': {'vbd_eq_vbn': ''},
 'duded': {'vbd_eq_vbn': ''},
 'dueled': {'vbd_eq_vbn': ''},
 'duelled': {'vbd_eq_vbn': ''},
 'duetted': {'vbd_eq_vbn': ''},
 'duffed': {'vbd_eq_vbn': ''},
 'duked': {'vbd_eq_vbn': ''},
 'dulcified': {'vbd_eq_vbn': ''},
 'dumbed': {'vbd_eq_vbn': ''},
 'dummied': {'vbd_eq_vbn': ''},
 'dumped': {'vbd_eq_vbn': ''},
 'dunged': {'vbd_eq_vbn': ''},
 'dunked': {'vbd_eq_vbn': ''},
 'dunned': {'vbd_eq_vbn': ''},
 'duped': {'vbd_eq_vbn': ''},
 'duplicated': {'vbd_eq_vbn': ''},
 'dusked': {'vbd_eq_vbn': ''},
 'dwarfed': {'vbd_eq_vbn': ''},
 'dwelled': {'vbd_eq_vbn': ''},
 'dwelt': {'vbd_eq_vbn': ''},
 'dwindled': {'vbd_eq_vbn': ''},
 'dyked': {'vbd_eq_vbn': ''},
 'dynamised': {'vbd_eq_vbn': ''},
 'dynamited': {'vbd_eq_vbn': ''},
 'dynamized': {'vbd_eq_vbn': ''},
 'e-mailed': {'vbd_eq_vbn': ''},
 'eagled': {'vbd_eq_vbn': ''},
 'earmarked': {'vbd_eq_vbn': ''},
 'earwigged': {'vbd_eq_vbn': ''},
 'eavesdropped': {'vbd_eq_vbn': ''},
 'ebbed': {'vbd_eq_vbn': ''},
 'ebonised': {'vbd_eq_vbn': ''},
 'ebonized': {'vbd_eq_vbn': ''},
 'echoed': {'vbd_eq_vbn': ''},
 'eclipsed': {'vbd_eq_vbn': ''},
 'economised': {'vbd_eq_vbn': ''},
 'economized': {'vbd_eq_vbn': ''},
 'eddied': {'vbd_eq_vbn': ''},
 'edified': {'vbd_eq_vbn': ''},
 'edited': {'vbd_eq_vbn': ''},
 'editorialised': {'vbd_eq_vbn': ''},
 'editorialized': {'vbd_eq_vbn': ''},
 'educed': {'vbd_eq_vbn': ''},
 'eeped': {'vbd_eq_vbn': ''},
 'effaced': {'vbd_eq_vbn': ''},
 'effectuated': {'vbd_eq_vbn': ''},
 'effed': {'vbd_eq_vbn': ''},
 'effeminised': {'vbd_eq_vbn': ''},
 'effeminized': {'vbd_eq_vbn': ''},
 'effervesced': {'vbd_eq_vbn': ''},
 'effleuraged': {'vbd_eq_vbn': ''},
 'effloresced': {'vbd_eq_vbn': ''},
 'effused': {'vbd_eq_vbn': ''},
 'egested': {'vbd_eq_vbn': ''},
 'egotripped': {'vbd_eq_vbn': ''},
 'egressed': {'vbd_eq_vbn': ''},
 'ejaculated': {'vbd_eq_vbn': ''},
 'ejected': {'vbd_eq_vbn': ''},
 'eked': {'vbd_eq_vbn': ''},
 'elaborated': {'vbd_eq_vbn': ''},
 'elapsed': {'vbd_eq_vbn': ''},
 'elbowed': {'vbd_eq_vbn': ''},
 'electioneered': {'vbd_eq_vbn': ''},
 'electrocuted': {'vbd_eq_vbn': ''},
 'electroplated': {'vbd_eq_vbn': ''},
 'elegised': {'vbd_eq_vbn': ''},
 'elegized': {'vbd_eq_vbn': ''},
 'elicited': {'vbd_eq_vbn': ''},
 'elided': {'vbd_eq_vbn': ''},
 'eliminated': {'vbd_eq_vbn': ''},
 'elocuted': {'vbd_eq_vbn': ''},
 'elongated': {'vbd_eq_vbn': ''},
 'eloped': {'vbd_eq_vbn': ''},
 'elucidated': {'vbd_eq_vbn': ''},
 'eluded': {'vbd_eq_vbn': ''},
 'eluted': {'vbd_eq_vbn': ''},
 'emailed': {'vbd_eq_vbn': ''},
 'emanated': {'vbd_eq_vbn': ''},
 'emasculated': {'vbd_eq_vbn': ''},
 'embalmed': {'vbd_eq_vbn': ''},
 'embanked': {'vbd_eq_vbn': ''},
 'embargoed': {'vbd_eq_vbn': ''},
 'embarked': {'vbd_eq_vbn': ''},
 'embedded': {'vbd_eq_vbn': ''},
 'embellished': {'vbd_eq_vbn': ''},
 'embezzled': {'vbd_eq_vbn': ''},
 'embodied': {'vbd_eq_vbn': ''},
 'emboldened': {'vbd_eq_vbn': ''},
 'embosomed': {'vbd_eq_vbn': ''},
 'embowered': {'vbd_eq_vbn': ''},
 'embraced': {'vbd_eq_vbn': ''},
 'embrangled': {'vbd_eq_vbn': ''},
 'embrocated': {'vbd_eq_vbn': ''},
 'embroidered': {'vbd_eq_vbn': ''},
 'embroiled': {'vbd_eq_vbn': ''},
 'embrowned': {'vbd_eq_vbn': ''},
 'emceed': {'vbd_eq_vbn': ''},
 'emended': {'vbd_eq_vbn': ''},
 'emigrated': {'vbd_eq_vbn': ''},
 'emitted': {'vbd_eq_vbn': ''},
 'emoted': {'vbd_eq_vbn': ''},
 'empaled': {'vbd_eq_vbn': ''},
 'empaneled': {'vbd_eq_vbn': ''},
 'empanelled': {'vbd_eq_vbn': ''},
 'empathised': {'vbd_eq_vbn': ''},
 'empathized': {'vbd_eq_vbn': ''},
 'emphasised': {'vbd_eq_vbn': ''},
 'emplaced': {'vbd_eq_vbn': ''},
 'emplaned': {'vbd_eq_vbn': ''},
 'empowered': {'vbd_eq_vbn': ''},
 'empurpled': {'vbd_eq_vbn': ''},
 'emulated': {'vbd_eq_vbn': ''},
 'emulsified': {'vbd_eq_vbn': ''},
 'enacted': {'vbd_eq_vbn': ''},
 'enameled': {'vbd_eq_vbn': ''},
 'enamelled': {'vbd_eq_vbn': ''},
 'enamored': {'vbd_eq_vbn': ''},
 'encamped': {'vbd_eq_vbn': ''},
 'encapsulated': {'vbd_eq_vbn': ''},
 'encased': {'vbd_eq_vbn': ''},
 'enchained': {'vbd_eq_vbn': ''},
 'enciphered': {'vbd_eq_vbn': ''},
 'encircled': {'vbd_eq_vbn': ''},
 'enclothed': {'vbd_eq_vbn': ''},
 'encoded': {'vbd_eq_vbn': ''},
 'encompassed': {'vbd_eq_vbn': ''},
 'encored': {'vbd_eq_vbn': ''},
 'encrimsoned': {'vbd_eq_vbn': ''},
 'encroached': {'vbd_eq_vbn': ''},
 'enculturated': {'vbd_eq_vbn': ''},
 'encumbered': {'vbd_eq_vbn': ''},
 'endeared': {'vbd_eq_vbn': ''},
 'endeavored': {'vbd_eq_vbn': ''},
 'endeavoured': {'vbd_eq_vbn': ''},
 'endorsed': {'vbd_eq_vbn': ''},
 'endowed': {'vbd_eq_vbn': ''},
 'endued': {'vbd_eq_vbn': ''},
 'endured': {'vbd_eq_vbn': ''},
 'energised': {'vbd_eq_vbn': ''},
 'energized': {'vbd_eq_vbn': ''},
 'enfeoffed': {'vbd_eq_vbn': ''},
 'enfiladed': {'vbd_eq_vbn': ''},
 'enfolded': {'vbd_eq_vbn': ''},
 'engendered': {'vbd_eq_vbn': ''},
 'engilded': {'vbd_eq_vbn': ''},
 'englutted': {'vbd_eq_vbn': ''},
 'engrafted': {'vbd_eq_vbn': ''},
 'engraved': {'vbd_eq_vbn': ''},
 'engulfed': {'vbd_eq_vbn': ''},
 'enjoined': {'vbd_eq_vbn': ''},
 'enkindled': {'vbd_eq_vbn': ''},
 'enlaced': {'vbd_eq_vbn': ''},
 'enlarged': {'vbd_eq_vbn': ''},
 'enlightened': {'vbd_eq_vbn': ''},
 'enlivened': {'vbd_eq_vbn': ''},
 'ennobled': {'vbd_eq_vbn': ''},
 'enounced': {'vbd_eq_vbn': ''},
 'enplaned': {'vbd_eq_vbn': ''},
 'enquired': {'vbd_eq_vbn': ''},
 'enraged': {'vbd_eq_vbn': ''},
 'enrobed': {'vbd_eq_vbn': ''},
 'enrolled': {'vbd_eq_vbn': ''},
 'ensconced': {'vbd_eq_vbn': ''},
 'enshrined': {'vbd_eq_vbn': ''},
 'enshrouded': {'vbd_eq_vbn': ''},
 'ensiled': {'vbd_eq_vbn': ''},
 'enskied': {'vbd_eq_vbn': ''},
 'enslaved': {'vbd_eq_vbn': ''},
 'ensnared': {'vbd_eq_vbn': ''},
 'ensnarled': {'vbd_eq_vbn': ''},
 'ensued': {'vbd_eq_vbn': ''},
 'entailed': {'vbd_eq_vbn': ''},
 'enthroned': {'vbd_eq_vbn': ''},
 'enthused': {'vbd_eq_vbn': ''},
 'enticed': {'vbd_eq_vbn': ''},
 'entombed': {'vbd_eq_vbn': ''},
 'entrained': {'vbd_eq_vbn': ''},
 'entrapped': {'vbd_eq_vbn': ''},
 'entreated': {'vbd_eq_vbn': ''},
 'entrepreneured': {'vbd_eq_vbn': ''},
 'entrusted': {'vbd_eq_vbn': ''},
 'entwined': {'vbd_eq_vbn': ''},
 'enucleated': {'vbd_eq_vbn': ''},
 'enumerated': {'vbd_eq_vbn': ''},
 'enunciated': {'vbd_eq_vbn': ''},
 'enured': {'vbd_eq_vbn': ''},
 'enveloped': {'vbd_eq_vbn': ''},
 'envenomed': {'vbd_eq_vbn': ''},
 'envied': {'vbd_eq_vbn': ''},
 'environed': {'vbd_eq_vbn': ''},
 'envisaged': {'vbd_eq_vbn': ''},
 'envisioned': {'vbd_eq_vbn': ''},
 'enwrapped': {'vbd_eq_vbn': ''},
 'epilated': {'vbd_eq_vbn': ''},
 'epitomised': {'vbd_eq_vbn': ''},
 'epitomized': {'vbd_eq_vbn': ''},
 'equaled': {'vbd_eq_vbn': ''},
 'equalised': {'vbd_eq_vbn': ''},
 'equalized': {'vbd_eq_vbn': ''},
 'equated': {'vbd_eq_vbn': ''},
 'equilibrated': {'vbd_eq_vbn': ''},
 'equipoised': {'vbd_eq_vbn': ''},
 'equipped': {'vbd_eq_vbn': ''},
 'equivocated': {'vbd_eq_vbn': ''},
 'eradicated': {'vbd_eq_vbn': ''},
 'erased': {'vbd_eq_vbn': ''},
 'erected': {'vbd_eq_vbn': ''},
 'eroded': {'vbd_eq_vbn': ''},
 'eroticised': {'vbd_eq_vbn': ''},
 'eroticized': {'vbd_eq_vbn': ''},
 'erred': {'vbd_eq_vbn': ''},
 'eructed': {'vbd_eq_vbn': ''},
 'erupted': {'vbd_eq_vbn': ''},
 'escaladed': {'vbd_eq_vbn': ''},
 'escalated': {'vbd_eq_vbn': ''},
 'eschewed': {'vbd_eq_vbn': ''},
 'escorted': {'vbd_eq_vbn': ''},
 'escrowed': {'vbd_eq_vbn': ''},
 'espaliered': {'vbd_eq_vbn': ''},
 'espied': {'vbd_eq_vbn': ''},
 'espoused': {'vbd_eq_vbn': ''},
 'essayed': {'vbd_eq_vbn': ''},
 'est': {'vbd_eq_vbn': ''},
 'estivated': {'vbd_eq_vbn': ''},
 'etched': {'vbd_eq_vbn': ''},
 'eternalised': {'vbd_eq_vbn': ''},
 'eternalized': {'vbd_eq_vbn': ''},
 'etherealised': {'vbd_eq_vbn': ''},
 'etherealized': {'vbd_eq_vbn': ''},
 'etherified': {'vbd_eq_vbn': ''},
 'etymologised': {'vbd_eq_vbn': ''},
 'etymologized': {'vbd_eq_vbn': ''},
 'eulogised': {'vbd_eq_vbn': ''},
 'eulogized': {'vbd_eq_vbn': ''},
 'euphemised': {'vbd_eq_vbn': ''},
 'euphemized': {'vbd_eq_vbn': ''},
 'europeanised': {'vbd_eq_vbn': ''},
 'europeanized': {'vbd_eq_vbn': ''},
 'euthanised': {'vbd_eq_vbn': ''},
 'euthanized': {'vbd_eq_vbn': ''},
 'evacuated': {'vbd_eq_vbn': ''},
 'evaded': {'vbd_eq_vbn': ''},
 'evaluated': {'vbd_eq_vbn': ''},
 'evanesced': {'vbd_eq_vbn': ''},
 'evangelised': {'vbd_eq_vbn': ''},
 'evangelized': {'vbd_eq_vbn': ''},
 'evaporated': {'vbd_eq_vbn': ''},
 'evened': {'vbd_eq_vbn': ''},
 'eventuated': {'vbd_eq_vbn': ''},
 'everted': {'vbd_eq_vbn': ''},
 'evicted': {'vbd_eq_vbn': ''},
 'evidenced': {'vbd_eq_vbn': ''},
 'evinced': {'vbd_eq_vbn': ''},
 'eviscerated': {'vbd_eq_vbn': ''},
 'evoked': {'vbd_eq_vbn': ''},
 'evolved': {'vbd_eq_vbn': ''},
 'exacerbated': {'vbd_eq_vbn': ''},
 'exacted': {'vbd_eq_vbn': ''},
 'excavated': {'vbd_eq_vbn': ''},
 'exceeded': {'vbd_eq_vbn': ''},
 'excelled': {'vbd_eq_vbn': ''},
 'excerpted': {'vbd_eq_vbn': ''},
 'excessed': {'vbd_eq_vbn': ''},
 'excised': {'vbd_eq_vbn': ''},
 'exclaimed': {'vbd_eq_vbn': ''},
 'excogitated': {'vbd_eq_vbn': ''},
 'excommunicated': {'vbd_eq_vbn': ''},
 'excoriated': {'vbd_eq_vbn': ''},
 'excreted': {'vbd_eq_vbn': ''},
 'excruciated': {'vbd_eq_vbn': ''},
 'exculpated': {'vbd_eq_vbn': ''},
 'execrated': {'vbd_eq_vbn': ''},
 'executed': {'vbd_eq_vbn': ''},
 'exemplified': {'vbd_eq_vbn': ''},
 'exempted': {'vbd_eq_vbn': ''},
 'exenterated': {'vbd_eq_vbn': ''},
 'exerted': {'vbd_eq_vbn': ''},
 'exfoliated': {'vbd_eq_vbn': ''},
 'exhaled': {'vbd_eq_vbn': ''},
 'exhorted': {'vbd_eq_vbn': ''},
 'exhumed': {'vbd_eq_vbn': ''},
 'exiled': {'vbd_eq_vbn': ''},
 'exonerated': {'vbd_eq_vbn': ''},
 'exorcised': {'vbd_eq_vbn': ''},
 'exorcized': {'vbd_eq_vbn': ''},
 'expatiated': {'vbd_eq_vbn': ''},
 'expatriated': {'vbd_eq_vbn': ''},
 'expectorated': {'vbd_eq_vbn': ''},
 'expedited': {'vbd_eq_vbn': ''},
 'expelled': {'vbd_eq_vbn': ''},
 'expended': {'vbd_eq_vbn': ''},
 'expensed': {'vbd_eq_vbn': ''},
 'expiated': {'vbd_eq_vbn': ''},
 'expired': {'vbd_eq_vbn': ''},
 'explicated': {'vbd_eq_vbn': ''},
 'exploited': {'vbd_eq_vbn': ''},
 'exported': {'vbd_eq_vbn': ''},
 'exposited': {'vbd_eq_vbn': ''},
 'expostulated': {'vbd_eq_vbn': ''},
 'expounded': {'vbd_eq_vbn': ''},
 'expropriated': {'vbd_eq_vbn': ''},
 'expunged': {'vbd_eq_vbn': ''},
 'exserted': {'vbd_eq_vbn': ''},
 'exsiccated': {'vbd_eq_vbn': ''},
 'extemporised': {'vbd_eq_vbn': ''},
 'extemporized': {'vbd_eq_vbn': ''},
 'extenuated': {'vbd_eq_vbn': ''},
 'exteriorised': {'vbd_eq_vbn': ''},
 'exteriorized': {'vbd_eq_vbn': ''},
 'exterminated': {'vbd_eq_vbn': ''},
 'externalised': {'vbd_eq_vbn': ''},
 'externalized': {'vbd_eq_vbn': ''},
 'externed': {'vbd_eq_vbn': ''},
 'extinguished': {'vbd_eq_vbn': ''},
 'extirpated': {'vbd_eq_vbn': ''},
 'extolled': {'vbd_eq_vbn': ''},
 'extorted': {'vbd_eq_vbn': ''},
 'extradited': {'vbd_eq_vbn': ''},
 'extrapolated': {'vbd_eq_vbn': ''},
 'extravasated': {'vbd_eq_vbn': ''},
 'extricated': {'vbd_eq_vbn': ''},
 'extruded': {'vbd_eq_vbn': ''},
 'exuberated': {'vbd_eq_vbn': ''},
 'exuded': {'vbd_eq_vbn': ''},
 'exulted': {'vbd_eq_vbn': ''},
 'exuviated': {'vbd_eq_vbn': ''},
 'eyeballed': {'vbd_eq_vbn': ''},
 'eyed': {'vbd_eq_vbn': ''},
 'fabricated': {'vbd_eq_vbn': ''},
 'face-lifted': {'vbd_eq_vbn': ''},
 'facilitated': {'vbd_eq_vbn': ''},
 'factorised': {'vbd_eq_vbn': ''},
 'factorized': {'vbd_eq_vbn': ''},
 'faggoted': {'vbd_eq_vbn': ''},
 'fagoted': {'vbd_eq_vbn': ''},
 'fainted': {'vbd_eq_vbn': ''},
 'faired': {'vbd_eq_vbn': ''},
 'faked': {'vbd_eq_vbn': ''},
 'fallowed': {'vbd_eq_vbn': ''},
 'falsified': {'vbd_eq_vbn': ''},
 'faltered': {'vbd_eq_vbn': ''},
 'familiarised': {'vbd_eq_vbn': ''},
 'familiarized': {'vbd_eq_vbn': ''},
 'fancified': {'vbd_eq_vbn': ''},
 'fantasied': {'vbd_eq_vbn': ''},
 'fantasised': {'vbd_eq_vbn': ''},
 'fantasized': {'vbd_eq_vbn': ''},
 'farced': {'vbd_eq_vbn': ''},
 'fared': {'vbd_eq_vbn': ''},
 'farrowed': {'vbd_eq_vbn': ''},
 'farted': {'vbd_eq_vbn': ''},
 'fast-forwarded': {'vbd_eq_vbn': ''},
 'fast-tracked': {'vbd_eq_vbn': ''},
 'fasted': {'vbd_eq_vbn': ''},
 'fastened': {'vbd_eq_vbn': ''},
 'fathered': {'vbd_eq_vbn': ''},
 'fathomed': {'vbd_eq_vbn': ''},
 'fatted': {'vbd_eq_vbn': ''},
 'fattened': {'vbd_eq_vbn': ''},
 'fawned': {'vbd_eq_vbn': ''},
 'faxed': {'vbd_eq_vbn': ''},
 'fayed': {'vbd_eq_vbn': ''},
 'fazed': {'vbd_eq_vbn': ''},
 'feasted': {'vbd_eq_vbn': ''},
 'featherbedded': {'vbd_eq_vbn': ''},
 'federalised': {'vbd_eq_vbn': ''},
 'federalized': {'vbd_eq_vbn': ''},
 'federated': {'vbd_eq_vbn': ''},
 'feigned': {'vbd_eq_vbn': ''},
 'feinted': {'vbd_eq_vbn': ''},
 'felicitated': {'vbd_eq_vbn': ''},
 'fellated': {'vbd_eq_vbn': ''},
 'felled': {'vbd_eq_vbn': ''},
 'felted': {'vbd_eq_vbn': ''},
 'feminised': {'vbd_eq_vbn': ''},
 'feminized': {'vbd_eq_vbn': ''},
 'fended': {'vbd_eq_vbn': ''},
 'fermented': {'vbd_eq_vbn': ''},
 'ferreted': {'vbd_eq_vbn': ''},
 'ferried': {'vbd_eq_vbn': ''},
 'fertilised': {'vbd_eq_vbn': ''},
 'fertilized': {'vbd_eq_vbn': ''},
 'fessed': {'vbd_eq_vbn': ''},
 'festered': {'vbd_eq_vbn': ''},
 'festinated': {'vbd_eq_vbn': ''},
 'festooned': {'vbd_eq_vbn': ''},
 'feted': {'vbd_eq_vbn': ''},
 'fetishised': {'vbd_eq_vbn': ''},
 'fetishized': {'vbd_eq_vbn': ''},
 'fettered': {'vbd_eq_vbn': ''},
 'fettled': {'vbd_eq_vbn': ''},
 'feudalised': {'vbd_eq_vbn': ''},
 'feudalized': {'vbd_eq_vbn': ''},
 'feuded': {'vbd_eq_vbn': ''},
 'fibbed': {'vbd_eq_vbn': ''},
 'fibrillated': {'vbd_eq_vbn': ''},
 'fictionalised': {'vbd_eq_vbn': ''},
 'fictionalized': {'vbd_eq_vbn': ''},
 'fiddle-faddled': {'vbd_eq_vbn': ''},
 'fiddled': {'vbd_eq_vbn': ''},
 'fidgeted': {'vbd_eq_vbn': ''},
 'field-tested': {'vbd_eq_vbn': ''},
 'fielded': {'vbd_eq_vbn': ''},
 'filched': {'vbd_eq_vbn': ''},
 'filed': {'vbd_eq_vbn': ''},
 'fileted': {'vbd_eq_vbn': ''},
 'filiated': {'vbd_eq_vbn': ''},
 'filibustered': {'vbd_eq_vbn': ''},
 'filigreed': {'vbd_eq_vbn': ''},
 'filleted': {'vbd_eq_vbn': ''},
 'filliped': {'vbd_eq_vbn': ''},
 'filtered': {'vbd_eq_vbn': ''},
 'filtrated': {'vbd_eq_vbn': ''},
 'finagled': {'vbd_eq_vbn': ''},
 'finalised': {'vbd_eq_vbn': ''},
 'finalized': {'vbd_eq_vbn': ''},
 'financed': {'vbd_eq_vbn': ''},
 'financialised': {'vbd_eq_vbn': ''},
 'financialized': {'vbd_eq_vbn': ''},
 'fine-tuned': {'vbd_eq_vbn': ''},
 'fined': {'vbd_eq_vbn': ''},
 'finessed': {'vbd_eq_vbn': ''},
 'finger-painted': {'vbd_eq_vbn': ''},
 'fingered': {'vbd_eq_vbn': ''},
 'fingerprinted': {'vbd_eq_vbn': ''},
 'finked': {'vbd_eq_vbn': ''},
 'firebombed': {'vbd_eq_vbn': ''},
 'fired': {'vbd_eq_vbn': ''},
 'fireproofed': {'vbd_eq_vbn': ''},
 'firmed': {'vbd_eq_vbn': ''},
 'fished': {'vbd_eq_vbn': ''},
 'fishtailed': {'vbd_eq_vbn': ''},
 'fisted': {'vbd_eq_vbn': ''},
 'fizzed': {'vbd_eq_vbn': ''},
 'fizzled': {'vbd_eq_vbn': ''},
 'flagellated': {'vbd_eq_vbn': ''},
 'flailed': {'vbd_eq_vbn': ''},
 'flaked': {'vbd_eq_vbn': ''},
 'flamed': {'vbd_eq_vbn': ''},
 'flanked': {'vbd_eq_vbn': ''},
 'flanneled': {'vbd_eq_vbn': ''},
 'flannelled': {'vbd_eq_vbn': ''},
 'flapped': {'vbd_eq_vbn': ''},
 'flatlined': {'vbd_eq_vbn': ''},
 'flatted': {'vbd_eq_vbn': ''},
 'flaunted': {'vbd_eq_vbn': ''},
 'flayed': {'vbd_eq_vbn': ''},
 'fled': {'vbd_eq_vbn': ''},
 'fleeced': {'vbd_eq_vbn': ''},
 'fleered': {'vbd_eq_vbn': ''},
 'fleeted': {'vbd_eq_vbn': ''},
 'flensed': {'vbd_eq_vbn': ''},
 'flexed': {'vbd_eq_vbn': ''},
 'flicked': {'vbd_eq_vbn': ''},
 'flickered': {'vbd_eq_vbn': ''},
 'flight-tested': {'vbd_eq_vbn': ''},
 'flighted': {'vbd_eq_vbn': ''},
 'flimflammed': {'vbd_eq_vbn': ''},
 'flinched': {'vbd_eq_vbn': ''},
 'flip-flopped': {'vbd_eq_vbn': ''},
 'flipped': {'vbd_eq_vbn': ''},
 'flirted': {'vbd_eq_vbn': ''},
 'flitted': {'vbd_eq_vbn': ''},
 'flittered': {'vbd_eq_vbn': ''},
 'floated': {'vbd_eq_vbn': ''},
 'flocculated': {'vbd_eq_vbn': ''},
 'flocked': {'vbd_eq_vbn': ''},
 'flogged': {'vbd_eq_vbn': ''},
 'floodlighted': {'vbd_eq_vbn': ''},
 'floodlit': {'vbd_eq_vbn': ''},
 'flopped': {'vbd_eq_vbn': ''},
 'flossed': {'vbd_eq_vbn': ''},
 'floundered': {'vbd_eq_vbn': ''},
 'floured': {'vbd_eq_vbn': ''},
 'flourished': {'vbd_eq_vbn': ''},
 'flouted': {'vbd_eq_vbn': ''},
 'flowed': {'vbd_eq_vbn': ''},
 'flubbed': {'vbd_eq_vbn': ''},
 'fluctuated': {'vbd_eq_vbn': ''},
 'fluffed': {'vbd_eq_vbn': ''},
 'flumped': {'vbd_eq_vbn': ''},
 'flung': {'vbd_eq_vbn': ''},
 'flunked': {'vbd_eq_vbn': ''},
 'fluoresced': {'vbd_eq_vbn': ''},
 'fluoridated': {'vbd_eq_vbn': ''},
 'fluoridised': {'vbd_eq_vbn': ''},
 'fluoridized': {'vbd_eq_vbn': ''},
 'fluorinated': {'vbd_eq_vbn': ''},
 'fluttered': {'vbd_eq_vbn': ''},
 'fluxed': {'vbd_eq_vbn': ''},
 'fly-fished': {'vbd_eq_vbn': ''},
 'flyspecked': {'vbd_eq_vbn': ''},
 'foaled': {'vbd_eq_vbn': ''},
 'foamed': {'vbd_eq_vbn': ''},
 'fobbed': {'vbd_eq_vbn': ''},
 'focalised': {'vbd_eq_vbn': ''},
 'focalized': {'vbd_eq_vbn': ''},
 'foddered': {'vbd_eq_vbn': ''},
 'fogged': {'vbd_eq_vbn': ''},
 'foiled': {'vbd_eq_vbn': ''},
 'foisted': {'vbd_eq_vbn': ''},
 'folioed': {'vbd_eq_vbn': ''},
 'fomented': {'vbd_eq_vbn': ''},
 'fondled': {'vbd_eq_vbn': ''},
 'fooled': {'vbd_eq_vbn': ''},
 'footled': {'vbd_eq_vbn': ''},
 'footnoted': {'vbd_eq_vbn': ''},
 'foraged': {'vbd_eq_vbn': ''},
 'forayed': {'vbd_eq_vbn': ''},
 'force-fed': {'vbd_eq_vbn': ''},
 'forded': {'vbd_eq_vbn': ''},
 'foreboded': {'vbd_eq_vbn': ''},
 'forecasted': {'vbd_eq_vbn': ''},
 'foreclosed': {'vbd_eq_vbn': ''},
 'foredated': {'vbd_eq_vbn': ''},
 'foredoomed': {'vbd_eq_vbn': ''},
 'foregathered': {'vbd_eq_vbn': ''},
 'foregrounded': {'vbd_eq_vbn': ''},
 'foreordained': {'vbd_eq_vbn': ''},
 'foreshadowed': {'vbd_eq_vbn': ''},
 'foreshowed': {'vbd_eq_vbn': ''},
 'forestalled': {'vbd_eq_vbn': ''},
 'foretasted': {'vbd_eq_vbn': ''},
 'foretold': {'vbd_eq_vbn': ''},
 'forewarned': {'vbd_eq_vbn': ''},
 'forfeited': {'vbd_eq_vbn': ''},
 'forfended': {'vbd_eq_vbn': ''},
 'forgathered': {'vbd_eq_vbn': ''},
 'forged': {'vbd_eq_vbn': ''},
 'formalised': {'vbd_eq_vbn': ''},
 'formalized': {'vbd_eq_vbn': ''},
 'formicated': {'vbd_eq_vbn': ''},
 'formularised': {'vbd_eq_vbn': ''},
 'formularized': {'vbd_eq_vbn': ''},
 'formulated': {'vbd_eq_vbn': ''},
 'fornicated': {'vbd_eq_vbn': ''},
 'forted': {'vbd_eq_vbn': ''},
 'fortified': {'vbd_eq_vbn': ''},
 'fortuned': {'vbd_eq_vbn': ''},
 'fossilized': {'vbd_eq_vbn': ''},
 'fostered': {'vbd_eq_vbn': ''},
 'fouled': {'vbd_eq_vbn': ''},
 'foundered': {'vbd_eq_vbn': ''},
 'four-flushed': {'vbd_eq_vbn': ''},
 'fowled': {'vbd_eq_vbn': ''},
 'foxed': {'vbd_eq_vbn': ''},
 'foxtrotted': {'vbd_eq_vbn': ''},
 'fractionated': {'vbd_eq_vbn': ''},
 'fractioned': {'vbd_eq_vbn': ''},
 'fragmentised': {'vbd_eq_vbn': ''},
 'fragmentized': {'vbd_eq_vbn': ''},
 'franchised': {'vbd_eq_vbn': ''},
 'franked': {'vbd_eq_vbn': ''},
 'frapped': {'vbd_eq_vbn': ''},
 'fraternised': {'vbd_eq_vbn': ''},
 'fraternized': {'vbd_eq_vbn': ''},
 'freaked': {'vbd_eq_vbn': ''},
 'free-associated': {'vbd_eq_vbn': ''},
 'freebased': {'vbd_eq_vbn': ''},
 'freelanced': {'vbd_eq_vbn': ''},
 'freeloaded': {'vbd_eq_vbn': ''},
 'freewheeled': {'vbd_eq_vbn': ''},
 'freighted': {'vbd_eq_vbn': ''},
 'Frenchified': {'vbd_eq_vbn': ''},
 'frequented': {'vbd_eq_vbn': ''},
 'frescoed': {'vbd_eq_vbn': ''},
 'freshened': {'vbd_eq_vbn': ''},
 'fricasseed': {'vbd_eq_vbn': ''},
 'friended': {'vbd_eq_vbn': ''},
 'frigged': {'vbd_eq_vbn': ''},
 'frighted': {'vbd_eq_vbn': ''},
 'fringed': {'vbd_eq_vbn': ''},
 'frisked': {'vbd_eq_vbn': ''},
 'frittered': {'vbd_eq_vbn': ''},
 'frivoled': {'vbd_eq_vbn': ''},
 'frivolled': {'vbd_eq_vbn': ''},
 'frizzed': {'vbd_eq_vbn': ''},
 'frizzled': {'vbd_eq_vbn': ''},
 'frocked': {'vbd_eq_vbn': ''},
 'frogmarched': {'vbd_eq_vbn': ''},
 'frolicked': {'vbd_eq_vbn': ''},
 'front-loaded': {'vbd_eq_vbn': ''},
 'frothed': {'vbd_eq_vbn': ''},
 'frowned': {'vbd_eq_vbn': ''},
 'fructified': {'vbd_eq_vbn': ''},
 'ftped': {'vbd_eq_vbn': ''},
 'fucked': {'vbd_eq_vbn': ''},
 'fudged': {'vbd_eq_vbn': ''},
 'fuelled': {'vbd_eq_vbn': ''},
 'fulgurated': {'vbd_eq_vbn': ''},
 'fullered': {'vbd_eq_vbn': ''},
 'fulminated': {'vbd_eq_vbn': ''},
 'fumbled': {'vbd_eq_vbn': ''},
 'fumed': {'vbd_eq_vbn': ''},
 'fumigated': {'vbd_eq_vbn': ''},
 'fund-raised': {'vbd_eq_vbn': ''},
 'fundraised': {'vbd_eq_vbn': ''},
 'funked': {'vbd_eq_vbn': ''},
 'furbished': {'vbd_eq_vbn': ''},
 'furloughed': {'vbd_eq_vbn': ''},
 'furthered': {'vbd_eq_vbn': ''},
 'fustigated': {'vbd_eq_vbn': ''},
 'fuzed': {'vbd_eq_vbn': ''},
 'fuzzed': {'vbd_eq_vbn': ''},
 'gabbed': {'vbd_eq_vbn': ''},
 'gabbled': {'vbd_eq_vbn': ''},
 'gadded': {'vbd_eq_vbn': ''},
 'gaffed': {'vbd_eq_vbn': ''},
 'gaged': {'vbd_eq_vbn': ''},
 'gagged': {'vbd_eq_vbn': ''},
 'gainsaid': {'vbd_eq_vbn': ''},
 'gallanted': {'vbd_eq_vbn': ''},
 'galled': {'vbd_eq_vbn': ''},
 'gallivanted': {'vbd_eq_vbn': ''},
 'galloped': {'vbd_eq_vbn': ''},
 'galumphed': {'vbd_eq_vbn': ''},
 'galvanised': {'vbd_eq_vbn': ''},
 'gambled': {'vbd_eq_vbn': ''},
 'gamboled': {'vbd_eq_vbn': ''},
 'gambolled': {'vbd_eq_vbn': ''},
 'gamed': {'vbd_eq_vbn': ''},
 'gang-raped': {'vbd_eq_vbn': ''},
 'gangbanged': {'vbd_eq_vbn': ''},
 'gangrened': {'vbd_eq_vbn': ''},
 'gaoled': {'vbd_eq_vbn': ''},
 'gaped': {'vbd_eq_vbn': ''},
 'gapped': {'vbd_eq_vbn': ''},
 'gargled': {'vbd_eq_vbn': ''},
 'garlanded': {'vbd_eq_vbn': ''},
 'garmented': {'vbd_eq_vbn': ''},
 'garnered': {'vbd_eq_vbn': ''},
 'garnished': {'vbd_eq_vbn': ''},
 'garnisheed': {'vbd_eq_vbn': ''},
 'garotted': {'vbd_eq_vbn': ''},
 'garrisoned': {'vbd_eq_vbn': ''},
 'garroted': {'vbd_eq_vbn': ''},
 'garrotted': {'vbd_eq_vbn': ''},
 'gartered': {'vbd_eq_vbn': ''},
 'gasconaded': {'vbd_eq_vbn': ''},
 'gashed': {'vbd_eq_vbn': ''},
 'gasified': {'vbd_eq_vbn': ''},
 'gasped': {'vbd_eq_vbn': ''},
 'gate-crashed': {'vbd_eq_vbn': ''},
 'gatecrashed': {'vbd_eq_vbn': ''},
 'gated': {'vbd_eq_vbn': ''},
 'gauged': {'vbd_eq_vbn': ''},
 'gaveled': {'vbd_eq_vbn': ''},
 'gavelled': {'vbd_eq_vbn': ''},
 'gawked': {'vbd_eq_vbn': ''},
 'gawped': {'vbd_eq_vbn': ''},
 'gazed': {'vbd_eq_vbn': ''},
 'gazetted': {'vbd_eq_vbn': ''},
 'gazumped': {'vbd_eq_vbn': ''},
 'geed': {'vbd_eq_vbn': ''},
 'geeked': {'vbd_eq_vbn': ''},
 'gelatinised': {'vbd_eq_vbn': ''},
 'gelatinized': {'vbd_eq_vbn': ''},
 'gelded': {'vbd_eq_vbn': ''},
 'gelled': {'vbd_eq_vbn': ''},
 'geminated': {'vbd_eq_vbn': ''},
 'gemmed': {'vbd_eq_vbn': ''},
 'gendered': {'vbd_eq_vbn': ''},
 'gentled': {'vbd_eq_vbn': ''},
 'gentrified': {'vbd_eq_vbn': ''},
 'genuflected': {'vbd_eq_vbn': ''},
 'geotagged': {'vbd_eq_vbn': ''},
 'germinated': {'vbd_eq_vbn': ''},
 'gerrymandered': {'vbd_eq_vbn': ''},
 'gestated': {'vbd_eq_vbn': ''},
 'gesticulated': {'vbd_eq_vbn': ''},
 'gestured': {'vbd_eq_vbn': ''},
 'ghettoised': {'vbd_eq_vbn': ''},
 'ghettoized': {'vbd_eq_vbn': ''},
 'ghosted': {'vbd_eq_vbn': ''},
 'gibbered': {'vbd_eq_vbn': ''},
 'gibbeted': {'vbd_eq_vbn': ''},
 'gibbetted': {'vbd_eq_vbn': ''},
 'gibed': {'vbd_eq_vbn': ''},
 'giddied': {'vbd_eq_vbn': ''},
 'gift-wrapped': {'vbd_eq_vbn': ''},
 'gigged': {'vbd_eq_vbn': ''},
 'giggled': {'vbd_eq_vbn': ''},
 'gilded': {'vbd_eq_vbn': ''},
 'gilled': {'vbd_eq_vbn': ''},
 'gimbaled': {'vbd_eq_vbn': ''},
 'gimballed': {'vbd_eq_vbn': ''},
 'gimmicked': {'vbd_eq_vbn': ''},
 'gingered': {'vbd_eq_vbn': ''},
 'ginned': {'vbd_eq_vbn': ''},
 'gipped': {'vbd_eq_vbn': ''},
 'girded': {'vbd_eq_vbn': ''},
 'girdled': {'vbd_eq_vbn': ''},
 'girt': {'vbd_eq_vbn': ''},
 'girthed': {'vbd_eq_vbn': ''},
 'glad-handed': {'vbd_eq_vbn': ''},
 'gladded': {'vbd_eq_vbn': ''},
 'gladdened': {'vbd_eq_vbn': ''},
 'glamorised': {'vbd_eq_vbn': ''},
 'glamorized': {'vbd_eq_vbn': ''},
 'glared': {'vbd_eq_vbn': ''},
 'gleamed': {'vbd_eq_vbn': ''},
 'gleaned': {'vbd_eq_vbn': ''},
 'glided': {'vbd_eq_vbn': ''},
 'glimmered': {'vbd_eq_vbn': ''},
 'glimpsed': {'vbd_eq_vbn': ''},
 'glinted': {'vbd_eq_vbn': ''},
 'glissaded': {'vbd_eq_vbn': ''},
 'glistened': {'vbd_eq_vbn': ''},
 'glittered': {'vbd_eq_vbn': ''},
 'gloated': {'vbd_eq_vbn': ''},
 'globalised': {'vbd_eq_vbn': ''},
 'globalized': {'vbd_eq_vbn': ''},
 'globe-trotted': {'vbd_eq_vbn': ''},
 'globed': {'vbd_eq_vbn': ''},
 'glommed': {'vbd_eq_vbn': ''},
 'gloomed': {'vbd_eq_vbn': ''},
 'gloried': {'vbd_eq_vbn': ''},
 'glossed': {'vbd_eq_vbn': ''},
 'glowed': {'vbd_eq_vbn': ''},
 'glowered': {'vbd_eq_vbn': ''},
 'glued': {'vbd_eq_vbn': ''},
 'glutted': {'vbd_eq_vbn': ''},
 'glycerolized': {'vbd_eq_vbn': ''},
 'gnashed': {'vbd_eq_vbn': ''},
 'gnawed': {'vbd_eq_vbn': ''},
 'goaded': {'vbd_eq_vbn': ''},
 'gobbled': {'vbd_eq_vbn': ''},
 'goffered': {'vbd_eq_vbn': ''},
 'goggled': {'vbd_eq_vbn': ''},
 'goldbricked': {'vbd_eq_vbn': ''},
 'golfed': {'vbd_eq_vbn': ''},
 'gonged': {'vbd_eq_vbn': ''},
 'goofed': {'vbd_eq_vbn': ''},
 'googled': {'vbd_eq_vbn': ''},
 'goose-stepped': {'vbd_eq_vbn': ''},
 'goosed': {'vbd_eq_vbn': ''},
 'gored': {'vbd_eq_vbn': ''},
 'gorged': {'vbd_eq_vbn': ''},
 'gormandised': {'vbd_eq_vbn': ''},
 'gormandized': {'vbd_eq_vbn': ''},
 'gossiped': {'vbd_eq_vbn': ''},
 'gouged': {'vbd_eq_vbn': ''},
 'gowned': {'vbd_eq_vbn': ''},
 'graced': {'vbd_eq_vbn': ''},
 'gradated': {'vbd_eq_vbn': ''},
 'grafted': {'vbd_eq_vbn': ''},
 'grained': {'vbd_eq_vbn': ''},
 'grandfathered': {'vbd_eq_vbn': ''},
 'grandstanded': {'vbd_eq_vbn': ''},
 'grappled': {'vbd_eq_vbn': ''},
 'grasped': {'vbd_eq_vbn': ''},
 'grassed': {'vbd_eq_vbn': ''},
 'grated': {'vbd_eq_vbn': ''},
 'graunted': {'vbd_eq_vbn': ''},
 'graved': {'vbd_eq_vbn': ''},
 'graveled': {'vbd_eq_vbn': ''},
 'gravitated': {'vbd_eq_vbn': ''},
 'grayed': {'vbd_eq_vbn': ''},
 'greased': {'vbd_eq_vbn': ''},
 'greatened': {'vbd_eq_vbn': ''},
 'greened': {'vbd_eq_vbn': ''},
 'greenlighted': {'vbd_eq_vbn': ''},
 'greenlit': {'vbd_eq_vbn': ''},
 'greeted': {'vbd_eq_vbn': ''},
 'greyed': {'vbd_eq_vbn': ''},
 'griddled': {'vbd_eq_vbn': ''},
 'grieved': {'vbd_eq_vbn': ''},
 'grilled': {'vbd_eq_vbn': ''},
 'grimaced': {'vbd_eq_vbn': ''},
 'grimed': {'vbd_eq_vbn': ''},
 'grinned': {'vbd_eq_vbn': ''},
 'griped': {'vbd_eq_vbn': ''},
 'gripped': {'vbd_eq_vbn': ''},
 'gritted': {'vbd_eq_vbn': ''},
 'groaked': {'vbd_eq_vbn': ''},
 'groaned': {'vbd_eq_vbn': ''},
 'groined': {'vbd_eq_vbn': ''},
 'grokked': {'vbd_eq_vbn': ''},
 'groomed': {'vbd_eq_vbn': ''},
 'groped': {'vbd_eq_vbn': ''},
 'grossed': {'vbd_eq_vbn': ''},
 'grouched': {'vbd_eq_vbn': ''},
 'groused': {'vbd_eq_vbn': ''},
 'grouted': {'vbd_eq_vbn': ''},
 'groveled': {'vbd_eq_vbn': ''},
 'grovelled': {'vbd_eq_vbn': ''},
 'growled': {'vbd_eq_vbn': ''},
 'grubbed': {'vbd_eq_vbn': ''},
 'grudged': {'vbd_eq_vbn': ''},
 'grumbled': {'vbd_eq_vbn': ''},
 'grumped': {'vbd_eq_vbn': ''},
 'grunted': {'vbd_eq_vbn': ''},
 'gruntled': {'vbd_eq_vbn': ''},
 'guarantied': {'vbd_eq_vbn': ''},
 'guested': {'vbd_eq_vbn': ''},
 'guffawed': {'vbd_eq_vbn': ''},
 'guggled': {'vbd_eq_vbn': ''},
 'guillotined': {'vbd_eq_vbn': ''},
 'gulled': {'vbd_eq_vbn': ''},
 'gullied': {'vbd_eq_vbn': ''},
 'gulped': {'vbd_eq_vbn': ''},
 'gummed': {'vbd_eq_vbn': ''},
 'gunned': {'vbd_eq_vbn': ''},
 'gurgled': {'vbd_eq_vbn': ''},
 'gushed': {'vbd_eq_vbn': ''},
 'gussied': {'vbd_eq_vbn': ''},
 'gusted': {'vbd_eq_vbn': ''},
 'guttered': {'vbd_eq_vbn': ''},
 'guttled': {'vbd_eq_vbn': ''},
 'guyed': {'vbd_eq_vbn': ''},
 'guzzled': {'vbd_eq_vbn': ''},
 'gybed': {'vbd_eq_vbn': ''},
 'gypped': {'vbd_eq_vbn': ''},
 'gyrated': {'vbd_eq_vbn': ''},
 'habilitated': {'vbd_eq_vbn': ''},
 'habituated': {'vbd_eq_vbn': ''},
 'hacked': {'vbd_eq_vbn': ''},
 'haemorrhaged': {'vbd_eq_vbn': ''},
 'haggled': {'vbd_eq_vbn': ''},
 'hailed': {'vbd_eq_vbn': ''},
 'halalled': {'vbd_eq_vbn': ''},
 'haled': {'vbd_eq_vbn': ''},
 'half-inched': {'vbd_eq_vbn': ''},
 'half-masted': {'vbd_eq_vbn': ''},
 'hallmarked': {'vbd_eq_vbn': ''},
 'halloaed': {'vbd_eq_vbn': ''},
 'hallooed': {'vbd_eq_vbn': ''},
 'hallucinated': {'vbd_eq_vbn': ''},
 'haloed': {'vbd_eq_vbn': ''},
 'halogenated': {'vbd_eq_vbn': ''},
 'halted': {'vbd_eq_vbn': ''},
 'haltered': {'vbd_eq_vbn': ''},
 'halved': {'vbd_eq_vbn': ''},
 'hammed': {'vbd_eq_vbn': ''},
 'hampered': {'vbd_eq_vbn': ''},
 'hamstrung': {'vbd_eq_vbn': ''},
 'hand-fed': {'vbd_eq_vbn': ''},
 'hand-knit': {'vbd_eq_vbn': ''},
 'hand-knitted': {'vbd_eq_vbn': ''},
 'hand-reared': {'vbd_eq_vbn': ''},
 'hand-washed': {'vbd_eq_vbn': ''},
 'handcuffed': {'vbd_eq_vbn': ''},
 'handwashed': {'vbd_eq_vbn': ''},
 'hanged': {'vbd_eq_vbn': ''},
 'hankered': {'vbd_eq_vbn': ''},
 'happed': {'vbd_eq_vbn': ''},
 'harangued': {'vbd_eq_vbn': ''},
 'harbingered': {'vbd_eq_vbn': ''},
 'harbored': {'vbd_eq_vbn': ''},
 'harboured': {'vbd_eq_vbn': ''},
 'hared': {'vbd_eq_vbn': ''},
 'harked': {'vbd_eq_vbn': ''},
 'harkened': {'vbd_eq_vbn': ''},
 'harmonised': {'vbd_eq_vbn': ''},
 'harmonized': {'vbd_eq_vbn': ''},
 'harnessed': {'vbd_eq_vbn': ''},
 'harped': {'vbd_eq_vbn': ''},
 'harpooned': {'vbd_eq_vbn': ''},
 'harried': {'vbd_eq_vbn': ''},
 'harrowed': {'vbd_eq_vbn': ''},
 'harrumphed': {'vbd_eq_vbn': ''},
 'harshened': {'vbd_eq_vbn': ''},
 'harvested': {'vbd_eq_vbn': ''},
 'hashed': {'vbd_eq_vbn': ''},
 'hashtagged': {'vbd_eq_vbn': ''},
 'hassled': {'vbd_eq_vbn': ''},
 'hasted': {'vbd_eq_vbn': ''},
 'hastened': {'vbd_eq_vbn': ''},
 'hatched': {'vbd_eq_vbn': ''},
 'hatcheled': {'vbd_eq_vbn': ''},
 'hatchelled': {'vbd_eq_vbn': ''},
 'hauled': {'vbd_eq_vbn': ''},
 'havened': {'vbd_eq_vbn': ''},
 'havered': {'vbd_eq_vbn': ''},
 'havocked': {'vbd_eq_vbn': ''},
 'hawed': {'vbd_eq_vbn': ''},
 'hawked': {'vbd_eq_vbn': ''},
 'hayed': {'vbd_eq_vbn': ''},
 'hazarded': {'vbd_eq_vbn': ''},
 'hazed': {'vbd_eq_vbn': ''},
 'headbanged': {'vbd_eq_vbn': ''},
 'headbutted': {'vbd_eq_vbn': ''},
 'headlined': {'vbd_eq_vbn': ''},
 'healed': {'vbd_eq_vbn': ''},
 'hearkened': {'vbd_eq_vbn': ''},
 'hearted': {'vbd_eq_vbn': ''},
 'heartened': {'vbd_eq_vbn': ''},
 'heaved': {'vbd_eq_vbn': ''},
 'heckled': {'vbd_eq_vbn': ''},
 'hectographed': {'vbd_eq_vbn': ''},
 'hectored': {'vbd_eq_vbn': ''},
 'hedged': {'vbd_eq_vbn': ''},
 'hedgehopped': {'vbd_eq_vbn': ''},
 'heeded': {'vbd_eq_vbn': ''},
 'heeled': {'vbd_eq_vbn': ''},
 'hefted': {'vbd_eq_vbn': ''},
 'heightened': {'vbd_eq_vbn': ''},
 'heisted': {'vbd_eq_vbn': ''},
 'helicoptered': {'vbd_eq_vbn': ''},
 'helloed': {'vbd_eq_vbn': ''},
 'helmed': {'vbd_eq_vbn': ''},
 'hemmed': {'vbd_eq_vbn': ''},
 'hemorrhaged': {'vbd_eq_vbn': ''},
 'hennaed': {'vbd_eq_vbn': ''},
 'heralded': {'vbd_eq_vbn': ''},
 'herded': {'vbd_eq_vbn': ''},
 'herniated': {'vbd_eq_vbn': ''},
 'hero-worshipped': {'vbd_eq_vbn': ''},
 'heterodyned': {'vbd_eq_vbn': ''},
 'hewed': {'vbd_eq_vbn': ''},
 'hexed': {'vbd_eq_vbn': ''},
 'hibernated': {'vbd_eq_vbn': ''},
 'hiccoughed': {'vbd_eq_vbn': ''},
 'hiccupped': {'vbd_eq_vbn': ''},
 'hied': {'vbd_eq_vbn': ''},
 'high-fived': {'vbd_eq_vbn': ''},
 'high-hatted': {'vbd_eq_vbn': ''},
 'high-pressured': {'vbd_eq_vbn': ''},
 'high-tailed': {'vbd_eq_vbn': ''},
 'highballed': {'vbd_eq_vbn': ''},
 'highjacked': {'vbd_eq_vbn': ''},
 'hightailed': {'vbd_eq_vbn': ''},
 'hijacked': {'vbd_eq_vbn': ''},
 'hiked': {'vbd_eq_vbn': ''},
 'hilled': {'vbd_eq_vbn': ''},
 'hindered': {'vbd_eq_vbn': ''},
 'hinged': {'vbd_eq_vbn': ''},
 'hinted': {'vbd_eq_vbn': ''},
 'hipped': {'vbd_eq_vbn': ''},
 'hissed': {'vbd_eq_vbn': ''},
 'historicised': {'vbd_eq_vbn': ''},
 'historicized': {'vbd_eq_vbn': ''},
 'hitch-hiked': {'vbd_eq_vbn': ''},
 'hitched': {'vbd_eq_vbn': ''},
 'hitchhiked': {'vbd_eq_vbn': ''},
 'hived': {'vbd_eq_vbn': ''},
 'hoarded': {'vbd_eq_vbn': ''},
 'hoaxed': {'vbd_eq_vbn': ''},
 'hobbed': {'vbd_eq_vbn': ''},
 'hobbled': {'vbd_eq_vbn': ''},
 'hobnobbed': {'vbd_eq_vbn': ''},
 'hocked': {'vbd_eq_vbn': ''},
 'hoed': {'vbd_eq_vbn': ''},
 'hog-tied': {'vbd_eq_vbn': ''},
 'hogged': {'vbd_eq_vbn': ''},
 'hoisted': {'vbd_eq_vbn': ''},
 'hoked': {'vbd_eq_vbn': ''},
 'holidayed': {'vbd_eq_vbn': ''},
 'hollered': {'vbd_eq_vbn': ''},
 'holloaed': {'vbd_eq_vbn': ''},
 'holloed': {'vbd_eq_vbn': ''},
 'hollowed': {'vbd_eq_vbn': ''},
 'holystoned': {'vbd_eq_vbn': ''},
 'home-schooled': {'vbd_eq_vbn': ''},
 'homed': {'vbd_eq_vbn': ''},
 'homered': {'vbd_eq_vbn': ''},
 'homesteaded': {'vbd_eq_vbn': ''},
 'hominised': {'vbd_eq_vbn': ''},
 'hominized': {'vbd_eq_vbn': ''},
 'homogenised': {'vbd_eq_vbn': ''},
 'homologised': {'vbd_eq_vbn': ''},
 'homologized': {'vbd_eq_vbn': ''},
 'honed': {'vbd_eq_vbn': ''},
 'honeymooned': {'vbd_eq_vbn': ''},
 'honked': {'vbd_eq_vbn': ''},
 'honored': {'vbd_eq_vbn': ''},
 'hoodooed': {'vbd_eq_vbn': ''},
 'hoodwinked': {'vbd_eq_vbn': ''},
 'hoofed': {'vbd_eq_vbn': ''},
 'hoorayed': {'vbd_eq_vbn': ''},
 'hooted': {'vbd_eq_vbn': ''},
 'hoovered': {'vbd_eq_vbn': ''},
 'hopped': {'vbd_eq_vbn': ''},
 'hoppled': {'vbd_eq_vbn': ''},
 'horripilated': {'vbd_eq_vbn': ''},
 'horse-traded': {'vbd_eq_vbn': ''},
 'horse-whipped': {'vbd_eq_vbn': ''},
 'horseshoed': {'vbd_eq_vbn': ''},
 'horsewhipped': {'vbd_eq_vbn': ''},
 'hosed': {'vbd_eq_vbn': ''},
 'hospitalised': {'vbd_eq_vbn': ''},
 'hospitalized': {'vbd_eq_vbn': ''},
 'hosteled': {'vbd_eq_vbn': ''},
 'hot-dogged': {'vbd_eq_vbn': ''},
 'hot-tubbed': {'vbd_eq_vbn': ''},
 'hot-wired': {'vbd_eq_vbn': ''},
 'hot-worked': {'vbd_eq_vbn': ''},
 'hotfooted': {'vbd_eq_vbn': ''},
 'hotted': {'vbd_eq_vbn': ''},
 'hounded': {'vbd_eq_vbn': ''},
 'housecleaned': {'vbd_eq_vbn': ''},
 'housekept': {'vbd_eq_vbn': ''},
 'hove': {'vbd_eq_vbn': ''},
 'hovered': {'vbd_eq_vbn': ''},
 'howled': {'vbd_eq_vbn': ''},
 'huckstered': {'vbd_eq_vbn': ''},
 'huddled': {'vbd_eq_vbn': ''},
 'huffed': {'vbd_eq_vbn': ''},
 'hugged': {'vbd_eq_vbn': ''},
 'hulked': {'vbd_eq_vbn': ''},
 'hulled': {'vbd_eq_vbn': ''},
 'humanised': {'vbd_eq_vbn': ''},
 'humanized': {'vbd_eq_vbn': ''},
 'humbled': {'vbd_eq_vbn': ''},
 'humbugged': {'vbd_eq_vbn': ''},
 'humidified': {'vbd_eq_vbn': ''},
 'humified': {'vbd_eq_vbn': ''},
 'hummed': {'vbd_eq_vbn': ''},
 'humored': {'vbd_eq_vbn': ''},
 'humoured': {'vbd_eq_vbn': ''},
 'humped': {'vbd_eq_vbn': ''},
 'hungered': {'vbd_eq_vbn': ''},
 'hunkered': {'vbd_eq_vbn': ''},
 'hurdled': {'vbd_eq_vbn': ''},
 'hurled': {'vbd_eq_vbn': ''},
 'hurrahed': {'vbd_eq_vbn': ''},
 'hurtled': {'vbd_eq_vbn': ''},
 'husbanded': {'vbd_eq_vbn': ''},
 'husked': {'vbd_eq_vbn': ''},
 'hustled': {'vbd_eq_vbn': ''},
 'hutted': {'vbd_eq_vbn': ''},
 'hybridised': {'vbd_eq_vbn': ''},
 'hybridized': {'vbd_eq_vbn': ''},
 'hydrated': {'vbd_eq_vbn': ''},
 'hydrogenated': {'vbd_eq_vbn': ''},
 'hydrolised': {'vbd_eq_vbn': ''},
 'hydrolized': {'vbd_eq_vbn': ''},
 'hydrolysed': {'vbd_eq_vbn': ''},
 'hydrolyzed': {'vbd_eq_vbn': ''},
 'hydroplaned': {'vbd_eq_vbn': ''},
 'hygienised': {'vbd_eq_vbn': ''},
 'hygienized': {'vbd_eq_vbn': ''},
 'hymned': {'vbd_eq_vbn': ''},
 'hyped': {'vbd_eq_vbn': ''},
 'hyperbolised': {'vbd_eq_vbn': ''},
 'hyperbolized': {'vbd_eq_vbn': ''},
 'hyperextended': {'vbd_eq_vbn': ''},
 'hyperlinked': {'vbd_eq_vbn': ''},
 'hypersexualised': {'vbd_eq_vbn': ''},
 'hypersexualized': {'vbd_eq_vbn': ''},
 'hypertrophied': {'vbd_eq_vbn': ''},
 'hyperventilated': {'vbd_eq_vbn': ''},
 'hyphened': {'vbd_eq_vbn': ''},
 'hypnotised': {'vbd_eq_vbn': ''},
 'hypnotized': {'vbd_eq_vbn': ''},
 'hypophysectomised': {'vbd_eq_vbn': ''},
 'hypophysectomized': {'vbd_eq_vbn': ''},
 'hypostatised': {'vbd_eq_vbn': ''},
 'hypostatized': {'vbd_eq_vbn': ''},
 'hypothecated': {'vbd_eq_vbn': ''},
 'hypothesised': {'vbd_eq_vbn': ''},
 'hypothesized': {'vbd_eq_vbn': ''},
 'ice-skated': {'vbd_eq_vbn': ''},
 'idealised': {'vbd_eq_vbn': ''},
 'idealized': {'vbd_eq_vbn': ''},
 'ideated': {'vbd_eq_vbn': ''},
 'IDed': {'vbd_eq_vbn': ''},
 'idled': {'vbd_eq_vbn': ''},
 'idolised': {'vbd_eq_vbn': ''},
 'idolized': {'vbd_eq_vbn': ''},
 'ignited': {'vbd_eq_vbn': ''},
 'ill-treated': {'vbd_eq_vbn': ''},
 'illegalised': {'vbd_eq_vbn': ''},
 'illegalized': {'vbd_eq_vbn': ''},
 'illumed': {'vbd_eq_vbn': ''},
 'illumined': {'vbd_eq_vbn': ''},
 'imaged': {'vbd_eq_vbn': ''},
 'imbedded': {'vbd_eq_vbn': ''},
 'imbibed': {'vbd_eq_vbn': ''},
 'imbricated': {'vbd_eq_vbn': ''},
 'imbrued': {'vbd_eq_vbn': ''},
 'imbued': {'vbd_eq_vbn': ''},
 'immaterialised': {'vbd_eq_vbn': ''},
 'immaterialized': {'vbd_eq_vbn': ''},
 'immigrated': {'vbd_eq_vbn': ''},
 'immingled': {'vbd_eq_vbn': ''},
 'immobilised': {'vbd_eq_vbn': ''},
 'immobilized': {'vbd_eq_vbn': ''},
 'immolated': {'vbd_eq_vbn': ''},
 'immortalised': {'vbd_eq_vbn': ''},
 'immortalized': {'vbd_eq_vbn': ''},
 'immunised': {'vbd_eq_vbn': ''},
 'immunized': {'vbd_eq_vbn': ''},
 'immured': {'vbd_eq_vbn': ''},
 'impaled': {'vbd_eq_vbn': ''},
 'impaneled': {'vbd_eq_vbn': ''},
 'impanelled': {'vbd_eq_vbn': ''},
 'imparted': {'vbd_eq_vbn': ''},
 'impeached': {'vbd_eq_vbn': ''},
 'imped': {'vbd_eq_vbn': ''},
 'impeded': {'vbd_eq_vbn': ''},
 'impelled': {'vbd_eq_vbn': ''},
 'impended': {'vbd_eq_vbn': ''},
 'imperiled': {'vbd_eq_vbn': ''},
 'imperilled': {'vbd_eq_vbn': ''},
 'impersonated': {'vbd_eq_vbn': ''},
 'impinged': {'vbd_eq_vbn': ''},
 'implanted': {'vbd_eq_vbn': ''},
 'imploded': {'vbd_eq_vbn': ''},
 'implored': {'vbd_eq_vbn': ''},
 'importuned': {'vbd_eq_vbn': ''},
 'impounded': {'vbd_eq_vbn': ''},
 'imprecated': {'vbd_eq_vbn': ''},
 'impregnated': {'vbd_eq_vbn': ''},
 'imprinted': {'vbd_eq_vbn': ''},
 'imprisoned': {'vbd_eq_vbn': ''},
 'improvised': {'vbd_eq_vbn': ''},
 'impugned': {'vbd_eq_vbn': ''},
 'impulse-bought': {'vbd_eq_vbn': ''},
 'imputed': {'vbd_eq_vbn': ''},
 'inactivated': {'vbd_eq_vbn': ''},
 'inaugurated': {'vbd_eq_vbn': ''},
 'incandesced': {'vbd_eq_vbn': ''},
 'incanted': {'vbd_eq_vbn': ''},
 'incapacitated': {'vbd_eq_vbn': ''},
 'incarcerated': {'vbd_eq_vbn': ''},
 'incarnated': {'vbd_eq_vbn': ''},
 'incased': {'vbd_eq_vbn': ''},
 'incepted': {'vbd_eq_vbn': ''},
 'incinerated': {'vbd_eq_vbn': ''},
 'incised': {'vbd_eq_vbn': ''},
 'incited': {'vbd_eq_vbn': ''},
 'inclosed': {'vbd_eq_vbn': ''},
 'incommoded': {'vbd_eq_vbn': ''},
 'inconvenienced': {'vbd_eq_vbn': ''},
 'incriminated': {'vbd_eq_vbn': ''},
 'incrusted': {'vbd_eq_vbn': ''},
 'incubated': {'vbd_eq_vbn': ''},
 'inculcated': {'vbd_eq_vbn': ''},
 'inculpated': {'vbd_eq_vbn': ''},
 'incurred': {'vbd_eq_vbn': ''},
 'incurvated': {'vbd_eq_vbn': ''},
 'indemnified': {'vbd_eq_vbn': ''},
 'indicted': {'vbd_eq_vbn': ''},
 'individualised': {'vbd_eq_vbn': ''},
 'individuated': {'vbd_eq_vbn': ''},
 'indoctrinated': {'vbd_eq_vbn': ''},
 'indorsed': {'vbd_eq_vbn': ''},
 'induced': {'vbd_eq_vbn': ''},
 'inducted': {'vbd_eq_vbn': ''},
 'indulged': {'vbd_eq_vbn': ''},
 'indulgenced': {'vbd_eq_vbn': ''},
 'indurated': {'vbd_eq_vbn': ''},
 'indwelt': {'vbd_eq_vbn': ''},
 'infantilised': {'vbd_eq_vbn': ''},
 'infantilized': {'vbd_eq_vbn': ''},
 'infested': {'vbd_eq_vbn': ''},
 'infiltrated': {'vbd_eq_vbn': ''},
 'infixed': {'vbd_eq_vbn': ''},
 'inflicted': {'vbd_eq_vbn': ''},
 'infolded': {'vbd_eq_vbn': ''},
 'infolding': {'vbd_eq_vbn': ''},
 'informalized': {'vbd_eq_vbn': ''},
 'infracted': {'vbd_eq_vbn': ''},
 'infringed': {'vbd_eq_vbn': ''},
 'infused': {'vbd_eq_vbn': ''},
 'ingeminated': {'vbd_eq_vbn': ''},
 'ingested': {'vbd_eq_vbn': ''},
 'ingrafted': {'vbd_eq_vbn': ''},
 'ingratiated': {'vbd_eq_vbn': ''},
 'ingurgitated': {'vbd_eq_vbn': ''},
 'inhabited': {'vbd_eq_vbn': ''},
 'inhaled': {'vbd_eq_vbn': ''},
 'inhered': {'vbd_eq_vbn': ''},
 'inherited': {'vbd_eq_vbn': ''},
 'inhumed': {'vbd_eq_vbn': ''},
 'initialised': {'vbd_eq_vbn': ''},
 'initialized': {'vbd_eq_vbn': ''},
 'initialled': {'vbd_eq_vbn': ''},
 'initiated': {'vbd_eq_vbn': ''},
 'injected': {'vbd_eq_vbn': ''},
 'inked': {'vbd_eq_vbn': ''},
 'inlaid': {'vbd_eq_vbn': ''},
 'innervated': {'vbd_eq_vbn': ''},
 'innovated': {'vbd_eq_vbn': ''},
 'inoculated': {'vbd_eq_vbn': ''},
 'inosculated': {'vbd_eq_vbn': ''},
 'inputted': {'vbd_eq_vbn': ''},
 'inquired': {'vbd_eq_vbn': ''},
 'inscribed': {'vbd_eq_vbn': ''},
 'inseminated': {'vbd_eq_vbn': ''},
 'insinuated': {'vbd_eq_vbn': ''},
 'insolated': {'vbd_eq_vbn': ''},
 'inspanned': {'vbd_eq_vbn': ''},
 'inspirited': {'vbd_eq_vbn': ''},
 'inspissated': {'vbd_eq_vbn': ''},
 'Instagrammed': {'vbd_eq_vbn': ''},
 'instantiated': {'vbd_eq_vbn': ''},
 'instated': {'vbd_eq_vbn': ''},
 'instigated': {'vbd_eq_vbn': ''},
 'instilled': {'vbd_eq_vbn': ''},
 'instructed': {'vbd_eq_vbn': ''},
 'instrumented': {'vbd_eq_vbn': ''},
 'insufflated': {'vbd_eq_vbn': ''},
 'insulated': {'vbd_eq_vbn': ''},
 'insulted': {'vbd_eq_vbn': ''},
 'intellectualised': {'vbd_eq_vbn': ''},
 'intellectualized': {'vbd_eq_vbn': ''},
 'intensified': {'vbd_eq_vbn': ''},
 'interacted': {'vbd_eq_vbn': ''},
 'interbred': {'vbd_eq_vbn': ''},
 'intercalated': {'vbd_eq_vbn': ''},
 'interceded': {'vbd_eq_vbn': ''},
 'intercepted': {'vbd_eq_vbn': ''},
 'interchanged': {'vbd_eq_vbn': ''},
 'intercommunicated': {'vbd_eq_vbn': ''},
 'interconnected': {'vbd_eq_vbn': ''},
 'intercrossed': {'vbd_eq_vbn': ''},
 'interdepended': {'vbd_eq_vbn': ''},
 'interdicted': {'vbd_eq_vbn': ''},
 'interfaced': {'vbd_eq_vbn': ''},
 'interfered': {'vbd_eq_vbn': ''},
 'interiorised': {'vbd_eq_vbn': ''},
 'interiorized': {'vbd_eq_vbn': ''},
 'interjected': {'vbd_eq_vbn': ''},
 'interlarded': {'vbd_eq_vbn': ''},
 'interleaved': {'vbd_eq_vbn': ''},
 'interlineated': {'vbd_eq_vbn': ''},
 'interlined': {'vbd_eq_vbn': ''},
 'interlinked': {'vbd_eq_vbn': ''},
 'interlocked': {'vbd_eq_vbn': ''},
 'interloped': {'vbd_eq_vbn': ''},
 'intermarried': {'vbd_eq_vbn': ''},
 'intermediated': {'vbd_eq_vbn': ''},
 'intermeshed': {'vbd_eq_vbn': ''},
 'intermingled': {'vbd_eq_vbn': ''},
 'intermitted': {'vbd_eq_vbn': ''},
 'intermixed': {'vbd_eq_vbn': ''},
 'internalised': {'vbd_eq_vbn': ''},
 'internalized': {'vbd_eq_vbn': ''},
 'internationalised': {'vbd_eq_vbn': ''},
 'internationalized': {'vbd_eq_vbn': ''},
 'interned': {'vbd_eq_vbn': ''},
 'interpellated': {'vbd_eq_vbn': ''},
 'interpenetrated': {'vbd_eq_vbn': ''},
 'interplayed': {'vbd_eq_vbn': ''},
 'interpolated': {'vbd_eq_vbn': ''},
 'interposed': {'vbd_eq_vbn': ''},
 'interred': {'vbd_eq_vbn': ''},
 'interrogated': {'vbd_eq_vbn': ''},
 'intersected': {'vbd_eq_vbn': ''},
 'interspersed': {'vbd_eq_vbn': ''},
 'interstratified': {'vbd_eq_vbn': ''},
 'intertwined': {'vbd_eq_vbn': ''},
 'intervened': {'vbd_eq_vbn': ''},
 'intimated': {'vbd_eq_vbn': ''},
 'intonated': {'vbd_eq_vbn': ''},
 'intoned': {'vbd_eq_vbn': ''},
 'introjected': {'vbd_eq_vbn': ''},
 'intromitted': {'vbd_eq_vbn': ''},
 'introspected': {'vbd_eq_vbn': ''},
 'intruded': {'vbd_eq_vbn': ''},
 'intrusted': {'vbd_eq_vbn': ''},
 'intubated': {'vbd_eq_vbn': ''},
 'intuited': {'vbd_eq_vbn': ''},
 'intumesced': {'vbd_eq_vbn': ''},
 'intussuscepted': {'vbd_eq_vbn': ''},
 'inuncted': {'vbd_eq_vbn': ''},
 'inundated': {'vbd_eq_vbn': ''},
 'inured': {'vbd_eq_vbn': ''},
 'invaded': {'vbd_eq_vbn': ''},
 'invaginated': {'vbd_eq_vbn': ''},
 'invalidated': {'vbd_eq_vbn': ''},
 'invalided': {'vbd_eq_vbn': ''},
 'inveighed': {'vbd_eq_vbn': ''},
 'inveigled': {'vbd_eq_vbn': ''},
 'inventoried': {'vbd_eq_vbn': ''},
 'inverted': {'vbd_eq_vbn': ''},
 'invigorated': {'vbd_eq_vbn': ''},
 'invoiced': {'vbd_eq_vbn': ''},
 'invoked': {'vbd_eq_vbn': ''},
 'inweaved': {'vbd_eq_vbn': ''},
 'iodinated': {'vbd_eq_vbn': ''},
 'iodised': {'vbd_eq_vbn': ''},
 'iodized': {'vbd_eq_vbn': ''},
 'ionised': {'vbd_eq_vbn': ''},
 'ionized': {'vbd_eq_vbn': ''},
 'iridesced': {'vbd_eq_vbn': ''},
 'irked': {'vbd_eq_vbn': ''},
 'irradiated': {'vbd_eq_vbn': ''},
 'irrigated': {'vbd_eq_vbn': ''},
 'irrupted': {'vbd_eq_vbn': ''},
 'Islamised': {'vbd_eq_vbn': ''},
 'Islamized': {'vbd_eq_vbn': ''},
 'islanded': {'vbd_eq_vbn': ''},
 'isomerised': {'vbd_eq_vbn': ''},
 'isomerized': {'vbd_eq_vbn': ''},
 'italicised': {'vbd_eq_vbn': ''},
 'itched': {'vbd_eq_vbn': ''},
 'itemised': {'vbd_eq_vbn': ''},
 'itemized': {'vbd_eq_vbn': ''},
 'iterated': {'vbd_eq_vbn': ''},
 'itinerated': {'vbd_eq_vbn': ''},
 'jabbed': {'vbd_eq_vbn': ''},
 'jabbered': {'vbd_eq_vbn': ''},
 'jacked': {'vbd_eq_vbn': ''},
 'jacketed': {'vbd_eq_vbn': ''},
 'jailed': {'vbd_eq_vbn': ''},
 'jampacked': {'vbd_eq_vbn': ''},
 'jangled': {'vbd_eq_vbn': ''},
 'japanned': {'vbd_eq_vbn': ''},
 'jargoned': {'vbd_eq_vbn': ''},
 'jarred': {'vbd_eq_vbn': ''},
 'jaunted': {'vbd_eq_vbn': ''},
 'jawboned': {'vbd_eq_vbn': ''},
 'jawed': {'vbd_eq_vbn': ''},
 'jaywalked': {'vbd_eq_vbn': ''},
 'jazzed': {'vbd_eq_vbn': ''},
 'jeered': {'vbd_eq_vbn': ''},
 'jelled': {'vbd_eq_vbn': ''},
 'jellified': {'vbd_eq_vbn': ''},
 'jemmied': {'vbd_eq_vbn': ''},
 'jeopardised': {'vbd_eq_vbn': ''},
 'jeopardized': {'vbd_eq_vbn': ''},
 'jerked': {'vbd_eq_vbn': ''},
 'jerry-built': {'vbd_eq_vbn': ''},
 'jessed': {'vbd_eq_vbn': ''},
 'jested': {'vbd_eq_vbn': ''},
 'jetted': {'vbd_eq_vbn': ''},
 'jettisoned': {'vbd_eq_vbn': ''},
 'jeweled': {'vbd_eq_vbn': ''},
 'jibbed': {'vbd_eq_vbn': ''},
 'jibed': {'vbd_eq_vbn': ''},
 'jigged': {'vbd_eq_vbn': ''},
 'jiggled': {'vbd_eq_vbn': ''},
 'jilted': {'vbd_eq_vbn': ''},
 'jimmied': {'vbd_eq_vbn': ''},
 'jingled': {'vbd_eq_vbn': ''},
 'jinked': {'vbd_eq_vbn': ''},
 'jitterbuged': {'vbd_eq_vbn': ''},
 'jittered': {'vbd_eq_vbn': ''},
 'jived': {'vbd_eq_vbn': ''},
 'jobbed': {'vbd_eq_vbn': ''},
 'jockeyed': {'vbd_eq_vbn': ''},
 'jogged': {'vbd_eq_vbn': ''},
 'joggled': {'vbd_eq_vbn': ''},
 'jollied': {'vbd_eq_vbn': ''},
 'jollified': {'vbd_eq_vbn': ''},
 'jolted': {'vbd_eq_vbn': ''},
 'joshed': {'vbd_eq_vbn': ''},
 'jostled': {'vbd_eq_vbn': ''},
 'jotted': {'vbd_eq_vbn': ''},
 'jounced': {'vbd_eq_vbn': ''},
 'journeyed': {'vbd_eq_vbn': ''},
 'jousted': {'vbd_eq_vbn': ''},
 'joyed': {'vbd_eq_vbn': ''},
 'joyrided': {'vbd_eq_vbn': ''},
 'jubilated': {'vbd_eq_vbn': ''},
 'juddered': {'vbd_eq_vbn': ''},
 'jugged': {'vbd_eq_vbn': ''},
 'juggled': {'vbd_eq_vbn': ''},
 'jumbled': {'vbd_eq_vbn': ''},
 'jump-started': {'vbd_eq_vbn': ''},
 'jumpstarted': {'vbd_eq_vbn': ''},
 'junked': {'vbd_eq_vbn': ''},
 'junketed': {'vbd_eq_vbn': ''},
 'jutted': {'vbd_eq_vbn': ''},
 'juxtaposed': {'vbd_eq_vbn': ''},
 'kayoed': {'vbd_eq_vbn': ''},
 'keeled': {'vbd_eq_vbn': ''},
 'keened': {'vbd_eq_vbn': ''},
 'kenned': {'vbd_eq_vbn': ''},
 'kenneled': {'vbd_eq_vbn': ''},
 'kennelled': {'vbd_eq_vbn': ''},
 'keratinised': {'vbd_eq_vbn': ''},
 'keratinized': {'vbd_eq_vbn': ''},
 'kerned': {'vbd_eq_vbn': ''},
 'keyboarded': {'vbd_eq_vbn': ''},
 'keyed': {'vbd_eq_vbn': ''},
 'keynoted': {'vbd_eq_vbn': ''},
 'kibitzed': {'vbd_eq_vbn': ''},
 'kick-started': {'vbd_eq_vbn': ''},
 'kidded': {'vbd_eq_vbn': ''},
 'kidnaped': {'vbd_eq_vbn': ''},
 'kidnapped': {'vbd_eq_vbn': ''},
 'kilned': {'vbd_eq_vbn': ''},
 'kindled': {'vbd_eq_vbn': ''},
 'kinged': {'vbd_eq_vbn': ''},
 'kinked': {'vbd_eq_vbn': ''},
 'kipped': {'vbd_eq_vbn': ''},
 'kited': {'vbd_eq_vbn': ''},
 'kittened': {'vbd_eq_vbn': ''},
 'kludged': {'vbd_eq_vbn': ''},
 'knapped': {'vbd_eq_vbn': ''},
 'kneaded': {'vbd_eq_vbn': ''},
 'kneecapped': {'vbd_eq_vbn': ''},
 'kneeled': {'vbd_eq_vbn': ''},
 'knelled': {'vbd_eq_vbn': ''},
 'knelt': {'vbd_eq_vbn': ''},
 'knifed': {'vbd_eq_vbn': ''},
 'knighted': {'vbd_eq_vbn': ''},
 'knitted': {'vbd_eq_vbn': ''},
 'knuckled': {'vbd_eq_vbn': ''},
 "KO'd": {'vbd_eq_vbn': ''},
 'kowtowed': {'vbd_eq_vbn': ''},
 'kvetched': {'vbd_eq_vbn': ''},
 'labelled': {'vbd_eq_vbn': ''},
 'labialised': {'vbd_eq_vbn': ''},
 'labialized': {'vbd_eq_vbn': ''},
 'laced': {'vbd_eq_vbn': ''},
 'lacerated': {'vbd_eq_vbn': ''},
 'lackeyed': {'vbd_eq_vbn': ''},
 'lacquered': {'vbd_eq_vbn': ''},
 'lactated': {'vbd_eq_vbn': ''},
 'laded': {'vbd_eq_vbn': ''},
 'ladled': {'vbd_eq_vbn': ''},
 'lagged': {'vbd_eq_vbn': ''},
 'laicised': {'vbd_eq_vbn': ''},
 'laicized': {'vbd_eq_vbn': ''},
 'lallygagged': {'vbd_eq_vbn': ''},
 'lambasted': {'vbd_eq_vbn': ''},
 'lamed': {'vbd_eq_vbn': ''},
 'lamented': {'vbd_eq_vbn': ''},
 'lammed': {'vbd_eq_vbn': ''},
 'lampooned': {'vbd_eq_vbn': ''},
 'lanced': {'vbd_eq_vbn': ''},
 'landmarked': {'vbd_eq_vbn': ''},
 'languished': {'vbd_eq_vbn': ''},
 'lapidated': {'vbd_eq_vbn': ''},
 'lapidified': {'vbd_eq_vbn': ''},
 'lapped': {'vbd_eq_vbn': ''},
 'larded': {'vbd_eq_vbn': ''},
 'larged': {'vbd_eq_vbn': ''},
 'largened': {'vbd_eq_vbn': ''},
 'larked': {'vbd_eq_vbn': ''},
 'larned': {'vbd_eq_vbn': ''},
 'larruped': {'vbd_eq_vbn': ''},
 'lashed': {'vbd_eq_vbn': ''},
 'lassoed': {'vbd_eq_vbn': ''},
 'latched': {'vbd_eq_vbn': ''},
 'lateralised': {'vbd_eq_vbn': ''},
 'lateralized': {'vbd_eq_vbn': ''},
 'lathed': {'vbd_eq_vbn': ''},
 'lathered': {'vbd_eq_vbn': ''},
 'Latinised': {'vbd_eq_vbn': ''},
 'Latinized': {'vbd_eq_vbn': ''},
 'latticed': {'vbd_eq_vbn': ''},
 'lauded': {'vbd_eq_vbn': ''},
 'laundered': {'vbd_eq_vbn': ''},
 'laved': {'vbd_eq_vbn': ''},
 'lavished': {'vbd_eq_vbn': ''},
 'lazed': {'vbd_eq_vbn': ''},
 'leached': {'vbd_eq_vbn': ''},
 'leafleted': {'vbd_eq_vbn': ''},
 'leagued': {'vbd_eq_vbn': ''},
 'leaguered': {'vbd_eq_vbn': ''},
 'leaked': {'vbd_eq_vbn': ''},
 'leant': {'vbd_eq_vbn': ''},
 'leaped': {'vbd_eq_vbn': ''},
 'leapfrogged': {'vbd_eq_vbn': ''},
 'leapt': {'vbd_eq_vbn': ''},
 'learnt': {'vbd_eq_vbn': ''},
 'leased': {'vbd_eq_vbn': ''},
 'leashed': {'vbd_eq_vbn': ''},
 'leathered': {'vbd_eq_vbn': ''},
 'leavened': {'vbd_eq_vbn': ''},
 'leched': {'vbd_eq_vbn': ''},
 'lectured': {'vbd_eq_vbn': ''},
 'leered': {'vbd_eq_vbn': ''},
 'legalised': {'vbd_eq_vbn': ''},
 'legalized': {'vbd_eq_vbn': ''},
 'legislated': {'vbd_eq_vbn': ''},
 'legitimated': {'vbd_eq_vbn': ''},
 'legitimatised': {'vbd_eq_vbn': ''},
 'legitimatized': {'vbd_eq_vbn': ''},
 'legitimised': {'vbd_eq_vbn': ''},
 'legitimized': {'vbd_eq_vbn': ''},
 'lend-leased': {'vbd_eq_vbn': ''},
 'lengthened': {'vbd_eq_vbn': ''},
 'lenified': {'vbd_eq_vbn': ''},
 'lessoned': {'vbd_eq_vbn': ''},
 'levanted': {'vbd_eq_vbn': ''},
 'leveled': {'vbd_eq_vbn': ''},
 'levelled': {'vbd_eq_vbn': ''},
 'leveraged': {'vbd_eq_vbn': ''},
 'levered': {'vbd_eq_vbn': ''},
 'levied': {'vbd_eq_vbn': ''},
 'levitated': {'vbd_eq_vbn': ''},
 'lexicalised': {'vbd_eq_vbn': ''},
 'lexicalized': {'vbd_eq_vbn': ''},
 'liaised': {'vbd_eq_vbn': ''},
 'libeled': {'vbd_eq_vbn': ''},
 'libelled': {'vbd_eq_vbn': ''},
 'liberalised': {'vbd_eq_vbn': ''},
 'liberalized': {'vbd_eq_vbn': ''},
 'liberated': {'vbd_eq_vbn': ''},
 'librated': {'vbd_eq_vbn': ''},
 'licenced': {'vbd_eq_vbn': ''},
 'lichened': {'vbd_eq_vbn': ''},
 'lifeguarded': {'vbd_eq_vbn': ''},
 'lifehacked': {'vbd_eq_vbn': ''},
 'ligated': {'vbd_eq_vbn': ''},
 'lightened': {'vbd_eq_vbn': ''},
 'lightered': {'vbd_eq_vbn': ''},
 'lignified': {'vbd_eq_vbn': ''},
 'likened': {'vbd_eq_vbn': ''},
 'lilted': {'vbd_eq_vbn': ''},
 'limbered': {'vbd_eq_vbn': ''},
 'limed': {'vbd_eq_vbn': ''},
 'limned': {'vbd_eq_vbn': ''},
 'limped': {'vbd_eq_vbn': ''},
 'linearised': {'vbd_eq_vbn': ''},
 'linearized': {'vbd_eq_vbn': ''},
 'lingered': {'vbd_eq_vbn': ''},
 'lionised': {'vbd_eq_vbn': ''},
 'lionized': {'vbd_eq_vbn': ''},
 'lip-read': {'vbd_eq_vbn': ''},
 'lip-synced': {'vbd_eq_vbn': ''},
 'lip-synched': {'vbd_eq_vbn': ''},
 'lipped': {'vbd_eq_vbn': ''},
 'liquefied': {'vbd_eq_vbn': ''},
 'liquidated': {'vbd_eq_vbn': ''},
 'liquidised': {'vbd_eq_vbn': ''},
 'liquidized': {'vbd_eq_vbn': ''},
 'liquified': {'vbd_eq_vbn': ''},
 'liquored': {'vbd_eq_vbn': ''},
 'lisped': {'vbd_eq_vbn': ''},
 'lit': {'vbd_eq_vbn': ''},
 'literalised': {'vbd_eq_vbn': ''},
 'literalized': {'vbd_eq_vbn': ''},
 'lithographed': {'vbd_eq_vbn': ''},
 'litigated': {'vbd_eq_vbn': ''},
 'littered': {'vbd_eq_vbn': ''},
 'Lived': {'vbd_eq_vbn': ''},
 'livened': {'vbd_eq_vbn': ''},
 'livestreamed': {'vbd_eq_vbn': ''},
 'loafed': {'vbd_eq_vbn': ''},
 'loaned': {'vbd_eq_vbn': ''},
 'loathed': {'vbd_eq_vbn': ''},
 'lobbed': {'vbd_eq_vbn': ''},
 'lobbied': {'vbd_eq_vbn': ''},
 'lobotomized': {'vbd_eq_vbn': ''},
 'localised': {'vbd_eq_vbn': ''},
 'lockpicked': {'vbd_eq_vbn': ''},
 'locoed': {'vbd_eq_vbn': ''},
 'locomoted': {'vbd_eq_vbn': ''},
 'lodged': {'vbd_eq_vbn': ''},
 'lofted': {'vbd_eq_vbn': ''},
 'logged': {'vbd_eq_vbn': ''},
 'logrolled': {'vbd_eq_vbn': ''},
 'loitered': {'vbd_eq_vbn': ''},
 'lolled': {'vbd_eq_vbn': ''},
 'lolloped': {'vbd_eq_vbn': ''},
 'lollygagged': {'vbd_eq_vbn': ''},
 'longed': {'vbd_eq_vbn': ''},
 'loomed': {'vbd_eq_vbn': ''},
 'looped': {'vbd_eq_vbn': ''},
 'loosed': {'vbd_eq_vbn': ''},
 'loosened': {'vbd_eq_vbn': ''},
 'looted': {'vbd_eq_vbn': ''},
 'loped': {'vbd_eq_vbn': ''},
 'lopped': {'vbd_eq_vbn': ''},
 'lorded': {'vbd_eq_vbn': ''},
 'lotted': {'vbd_eq_vbn': ''},
 'loudened': {'vbd_eq_vbn': ''},
 'lounged': {'vbd_eq_vbn': ''},
 'loured': {'vbd_eq_vbn': ''},
 'loused': {'vbd_eq_vbn': ''},
 'lowballed': {'vbd_eq_vbn': ''},
 'lowed': {'vbd_eq_vbn': ''},
 'lubricated': {'vbd_eq_vbn': ''},
 'lucked': {'vbd_eq_vbn': ''},
 'lucubrated': {'vbd_eq_vbn': ''},
 'luffed': {'vbd_eq_vbn': ''},
 'lugged': {'vbd_eq_vbn': ''},
 'lullabied': {'vbd_eq_vbn': ''},
 'lulled': {'vbd_eq_vbn': ''},
 'lumbered': {'vbd_eq_vbn': ''},
 'luminesced': {'vbd_eq_vbn': ''},
 'lumped': {'vbd_eq_vbn': ''},
 'lunched': {'vbd_eq_vbn': ''},
 'lunged': {'vbd_eq_vbn': ''},
 'lurched': {'vbd_eq_vbn': ''},
 'lurked': {'vbd_eq_vbn': ''},
 'lushed': {'vbd_eq_vbn': ''},
 'lusted': {'vbd_eq_vbn': ''},
 'lustered': {'vbd_eq_vbn': ''},
 'lustrated': {'vbd_eq_vbn': ''},
 'luted': {'vbd_eq_vbn': ''},
 'luxated': {'vbd_eq_vbn': ''},
 'luxuriated': {'vbd_eq_vbn': ''},
 'lynched': {'vbd_eq_vbn': ''},
 'lyophilised': {'vbd_eq_vbn': ''},
 'lyophilized': {'vbd_eq_vbn': ''},
 'lysogenised': {'vbd_eq_vbn': ''},
 'lysogenized': {'vbd_eq_vbn': ''},
 'macadamised': {'vbd_eq_vbn': ''},
 'macadamized': {'vbd_eq_vbn': ''},
 'macerated': {'vbd_eq_vbn': ''},
 'machicolated': {'vbd_eq_vbn': ''},
 'machinated': {'vbd_eq_vbn': ''},
 'machine-gunned': {'vbd_eq_vbn': ''},
 'machine-washed': {'vbd_eq_vbn': ''},
 'machined': {'vbd_eq_vbn': ''},
 'maculated': {'vbd_eq_vbn': ''},
 'maddened': {'vbd_eq_vbn': ''},
 'magicked': {'vbd_eq_vbn': ''},
 'magnetized': {'vbd_eq_vbn': ''},
 'magnified': {'vbd_eq_vbn': ''},
 'maimed': {'vbd_eq_vbn': ''},
 'mainlined': {'vbd_eq_vbn': ''},
 'mainstreamed': {'vbd_eq_vbn': ''},
 'majored': {'vbd_eq_vbn': ''},
 'maledicted': {'vbd_eq_vbn': ''},
 'malfunctioned': {'vbd_eq_vbn': ''},
 'maligned': {'vbd_eq_vbn': ''},
 'malingered': {'vbd_eq_vbn': ''},
 'maltreated': {'vbd_eq_vbn': ''},
 'mamboed': {'vbd_eq_vbn': ''},
 'mandated': {'vbd_eq_vbn': ''},
 'manducated': {'vbd_eq_vbn': ''},
 'maneuvered': {'vbd_eq_vbn': ''},
 'manhandled': {'vbd_eq_vbn': ''},
 'manifested': {'vbd_eq_vbn': ''},
 'manifolded': {'vbd_eq_vbn': ''},
 'manipulated': {'vbd_eq_vbn': ''},
 'manned': {'vbd_eq_vbn': ''},
 'manoeuvred': {'vbd_eq_vbn': ''},
 'mansplained': {'vbd_eq_vbn': ''},
 'mantled': {'vbd_eq_vbn': ''},
 'Manufactured': {'vbd_eq_vbn': ''},
 'manumitted': {'vbd_eq_vbn': ''},
 'manured': {'vbd_eq_vbn': ''},
 'mapped': {'vbd_eq_vbn': ''},
 'marauded': {'vbd_eq_vbn': ''},
 'marbleised': {'vbd_eq_vbn': ''},
 'marbleized': {'vbd_eq_vbn': ''},
 'marcelled': {'vbd_eq_vbn': ''},
 'marginalised': {'vbd_eq_vbn': ''},
 'margined': {'vbd_eq_vbn': ''},
 'marinaded': {'vbd_eq_vbn': ''},
 'marinated': {'vbd_eq_vbn': ''},
 'marketed': {'vbd_eq_vbn': ''},
 'marooned': {'vbd_eq_vbn': ''},
 'marred': {'vbd_eq_vbn': ''},
 'marshaled': {'vbd_eq_vbn': ''},
 'marshalled': {'vbd_eq_vbn': ''},
 'martyrised': {'vbd_eq_vbn': ''},
 'martyrized': {'vbd_eq_vbn': ''},
 'marveled': {'vbd_eq_vbn': ''},
 'marvelled': {'vbd_eq_vbn': ''},
 'masculinised': {'vbd_eq_vbn': ''},
 'masculinized': {'vbd_eq_vbn': ''},
 'masoned': {'vbd_eq_vbn': ''},
 'masqueraded': {'vbd_eq_vbn': ''},
 'massacred': {'vbd_eq_vbn': ''},
 'massaged': {'vbd_eq_vbn': ''},
 'mastered': {'vbd_eq_vbn': ''},
 'masterminded': {'vbd_eq_vbn': ''},
 'masticated': {'vbd_eq_vbn': ''},
 'masturbated': {'vbd_eq_vbn': ''},
 'mated': {'vbd_eq_vbn': ''},
 'materialised': {'vbd_eq_vbn': ''},
 'materialized': {'vbd_eq_vbn': ''},
 'matriculated': {'vbd_eq_vbn': ''},
 'maturated': {'vbd_eq_vbn': ''},
 'matured': {'vbd_eq_vbn': ''},
 'mauled': {'vbd_eq_vbn': ''},
 'maundered': {'vbd_eq_vbn': ''},
 'maxed': {'vbd_eq_vbn': ''},
 'maximised': {'vbd_eq_vbn': ''},
 'maximized': {'vbd_eq_vbn': ''},
 'mazed': {'vbd_eq_vbn': ''},
 'meandered': {'vbd_eq_vbn': ''},
 'meant': {'vbd_eq_vbn': ''},
 'mechanised': {'vbd_eq_vbn': ''},
 'medaled': {'vbd_eq_vbn': ''},
 'medalled': {'vbd_eq_vbn': ''},
 'meddled': {'vbd_eq_vbn': ''},
 'medevacked': {'vbd_eq_vbn': ''},
 'mediated': {'vbd_eq_vbn': ''},
 'medicalised': {'vbd_eq_vbn': ''},
 'medicalized': {'vbd_eq_vbn': ''},
 'meditated': {'vbd_eq_vbn': ''},
 'medivacked': {'vbd_eq_vbn': ''},
 'melanised': {'vbd_eq_vbn': ''},
 'melanized': {'vbd_eq_vbn': ''},
 'melded': {'vbd_eq_vbn': ''},
 'meliorated': {'vbd_eq_vbn': ''},
 'mellowed': {'vbd_eq_vbn': ''},
 'melodised': {'vbd_eq_vbn': ''},
 'melodized': {'vbd_eq_vbn': ''},
 'memorialised': {'vbd_eq_vbn': ''},
 'memorialized': {'vbd_eq_vbn': ''},
 'memorised': {'vbd_eq_vbn': ''},
 'memorized': {'vbd_eq_vbn': ''},
 'menaced': {'vbd_eq_vbn': ''},
 'mended': {'vbd_eq_vbn': ''},
 'menstruated': {'vbd_eq_vbn': ''},
 'mensurated': {'vbd_eq_vbn': ''},
 'mentored': {'vbd_eq_vbn': ''},
 'meowed': {'vbd_eq_vbn': ''},
 'mercerised': {'vbd_eq_vbn': ''},
 'mercerized': {'vbd_eq_vbn': ''},
 'merchandised': {'vbd_eq_vbn': ''},
 'mercurialised': {'vbd_eq_vbn': ''},
 'mercurialized': {'vbd_eq_vbn': ''},
 'merged': {'vbd_eq_vbn': ''},
 'merited': {'vbd_eq_vbn': ''},
 'meshed': {'vbd_eq_vbn': ''},
 'mesmerised': {'vbd_eq_vbn': ''},
 'messaged': {'vbd_eq_vbn': ''},
 'messengered': {'vbd_eq_vbn': ''},
 'metabolised': {'vbd_eq_vbn': ''},
 'metabolized': {'vbd_eq_vbn': ''},
 'metagrabolised': {'vbd_eq_vbn': ''},
 'metagrabolized': {'vbd_eq_vbn': ''},
 'metagrobolised': {'vbd_eq_vbn': ''},
 'metagrobolized': {'vbd_eq_vbn': ''},
 'metaled': {'vbd_eq_vbn': ''},
 'metalized': {'vbd_eq_vbn': ''},
 'metalled': {'vbd_eq_vbn': ''},
 'metallised': {'vbd_eq_vbn': ''},
 'metallized': {'vbd_eq_vbn': ''},
 'metamorphosed': {'vbd_eq_vbn': ''},
 'metaphorised': {'vbd_eq_vbn': ''},
 'metaphorized': {'vbd_eq_vbn': ''},
 'metastasised': {'vbd_eq_vbn': ''},
 'metastasized': {'vbd_eq_vbn': ''},
 'meted': {'vbd_eq_vbn': ''},
 'metered': {'vbd_eq_vbn': ''},
 'methylated': {'vbd_eq_vbn': ''},
 'metricated': {'vbd_eq_vbn': ''},
 'metrified': {'vbd_eq_vbn': ''},
 'mewed': {'vbd_eq_vbn': ''},
 'mewled': {'vbd_eq_vbn': ''},
 'miaowed': {'vbd_eq_vbn': ''},
 'microfilmed': {'vbd_eq_vbn': ''},
 'micromanaged': {'vbd_eq_vbn': ''},
 'microwaved': {'vbd_eq_vbn': ''},
 'micturated': {'vbd_eq_vbn': ''},
 'middled': {'vbd_eq_vbn': ''},
 'midwifed': {'vbd_eq_vbn': ''},
 'midwived': {'vbd_eq_vbn': ''},
 'migrated': {'vbd_eq_vbn': ''},
 'miked': {'vbd_eq_vbn': ''},
 'Mildred': {'vbd_eq_vbn': ''},
 'militarised': {'vbd_eq_vbn': ''},
 'militated': {'vbd_eq_vbn': ''},
 'milked': {'vbd_eq_vbn': ''},
 'milted': {'vbd_eq_vbn': ''},
 'mimed': {'vbd_eq_vbn': ''},
 'mimeoed': {'vbd_eq_vbn': ''},
 'mimeographed': {'vbd_eq_vbn': ''},
 'mimicked': {'vbd_eq_vbn': ''},
 'minced': {'vbd_eq_vbn': ''},
 'mined': {'vbd_eq_vbn': ''},
 'mineralised': {'vbd_eq_vbn': ''},
 'mineralized': {'vbd_eq_vbn': ''},
 'mingled': {'vbd_eq_vbn': ''},
 'miniaturised': {'vbd_eq_vbn': ''},
 'minified': {'vbd_eq_vbn': ''},
 'minimised': {'vbd_eq_vbn': ''},
 'minimized': {'vbd_eq_vbn': ''},
 'ministered': {'vbd_eq_vbn': ''},
 'minored': {'vbd_eq_vbn': ''},
 'minuted': {'vbd_eq_vbn': ''},
 'Mired': {'vbd_eq_vbn': ''},
 'mirrored': {'vbd_eq_vbn': ''},
 'misaddressed': {'vbd_eq_vbn': ''},
 'misadjusted': {'vbd_eq_vbn': ''},
 'misadvised': {'vbd_eq_vbn': ''},
 'misaimed': {'vbd_eq_vbn': ''},
 'misaligned': {'vbd_eq_vbn': ''},
 'misallied': {'vbd_eq_vbn': ''},
 'misallocated': {'vbd_eq_vbn': ''},
 'misapplied': {'vbd_eq_vbn': ''},
 'misapprehended': {'vbd_eq_vbn': ''},
 'misappropriated': {'vbd_eq_vbn': ''},
 'misattributed': {'vbd_eq_vbn': ''},
 'misbehaved': {'vbd_eq_vbn': ''},
 'misbelieved': {'vbd_eq_vbn': ''},
 'misbound': {'vbd_eq_vbn': ''},
 'misbranded': {'vbd_eq_vbn': ''},
 'misbuttoned': {'vbd_eq_vbn': ''},
 'miscalculated': {'vbd_eq_vbn': ''},
 'miscalled': {'vbd_eq_vbn': ''},
 'miscarried': {'vbd_eq_vbn': ''},
 'miscast': {'vbd_eq_vbn': ''},
 'miscegenated': {'vbd_eq_vbn': ''},
 'mischaracterized': {'vbd_eq_vbn': ''},
 'mischarged': {'vbd_eq_vbn': ''},
 'misclassified': {'vbd_eq_vbn': ''},
 'miscomputed': {'vbd_eq_vbn': ''},
 'misconducted': {'vbd_eq_vbn': ''},
 'misconnected': {'vbd_eq_vbn': ''},
 'misconstrued': {'vbd_eq_vbn': ''},
 'miscopied': {'vbd_eq_vbn': ''},
 'miscounted': {'vbd_eq_vbn': ''},
 'miscreated': {'vbd_eq_vbn': ''},
 'miscued': {'vbd_eq_vbn': ''},
 'miscut': {'vbd_eq_vbn': ''},
 'misdated': {'vbd_eq_vbn': ''},
 'misdealt': {'vbd_eq_vbn': ''},
 'misdeemed': {'vbd_eq_vbn': ''},
 'misdefined': {'vbd_eq_vbn': ''},
 'misdelivered': {'vbd_eq_vbn': ''},
 'misdemeaned': {'vbd_eq_vbn': ''},
 'misdescribed': {'vbd_eq_vbn': ''},
 'misdiagnosed': {'vbd_eq_vbn': ''},
 'misdialed': {'vbd_eq_vbn': ''},
 'misdialled': {'vbd_eq_vbn': ''},
 'misdirected': {'vbd_eq_vbn': ''},
 'miseducated': {'vbd_eq_vbn': ''},
 'misemployed': {'vbd_eq_vbn': ''},
 'misestimated': {'vbd_eq_vbn': ''},
 'misevaluated': {'vbd_eq_vbn': ''},
 'misfed': {'vbd_eq_vbn': ''},
 'misfielded': {'vbd_eq_vbn': ''},
 'misfired': {'vbd_eq_vbn': ''},
 'misfocused': {'vbd_eq_vbn': ''},
 'misfocussed': {'vbd_eq_vbn': ''},
 'misfunctioned': {'vbd_eq_vbn': ''},
 'misgauged': {'vbd_eq_vbn': ''},
 'misgoverned': {'vbd_eq_vbn': ''},
 'misgraded': {'vbd_eq_vbn': ''},
 'mish-mashed': {'vbd_eq_vbn': ''},
 'mishandled': {'vbd_eq_vbn': ''},
 'misheard': {'vbd_eq_vbn': ''},
 'mishmashed': {'vbd_eq_vbn': ''},
 'misidentified': {'vbd_eq_vbn': ''},
 'misinformed': {'vbd_eq_vbn': ''},
 'misinterpreted': {'vbd_eq_vbn': ''},
 'misjudged': {'vbd_eq_vbn': ''},
 'miskicked': {'vbd_eq_vbn': ''},
 'mislabeled': {'vbd_eq_vbn': ''},
 'mislabelled': {'vbd_eq_vbn': ''},
 'mislaid': {'vbd_eq_vbn': ''},
 'mislearned': {'vbd_eq_vbn': ''},
 'mislearnt': {'vbd_eq_vbn': ''},
 'misled': {'vbd_eq_vbn': ''},
 'mislocated': {'vbd_eq_vbn': ''},
 'mismanaged': {'vbd_eq_vbn': ''},
 'mismarked': {'vbd_eq_vbn': ''},
 'mismarried': {'vbd_eq_vbn': ''},
 'mismatched': {'vbd_eq_vbn': ''},
 'mismated': {'vbd_eq_vbn': ''},
 'mismeasured': {'vbd_eq_vbn': ''},
 'misnamed': {'vbd_eq_vbn': ''},
 'misordered': {'vbd_eq_vbn': ''},
 'misoriented': {'vbd_eq_vbn': ''},
 'misperceived': {'vbd_eq_vbn': ''},
 'misplanned': {'vbd_eq_vbn': ''},
 'misplayed': {'vbd_eq_vbn': ''},
 'mispriced': {'vbd_eq_vbn': ''},
 'misprinted': {'vbd_eq_vbn': ''},
 'misprogrammed': {'vbd_eq_vbn': ''},
 'mispronounced': {'vbd_eq_vbn': ''},
 'misquoted': {'vbd_eq_vbn': ''},
 'misreckoned': {'vbd_eq_vbn': ''},
 'misrecorded': {'vbd_eq_vbn': ''},
 'misrelated': {'vbd_eq_vbn': ''},
 'misremembered': {'vbd_eq_vbn': ''},
 'misrendered': {'vbd_eq_vbn': ''},
 'misreported': {'vbd_eq_vbn': ''},
 'misrepresented': {'vbd_eq_vbn': ''},
 'misrouted': {'vbd_eq_vbn': ''},
 'misruled': {'vbd_eq_vbn': ''},
 'misset': {'vbd_eq_vbn': ''},
 'misshaped': {'vbd_eq_vbn': ''},
 'missioned': {'vbd_eq_vbn': ''},
 'missorted': {'vbd_eq_vbn': ''},
 'misspelled': {'vbd_eq_vbn': ''},
 'misspelt': {'vbd_eq_vbn': ''},
 'misspent': {'vbd_eq_vbn': ''},
 'misstated': {'vbd_eq_vbn': ''},
 'misted': {'vbd_eq_vbn': ''},
 'mistimed': {'vbd_eq_vbn': ''},
 'mistitled': {'vbd_eq_vbn': ''},
 'mistrained': {'vbd_eq_vbn': ''},
 'mistranscribed': {'vbd_eq_vbn': ''},
 'mistranslated': {'vbd_eq_vbn': ''},
 'mistreated': {'vbd_eq_vbn': ''},
 'mistrusted': {'vbd_eq_vbn': ''},
 'mistuned': {'vbd_eq_vbn': ''},
 'mistyped': {'vbd_eq_vbn': ''},
 'misunderestimated': {'vbd_eq_vbn': ''},
 'misunderstood': {'vbd_eq_vbn': ''},
 'misused': {'vbd_eq_vbn': ''},
 'mitered': {'vbd_eq_vbn': ''},
 'mitigated': {'vbd_eq_vbn': ''},
 'mitred': {'vbd_eq_vbn': ''},
 'mizzled': {'vbd_eq_vbn': ''},
 'moaned': {'vbd_eq_vbn': ''},
 'mobbed': {'vbd_eq_vbn': ''},
 'mobilised': {'vbd_eq_vbn': ''},
 'mobilized': {'vbd_eq_vbn': ''},
 'mocked': {'vbd_eq_vbn': ''},
 'modeled': {'vbd_eq_vbn': ''},
 'modelled': {'vbd_eq_vbn': ''},
 'moderated': {'vbd_eq_vbn': ''},
 'modernised': {'vbd_eq_vbn': ''},
 'modernized': {'vbd_eq_vbn': ''},
 'modulated': {'vbd_eq_vbn': ''},
 'moiled': {'vbd_eq_vbn': ''},
 'moistened': {'vbd_eq_vbn': ''},
 'moisturised': {'vbd_eq_vbn': ''},
 'moisturized': {'vbd_eq_vbn': ''},
 'molded': {'vbd_eq_vbn': ''},
 'moldered': {'vbd_eq_vbn': ''},
 'molested': {'vbd_eq_vbn': ''},
 'mollified': {'vbd_eq_vbn': ''},
 'mollycoddled': {'vbd_eq_vbn': ''},
 'molted': {'vbd_eq_vbn': ''},
 'monetised': {'vbd_eq_vbn': ''},
 'monetized': {'vbd_eq_vbn': ''},
 'mongrelised': {'vbd_eq_vbn': ''},
 'mongrelized': {'vbd_eq_vbn': ''},
 'monished': {'vbd_eq_vbn': ''},
 'monkeyed': {'vbd_eq_vbn': ''},
 'monogramed': {'vbd_eq_vbn': ''},
 'monologged': {'vbd_eq_vbn': ''},
 'monologued': {'vbd_eq_vbn': ''},
 'monologuised': {'vbd_eq_vbn': ''},
 'monologuized': {'vbd_eq_vbn': ''},
 'monopolised': {'vbd_eq_vbn': ''},
 'monopolized': {'vbd_eq_vbn': ''},
 'monotoned': {'vbd_eq_vbn': ''},
 'monumentalised': {'vbd_eq_vbn': ''},
 'monumentalized': {'vbd_eq_vbn': ''},
 'mooched': {'vbd_eq_vbn': ''},
 'mooed': {'vbd_eq_vbn': ''},
 'mooned': {'vbd_eq_vbn': ''},
 'moonlighted': {'vbd_eq_vbn': ''},
 'moonshined': {'vbd_eq_vbn': ''},
 'moonwalked': {'vbd_eq_vbn': ''},
 'moored': {'vbd_eq_vbn': ''},
 'mooted': {'vbd_eq_vbn': ''},
 'mopped': {'vbd_eq_vbn': ''},
 'moralised': {'vbd_eq_vbn': ''},
 'moralized': {'vbd_eq_vbn': ''},
 'morphed': {'vbd_eq_vbn': ''},
 'mortared': {'vbd_eq_vbn': ''},
 'mortgaged': {'vbd_eq_vbn': ''},
 'morticed': {'vbd_eq_vbn': ''},
 'mortised': {'vbd_eq_vbn': ''},
 'mosaicked': {'vbd_eq_vbn': ''},
 'moseyed': {'vbd_eq_vbn': ''},
 'moshed': {'vbd_eq_vbn': ''},
 'mossed': {'vbd_eq_vbn': ''},
 'mothballed': {'vbd_eq_vbn': ''},
 'mothed': {'vbd_eq_vbn': ''},
 'mothered': {'vbd_eq_vbn': ''},
 'mothproofed': {'vbd_eq_vbn': ''},
 'motioned': {'vbd_eq_vbn': ''},
 'motorcycled': {'vbd_eq_vbn': ''},
 'motored': {'vbd_eq_vbn': ''},
 'motorised': {'vbd_eq_vbn': ''},
 'Motorized': {'vbd_eq_vbn': ''},
 'moulded': {'vbd_eq_vbn': ''},
 'mouldered': {'vbd_eq_vbn': ''},
 'moulted': {'vbd_eq_vbn': ''},
 'mounded': {'vbd_eq_vbn': ''},
 'mountaineered': {'vbd_eq_vbn': ''},
 'mourned': {'vbd_eq_vbn': ''},
 'moused': {'vbd_eq_vbn': ''},
 'mousetrapped': {'vbd_eq_vbn': ''},
 'mouthed': {'vbd_eq_vbn': ''},
 'mowed': {'vbd_eq_vbn': ''},
 'mucked': {'vbd_eq_vbn': ''},
 'muckraked': {'vbd_eq_vbn': ''},
 'mud-wrestled': {'vbd_eq_vbn': ''},
 'mudded': {'vbd_eq_vbn': ''},
 'muddied': {'vbd_eq_vbn': ''},
 'muffed': {'vbd_eq_vbn': ''},
 'mugged': {'vbd_eq_vbn': ''},
 'mulched': {'vbd_eq_vbn': ''},
 'mulcted': {'vbd_eq_vbn': ''},
 'mulled': {'vbd_eq_vbn': ''},
 'multiplexed': {'vbd_eq_vbn': ''},
 'multiplied': {'vbd_eq_vbn': ''},
 'mumbled': {'vbd_eq_vbn': ''},
 'mummed': {'vbd_eq_vbn': ''},
 'mummified': {'vbd_eq_vbn': ''},
 'munched': {'vbd_eq_vbn': ''},
 'munitioned': {'vbd_eq_vbn': ''},
 'murdered': {'vbd_eq_vbn': ''},
 'murmured': {'vbd_eq_vbn': ''},
 'mused': {'vbd_eq_vbn': ''},
 'mushed': {'vbd_eq_vbn': ''},
 'mushroomed': {'vbd_eq_vbn': ''},
 'mussed': {'vbd_eq_vbn': ''},
 'mussitated': {'vbd_eq_vbn': ''},
 'mustered': {'vbd_eq_vbn': ''},
 'mutated': {'vbd_eq_vbn': ''},
 'mutilated': {'vbd_eq_vbn': ''},
 'mutinied': {'vbd_eq_vbn': ''},
 'muttered': {'vbd_eq_vbn': ''},
 'muzzled': {'vbd_eq_vbn': ''},
 'mystified': {'vbd_eq_vbn': ''},
 'mythicised': {'vbd_eq_vbn': ''},
 'mythicized': {'vbd_eq_vbn': ''},
 'mythologised': {'vbd_eq_vbn': ''},
 'mythologized': {'vbd_eq_vbn': ''},
 'nabbed': {'vbd_eq_vbn': ''},
 'nagged': {'vbd_eq_vbn': ''},
 'nailed': {'vbd_eq_vbn': ''},
 'name-dropped': {'vbd_eq_vbn': ''},
 'napalmed': {'vbd_eq_vbn': ''},
 'napped': {'vbd_eq_vbn': ''},
 'narced': {'vbd_eq_vbn': ''},
 'narcotised': {'vbd_eq_vbn': ''},
 'narcotized': {'vbd_eq_vbn': ''},
 'narrated': {'vbd_eq_vbn': ''},
 'narrowed': {'vbd_eq_vbn': ''},
 'nasalised': {'vbd_eq_vbn': ''},
 'nasalized': {'vbd_eq_vbn': ''},
 'nationalised': {'vbd_eq_vbn': ''},
 'nationalized': {'vbd_eq_vbn': ''},
 'nattered': {'vbd_eq_vbn': ''},
 'naturalised': {'vbd_eq_vbn': ''},
 'naturalized': {'vbd_eq_vbn': ''},
 'nauseated': {'vbd_eq_vbn': ''},
 'navigated': {'vbd_eq_vbn': ''},
 'naysaid': {'vbd_eq_vbn': ''},
 'Nazified': {'vbd_eq_vbn': ''},
 'neared': {'vbd_eq_vbn': ''},
 'neatened': {'vbd_eq_vbn': ''},
 'nebulised': {'vbd_eq_vbn': ''},
 'nebulized': {'vbd_eq_vbn': ''},
 'necessitated': {'vbd_eq_vbn': ''},
 'necked': {'vbd_eq_vbn': ''},
 'necrosed': {'vbd_eq_vbn': ''},
 'Ned': {'vbd_eq_vbn': ''},
 'negated': {'vbd_eq_vbn': ''},
 'negatived': {'vbd_eq_vbn': ''},
 'neighbored': {'vbd_eq_vbn': ''},
 'neighboured': {'vbd_eq_vbn': ''},
 'neighed': {'vbd_eq_vbn': ''},
 'nerved': {'vbd_eq_vbn': ''},
 'nestled': {'vbd_eq_vbn': ''},
 'netted': {'vbd_eq_vbn': ''},
 'nettled': {'vbd_eq_vbn': ''},
 'networked': {'vbd_eq_vbn': ''},
 'neutered': {'vbd_eq_vbn': ''},
 'neutralised': {'vbd_eq_vbn': ''},
 'neutralized': {'vbd_eq_vbn': ''},
 'nibbed': {'vbd_eq_vbn': ''},
 'nibbled': {'vbd_eq_vbn': ''},
 'niched': {'vbd_eq_vbn': ''},
 'nicked': {'vbd_eq_vbn': ''},
 'nickel-and-dimed': {'vbd_eq_vbn': ''},
 'nickeled': {'vbd_eq_vbn': ''},
 'nickeled-and-dimed': {'vbd_eq_vbn': ''},
 'nickelled': {'vbd_eq_vbn': ''},
 'nickered': {'vbd_eq_vbn': ''},
 'nicknamed': {'vbd_eq_vbn': ''},
 'nictated': {'vbd_eq_vbn': ''},
 'nictitated': {'vbd_eq_vbn': ''},
 'niggled': {'vbd_eq_vbn': ''},
 'nigrified': {'vbd_eq_vbn': ''},
 'nipped': {'vbd_eq_vbn': ''},
 'nitpicked': {'vbd_eq_vbn': ''},
 'nitrated': {'vbd_eq_vbn': ''},
 'nitrified': {'vbd_eq_vbn': ''},
 'nitrogenised': {'vbd_eq_vbn': ''},
 'nitrogenized': {'vbd_eq_vbn': ''},
 'nixed': {'vbd_eq_vbn': ''},
 'no-balled': {'vbd_eq_vbn': ''},
 'nobbled': {'vbd_eq_vbn': ''},
 'nocked': {'vbd_eq_vbn': ''},
 'nogged': {'vbd_eq_vbn': ''},
 'noised': {'vbd_eq_vbn': ''},
 'nol-prossed': {'vbd_eq_vbn': ''},
 'nominated': {'vbd_eq_vbn': ''},
 'nonplused': {'vbd_eq_vbn': ''},
 'noodled': {'vbd_eq_vbn': ''},
 'noosed': {'vbd_eq_vbn': ''},
 'normalised': {'vbd_eq_vbn': ''},
 'normalized': {'vbd_eq_vbn': ''},
 'nose-dived': {'vbd_eq_vbn': ''},
 'nosed': {'vbd_eq_vbn': ''},
 'nosedived': {'vbd_eq_vbn': ''},
 'noshed': {'vbd_eq_vbn': ''},
 'notarised': {'vbd_eq_vbn': ''},
 'notated': {'vbd_eq_vbn': ''},
 'notched': {'vbd_eq_vbn': ''},
 'notified': {'vbd_eq_vbn': ''},
 'nourished': {'vbd_eq_vbn': ''},
 'novelised': {'vbd_eq_vbn': ''},
 'novelized': {'vbd_eq_vbn': ''},
 'nucleated': {'vbd_eq_vbn': ''},
 'nudged': {'vbd_eq_vbn': ''},
 'nuked': {'vbd_eq_vbn': ''},
 'nullified': {'vbd_eq_vbn': ''},
 'numbed': {'vbd_eq_vbn': ''},
 'numerated': {'vbd_eq_vbn': ''},
 'nursed': {'vbd_eq_vbn': ''},
 'nurtured': {'vbd_eq_vbn': ''},
 'nutated': {'vbd_eq_vbn': ''},
 'nutmegged': {'vbd_eq_vbn': ''},
 'nutrified': {'vbd_eq_vbn': ''},
 'nutted': {'vbd_eq_vbn': ''},
 'nuzzled': {'vbd_eq_vbn': ''},
 'oared': {'vbd_eq_vbn': ''},
 'obeyed': {'vbd_eq_vbn': ''},
 'obfuscated': {'vbd_eq_vbn': ''},
 'objectified': {'vbd_eq_vbn': ''},
 'objurgated': {'vbd_eq_vbn': ''},
 'obligated': {'vbd_eq_vbn': ''},
 'obliged': {'vbd_eq_vbn': ''},
 'obliterated': {'vbd_eq_vbn': ''},
 'obnubilated': {'vbd_eq_vbn': ''},
 'obscured': {'vbd_eq_vbn': ''},
 'obsessed': {'vbd_eq_vbn': ''},
 'obsolesced': {'vbd_eq_vbn': ''},
 'obsoleted': {'vbd_eq_vbn': ''},
 'obstipated': {'vbd_eq_vbn': ''},
 'obstructed': {'vbd_eq_vbn': ''},
 'obtruded': {'vbd_eq_vbn': ''},
 'obtunded': {'vbd_eq_vbn': ''},
 'obturated': {'vbd_eq_vbn': ''},
 'obviated': {'vbd_eq_vbn': ''},
 'occasioned': {'vbd_eq_vbn': ''},
 'Occidentalised': {'vbd_eq_vbn': ''},
 'Occidentalized': {'vbd_eq_vbn': ''},
 'occluded': {'vbd_eq_vbn': ''},
 'occulted': {'vbd_eq_vbn': ''},
 'occurred': {'vbd_eq_vbn': ''},
 "OD'd": {'vbd_eq_vbn': ''},
 'odorised': {'vbd_eq_vbn': ''},
 'odorized': {'vbd_eq_vbn': ''},
 'odourised': {'vbd_eq_vbn': ''},
 'offed': {'vbd_eq_vbn': ''},
 'officered': {'vbd_eq_vbn': ''},
 'officialised': {'vbd_eq_vbn': ''},
 'officialized': {'vbd_eq_vbn': ''},
 'officiated': {'vbd_eq_vbn': ''},
 'offloaded': {'vbd_eq_vbn': ''},
 'offsaddled': {'vbd_eq_vbn': ''},
 'offshored': {'vbd_eq_vbn': ''},
 'ogled': {'vbd_eq_vbn': ''},
 'oinked': {'vbd_eq_vbn': ''},
 'okayed': {'vbd_eq_vbn': ''},
 'omened': {'vbd_eq_vbn': ''},
 'omitted': {'vbd_eq_vbn': ''},
 'one-stepped': {'vbd_eq_vbn': ''},
 'one-upped': {'vbd_eq_vbn': ''},
 'oohed': {'vbd_eq_vbn': ''},
 'oozed': {'vbd_eq_vbn': ''},
 'opacified': {'vbd_eq_vbn': ''},
 'opalesced': {'vbd_eq_vbn': ''},
 'opalised': {'vbd_eq_vbn': ''},
 'opalized': {'vbd_eq_vbn': ''},
 'operationalized': {'vbd_eq_vbn': ''},
 'opined': {'vbd_eq_vbn': ''},
 'opinionised': {'vbd_eq_vbn': ''},
 'opinionized': {'vbd_eq_vbn': ''},
 'oppugned': {'vbd_eq_vbn': ''},
 'opsonised': {'vbd_eq_vbn': ''},
 'opsonized': {'vbd_eq_vbn': ''},
 'opted': {'vbd_eq_vbn': ''},
 'optimised': {'vbd_eq_vbn': ''},
 'optimized': {'vbd_eq_vbn': ''},
 'optioned': {'vbd_eq_vbn': ''},
 'orated': {'vbd_eq_vbn': ''},
 'orbed': {'vbd_eq_vbn': ''},
 'orbited': {'vbd_eq_vbn': ''},
 'orchestrated': {'vbd_eq_vbn': ''},
 'ordained': {'vbd_eq_vbn': ''},
 'ordinated': {'vbd_eq_vbn': ''},
 'organised': {'vbd_eq_vbn': ''},
 'orientalised': {'vbd_eq_vbn': ''},
 'orientalized': {'vbd_eq_vbn': ''},
 'originated': {'vbd_eq_vbn': ''},
 'ornamented': {'vbd_eq_vbn': ''},
 'orphaned': {'vbd_eq_vbn': ''},
 'oscillated': {'vbd_eq_vbn': ''},
 'osculated': {'vbd_eq_vbn': ''},
 'ossified': {'vbd_eq_vbn': ''},
 'ostentated': {'vbd_eq_vbn': ''},
 'ostracised': {'vbd_eq_vbn': ''},
 'ostracized': {'vbd_eq_vbn': ''},
 'ousted': {'vbd_eq_vbn': ''},
 'out-Herodded': {'vbd_eq_vbn': ''},
 'outbalanced': {'vbd_eq_vbn': ''},
 'outbraved': {'vbd_eq_vbn': ''},
 'outbred': {'vbd_eq_vbn': ''},
 'outcasted': {'vbd_eq_vbn': ''},
 'outclassed': {'vbd_eq_vbn': ''},
 'outcompeted': {'vbd_eq_vbn': ''},
 'outcropped': {'vbd_eq_vbn': ''},
 'outdistanced': {'vbd_eq_vbn': ''},
 'outed': {'vbd_eq_vbn': ''},
 'outfaced': {'vbd_eq_vbn': ''},
 'outfitted': {'vbd_eq_vbn': ''},
 'outflanked': {'vbd_eq_vbn': ''},
 'outfought': {'vbd_eq_vbn': ''},
 'outfoxed': {'vbd_eq_vbn': ''},
 'outgained': {'vbd_eq_vbn': ''},
 'outgeneraled': {'vbd_eq_vbn': ''},
 'outgeneralled': {'vbd_eq_vbn': ''},
 'outguessed': {'vbd_eq_vbn': ''},
 'outgunned': {'vbd_eq_vbn': ''},
 'outlaid': {'vbd_eq_vbn': ''},
 'outlasted': {'vbd_eq_vbn': ''},
 'outlawed': {'vbd_eq_vbn': ''},
 'outleaped': {'vbd_eq_vbn': ''},
 'outlined': {'vbd_eq_vbn': ''},
 'outlived': {'vbd_eq_vbn': ''},
 'outmaneuvered': {'vbd_eq_vbn': ''},
 'outmanoeuvred': {'vbd_eq_vbn': ''},
 'outmarched': {'vbd_eq_vbn': ''},
 'outmatched': {'vbd_eq_vbn': ''},
 'outnumbered': {'vbd_eq_vbn': ''},
 'outpaced': {'vbd_eq_vbn': ''},
 'outperformed': {'vbd_eq_vbn': ''},
 'outplayed': {'vbd_eq_vbn': ''},
 'outpointed': {'vbd_eq_vbn': ''},
 'outpoured': {'vbd_eq_vbn': ''},
 'outputted': {'vbd_eq_vbn': ''},
 'outraged': {'vbd_eq_vbn': ''},
 'outranged': {'vbd_eq_vbn': ''},
 'outranked': {'vbd_eq_vbn': ''},
 'outreached': {'vbd_eq_vbn': ''},
 'outrivaled': {'vbd_eq_vbn': ''},
 'outrivalled': {'vbd_eq_vbn': ''},
 'outroared': {'vbd_eq_vbn': ''},
 'outsailed': {'vbd_eq_vbn': ''},
 'outscored': {'vbd_eq_vbn': ''},
 'outshone': {'vbd_eq_vbn': ''},
 'outshot': {'vbd_eq_vbn': ''},
 'outshouted': {'vbd_eq_vbn': ''},
 'outslugged': {'vbd_eq_vbn': ''},
 'outsmarted': {'vbd_eq_vbn': ''},
 'outsold': {'vbd_eq_vbn': ''},
 'outsourced': {'vbd_eq_vbn': ''},
 'outspanned': {'vbd_eq_vbn': ''},
 'outspent': {'vbd_eq_vbn': ''},
 'outspread': {'vbd_eq_vbn': ''},
 'outstared': {'vbd_eq_vbn': ''},
 'outstayed': {'vbd_eq_vbn': ''},
 'outstood': {'vbd_eq_vbn': ''},
 'outstripped': {'vbd_eq_vbn': ''},
 'outthought': {'vbd_eq_vbn': ''},
 'outvied': {'vbd_eq_vbn': ''},
 'outvoted': {'vbd_eq_vbn': ''},
 'outweighed': {'vbd_eq_vbn': ''},
 'outwitted': {'vbd_eq_vbn': ''},
 'outworked': {'vbd_eq_vbn': ''},
 'ovenbaked': {'vbd_eq_vbn': ''},
 'over-advertised': {'vbd_eq_vbn': ''},
 'over-articulated': {'vbd_eq_vbn': ''},
 'over-busied': {'vbd_eq_vbn': ''},
 'over-egged': {'vbd_eq_vbn': ''},
 'over-ruled': {'vbd_eq_vbn': ''},
 'over-used': {'vbd_eq_vbn': ''},
 'overabounded': {'vbd_eq_vbn': ''},
 'overabstracted': {'vbd_eq_vbn': ''},
 'overaccentuated': {'vbd_eq_vbn': ''},
 'overachieved': {'vbd_eq_vbn': ''},
 'overacted': {'vbd_eq_vbn': ''},
 'overadvertised': {'vbd_eq_vbn': ''},
 'overanalysed': {'vbd_eq_vbn': ''},
 'overanalyzed': {'vbd_eq_vbn': ''},
 'overarched': {'vbd_eq_vbn': ''},
 'overarmed': {'vbd_eq_vbn': ''},
 'overarranged': {'vbd_eq_vbn': ''},
 'overarticulated': {'vbd_eq_vbn': ''},
 'overasserted': {'vbd_eq_vbn': ''},
 'overattributed': {'vbd_eq_vbn': ''},
 'overbaked': {'vbd_eq_vbn': ''},
 'overbalanced': {'vbd_eq_vbn': ''},
 'overbeat': {'vbd_eq_vbn': ''},
 'overbent': {'vbd_eq_vbn': ''},
 'overbet': {'vbd_eq_vbn': ''},
 'overbid': {'vbd_eq_vbn': ''},
 'overbided': {'vbd_eq_vbn': ''},
 'overbilled': {'vbd_eq_vbn': ''},
 'overbinded': {'vbd_eq_vbn': ''},
 'overbleached': {'vbd_eq_vbn': ''},
 'overboiled': {'vbd_eq_vbn': ''},
 'overbooked': {'vbd_eq_vbn': ''},
 'overborrowed': {'vbd_eq_vbn': ''},
 'overbought': {'vbd_eq_vbn': ''},
 'overbounded': {'vbd_eq_vbn': ''},
 'overbowed': {'vbd_eq_vbn': ''},
 'overbraked': {'vbd_eq_vbn': ''},
 'overbranded': {'vbd_eq_vbn': ''},
 'overbred': {'vbd_eq_vbn': ''},
 'overbrimmed': {'vbd_eq_vbn': ''},
 'overbrowed': {'vbd_eq_vbn': ''},
 'overbrowsed': {'vbd_eq_vbn': ''},
 'overbubbled': {'vbd_eq_vbn': ''},
 'overbudgetd': {'vbd_eq_vbn': ''},
 'overbuilt': {'vbd_eq_vbn': ''},
 'overbulked': {'vbd_eq_vbn': ''},
 'overburdened': {'vbd_eq_vbn': ''},
 'overburned': {'vbd_eq_vbn': ''},
 'overburnt': {'vbd_eq_vbn': ''},
 'overbusied': {'vbd_eq_vbn': ''},
 'overcalculated': {'vbd_eq_vbn': ''},
 'overcalled': {'vbd_eq_vbn': ''},
 'overcanopied': {'vbd_eq_vbn': ''},
 'overcapitalised': {'vbd_eq_vbn': ''},
 'overcapitalized': {'vbd_eq_vbn': ''},
 'overcared': {'vbd_eq_vbn': ''},
 'overcarked': {'vbd_eq_vbn': ''},
 'overcarried': {'vbd_eq_vbn': ''},
 'overcarved': {'vbd_eq_vbn': ''},
 'overcategorized': {'vbd_eq_vbn': ''},
 'overcaught': {'vbd_eq_vbn': ''},
 'overcentralised': {'vbd_eq_vbn': ''},
 'overcentralized': {'vbd_eq_vbn': ''},
 'overchilled': {'vbd_eq_vbn': ''},
 'overchoreographed': {'vbd_eq_vbn': ''},
 'overcited': {'vbd_eq_vbn': ''},
 'overclaimed': {'vbd_eq_vbn': ''},
 'overclassified': {'vbd_eq_vbn': ''},
 'overcleaned': {'vbd_eq_vbn': ''},
 'overclimbed': {'vbd_eq_vbn': ''},
 'overclocked': {'vbd_eq_vbn': ''},
 'overclouded': {'vbd_eq_vbn': ''},
 'overcloyed': {'vbd_eq_vbn': ''},
 'overclubbed': {'vbd_eq_vbn': ''},
 'overcoached': {'vbd_eq_vbn': ''},
 'overcoddled': {'vbd_eq_vbn': ''},
 'overcollateralized': {'vbd_eq_vbn': ''},
 'overcolored': {'vbd_eq_vbn': ''},
 'overcoloured': {'vbd_eq_vbn': ''},
 'overcommercialized': {'vbd_eq_vbn': ''},
 'overcommitted': {'vbd_eq_vbn': ''},
 'overcommunicated': {'vbd_eq_vbn': ''},
 'overcompensated': {'vbd_eq_vbn': ''},
 'overcomplicated': {'vbd_eq_vbn': ''},
 'overcomplimented': {'vbd_eq_vbn': ''},
 'overcompressed': {'vbd_eq_vbn': ''},
 'overconcerned': {'vbd_eq_vbn': ''},
 'overconstructed': {'vbd_eq_vbn': ''},
 'overconsumed': {'vbd_eq_vbn': ''},
 'overcontrolled': {'vbd_eq_vbn': ''},
 'overcooked': {'vbd_eq_vbn': ''},
 'overcooled': {'vbd_eq_vbn': ''},
 'overcorrected': {'vbd_eq_vbn': ''},
 'overcounted': {'vbd_eq_vbn': ''},
 'overcovered': {'vbd_eq_vbn': ''},
 'overcrammed': {'vbd_eq_vbn': ''},
 'overcropped': {'vbd_eq_vbn': ''},
 'overcultivated': {'vbd_eq_vbn': ''},
 'overcured': {'vbd_eq_vbn': ''},
 'overcut': {'vbd_eq_vbn': ''},
 'overdared': {'vbd_eq_vbn': ''},
 'overdated': {'vbd_eq_vbn': ''},
 'overdecked': {'vbd_eq_vbn': ''},
 'overdecorated': {'vbd_eq_vbn': ''},
 'overdemanded': {'vbd_eq_vbn': ''},
 'overdesigned': {'vbd_eq_vbn': ''},
 'overdetermined': {'vbd_eq_vbn': ''},
 'overdeviated': {'vbd_eq_vbn': ''},
 'overdiagnosed': {'vbd_eq_vbn': ''},
 'overdiscounted': {'vbd_eq_vbn': ''},
 'overdocumented': {'vbd_eq_vbn': ''},
 'overdosed': {'vbd_eq_vbn': ''},
 'overdramatised': {'vbd_eq_vbn': ''},
 'overdramatized': {'vbd_eq_vbn': ''},
 'overdried': {'vbd_eq_vbn': ''},
 'overdubbed': {'vbd_eq_vbn': ''},
 'overdusted': {'vbd_eq_vbn': ''},
 'overdyed': {'vbd_eq_vbn': ''},
 'overed': {'vbd_eq_vbn': ''},
 'overedited': {'vbd_eq_vbn': ''},
 'overeducated': {'vbd_eq_vbn': ''},
 'overegged': {'vbd_eq_vbn': ''},
 'overelaborated': {'vbd_eq_vbn': ''},
 'overembellished': {'vbd_eq_vbn': ''},
 'overemoted': {'vbd_eq_vbn': ''},
 'overemphasised': {'vbd_eq_vbn': ''},
 'overemphasized': {'vbd_eq_vbn': ''},
 'overencouraged': {'vbd_eq_vbn': ''},
 'overengineered': {'vbd_eq_vbn': ''},
 'overequipped': {'vbd_eq_vbn': ''},
 'overestimated': {'vbd_eq_vbn': ''},
 'overevaluated': {'vbd_eq_vbn': ''},
 'overexaggerated': {'vbd_eq_vbn': ''},
 'overexercised': {'vbd_eq_vbn': ''},
 'overexerted': {'vbd_eq_vbn': ''},
 'overexpanded': {'vbd_eq_vbn': ''},
 'overexplained': {'vbd_eq_vbn': ''},
 'overexploited': {'vbd_eq_vbn': ''},
 'overexposed': {'vbd_eq_vbn': ''},
 'overfatigued': {'vbd_eq_vbn': ''},
 'overfavored': {'vbd_eq_vbn': ''},
 'overfavoured': {'vbd_eq_vbn': ''},
 'overfeared': {'vbd_eq_vbn': ''},
 'overfed': {'vbd_eq_vbn': ''},
 'overfertilised': {'vbd_eq_vbn': ''},
 'overfertilized': {'vbd_eq_vbn': ''},
 'overfilled': {'vbd_eq_vbn': ''},
 'overfished': {'vbd_eq_vbn': ''},
 'overflooded': {'vbd_eq_vbn': ''},
 'overflourished': {'vbd_eq_vbn': ''},
 'overflowed': {'vbd_eq_vbn': ''},
 'overfunded': {'vbd_eq_vbn': ''},
 'overgeneralised': {'vbd_eq_vbn': ''},
 'overgeneralized': {'vbd_eq_vbn': ''},
 'overgorged': {'vbd_eq_vbn': ''},
 'overgrazed': {'vbd_eq_vbn': ''},
 'overhanded': {'vbd_eq_vbn': ''},
 'overhauled': {'vbd_eq_vbn': ''},
 'overheard': {'vbd_eq_vbn': ''},
 'overhung': {'vbd_eq_vbn': ''},
 'overhyped': {'vbd_eq_vbn': ''},
 'overindulged': {'vbd_eq_vbn': ''},
 'overinvested': {'vbd_eq_vbn': ''},
 'overkilled': {'vbd_eq_vbn': ''},
 'overlaid': {'vbd_eq_vbn': ''},
 'overlapped': {'vbd_eq_vbn': ''},
 'overleaped': {'vbd_eq_vbn': ''},
 'overleapt': {'vbd_eq_vbn': ''},
 'overleveraged': {'vbd_eq_vbn': ''},
 'overloaded': {'vbd_eq_vbn': ''},
 'overlooked': {'vbd_eq_vbn': ''},
 'overmastered': {'vbd_eq_vbn': ''},
 'overmatched': {'vbd_eq_vbn': ''},
 'overmedicated': {'vbd_eq_vbn': ''},
 'overnighted': {'vbd_eq_vbn': ''},
 'overpaid': {'vbd_eq_vbn': ''},
 'overpassed': {'vbd_eq_vbn': ''},
 'overplanted': {'vbd_eq_vbn': ''},
 'overplayed': {'vbd_eq_vbn': ''},
 'overpowered': {'vbd_eq_vbn': ''},
 'overpraised': {'vbd_eq_vbn': ''},
 'Overpriced': {'vbd_eq_vbn': ''},
 'overprinted': {'vbd_eq_vbn': ''},
 'overproduced': {'vbd_eq_vbn': ''},
 'overprotected': {'vbd_eq_vbn': ''},
 'overpurchased': {'vbd_eq_vbn': ''},
 'overreached': {'vbd_eq_vbn': ''},
 'overreacted': {'vbd_eq_vbn': ''},
 'overrefined': {'vbd_eq_vbn': ''},
 'overregulated': {'vbd_eq_vbn': ''},
 'overruled': {'vbd_eq_vbn': ''},
 'oversaturated': {'vbd_eq_vbn': ''},
 'oversewed': {'vbd_eq_vbn': ''},
 'overshadowed': {'vbd_eq_vbn': ''},
 'overshared': {'vbd_eq_vbn': ''},
 'overshone': {'vbd_eq_vbn': ''},
 'overshot': {'vbd_eq_vbn': ''},
 'overshowered': {'vbd_eq_vbn': ''},
 'oversimplified': {'vbd_eq_vbn': ''},
 'overskipped': {'vbd_eq_vbn': ''},
 'overslaughed': {'vbd_eq_vbn': ''},
 'overslept': {'vbd_eq_vbn': ''},
 'overslipped': {'vbd_eq_vbn': ''},
 'oversmoked': {'vbd_eq_vbn': ''},
 'oversoaked': {'vbd_eq_vbn': ''},
 'oversold': {'vbd_eq_vbn': ''},
 'overspecialised': {'vbd_eq_vbn': ''},
 'overspecialized': {'vbd_eq_vbn': ''},
 'overspeculated': {'vbd_eq_vbn': ''},
 'overspent': {'vbd_eq_vbn': ''},
 'overspiced': {'vbd_eq_vbn': ''},
 'overspilled': {'vbd_eq_vbn': ''},
 'overspilt': {'vbd_eq_vbn': ''},
 'overspread': {'vbd_eq_vbn': ''},
 'overstained': {'vbd_eq_vbn': ''},
 'overstared': {'vbd_eq_vbn': ''},
 'overstated': {'vbd_eq_vbn': ''},
 'overstayed': {'vbd_eq_vbn': ''},
 'oversteered': {'vbd_eq_vbn': ''},
 'overstepped': {'vbd_eq_vbn': ''},
 'overstimulated': {'vbd_eq_vbn': ''},
 'overstirred': {'vbd_eq_vbn': ''},
 'overstitched': {'vbd_eq_vbn': ''},
 'overstocked': {'vbd_eq_vbn': ''},
 'overstood': {'vbd_eq_vbn': ''},
 'overstored': {'vbd_eq_vbn': ''},
 'overstressed': {'vbd_eq_vbn': ''},
 'overstretched': {'vbd_eq_vbn': ''},
 'overstrewed': {'vbd_eq_vbn': ''},
 'overstruck': {'vbd_eq_vbn': ''},
 'overstudied': {'vbd_eq_vbn': ''},
 'oversupped': {'vbd_eq_vbn': ''},
 'oversupplied': {'vbd_eq_vbn': ''},
 'overswayed': {'vbd_eq_vbn': ''},
 'oversweetened': {'vbd_eq_vbn': ''},
 'overswelled': {'vbd_eq_vbn': ''},
 'overswung': {'vbd_eq_vbn': ''},
 'overtalked': {'vbd_eq_vbn': ''},
 'overtasked': {'vbd_eq_vbn': ''},
 'overtaught': {'vbd_eq_vbn': ''},
 'overtaxed': {'vbd_eq_vbn': ''},
 'overteemed': {'vbd_eq_vbn': ''},
 'overthought': {'vbd_eq_vbn': ''},
 'overtightened': {'vbd_eq_vbn': ''},
 'overtimed': {'vbd_eq_vbn': ''},
 'overtipped': {'vbd_eq_vbn': ''},
 'overtoiled': {'vbd_eq_vbn': ''},
 'overtopped': {'vbd_eq_vbn': ''},
 'overtowered': {'vbd_eq_vbn': ''},
 'overtraded': {'vbd_eq_vbn': ''},
 'overtrained': {'vbd_eq_vbn': ''},
 'overtreated': {'vbd_eq_vbn': ''},
 'overtrimmed': {'vbd_eq_vbn': ''},
 'overtrumped': {'vbd_eq_vbn': ''},
 'overtrusted': {'vbd_eq_vbn': ''},
 'overturned': {'vbd_eq_vbn': ''},
 'overtyped': {'vbd_eq_vbn': ''},
 'overurged': {'vbd_eq_vbn': ''},
 'overused': {'vbd_eq_vbn': ''},
 'overutilised': {'vbd_eq_vbn': ''},
 'overutilized': {'vbd_eq_vbn': ''},
 'overvalued': {'vbd_eq_vbn': ''},
 'overveiled': {'vbd_eq_vbn': ''},
 'overvoted': {'vbd_eq_vbn': ''},
 'overwarmed': {'vbd_eq_vbn': ''},
 'overwashed': {'vbd_eq_vbn': ''},
 'overwatched': {'vbd_eq_vbn': ''},
 'overwatered': {'vbd_eq_vbn': ''},
 'overwearied': {'vbd_eq_vbn': ''},
 'overweathered': {'vbd_eq_vbn': ''},
 'overweened': {'vbd_eq_vbn': ''},
 'overweighed': {'vbd_eq_vbn': ''},
 'overweighted': {'vbd_eq_vbn': ''},
 'overwet': {'vbd_eq_vbn': ''},
 'overwetted': {'vbd_eq_vbn': ''},
 'overwinged': {'vbd_eq_vbn': ''},
 'overwintered': {'vbd_eq_vbn': ''},
 'overwithheld': {'vbd_eq_vbn': ''},
 'overworded': {'vbd_eq_vbn': ''},
 'overwound': {'vbd_eq_vbn': ''},
 'overwrapped': {'vbd_eq_vbn': ''},
 'overwrested': {'vbd_eq_vbn': ''},
 'overwrestled': {'vbd_eq_vbn': ''},
 'ovulated': {'vbd_eq_vbn': ''},
 'oxidated': {'vbd_eq_vbn': ''},
 'oxidised': {'vbd_eq_vbn': ''},
 'oxidized': {'vbd_eq_vbn': ''},
 'oxygenated': {'vbd_eq_vbn': ''},
 'oxygenised': {'vbd_eq_vbn': ''},
 'oxygenized': {'vbd_eq_vbn': ''},
 'oystered': {'vbd_eq_vbn': ''},
 'ozonised': {'vbd_eq_vbn': ''},
 'ozonized': {'vbd_eq_vbn': ''},
 'paced': {'vbd_eq_vbn': ''},
 'pacified': {'vbd_eq_vbn': ''},
 'packaged': {'vbd_eq_vbn': ''},
 'paddleboarded': {'vbd_eq_vbn': ''},
 'paddled': {'vbd_eq_vbn': ''},
 'paddocked': {'vbd_eq_vbn': ''},
 'padlocked': {'vbd_eq_vbn': ''},
 'paganised': {'vbd_eq_vbn': ''},
 'paganized': {'vbd_eq_vbn': ''},
 'paged': {'vbd_eq_vbn': ''},
 'paginated': {'vbd_eq_vbn': ''},
 'paired': {'vbd_eq_vbn': ''},
 'palatalised': {'vbd_eq_vbn': ''},
 'palatalized': {'vbd_eq_vbn': ''},
 'palavered': {'vbd_eq_vbn': ''},
 'paled': {'vbd_eq_vbn': ''},
 'palisaded': {'vbd_eq_vbn': ''},
 'palled': {'vbd_eq_vbn': ''},
 'palmed': {'vbd_eq_vbn': ''},
 'palpated': {'vbd_eq_vbn': ''},
 'palpitated': {'vbd_eq_vbn': ''},
 'palsied': {'vbd_eq_vbn': ''},
 'paltered': {'vbd_eq_vbn': ''},
 'pampered': {'vbd_eq_vbn': ''},
 'pan-broiled': {'vbd_eq_vbn': ''},
 'pandered': {'vbd_eq_vbn': ''},
 'paneled': {'vbd_eq_vbn': ''},
 'panfried': {'vbd_eq_vbn': ''},
 'panged': {'vbd_eq_vbn': ''},
 'panhandled': {'vbd_eq_vbn': ''},
 'panned': {'vbd_eq_vbn': ''},
 'panted': {'vbd_eq_vbn': ''},
 'pantomimed': {'vbd_eq_vbn': ''},
 'papered': {'vbd_eq_vbn': ''},
 'par-cooked': {'vbd_eq_vbn': ''},
 'parachuted': {'vbd_eq_vbn': ''},
 'paraded': {'vbd_eq_vbn': ''},
 'paraffined': {'vbd_eq_vbn': ''},
 'paraglided': {'vbd_eq_vbn': ''},
 'paragoned': {'vbd_eq_vbn': ''},
 'paragraphed': {'vbd_eq_vbn': ''},
 'paralleled': {'vbd_eq_vbn': ''},
 'parallelised': {'vbd_eq_vbn': ''},
 'parallelized': {'vbd_eq_vbn': ''},
 'parallelled': {'vbd_eq_vbn': ''},
 'paralysed': {'vbd_eq_vbn': ''},
 'paraphrased': {'vbd_eq_vbn': ''},
 'parasailed': {'vbd_eq_vbn': ''},
 'parasitised': {'vbd_eq_vbn': ''},
 'parasitized': {'vbd_eq_vbn': ''},
 'parboiled': {'vbd_eq_vbn': ''},
 'parceled': {'vbd_eq_vbn': ''},
 'parcelled': {'vbd_eq_vbn': ''},
 'pardoned': {'vbd_eq_vbn': ''},
 'pared': {'vbd_eq_vbn': ''},
 'parented': {'vbd_eq_vbn': ''},
 'pargeted': {'vbd_eq_vbn': ''},
 'pargetted': {'vbd_eq_vbn': ''},
 'parlayed': {'vbd_eq_vbn': ''},
 'parleyed': {'vbd_eq_vbn': ''},
 'parodied': {'vbd_eq_vbn': ''},
 'paroled': {'vbd_eq_vbn': ''},
 'parried': {'vbd_eq_vbn': ''},
 'parroted': {'vbd_eq_vbn': ''},
 'parsed': {'vbd_eq_vbn': ''},
 'parted': {'vbd_eq_vbn': ''},
 'particularised': {'vbd_eq_vbn': ''},
 'particularized': {'vbd_eq_vbn': ''},
 'partied': {'vbd_eq_vbn': ''},
 'partitioned': {'vbd_eq_vbn': ''},
 'partnered': {'vbd_eq_vbn': ''},
 'passaged': {'vbd_eq_vbn': ''},
 'pasted': {'vbd_eq_vbn': ''},
 'pasteurised': {'vbd_eq_vbn': ''},
 'pastored': {'vbd_eq_vbn': ''},
 'pastured': {'vbd_eq_vbn': ''},
 'patched': {'vbd_eq_vbn': ''},
 'patented': {'vbd_eq_vbn': ''},
 'patinated': {'vbd_eq_vbn': ''},
 'patrolled': {'vbd_eq_vbn': ''},
 'patronised': {'vbd_eq_vbn': ''},
 'patronized': {'vbd_eq_vbn': ''},
 'patted': {'vbd_eq_vbn': ''},
 'pattered': {'vbd_eq_vbn': ''},
 'pauperised': {'vbd_eq_vbn': ''},
 'pauperized': {'vbd_eq_vbn': ''},
 'paved': {'vbd_eq_vbn': ''},
 'pawed': {'vbd_eq_vbn': ''},
 'pawned': {'vbd_eq_vbn': ''},
 'peached': {'vbd_eq_vbn': ''},
 'peacocked': {'vbd_eq_vbn': ''},
 'pealed': {'vbd_eq_vbn': ''},
 'pearled': {'vbd_eq_vbn': ''},
 'pebbled': {'vbd_eq_vbn': ''},
 'pecked': {'vbd_eq_vbn': ''},
 'peculated': {'vbd_eq_vbn': ''},
 'pedaled': {'vbd_eq_vbn': ''},
 'pedalled': {'vbd_eq_vbn': ''},
 'peddled': {'vbd_eq_vbn': ''},
 'pedestaled': {'vbd_eq_vbn': ''},
 'pedestalled': {'vbd_eq_vbn': ''},
 'pee-peed': {'vbd_eq_vbn': ''},
 'peed': {'vbd_eq_vbn': ''},
 'peeked': {'vbd_eq_vbn': ''},
 'peeled': {'vbd_eq_vbn': ''},
 'peened': {'vbd_eq_vbn': ''},
 'peeped': {'vbd_eq_vbn': ''},
 'peered': {'vbd_eq_vbn': ''},
 'pegged': {'vbd_eq_vbn': ''},
 'pelleted': {'vbd_eq_vbn': ''},
 'pelted': {'vbd_eq_vbn': ''},
 'penalised': {'vbd_eq_vbn': ''},
 'penalized': {'vbd_eq_vbn': ''},
 'penciled': {'vbd_eq_vbn': ''},
 'pencilled': {'vbd_eq_vbn': ''},
 'penetrated': {'vbd_eq_vbn': ''},
 'penned': {'vbd_eq_vbn': ''},
 'penny-pinched': {'vbd_eq_vbn': ''},
 'pensioned': {'vbd_eq_vbn': ''},
 'peopled': {'vbd_eq_vbn': ''},
 'pepped': {'vbd_eq_vbn': ''},
 'peppered': {'vbd_eq_vbn': ''},
 'peptised': {'vbd_eq_vbn': ''},
 'peptized': {'vbd_eq_vbn': ''},
 'perambulated': {'vbd_eq_vbn': ''},
 'perched': {'vbd_eq_vbn': ''},
 'percolated': {'vbd_eq_vbn': ''},
 'percussed': {'vbd_eq_vbn': ''},
 'peregrinated': {'vbd_eq_vbn': ''},
 'perennated': {'vbd_eq_vbn': ''},
 'perfected': {'vbd_eq_vbn': ''},
 'perfused': {'vbd_eq_vbn': ''},
 'periled': {'vbd_eq_vbn': ''},
 'perilled': {'vbd_eq_vbn': ''},
 'perked': {'vbd_eq_vbn': ''},
 'permeated': {'vbd_eq_vbn': ''},
 'permed': {'vbd_eq_vbn': ''},
 'permuted': {'vbd_eq_vbn': ''},
 'perorated': {'vbd_eq_vbn': ''},
 'peroxided': {'vbd_eq_vbn': ''},
 'perpetrated': {'vbd_eq_vbn': ''},
 'perpetuated': {'vbd_eq_vbn': ''},
 'persecuted': {'vbd_eq_vbn': ''},
 'perseverated': {'vbd_eq_vbn': ''},
 'persevered': {'vbd_eq_vbn': ''},
 'persisted': {'vbd_eq_vbn': ''},
 'personalised': {'vbd_eq_vbn': ''},
 'personated': {'vbd_eq_vbn': ''},
 'personified': {'vbd_eq_vbn': ''},
 'perspired': {'vbd_eq_vbn': ''},
 'pertained': {'vbd_eq_vbn': ''},
 'perused': {'vbd_eq_vbn': ''},
 'pervaded': {'vbd_eq_vbn': ''},
 'pervaporated': {'vbd_eq_vbn': ''},
 'pestered': {'vbd_eq_vbn': ''},
 'pestled': {'vbd_eq_vbn': ''},
 'petered': {'vbd_eq_vbn': ''},
 'petitioned': {'vbd_eq_vbn': ''},
 'petsat': {'vbd_eq_vbn': ''},
 'petted': {'vbd_eq_vbn': ''},
 'pettifogged': {'vbd_eq_vbn': ''},
 'phased': {'vbd_eq_vbn': ''},
 'philandered': {'vbd_eq_vbn': ''},
 'philosophised': {'vbd_eq_vbn': ''},
 'philosophized': {'vbd_eq_vbn': ''},
 'phlebotomised': {'vbd_eq_vbn': ''},
 'phlebotomized': {'vbd_eq_vbn': ''},
 'phonated': {'vbd_eq_vbn': ''},
 'phosphoresced': {'vbd_eq_vbn': ''},
 'photoengraved': {'vbd_eq_vbn': ''},
 'photographed': {'vbd_eq_vbn': ''},
 'photosensitised': {'vbd_eq_vbn': ''},
 'photosensitized': {'vbd_eq_vbn': ''},
 'photostated': {'vbd_eq_vbn': ''},
 'photostatted': {'vbd_eq_vbn': ''},
 'photosynthesised': {'vbd_eq_vbn': ''},
 'photosynthesized': {'vbd_eq_vbn': ''},
 'phrased': {'vbd_eq_vbn': ''},
 'physicked': {'vbd_eq_vbn': ''},
 'picketed': {'vbd_eq_vbn': ''},
 'picnicked': {'vbd_eq_vbn': ''},
 'pictured': {'vbd_eq_vbn': ''},
 'piddled': {'vbd_eq_vbn': ''},
 'pieced': {'vbd_eq_vbn': ''},
 'pierced': {'vbd_eq_vbn': ''},
 'piffled': {'vbd_eq_vbn': ''},
 'pigeon-holed': {'vbd_eq_vbn': ''},
 'pigeonholed': {'vbd_eq_vbn': ''},
 'pigged': {'vbd_eq_vbn': ''},
 'piggy-backed': {'vbd_eq_vbn': ''},
 'piggybacked': {'vbd_eq_vbn': ''},
 'piked': {'vbd_eq_vbn': ''},
 'piled': {'vbd_eq_vbn': ''},
 'pilfered': {'vbd_eq_vbn': ''},
 'pilgrimaged': {'vbd_eq_vbn': ''},
 'pillaged': {'vbd_eq_vbn': ''},
 'pilled': {'vbd_eq_vbn': ''},
 'pilloried': {'vbd_eq_vbn': ''},
 'pillowed': {'vbd_eq_vbn': ''},
 'piloted': {'vbd_eq_vbn': ''},
 'pimped': {'vbd_eq_vbn': ''},
 'pinch-hit': {'vbd_eq_vbn': ''},
 'pined': {'vbd_eq_vbn': ''},
 'pinged': {'vbd_eq_vbn': ''},
 'pinioned': {'vbd_eq_vbn': ''},
 'pinked': {'vbd_eq_vbn': ''},
 'pinnacled': {'vbd_eq_vbn': ''},
 'pinned': {'vbd_eq_vbn': ''},
 'pinpointed': {'vbd_eq_vbn': ''},
 'pioneered': {'vbd_eq_vbn': ''},
 'pipe-clayed': {'vbd_eq_vbn': ''},
 'pipeclayed': {'vbd_eq_vbn': ''},
 'piped': {'vbd_eq_vbn': ''},
 'pipped': {'vbd_eq_vbn': ''},
 'piqued': {'vbd_eq_vbn': ''},
 'pirated': {'vbd_eq_vbn': ''},
 'pirouetted': {'vbd_eq_vbn': ''},
 'pistol-whipped': {'vbd_eq_vbn': ''},
 'pistoled': {'vbd_eq_vbn': ''},
 'pistolled': {'vbd_eq_vbn': ''},
 'pitchforked': {'vbd_eq_vbn': ''},
 'pithed': {'vbd_eq_vbn': ''},
 'pitied': {'vbd_eq_vbn': ''},
 'pitter-pattered': {'vbd_eq_vbn': ''},
 'pivoted': {'vbd_eq_vbn': ''},
 'placarded': {'vbd_eq_vbn': ''},
 'placated': {'vbd_eq_vbn': ''},
 'plagiarised': {'vbd_eq_vbn': ''},
 'plagiarized': {'vbd_eq_vbn': ''},
 'plagued': {'vbd_eq_vbn': ''},
 'plaited': {'vbd_eq_vbn': ''},
 'planed': {'vbd_eq_vbn': ''},
 'planked': {'vbd_eq_vbn': ''},
 'Planned': {'vbd_eq_vbn': ''},
 'planted': {'vbd_eq_vbn': ''},
 'plashed': {'vbd_eq_vbn': ''},
 'plasticised': {'vbd_eq_vbn': ''},
 'plasticized': {'vbd_eq_vbn': ''},
 'plateaued': {'vbd_eq_vbn': ''},
 'plated': {'vbd_eq_vbn': ''},
 'platinized': {'vbd_eq_vbn': ''},
 'platitudinized': {'vbd_eq_vbn': ''},
 'platooned': {'vbd_eq_vbn': ''},
 'platted': {'vbd_eq_vbn': ''},
 'play-acted': {'vbd_eq_vbn': ''},
 'playacted': {'vbd_eq_vbn': ''},
 'playlisted': {'vbd_eq_vbn': ''},
 'plea-bargained': {'vbd_eq_vbn': ''},
 'pleached': {'vbd_eq_vbn': ''},
 'pleaded': {'vbd_eq_vbn': ''},
 'pleasured': {'vbd_eq_vbn': ''},
 'pled': {'vbd_eq_vbn': ''},
 'pledged': {'vbd_eq_vbn': ''},
 'plied': {'vbd_eq_vbn': ''},
 'plighted': {'vbd_eq_vbn': ''},
 'plinked': {'vbd_eq_vbn': ''},
 'plodded': {'vbd_eq_vbn': ''},
 'plonked': {'vbd_eq_vbn': ''},
 'plopped': {'vbd_eq_vbn': ''},
 'plotted': {'vbd_eq_vbn': ''},
 'ploughed': {'vbd_eq_vbn': ''},
 'plowed': {'vbd_eq_vbn': ''},
 'plucked': {'vbd_eq_vbn': ''},
 'plugged': {'vbd_eq_vbn': ''},
 'plumbed': {'vbd_eq_vbn': ''},
 'plummeted': {'vbd_eq_vbn': ''},
 'plumped': {'vbd_eq_vbn': ''},
 'plundered': {'vbd_eq_vbn': ''},
 'plunged': {'vbd_eq_vbn': ''},
 'plunked': {'vbd_eq_vbn': ''},
 'pluralised': {'vbd_eq_vbn': ''},
 'pluralized': {'vbd_eq_vbn': ''},
 'poached': {'vbd_eq_vbn': ''},
 'pocketed': {'vbd_eq_vbn': ''},
 'podcast': {'vbd_eq_vbn': ''},
 'podcasted': {'vbd_eq_vbn': ''},
 'podded': {'vbd_eq_vbn': ''},
 'poeticised': {'vbd_eq_vbn': ''},
 'poeticized': {'vbd_eq_vbn': ''},
 'poetised': {'vbd_eq_vbn': ''},
 'poetized': {'vbd_eq_vbn': ''},
 'poisoned': {'vbd_eq_vbn': ''},
 'poked': {'vbd_eq_vbn': ''},
 'polarised': {'vbd_eq_vbn': ''},
 'polarized': {'vbd_eq_vbn': ''},
 'pole-vaulted': {'vbd_eq_vbn': ''},
 'poleaxed': {'vbd_eq_vbn': ''},
 'poled': {'vbd_eq_vbn': ''},
 'polemicised': {'vbd_eq_vbn': ''},
 'polemicized': {'vbd_eq_vbn': ''},
 'policed': {'vbd_eq_vbn': ''},
 'politicised': {'vbd_eq_vbn': ''},
 'politicked': {'vbd_eq_vbn': ''},
 'polkaed': {'vbd_eq_vbn': ''},
 'pollarded': {'vbd_eq_vbn': ''},
 'polled': {'vbd_eq_vbn': ''},
 'pollenated': {'vbd_eq_vbn': ''},
 'pollinated': {'vbd_eq_vbn': ''},
 'polymerised': {'vbd_eq_vbn': ''},
 'polymerized': {'vbd_eq_vbn': ''},
 'pomaded': {'vbd_eq_vbn': ''},
 'pommeled': {'vbd_eq_vbn': ''},
 'pommelled': {'vbd_eq_vbn': ''},
 'pompadoured': {'vbd_eq_vbn': ''},
 'ponced': {'vbd_eq_vbn': ''},
 'pondered': {'vbd_eq_vbn': ''},
 'ponged': {'vbd_eq_vbn': ''},
 'poniarded': {'vbd_eq_vbn': ''},
 'ponied': {'vbd_eq_vbn': ''},
 'pontificated': {'vbd_eq_vbn': ''},
 'pooed': {'vbd_eq_vbn': ''},
 'pooh-poohed': {'vbd_eq_vbn': ''},
 'pooled': {'vbd_eq_vbn': ''},
 'popularised': {'vbd_eq_vbn': ''},
 'popularized': {'vbd_eq_vbn': ''},
 'populated': {'vbd_eq_vbn': ''},
 'porcelainised': {'vbd_eq_vbn': ''},
 'porcelainized': {'vbd_eq_vbn': ''},
 'pored': {'vbd_eq_vbn': ''},
 'portaged': {'vbd_eq_vbn': ''},
 'ported': {'vbd_eq_vbn': ''},
 'portended': {'vbd_eq_vbn': ''},
 'portioned': {'vbd_eq_vbn': ''},
 'portrayed': {'vbd_eq_vbn': ''},
 'posited': {'vbd_eq_vbn': ''},
 'positioned': {'vbd_eq_vbn': ''},
 'postdated': {'vbd_eq_vbn': ''},
 'postmarked': {'vbd_eq_vbn': ''},
 'postponed': {'vbd_eq_vbn': ''},
 'postposed': {'vbd_eq_vbn': ''},
 'postulated': {'vbd_eq_vbn': ''},
 'postured': {'vbd_eq_vbn': ''},
 'potentiated': {'vbd_eq_vbn': ''},
 'pothered': {'vbd_eq_vbn': ''},
 'pottered': {'vbd_eq_vbn': ''},
 'poulticed': {'vbd_eq_vbn': ''},
 'pounced': {'vbd_eq_vbn': ''},
 'pounded': {'vbd_eq_vbn': ''},
 'pouted': {'vbd_eq_vbn': ''},
 'power-dived': {'vbd_eq_vbn': ''},
 'powwowed': {'vbd_eq_vbn': ''},
 'practiced': {'vbd_eq_vbn': ''},
 'praised': {'vbd_eq_vbn': ''},
 'pranced': {'vbd_eq_vbn': ''},
 'pranged': {'vbd_eq_vbn': ''},
 'pranked': {'vbd_eq_vbn': ''},
 'prated': {'vbd_eq_vbn': ''},
 'prattled': {'vbd_eq_vbn': ''},
 'prawned': {'vbd_eq_vbn': ''},
 'pre-arranged': {'vbd_eq_vbn': ''},
 'pre-cut': {'vbd_eq_vbn': ''},
 'pre-empted': {'vbd_eq_vbn': ''},
 'pre-established': {'vbd_eq_vbn': ''},
 'pre-qualified': {'vbd_eq_vbn': ''},
 'pre-recorded': {'vbd_eq_vbn': ''},
 'pre-set': {'vbd_eq_vbn': ''},
 'pre-soaked': {'vbd_eq_vbn': ''},
 'pre-sold': {'vbd_eq_vbn': ''},
 'preached': {'vbd_eq_vbn': ''},
 'preachified': {'vbd_eq_vbn': ''},
 'preannounced': {'vbd_eq_vbn': ''},
 'preapproved': {'vbd_eq_vbn': ''},
 'precast': {'vbd_eq_vbn': ''},
 'preceded': {'vbd_eq_vbn': ''},
 'precessed': {'vbd_eq_vbn': ''},
 'precipitated': {'vbd_eq_vbn': ''},
 'precised': {'vbd_eq_vbn': ''},
 'precluded': {'vbd_eq_vbn': ''},
 'preconcerted': {'vbd_eq_vbn': ''},
 'preconditioned': {'vbd_eq_vbn': ''},
 'precooled': {'vbd_eq_vbn': ''},
 'precut': {'vbd_eq_vbn': ''},
 'predated': {'vbd_eq_vbn': ''},
 'predeceased': {'vbd_eq_vbn': ''},
 'predestinated': {'vbd_eq_vbn': ''},
 'predicated': {'vbd_eq_vbn': ''},
 'predominated': {'vbd_eq_vbn': ''},
 'preempted': {'vbd_eq_vbn': ''},
 'preened': {'vbd_eq_vbn': ''},
 'preestablished': {'vbd_eq_vbn': ''},
 'preexisted': {'vbd_eq_vbn': ''},
 'prefaced': {'vbd_eq_vbn': ''},
 'preferred': {'vbd_eq_vbn': ''},
 'prefigured': {'vbd_eq_vbn': ''},
 'prefixed': {'vbd_eq_vbn': ''},
 'preformed': {'vbd_eq_vbn': ''},
 'prefunded': {'vbd_eq_vbn': ''},
 'preheated': {'vbd_eq_vbn': ''},
 'prehended': {'vbd_eq_vbn': ''},
 'prejudged': {'vbd_eq_vbn': ''},
 'preluded': {'vbd_eq_vbn': ''},
 'premediated': {'vbd_eq_vbn': ''},
 'premiered': {'vbd_eq_vbn': ''},
 'prepaid': {'vbd_eq_vbn': ''},
 'preponderated': {'vbd_eq_vbn': ''},
 'preposed': {'vbd_eq_vbn': ''},
 'prepossessed': {'vbd_eq_vbn': ''},
 'prepped': {'vbd_eq_vbn': ''},
 'prequalified': {'vbd_eq_vbn': ''},
 'prerecorded': {'vbd_eq_vbn': ''},
 'presaged': {'vbd_eq_vbn': ''},
 'preset': {'vbd_eq_vbn': ''},
 'presided': {'vbd_eq_vbn': ''},
 'press-ganged': {'vbd_eq_vbn': ''},
 'pressure-cooked': {'vbd_eq_vbn': ''},
 'pressurised': {'vbd_eq_vbn': ''},
 'presupposed': {'vbd_eq_vbn': ''},
 'pretermitted': {'vbd_eq_vbn': ''},
 'pretested': {'vbd_eq_vbn': ''},
 'pretexted': {'vbd_eq_vbn': ''},
 'prettied': {'vbd_eq_vbn': ''},
 'prettified': {'vbd_eq_vbn': ''},
 'prevailed': {'vbd_eq_vbn': ''},
 'prevaricated': {'vbd_eq_vbn': ''},
 'previewed': {'vbd_eq_vbn': ''},
 'prevised': {'vbd_eq_vbn': ''},
 'preyed': {'vbd_eq_vbn': ''},
 'priced': {'vbd_eq_vbn': ''},
 'pricked': {'vbd_eq_vbn': ''},
 'prickled': {'vbd_eq_vbn': ''},
 'prided': {'vbd_eq_vbn': ''},
 'pried': {'vbd_eq_vbn': ''},
 'prigged': {'vbd_eq_vbn': ''},
 'primed': {'vbd_eq_vbn': ''},
 'primmed': {'vbd_eq_vbn': ''},
 'primped': {'vbd_eq_vbn': ''},
 'prinked': {'vbd_eq_vbn': ''},
 'prioritised': {'vbd_eq_vbn': ''},
 'prioritized': {'vbd_eq_vbn': ''},
 'prised': {'vbd_eq_vbn': ''},
 'privateered': {'vbd_eq_vbn': ''},
 'privatised': {'vbd_eq_vbn': ''},
 'privatized': {'vbd_eq_vbn': ''},
 'probated': {'vbd_eq_vbn': ''},
 'probed': {'vbd_eq_vbn': ''},
 'problematized': {'vbd_eq_vbn': ''},
 'proceeded': {'vbd_eq_vbn': ''},
 'proclaimed': {'vbd_eq_vbn': ''},
 'procrastinated': {'vbd_eq_vbn': ''},
 'procreated': {'vbd_eq_vbn': ''},
 'proctored': {'vbd_eq_vbn': ''},
 'procured': {'vbd_eq_vbn': ''},
 'prodded': {'vbd_eq_vbn': ''},
 'profaned': {'vbd_eq_vbn': ''},
 'professionalised': {'vbd_eq_vbn': ''},
 'professionalized': {'vbd_eq_vbn': ''},
 'proffered': {'vbd_eq_vbn': ''},
 'profiled': {'vbd_eq_vbn': ''},
 'profited': {'vbd_eq_vbn': ''},
 'profiteered': {'vbd_eq_vbn': ''},
 'prognosticated': {'vbd_eq_vbn': ''},
 'programed': {'vbd_eq_vbn': ''},
 'programmed': {'vbd_eq_vbn': ''},
 'progressed': {'vbd_eq_vbn': ''},
 'prohibited': {'vbd_eq_vbn': ''},
 'projected': {'vbd_eq_vbn': ''},
 'prolapsed': {'vbd_eq_vbn': ''},
 'proliferated': {'vbd_eq_vbn': ''},
 'prologised': {'vbd_eq_vbn': ''},
 'prologized': {'vbd_eq_vbn': ''},
 'prologuised': {'vbd_eq_vbn': ''},
 'prologuized': {'vbd_eq_vbn': ''},
 'promenaded': {'vbd_eq_vbn': ''},
 'prompted': {'vbd_eq_vbn': ''},
 'promulgated': {'vbd_eq_vbn': ''},
 'pronated': {'vbd_eq_vbn': ''},
 'pronked': {'vbd_eq_vbn': ''},
 'proofed': {'vbd_eq_vbn': ''},
 'propagandised': {'vbd_eq_vbn': ''},
 'propagandized': {'vbd_eq_vbn': ''},
 'propagated': {'vbd_eq_vbn': ''},
 'propelled': {'vbd_eq_vbn': ''},
 'prophesied': {'vbd_eq_vbn': ''},
 'propitiated': {'vbd_eq_vbn': ''},
 'propositioned': {'vbd_eq_vbn': ''},
 'propounded': {'vbd_eq_vbn': ''},
 'propped': {'vbd_eq_vbn': ''},
 'prorated': {'vbd_eq_vbn': ''},
 'prorogued': {'vbd_eq_vbn': ''},
 'proscribed': {'vbd_eq_vbn': ''},
 'prosecuted': {'vbd_eq_vbn': ''},
 'proselyted': {'vbd_eq_vbn': ''},
 'proselytised': {'vbd_eq_vbn': ''},
 'proselytized': {'vbd_eq_vbn': ''},
 'prospected': {'vbd_eq_vbn': ''},
 'prospered': {'vbd_eq_vbn': ''},
 'prostituted': {'vbd_eq_vbn': ''},
 'prostrated': {'vbd_eq_vbn': ''},
 'protested': {'vbd_eq_vbn': ''},
 'protocoled': {'vbd_eq_vbn': ''},
 'protocolled': {'vbd_eq_vbn': ''},
 'protruded': {'vbd_eq_vbn': ''},
 'provisioned': {'vbd_eq_vbn': ''},
 'prowled': {'vbd_eq_vbn': ''},
 'pruned': {'vbd_eq_vbn': ''},
 'psychoanalysed': {'vbd_eq_vbn': ''},
 'psychoanalyzed': {'vbd_eq_vbn': ''},
 'pub-crawled': {'vbd_eq_vbn': ''},
 'publicised': {'vbd_eq_vbn': ''},
 'publicized': {'vbd_eq_vbn': ''},
 'puddled': {'vbd_eq_vbn': ''},
 'pugged': {'vbd_eq_vbn': ''},
 'puked': {'vbd_eq_vbn': ''},
 'puled': {'vbd_eq_vbn': ''},
 'pullulated': {'vbd_eq_vbn': ''},
 'pulped': {'vbd_eq_vbn': ''},
 'pulsated': {'vbd_eq_vbn': ''},
 'pulsed': {'vbd_eq_vbn': ''},
 'pulverised': {'vbd_eq_vbn': ''},
 'pummeled': {'vbd_eq_vbn': ''},
 'pummelled': {'vbd_eq_vbn': ''},
 'pumped': {'vbd_eq_vbn': ''},
 'punctuated': {'vbd_eq_vbn': ''},
 'punctured': {'vbd_eq_vbn': ''},
 'punished': {'vbd_eq_vbn': ''},
 'punned': {'vbd_eq_vbn': ''},
 'punted': {'vbd_eq_vbn': ''},
 'pupated': {'vbd_eq_vbn': ''},
 'pupped': {'vbd_eq_vbn': ''},
 'pureed': {'vbd_eq_vbn': ''},
 'purged': {'vbd_eq_vbn': ''},
 'purified': {'vbd_eq_vbn': ''},
 'purled': {'vbd_eq_vbn': ''},
 'purloined': {'vbd_eq_vbn': ''},
 'purported': {'vbd_eq_vbn': ''},
 'purposed': {'vbd_eq_vbn': ''},
 'purred': {'vbd_eq_vbn': ''},
 'pursed': {'vbd_eq_vbn': ''},
 'purveyed': {'vbd_eq_vbn': ''},
 'pussyfooted': {'vbd_eq_vbn': ''},
 'pustulated': {'vbd_eq_vbn': ''},
 'put-putted': {'vbd_eq_vbn': ''},
 'putrefied': {'vbd_eq_vbn': ''},
 'putt-putted': {'vbd_eq_vbn': ''},
 'putted': {'vbd_eq_vbn': ''},
 'puttered': {'vbd_eq_vbn': ''},
 'puttied': {'vbd_eq_vbn': ''},
 'putzed': {'vbd_eq_vbn': ''},
 'pyramided': {'vbd_eq_vbn': ''},
 'quacked': {'vbd_eq_vbn': ''},
 'quadrated': {'vbd_eq_vbn': ''},
 'quadrupled': {'vbd_eq_vbn': ''},
 'quadruplicated': {'vbd_eq_vbn': ''},
 'quaffed': {'vbd_eq_vbn': ''},
 'quailed': {'vbd_eq_vbn': ''},
 'quaked': {'vbd_eq_vbn': ''},
 'quantified': {'vbd_eq_vbn': ''},
 'quantised': {'vbd_eq_vbn': ''},
 'quantized': {'vbd_eq_vbn': ''},
 'quarantined': {'vbd_eq_vbn': ''},
 'quarreled': {'vbd_eq_vbn': ''},
 'quarrelled': {'vbd_eq_vbn': ''},
 'quarried': {'vbd_eq_vbn': ''},
 'quarterbacked': {'vbd_eq_vbn': ''},
 'quartered': {'vbd_eq_vbn': ''},
 'quashed': {'vbd_eq_vbn': ''},
 'quavered': {'vbd_eq_vbn': ''},
 'queened': {'vbd_eq_vbn': ''},
 'queered': {'vbd_eq_vbn': ''},
 'quelled': {'vbd_eq_vbn': ''},
 'quenched': {'vbd_eq_vbn': ''},
 'queried': {'vbd_eq_vbn': ''},
 'quested': {'vbd_eq_vbn': ''},
 'queued': {'vbd_eq_vbn': ''},
 'quibbled': {'vbd_eq_vbn': ''},
 'quickened': {'vbd_eq_vbn': ''},
 'quiesced': {'vbd_eq_vbn': ''},
 'quieted': {'vbd_eq_vbn': ''},
 'quietened': {'vbd_eq_vbn': ''},
 'quilled': {'vbd_eq_vbn': ''},
 'quintupled': {'vbd_eq_vbn': ''},
 'quipped': {'vbd_eq_vbn': ''},
 'quitted': {'vbd_eq_vbn': ''},
 'quivered': {'vbd_eq_vbn': ''},
 'quizzed': {'vbd_eq_vbn': ''},
 'rabbeted': {'vbd_eq_vbn': ''},
 'rabbited': {'vbd_eq_vbn': ''},
 'racemised': {'vbd_eq_vbn': ''},
 'racemized': {'vbd_eq_vbn': ''},
 'racialised': {'vbd_eq_vbn': ''},
 'racialized': {'vbd_eq_vbn': ''},
 'rack-rented': {'vbd_eq_vbn': ''},
 'racked': {'vbd_eq_vbn': ''},
 'racketed': {'vbd_eq_vbn': ''},
 'racketeered': {'vbd_eq_vbn': ''},
 'radiated': {'vbd_eq_vbn': ''},
 'radicalised': {'vbd_eq_vbn': ''},
 'radicalized': {'vbd_eq_vbn': ''},
 'radioed': {'vbd_eq_vbn': ''},
 'radiographed': {'vbd_eq_vbn': ''},
 'radiosterilized': {'vbd_eq_vbn': ''},
 'raffled': {'vbd_eq_vbn': ''},
 'rafted': {'vbd_eq_vbn': ''},
 'raged': {'vbd_eq_vbn': ''},
 'raided': {'vbd_eq_vbn': ''},
 'railroaded': {'vbd_eq_vbn': ''},
 'rainproofed': {'vbd_eq_vbn': ''},
 'rallied': {'vbd_eq_vbn': ''},
 'rambled': {'vbd_eq_vbn': ''},
 'ramified': {'vbd_eq_vbn': ''},
 'rammed': {'vbd_eq_vbn': ''},
 'rampaged': {'vbd_eq_vbn': ''},
 'ramparted': {'vbd_eq_vbn': ''},
 'ramped': {'vbd_eq_vbn': ''},
 'ramrodded': {'vbd_eq_vbn': ''},
 'ranched': {'vbd_eq_vbn': ''},
 'randomised': {'vbd_eq_vbn': ''},
 'randomized': {'vbd_eq_vbn': ''},
 'rankled': {'vbd_eq_vbn': ''},
 'ransacked': {'vbd_eq_vbn': ''},
 'ransomed': {'vbd_eq_vbn': ''},
 'ranted': {'vbd_eq_vbn': ''},
 'raped': {'vbd_eq_vbn': ''},
 'rapped': {'vbd_eq_vbn': ''},
 'rappelled': {'vbd_eq_vbn': ''},
 'raptured': {'vbd_eq_vbn': ''},
 'rarified': {'vbd_eq_vbn': ''},
 'rased': {'vbd_eq_vbn': ''},
 'rasped': {'vbd_eq_vbn': ''},
 'ratcheted': {'vbd_eq_vbn': ''},
 'rate-capped': {'vbd_eq_vbn': ''},
 'ratified': {'vbd_eq_vbn': ''},
 'ratiocinated': {'vbd_eq_vbn': ''},
 'rationalised': {'vbd_eq_vbn': ''},
 'rationalized': {'vbd_eq_vbn': ''},
 'rationed': {'vbd_eq_vbn': ''},
 'ratted': {'vbd_eq_vbn': ''},
 'rattled': {'vbd_eq_vbn': ''},
 'ravaged': {'vbd_eq_vbn': ''},
 'raved': {'vbd_eq_vbn': ''},
 'raveled': {'vbd_eq_vbn': ''},
 'ravelled': {'vbd_eq_vbn': ''},
 'ravened': {'vbd_eq_vbn': ''},
 'ravished': {'vbd_eq_vbn': ''},
 'rayed': {'vbd_eq_vbn': ''},
 'razed': {'vbd_eq_vbn': ''},
 'razor-cut': {'vbd_eq_vbn': ''},
 'razored': {'vbd_eq_vbn': ''},
 'razzed': {'vbd_eq_vbn': ''},
 're-argued': {'vbd_eq_vbn': ''},
 're-armed': {'vbd_eq_vbn': ''},
 're-created': {'vbd_eq_vbn': ''},
 're-echoed': {'vbd_eq_vbn': ''},
 're-edited': {'vbd_eq_vbn': ''},
 're-educated': {'vbd_eq_vbn': ''},
 're-elected': {'vbd_eq_vbn': ''},
 're-emerged': {'vbd_eq_vbn': ''},
 're-emitted': {'vbd_eq_vbn': ''},
 're-emphasised': {'vbd_eq_vbn': ''},
 're-emphasized': {'vbd_eq_vbn': ''},
 're-enacted': {'vbd_eq_vbn': ''},
 're-energised': {'vbd_eq_vbn': ''},
 're-energized': {'vbd_eq_vbn': ''},
 're-enforced': {'vbd_eq_vbn': ''},
 're-engineered': {'vbd_eq_vbn': ''},
 're-enrolled': {'vbd_eq_vbn': ''},
 're-entered': {'vbd_eq_vbn': ''},
 're-equipped': {'vbd_eq_vbn': ''},
 're-established': {'vbd_eq_vbn': ''},
 're-evaluated': {'vbd_eq_vbn': ''},
 're-examined': {'vbd_eq_vbn': ''},
 're-experienced': {'vbd_eq_vbn': ''},
 're-explained': {'vbd_eq_vbn': ''},
 're-explored': {'vbd_eq_vbn': ''},
 're-exported': {'vbd_eq_vbn': ''},
 're-formed': {'vbd_eq_vbn': ''},
 're-offered': {'vbd_eq_vbn': ''},
 're-presented': {'vbd_eq_vbn': ''},
 're-released': {'vbd_eq_vbn': ''},
 'reabsorbed': {'vbd_eq_vbn': ''},
 'reaccelerated': {'vbd_eq_vbn': ''},
 'reacquainted': {'vbd_eq_vbn': ''},
 'reacquired': {'vbd_eq_vbn': ''},
 'reactivated': {'vbd_eq_vbn': ''},
 'readapted': {'vbd_eq_vbn': ''},
 'readdressed': {'vbd_eq_vbn': ''},
 'readied': {'vbd_eq_vbn': ''},
 'readjusted': {'vbd_eq_vbn': ''},
 'readmitted': {'vbd_eq_vbn': ''},
 'readopted': {'vbd_eq_vbn': ''},
 'reaffirmed': {'vbd_eq_vbn': ''},
 'reafforested': {'vbd_eq_vbn': ''},
 'realigned': {'vbd_eq_vbn': ''},
 'realised': {'vbd_eq_vbn': ''},
 'reallocated': {'vbd_eq_vbn': ''},
 'reallotted': {'vbd_eq_vbn': ''},
 'reamed': {'vbd_eq_vbn': ''},
 'reanimated': {'vbd_eq_vbn': ''},
 'reaped': {'vbd_eq_vbn': ''},
 'reappeared': {'vbd_eq_vbn': ''},
 'reappointed': {'vbd_eq_vbn': ''},
 'reapportioned': {'vbd_eq_vbn': ''},
 'reappraised': {'vbd_eq_vbn': ''},
 'rear-ended': {'vbd_eq_vbn': ''},
 'reared': {'vbd_eq_vbn': ''},
 'rearmed': {'vbd_eq_vbn': ''},
 'rearranged': {'vbd_eq_vbn': ''},
 'rearrested': {'vbd_eq_vbn': ''},
 'reassembled': {'vbd_eq_vbn': ''},
 'reasserted': {'vbd_eq_vbn': ''},
 'reassessed': {'vbd_eq_vbn': ''},
 'reassigned': {'vbd_eq_vbn': ''},
 'reassumed': {'vbd_eq_vbn': ''},
 'reassured': {'vbd_eq_vbn': ''},
 'reattached': {'vbd_eq_vbn': ''},
 'reattributed': {'vbd_eq_vbn': ''},
 'reauthorised': {'vbd_eq_vbn': ''},
 'reauthorized': {'vbd_eq_vbn': ''},
 'reaved': {'vbd_eq_vbn': ''},
 'reawakened': {'vbd_eq_vbn': ''},
 'rebalanced': {'vbd_eq_vbn': ''},
 'rebated': {'vbd_eq_vbn': ''},
 'rebelled': {'vbd_eq_vbn': ''},
 'rebooted': {'vbd_eq_vbn': ''},
 'rebounded': {'vbd_eq_vbn': ''},
 'rebroadcasted': {'vbd_eq_vbn': ''},
 'rebuffed': {'vbd_eq_vbn': ''},
 'rebuilt': {'vbd_eq_vbn': ''},
 'rebuked': {'vbd_eq_vbn': ''},
 'reburied': {'vbd_eq_vbn': ''},
 'rebutted': {'vbd_eq_vbn': ''},
 'recalcitrated': {'vbd_eq_vbn': ''},
 'recalculated': {'vbd_eq_vbn': ''},
 'recanted': {'vbd_eq_vbn': ''},
 'recapitalised': {'vbd_eq_vbn': ''},
 'recapitalized': {'vbd_eq_vbn': ''},
 'recapitulated': {'vbd_eq_vbn': ''},
 'recapped': {'vbd_eq_vbn': ''},
 'recaptured': {'vbd_eq_vbn': ''},
 'recategorised': {'vbd_eq_vbn': ''},
 'recategorized': {'vbd_eq_vbn': ''},
 'recced': {'vbd_eq_vbn': ''},
 'receded': {'vbd_eq_vbn': ''},
 'recentralized': {'vbd_eq_vbn': ''},
 'rechannelled': {'vbd_eq_vbn': ''},
 'recharged': {'vbd_eq_vbn': ''},
 'rechartered': {'vbd_eq_vbn': ''},
 'rechecked': {'vbd_eq_vbn': ''},
 'rechristened': {'vbd_eq_vbn': ''},
 'recidivated': {'vbd_eq_vbn': ''},
 'reciprocated': {'vbd_eq_vbn': ''},
 'recirculated': {'vbd_eq_vbn': ''},
 'recited': {'vbd_eq_vbn': ''},
 'reclaimed': {'vbd_eq_vbn': ''},
 'reclassified': {'vbd_eq_vbn': ''},
 'reclined': {'vbd_eq_vbn': ''},
 'recoated': {'vbd_eq_vbn': ''},
 'recoded': {'vbd_eq_vbn': ''},
 'recognised': {'vbd_eq_vbn': ''},
 'recoiled': {'vbd_eq_vbn': ''},
 'recollected': {'vbd_eq_vbn': ''},
 'recombined': {'vbd_eq_vbn': ''},
 'recommenced': {'vbd_eq_vbn': ''},
 'recommitted': {'vbd_eq_vbn': ''},
 'recompensed': {'vbd_eq_vbn': ''},
 'recomposed': {'vbd_eq_vbn': ''},
 'reconceived': {'vbd_eq_vbn': ''},
 'reconciled': {'vbd_eq_vbn': ''},
 'reconditioned': {'vbd_eq_vbn': ''},
 'reconfigured': {'vbd_eq_vbn': ''},
 'reconfirmed': {'vbd_eq_vbn': ''},
 'reconnected': {'vbd_eq_vbn': ''},
 'reconnoitered': {'vbd_eq_vbn': ''},
 'reconnoitred': {'vbd_eq_vbn': ''},
 'reconquered': {'vbd_eq_vbn': ''},
 'reconsidered': {'vbd_eq_vbn': ''},
 'reconstituted': {'vbd_eq_vbn': ''},
 'reconstructed': {'vbd_eq_vbn': ''},
 'reconvened': {'vbd_eq_vbn': ''},
 'reconverted': {'vbd_eq_vbn': ''},
 'reconvicted': {'vbd_eq_vbn': ''},
 'recopied': {'vbd_eq_vbn': ''},
 'recounted': {'vbd_eq_vbn': ''},
 'recouped': {'vbd_eq_vbn': ''},
 'recreated': {'vbd_eq_vbn': ''},
 'recriminated': {'vbd_eq_vbn': ''},
 'recrudesced': {'vbd_eq_vbn': ''},
 'recruited': {'vbd_eq_vbn': ''},
 'rectified': {'vbd_eq_vbn': ''},
 'recuperated': {'vbd_eq_vbn': ''},
 'recurred': {'vbd_eq_vbn': ''},
 'recurved': {'vbd_eq_vbn': ''},
 'recused': {'vbd_eq_vbn': ''},
 'recut': {'vbd_eq_vbn': ''},
 'recycled': {'vbd_eq_vbn': ''},
 'red-flagged': {'vbd_eq_vbn': ''},
 'redacted': {'vbd_eq_vbn': ''},
 'redd': {'vbd_eq_vbn': ''},
 'redded': {'vbd_eq_vbn': ''},
 'reddened': {'vbd_eq_vbn': ''},
 'redecorated': {'vbd_eq_vbn': ''},
 'reded': {'vbd_eq_vbn': ''},
 'rededicated': {'vbd_eq_vbn': ''},
 'redeemed': {'vbd_eq_vbn': ''},
 'redefined': {'vbd_eq_vbn': ''},
 'redelivered': {'vbd_eq_vbn': ''},
 'redeployed': {'vbd_eq_vbn': ''},
 'redesignated': {'vbd_eq_vbn': ''},
 'redesigned': {'vbd_eq_vbn': ''},
 'redetermined': {'vbd_eq_vbn': ''},
 'redeveloped': {'vbd_eq_vbn': ''},
 'redialed': {'vbd_eq_vbn': ''},
 'redialled': {'vbd_eq_vbn': ''},
 'redirected': {'vbd_eq_vbn': ''},
 'rediscovered': {'vbd_eq_vbn': ''},
 'redisposed': {'vbd_eq_vbn': ''},
 'redistributed': {'vbd_eq_vbn': ''},
 'redistricted': {'vbd_eq_vbn': ''},
 'redlined': {'vbd_eq_vbn': ''},
 'redoubled': {'vbd_eq_vbn': ''},
 'redounded': {'vbd_eq_vbn': ''},
 'redrafted': {'vbd_eq_vbn': ''},
 'redressed': {'vbd_eq_vbn': ''},
 'redshirted': {'vbd_eq_vbn': ''},
 'reduplicated': {'vbd_eq_vbn': ''},
 'reechoed': {'vbd_eq_vbn': ''},
 'reefed': {'vbd_eq_vbn': ''},
 'reeked': {'vbd_eq_vbn': ''},
 'reelected': {'vbd_eq_vbn': ''},
 'reeled': {'vbd_eq_vbn': ''},
 'reemitted': {'vbd_eq_vbn': ''},
 'reemphasized': {'vbd_eq_vbn': ''},
 'reenacted': {'vbd_eq_vbn': ''},
 'reenforced': {'vbd_eq_vbn': ''},
 'reengineered': {'vbd_eq_vbn': ''},
 'reenrolled': {'vbd_eq_vbn': ''},
 'reentered': {'vbd_eq_vbn': ''},
 'reestablished': {'vbd_eq_vbn': ''},
 'reevaluated': {'vbd_eq_vbn': ''},
 'reeved': {'vbd_eq_vbn': ''},
 'reexamined': {'vbd_eq_vbn': ''},
 'refaced': {'vbd_eq_vbn': ''},
 'refashioned': {'vbd_eq_vbn': ''},
 'refereed': {'vbd_eq_vbn': ''},
 'referenced': {'vbd_eq_vbn': ''},
 'refighted': {'vbd_eq_vbn': ''},
 'refiled': {'vbd_eq_vbn': ''},
 'refilled': {'vbd_eq_vbn': ''},
 'refinanced': {'vbd_eq_vbn': ''},
 'refinished': {'vbd_eq_vbn': ''},
 'refitted': {'vbd_eq_vbn': ''},
 'reflated': {'vbd_eq_vbn': ''},
 'reflectorised': {'vbd_eq_vbn': ''},
 'reflectorized': {'vbd_eq_vbn': ''},
 'reflexed': {'vbd_eq_vbn': ''},
 'refloated': {'vbd_eq_vbn': ''},
 'refluxed': {'vbd_eq_vbn': ''},
 'refocused': {'vbd_eq_vbn': ''},
 'refolded': {'vbd_eq_vbn': ''},
 'reforested': {'vbd_eq_vbn': ''},
 'reforged': {'vbd_eq_vbn': ''},
 'reformulated': {'vbd_eq_vbn': ''},
 'refracted': {'vbd_eq_vbn': ''},
 'refrained': {'vbd_eq_vbn': ''},
 'refrigerated': {'vbd_eq_vbn': ''},
 'reft': {'vbd_eq_vbn': ''},
 'refueled': {'vbd_eq_vbn': ''},
 'refuelled': {'vbd_eq_vbn': ''},
 'refuged': {'vbd_eq_vbn': ''},
 'refunded': {'vbd_eq_vbn': ''},
 'refurbished': {'vbd_eq_vbn': ''},
 'refuted': {'vbd_eq_vbn': ''},
 'regained': {'vbd_eq_vbn': ''},
 'regaled': {'vbd_eq_vbn': ''},
 'regenerated': {'vbd_eq_vbn': ''},
 'regimented': {'vbd_eq_vbn': ''},
 'regorged': {'vbd_eq_vbn': ''},
 'regressed': {'vbd_eq_vbn': ''},
 'regrouped': {'vbd_eq_vbn': ''},
 'regularised': {'vbd_eq_vbn': ''},
 'regularized': {'vbd_eq_vbn': ''},
 'regulated': {'vbd_eq_vbn': ''},
 'regurgitated': {'vbd_eq_vbn': ''},
 'rehabbed': {'vbd_eq_vbn': ''},
 'rehabilitated': {'vbd_eq_vbn': ''},
 'rehashed': {'vbd_eq_vbn': ''},
 'reheard': {'vbd_eq_vbn': ''},
 'rehearsed': {'vbd_eq_vbn': ''},
 'reheated': {'vbd_eq_vbn': ''},
 'reheeled': {'vbd_eq_vbn': ''},
 'rehoused': {'vbd_eq_vbn': ''},
 'reified': {'vbd_eq_vbn': ''},
 'reigned': {'vbd_eq_vbn': ''},
 'reignited': {'vbd_eq_vbn': ''},
 'reimbursed': {'vbd_eq_vbn': ''},
 'reimposed': {'vbd_eq_vbn': ''},
 'reincarnated': {'vbd_eq_vbn': ''},
 'reincorporated': {'vbd_eq_vbn': ''},
 'reindicted': {'vbd_eq_vbn': ''},
 'reined': {'vbd_eq_vbn': ''},
 'reinjected': {'vbd_eq_vbn': ''},
 'reinstalled': {'vbd_eq_vbn': ''},
 'reinstated': {'vbd_eq_vbn': ''},
 'reinstituted': {'vbd_eq_vbn': ''},
 'reinsured': {'vbd_eq_vbn': ''},
 'reintegrated': {'vbd_eq_vbn': ''},
 'reinterpreted': {'vbd_eq_vbn': ''},
 'reintroduced': {'vbd_eq_vbn': ''},
 'reinvented': {'vbd_eq_vbn': ''},
 'reinvested': {'vbd_eq_vbn': ''},
 'reinvestigated': {'vbd_eq_vbn': ''},
 'reinvigorated': {'vbd_eq_vbn': ''},
 'reissued': {'vbd_eq_vbn': ''},
 'reiterated': {'vbd_eq_vbn': ''},
 'rejigged': {'vbd_eq_vbn': ''},
 'rejiggered': {'vbd_eq_vbn': ''},
 'rejoiced': {'vbd_eq_vbn': ''},
 'rejoined': {'vbd_eq_vbn': ''},
 'rejuvenated': {'vbd_eq_vbn': ''},
 'rekindled': {'vbd_eq_vbn': ''},
 'relabeled': {'vbd_eq_vbn': ''},
 'relaced': {'vbd_eq_vbn': ''},
 'relapsed': {'vbd_eq_vbn': ''},
 'relativised': {'vbd_eq_vbn': ''},
 'relativized': {'vbd_eq_vbn': ''},
 'relaunched': {'vbd_eq_vbn': ''},
 'relayed': {'vbd_eq_vbn': ''},
 'relearned': {'vbd_eq_vbn': ''},
 'relegated': {'vbd_eq_vbn': ''},
 'relented': {'vbd_eq_vbn': ''},
 'relicensed': {'vbd_eq_vbn': ''},
 'relined': {'vbd_eq_vbn': ''},
 'relinquished': {'vbd_eq_vbn': ''},
 'relished': {'vbd_eq_vbn': ''},
 'relisted': {'vbd_eq_vbn': ''},
 'relitigated': {'vbd_eq_vbn': ''},
 'relived': {'vbd_eq_vbn': ''},
 'reloaded': {'vbd_eq_vbn': ''},
 'relocated': {'vbd_eq_vbn': ''},
 'relyriced': {'vbd_eq_vbn': ''},
 'remade': {'vbd_eq_vbn': ''},
 'remaindered': {'vbd_eq_vbn': ''},
 'remanded': {'vbd_eq_vbn': ''},
 'remarketed': {'vbd_eq_vbn': ''},
 'remarried': {'vbd_eq_vbn': ''},
 'remediated': {'vbd_eq_vbn': ''},
 'remedied': {'vbd_eq_vbn': ''},
 'remilitarised': {'vbd_eq_vbn': ''},
 'remilitarized': {'vbd_eq_vbn': ''},
 'reminisced': {'vbd_eq_vbn': ''},
 'remised': {'vbd_eq_vbn': ''},
 'remitted': {'vbd_eq_vbn': ''},
 'remixed': {'vbd_eq_vbn': ''},
 'remodeled': {'vbd_eq_vbn': ''},
 'remodelled': {'vbd_eq_vbn': ''},
 'remolded': {'vbd_eq_vbn': ''},
 'remonstrated': {'vbd_eq_vbn': ''},
 'remoralised': {'vbd_eq_vbn': ''},
 'remoralized': {'vbd_eq_vbn': ''},
 'remoulded': {'vbd_eq_vbn': ''},
 'remounted': {'vbd_eq_vbn': ''},
 'remunerated': {'vbd_eq_vbn': ''},
 'renamed': {'vbd_eq_vbn': ''},
 'renationalised': {'vbd_eq_vbn': ''},
 'renationalized': {'vbd_eq_vbn': ''},
 'rended': {'vbd_eq_vbn': ''},
 'rendered': {'vbd_eq_vbn': ''},
 'rendezvoused': {'vbd_eq_vbn': ''},
 'renegaded': {'vbd_eq_vbn': ''},
 'reneged': {'vbd_eq_vbn': ''},
 'renegotiated': {'vbd_eq_vbn': ''},
 'renormalised': {'vbd_eq_vbn': ''},
 'renormalized': {'vbd_eq_vbn': ''},
 'renounced': {'vbd_eq_vbn': ''},
 'renovated': {'vbd_eq_vbn': ''},
 'reoccupied': {'vbd_eq_vbn': ''},
 'reoccurred': {'vbd_eq_vbn': ''},
 'reoffended': {'vbd_eq_vbn': ''},
 'reopened': {'vbd_eq_vbn': ''},
 'reordered': {'vbd_eq_vbn': ''},
 'reorganised': {'vbd_eq_vbn': ''},
 'reorganized': {'vbd_eq_vbn': ''},
 'reorientated': {'vbd_eq_vbn': ''},
 'reoriented': {'vbd_eq_vbn': ''},
 'repackaged': {'vbd_eq_vbn': ''},
 'repacked': {'vbd_eq_vbn': ''},
 'repaid': {'vbd_eq_vbn': ''},
 'repainted': {'vbd_eq_vbn': ''},
 'repassed': {'vbd_eq_vbn': ''},
 'repasted': {'vbd_eq_vbn': ''},
 'repatriated': {'vbd_eq_vbn': ''},
 'repealed': {'vbd_eq_vbn': ''},
 'repelled': {'vbd_eq_vbn': ''},
 'repented': {'vbd_eq_vbn': ''},
 'repercussed': {'vbd_eq_vbn': ''},
 'rephrased': {'vbd_eq_vbn': ''},
 'repined': {'vbd_eq_vbn': ''},
 'replanted': {'vbd_eq_vbn': ''},
 'replastered': {'vbd_eq_vbn': ''},
 'replayed': {'vbd_eq_vbn': ''},
 'replenished': {'vbd_eq_vbn': ''},
 'replicated': {'vbd_eq_vbn': ''},
 'repointed': {'vbd_eq_vbn': ''},
 'reposed': {'vbd_eq_vbn': ''},
 'reposited': {'vbd_eq_vbn': ''},
 'repositioned': {'vbd_eq_vbn': ''},
 'repossessed': {'vbd_eq_vbn': ''},
 'repotted': {'vbd_eq_vbn': ''},
 'reprehended': {'vbd_eq_vbn': ''},
 'repriced': {'vbd_eq_vbn': ''},
 'reprieved': {'vbd_eq_vbn': ''},
 'reprimanded': {'vbd_eq_vbn': ''},
 'reprinted': {'vbd_eq_vbn': ''},
 'reprised': {'vbd_eq_vbn': ''},
 'reproached': {'vbd_eq_vbn': ''},
 'reprobated': {'vbd_eq_vbn': ''},
 'reprocessed': {'vbd_eq_vbn': ''},
 'reproduced': {'vbd_eq_vbn': ''},
 'reprogrammed': {'vbd_eq_vbn': ''},
 'reproofed': {'vbd_eq_vbn': ''},
 'reproved': {'vbd_eq_vbn': ''},
 'republished': {'vbd_eq_vbn': ''},
 'repudiated': {'vbd_eq_vbn': ''},
 'repugned': {'vbd_eq_vbn': ''},
 'repulsed': {'vbd_eq_vbn': ''},
 'repurchased': {'vbd_eq_vbn': ''},
 'repurposed': {'vbd_eq_vbn': ''},
 'requalified': {'vbd_eq_vbn': ''},
 'requisitioned': {'vbd_eq_vbn': ''},
 'requited': {'vbd_eq_vbn': ''},
 'rereleased': {'vbd_eq_vbn': ''},
 'reroofed': {'vbd_eq_vbn': ''},
 'rerouted': {'vbd_eq_vbn': ''},
 'rescaled': {'vbd_eq_vbn': ''},
 'rescheduled': {'vbd_eq_vbn': ''},
 'rescinded': {'vbd_eq_vbn': ''},
 'resealed': {'vbd_eq_vbn': ''},
 'reseated': {'vbd_eq_vbn': ''},
 'resected': {'vbd_eq_vbn': ''},
 'reseeded': {'vbd_eq_vbn': ''},
 'resembled': {'vbd_eq_vbn': ''},
 'resented': {'vbd_eq_vbn': ''},
 'resettled': {'vbd_eq_vbn': ''},
 'reshaped': {'vbd_eq_vbn': ''},
 'reshipped': {'vbd_eq_vbn': ''},
 'reshot': {'vbd_eq_vbn': ''},
 'reshuffled': {'vbd_eq_vbn': ''},
 'resided': {'vbd_eq_vbn': ''},
 'resifted': {'vbd_eq_vbn': ''},
 'resiled': {'vbd_eq_vbn': ''},
 'resinated': {'vbd_eq_vbn': ''},
 'resined': {'vbd_eq_vbn': ''},
 'resized': {'vbd_eq_vbn': ''},
 'reskilled': {'vbd_eq_vbn': ''},
 'resold': {'vbd_eq_vbn': ''},
 'resoled': {'vbd_eq_vbn': ''},
 'resonated': {'vbd_eq_vbn': ''},
 'resorbed': {'vbd_eq_vbn': ''},
 'resounded': {'vbd_eq_vbn': ''},
 'resourced': {'vbd_eq_vbn': ''},
 'respired': {'vbd_eq_vbn': ''},
 'respited': {'vbd_eq_vbn': ''},
 'restaffed': {'vbd_eq_vbn': ''},
 'restaged': {'vbd_eq_vbn': ''},
 'restarted': {'vbd_eq_vbn': ''},
 'restated': {'vbd_eq_vbn': ''},
 'restituted': {'vbd_eq_vbn': ''},
 'restocked': {'vbd_eq_vbn': ''},
 'restructured': {'vbd_eq_vbn': ''},
 'restudied': {'vbd_eq_vbn': ''},
 'restyled': {'vbd_eq_vbn': ''},
 'resublimed': {'vbd_eq_vbn': ''},
 'resubmitted': {'vbd_eq_vbn': ''},
 'resumed': {'vbd_eq_vbn': ''},
 'resupplied': {'vbd_eq_vbn': ''},
 'resurfaced': {'vbd_eq_vbn': ''},
 'resurged': {'vbd_eq_vbn': ''},
 'resurrected': {'vbd_eq_vbn': ''},
 'resuscitated': {'vbd_eq_vbn': ''},
 'resuspended': {'vbd_eq_vbn': ''},
 'retailed': {'vbd_eq_vbn': ''},
 'retaliated': {'vbd_eq_vbn': ''},
 'retargeted': {'vbd_eq_vbn': ''},
 'retched': {'vbd_eq_vbn': ''},
 'reteamed': {'vbd_eq_vbn': ''},
 'rethought': {'vbd_eq_vbn': ''},
 'reticulated': {'vbd_eq_vbn': ''},
 'retied': {'vbd_eq_vbn': ''},
 'retold': {'vbd_eq_vbn': ''},
 'retooled': {'vbd_eq_vbn': ''},
 'retorted': {'vbd_eq_vbn': ''},
 'retouched': {'vbd_eq_vbn': ''},
 'retraced': {'vbd_eq_vbn': ''},
 'retracted': {'vbd_eq_vbn': ''},
 'retrained': {'vbd_eq_vbn': ''},
 'retranslated': {'vbd_eq_vbn': ''},
 'retransmitted': {'vbd_eq_vbn': ''},
 'retreaded': {'vbd_eq_vbn': ''},
 'retreated': {'vbd_eq_vbn': ''},
 'retrenched': {'vbd_eq_vbn': ''},
 'retried': {'vbd_eq_vbn': ''},
 'retrieved': {'vbd_eq_vbn': ''},
 'retrofitted': {'vbd_eq_vbn': ''},
 'retrograded': {'vbd_eq_vbn': ''},
 'retrogressed': {'vbd_eq_vbn': ''},
 'retrospected': {'vbd_eq_vbn': ''},
 'retted': {'vbd_eq_vbn': ''},
 'retweeted': {'vbd_eq_vbn': ''},
 'reunified': {'vbd_eq_vbn': ''},
 'reunited': {'vbd_eq_vbn': ''},
 'reupholstered': {'vbd_eq_vbn': ''},
 'reused': {'vbd_eq_vbn': ''},
 'revalued': {'vbd_eq_vbn': ''},
 'revamped': {'vbd_eq_vbn': ''},
 'reveled': {'vbd_eq_vbn': ''},
 'revelled': {'vbd_eq_vbn': ''},
 'revenged': {'vbd_eq_vbn': ''},
 'reverberated': {'vbd_eq_vbn': ''},
 'reverenced': {'vbd_eq_vbn': ''},
 'reverted': {'vbd_eq_vbn': ''},
 'revetted': {'vbd_eq_vbn': ''},
 'reviled': {'vbd_eq_vbn': ''},
 'revised': {'vbd_eq_vbn': ''},
 'revisited': {'vbd_eq_vbn': ''},
 'revitalised': {'vbd_eq_vbn': ''},
 'revitalized': {'vbd_eq_vbn': ''},
 'revived': {'vbd_eq_vbn': ''},
 'revivified': {'vbd_eq_vbn': ''},
 'revoked': {'vbd_eq_vbn': ''},
 'revolted': {'vbd_eq_vbn': ''},
 'revolutionised': {'vbd_eq_vbn': ''},
 'revolutionized': {'vbd_eq_vbn': ''},
 'revolved': {'vbd_eq_vbn': ''},
 'revved': {'vbd_eq_vbn': ''},
 'rewilded': {'vbd_eq_vbn': ''},
 'rewired': {'vbd_eq_vbn': ''},
 'reworded': {'vbd_eq_vbn': ''},
 'reworked': {'vbd_eq_vbn': ''},
 'rewrapped': {'vbd_eq_vbn': ''},
 'rhapsodised': {'vbd_eq_vbn': ''},
 'rhapsodized': {'vbd_eq_vbn': ''},
 'rhymed': {'vbd_eq_vbn': ''},
 'ribboned': {'vbd_eq_vbn': ''},
 'riced': {'vbd_eq_vbn': ''},
 'ricked': {'vbd_eq_vbn': ''},
 'ricocheted': {'vbd_eq_vbn': ''},
 'ricochetted': {'vbd_eq_vbn': ''},
 'ridiculed': {'vbd_eq_vbn': ''},
 'riffed': {'vbd_eq_vbn': ''},
 'riffled': {'vbd_eq_vbn': ''},
 'rifled': {'vbd_eq_vbn': ''},
 'rifted': {'vbd_eq_vbn': ''},
 'rigged': {'vbd_eq_vbn': ''},
 'righted': {'vbd_eq_vbn': ''},
 'rigidified': {'vbd_eq_vbn': ''},
 'riled': {'vbd_eq_vbn': ''},
 'rimed': {'vbd_eq_vbn': ''},
 'rimmed': {'vbd_eq_vbn': ''},
 'rinsed': {'vbd_eq_vbn': ''},
 'rioted': {'vbd_eq_vbn': ''},
 'ripened': {'vbd_eq_vbn': ''},
 'riposted': {'vbd_eq_vbn': ''},
 'rippled': {'vbd_eq_vbn': ''},
 'ritualised': {'vbd_eq_vbn': ''},
 'ritualized': {'vbd_eq_vbn': ''},
 'rivalled': {'vbd_eq_vbn': ''},
 'rived': {'vbd_eq_vbn': ''},
 'riveted': {'vbd_eq_vbn': ''},
 'roamed': {'vbd_eq_vbn': ''},
 'roared': {'vbd_eq_vbn': ''},
 'roasted': {'vbd_eq_vbn': ''},
 'rocketed': {'vbd_eq_vbn': ''},
 'roiled': {'vbd_eq_vbn': ''},
 'roistered': {'vbd_eq_vbn': ''},
 'role-played': {'vbd_eq_vbn': ''},
 'roller-skated': {'vbd_eq_vbn': ''},
 'rollicked': {'vbd_eq_vbn': ''},
 'romanced': {'vbd_eq_vbn': ''},
 'Romanised': {'vbd_eq_vbn': ''},
 'Romanized': {'vbd_eq_vbn': ''},
 'romanticised': {'vbd_eq_vbn': ''},
 'romanticized': {'vbd_eq_vbn': ''},
 'romped': {'vbd_eq_vbn': ''},
 'Roneoed': {'vbd_eq_vbn': ''},
 'rooked': {'vbd_eq_vbn': ''},
 'roomed': {'vbd_eq_vbn': ''},
 'roosted': {'vbd_eq_vbn': ''},
 'rootled': {'vbd_eq_vbn': ''},
 'rosined': {'vbd_eq_vbn': ''},
 'rostered': {'vbd_eq_vbn': ''},
 'rotated': {'vbd_eq_vbn': ''},
 'rotted': {'vbd_eq_vbn': ''},
 'rough-dried': {'vbd_eq_vbn': ''},
 'rough-hewed': {'vbd_eq_vbn': ''},
 'roughed': {'vbd_eq_vbn': ''},
 'roughened': {'vbd_eq_vbn': ''},
 'roughhoused': {'vbd_eq_vbn': ''},
 'rouletted': {'vbd_eq_vbn': ''},
 'rousted': {'vbd_eq_vbn': ''},
 'roved': {'vbd_eq_vbn': ''},
 'rubber-stamped': {'vbd_eq_vbn': ''},
 'rubberised': {'vbd_eq_vbn': ''},
 'rubbernecked': {'vbd_eq_vbn': ''},
 'rubbished': {'vbd_eq_vbn': ''},
 'rubricated': {'vbd_eq_vbn': ''},
 'rucked': {'vbd_eq_vbn': ''},
 'ruddled': {'vbd_eq_vbn': ''},
 'rued': {'vbd_eq_vbn': ''},
 'ruffed': {'vbd_eq_vbn': ''},
 'rumbled': {'vbd_eq_vbn': ''},
 'ruminated': {'vbd_eq_vbn': ''},
 'rummaged': {'vbd_eq_vbn': ''},
 'rumored': {'vbd_eq_vbn': ''},
 'rumoured': {'vbd_eq_vbn': ''},
 'ruptured': {'vbd_eq_vbn': ''},
 'rust-proofed': {'vbd_eq_vbn': ''},
 'rusted': {'vbd_eq_vbn': ''},
 'rusticated': {'vbd_eq_vbn': ''},
 'rustled': {'vbd_eq_vbn': ''},
 'sabotaged': {'vbd_eq_vbn': ''},
 'saccharified': {'vbd_eq_vbn': ''},
 'saccharised': {'vbd_eq_vbn': ''},
 'saccharized': {'vbd_eq_vbn': ''},
 'sacrificed': {'vbd_eq_vbn': ''},
 'saddened': {'vbd_eq_vbn': ''},
 'saddled': {'vbd_eq_vbn': ''},
 'safeguarded': {'vbd_eq_vbn': ''},
 'sagged': {'vbd_eq_vbn': ''},
 'sailplaned': {'vbd_eq_vbn': ''},
 'salaamed': {'vbd_eq_vbn': ''},
 'salivated': {'vbd_eq_vbn': ''},
 'sallied': {'vbd_eq_vbn': ''},
 'sallowed': {'vbd_eq_vbn': ''},
 'saltated': {'vbd_eq_vbn': ''},
 'saluted': {'vbd_eq_vbn': ''},
 'salvaged': {'vbd_eq_vbn': ''},
 'salved': {'vbd_eq_vbn': ''},
 'sambaed': {'vbd_eq_vbn': ''},
 'sammed': {'vbd_eq_vbn': ''},
 'sanctified': {'vbd_eq_vbn': ''},
 'sanctioned': {'vbd_eq_vbn': ''},
 'sandbagged': {'vbd_eq_vbn': ''},
 'sandblasted': {'vbd_eq_vbn': ''},
 'sandpapered': {'vbd_eq_vbn': ''},
 'sanitated': {'vbd_eq_vbn': ''},
 'sanitized': {'vbd_eq_vbn': ''},
 'saponified': {'vbd_eq_vbn': ''},
 'sapped': {'vbd_eq_vbn': ''},
 'sashayed': {'vbd_eq_vbn': ''},
 'sashed': {'vbd_eq_vbn': ''},
 'sassed': {'vbd_eq_vbn': ''},
 'satirised': {'vbd_eq_vbn': ''},
 'satirized': {'vbd_eq_vbn': ''},
 'satisficed': {'vbd_eq_vbn': ''},
 'sauntered': {'vbd_eq_vbn': ''},
 'sauteed': {'vbd_eq_vbn': ''},
 'savaged': {'vbd_eq_vbn': ''},
 'savored': {'vbd_eq_vbn': ''},
 'savoured': {'vbd_eq_vbn': ''},
 'savvied': {'vbd_eq_vbn': ''},
 'sawed': {'vbd_eq_vbn': ''},
 'scabbed': {'vbd_eq_vbn': ''},
 'scaffolded': {'vbd_eq_vbn': ''},
 'scalded': {'vbd_eq_vbn': ''},
 'scalped': {'vbd_eq_vbn': ''},
 'scammed': {'vbd_eq_vbn': ''},
 'scamped': {'vbd_eq_vbn': ''},
 'scampered': {'vbd_eq_vbn': ''},
 'scandalised': {'vbd_eq_vbn': ''},
 'scandalized': {'vbd_eq_vbn': ''},
 'scanned': {'vbd_eq_vbn': ''},
 'scanted': {'vbd_eq_vbn': ''},
 'scapegoated': {'vbd_eq_vbn': ''},
 'scarfed': {'vbd_eq_vbn': ''},
 'scarified': {'vbd_eq_vbn': ''},
 'scarped': {'vbd_eq_vbn': ''},
 'scarpered': {'vbd_eq_vbn': ''},
 'scarred': {'vbd_eq_vbn': ''},
 'scathed': {'vbd_eq_vbn': ''},
 'scatted': {'vbd_eq_vbn': ''},
 'scavenged': {'vbd_eq_vbn': ''},
 'scended': {'vbd_eq_vbn': ''},
 'schematised': {'vbd_eq_vbn': ''},
 'schematized': {'vbd_eq_vbn': ''},
 'schlepped': {'vbd_eq_vbn': ''},
 'Schmalzried': {'vbd_eq_vbn': ''},
 'schmoozed': {'vbd_eq_vbn': ''},
 'scintillated': {'vbd_eq_vbn': ''},
 'scissored': {'vbd_eq_vbn': ''},
 'scoffed': {'vbd_eq_vbn': ''},
 'scolded': {'vbd_eq_vbn': ''},
 'scolloped': {'vbd_eq_vbn': ''},
 'scooped': {'vbd_eq_vbn': ''},
 'scooted': {'vbd_eq_vbn': ''},
 'scoped': {'vbd_eq_vbn': ''},
 'scorned': {'vbd_eq_vbn': ''},
 'scotched': {'vbd_eq_vbn': ''},
 'scoured': {'vbd_eq_vbn': ''},
 'scourged': {'vbd_eq_vbn': ''},
 'scouted': {'vbd_eq_vbn': ''},
 'scowled': {'vbd_eq_vbn': ''},
 'scrabbled': {'vbd_eq_vbn': ''},
 'scragged': {'vbd_eq_vbn': ''},
 'scrambled': {'vbd_eq_vbn': ''},
 'scrammed': {'vbd_eq_vbn': ''},
 'scraped': {'vbd_eq_vbn': ''},
 'scrapped': {'vbd_eq_vbn': ''},
 'scrawled': {'vbd_eq_vbn': ''},
 'screeched': {'vbd_eq_vbn': ''},
 'Screwed': {'vbd_eq_vbn': ''},
 'scribbled': {'vbd_eq_vbn': ''},
 'scribed': {'vbd_eq_vbn': ''},
 'scried': {'vbd_eq_vbn': ''},
 'scrimmaged': {'vbd_eq_vbn': ''},
 'scrimped': {'vbd_eq_vbn': ''},
 'scrolled': {'vbd_eq_vbn': ''},
 'scrounged': {'vbd_eq_vbn': ''},
 'scrubbed': {'vbd_eq_vbn': ''},
 'scrummed': {'vbd_eq_vbn': ''},
 'scrunched': {'vbd_eq_vbn': ''},
 'scrupled': {'vbd_eq_vbn': ''},
 'scrutinised': {'vbd_eq_vbn': ''},
 'scrutinized': {'vbd_eq_vbn': ''},
 'scudded': {'vbd_eq_vbn': ''},
 'scuffed': {'vbd_eq_vbn': ''},
 'scuffled': {'vbd_eq_vbn': ''},
 'sculled': {'vbd_eq_vbn': ''},
 'scummed': {'vbd_eq_vbn': ''},
 'scuppered': {'vbd_eq_vbn': ''},
 'scurried': {'vbd_eq_vbn': ''},
 'scuttled': {'vbd_eq_vbn': ''},
 'scythed': {'vbd_eq_vbn': ''},
 'seared': {'vbd_eq_vbn': ''},
 'seceded': {'vbd_eq_vbn': ''},
 'second-guessed': {'vbd_eq_vbn': ''},
 'secreted': {'vbd_eq_vbn': ''},
 'sectionalised': {'vbd_eq_vbn': ''},
 'sectionalized': {'vbd_eq_vbn': ''},
 'secularised': {'vbd_eq_vbn': ''},
 'secularized': {'vbd_eq_vbn': ''},
 'sedated': {'vbd_eq_vbn': ''},
 'seduced': {'vbd_eq_vbn': ''},
 'see-sawed': {'vbd_eq_vbn': ''},
 'seeled': {'vbd_eq_vbn': ''},
 'seeped': {'vbd_eq_vbn': ''},
 'seesawed': {'vbd_eq_vbn': ''},
 'seethed': {'vbd_eq_vbn': ''},
 'segued': {'vbd_eq_vbn': ''},
 'seined': {'vbd_eq_vbn': ''},
 'self-dealed': {'vbd_eq_vbn': ''},
 'self-destructed': {'vbd_eq_vbn': ''},
 'self-identified': {'vbd_eq_vbn': ''},
 'sellotaped': {'vbd_eq_vbn': ''},
 'semaphored': {'vbd_eq_vbn': ''},
 'sensationalised': {'vbd_eq_vbn': ''},
 'sensationalized': {'vbd_eq_vbn': ''},
 'sensitised': {'vbd_eq_vbn': ''},
 'sensitized': {'vbd_eq_vbn': ''},
 'sentimentalised': {'vbd_eq_vbn': ''},
 'sentimentalized': {'vbd_eq_vbn': ''},
 'sentineled': {'vbd_eq_vbn': ''},
 'sentinelled': {'vbd_eq_vbn': ''},
 'sepulchered': {'vbd_eq_vbn': ''},
 'sepulchred': {'vbd_eq_vbn': ''},
 'sequestrated': {'vbd_eq_vbn': ''},
 'serenaded': {'vbd_eq_vbn': ''},
 'serialised': {'vbd_eq_vbn': ''},
 'serialized': {'vbd_eq_vbn': ''},
 'sermonised': {'vbd_eq_vbn': ''},
 'sermonized': {'vbd_eq_vbn': ''},
 'severed': {'vbd_eq_vbn': ''},
 'sexed': {'vbd_eq_vbn': ''},
 'sexted': {'vbd_eq_vbn': ''},
 'sextupled': {'vbd_eq_vbn': ''},
 'sexualised': {'vbd_eq_vbn': ''},
 'sexualized': {'vbd_eq_vbn': ''},
 'shacked': {'vbd_eq_vbn': ''},
 'shackled': {'vbd_eq_vbn': ''},
 'shaded': {'vbd_eq_vbn': ''},
 'shadow-boxed': {'vbd_eq_vbn': ''},
 'shafted': {'vbd_eq_vbn': ''},
 'shallowed': {'vbd_eq_vbn': ''},
 'shambled': {'vbd_eq_vbn': ''},
 'shammed': {'vbd_eq_vbn': ''},
 'shampooed': {'vbd_eq_vbn': ''},
 'shanghaied': {'vbd_eq_vbn': ''},
 'shape-shifted': {'vbd_eq_vbn': ''},
 'shapeshifted': {'vbd_eq_vbn': ''},
 'sharecropped': {'vbd_eq_vbn': ''},
 'sharped': {'vbd_eq_vbn': ''},
 'sharpened': {'vbd_eq_vbn': ''},
 'shat': {'vbd_eq_vbn': ''},
 'sheafed': {'vbd_eq_vbn': ''},
 'sheared': {'vbd_eq_vbn': ''},
 'sheathed': {'vbd_eq_vbn': ''},
 'sheered': {'vbd_eq_vbn': ''},
 'sheeted': {'vbd_eq_vbn': ''},
 'shellacked': {'vbd_eq_vbn': ''},
 'shelved': {'vbd_eq_vbn': ''},
 'shepherded': {'vbd_eq_vbn': ''},
 'shewed': {'vbd_eq_vbn': ''},
 'shied': {'vbd_eq_vbn': ''},
 'shielded': {'vbd_eq_vbn': ''},
 'shilled': {'vbd_eq_vbn': ''},
 'shilly-shallied': {'vbd_eq_vbn': ''},
 'shillyshallied': {'vbd_eq_vbn': ''},
 'shimmed': {'vbd_eq_vbn': ''},
 'shimmered': {'vbd_eq_vbn': ''},
 'shimmied': {'vbd_eq_vbn': ''},
 'shined': {'vbd_eq_vbn': ''},
 'shingled': {'vbd_eq_vbn': ''},
 'shinned': {'vbd_eq_vbn': ''},
 'shinnied': {'vbd_eq_vbn': ''},
 'shirked': {'vbd_eq_vbn': ''},
 'shirred': {'vbd_eq_vbn': ''},
 'shitted': {'vbd_eq_vbn': ''},
 'shivered': {'vbd_eq_vbn': ''},
 'shoaled': {'vbd_eq_vbn': ''},
 'shod': {'vbd_eq_vbn': ''},
 'shoehorned': {'vbd_eq_vbn': ''},
 'shooed': {'vbd_eq_vbn': ''},
 'shoplifted': {'vbd_eq_vbn': ''},
 'shored': {'vbd_eq_vbn': ''},
 'short-changed': {'vbd_eq_vbn': ''},
 'short-circuited': {'vbd_eq_vbn': ''},
 'short-listed': {'vbd_eq_vbn': ''},
 'shorted': {'vbd_eq_vbn': ''},
 'shortened': {'vbd_eq_vbn': ''},
 'shortlisted': {'vbd_eq_vbn': ''},
 'shoveled': {'vbd_eq_vbn': ''},
 'shovelled': {'vbd_eq_vbn': ''},
 'showcased': {'vbd_eq_vbn': ''},
 'shredded': {'vbd_eq_vbn': ''},
 'shrieked': {'vbd_eq_vbn': ''},
 'shrilled': {'vbd_eq_vbn': ''},
 'shrimped': {'vbd_eq_vbn': ''},
 'shrined': {'vbd_eq_vbn': ''},
 'shrived': {'vbd_eq_vbn': ''},
 'shriveled': {'vbd_eq_vbn': ''},
 'shrivelled': {'vbd_eq_vbn': ''},
 'shrouded': {'vbd_eq_vbn': ''},
 'Shrugged': {'vbd_eq_vbn': ''},
 'shrunk': {'vbd_eq_vbn': ''},
 'shucked': {'vbd_eq_vbn': ''},
 'shuddered': {'vbd_eq_vbn': ''},
 'shuffled': {'vbd_eq_vbn': ''},
 'shunned': {'vbd_eq_vbn': ''},
 'shunted': {'vbd_eq_vbn': ''},
 'shushed': {'vbd_eq_vbn': ''},
 'shuttered': {'vbd_eq_vbn': ''},
 'shuttlecocked': {'vbd_eq_vbn': ''},
 'shuttled': {'vbd_eq_vbn': ''},
 'sicced': {'vbd_eq_vbn': ''},
 'sicked': {'vbd_eq_vbn': ''},
 'sickened': {'vbd_eq_vbn': ''},
 'side-slipped': {'vbd_eq_vbn': ''},
 'side-stepped': {'vbd_eq_vbn': ''},
 'side-tracked': {'vbd_eq_vbn': ''},
 'sided': {'vbd_eq_vbn': ''},
 'sidelined': {'vbd_eq_vbn': ''},
 'sidestepped': {'vbd_eq_vbn': ''},
 'sideswiped': {'vbd_eq_vbn': ''},
 'sidetracked': {'vbd_eq_vbn': ''},
 'sidled': {'vbd_eq_vbn': ''},
 'sieged': {'vbd_eq_vbn': ''},
 'Siegfried': {'vbd_eq_vbn': ''},
 'sieved': {'vbd_eq_vbn': ''},
 'sifted': {'vbd_eq_vbn': ''},
 'sighed': {'vbd_eq_vbn': ''},
 'sight-read': {'vbd_eq_vbn': ''},
 'signalised': {'vbd_eq_vbn': ''},
 'signalized': {'vbd_eq_vbn': ''},
 'signalled': {'vbd_eq_vbn': ''},
 'signeted': {'vbd_eq_vbn': ''},
 'signified': {'vbd_eq_vbn': ''},
 'signposted': {'vbd_eq_vbn': ''},
 'silenced': {'vbd_eq_vbn': ''},
 'silked': {'vbd_eq_vbn': ''},
 'silted': {'vbd_eq_vbn': ''},
 'simmered': {'vbd_eq_vbn': ''},
 'simpered': {'vbd_eq_vbn': ''},
 'simplified': {'vbd_eq_vbn': ''},
 'simulcast': {'vbd_eq_vbn': ''},
 'singed': {'vbd_eq_vbn': ''},
 'single-footed': {'vbd_eq_vbn': ''},
 'singled': {'vbd_eq_vbn': ''},
 'singularised': {'vbd_eq_vbn': ''},
 'singularized': {'vbd_eq_vbn': ''},
 'sintered': {'vbd_eq_vbn': ''},
 'siphoned': {'vbd_eq_vbn': ''},
 'sipped': {'vbd_eq_vbn': ''},
 'sired': {'vbd_eq_vbn': ''},
 'sizzled': {'vbd_eq_vbn': ''},
 'skateboarded': {'vbd_eq_vbn': ''},
 'skated': {'vbd_eq_vbn': ''},
 'skedaddled': {'vbd_eq_vbn': ''},
 'sketched': {'vbd_eq_vbn': ''},
 'skewed': {'vbd_eq_vbn': ''},
 'skewered': {'vbd_eq_vbn': ''},
 'skidded': {'vbd_eq_vbn': ''},
 'skied': {'vbd_eq_vbn': ''},
 'skimmed': {'vbd_eq_vbn': ''},
 'skimped': {'vbd_eq_vbn': ''},
 'skinny-dipped': {'vbd_eq_vbn': ''},
 'skipped': {'vbd_eq_vbn': ''},
 'skippered': {'vbd_eq_vbn': ''},
 'skirled': {'vbd_eq_vbn': ''},
 'skirmished': {'vbd_eq_vbn': ''},
 'skittered': {'vbd_eq_vbn': ''},
 'skittled': {'vbd_eq_vbn': ''},
 'skived': {'vbd_eq_vbn': ''},
 'skivvied': {'vbd_eq_vbn': ''},
 'skulked': {'vbd_eq_vbn': ''},
 'skunked': {'vbd_eq_vbn': ''},
 'sky-rocketed': {'vbd_eq_vbn': ''},
 'skyjacked': {'vbd_eq_vbn': ''},
 'skylarked': {'vbd_eq_vbn': ''},
 'skyrocketed': {'vbd_eq_vbn': ''},
 'slacked': {'vbd_eq_vbn': ''},
 'slackened': {'vbd_eq_vbn': ''},
 'slagged': {'vbd_eq_vbn': ''},
 'slaked': {'vbd_eq_vbn': ''},
 'slam-dunked': {'vbd_eq_vbn': ''},
 'slammed': {'vbd_eq_vbn': ''},
 'slandered': {'vbd_eq_vbn': ''},
 'slanged': {'vbd_eq_vbn': ''},
 'slapped': {'vbd_eq_vbn': ''},
 'slashed': {'vbd_eq_vbn': ''},
 'slated': {'vbd_eq_vbn': ''},
 'slathered': {'vbd_eq_vbn': ''},
 'slaved': {'vbd_eq_vbn': ''},
 'slavered': {'vbd_eq_vbn': ''},
 'sledded': {'vbd_eq_vbn': ''},
 'sledge-hammered': {'vbd_eq_vbn': ''},
 'sledged': {'vbd_eq_vbn': ''},
 'sledgehammered': {'vbd_eq_vbn': ''},
 'sleeked': {'vbd_eq_vbn': ''},
 'sleepwalked': {'vbd_eq_vbn': ''},
 'sleeted': {'vbd_eq_vbn': ''},
 'sleighed': {'vbd_eq_vbn': ''},
 'sleuthed': {'vbd_eq_vbn': ''},
 'slewed': {'vbd_eq_vbn': ''},
 'sliced': {'vbd_eq_vbn': ''},
 'slicked': {'vbd_eq_vbn': ''},
 'slid': {'vbd_eq_vbn': ''},
 'slighted': {'vbd_eq_vbn': ''},
 'slimed': {'vbd_eq_vbn': ''},
 'slimmed': {'vbd_eq_vbn': ''},
 'slithered': {'vbd_eq_vbn': ''},
 'slivered': {'vbd_eq_vbn': ''},
 'slobbed': {'vbd_eq_vbn': ''},
 'slobbered': {'vbd_eq_vbn': ''},
 'sloganeered': {'vbd_eq_vbn': ''},
 'slogged': {'vbd_eq_vbn': ''},
 'slopped': {'vbd_eq_vbn': ''},
 'slotted': {'vbd_eq_vbn': ''},
 'slouched': {'vbd_eq_vbn': ''},
 'sloughed': {'vbd_eq_vbn': ''},
 'slubbed': {'vbd_eq_vbn': ''},
 'slugged': {'vbd_eq_vbn': ''},
 'sluiced': {'vbd_eq_vbn': ''},
 'slumbered': {'vbd_eq_vbn': ''},
 'slummed': {'vbd_eq_vbn': ''},
 'slumped': {'vbd_eq_vbn': ''},
 'slung': {'vbd_eq_vbn': ''},
 'slunk': {'vbd_eq_vbn': ''},
 'slurped': {'vbd_eq_vbn': ''},
 'slurred': {'vbd_eq_vbn': ''},
 'slushed': {'vbd_eq_vbn': ''},
 'smacked': {'vbd_eq_vbn': ''},
 'smarted': {'vbd_eq_vbn': ''},
 'smartened': {'vbd_eq_vbn': ''},
 'smattered': {'vbd_eq_vbn': ''},
 'smeared': {'vbd_eq_vbn': ''},
 'smelled': {'vbd_eq_vbn': ''},
 'smelted': {'vbd_eq_vbn': ''},
 'smirched': {'vbd_eq_vbn': ''},
 'smirked': {'vbd_eq_vbn': ''},
 'smoldered': {'vbd_eq_vbn': ''},
 'smooched': {'vbd_eq_vbn': ''},
 'smooth-talked': {'vbd_eq_vbn': ''},
 'smoothened': {'vbd_eq_vbn': ''},
 'smothered': {'vbd_eq_vbn': ''},
 'smouldered': {'vbd_eq_vbn': ''},
 'smudged': {'vbd_eq_vbn': ''},
 'smuggled': {'vbd_eq_vbn': ''},
 'smutted': {'vbd_eq_vbn': ''},
 'snacked': {'vbd_eq_vbn': ''},
 'snaffled': {'vbd_eq_vbn': ''},
 'snafued': {'vbd_eq_vbn': ''},
 'snagged': {'vbd_eq_vbn': ''},
 'snaked': {'vbd_eq_vbn': ''},
 'snapped': {'vbd_eq_vbn': ''},
 'snared': {'vbd_eq_vbn': ''},
 'snarfed': {'vbd_eq_vbn': ''},
 'snarled': {'vbd_eq_vbn': ''},
 'snatched': {'vbd_eq_vbn': ''},
 'sneaked': {'vbd_eq_vbn': ''},
 'sneered': {'vbd_eq_vbn': ''},
 'sneezed': {'vbd_eq_vbn': ''},
 'snicked': {'vbd_eq_vbn': ''},
 'snickered': {'vbd_eq_vbn': ''},
 'sniffed': {'vbd_eq_vbn': ''},
 'sniffled': {'vbd_eq_vbn': ''},
 'sniggered': {'vbd_eq_vbn': ''},
 'sniped': {'vbd_eq_vbn': ''},
 'snipped': {'vbd_eq_vbn': ''},
 'snitched': {'vbd_eq_vbn': ''},
 'sniveled': {'vbd_eq_vbn': ''},
 'snivelled': {'vbd_eq_vbn': ''},
 'snogged': {'vbd_eq_vbn': ''},
 'snookered': {'vbd_eq_vbn': ''},
 'snooped': {'vbd_eq_vbn': ''},
 'snoozed': {'vbd_eq_vbn': ''},
 'snored': {'vbd_eq_vbn': ''},
 'snorkeled': {'vbd_eq_vbn': ''},
 'snorkelled': {'vbd_eq_vbn': ''},
 'snorted': {'vbd_eq_vbn': ''},
 'snowballed': {'vbd_eq_vbn': ''},
 'snowed': {'vbd_eq_vbn': ''},
 'snubbed': {'vbd_eq_vbn': ''},
 'snuck': {'vbd_eq_vbn': ''},
 'snuffed': {'vbd_eq_vbn': ''},
 'snuffled': {'vbd_eq_vbn': ''},
 'snugged': {'vbd_eq_vbn': ''},
 'snuggled': {'vbd_eq_vbn': ''},
 'soaped': {'vbd_eq_vbn': ''},
 'soared': {'vbd_eq_vbn': ''},
 'sobbed': {'vbd_eq_vbn': ''},
 'sobered': {'vbd_eq_vbn': ''},
 'socialised': {'vbd_eq_vbn': ''},
 'socialized': {'vbd_eq_vbn': ''},
 'socked': {'vbd_eq_vbn': ''},
 'socketed': {'vbd_eq_vbn': ''},
 'sodded': {'vbd_eq_vbn': ''},
 'soddened': {'vbd_eq_vbn': ''},
 'soft-pedaled': {'vbd_eq_vbn': ''},
 'soft-pedalled': {'vbd_eq_vbn': ''},
 'soft-soaped': {'vbd_eq_vbn': ''},
 'sojourned': {'vbd_eq_vbn': ''},
 'solaced': {'vbd_eq_vbn': ''},
 'soldered': {'vbd_eq_vbn': ''},
 'soldiered': {'vbd_eq_vbn': ''},
 'soled': {'vbd_eq_vbn': ''},
 'solemnised': {'vbd_eq_vbn': ''},
 'solemnized': {'vbd_eq_vbn': ''},
 'solicited': {'vbd_eq_vbn': ''},
 'soliloquised': {'vbd_eq_vbn': ''},
 'soliloquized': {'vbd_eq_vbn': ''},
 'soloed': {'vbd_eq_vbn': ''},
 'solvated': {'vbd_eq_vbn': ''},
 'somersaulted': {'vbd_eq_vbn': ''},
 'sooted': {'vbd_eq_vbn': ''},
 'soothed': {'vbd_eq_vbn': ''},
 'soothsaid': {'vbd_eq_vbn': ''},
 'sopped': {'vbd_eq_vbn': ''},
 'sorrowed': {'vbd_eq_vbn': ''},
 'sortied': {'vbd_eq_vbn': ''},
 'soughed': {'vbd_eq_vbn': ''},
 'sound-proofed': {'vbd_eq_vbn': ''},
 'soundproofed': {'vbd_eq_vbn': ''},
 'souped': {'vbd_eq_vbn': ''},
 'soured': {'vbd_eq_vbn': ''},
 'sovietised': {'vbd_eq_vbn': ''},
 'sovietized': {'vbd_eq_vbn': ''},
 'sowed': {'vbd_eq_vbn': ''},
 'Spaced': {'vbd_eq_vbn': ''},
 'spacewalked': {'vbd_eq_vbn': ''},
 'spackled': {'vbd_eq_vbn': ''},
 'spammed': {'vbd_eq_vbn': ''},
 'spangled': {'vbd_eq_vbn': ''},
 'spanked': {'vbd_eq_vbn': ''},
 'spanned': {'vbd_eq_vbn': ''},
 'sparged': {'vbd_eq_vbn': ''},
 'sparked': {'vbd_eq_vbn': ''},
 'sparkled': {'vbd_eq_vbn': ''},
 'sparred': {'vbd_eq_vbn': ''},
 'spatchcocked': {'vbd_eq_vbn': ''},
 'spatted': {'vbd_eq_vbn': ''},
 'spattered': {'vbd_eq_vbn': ''},
 'spawned': {'vbd_eq_vbn': ''},
 'spayed': {'vbd_eq_vbn': ''},
 'speared': {'vbd_eq_vbn': ''},
 'spearheaded': {'vbd_eq_vbn': ''},
 'specked': {'vbd_eq_vbn': ''},
 'spectated': {'vbd_eq_vbn': ''},
 'speculated': {'vbd_eq_vbn': ''},
 'sped': {'vbd_eq_vbn': ''},
 'speechified': {'vbd_eq_vbn': ''},
 'speeded': {'vbd_eq_vbn': ''},
 'spell-checked': {'vbd_eq_vbn': ''},
 'spellbound': {'vbd_eq_vbn': ''},
 'spelled': {'vbd_eq_vbn': ''},
 'spelunked': {'vbd_eq_vbn': ''},
 'spewed': {'vbd_eq_vbn': ''},
 'sphered': {'vbd_eq_vbn': ''},
 'spiced': {'vbd_eq_vbn': ''},
 'spidered': {'vbd_eq_vbn': ''},
 'spied': {'vbd_eq_vbn': ''},
 'spieled': {'vbd_eq_vbn': ''},
 'spiked': {'vbd_eq_vbn': ''},
 'spilled': {'vbd_eq_vbn': ''},
 'spilt': {'vbd_eq_vbn': ''},
 'spin-dried': {'vbd_eq_vbn': ''},
 'spindled': {'vbd_eq_vbn': ''},
 'spiraled': {'vbd_eq_vbn': ''},
 'spiralled': {'vbd_eq_vbn': ''},
 'spired': {'vbd_eq_vbn': ''},
 'spirted': {'vbd_eq_vbn': ''},
 'spited': {'vbd_eq_vbn': ''},
 'splashed': {'vbd_eq_vbn': ''},
 'splatted': {'vbd_eq_vbn': ''},
 'splattered': {'vbd_eq_vbn': ''},
 'splayed': {'vbd_eq_vbn': ''},
 'spliced': {'vbd_eq_vbn': ''},
 'splined': {'vbd_eq_vbn': ''},
 'splinted': {'vbd_eq_vbn': ''},
 'splintered': {'vbd_eq_vbn': ''},
 'splotched': {'vbd_eq_vbn': ''},
 'splurged': {'vbd_eq_vbn': ''},
 'spluttered': {'vbd_eq_vbn': ''},
 'spoilt': {'vbd_eq_vbn': ''},
 'spoked': {'vbd_eq_vbn': ''},
 'sponged': {'vbd_eq_vbn': ''},
 'sponsored': {'vbd_eq_vbn': ''},
 'spoofed': {'vbd_eq_vbn': ''},
 'spooked': {'vbd_eq_vbn': ''},
 'spooled': {'vbd_eq_vbn': ''},
 'spoon-fed': {'vbd_eq_vbn': ''},
 'spooned': {'vbd_eq_vbn': ''},
 'sported': {'vbd_eq_vbn': ''},
 'sporulated': {'vbd_eq_vbn': ''},
 'spot-checked': {'vbd_eq_vbn': ''},
 'spot-welded': {'vbd_eq_vbn': ''},
 'spotlighted': {'vbd_eq_vbn': ''},
 'spotlit': {'vbd_eq_vbn': ''},
 'spouted': {'vbd_eq_vbn': ''},
 'sprained': {'vbd_eq_vbn': ''},
 'spread-eagled': {'vbd_eq_vbn': ''},
 'spring-cleaned': {'vbd_eq_vbn': ''},
 'sprinkled': {'vbd_eq_vbn': ''},
 'sprinted': {'vbd_eq_vbn': ''},
 'spritzed': {'vbd_eq_vbn': ''},
 'sprouted': {'vbd_eq_vbn': ''},
 'spruced': {'vbd_eq_vbn': ''},
 'spurned': {'vbd_eq_vbn': ''},
 'spurred': {'vbd_eq_vbn': ''},
 'spurted': {'vbd_eq_vbn': ''},
 'sputtered': {'vbd_eq_vbn': ''},
 'squabbled': {'vbd_eq_vbn': ''},
 'squalled': {'vbd_eq_vbn': ''},
 'squandered': {'vbd_eq_vbn': ''},
 'squatted': {'vbd_eq_vbn': ''},
 'squawked': {'vbd_eq_vbn': ''},
 'squeaked': {'vbd_eq_vbn': ''},
 'squealed': {'vbd_eq_vbn': ''},
 'squeegeed': {'vbd_eq_vbn': ''},
 'squelched': {'vbd_eq_vbn': ''},
 'squibbed': {'vbd_eq_vbn': ''},
 'squinched': {'vbd_eq_vbn': ''},
 'squinted': {'vbd_eq_vbn': ''},
 'squired': {'vbd_eq_vbn': ''},
 'squirmed': {'vbd_eq_vbn': ''},
 'squirreled': {'vbd_eq_vbn': ''},
 'squirrelled': {'vbd_eq_vbn': ''},
 'squirted': {'vbd_eq_vbn': ''},
 'squished': {'vbd_eq_vbn': ''},
 'stabbed': {'vbd_eq_vbn': ''},
 'stabled': {'vbd_eq_vbn': ''},
 'staffed': {'vbd_eq_vbn': ''},
 'stage-managed': {'vbd_eq_vbn': ''},
 'Staged': {'vbd_eq_vbn': ''},
 'stagged': {'vbd_eq_vbn': ''},
 'stagnated': {'vbd_eq_vbn': ''},
 'staked': {'vbd_eq_vbn': ''},
 'staled': {'vbd_eq_vbn': ''},
 'stalemated': {'vbd_eq_vbn': ''},
 'stalked': {'vbd_eq_vbn': ''},
 'stall-fed': {'vbd_eq_vbn': ''},
 'stalled': {'vbd_eq_vbn': ''},
 'stammered': {'vbd_eq_vbn': ''},
 'stampeded': {'vbd_eq_vbn': ''},
 'stanched': {'vbd_eq_vbn': ''},
 'standardised': {'vbd_eq_vbn': ''},
 'standardized': {'vbd_eq_vbn': ''},
 'stapled': {'vbd_eq_vbn': ''},
 'starched': {'vbd_eq_vbn': ''},
 'stargazed': {'vbd_eq_vbn': ''},
 'stashed': {'vbd_eq_vbn': ''},
 'statemented': {'vbd_eq_vbn': ''},
 'stationed': {'vbd_eq_vbn': ''},
 'staunched': {'vbd_eq_vbn': ''},
 'staved': {'vbd_eq_vbn': ''},
 'steadied': {'vbd_eq_vbn': ''},
 'steamrollered': {'vbd_eq_vbn': ''},
 'steeled': {'vbd_eq_vbn': ''},
 'steeped': {'vbd_eq_vbn': ''},
 'steepened': {'vbd_eq_vbn': ''},
 'stenciled': {'vbd_eq_vbn': ''},
 'stencilled': {'vbd_eq_vbn': ''},
 'stept': {'vbd_eq_vbn': ''},
 'sterilised': {'vbd_eq_vbn': ''},
 'sterilized': {'vbd_eq_vbn': ''},
 'stetted': {'vbd_eq_vbn': ''},
 'stevedored': {'vbd_eq_vbn': ''},
 'stewarded': {'vbd_eq_vbn': ''},
 'stickled': {'vbd_eq_vbn': ''},
 'stiffed': {'vbd_eq_vbn': ''},
 'stifled': {'vbd_eq_vbn': ''},
 'stigmatised': {'vbd_eq_vbn': ''},
 'stigmatized': {'vbd_eq_vbn': ''},
 'stilled': {'vbd_eq_vbn': ''},
 'stimmed': {'vbd_eq_vbn': ''},
 'stinted': {'vbd_eq_vbn': ''},
 'stipulated': {'vbd_eq_vbn': ''},
 'stir-fried': {'vbd_eq_vbn': ''},
 'stitched': {'vbd_eq_vbn': ''},
 'stockaded': {'vbd_eq_vbn': ''},
 'stocked': {'vbd_eq_vbn': ''},
 'stockpiled': {'vbd_eq_vbn': ''},
 'stomached': {'vbd_eq_vbn': ''},
 'stomped': {'vbd_eq_vbn': ''},
 'stonewalled': {'vbd_eq_vbn': ''},
 'stooled': {'vbd_eq_vbn': ''},
 'stoped': {'vbd_eq_vbn': ''},
 'stoppered': {'vbd_eq_vbn': ''},
 'stormed': {'vbd_eq_vbn': ''},
 'stowed': {'vbd_eq_vbn': ''},
 'straddled': {'vbd_eq_vbn': ''},
 'strafed': {'vbd_eq_vbn': ''},
 'straggled': {'vbd_eq_vbn': ''},
 'straight-armed': {'vbd_eq_vbn': ''},
 'straightened': {'vbd_eq_vbn': ''},
 'strategised': {'vbd_eq_vbn': ''},
 'strategized': {'vbd_eq_vbn': ''},
 'strayed': {'vbd_eq_vbn': ''},
 'streaked': {'vbd_eq_vbn': ''},
 'streamed': {'vbd_eq_vbn': ''},
 'stretchered': {'vbd_eq_vbn': ''},
 'strewed': {'vbd_eq_vbn': ''},
 'strickled': {'vbd_eq_vbn': ''},
 'stridulated': {'vbd_eq_vbn': ''},
 'strip-mined': {'vbd_eq_vbn': ''},
 'strip-searched': {'vbd_eq_vbn': ''},
 'stroked': {'vbd_eq_vbn': ''},
 'strolled': {'vbd_eq_vbn': ''},
 'strong-armed': {'vbd_eq_vbn': ''},
 'stropped': {'vbd_eq_vbn': ''},
 'strummed': {'vbd_eq_vbn': ''},
 'strung': {'vbd_eq_vbn': ''},
 'strutted': {'vbd_eq_vbn': ''},
 'stubbed': {'vbd_eq_vbn': ''},
 'stuccoed': {'vbd_eq_vbn': ''},
 'stultified': {'vbd_eq_vbn': ''},
 'stumbled': {'vbd_eq_vbn': ''},
 'stung': {'vbd_eq_vbn': ''},
 'stuttered': {'vbd_eq_vbn': ''},
 'styled': {'vbd_eq_vbn': ''},
 'stymied': {'vbd_eq_vbn': ''},
 'subbed': {'vbd_eq_vbn': ''},
 'subcontracted': {'vbd_eq_vbn': ''},
 'subdivided': {'vbd_eq_vbn': ''},
 'subedited': {'vbd_eq_vbn': ''},
 'subjected': {'vbd_eq_vbn': ''},
 'subjugated': {'vbd_eq_vbn': ''},
 'subleased': {'vbd_eq_vbn': ''},
 'sublimated': {'vbd_eq_vbn': ''},
 'sublimed': {'vbd_eq_vbn': ''},
 'submarined': {'vbd_eq_vbn': ''},
 'submersed': {'vbd_eq_vbn': ''},
 'subordinated': {'vbd_eq_vbn': ''},
 'suborned': {'vbd_eq_vbn': ''},
 'subpoenaed': {'vbd_eq_vbn': ''},
 'subscribed': {'vbd_eq_vbn': ''},
 'subsided': {'vbd_eq_vbn': ''},
 'subsisted': {'vbd_eq_vbn': ''},
 'subsoiled': {'vbd_eq_vbn': ''},
 'substantiated': {'vbd_eq_vbn': ''},
 'substituted': {'vbd_eq_vbn': ''},
 'subsumed': {'vbd_eq_vbn': ''},
 'subtended': {'vbd_eq_vbn': ''},
 'subtracted': {'vbd_eq_vbn': ''},
 'subtweeted': {'vbd_eq_vbn': ''},
 'suburbanised': {'vbd_eq_vbn': ''},
 'suburbanized': {'vbd_eq_vbn': ''},
 'subverted': {'vbd_eq_vbn': ''},
 'succored': {'vbd_eq_vbn': ''},
 'succoured': {'vbd_eq_vbn': ''},
 'succumbed': {'vbd_eq_vbn': ''},
 'suckered': {'vbd_eq_vbn': ''},
 'suckled': {'vbd_eq_vbn': ''},
 'suctioned': {'vbd_eq_vbn': ''},
 'sued': {'vbd_eq_vbn': ''},
 'sufficed': {'vbd_eq_vbn': ''},
 'suffixed': {'vbd_eq_vbn': ''},
 'suffused': {'vbd_eq_vbn': ''},
 'sulfated': {'vbd_eq_vbn': ''},
 'sulfured': {'vbd_eq_vbn': ''},
 'sulfureted': {'vbd_eq_vbn': ''},
 'sulfuretted': {'vbd_eq_vbn': ''},
 'sulfurized': {'vbd_eq_vbn': ''},
 'sulked': {'vbd_eq_vbn': ''},
 'sullied': {'vbd_eq_vbn': ''},
 'sulphated': {'vbd_eq_vbn': ''},
 'summarised': {'vbd_eq_vbn': ''},
 'summarized': {'vbd_eq_vbn': ''},
 'summated': {'vbd_eq_vbn': ''},
 'summed': {'vbd_eq_vbn': ''},
 'summered': {'vbd_eq_vbn': ''},
 'summoned': {'vbd_eq_vbn': ''},
 'summonsed': {'vbd_eq_vbn': ''},
 'sunbathed': {'vbd_eq_vbn': ''},
 'sunburnt': {'vbd_eq_vbn': ''},
 'sundered': {'vbd_eq_vbn': ''},
 'sunned': {'vbd_eq_vbn': ''},
 'superabounded': {'vbd_eq_vbn': ''},
 'superadded': {'vbd_eq_vbn': ''},
 'supercalendered': {'vbd_eq_vbn': ''},
 'superceded': {'vbd_eq_vbn': ''},
 'superclassed': {'vbd_eq_vbn': ''},
 'supercoiled': {'vbd_eq_vbn': ''},
 'superconducted': {'vbd_eq_vbn': ''},
 'supercooled': {'vbd_eq_vbn': ''},
 'supered': {'vbd_eq_vbn': ''},
 'superelevated': {'vbd_eq_vbn': ''},
 'supererogated': {'vbd_eq_vbn': ''},
 'superexalted': {'vbd_eq_vbn': ''},
 'superfetated': {'vbd_eq_vbn': ''},
 'superficialised': {'vbd_eq_vbn': ''},
 'superficialized': {'vbd_eq_vbn': ''},
 'superfixed': {'vbd_eq_vbn': ''},
 'superfused': {'vbd_eq_vbn': ''},
 'superglued': {'vbd_eq_vbn': ''},
 'superhardened': {'vbd_eq_vbn': ''},
 'superheated': {'vbd_eq_vbn': ''},
 'superhumanised': {'vbd_eq_vbn': ''},
 'superhumanized': {'vbd_eq_vbn': ''},
 'superimposed': {'vbd_eq_vbn': ''},
 'superinduced': {'vbd_eq_vbn': ''},
 'superinfected': {'vbd_eq_vbn': ''},
 'superintended': {'vbd_eq_vbn': ''},
 'supernaturalised': {'vbd_eq_vbn': ''},
 'supernaturalized': {'vbd_eq_vbn': ''},
 'superordinated': {'vbd_eq_vbn': ''},
 'superovulated': {'vbd_eq_vbn': ''},
 'superposed': {'vbd_eq_vbn': ''},
 'superrefined': {'vbd_eq_vbn': ''},
 'superscribed': {'vbd_eq_vbn': ''},
 'superseded': {'vbd_eq_vbn': ''},
 'supersized': {'vbd_eq_vbn': ''},
 'supersold': {'vbd_eq_vbn': ''},
 'superstimulated': {'vbd_eq_vbn': ''},
 'superstrated': {'vbd_eq_vbn': ''},
 'superstructed': {'vbd_eq_vbn': ''},
 'supervened': {'vbd_eq_vbn': ''},
 'supervised': {'vbd_eq_vbn': ''},
 'supped': {'vbd_eq_vbn': ''},
 'supplanted': {'vbd_eq_vbn': ''},
 'supplemented': {'vbd_eq_vbn': ''},
 'supplicated': {'vbd_eq_vbn': ''},
 'suppressed': {'vbd_eq_vbn': ''},
 'suppurated': {'vbd_eq_vbn': ''},
 'surcharged': {'vbd_eq_vbn': ''},
 'surfed': {'vbd_eq_vbn': ''},
 'surfeited': {'vbd_eq_vbn': ''},
 'surged': {'vbd_eq_vbn': ''},
 'surmised': {'vbd_eq_vbn': ''},
 'surmounted': {'vbd_eq_vbn': ''},
 'surnamed': {'vbd_eq_vbn': ''},
 'surpassed': {'vbd_eq_vbn': ''},
 'surrendered': {'vbd_eq_vbn': ''},
 'surrogated': {'vbd_eq_vbn': ''},
 'surveilled': {'vbd_eq_vbn': ''},
 'surveyed': {'vbd_eq_vbn': ''},
 'susurrated': {'vbd_eq_vbn': ''},
 'sutured': {'vbd_eq_vbn': ''},
 'swabbed': {'vbd_eq_vbn': ''},
 'swaddled': {'vbd_eq_vbn': ''},
 'swaged': {'vbd_eq_vbn': ''},
 'swaggered': {'vbd_eq_vbn': ''},
 'swallowed': {'vbd_eq_vbn': ''},
 'swamped': {'vbd_eq_vbn': ''},
 'swanked': {'vbd_eq_vbn': ''},
 'swanned': {'vbd_eq_vbn': ''},
 'swarmed': {'vbd_eq_vbn': ''},
 'swathed': {'vbd_eq_vbn': ''},
 'swatted': {'vbd_eq_vbn': ''},
 'swayed': {'vbd_eq_vbn': ''},
 'sweet-talked': {'vbd_eq_vbn': ''},
 'sweetened': {'vbd_eq_vbn': ''},
 'swelled': {'vbd_eq_vbn': ''},
 'sweltered': {'vbd_eq_vbn': ''},
 'swerved': {'vbd_eq_vbn': ''},
 'swigged': {'vbd_eq_vbn': ''},
 'swilled': {'vbd_eq_vbn': ''},
 'swindled': {'vbd_eq_vbn': ''},
 'swinged': {'vbd_eq_vbn': ''},
 'swiped': {'vbd_eq_vbn': ''},
 'swirled': {'vbd_eq_vbn': ''},
 'swished': {'vbd_eq_vbn': ''},
 'swiveled': {'vbd_eq_vbn': ''},
 'swivelled': {'vbd_eq_vbn': ''},
 'swobbed': {'vbd_eq_vbn': ''},
 'swooned': {'vbd_eq_vbn': ''},
 'swooped': {'vbd_eq_vbn': ''},
 'swooshed': {'vbd_eq_vbn': ''},
 'swotted': {'vbd_eq_vbn': ''},
 'Syed': {'vbd_eq_vbn': ''},
 'syllabified': {'vbd_eq_vbn': ''},
 'syllabled': {'vbd_eq_vbn': ''},
 'symbolised': {'vbd_eq_vbn': ''},
 'symbolized': {'vbd_eq_vbn': ''},
 'sympathised': {'vbd_eq_vbn': ''},
 'sympathized': {'vbd_eq_vbn': ''},
 'synced': {'vbd_eq_vbn': ''},
 'synched': {'vbd_eq_vbn': ''},
 'synchronised': {'vbd_eq_vbn': ''},
 'synchronized': {'vbd_eq_vbn': ''},
 'syndicated': {'vbd_eq_vbn': ''},
 'synthesised': {'vbd_eq_vbn': ''},
 'synthesized': {'vbd_eq_vbn': ''},
 'syphoned': {'vbd_eq_vbn': ''},
 'syringed': {'vbd_eq_vbn': ''},
 'systematised': {'vbd_eq_vbn': ''},
 'systematized': {'vbd_eq_vbn': ''},
 'tabbed': {'vbd_eq_vbn': ''},
 'tabled': {'vbd_eq_vbn': ''},
 'tabooed': {'vbd_eq_vbn': ''},
 'tabued': {'vbd_eq_vbn': ''},
 'tabulated': {'vbd_eq_vbn': ''},
 'tacked': {'vbd_eq_vbn': ''},
 'tagged': {'vbd_eq_vbn': ''},
 'tailed': {'vbd_eq_vbn': ''},
 'tailgated': {'vbd_eq_vbn': ''},
 'tailor-made': {'vbd_eq_vbn': ''},
 'tallied': {'vbd_eq_vbn': ''},
 'tamboured': {'vbd_eq_vbn': ''},
 'tamed': {'vbd_eq_vbn': ''},
 'tamped': {'vbd_eq_vbn': ''},
 'tampered': {'vbd_eq_vbn': ''},
 'Tancred': {'vbd_eq_vbn': ''},
 'tanged': {'vbd_eq_vbn': ''},
 'tangoed': {'vbd_eq_vbn': ''},
 'tanked': {'vbd_eq_vbn': ''},
 'tantalised': {'vbd_eq_vbn': ''},
 'tantalized': {'vbd_eq_vbn': ''},
 'tap-danced': {'vbd_eq_vbn': ''},
 'tape-recorded': {'vbd_eq_vbn': ''},
 'Targetted': {'vbd_eq_vbn': ''},
 'tariffed': {'vbd_eq_vbn': ''},
 'tarmacked': {'vbd_eq_vbn': ''},
 'tarnished': {'vbd_eq_vbn': ''},
 'tarred': {'vbd_eq_vbn': ''},
 'tarried': {'vbd_eq_vbn': ''},
 'tarted': {'vbd_eq_vbn': ''},
 'tased': {'vbd_eq_vbn': ''},
 'tasered': {'vbd_eq_vbn': ''},
 'tasked': {'vbd_eq_vbn': ''},
 'tasseled': {'vbd_eq_vbn': ''},
 'tasselled': {'vbd_eq_vbn': ''},
 'tatted': {'vbd_eq_vbn': ''},
 'tattled': {'vbd_eq_vbn': ''},
 'taught': {'vbd_eq_vbn': ''},
 'taunted': {'vbd_eq_vbn': ''},
 'tautened': {'vbd_eq_vbn': ''},
 'taxed': {'vbd_eq_vbn': ''},
 'taxied': {'vbd_eq_vbn': ''},
 'tazed': {'vbd_eq_vbn': ''},
 'teamed': {'vbd_eq_vbn': ''},
 'teased': {'vbd_eq_vbn': ''},
 'technologized': {'vbd_eq_vbn': ''},
 'teed': {'vbd_eq_vbn': ''},
 'teemed': {'vbd_eq_vbn': ''},
 'teetered': {'vbd_eq_vbn': ''},
 'teethed': {'vbd_eq_vbn': ''},
 'telecasted': {'vbd_eq_vbn': ''},
 'teleconferenced': {'vbd_eq_vbn': ''},
 'telegraphed': {'vbd_eq_vbn': ''},
 'telephoned': {'vbd_eq_vbn': ''},
 'telescoped': {'vbd_eq_vbn': ''},
 'televised': {'vbd_eq_vbn': ''},
 'telexed': {'vbd_eq_vbn': ''},
 'tempered': {'vbd_eq_vbn': ''},
 'temporised': {'vbd_eq_vbn': ''},
 'temporized': {'vbd_eq_vbn': ''},
 'tenanted': {'vbd_eq_vbn': ''},
 'tendered': {'vbd_eq_vbn': ''},
 'tenderised': {'vbd_eq_vbn': ''},
 'tenderized': {'vbd_eq_vbn': ''},
 'tensed': {'vbd_eq_vbn': ''},
 'tented': {'vbd_eq_vbn': ''},
 'tergiversated': {'vbd_eq_vbn': ''},
 'termed': {'vbd_eq_vbn': ''},
 'territorialised': {'vbd_eq_vbn': ''},
 'territorialized': {'vbd_eq_vbn': ''},
 'terrorised': {'vbd_eq_vbn': ''},
 'terrorized': {'vbd_eq_vbn': ''},
 'test-marketed': {'vbd_eq_vbn': ''},
 'testified': {'vbd_eq_vbn': ''},
 'tethered': {'vbd_eq_vbn': ''},
 'thawed': {'vbd_eq_vbn': ''},
 'theologised': {'vbd_eq_vbn': ''},
 'theologized': {'vbd_eq_vbn': ''},
 'theorised': {'vbd_eq_vbn': ''},
 'theorized': {'vbd_eq_vbn': ''},
 'thermoformed': {'vbd_eq_vbn': ''},
 'thickened': {'vbd_eq_vbn': ''},
 'thieved': {'vbd_eq_vbn': ''},
 'thimblerigged': {'vbd_eq_vbn': ''},
 'thirsted': {'vbd_eq_vbn': ''},
 'thoriated': {'vbd_eq_vbn': ''},
 'thrashed': {'vbd_eq_vbn': ''},
 'threepeated': {'vbd_eq_vbn': ''},
 'threshed': {'vbd_eq_vbn': ''},
 'thrived': {'vbd_eq_vbn': ''},
 'throbbed': {'vbd_eq_vbn': ''},
 'throned': {'vbd_eq_vbn': ''},
 'thronged': {'vbd_eq_vbn': ''},
 'throttled': {'vbd_eq_vbn': ''},
 'thrummed': {'vbd_eq_vbn': ''},
 'thudded': {'vbd_eq_vbn': ''},
 'thumbed': {'vbd_eq_vbn': ''},
 'thumped': {'vbd_eq_vbn': ''},
 'thundered': {'vbd_eq_vbn': ''},
 'thwacked': {'vbd_eq_vbn': ''},
 'thwarted': {'vbd_eq_vbn': ''},
 'ticked': {'vbd_eq_vbn': ''},
 'ticketed': {'vbd_eq_vbn': ''},
 'tickled': {'vbd_eq_vbn': ''},
 'tided': {'vbd_eq_vbn': ''},
 'tidied': {'vbd_eq_vbn': ''},
 'tie-dyed': {'vbd_eq_vbn': ''},
 'tiffed': {'vbd_eq_vbn': ''},
 'tightened': {'vbd_eq_vbn': ''},
 'tilled': {'vbd_eq_vbn': ''},
 'tillered': {'vbd_eq_vbn': ''},
 'Tilted': {'vbd_eq_vbn': ''},
 'timed': {'vbd_eq_vbn': ''},
 'timetabled': {'vbd_eq_vbn': ''},
 'tinctured': {'vbd_eq_vbn': ''},
 'tingled': {'vbd_eq_vbn': ''},
 'tinkered': {'vbd_eq_vbn': ''},
 'tinkled': {'vbd_eq_vbn': ''},
 'tinseled': {'vbd_eq_vbn': ''},
 'tinselled': {'vbd_eq_vbn': ''},
 'tippled': {'vbd_eq_vbn': ''},
 'tiptoed': {'vbd_eq_vbn': ''},
 'tithed': {'vbd_eq_vbn': ''},
 'titillated': {'vbd_eq_vbn': ''},
 'titivated': {'vbd_eq_vbn': ''},
 'tittered': {'vbd_eq_vbn': ''},
 'tittuped': {'vbd_eq_vbn': ''},
 'tittupped': {'vbd_eq_vbn': ''},
 'toadied': {'vbd_eq_vbn': ''},
 'toasted': {'vbd_eq_vbn': ''},
 'tobogganed': {'vbd_eq_vbn': ''},
 'toddled': {'vbd_eq_vbn': ''},
 'toed': {'vbd_eq_vbn': ''},
 'togged': {'vbd_eq_vbn': ''},
 'toggled': {'vbd_eq_vbn': ''},
 'toiled': {'vbd_eq_vbn': ''},
 'toked': {'vbd_eq_vbn': ''},
 'tokened': {'vbd_eq_vbn': ''},
 'tolerated': {'vbd_eq_vbn': ''},
 'tolled': {'vbd_eq_vbn': ''},
 'tomahawked': {'vbd_eq_vbn': ''},
 'toned': {'vbd_eq_vbn': ''},
 'tonged': {'vbd_eq_vbn': ''},
 'tongued': {'vbd_eq_vbn': ''},
 'tooled': {'vbd_eq_vbn': ''},
 'tooted': {'vbd_eq_vbn': ''},
 'tootled': {'vbd_eq_vbn': ''},
 'top-dressed': {'vbd_eq_vbn': ''},
 'toped': {'vbd_eq_vbn': ''},
 'topped': {'vbd_eq_vbn': ''},
 'toppled': {'vbd_eq_vbn': ''},
 'torched': {'vbd_eq_vbn': ''},
 'tormented': {'vbd_eq_vbn': ''},
 'torpedoed': {'vbd_eq_vbn': ''},
 'tortured': {'vbd_eq_vbn': ''},
 'tossed': {'vbd_eq_vbn': ''},
 'totaled': {'vbd_eq_vbn': ''},
 'totalled': {'vbd_eq_vbn': ''},
 'toted': {'vbd_eq_vbn': ''},
 'totted': {'vbd_eq_vbn': ''},
 'tottered': {'vbd_eq_vbn': ''},
 'touch-typed': {'vbd_eq_vbn': ''},
 'toughed': {'vbd_eq_vbn': ''},
 'toughened': {'vbd_eq_vbn': ''},
 'toured': {'vbd_eq_vbn': ''},
 'tourneyed': {'vbd_eq_vbn': ''},
 'touted': {'vbd_eq_vbn': ''},
 'towed': {'vbd_eq_vbn': ''},
 'toweled': {'vbd_eq_vbn': ''},
 'towelled': {'vbd_eq_vbn': ''},
 'towered': {'vbd_eq_vbn': ''},
 'toyed': {'vbd_eq_vbn': ''},
 'traced': {'vbd_eq_vbn': ''},
 'trademarked': {'vbd_eq_vbn': ''},
 'traditionalized': {'vbd_eq_vbn': ''},
 'traduced': {'vbd_eq_vbn': ''},
 'trafficked': {'vbd_eq_vbn': ''},
 'trailed': {'vbd_eq_vbn': ''},
 'trailered': {'vbd_eq_vbn': ''},
 'trained': {'vbd_eq_vbn': ''},
 'traipsed': {'vbd_eq_vbn': ''},
 'trammeled': {'vbd_eq_vbn': ''},
 'trammelled': {'vbd_eq_vbn': ''},
 'tramped': {'vbd_eq_vbn': ''},
 'trampled': {'vbd_eq_vbn': ''},
 'tranquilised': {'vbd_eq_vbn': ''},
 'tranquilized': {'vbd_eq_vbn': ''},
 'tranquillised': {'vbd_eq_vbn': ''},
 'tranquillized': {'vbd_eq_vbn': ''},
 'transacted': {'vbd_eq_vbn': ''},
 'transcended': {'vbd_eq_vbn': ''},
 'transcribed': {'vbd_eq_vbn': ''},
 'transferred': {'vbd_eq_vbn': ''},
 'transfigured': {'vbd_eq_vbn': ''},
 'transfused': {'vbd_eq_vbn': ''},
 'transgressed': {'vbd_eq_vbn': ''},
 'transistorised': {'vbd_eq_vbn': ''},
 'transistorized': {'vbd_eq_vbn': ''},
 'transited': {'vbd_eq_vbn': ''},
 'transitioned': {'vbd_eq_vbn': ''},
 'transliterated': {'vbd_eq_vbn': ''},
 'translocated': {'vbd_eq_vbn': ''},
 'transmigrated': {'vbd_eq_vbn': ''},
 'transmitted': {'vbd_eq_vbn': ''},
 'transmogrified': {'vbd_eq_vbn': ''},
 'transmuted': {'vbd_eq_vbn': ''},
 'transpired': {'vbd_eq_vbn': ''},
 'transplanted': {'vbd_eq_vbn': ''},
 'transported': {'vbd_eq_vbn': ''},
 'transposed': {'vbd_eq_vbn': ''},
 'transshipped': {'vbd_eq_vbn': ''},
 'transubstantiated': {'vbd_eq_vbn': ''},
 'trapanned': {'vbd_eq_vbn': ''},
 'trapped': {'vbd_eq_vbn': ''},
 'traumatised': {'vbd_eq_vbn': ''},
 'travailed': {'vbd_eq_vbn': ''},
 'traveled': {'vbd_eq_vbn': ''},
 'traversed': {'vbd_eq_vbn': ''},
 'travestied': {'vbd_eq_vbn': ''},
 'trawled': {'vbd_eq_vbn': ''},
 'treadled': {'vbd_eq_vbn': ''},
 'trebled': {'vbd_eq_vbn': ''},
 'treed': {'vbd_eq_vbn': ''},
 'trekked': {'vbd_eq_vbn': ''},
 'trembled': {'vbd_eq_vbn': ''},
 'trenched': {'vbd_eq_vbn': ''},
 'trended': {'vbd_eq_vbn': ''},
 'trepanned': {'vbd_eq_vbn': ''},
 'trephined': {'vbd_eq_vbn': ''},
 'trespassed': {'vbd_eq_vbn': ''},
 'triaged': {'vbd_eq_vbn': ''},
 'trialled': {'vbd_eq_vbn': ''},
 'triangulated': {'vbd_eq_vbn': ''},
 'triced': {'vbd_eq_vbn': ''},
 'tricked': {'vbd_eq_vbn': ''},
 'trickled': {'vbd_eq_vbn': ''},
 'trifled': {'vbd_eq_vbn': ''},
 'trigged': {'vbd_eq_vbn': ''},
 'triggered': {'vbd_eq_vbn': ''},
 'trilled': {'vbd_eq_vbn': ''},
 'trimmed': {'vbd_eq_vbn': ''},
 'tripled': {'vbd_eq_vbn': ''},
 'tripped': {'vbd_eq_vbn': ''},
 'triumphed': {'vbd_eq_vbn': ''},
 'trivialised': {'vbd_eq_vbn': ''},
 'trivialized': {'vbd_eq_vbn': ''},
 'trolled': {'vbd_eq_vbn': ''},
 'trolleyed': {'vbd_eq_vbn': ''},
 'trollied': {'vbd_eq_vbn': ''},
 'trooped': {'vbd_eq_vbn': ''},
 'trothed': {'vbd_eq_vbn': ''},
 'trotted': {'vbd_eq_vbn': ''},
 'trouble-shot': {'vbd_eq_vbn': ''},
 'troubleshot': {'vbd_eq_vbn': ''},
 'trounced': {'vbd_eq_vbn': ''},
 'trouped': {'vbd_eq_vbn': ''},
 'trousered': {'vbd_eq_vbn': ''},
 'troweled': {'vbd_eq_vbn': ''},
 'trowelled': {'vbd_eq_vbn': ''},
 'truanted': {'vbd_eq_vbn': ''},
 'trucked': {'vbd_eq_vbn': ''},
 'truckled': {'vbd_eq_vbn': ''},
 'trudged': {'vbd_eq_vbn': ''},
 'trued': {'vbd_eq_vbn': ''},
 'trumped': {'vbd_eq_vbn': ''},
 'trumpeted': {'vbd_eq_vbn': ''},
 'truncated': {'vbd_eq_vbn': ''},
 'trundled': {'vbd_eq_vbn': ''},
 'trussed': {'vbd_eq_vbn': ''},
 'trusteed': {'vbd_eq_vbn': ''},
 'trysted': {'vbd_eq_vbn': ''},
 'tsked': {'vbd_eq_vbn': ''},
 'tubbed': {'vbd_eq_vbn': ''},
 'tubed': {'vbd_eq_vbn': ''},
 'tucked': {'vbd_eq_vbn': ''},
 'tuckered': {'vbd_eq_vbn': ''},
 'tugged': {'vbd_eq_vbn': ''},
 'tumbled': {'vbd_eq_vbn': ''},
 'tumefied': {'vbd_eq_vbn': ''},
 'tuned': {'vbd_eq_vbn': ''},
 'tunned': {'vbd_eq_vbn': ''},
 'tunneled': {'vbd_eq_vbn': ''},
 'tunnelled': {'vbd_eq_vbn': ''},
 'tupped': {'vbd_eq_vbn': ''},
 'turbocharged': {'vbd_eq_vbn': ''},
 'turfed': {'vbd_eq_vbn': ''},
 'turpentined': {'vbd_eq_vbn': ''},
 'turtled': {'vbd_eq_vbn': ''},
 'tusked': {'vbd_eq_vbn': ''},
 'tussled': {'vbd_eq_vbn': ''},
 'tut-tutted': {'vbd_eq_vbn': ''},
 'tutored': {'vbd_eq_vbn': ''},
 'tutted': {'vbd_eq_vbn': ''},
 'twaddled': {'vbd_eq_vbn': ''},
 'twanged': {'vbd_eq_vbn': ''},
 'tweaked': {'vbd_eq_vbn': ''},
 'tweedled': {'vbd_eq_vbn': ''},
 'tweeted': {'vbd_eq_vbn': ''},
 'tweezed': {'vbd_eq_vbn': ''},
 'twerked': {'vbd_eq_vbn': ''},
 'twiddled': {'vbd_eq_vbn': ''},
 'twigged': {'vbd_eq_vbn': ''},
 'twilled': {'vbd_eq_vbn': ''},
 'twined': {'vbd_eq_vbn': ''},
 'twinged': {'vbd_eq_vbn': ''},
 'twinkled': {'vbd_eq_vbn': ''},
 'twinned': {'vbd_eq_vbn': ''},
 'twirled': {'vbd_eq_vbn': ''},
 'twitched': {'vbd_eq_vbn': ''},
 'twitted': {'vbd_eq_vbn': ''},
 'twittered': {'vbd_eq_vbn': ''},
 'two-timed': {'vbd_eq_vbn': ''},
 'type-cast': {'vbd_eq_vbn': ''},
 'typed': {'vbd_eq_vbn': ''},
 'typified': {'vbd_eq_vbn': ''},
 'tyrannised': {'vbd_eq_vbn': ''},
 'tyrannized': {'vbd_eq_vbn': ''},
 'uglified': {'vbd_eq_vbn': ''},
 'ullaged': {'vbd_eq_vbn': ''},
 'ultracentrifuged': {'vbd_eq_vbn': ''},
 'ululated': {'vbd_eq_vbn': ''},
 'umped': {'vbd_eq_vbn': ''},
 'umpired': {'vbd_eq_vbn': ''},
 'unbarred': {'vbd_eq_vbn': ''},
 'unbent': {'vbd_eq_vbn': ''},
 'unbosomed': {'vbd_eq_vbn': ''},
 'unbound': {'vbd_eq_vbn': ''},
 'unbraced': {'vbd_eq_vbn': ''},
 'unbuckled': {'vbd_eq_vbn': ''},
 'unbundled': {'vbd_eq_vbn': ''},
 'unburdened': {'vbd_eq_vbn': ''},
 'unbuttoned': {'vbd_eq_vbn': ''},
 'unchained': {'vbd_eq_vbn': ''},
 'unchurched': {'vbd_eq_vbn': ''},
 'unclad': {'vbd_eq_vbn': ''},
 'unclenched': {'vbd_eq_vbn': ''},
 'unclipped': {'vbd_eq_vbn': ''},
 'uncloaked': {'vbd_eq_vbn': ''},
 'unclocked': {'vbd_eq_vbn': ''},
 'unclogged': {'vbd_eq_vbn': ''},
 'uncoiled': {'vbd_eq_vbn': ''},
 'uncorked': {'vbd_eq_vbn': ''},
 'uncoupled': {'vbd_eq_vbn': ''},
 'uncovered': {'vbd_eq_vbn': ''},
 'uncurled': {'vbd_eq_vbn': ''},
 'undeceived': {'vbd_eq_vbn': ''},
 'underachieved': {'vbd_eq_vbn': ''},
 'underacted': {'vbd_eq_vbn': ''},
 'underbaked': {'vbd_eq_vbn': ''},
 'undercapitalised': {'vbd_eq_vbn': ''},
 'undercharged': {'vbd_eq_vbn': ''},
 'undercoated': {'vbd_eq_vbn': ''},
 'underestimated': {'vbd_eq_vbn': ''},
 'undergirded': {'vbd_eq_vbn': ''},
 'underinvested': {'vbd_eq_vbn': ''},
 'underlaid': {'vbd_eq_vbn': ''},
 'underlined': {'vbd_eq_vbn': ''},
 'undermined': {'vbd_eq_vbn': ''},
 'underpaid': {'vbd_eq_vbn': ''},
 'underperformed': {'vbd_eq_vbn': ''},
 'underpinned': {'vbd_eq_vbn': ''},
 'underplayed': {'vbd_eq_vbn': ''},
 'underproduced': {'vbd_eq_vbn': ''},
 'underquoted': {'vbd_eq_vbn': ''},
 'underreacted': {'vbd_eq_vbn': ''},
 'underreported': {'vbd_eq_vbn': ''},
 'underscored': {'vbd_eq_vbn': ''},
 'undersealed': {'vbd_eq_vbn': ''},
 'undershot': {'vbd_eq_vbn': ''},
 'undersold': {'vbd_eq_vbn': ''},
 'underspent': {'vbd_eq_vbn': ''},
 'understudied': {'vbd_eq_vbn': ''},
 'undervalued': {'vbd_eq_vbn': ''},
 'undraped': {'vbd_eq_vbn': ''},
 'undulated': {'vbd_eq_vbn': ''},
 'unearthed': {'vbd_eq_vbn': ''},
 'unfastened': {'vbd_eq_vbn': ''},
 'unfitted': {'vbd_eq_vbn': ''},
 'unfixed': {'vbd_eq_vbn': ''},
 'unfleshed': {'vbd_eq_vbn': ''},
 'unflushed': {'vbd_eq_vbn': ''},
 'unfolded': {'vbd_eq_vbn': ''},
 'unfrocked': {'vbd_eq_vbn': ''},
 'unfurled': {'vbd_eq_vbn': ''},
 'unhitched': {'vbd_eq_vbn': ''},
 'unhooked': {'vbd_eq_vbn': ''},
 'unhorsed': {'vbd_eq_vbn': ''},
 'unhusked': {'vbd_eq_vbn': ''},
 'unitised': {'vbd_eq_vbn': ''},
 'unitized': {'vbd_eq_vbn': ''},
 'universalised': {'vbd_eq_vbn': ''},
 'universalized': {'vbd_eq_vbn': ''},
 'unknotted': {'vbd_eq_vbn': ''},
 'unladed': {'vbd_eq_vbn': ''},
 'unlashed': {'vbd_eq_vbn': ''},
 'unlatched': {'vbd_eq_vbn': ''},
 'unlaxed': {'vbd_eq_vbn': ''},
 'unlearned': {'vbd_eq_vbn': ''},
 'unleashed': {'vbd_eq_vbn': ''},
 'unlinked': {'vbd_eq_vbn': ''},
 'unlived': {'vbd_eq_vbn': ''},
 'unloaded': {'vbd_eq_vbn': ''},
 'unlocked': {'vbd_eq_vbn': ''},
 'Unloved': {'vbd_eq_vbn': ''},
 'unmade': {'vbd_eq_vbn': ''},
 'unmasked': {'vbd_eq_vbn': ''},
 'unpacked': {'vbd_eq_vbn': ''},
 'unpegged': {'vbd_eq_vbn': ''},
 'unpicked': {'vbd_eq_vbn': ''},
 'unpinned': {'vbd_eq_vbn': ''},
 'unraveled': {'vbd_eq_vbn': ''},
 'unravelled': {'vbd_eq_vbn': ''},
 'unreeled': {'vbd_eq_vbn': ''},
 'unrolled': {'vbd_eq_vbn': ''},
 'unsaddled': {'vbd_eq_vbn': ''},
 'unsaid': {'vbd_eq_vbn': ''},
 'unsanctified': {'vbd_eq_vbn': ''},
 'unscrambled': {'vbd_eq_vbn': ''},
 'unscrewed': {'vbd_eq_vbn': ''},
 'unseated': {'vbd_eq_vbn': ''},
 'unshackled': {'vbd_eq_vbn': ''},
 'unsheathed': {'vbd_eq_vbn': ''},
 'unsnarled': {'vbd_eq_vbn': ''},
 'unspooled': {'vbd_eq_vbn': ''},
 'unsteadied': {'vbd_eq_vbn': ''},
 'unstrapped': {'vbd_eq_vbn': ''},
 'unstrung': {'vbd_eq_vbn': ''},
 'unstuck': {'vbd_eq_vbn': ''},
 'unstuffed': {'vbd_eq_vbn': ''},
 'untangled': {'vbd_eq_vbn': ''},
 'untaught': {'vbd_eq_vbn': ''},
 'unthawed': {'vbd_eq_vbn': ''},
 'unthought': {'vbd_eq_vbn': ''},
 'untied': {'vbd_eq_vbn': ''},
 'untwisted': {'vbd_eq_vbn': ''},
 'unveiled': {'vbd_eq_vbn': ''},
 'unwired': {'vbd_eq_vbn': ''},
 'unwound': {'vbd_eq_vbn': ''},
 'unwrapped': {'vbd_eq_vbn': ''},
 'unwrinkled': {'vbd_eq_vbn': ''},
 'unyoked': {'vbd_eq_vbn': ''},
 'unzipped': {'vbd_eq_vbn': ''},
 'upbraided': {'vbd_eq_vbn': ''},
 'upcast': {'vbd_eq_vbn': ''},
 'upchucked': {'vbd_eq_vbn': ''},
 'updated': {'vbd_eq_vbn': ''},
 'upended': {'vbd_eq_vbn': ''},
 'upgraded': {'vbd_eq_vbn': ''},
 'upheld': {'vbd_eq_vbn': ''},
 'uploaded': {'vbd_eq_vbn': ''},
 'upped': {'vbd_eq_vbn': ''},
 'uprooted': {'vbd_eq_vbn': ''},
 'upscaled': {'vbd_eq_vbn': ''},
 'upstaged': {'vbd_eq_vbn': ''},
 'upstarted': {'vbd_eq_vbn': ''},
 'upsurged': {'vbd_eq_vbn': ''},
 'upvoted': {'vbd_eq_vbn': ''},
 'Urged': {'vbd_eq_vbn': ''},
 'urinated': {'vbd_eq_vbn': ''},
 'ushered': {'vbd_eq_vbn': ''},
 'usurped': {'vbd_eq_vbn': ''},
 'utilised': {'vbd_eq_vbn': ''},
 'utilized': {'vbd_eq_vbn': ''},
 'uttered': {'vbd_eq_vbn': ''},
 'vacated': {'vbd_eq_vbn': ''},
 'vaccinated': {'vbd_eq_vbn': ''},
 'vacillated': {'vbd_eq_vbn': ''},
 'vacuumed': {'vbd_eq_vbn': ''},
 'vagabonded': {'vbd_eq_vbn': ''},
 'vailed': {'vbd_eq_vbn': ''},
 'valeted': {'vbd_eq_vbn': ''},
 'valuated': {'vbd_eq_vbn': ''},
 'valved': {'vbd_eq_vbn': ''},
 'vamped': {'vbd_eq_vbn': ''},
 'vandalised': {'vbd_eq_vbn': ''},
 'vandalized': {'vbd_eq_vbn': ''},
 'vanished': {'vbd_eq_vbn': ''},
 'vanned': {'vbd_eq_vbn': ''},
 'vanquished': {'vbd_eq_vbn': ''},
 'vaped': {'vbd_eq_vbn': ''},
 'vapored': {'vbd_eq_vbn': ''},
 'vaporised': {'vbd_eq_vbn': ''},
 'vaporized': {'vbd_eq_vbn': ''},
 'vapoured': {'vbd_eq_vbn': ''},
 'varityped': {'vbd_eq_vbn': ''},
 'varnished': {'vbd_eq_vbn': ''},
 'vatted': {'vbd_eq_vbn': ''},
 'vectored': {'vbd_eq_vbn': ''},
 'veered': {'vbd_eq_vbn': ''},
 'vegetated': {'vbd_eq_vbn': ''},
 'vegged': {'vbd_eq_vbn': ''},
 'vellicated': {'vbd_eq_vbn': ''},
 'vended': {'vbd_eq_vbn': ''},
 'veneered': {'vbd_eq_vbn': ''},
 'venerated': {'vbd_eq_vbn': ''},
 'venomed': {'vbd_eq_vbn': ''},
 'vented': {'vbd_eq_vbn': ''},
 'ventilated': {'vbd_eq_vbn': ''},
 'ventured': {'vbd_eq_vbn': ''},
 'verbalised': {'vbd_eq_vbn': ''},
 'verbalized': {'vbd_eq_vbn': ''},
 'verbified': {'vbd_eq_vbn': ''},
 'verged': {'vbd_eq_vbn': ''},
 'verified': {'vbd_eq_vbn': ''},
 'vermiculated': {'vbd_eq_vbn': ''},
 'versified': {'vbd_eq_vbn': ''},
 'vesiculated': {'vbd_eq_vbn': ''},
 'vestured': {'vbd_eq_vbn': ''},
 'vetoed': {'vbd_eq_vbn': ''},
 'vetted': {'vbd_eq_vbn': ''},
 'vialed': {'vbd_eq_vbn': ''},
 'vialled': {'vbd_eq_vbn': ''},
 'vibrated': {'vbd_eq_vbn': ''},
 'viced': {'vbd_eq_vbn': ''},
 'victimised': {'vbd_eq_vbn': ''},
 'victimized': {'vbd_eq_vbn': ''},
 'victualed': {'vbd_eq_vbn': ''},
 'victualled': {'vbd_eq_vbn': ''},
 'vided': {'vbd_eq_vbn': ''},
 'videoconferenced': {'vbd_eq_vbn': ''},
 'videoed': {'vbd_eq_vbn': ''},
 'videotaped': {'vbd_eq_vbn': ''},
 'vied': {'vbd_eq_vbn': ''},
 'Viewed': {'vbd_eq_vbn': ''},
 'vilified': {'vbd_eq_vbn': ''},
 'vindicated': {'vbd_eq_vbn': ''},
 'vinified': {'vbd_eq_vbn': ''},
 'violated': {'vbd_eq_vbn': ''},
 'visaed': {'vbd_eq_vbn': ''},
 'vised': {'vbd_eq_vbn': ''},
 'visioned': {'vbd_eq_vbn': ''},
 'visored': {'vbd_eq_vbn': ''},
 'visualised': {'vbd_eq_vbn': ''},
 'visualized': {'vbd_eq_vbn': ''},
 'vitalised': {'vbd_eq_vbn': ''},
 'vitalized': {'vbd_eq_vbn': ''},
 'vitaminised': {'vbd_eq_vbn': ''},
 'vitaminized': {'vbd_eq_vbn': ''},
 'vitiated': {'vbd_eq_vbn': ''},
 'vitrified': {'vbd_eq_vbn': ''},
 'vitrioled': {'vbd_eq_vbn': ''},
 'vitriolled': {'vbd_eq_vbn': ''},
 'vituperated': {'vbd_eq_vbn': ''},
 'vivified': {'vbd_eq_vbn': ''},
 'vizored': {'vbd_eq_vbn': ''},
 'vocalized': {'vbd_eq_vbn': ''},
 'voided': {'vbd_eq_vbn': ''},
 'volatilised': {'vbd_eq_vbn': ''},
 'volatilized': {'vbd_eq_vbn': ''},
 'volleyed': {'vbd_eq_vbn': ''},
 'volumised': {'vbd_eq_vbn': ''},
 'volumized': {'vbd_eq_vbn': ''},
 'volunteered': {'vbd_eq_vbn': ''},
 'vomited': {'vbd_eq_vbn': ''},
 'voodooed': {'vbd_eq_vbn': ''},
 'vouched': {'vbd_eq_vbn': ''},
 'voucherised': {'vbd_eq_vbn': ''},
 'voucherized': {'vbd_eq_vbn': ''},
 'vouchsafed': {'vbd_eq_vbn': ''},
 'vowed': {'vbd_eq_vbn': ''},
 'voyaged': {'vbd_eq_vbn': ''},
 'vulcanised': {'vbd_eq_vbn': ''},
 'vulcanized': {'vbd_eq_vbn': ''},
 'wadded': {'vbd_eq_vbn': ''},
 'waddled': {'vbd_eq_vbn': ''},
 'waded': {'vbd_eq_vbn': ''},
 'wafered': {'vbd_eq_vbn': ''},
 'waffled': {'vbd_eq_vbn': ''},
 'wafted': {'vbd_eq_vbn': ''},
 'wagered': {'vbd_eq_vbn': ''},
 'wagged': {'vbd_eq_vbn': ''},
 'waggled': {'vbd_eq_vbn': ''},
 'wailed': {'vbd_eq_vbn': ''},
 'wainscoted': {'vbd_eq_vbn': ''},
 'wait-listed': {'vbd_eq_vbn': ''},
 'waitlisted': {'vbd_eq_vbn': ''},
 'waitressed': {'vbd_eq_vbn': ''},
 'waived': {'vbd_eq_vbn': ''},
 'wakeboarded': {'vbd_eq_vbn': ''},
 'wakened': {'vbd_eq_vbn': ''},
 'waled': {'vbd_eq_vbn': ''},
 'walloped': {'vbd_eq_vbn': ''},
 'wallowed': {'vbd_eq_vbn': ''},
 'wallpapered': {'vbd_eq_vbn': ''},
 'waltzed': {'vbd_eq_vbn': ''},
 'wambled': {'vbd_eq_vbn': ''},
 'waned': {'vbd_eq_vbn': ''},
 'wangled': {'vbd_eq_vbn': ''},
 'wanned': {'vbd_eq_vbn': ''},
 'wantoned': {'vbd_eq_vbn': ''},
 'warbled': {'vbd_eq_vbn': ''},
 'warded': {'vbd_eq_vbn': ''},
 'wared': {'vbd_eq_vbn': ''},
 'warehoused': {'vbd_eq_vbn': ''},
 'warmed': {'vbd_eq_vbn': ''},
 'warranted': {'vbd_eq_vbn': ''},
 'warred': {'vbd_eq_vbn': ''},
 'wassailed': {'vbd_eq_vbn': ''},
 'water-skied': {'vbd_eq_vbn': ''},
 'watered': {'vbd_eq_vbn': ''},
 'watermarked': {'vbd_eq_vbn': ''},
 'wauled': {'vbd_eq_vbn': ''},
 'wavered': {'vbd_eq_vbn': ''},
 'waxed': {'vbd_eq_vbn': ''},
 'waylaid': {'vbd_eq_vbn': ''},
 'weakened': {'vbd_eq_vbn': ''},
 'weaned': {'vbd_eq_vbn': ''},
 'weaponized': {'vbd_eq_vbn': ''},
 'wearied': {'vbd_eq_vbn': ''},
 'weaseled': {'vbd_eq_vbn': ''},
 'weaselled': {'vbd_eq_vbn': ''},
 'weatherboarded': {'vbd_eq_vbn': ''},
 'weathered': {'vbd_eq_vbn': ''},
 'weatherstripped': {'vbd_eq_vbn': ''},
 'Wedged': {'vbd_eq_vbn': ''},
 'wee-weed': {'vbd_eq_vbn': ''},
 'weeded': {'vbd_eq_vbn': ''},
 'weekended': {'vbd_eq_vbn': ''},
 'weened': {'vbd_eq_vbn': ''},
 'Weighted': {'vbd_eq_vbn': ''},
 'weirded': {'vbd_eq_vbn': ''},
 'welched': {'vbd_eq_vbn': ''},
 'welded': {'vbd_eq_vbn': ''},
 'welled': {'vbd_eq_vbn': ''},
 'welshed': {'vbd_eq_vbn': ''},
 'welted': {'vbd_eq_vbn': ''},
 'weltered': {'vbd_eq_vbn': ''},
 'wenched': {'vbd_eq_vbn': ''},
 'wended': {'vbd_eq_vbn': ''},
 'wept': {'vbd_eq_vbn': ''},
 'westernised': {'vbd_eq_vbn': ''},
 'wetted': {'vbd_eq_vbn': ''},
 'whaled': {'vbd_eq_vbn': ''},
 'whammed': {'vbd_eq_vbn': ''},
 'whanged': {'vbd_eq_vbn': ''},
 'whapped': {'vbd_eq_vbn': ''},
 'wharfed': {'vbd_eq_vbn': ''},
 'wheedled': {'vbd_eq_vbn': ''},
 'wheezed': {'vbd_eq_vbn': ''},
 'whelmed': {'vbd_eq_vbn': ''},
 'whelped': {'vbd_eq_vbn': ''},
 'whetted': {'vbd_eq_vbn': ''},
 'whickered': {'vbd_eq_vbn': ''},
 'whiffed': {'vbd_eq_vbn': ''},
 'whiffled': {'vbd_eq_vbn': ''},
 'whiled': {'vbd_eq_vbn': ''},
 'whimpered': {'vbd_eq_vbn': ''},
 'whined': {'vbd_eq_vbn': ''},
 'whinnied': {'vbd_eq_vbn': ''},
 'whiplashed': {'vbd_eq_vbn': ''},
 'whipsawed': {'vbd_eq_vbn': ''},
 'whirled': {'vbd_eq_vbn': ''},
 'whirred': {'vbd_eq_vbn': ''},
 'whisked': {'vbd_eq_vbn': ''},
 'whistle-stopped': {'vbd_eq_vbn': ''},
 'whistled': {'vbd_eq_vbn': ''},
 'whited': {'vbd_eq_vbn': ''},
 'whitened': {'vbd_eq_vbn': ''},
 'whitewashed': {'vbd_eq_vbn': ''},
 'whittled': {'vbd_eq_vbn': ''},
 'whizzed': {'vbd_eq_vbn': ''},
 'wholesaled': {'vbd_eq_vbn': ''},
 'whomped': {'vbd_eq_vbn': ''},
 'whooped': {'vbd_eq_vbn': ''},
 'whooshed': {'vbd_eq_vbn': ''},
 'whopped': {'vbd_eq_vbn': ''},
 'whored': {'vbd_eq_vbn': ''},
 'whupped': {'vbd_eq_vbn': ''},
 'widened': {'vbd_eq_vbn': ''},
 'wielded': {'vbd_eq_vbn': ''},
 'wigged': {'vbd_eq_vbn': ''},
 'wiggled': {'vbd_eq_vbn': ''},
 'wigwagged': {'vbd_eq_vbn': ''},
 'wildcatted': {'vbd_eq_vbn': ''},
 'wildered': {'vbd_eq_vbn': ''},
 'wiled': {'vbd_eq_vbn': ''},
 'willed': {'vbd_eq_vbn': ''},
 'willowed': {'vbd_eq_vbn': ''},
 'wilted': {'vbd_eq_vbn': ''},
 'wimped': {'vbd_eq_vbn': ''},
 'wimpled': {'vbd_eq_vbn': ''},
 'winced': {'vbd_eq_vbn': ''},
 'winched': {'vbd_eq_vbn': ''},
 'windlassed': {'vbd_eq_vbn': ''},
 'windmilled': {'vbd_eq_vbn': ''},
 'window-shopped': {'vbd_eq_vbn': ''},
 'windsurfed': {'vbd_eq_vbn': ''},
 'wined': {'vbd_eq_vbn': ''},
 'winked': {'vbd_eq_vbn': ''},
 'winkled': {'vbd_eq_vbn': ''},
 'winnowed': {'vbd_eq_vbn': ''},
 'wintered': {'vbd_eq_vbn': ''},
 'wirelessed': {'vbd_eq_vbn': ''},
 'wiretapped': {'vbd_eq_vbn': ''},
 'wisecracked': {'vbd_eq_vbn': ''},
 'wised': {'vbd_eq_vbn': ''},
 'wisped': {'vbd_eq_vbn': ''},
 'wist': {'vbd_eq_vbn': ''},
 'witched': {'vbd_eq_vbn': ''},
 'withed': {'vbd_eq_vbn': ''},
 'withheld': {'vbd_eq_vbn': ''},
 'withstood': {'vbd_eq_vbn': ''},
 'witnessed': {'vbd_eq_vbn': ''},
 'wived': {'vbd_eq_vbn': ''},
 'wobbled': {'vbd_eq_vbn': ''},
 'wolf-whistled': {'vbd_eq_vbn': ''},
 'wolfed': {'vbd_eq_vbn': ''},
 'womanised': {'vbd_eq_vbn': ''},
 'womanized': {'vbd_eq_vbn': ''},
 'wooed': {'vbd_eq_vbn': ''},
 'woofed': {'vbd_eq_vbn': ''},
 'woolgathered': {'vbd_eq_vbn': ''},
 'wooshed': {'vbd_eq_vbn': ''},
 'work-hardened': {'vbd_eq_vbn': ''},
 'wormed': {'vbd_eq_vbn': ''},
 'worsened': {'vbd_eq_vbn': ''},
 'worshiped': {'vbd_eq_vbn': ''},
 'worshipped': {'vbd_eq_vbn': ''},
 'worsted': {'vbd_eq_vbn': ''},
 'wowed': {'vbd_eq_vbn': ''},
 'wracked': {'vbd_eq_vbn': ''},
 'wrangled': {'vbd_eq_vbn': ''},
 'wrapped': {'vbd_eq_vbn': ''},
 'wreaked': {'vbd_eq_vbn': ''},
 'wreathed': {'vbd_eq_vbn': ''},
 'wrenched': {'vbd_eq_vbn': ''},
 'wrested': {'vbd_eq_vbn': ''},
 'wrestled': {'vbd_eq_vbn': ''},
 'wricked': {'vbd_eq_vbn': ''},
 'wriggled': {'vbd_eq_vbn': ''},
 'writhed': {'vbd_eq_vbn': ''},
 'wrong-footed': {'vbd_eq_vbn': ''},
 'wronged': {'vbd_eq_vbn': ''},
 'wrought': {'vbd_eq_vbn': ''},
 'wrung': {'vbd_eq_vbn': ''},
 'X-rayed': {'vbd_eq_vbn': ''},
 'Xeroxed': {'vbd_eq_vbn': ''},
 'yachted': {'vbd_eq_vbn': ''},
 'yakked': {'vbd_eq_vbn': ''},
 'yammered': {'vbd_eq_vbn': ''},
 'yanked': {'vbd_eq_vbn': ''},
 'yapped': {'vbd_eq_vbn': ''},
 'yarded': {'vbd_eq_vbn': ''},
 'yarned': {'vbd_eq_vbn': ''},
 'yawed': {'vbd_eq_vbn': ''},
 'yawned': {'vbd_eq_vbn': ''},
 'yearned': {'vbd_eq_vbn': ''},
 'yeasted': {'vbd_eq_vbn': ''},
 'yelled': {'vbd_eq_vbn': ''},
 'yellowed': {'vbd_eq_vbn': ''},
 'yelped': {'vbd_eq_vbn': ''},
 'yenned': {'vbd_eq_vbn': ''},
 'yessed': {'vbd_eq_vbn': ''},
 'yielded': {'vbd_eq_vbn': ''},
 'yipped': {'vbd_eq_vbn': ''},
 'yo-yoed': {'vbd_eq_vbn': ''},
 'yodeled': {'vbd_eq_vbn': ''},
 'yodelled': {'vbd_eq_vbn': ''},
 'yoked': {'vbd_eq_vbn': ''},
 'yowled': {'vbd_eq_vbn': ''},
 'yukked': {'vbd_eq_vbn': ''},
 'zagged': {'vbd_eq_vbn': ''},
 'zapped': {'vbd_eq_vbn': ''},
 'zeroed': {'vbd_eq_vbn': ''},
 'zested': {'vbd_eq_vbn': ''},
 'zigged': {'vbd_eq_vbn': ''},
 'zigzagged': {'vbd_eq_vbn': ''},
 'zinced': {'vbd_eq_vbn': ''},
 'zincked': {'vbd_eq_vbn': ''},
 'zinged': {'vbd_eq_vbn': ''},
 'zipped': {'vbd_eq_vbn': ''},
 'zippered': {'vbd_eq_vbn': ''},
 'zizzed': {'vbd_eq_vbn': ''},
 'zombified': {'vbd_eq_vbn': ''},
 'zoomed': {'vbd_eq_vbn': ''}}


def feed_pika():
	import redis
	r = redis.Redis(host='dev.werror.com', db=0, port=8008,  decode_responses=True)
	for k, v in word_attr.items() :r.hmset(f"wordattr:{k}", v)
	print("done")

if __name__ == '__main__': 
	feed_pika()